"""Языковой пакет: Французский (Français)."""

LANG_FR = {
    "code": "fr",
    "name": "Français",

    "trigrams": [
        "les", "des", "ent", "que", "ion", "tion", "est", "ous",
        "ait", "our", "res", "men", "ant", "par", "eur", "con",
        "com", "une", "pas", "ete", "dans", "sur", "ave", "pou",
        "ont", "ais", "ell", "aux", "ess", "ien", "ire", "eme",
        "pre", "ait", "ons", "ans", "ous", "qui", "tre", "ais",
    ],

    "stop_words": {
        "le", "la", "les", "un", "une", "des", "de", "du",
        "et", "ou", "mais", "donc", "or", "ni", "car",
        "je", "tu", "il", "elle", "on", "nous", "vous", "ils", "elles",
        "me", "te", "se", "en", "y",
        "est", "sont", "a", "ont", "fait", "être", "avoir",
        "ce", "cette", "ces", "mon", "ma", "mes", "ton", "ta", "tes",
        "son", "sa", "ses", "notre", "votre", "leur", "leurs",
        "dans", "sur", "sous", "avec", "pour", "par", "sans",
        "ne", "pas", "plus", "que", "qui", "quoi", "dont",
        "si", "bien", "très", "moins", "aussi",
        "tout", "tous", "toute", "toutes", "autre", "autres",
        "ici", "là", "où", "quand", "comme", "même",
    },

    "bureaucratic": {
        "implémenter": ["mettre en place", "réaliser"],
        "optimiser": ["améliorer", "ajuster"],
        "conceptualiser": ["penser", "imaginer", "concevoir"],
        "finaliser": ["terminer", "finir", "achever"],
        "prioriser": ["privilégier", "favoriser"],
        "préconiser": ["recommander", "conseiller"],
        "appréhender": ["comprendre", "saisir"],
        "concrétiser": ["réaliser", "accomplir"],
        "matérialiser": ["réaliser", "produire"],
        "substantiel": ["important", "considérable", "notable"],
        "significatif": ["notable", "important", "marquant"],
        "fondamental": ["essentiel", "de base", "central"],
        "primordial": ["essentiel", "capital", "vital"],
        "inhérent": ["propre", "naturel", "lié"],
        "conséquent": ["important", "notable"],
        "adéquat": ["adapté", "convenable", "approprié"],
        "préalable": ["avant", "d'abord", "initial"],
        "subséquent": ["suivant", "après", "ultérieur"],
        "exhaustif": ["complet", "détaillé", "approfondi"],
        "innovant": ["nouveau", "novateur", "créatif"],
        "systématique": ["régulier", "ordonné", "méthodique"],
        "paradigme": ["modèle", "schéma", "cadre"],
        "pérenne": ["durable", "stable", "continu"],
        "catalyser": ["stimuler", "accélérer", "déclencher"],
        "corroborer": ["confirmer", "valider", "appuyer"],
        "prépondérant": ["dominant", "majeur", "principal"],
        "concomitant": ["simultané", "parallèle", "conjoint"],
        "holistique": ["global", "complet", "d'ensemble"],
        "paradigmatique": ["exemplaire", "typique", "modèle"],
        "contextualiser": ["situer", "replacer", "mettre en contexte"],
        "opérationnaliser": ["appliquer", "mettre en œuvre", "exécuter"],
        "problématiser": ["questionner", "interroger", "remettre en cause"],
        "dynamiser": ["relancer", "stimuler", "booster"],
        "pérenniser": ["stabiliser", "ancrer", "maintenir"],
        "rationnaliser": ["simplifier", "alléger", "réorganiser"],
        "mutualiser": ["partager", "mettre en commun", "regrouper"],
        "hiérarchiser": ["classer", "trier", "ordonner"],
        "valoriser": ["mettre en valeur", "promouvoir", "souligner"],
        "expliciter": ["préciser", "clarifier", "détailler"],
        "formaliser": ["officialiser", "codifier", "structurer"],
        "déployer": ["lancer", "étendre", "mettre en place"],
        "mobiliser": ["rassembler", "engager", "impliquer"],
        "identifier": ["repérer", "trouver", "reconnaître"],
        "synthétiser": ["résumer", "condenser"],
        "proactif": ["anticipé", "prévoyant", "dynamique"],
        "transversal": ["commun", "partagé", "interdisciplinaire"],
        "pluridisciplinaire": ["varié", "divers", "mixte"],
        "incontournable": ["essentiel", "nécessaire", "indispensable"],
        "prédominant": ["principal", "majeur", "dominant"],
        "récurrent": ["fréquent", "répétitif", "habituel"],
        "tangible": ["concret", "réel", "palpable"],
        "notoire": ["connu", "reconnu", "évident"],
        "prééminent": ["supérieur", "premier", "dominant"],
        "susceptible": ["capable", "à même", "en mesure"],
        "prégnant": ["fort", "marquant", "présent"],
        "spécifique": ["précis", "particulier", "propre"],
        "pertinent": ["adapté", "juste", "approprié"],
        "performant": ["efficace", "puissant", "productif"],
        "structurant": ["organisateur", "fondateur", "clé"],
        "impactant": ["marquant", "fort", "frappant"],
        # === v0.11.0 massive expansion ===
        "accentuer": ["renforcer", "souligner", "intensifier"],
        "accroître": ["augmenter", "développer", "amplifier"],
        "acquérir": ["obtenir", "gagner", "recevoir"],
        "administrer": ["gérer", "diriger", "piloter"],
        "agréger": ["rassembler", "regrouper", "réunir"],
        "allouer": ["attribuer", "distribuer", "assigner"],
        "arbitrer": ["trancher", "décider", "juger"],
        "articuler": ["organiser", "structurer", "relier"],
        "assimiler": ["intégrer", "absorber", "comprendre"],
        "authentifier": ["vérifier", "confirmer", "valider"],
        "automatiser": ["mécaniser", "informatiser"],
        "calibrer": ["ajuster", "régler", "adapter"],
        "capitaliser": ["profiter de", "exploiter", "tirer parti"],
        "canaliser": ["diriger", "orienter", "guider"],
        "caractériser": ["définir", "décrire", "qualifier"],
        "circonscrire": ["limiter", "délimiter", "borner"],
        "codifier": ["formaliser", "systématiser", "normaliser"],
        "compenser": ["équilibrer", "rattraper", "pallier"],
        "compiler": ["rassembler", "réunir", "collecter"],
        "consolider": ["renforcer", "affermir", "stabiliser"],
        "constituer": ["former", "composer", "représenter"],
        "coordonner": ["organiser", "harmoniser", "synchroniser"],
        "cristalliser": ["figer", "fixer", "concentrer"],
        "culminer": ["atteindre", "aboutir", "se terminer"],
        "décentraliser": ["répartir", "distribuer", "déléguer"],
        "démocratiser": ["rendre accessible", "ouvrir", "populariser"],
        "diagnostiquer": ["analyser", "évaluer", "identifier"],
        "différencier": ["distinguer", "séparer", "varier"],
        "digitaliser": ["numériser", "informatiser"],
        "disséminer": ["diffuser", "répandre", "propager"],
        "diversifier": ["varier", "élargir", "multiplier"],
        "documenter": ["consigner", "noter", "enregistrer"],
        "dupliquer": ["copier", "reproduire", "doubler"],
        "édicter": ["promulguer", "établir", "imposer"],
        "élaborer": ["construire", "préparer", "développer"],
        "émanciper": ["libérer", "affranchir"],
        "encadrer": ["superviser", "accompagner", "guider"],
        "engendrer": ["provoquer", "causer", "créer"],
        "envisager": ["prévoir", "considérer", "imaginer"],
        "éradiquer": ["supprimer", "éliminer", "extirper"],
        "évaluer": ["mesurer", "estimer", "juger"],
        "extrapoler": ["déduire", "supposer", "projeter"],
        "fédérer": ["unir", "rassembler", "regrouper"],
        "fluctuer": ["varier", "changer", "osciller"],
        "générer": ["créer", "produire", "provoquer"],
        "globaliser": ["mondialiser", "élargir", "étendre"],
        "harmoniser": ["accorder", "aligner", "unifier"],
        "homogénéiser": ["uniformiser", "standardiser"],
        "hypothéquer": ["compromettre", "risquer", "mettre en danger"],
        "illustrer": ["montrer", "démontrer", "exemplifier"],
        "instaurer": ["établir", "créer", "mettre en place"],
        "intensifier": ["renforcer", "accentuer", "amplifier"],
        "interagir": ["échanger", "communiquer", "collaborer"],
        "interpréter": ["comprendre", "analyser", "lire"],
        "investiguer": ["enquêter", "rechercher", "examiner"],
        "légitimer": ["justifier", "fonder", "appuyer"],
        "libéraliser": ["ouvrir", "assouplir", "déréguler"],
        "maximiser": ["augmenter", "optimiser", "accroître"],
        "médiatiser": ["diffuser", "communiquer", "rendre public"],
        "minimiser": ["réduire", "diminuer", "atténuer"],
        "moderniser": ["rénover", "actualiser", "renouveler"],
        "monopoliser": ["accaparer", "concentrer", "dominer"],
        "normaliser": ["standardiser", "réguler", "unifier"],
        "objectiver": ["mesurer", "quantifier", "évaluer"],
        "occulter": ["cacher", "masquer", "dissimuler"],
        "orchestrer": ["organiser", "coordonner", "diriger"],
        "pénaliser": ["punir", "sanctionner", "désavantager"],
        "planifier": ["organiser", "prévoir", "programmer"],
        "polariser": ["diviser", "concentrer", "opposer"],
        "positionner": ["placer", "situer", "disposer"],
        "potentialiser": ["renforcer", "amplifier", "décupler"],
        "préfigurer": ["annoncer", "anticiper", "présager"],
        "promouvoir": ["encourager", "soutenir", "favoriser"],
        "quantifier": ["mesurer", "chiffrer", "évaluer"],
        "radicaliser": ["durcir", "extrémiser", "intensifier"],
        "réactualiser": ["mettre à jour", "actualiser", "renouveler"],
        "réguler": ["contrôler", "encadrer", "modérer"],
        "réhabiliter": ["restaurer", "revaloriser", "rétablir"],
        "rentabiliser": ["rendre rentable", "amortir", "valoriser"],
        "restructurer": ["réorganiser", "refondre", "remodeler"],
        "révolutionner": ["transformer", "bouleverser", "changer"],
        "scénariser": ["planifier", "imaginer", "prévoir"],
        "sécuriser": ["protéger", "garantir", "assurer"],
        "segmenter": ["diviser", "découper", "classer"],
        "sensibiliser": ["informer", "alerter", "éveiller"],
        "standardiser": ["normaliser", "unifier", "uniformiser"],
        "stimuler": ["encourager", "motiver", "impulser"],
        "subsidiariser": ["déléguer", "répartir"],
        "synchroniser": ["aligner", "coordonner", "harmoniser"],
        "systématiser": ["généraliser", "organiser", "formaliser"],
        "territorialiser": ["localiser", "ancrer", "régionaliser"],
        "transférer": ["déplacer", "céder", "confier"],
        "transformer": ["changer", "modifier", "convertir"],
        "uniformiser": ["standardiser", "harmoniser", "homogénéiser"],
        "universaliser": ["généraliser", "étendre", "répandre"],
        "vérifier": ["contrôler", "valider", "confirmer"],
        "visualiser": ["voir", "imaginer", "représenter"],
        # === v0.12.0 expansion ===
        "abroger": ["annuler", "supprimer", "révoquer"],
        "accréditer": ["certifier", "valider", "autoriser"],
        "adjuger": ["attribuer", "accorder", "décerner"],
        "agrémenter": ["embellir", "enrichir", "compléter"],
        "alléguer": ["invoquer", "prétendre", "avancer"],
        "amorcer": ["commencer", "lancer", "initier"],
        "annihiler": ["détruire", "anéantir", "supprimer"],
        "apprécier": ["estimer", "évaluer", "juger"],
        "astreindre": ["obliger", "contraindre", "forcer"],
        "atténuer": ["réduire", "adoucir", "amortir"],
        "avaliser": ["approuver", "soutenir", "entériner"],
        "borner": ["limiter", "restreindre", "délimiter"],
        "cautionner": ["garantir", "appuyer", "soutenir"],
        "censurer": ["interdire", "supprimer", "couper"],
        "collationner": ["comparer", "vérifier", "confronter"],
        "concocter": ["préparer", "inventer", "élaborer"],
        "conditionner": ["déterminer", "influencer", "limiter"],
        "confisquer": ["saisir", "prendre", "retirer"],
        "décréter": ["décider", "ordonner", "imposer"],
        "délibérer": ["discuter", "réfléchir", "débattre"],
        "démystifier": ["clarifier", "simplifier", "expliquer"],
        "déprécier": ["dévaloriser", "diminuer", "réduire"],
        "déréguler": ["libéraliser", "assouplir", "ouvrir"],
        "déstabiliser": ["ébranler", "fragiliser", "affaiblir"],
        "discréditer": ["dénigrer", "critiquer", "remettre en cause"],
        "dissiper": ["disperser", "chasser", "faire disparaître"],
        "entériner": ["approuver", "confirmer", "ratifier"],
        "esquisser": ["ébaucher", "tracer", "dessiner"],
        "exacerber": ["aggraver", "intensifier", "amplifier"],
        "exempter": ["dispenser", "libérer", "affranchir"],
        "exiger": ["demander", "réclamer", "imposer"],
        "exonérer": ["dispenser", "libérer", "décharger"],
        "gratifier": ["récompenser", "offrir", "accorder"],
        "homologuer": ["certifier", "valider", "approuver"],
        "impératif": ["obligatoire", "nécessaire", "urgent"],
        "incriminer": ["accuser", "mettre en cause", "reprocher"],
        "inférer": ["déduire", "conclure", "supposer"],
        "insuffler": ["inspirer", "transmettre", "communiquer"],
        "juguler": ["freiner", "stopper", "endiguer"],
        "légiférer": ["réglementer", "réguler", "légaliser"],
        "mandater": ["charger", "missionner", "déléguer"],
        "neutraliser": ["annuler", "contrebalancer", "bloquer"],
        "notifier": ["informer", "signaler", "communiquer"],
        "obtempérer": ["obéir", "se conformer", "se soumettre"],
        "officialiser": ["rendre officiel", "formaliser", "confirmer"],
        "plébisciter": ["approuver", "soutenir", "choisir"],
        "prédestiner": ["vouer", "préparer", "destiner"],
        "préempter": ["anticiper", "devancer", "prévenir"],
        "prescrire": ["ordonner", "recommander", "imposer"],
        "promulguer": ["publier", "décréter", "proclamer"],
        "prospérer": ["réussir", "croître", "se développer"],
        "récuser": ["rejeter", "refuser", "contester"],
        "rémunérer": ["payer", "rétribuer", "indemniser"],
        "répertorier": ["lister", "cataloguer", "inventorier"],
        "réprimer": ["punir", "sanctionner", "stopper"],
        "résilier": ["annuler", "rompre", "mettre fin"],
        "ratifier": ["approuver", "confirmer", "valider"],
        "recenser": ["dénombrer", "compter", "inventorier"],
        "réif ier": ["concrétiser", "matérialiser"],
        "restreindre": ["limiter", "réduire", "borner"],
        "sauvegarder": ["protéger", "préserver", "garantir"],
        "stigmatiser": ["critiquer", "condamner", "dénoncer"],
        "subsidiaire": ["secondaire", "complémentaire", "annexe"],
        "supplanter": ["remplacer", "dépasser", "détrôner"],
        "tolérer": ["accepter", "supporter", "admettre"],
        "valider": ["confirmer", "approuver", "certifier"],
        "véhiculer": ["transmettre", "diffuser", "porter"],
    },

    "bureaucratic_phrases": {
        "il convient de noter": ["notons que", "on remarque que"],
        "il est à souligner": ["soulignons", "important:"],
        "force est de constater": ["on voit que", "clairement"],
        "dans le cadre de": ["dans", "pendant", "lors de"],
        "en vue de": ["pour", "afin de"],
        "à l'égard de": ["envers", "pour", "concernant"],
        "eu égard à": ["vu", "étant donné"],
        "au regard de": ["par rapport à", "face à"],
        "de manière significative": ["nettement", "clairement", "beaucoup"],
        "joue un rôle crucial": ["est très important", "compte beaucoup"],
        "revêt une importance": ["est important", "compte"],
        "il apparaît que": ["on voit que", "visiblement"],
        "il s'avère que": ["il se trouve que", "en fait"],
        "il importe de": ["il faut", "on doit"],
        "de prime abord": ["au premier regard", "d'emblée"],
        "en l'occurrence": ["ici", "dans ce cas"],
        "à cet effet": ["pour cela", "dans ce but"],
        "compte tenu de": ["vu", "étant donné", "sachant"],
        "en ce qui concerne": ["pour", "quant à", "au sujet de"],
        "d'ores et déjà": ["déjà", "dès maintenant"],
        "dans la mesure où": ["si", "tant que", "puisque"],
        "sous réserve de": ["à condition de", "si"],
        "en tout état de cause": ["quoi qu'il en soit", "dans tous les cas"],
        "à l'instar de": ["comme", "à la manière de"],
        "il est indéniable que": ["c'est sûr que", "sans doute"],
        "il n'est pas sans importance": ["c'est important", "cela compte"],
        "au demeurant": ["d'ailleurs", "par ailleurs", "du reste"],
        "de facto": ["en fait", "concrètement", "vraiment"],
        # === v0.11.0 massive expansion ===
        "en dépit de": ["malgré", "nonobstant"],
        "il résulte de": ["on voit que", "il découle que"],
        "il est à préciser que": ["précisons", "notons que"],
        "il y a lieu de": ["il faut", "on doit"],
        "il ressort de": ["il découle de", "on comprend que"],
        "dans l'optique de": ["pour", "afin de", "en vue de"],
        "au vu de": ["étant donné", "vu", "compte tenu de"],
        "moyennant": ["avec", "grâce à", "en échange de"],
        "eu égard aux": ["vu les", "étant donné les"],
        "faire l'objet de": ["subir", "connaître", "être soumis à"],
        "mettre en lumière": ["révéler", "montrer", "souligner"],
        "mettre en évidence": ["montrer", "révéler", "prouver"],
        "prendre en considération": ["considérer", "tenir compte de"],
        "procéder à": ["faire", "réaliser", "effectuer"],
        "avoir pour objet de": ["viser à", "chercher à"],
        "porter atteinte à": ["nuire à", "endommager", "compromettre"],
        # === v0.12.0 expansion ===
        "aller dans le sens de": ["soutenir", "appuyer", "confirmer"],
        "avoir trait à": ["concerner", "toucher à", "porter sur"],
        "donner lieu à": ["provoquer", "entraîner", "causer"],
        "en définitive": ["au final", "en fin de compte", "finalement"],
        "en vertu de": ["selon", "conformément à", "en application de"],
        "faire état de": ["mentionner", "signaler", "rapporter"],
        "il est légitime de": ["on peut", "il est justifié de"],
        "il est patent que": ["il est clair que", "c'est évident"],
        "il incombe de": ["il revient de", "il faut", "c'est à"],
        "il sied de": ["il convient de", "il faut", "on doit"],
        "mettre en exergue": ["souligner", "mettre en avant", "illustrer"],
        "mettre en œuvre": ["appliquer", "réaliser", "exécuter"],
        "passer en revue": ["examiner", "analyser", "parcourir"],
        "prendre acte de": ["noter", "enregistrer", "constater"],
        "répondre aux exigences": ["satisfaire", "remplir les critères"],
        "s'inscrire dans": ["faire partie de", "relever de", "appartenir à"],
        "se prévaloir de": ["se servir de", "invoquer", "utiliser"],
        "tenir lieu de": ["remplacer", "servir de", "faire office de"],
        "tirer parti de": ["profiter de", "exploiter", "utiliser"],
        "venir à bout de": ["surmonter", "résoudre", "vaincre"],
        "il n'est pas exclu que": ["il se peut que", "peut-être"],
        "en l'absence de": ["sans", "faute de", "par manque de"],
        "au préalable": ["d'abord", "avant", "en premier"],
        "à l'évidence": ["clairement", "de toute évidence", "manifestement"],
        "il n'en demeure pas moins que": ["toutefois", "néanmoins", "mais"],
    },

    "ai_connectors": {
        "En outre": ["De plus", "Aussi", "Par ailleurs"],
        "Néanmoins": ["Toutefois", "Cependant", "Mais", "Pourtant"],
        "Par conséquent": ["Donc", "Du coup", "Ainsi", "Alors"],
        "En revanche": ["Par contre", "Mais", "À l'inverse"],
        "De surcroît": ["En plus", "De plus", "Aussi"],
        "En définitive": ["Au final", "En fin de compte"],
        "Il convient de souligner": ["Notons", "À noter"],
        "Force est de constater": ["On voit que", "Clairement"],
        "Dans cette perspective": ["Ici", "Dans ce sens"],
        "À cet égard": ["À ce sujet", "Là-dessus"],
        "En somme": ["Bref", "En résumé", "Au fond"],
        "Subséquemment": ["Ensuite", "Puis", "Après"],
        "Qui plus est": ["En plus", "D'autant plus", "De plus"],
        "Cela étant dit": ["Mais", "Toutefois"],
        "Parallèlement": ["En même temps", "Aussi"],
        "Corrélativement": ["En lien", "Par rapport"],
        "Effectivement": ["En effet", "Oui", "C'est vrai"],
        "Fondamentalement": ["Au fond", "En fait", "En réalité"],
        "Indubitablement": ["Sans aucun doute", "Clairement"],
        "En l'espèce": ["Ici", "Dans ce cas précis"],
        # === v0.11.0 massive expansion ===
        "Il est impératif": ["Il faut", "On doit", "C'est essentiel"],
        "Il est à noter que": ["Notons que", "Remarquons que", "Signalons que"],
        "Il s'avère que": ["En fait", "Il se trouve que", "En réalité"],
        "De manière générale": ["En général", "Glob alement", "Dans l'ensemble"],
        "En premier lieu": ["D'abord", "Tout d'abord", "Pour commencer"],
        "En second lieu": ["Ensuite", "De plus", "Aussi"],
        "En dernier lieu": ["Enfin", "Pour finir", "Pour conclure"],
        "Il n'est pas sans intérêt": ["C'est intéressant", "Il est utile"],
        "Il va de soi que": ["Bien sûr", "Évidemment", "Naturellement"],
        "Conséquemment": ["Donc", "Ainsi", "Par conséquent"],
        "Non seulement": ["Pas uniquement", "Pas juste"],
        "En dépit de": ["Malgré", "Nonobstant", "En face de"],
        "Tout bien considéré": ["Au final", "En fin de compte", "Tout compte fait"],
        "Au demeurant": ["D'ailleurs", "Du reste", "Par ailleurs"],
        "Quoi qu'il en soit": ["De toute façon", "En tout cas", "Dans tous les cas"],
        "Certes": ["Bien sûr", "Évidemment", "Il est vrai"],
        "D'autant plus que": ["Surtout que", "D'autant que", "Vu que"],
        "En l'occurrence": ["Ici", "Dans ce cas", "En l'espèce"],
        "Pour conclure": ["En conclusion", "Pour finir", "En bref"],
        # === v0.12.0 expansion ===
        "Il est à signaler que": ["Notons que", "Précisons que"],
        "Force est d'admettre": ["Il faut reconnaître", "Avouons-le"],
        "Il est indéniable": ["C'est sûr", "Sans aucun doute", "Assurément"],
        "En tout état de cause": ["De toute façon", "Quoi qu'il arrive"],
        "En substance": ["En résumé", "Pour l'essentiel", "Au fond"],
        "Cela étant": ["Cependant", "Toutefois", "Néanmoins"],
        "Il appert que": ["Il apparaît que", "Il semble que", "On voit que"],
        "Toujours est-il que": ["Le fait est que", "Il reste que"],
        "D'emblée": ["Dès le départ", "Tout de suite", "D'abord"],
        "Il convient également de": ["Il faut aussi", "On doit aussi"],
        "Voire": ["Et même", "Voire même", "Ou plutôt"],
        "En filigrane": ["Indirectement", "Subtilement", "En arrière-plan"],
        "En aval": ["Ensuite", "Après", "Plus tard"],
        "En amont": ["Avant", "Au préalable", "D'abord"],
        "A fortiori": ["D'autant plus", "Plus encore", "Surtout"],
        "In fine": ["Finalement", "Au bout du compte", "En définitive"],
        "Mutatis mutandis": ["En adaptant", "Toutes proportions gardées"],
        "Stricto sensu": ["Au sens strict", "Strictement", "Précisément"],
        "Ipso facto": ["De ce fait", "Automatiquement", "Par le fait même"],
        "A contrario": ["Au contraire", "Inversement", "À l'opposé"],
        "En marge de": ["À côté de", "Parallèlement à", "En dehors de"],
        "Soit dit en passant": ["Au passage", "D'ailleurs", "Accessoirement"],
    },

    "synonyms": {
        "important": ["capital", "essentiel", "majeur", "notable"],
        "grand": ["vaste", "considérable", "immense"],
        "petit": ["réduit", "modeste", "faible"],
        "rapide": ["vite", "prompt", "agile"],
        "problème": ["difficulté", "souci", "obstacle", "défi"],
        "solution": ["réponse", "issue", "remède"],
        "résultat": ["bilan", "effet", "aboutissement"],
        "méthode": ["approche", "technique", "procédé"],
        "processus": ["démarche", "procédure", "parcours"],
        "objectif": ["but", "visée", "cible"],
        "avantage": ["atout", "plus", "bénéfice"],
        "développement": ["évolution", "progression", "essor"],
        "amélioration": ["progrès", "avancée", "gain"],
        "analyse": ["étude", "examen", "exploration"],
        "domaine": ["champ", "secteur", "sphère"],
        "efficace": ["performant", "productif", "utile"],
        "complexe": ["compliqué", "élaboré", "dense"],
        "moderne": ["actuel", "récent", "d'aujourd'hui"],
        "qualité": ["niveau", "valeur", "calibre"],
        "essentiel": ["fondamental", "crucial", "vital"],
        "situation": ["contexte", "cas", "scénario"],
        "stratégie": ["plan", "tactique", "approche"],
        "concept": ["idée", "notion", "principe"],
        "structure": ["cadre", "organisation", "architecture"],
        "capacité": ["aptitude", "compétence", "potentiel"],
        "influence": ["impact", "effet", "poids"],
        "perspective": ["vision", "point de vue", "angle"],
        "dynamique": ["mouvement", "élan", "tendance"],
        "élément": ["composant", "partie", "facteur"],
        "système": ["dispositif", "mécanisme", "ensemble"],
        "ressource": ["moyen", "atout", "outil"],
        "dimension": ["aspect", "facette", "côté"],
        "contexte": ["cadre", "environnement", "milieu"],
        "enjeu": ["défi", "question", "problématique"],
        "évolution": ["changement", "progrès", "transformation"],
        "contribution": ["apport", "participation", "aide"],
        "expérience": ["vécu", "pratique", "savoir-faire"],
        "également": ["aussi", "de même", "pareillement"],
        "nécessaire": ["indispensable", "requis", "obligatoire"],
        # === v0.11.0 massive expansion ===
        "nouveau": ["neuf", "récent", "inédit"],
        "nouvelle": ["neuve", "récente", "inédite"],
        "ancien": ["précédent", "passé", "d'avant"],
        "bon": ["positif", "satisfaisant", "convenable"],
        "mauvais": ["médiocre", "défavorable", "néfaste"],
        "fort": ["puissant", "robuste", "intense"],
        "faible": ["fragile", "léger", "ténu"],
        "simple": ["facile", "aisé", "élémentaire"],
        "difficile": ["ardu", "pénible", "délicat"],
        "vrai": ["exact", "authentique", "réel"],
        "faux": ["erroné", "inexact", "incorrect"],
        "souvent": ["fréquemment", "régulièrement", "couramment"],
        "toujours": ["constamment", "en permanence", "sans cesse"],
        "jamais": ["en aucun cas", "nullement", "point"],
        "parfois": ["de temps en temps", "occasionnellement", "à l'occasion"],
        "beaucoup": ["considérablement", "largement", "fortement"],
        "peu": ["faiblement", "légèrement", "modérément"],
        "très": ["fort", "extrêmement", "hautement"],
        "bien": ["correctement", "convenablement", "comme il faut"],
        "mal": ["incorrectement", "de travers", "piètrement"],
        "vite": ["rapidement", "promptement", "aussitôt"],
        "lentement": ["doucement", "progressivement", "petit à petit"],
        "maintenant": ["à présent", "en ce moment", "désormais"],
        "déjà": ["d'ores et déjà", "désormais", "dès à présent"],
        "encore": ["toujours", "de nouveau", "une fois de plus"],
        "donc": ["ainsi", "par conséquent", "de ce fait"],
        "aussi": ["également", "de même", "en outre"],
        "mais": ["cependant", "toutefois", "néanmoins"],
        "parce que": ["car", "puisque", "du fait que"],
        "idée": ["pensée", "concept", "proposition"],
        "changement": ["modification", "transformation", "évolution"],
        "décision": ["choix", "résolution", "option"],
        "raison": ["motif", "cause", "fondement"],
        "réussite": ["succès", "victoire", "accomplissement"],
        "difficulté": ["obstacle", "barrière", "complication"],
        "information": ["donnée", "renseignement", "indication"],
        "partie": ["portion", "fraction", "segment"],
        "groupe": ["équipe", "ensemble", "collectif"],
        "travail": ["activité", "tâche", "ouvrage"],
        "utiliser": ["employer", "se servir de", "recourir à"],
        "créer": ["fonder", "bâtir", "établir"],
        "montrer": ["révéler", "illustrer", "démontrer"],
        "comprendre": ["saisir", "cerner", "appréhender"],
        "obtenir": ["acquérir", "décrocher", "remporter"],
        "donner": ["fournir", "offrir", "apporter"],
        "permettre": ["autoriser", "rendre possible", "favoriser"],
        "chercher": ["rechercher", "explorer", "sonder"],
        "trouver": ["découvrir", "dénicher", "repérer"],
        "penser": ["croire", "estimer", "juger"],
        "dire": ["affirmer", "déclarer", "soutenir"],
        "faire": ["réaliser", "effectuer", "accomplir"],
        "voir": ["observer", "constater", "remarquer"],
        "savoir": ["connaître", "maîtriser", "être au courant"],
        # === v0.12.0 expansion ===
        "précis": ["exact", "rigoureux", "minutieux"],
        "clair": ["évident", "limpide", "net"],
        "stable": ["solide", "ferme", "constant"],
        "fréquent": ["courant", "habituel", "régulier"],
        "rare": ["peu fréquent", "exceptionnel", "inhabituel"],
        "léger": ["faible", "mince", "délicat"],
        "lourd": ["pesant", "massif", "encombrant"],
        "large": ["ample", "étendu", "spacieux"],
        "étroit": ["serré", "limité", "restreint"],
        "profond": ["intense", "avancé", "marqué"],
        "superficiel": ["léger", "sommaire", "rapide"],
        "probable": ["vraisemblable", "possible", "plausible"],
        "précoce": ["anticipé", "prématuré", "hâtif"],
        "tardif": ["retardé", "différé", "en retard"],
        "provisoire": ["temporaire", "passager", "intérimaire"],
        "définitif": ["final", "irréversible", "conclusif"],
        "partiel": ["incomplet", "fragmentaire", "limité"],
        "total": ["complet", "intégral", "entier"],
        "habituel": ["courant", "normal", "classique"],
        "particulier": ["spécifique", "propre", "singulier"],
        "général": ["global", "d'ensemble", "large"],
        "actuel": ["présent", "courant", "contemporain"],
        "réel": ["effectif", "concret", "véritable"],
        "potentiel": ["éventuel", "possible", "latent"],
        "constant": ["continu", "permanent", "régulier"],
        "variable": ["changeant", "instable", "fluctuant"],
        "bref": ["court", "concis", "succinct"],
        "long": ["étendu", "prolongé", "durable"],
        "risque": ["danger", "menace", "aléa"],
        "conséquence": ["résultat", "effet", "impact"],
        "condition": ["exigence", "critère", "prérequis"],
        "mesure": ["action", "démarche", "disposition"],
        "progrès": ["avancée", "amélioration", "gain"],
        "réponse": ["réaction", "solution", "retour"],
        "question": ["problème", "sujet", "interrogation"],
        "erreur": ["faute", "méprise", "bévue"],
        "avenir": ["futur", "lendemain", "perspective"],
        "réalité": ["fait", "vérité", "concret"],
        "rôle": ["fonction", "place", "mission"],
        "valeur": ["importance", "mérite", "prix"],
        "effet": ["impact", "résultat", "conséquence"],
        "proposer": ["suggérer", "offrir", "présenter"],
        "développer": ["élaborer", "agrandir", "enrichir"],
        "améliorer": ["perfectionner", "renforcer", "bonifier"],
        "réduire": ["diminuer", "baisser", "limiter"],
        "augmenter": ["accroître", "amplifier", "élever"],
        "atteindre": ["parvenir à", "arriver à", "toucher"],
        "garantir": ["assurer", "certifier", "promettre"],
        "soutenir": ["appuyer", "encourager", "aider"],
    },

    "sentence_starters": {
        "Ce": ["Cet", "Tel", "Un tel", "Pareil"],
        "Il": ["L'homme", "On", "Le sujet"],
        "Elle": ["La personne", "Cette femme", "On"],
        "Ils": ["Ceux-ci", "L'équipe", "Ces gens"],
        "Nous": ["Notre équipe", "L'équipe", "On"],
        "Le": ["Un", "Chaque", "Ce"],
        "La": ["Une", "Cette", "Chaque"],
        "Les": ["Des", "Ces", "Plusieurs"],
        "Dans": ["Au sein de", "En", "À travers"],
        "Pour": ["Afin de", "En vue de", "Quant à"],
        "En": ["Dans", "Au cours de", "Lors de"],
        "Cependant": ["Mais", "Toutefois", "Par contre"],
        "Toutefois": ["Néanmoins", "Mais", "Cependant"],
        "Ainsi": ["De cette façon", "Donc", "Par conséquent"],
        "Or": ["Mais", "Pourtant", "Cependant"],
        "Bien que": ["Même si", "Quoique", "Malgré le fait que"],
        # === v0.11.0 massive expansion ===
        "Cette": ["Une telle", "Pareille", "La"],
        "Ces": ["De tels", "Pareils", "Les"],
        "Chaque": ["Tout", "N'importe quel", "Chacun des"],
        "Tous": ["L'ensemble", "Chacun", "Tous sans exception"],
        "On": ["Nous", "Les gens", "Chacun"],
        "Après": ["Suite à", "Une fois", "Lorsque"],
        "Avant": ["Préalablement", "D'abord", "En amont"],
        "Quand": ["Lorsque", "Dès que", "Au moment où"],
        "Si": ["Au cas où", "Dans l'hypothèse où", "Lorsque"],
        "Mais": ["Cependant", "Toutefois", "Néanmoins"],
        "Et": ["De plus", "Aussi", "En outre"],
        "Donc": ["Ainsi", "Par conséquent", "De ce fait"],
        "D'abord": ["En premier lieu", "Tout d'abord", "Avant tout"],
        "Ensuite": ["Puis", "Après", "Par la suite"],
        "Enfin": ["Pour finir", "En dernier lieu", "Pour conclure"],
        "D'ailleurs": ["Du reste", "Par ailleurs", "Au demeurant"],
        "Pourtant": ["Cependant", "Malgré tout", "Toutefois"],
        "Peut-être": ["Probablement", "Sans doute", "Vraisemblablement"],
        "Aujourd'hui": ["De nos jours", "Actuellement", "À l'époque actuelle"],
        "Ici": ["À cet endroit", "En ce lieu", "Là"],
        "Souvent": ["Fréquemment", "Régulièrement", "Bien des fois"],
        "Parfois": ["De temps en temps", "À l'occasion", "Il arrive que"],
        # === v0.12.0 expansion ===
        "Désormais": ["Dorénavant", "À partir de maintenant", "À l'avenir"],
        "Assurément": ["Certainement", "Sans doute", "Bien sûr"],
        "Manifestement": ["Visiblement", "De toute évidence", "Clairement"],
        "Généralement": ["En général", "D'habitude", "Le plus souvent"],
        "Initialement": ["Au début", "Au commencement", "D'abord"],
        "Finalement": ["Au final", "Pour finir", "En définitive"],
        "Curieusement": ["De façon surprenante", "Étonnamment", "Bizarrement"],
        "Heureusement": ["Par chance", "Fort heureusement", "Par bonheur"],
        "Malheureusement": ["Hélas", "Par malheur", "Tristement"],
        "Probablement": ["Sans doute", "Vraisemblablement", "Il est probable que"],
        "Précisément": ["Justement", "Exactement", "Pile"],
    },

    "colloquial_markers": [
        "franchement", "en fait", "au fond", "à vrai dire",
        "disons", "en gros", "avouons-le", "entre nous",
        "pour tout dire", "à bien y réfléchir",
        "curieusement", "étonnamment", "tout bien considéré",
        "soit dit en passant", "au passage", "notons au passage",
        "bref", "bon", "personnellement", "honnêtement",
        "en clair", "je dirais que", "il faut bien dire que",
        "chapeau bas", "carrément", "c'est un fait",
        # === v0.11.0 massive expansion ===
        "à mon avis", "à mon sens", "au juste",
        "autrement dit", "c'est-à-dire", "comment dire",
        "croyez-le ou non", "d'un certain point de vue",
        "disons-le", "en d'autres termes", "en quelque sorte",
        "en réalité", "en somme", "entre vous et moi",
        "en un mot", "écoutez", "figurez-vous",
        "force est d'admettre", "il faut reconnaître",
        "il va sans dire", "j'ai l'impression que",
        "je pense que", "l'important c'est", "mettons",
        "n'empêche", "notez bien", "objectivement",
        "pour ma part", "pour tout vous dire",
        "reconnaissons-le", "sans blague", "sans rire",
        "si j'ose dire", "si l'on veut", "si vous voulez",
        "sincèrement", "tenez", "voyez-vous",
        "vous savez", "il n'empêche que",
        # === v0.12.0 expansion ===
        "tout bien réfléchi", "ne nous voilons pas la face",
        "sans vouloir être méchant", "tout simplement",
        "d'une certaine manière", "en toute sincérité",
        "soyons clairs", "je m'explique",
        "reconnaissons-le", "entre parenthèses",
        "il faut bien l'admettre", "disons les choses",
        "ne nous leurrons pas", "sans détour",
        "pour parler clairement", "pas de doute",
        "c'est un fait", "il faut le dire",
        "soyons honnêtes", "tout de même",
    ],

    "abbreviations": [
        "M.", "Mme.", "Dr.", "Prof.", "etc.", "p. ex.",
        "c.-à-d.", "cf.", "vol.", "éd.", "fig.", "chap.",
        "Cie.", "Sté.", "av.", "bd.", "sq.", "réf.",
        "env.", "max.", "min.", "resp.", "tél.",
        "N.B.", "P.S.", "no.", "dépt.", "supp.", "dir.",
        "adj.", "adm.", "gouv.", "part.", "prov.",
        # === v0.11.0 massive expansion ===
        "apr.", "art.", "auj.", "bibl.", "bull.",
        "coll.", "conf.", "coord.", "dép.", "doc.",
        "éd.", "ex.", "fasc.", "gén.", "hab.",
        "ibid.", "id.", "inf.", "introd.", "j.",
        "livr.", "loc. cit.", "ms.", "n.", "obs.",
        "op. cit.", "p.", "parag.", "pl.", "préf.",
        "publ.", "rédact.", "rév.", "s.", "sect.",
        "suppl.", "supra", "t.", "trad.", "var.",
    ],

    "perplexity_boosters": [
        "ma foi", "somme toute", "tant s'en faut",
        "nolens volens", "de facto", "ipso facto",
        "curieusement", "paradoxalement", "soit dit en passant",
        "autrement dit", "à tout prendre", "en l'occurrence",
        "il n'empêche que", "bon gré mal gré", "peu ou prou",
        "en quelque sorte", "pour ainsi dire", "à la rigueur",
        "toujours est-il que", "quand bien même",
        "force est d'admettre", "à l'évidence",
        "c'est le moins qu'on puisse dire", "à bien des égards",
        "n'en déplaise", "quoi qu'il en coûte",
        # === v0.11.0 massive expansion ===
        "à plus forte raison", "à proprement parler",
        "à y regarder de plus près", "au demeurant",
        "au sens propre", "bien entendu", "bon an mal an",
        "c'est bien le moins", "chose curieuse",
        "comme de juste", "contrairement à ce qu'on pourrait croire",
        "coûte que coûte", "d'aucuns diraient",
        "de prime abord", "en bonne logique",
        "en dépit du bon sens", "en fin de compte",
        "en toute franchise", "entre les lignes",
        "fait notable", "il n'est pas inutile de rappeler",
        "loin s'en faut", "nul doute que",
        "on ne saurait", "par ailleurs", "sans conteste",
        "soit", "tant bien que mal",
        "tout compte fait", "trève de plaisanteries",
        # === v0.12.0 expansion ===
        "en toute rigueur", "il n'est pas inutile de",
        "tout bien pesé", "contrè toute attente",
        "en dépit des apparences", "mine de rien",
        "loin de là", "force est de reconnaître",
        "ne fût-ce que", "comme de bien entendu",
        "il n'empêche", "soit dit entre nous",
        "en y réfléchissant bien", "la question se pose",
        "dans un sens", "en toute humilité",
        "reconnaissons-le", "avouons-le",
        "sur le fond", "en creux",
    ],

    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    "conjunctions": ["et", "mais", "ou", "car", "donc", "puis"],

    "split_conjunctions": [
        " et ", " mais ", " cependant ", " tandis que ",
        " bien que ", " car ", " puisque ",
        " néanmoins ", " toutefois ", " pourtant ",
        " en revanche ", " par contre ", " quoique ",
        # === v0.11.0 massive expansion ===
        ", et ", ", mais ", ", car ",
        ", puisque ", ", donc ", ", or ",
        ", cependant ", ", toutefois ", ", néanmoins ",
        ", si bien que ", ", de sorte que ",
        ", après quoi ", ", alors que ",
        ", c'est-à-dire ", ", autrement dit ",
        "; ", " – ", " — ",
    ],
}
