"""Языковой пакет: Польский (Polski)."""

LANG_PL = {
    "code": "pl",
    "name": "Polski",

    "trigrams": [
        "nie", "prz", "ych", "nia", "prze", "rze", "sta", "owa",
        "ani", "tego", "jak", "kie", "czy", "pod", "icz", "est",
        "dzi", "osc", "icz", "ost", "rzy", "sze", "nia", "sto",
        "ale", "jes", "ich", "teg", "naw", "ier", "raj", "ien",
        "acz", "pow", "czn", "owy", "ter", "ści", "rod", "zna",
    ],

    "stop_words": {
        "i", "w", "na", "z", "do", "o", "się", "to", "nie",
        "jest", "że", "ale", "jak", "po", "za", "od", "tak",
        "ten", "ta", "te", "tym", "tego", "tej",
        "on", "ona", "ono", "my", "wy", "oni", "one",
        "co", "kto", "gdzie", "kiedy", "dlaczego",
        "być", "mieć", "mógł", "musi", "może",
        "już", "jeszcze", "też", "także", "bardzo",
        "wszystko", "każdy", "inny", "tylko",
        "tu", "tam", "teraz", "wtedy", "potem",
        "ich", "jej", "jego", "nasz", "wasz",
        "który", "która", "które", "których",
        "przez", "między", "pod", "nad", "przed",
        "bo", "więc", "gdyż", "gdy", "aby",
    },

    "bureaucratic": {
        "implementować": ["wdrożyć", "wprowadzić", "zastosować"],
        "optymalizować": ["ulepszać", "poprawiać", "doskonalić"],
        "ewaluować": ["oceniać", "sprawdzać"],
        "koordynować": ["organizować", "zarządzać"],
        "finalizować": ["kończyć", "zamykać", "dobijać"],
        "generować": ["tworzyć", "wytwarzać", "produkować"],
        "determinować": ["określać", "wyznaczać", "decydować"],
        "inicjować": ["rozpoczynać", "zaczynać", "wszczynać"],
        "dedykować": ["poświęcać", "przeznaczać"],
        "znacząco": ["wyraźnie", "odczuwalnie", "mocno"],
        "fundamentalny": ["podstawowy", "zasadniczy", "kluczowy"],
        "innowacyjny": ["nowy", "nowatorski", "twórczy"],
        "kompleksowy": ["pełny", "wszechstronny", "całościowy"],
        "kluczowy": ["główny", "najważniejszy", "centralny"],
        "zasadniczy": ["główny", "podstawowy", "istotny"],
        "komplementarny": ["uzupełniający", "dodatkowy"],
        "adekwatny": ["odpowiedni", "stosowny", "właściwy"],
        "priorytetowy": ["najważniejszy", "główny", "pilny"],
        # === v0.10.0 ===
        "kontekstualizować": ["umieścić w kontekście", "osadzić", "usytuować"],
        "operacjonalizować": ["wdrożyć", "zastosować", "uruchomić"],
        "problematyzować": ["kwestionować", "podważać", "dyskutować"],
        "dynamizować": ["ożywiać", "pobudzać", "stymulować"],
        "racjonalizować": ["upraszczać", "porządkować", "reorganizować"],
        "strukturyzować": ["organizować", "porządkować", "układać"],
        "artykułować": ["wyrażać", "formułować", "komunikować"],
        "waloryzować": ["doceniać", "podnosić wartość", "promować"],
        "eksplicytować": ["wyjaśniać", "precyzować", "doprecyzować"],
        "formalizować": ["oficjalizować", "kodyfikować", "normować"],
        "mobilizować": ["angażować", "gromadzić", "aktywizować"],
        "identyfikować": ["rozpoznawać", "znajdować", "określać"],
        "syntetyzować": ["podsumowywać", "streszczać", "skracać"],
        "proaktywny": ["wyprzedzający", "zapobiegawczy", "aktywny"],
        "wielowymiarowy": ["różnorodny", "zróżnicowany", "wieloaspektowy"],
        "substancjalny": ["istotny", "znaczny", "poważny"],
        "inherentny": ["wrodzony", "właściwy", "nieodłączny"],
        "pragmatyczny": ["praktyczny", "rzeczowy", "konkretny"],
        "integracyjny": ["łączący", "scalający", "spajający"],
        "paradygmatyczny": ["wzorcowy", "modelowy", "przykładowy"],
        "kongruencyjny": ["spójny", "zgodny", "koherentny"],
        "relewantny": ["istotny", "odpowiedni", "ważny"],
        "eksponencjalny": ["gwałtowny", "szybki", "lawinowy"],
        "systemowy": ["ogólny", "całościowy", "globalny"],
        "interdyscyplinarny": ["wielodyscyplinarny", "przekrojowy"],
        "transparentny": ["przejrzysty", "jawny", "otwarty"],
        "holistyczny": ["całościowy", "pełny", "globalny"],
        # === v0.11.0 massive expansion ===
        "aktualizować": ["uaktualniać", "odświeżać", "uaktualniać dane"],
        "antycypować": ["przewidywać", "uprzedzać", "oczekiwać"],
        "aprobować": ["zgadzać się", "akceptować", "popierać"],
        "autoryzować": ["zatwierdzać", "upoważniać", "dopuszczać"],
        "centralizować": ["skupiać", "łączyć", "gromadzić"],
        "certyfikować": ["poświadczać", "zatwierdzać", "atestować"],
        "definiować": ["określać", "opisywać", "precyzować"],
        "delegować": ["przekazywać", "zlecać", "powierzać"],
        "deprecjonować": ["umniejszać", "obniżać", "pomniejszać"],
        "destabilizować": ["zaburzać", "zachwiać", "osłabiać"],
        "diagnozować": ["rozpoznawać", "badać", "wykrywać"],
        "dystrybuować": ["rozprowadzać", "rozdawać", "dostarczać"],
        "ekonomizować": ["oszczędzać", "ograniczać koszty"],
        "eliminować": ["usuwać", "wykreślać", "pozbywać się"],
        "emitować": ["wysyłać", "wydawać", "nadawać"],
        "eskalować": ["nasilać", "zaostrzać", "wzmagać"],
        "ewidencjonować": ["rejestrować", "zapisywać", "notować"],
        "eksploatować": ["wykorzystywać", "użytkować", "używać"],
        "facylitować": ["ułatwiać", "wspomagać", "pomagać"],
        "forsować": ["wymuszać", "naciskać", "przeforsowywać"],
        "gwarantować": ["zapewniać", "ręczyć", "obiecywać"],
        "harmonizować": ["uzgadniać", "dostosowywać", "łączyć"],
        "hierarchizować": ["porządkować", "klasyfikować", "rangować"],
        "indeksować": ["katalogować", "porządkować", "spisywać"],
        "inkorporować": ["włączać", "przyłączać", "wchłaniać"],
        "intensyfikować": ["wzmagać", "nasilać", "wzmacniać"],
        "internalizować": ["przyswajać", "uwewnętrzniać"],
        "interpretować": ["tłumaczyć", "wyjaśniać", "objaśniać"],
        "interweniować": ["wkraczać", "reagować", "wtrącać się"],
        "kategoryzować": ["klasyfikować", "sortować", "grupować"],
        "kompensować": ["wyrównywać", "nadrabiać", "rekompensować"],
        "konsolidować": ["łączyć", "scalać", "umacniać"],
        "konsultować": ["radzić się", "pytać", "omawiać"],
        "kontemplować": ["rozważać", "rozmyślać", "zastanawiać się"],
        "kontestować": ["kwestionować", "podważać", "sprzeciwiać się"],
        "konkretyzować": ["doprecyzować", "uściślić", "sprecyzować"],
        "kreować": ["tworzyć", "budować", "kształtować"],
        "kwantyfikować": ["liczyć", "mierzyć", "obliczać"],
        "legalizować": ["zatwierdzać", "dopuszczać", "uznawać"],
        "legitymizować": ["uzasadniać", "uprawomocniać"],
        "liberalizować": ["rozluźniać", "łagodzić", "poluzowywać"],
        "limitować": ["ograniczać", "hamować", "zmniejszać"],
        "lokalizować": ["znajdować", "umieszczać", "ustalać"],
        "manifestować": ["pokazywać", "ujawniać", "okazywać"],
        "marginalizować": ["pomijać", "odsuwać", "bagatelizować"],
        "mediować": ["pośredniczyć", "rozjemcować", "godzić"],
        "modelować": ["kształtować", "formować", "budować"],
        "modernizować": ["unowocześniać", "odnawiać", "ulepszać"],
        "modyfikować": ["zmieniać", "przerabiać", "dostosowywać"],
        "monopolizować": ["zdominować", "przejąć", "opanować"],
        "motywować": ["zachęcać", "pobudzać", "inspirować"],
        "negocjować": ["ustalać", "dogadywać się", "pertraktować"],
        "neutralizować": ["niwelować", "osłabiać", "znosić"],
        "nominować": ["mianować", "wyznaczać", "wskazywać"],
        "normalizować": ["porządkować", "regulować", "ujednolicać"],
        "notyfikować": ["powiadamiać", "zawiadamiać", "informować"],
        "obligować": ["zobowiązywać", "nakazywać", "wymuszać"],
        "parametryzować": ["ustawiać", "konfigurować", "dobierać"],
        "partycypować": ["uczestniczyć", "brać udział", "angażować się"],
        "penalizować": ["karać", "sankcjonować", "grzywną obciążać"],
        "personalizować": ["dostosowywać", "indywidualizować"],
        "polaryzować": ["dzielić", "różnicować", "rozdzielać"],
        "popularyzować": ["promować", "upowszechniać", "szerzyć"],
        "postulować": ["proponować", "żądać", "domagać się"],
        "preferować": ["wolić", "wybierać", "faworyzować"],
        "prezentować": ["pokazywać", "przedstawiać", "demonstrować"],
        "prognozować": ["przewidywać", "szacować", "wróżyć"],
        "prolongować": ["przedłużać", "odwlekać", "odsuwać"],
        "redefiniować": ["na nowo określać", "zmieniać", "przekształcać"],
        "redukować": ["zmniejszać", "ograniczać", "obniżać"],
        "reformować": ["przebudowywać", "zmieniać", "naprawiać"],
        "regenerować": ["odnawiać", "odbudowywać", "naprawiać"],
        "regulować": ["kontrolować", "sterować", "korygować"],
        "rekomendować": ["polecać", "proponować", "doradzać"],
        "rekonstruować": ["odtwarzać", "odbudowywać", "przywracać"],
        "relokować": ["przenosić", "przemieszczać", "przesiedlać"],
        "restrukturyzować": ["reorganizować", "przebudowywać", "zmieniać"],
        "selekcjonować": ["wybierać", "dobierać", "przebierać"],
        "stymulować": ["pobudzać", "zachęcać", "ożywiać"],
        "sugerować": ["proponować", "podpowiadać", "naprowadzać"],
        "transferować": ["przenosić", "przekazywać", "przesyłać"],
        "transformować": ["zmieniać", "przekształcać", "przerabiać"],
        "unifikować": ["ujednolicać", "standaryzować", "zunifikować"],
        "walidować": ["sprawdzać", "potwierdzać", "weryfikować"],
        "weryfikować": ["sprawdzać", "kontrolować", "potwierdzać"],
        "wizualizować": ["obrazować", "unaoczniać", "pokazywać"],
        "konfigurować": ["ustawiać", "dostosowywać", "regulować"],
        "dezaktywować": ["wyłączać", "zatrzymywać", "odłączać"],
        "konceptualizować": ["wymyślać", "planować", "projektować"],
        "materializować": ["urzeczywistniać", "wcielać w życie"],
        "dywersyfikować": ["różnicować", "urozmaicać", "rozszerzać"],
        "standaryzować": ["ujednolicać", "normować", "porządkować"],
        "akceptowalny": ["do przyjęcia", "dopuszczalny", "znośny"],
        "alternatywny": ["inny", "zastępczy", "zamienny"],
        "ambiwalentny": ["niejednoznaczny", "dwuznaczny", "niezdecydowany"],
        "autonomiczny": ["niezależny", "samodzielny", "samowystarczalny"],
        "chroniczny": ["trwały", "długotrwały", "uporczywy"],
        "efektywny": ["skuteczny", "wydajny", "sprawny"],
        "ekskluzywny": ["wyłączny", "luksusowy", "elitarny"],
        "elastyczny": ["giętki", "podatny", "plastyczny"],
        "empiryczny": ["doświadczalny", "praktyczny", "oparty na danych"],
        "esencjonalny": ["zasadniczy", "istotny", "najważniejszy"],
        "ewidentny": ["oczywisty", "jasny", "wyraźny"],
        "fakultatywny": ["nieobowiązkowy", "dobrowolny", "do wyboru"],
        "globalny": ["światowy", "ogólny", "ogólnoświatowy"],
        "immanentny": ["wrodzony", "wewnętrzny", "tkwiący"],
        "incydentalny": ["przypadkowy", "okazjonalny", "sporadyczny"],
        "integralny": ["nieodłączny", "ścisły", "nierozerwalny"],
        "intensywny": ["silny", "nasilony", "wzmożony"],
        "kategoryczny": ["stanowczy", "zdecydowany", "bezwzględny"],
        "konceptualny": ["pojęciowy", "ideowy", "myślowy"],
        "konsekwentny": ["wytrwały", "stały", "niezmienny"],
        "konwencjonalny": ["tradycyjny", "zwykły", "klasyczny"],
        "marginalny": ["poboczny", "drugorzędny", "nieistotny"],
        "obligatoryjny": ["obowiązkowy", "wymagany", "konieczny"],
        "opcjonalny": ["nieobowiązkowy", "do wyboru", "dodatkowy"],
        "optymalny": ["najlepszy", "idealny", "najkorzystniejszy"],
        "permanentny": ["stały", "ciągły", "trwały"],
        "perspektywiczny": ["przyszłościowy", "obiecujący", "rozwojowy"],
        "precyzyjny": ["dokładny", "ścisły", "pedantyczny"],
        "preliminarny": ["wstępny", "początkowy", "pilotażowy"],
        "produktywny": ["wydajny", "twórczy", "płodny"],
        "progresywny": ["postępowy", "rozwojowy", "nowoczesny"],
        "prowizoryczny": ["tymczasowy", "doraźny", "chwilowy"],
        "rudymentarny": ["podstawowy", "elementarny", "prosty"],
        "selektywny": ["wybiórczy", "wybrany", "częściowy"],
        "spekulatywny": ["hipotetyczny", "domyślny", "przypuszczalny"],
        "sukcesywny": ["stopniowy", "kolejny", "systematyczny"],
        "utylitarny": ["użytkowy", "praktyczny", "pragmatyczny"],
        # === v0.12.0 expansion ===
        "abrewiacja": ["skrót", "skrócenie"],
        "adaptować": ["dostosowywać", "przystosowywać", "przerabiać"],
        "afirmować": ["potwierdzać", "przyjmować", "zgadzać się"],
        "agregować": ["zbierać", "gromadzić", "sumować"],
        "alienować": ["odsuwać", "izolować", "wykluczyć"],
        "ameliorować": ["ulepszać", "polepszyć", "poprawiać"],
        "amplifikować": ["zwiększać", "wzmacniać", "powiększać"],
        "anektować": ["przyłączać", "włączać", "przejmować"],
        "anulować": ["unieważniać", "kasować", "likwidować"],
        "aplikować": ["stosować", "nakładać", "używać"],
        "arbitrować": ["rozstrzygać", "osądzać", "mediować"],
        "atestować": ["poświadczać", "certyfikować", "zaświadczać"],
        "audytować": ["kontrolować", "sprawdzać", "badać"],
        "bilansować": ["podsumować", "rozliczyć", "zestawiać"],
        "chronologizować": ["porządkować w czasie", "datować"],
        "klaryfikować": ["wyjaśniać", "rozjaśniać", "tłumaczyć"],
        "komentować": ["odnosić się", "uwzględniać", "omówić"],
        "komparować": ["porównywać", "zestawiać", "konfrontować"],
        "komunikować": ["informować", "przekazywać", "mówić"],
        "konfirmować": ["potwierdzać", "zatwierdzać", "upewniać"],
        "konstruować": ["budować", "tworzyć", "projektować"],
        "kontynuować": ["dalej prowadzić", "ciągnąć", "nie przerywając"],
        "kultywować": ["pielęgnować", "podtrzymywać", "rozwijad"],
        "kwalifikować": ["określać", "uznawać", "zaliczać"],
        "negować": ["zaprzeczać", "odrzucać", "negować"],
        "optymizować": ["polepszyć", "zoptymalizować", "udoskonalić"],
        "parodiować": ["naśladować", "kpić", "przejaskrawiać"],
        "patronować": ["wspierać", "opiekować się", "protegować"],
        "priorytetyzować": ["nadawać priorytet", "wysuwać na pierwszy plan"],
        "profitować": ["korzystać", "czerpać zyski", "zarabiać"],
        "protokolować": ["zapisywać", "notować", "dokumentować"],
        "prowokować": ["wywoływać", "pobudzać", "draznować"],
        "ratyfikować": ["zatwierdzać", "potwierdzać", "sankcjonować"],
        "reaktywować": ["ponownie uruchomić", "ożywić", "wznowić"],
        "refutować": ["obalać", "odrzucać", "zaprzeczać"],
        "rekompensować": ["wyrównywać", "odpłacać", "nagradzać"],
        "rektyfikować": ["korygować", "poprawić", "sprostowywać"],
        "renomować": ["cięszyć się sławą", "być znanym"],
        "rewidować": ["przeglądać", "weryfikować", "zmieniać"],
        "sankcjonować": ["karać", "zatwierdzjać", "aprobować"],
        "selektywnować": ["wybiercać", "dobierać", "sortować"],
        "synchronizować": ["uzgadniać", "koordynować", "równoległy"],
        "taksować": ["wyceniać", "szacować", "obliczać"],
        "transparentować": ["ujawniać", "pokazywać", "upubliczniać"],
        "uniformizować": ["ujednolicać", "standaryzować", "równać"],
        "werbalny": ["słowny", "ustny", "językowy"],
        "wielopłaszczyznowy": ["złożony", "wielowarstwowy", "różnorodny"],
        "aksjomat": ["założenie", "prawda oczywista", "pewnik"],
        "determinanta": ["czynnik", "wyznacznik", "przesłanka"],
        "dysfunkcja": ["zaburzenie", "nieprawidłowość", "wada"],
        "egzemplifikacja": ["przykład", "ilustracja", "wzór"],
        "emanacja": ["wyraz", "przejaw", "pochodzenie"],
        "ewaluacja": ["ocena", "oszacowanie", "wartościowanie"],
        "gratyfikacja": ["nagroda", "wynagrodzenie", "premia"],
        "implikacja": ["wynik", "następstwo", "konsekwencja"],
        "jurydyczny": ["prawny", "prawniczy", "sądowy"],
        "kauzalny": ["przyczynowy", "sprawczy"],
        "koherentny": ["spójny", "logiczny", "konsekwentny"],
        "koniunktywny": ["łączny", "współbieżny"],
        "latentny": ["utajony", "ukryty", "drzemiący"],
        "meritum": ["sedno", "istota", "jądro"],
        "moratorium": ["wstrzymanie", "zawieszenie", "odroczenie"],
        "novum": ["nowość", "innowacja", "odkrycie"],
        "paradoks": ["sprzeczność", "absurd", "nielogiczność"],
        "prerogatywa": ["przywilej", "uprawnienie", "prawo"],
        "remisja": ["ustąpienie", "cofnięcie", "złagodzenie"],
        "sankcja": ["kara", "konsekwencja", "zaświadczenie"],
        "stymulus": ["bodziec", "impuls", "zachęta"],
        "substytut": ["zamiennik", "zastępnik", "namiastka"],
        "tezy": ["założenia", "twierdzenia", "argumenty"],
        "unilateralny": ["jednostronny", "samodzielny"],
        "weto": ["zakaz", "sprzeciw", "zablokowanie"],
        "złudny": ["iluzoryczny", "pozorny", "mylący"],
    },

    "bureaucratic_phrases": {
        "należy podkreślić": ["warto powiedzieć", "zaznaczmy"],
        "w ramach": ["w", "podczas", "w obrębie"],
        "w zakresie": ["w", "pod względem", "co do"],
        "w odniesieniu do": ["wobec", "co do", "jeśli chodzi o"],
        "na gruncie": ["na bazie", "w oparciu o"],
        "mając na uwadze": ["biorąc pod uwagę", "z uwagi na"],
        "celem": ["żeby", "aby", "w celu"],
        "odgrywa kluczową rolę": ["jest bardzo ważny", "ma duże znaczenie"],
        "ma fundamentalne znaczenie": ["jest bardzo ważne", "jest kluczowe"],
        "w istotny sposób": ["znacznie", "dużo", "bardzo"],
        # === v0.10.0 ===
        "wydaje się zasadnym": ["warto", "rozsądnie jest"],
        "w świetle powyższego": ["biorąc to pod uwagę", "w związku z tym"],
        "nie sposób pominąć": ["warto wspomnieć", "trzeba dodać"],
        "z punktu widzenia": ["patrząc na", "od strony"],
        "w kontekście": ["jeśli chodzi o", "w odniesieniu do"],
        "ze szczególnym uwzględnieniem": ["zwłaszcza", "szczególnie"],
        "po dokonaniu analizy": ["po przeanalizowaniu", "po sprawdzeniu"],
        "jak wspomniano powyżej": ["jak już mówiono", "jak podano wyżej"],
        "w ostatecznym rozrachunku": ["ostatecznie", "w końcu"],
        "na marginesie": ["przy okazji", "nawiasem"],
        "bez uszczerbku dla": ["nie naruszając", "zachowując"],
        "w trybie priorytetowym": ["pilnie", "w pierwszej kolejności"],
        "z uwzględnieniem specyfiki": ["biorąc pod uwagę", "pamiętając o"],
        "w perspektywie długofalowej": ["w dłuższym terminie", "na dłuższą metę"],
        "nie ulega wątpliwości": ["bez wątpienia", "jasne jest"],
        "prowadzi to do konkluzji": ["z tego wynika", "stąd wniosek"],
        # === v0.11.0 massive expansion ===
        "w przedmiotowej sprawie": ["w tej sprawie", "w tym przypadku"],
        "w dalszej perspektywie": ["w przyszłości", "w dłuższym okresie"],
        "z całą stanowczością": ["zdecydowanie", "stanowczo"],
        "w sposób niepodlegający dyskusji": ["bezsprzecznie", "bez wątpienia"],
        "w myśl obowiązujących przepisów": ["zgodnie z prawem", "według prawa"],
        "na chwilę obecną": ["teraz", "aktualnie", "w tej chwili"],
        "w chwili obecnej": ["teraz", "obecnie", "w tej chwili"],
        "celem przedsięwzięcia": ["żeby osiągnąć", "aby zrobić"],
        "dokonać analizy": ["przeanalizować", "zbadać"],
        "podjąć stosowne kroki": ["działać", "podjąć działania"],
        "z uwagi na powyższe": ["dlatego", "wobec tego"],
        "w nawiązaniu do": ["odnosząc się do", "co do"],
        "na mocy postanowień": ["zgodnie z", "w myśl"],
        "z należytą starannością": ["starannie", "dokładnie"],
        "podlega rozpatrzeniu": ["trzeba rozpatrzyć", "wymaga sprawdzenia"],
        "w trybie niezwłocznym": ["natychmiast", "od razu", "bezzwłocznie"],
        # === v0.12.0 expansion ===
        "biorąc powyższe pod uwagę": ["wobec tego", "dlatego"],
        "brak jest możliwości": ["nie można", "nie da się"],
        "czyniąc zadość": ["spełniając", "realizując"],
        "darć wyraz": ["wyrazić", "pokazać", "rzec"],
        "dokonać weryfikacji": ["zweryfikować", "sprawdzić"],
        "godzi się podkreślić": ["warto dodać", "należy powiedzieć"],
        "mieć na względzie": ["brać pod uwagę", "pamiętać o"],
        "na kanwie": ["na tle", "w związku z", "na gruncie"],
        "nie da się pominąć": ["trzeba wspomnieć", "warto dodać"],
        "nie ulega kwestii": ["nie ma wątpliwości", "jasne jest"],
        "pod rygorem": ["pod karą", "pod groźbą"],
        "po myśli": ["zgodnie z", "według", "w myśl"],
        "przywodzi na myśl": ["kojarzy się z", "przypomina"],
        "sięgać po": ["korzystać z", "używać", "stosować"],
        "skłonić do refleksji": ["zachęcić do przemyśleń", "dać do myślenia"],
        "stanąć na stanowisku": ["uznać", "stwierdzić", "dojść do wniosku"],
        "tożsamo z": ["równoznaczne z", "tak samo jak"],
        "udzielić odpowiedzi": ["odpowiedzieć", "odnieść się"],
        "wydać dyspozycję": ["polecić", "nakazać", "zlecić"],
        "wywierać wpływ": ["oddziaływać", "wpływać", "kształtować"],
        "zamknąć w ramy": ["ująć w ramy", "uporządkować"],
        "zastosować adekwatne środki": ["podjąć odpowiednie kroki", "działać"],
        "zgłosić zastrzeżenia": ["wyrazić wątpliwości", "zaprotestować"],
        "zgodnie z obowiązującymi": ["według", "na mocy", "w myśl"],
        "zmierzając do": ["żeby", "aby", "dążąc do"],
    },

    "ai_connectors": {
        "Ponadto": ["Poza tym", "Oprócz tego", "Do tego"],
        "Niemniej jednak": ["Ale", "Jednak", "Mimo to"],
        "W konsekwencji": ["Dlatego", "Więc", "Zatem"],
        "Jednakże": ["Ale", "Jednak", "Choć"],
        "Co więcej": ["Poza tym", "Do tego", "Na dodatek"],
        "W związku z tym": ["Dlatego", "Stąd", "W efekcie"],
        "Warto podkreślić": ["Ważne jest", "Godne uwagi"],
        "Należy zauważyć": ["Zauważmy", "Warto wiedzieć"],
        "Reasumując": ["Podsumowując", "W skrócie", "Ogólnie"],
        "Mając powyższe na uwadze": ["Biorąc to pod uwagę", "W tym świetle"],
        "W kontekście": ["Jeśli chodzi o", "Co do"],
        "Tym samym": ["Więc", "Dlatego", "Stąd"],
        # === v0.10.0 ===
        "Bądź co bądź": ["Tak czy inaczej", "W każdym razie"],
        "W każdym razie": ["Tak czy inaczej", "W każdym wypadku"],
        "Równocześnie": ["Jednocześnie", "W tym samym czasie"],
        "Co istotne": ["Co ważne", "Istotnie"],
        "Analogicznie": ["Podobnie", "W ten sam sposób"],
        "Niewątpliwie": ["Bez wątpienia", "Z pewnością"],
        "Rzecz jasna": ["Oczywiście", "Naturalnie"],
        "W istocie": ["W rzeczywistości", "De facto"],
        # === v0.11.0 massive expansion ===
        "Tym niemniej": ["Ale", "Jednak", "Mimo wszystko"],
        "Warto zauważyć": ["Ciekawe jest", "Zauważmy", "Warto wiedzieć"],
        "Podsumowując": ["Krótko mówiąc", "W skrócie", "W sumie"],
        "Przede wszystkim": ["Po pierwsze", "Głównie", "Najpierw"],
        "W dalszej kolejności": ["Następnie", "Potem", "Dalej"],
        "Niezależnie od tego": ["Mimo to", "Tak czy inaczej"],
        "Z drugiej strony": ["Natomiast", "Z kolei", "Ale"],
        "Mianowicie": ["To znaczy", "A konkretnie", "Czyli"],
        "Na tej podstawie": ["Dlatego", "W oparciu o to", "Stąd"],
        "W pierwszej kolejności": ["Najpierw", "Na początek", "Po pierwsze"],
        "Ogólnie rzecz biorąc": ["Ogólnie", "W sumie", "Generalnie"],
        "Innymi słowy": ["Czyli", "To znaczy", "Inaczej mówiąc"],
        "Wreszcie": ["W końcu", "Na koniec", "Ostatecznie"],
        "W szczególności": ["Zwłaszcza", "Szczególnie", "Głównie"],
        "Co za tym idzie": ["Dlatego", "Więc", "W efekcie"],
        "W rezultacie": ["W efekcie", "Przez to", "W wyniku tego"],
        # === v0.12.0 expansion ===
        "Jak wiadomo": ["Jak każdy wie", "Powszechnie wiadomo", "Oczywiście"],
        "Nie od rzeczy będzie": ["Warto", "Dobrze będzie", "Nie zaszkodzi"],
        "Nie należy zapominać": ["Pamiętajmy", "Trzeba pamiętać", "Ważne jest"],
        "O czym świadczy": ["Co dowodzi", "Co potwierdza"],
        "Dla porządku": ["Dla jasności", "Gwoli ścisłości"],
        "Jednym słowem": ["Krótko mówiąc", "Jednak", "Innymi słowy"],
        "Na marginesie": ["Przy okazji", "Nawiasem mówiąc", "Ćwiczeniem"],
        "Na zakończenie": ["Podsumowując", "Na koniec", "Wreszcie"],
        "Nota bene": ["Nawiasem mówiąc", "Co ciekawe", "Zresztą"],
        "Obiektywnie rzecz biorąc": ["Patrząc obiektywnie", "Bez stronniczości"],
        "Pod tym względem": ["W tym aspekcie", "Jeśli chodzi o to"],
        "Rzec można": ["Można powiedzieć", "Daje się stwierdzić"],
        "Silną stroną jest": ["Atutem jest", "Zaletą jest", "Mocną stroną"],
        "Swą drogą": ["Nawiasem mówiąc", "A propos", "Przy okazji"],
        "Tak czy inaczej": ["W każdym razie", "Niezależnie od tego"],
        "Trudno zaprzeczyć": ["Nie da się ukryć", "Faktem jest"],
        "Tym bardziej": ["Jeszcze bardziej", "Zwłaszcza", "Szczególnie"],
        "W gruncie rzeczy": ["W zasadzie", "Tak naprawdę", "W istocie"],
        "W obliczu tego": ["Wobec tego", "Stąd", "Dlatego"],
        "Zawsze": ["Każdorazowo", "Stale", "Niezmiennie"],
        "Zresztą": ["Nota bene", "Do tego", "Poza tym"],
        "Święta racja": ["Słusznie", "Zgadza się", "Prawda"],
        "Na pierwszy rzut oka": ["Na pozór", "Z pozoru", "Początkowo"],
        "Trafnie zauważono": ["Słusznie wskazano", "Celnie stwierdzono"],
    },

    "synonyms": {
        "ważny": ["istotny", "znaczący", "kluczowy"],
        "duży": ["wielki", "znaczny", "spory", "pokaźny"],
        "mały": ["niewielki", "skromny", "drobny"],
        "szybki": ["prędki", "błyskawiczny", "sprawny"],
        "problem": ["trudność", "kłopot", "wyzwanie"],
        "rozwiązanie": ["odpowiedź", "wyjście", "sposób"],
        "wynik": ["rezultat", "efekt", "skutek"],
        "metoda": ["sposób", "technika", "podejście"],
        "proces": ["przebieg", "procedura", "tok"],
        "cel": ["zamiar", "plan", "dążenie"],
        "zaleta": ["plus", "korzyść", "mocna strona"],
        "obszar": ["dziedzina", "pole", "sfera"],
        "rozwój": ["postęp", "ewolucja", "wzrost"],
        "analiza": ["badanie", "przegląd", "ocena"],
        "skuteczny": ["efektywny", "wydajny", "sprawny"],
        "złożony": ["skomplikowany", "wielowarstwowy"],
        "nowoczesny": ["współczesny", "aktualny", "dzisiejszy"],
        "jakość": ["poziom", "standard", "klasa"],
        # === v0.10.0 ===
        "istotny": ["kluczowy", "ważny", "zasadniczy"],
        "sytuacja": ["okoliczności", "przypadek", "scenariusz"],
        "strategia": ["plan", "podejście", "taktyka"],
        "koncepcja": ["idea", "pomysł", "zamysł"],
        "struktura": ["budowa", "układ", "organizacja"],
        "zdolność": ["umiejętność", "kompetencja", "potencjał"],
        "wpływ": ["oddziaływanie", "efekt", "siła"],
        "perspektywa": ["punkt widzenia", "wizja", "kąt"],
        "dynamika": ["ruch", "zmiana", "tempo"],
        "element": ["składnik", "część", "czynnik"],
        "system": ["mechanizm", "układ", "całość"],
        "zasób": ["środek", "narzędzie", "źródło"],
        "wymiar": ["aspekt", "strona", "płaszczyzna"],
        "kontekst": ["otoczenie", "tło", "okoliczności"],
        "wyzwanie": ["próba", "test", "trudność"],
        "ewolucja": ["zmiana", "postęp", "przeobrażenie"],
        "wkład": ["udział", "dorobek", "pomoc"],
        "doświadczenie": ["praktyka", "wiedza", "staż"],
        "również": ["także", "też", "ponadto"],
        "niezbędny": ["konieczny", "potrzebny", "wymagany"],
        # === v0.11.0 massive expansion ===
        "trudny": ["ciężki", "kłopotliwy", "wymagający"],
        "łatwy": ["prosty", "nieskomplikowany", "bezproblemowy"],
        "dobry": ["udany", "pozytywny", "korzystny"],
        "zły": ["negatywny", "niekorzystny", "szkodliwy"],
        "nowy": ["świeży", "niedawny", "najnowszy"],
        "stary": ["dawny", "wcześniejszy", "poprzedni"],
        "silny": ["mocny", "potężny", "intensywny"],
        "słaby": ["nikły", "marny", "niedostateczny"],
        "pewny": ["przekonany", "zdecydowany", "stanowczy"],
        "możliwy": ["wykonalny", "osiągalny", "realny"],
        "popularny": ["znany", "lubiany", "rozpowszechniony"],
        "ciekawy": ["interesujący", "intrygujący", "zajmujący"],
        "prosty": ["łatwy", "nieskomplikowany", "jasny"],
        "dokładny": ["precyzyjny", "ścisły", "pedantyczny"],
        "potrzebny": ["konieczny", "wymagany", "niezbędny"],
        "własny": ["osobisty", "prywatny", "indywidualny"],
        "główny": ["podstawowy", "zasadniczy", "najważniejszy"],
        "ogólny": ["powszechny", "całościowy", "zbiorczy"],
        "kolejny": ["następny", "dalszy", "nadchodzący"],
        "odpowiedni": ["właściwy", "stosowny", "trafny"],
        "szczególny": ["wyjątkowy", "specjalny", "osobliwy"],
        "znaczny": ["duży", "poważny", "istotny"],
        "wspólny": ["łączny", "zbiorowy", "kolektywny"],
        "wolny": ["powolny", "niespieszny", "leniwy"],
        "podobny": ["zbliżony", "bliski", "porównywalny"],
        "różny": ["odmienny", "rozmaity", "inny"],
        "typowy": ["charakterystyczny", "standardowy", "zwykły"],
        "podstawowy": ["elementarny", "zasadniczy", "główny"],
        "końcowy": ["finalny", "ostateczny", "zamykający"],
        "początkowy": ["startowy", "wstępny", "otwarty"],
        "rzeczywisty": ["prawdziwy", "faktyczny", "autentyczny"],
        "naturalny": ["swobodny", "spontaniczny", "niesztuczny"],
        "aktualny": ["bieżący", "obecny", "dzisiejszy"],
        "bezpośredni": ["wprost", "prosty", "otwarty"],
        "praktyczny": ["użyteczny", "przydatny", "funkcjonalny"],
        "teoretyczny": ["abstrakcyjny", "hipotetyczny", "koncepcyjny"],
        "indywidualny": ["osobisty", "jednostkowy", "prywatny"],
        "społeczny": ["publiczny", "obywatelski", "zbiorowy"],
        "ekonomiczny": ["gospodarczy", "finansowy", "oszczędny"],
        "techniczny": ["inżynierski", "specjalistyczny", "fachowy"],
        "zmiana": ["modyfikacja", "przeróbka", "korekta"],
        "praca": ["robota", "zajęcie", "działalność"],
        "wiedza": ["znajomość", "kompetencja", "erudycja"],
        "pomoc": ["wsparcie", "asysta", "wspomożenie"],
        "walka": ["zmaganie", "rywalizacja", "bitwa"],
        "stwierdzenie": ["konstatacja", "uwaga", "obserwacja"],
        "informacja": ["wiadomość", "dane", "komunikat"],
        "opinia": ["zdanie", "pogląd", "stanowisko"],
        "możliwość": ["szansa", "okazja", "sposobność"],
        "sposób": ["metoda", "technika", "droga"],
        "przykład": ["ilustracja", "wzór", "przypadek"],
        "przyczyna": ["powód", "motyw", "źródło"],
        "skutek": ["efekt", "rezultat", "następstwo"],
        "warunek": ["wymóg", "kryterium", "zastrzeżenie"],
        "wartość": ["znaczenie", "cena", "walor"],
        "poziom": ["stopień", "szczebel", "ranga"],
        "część": ["fragment", "kawałek", "odcinek"],
        "forma": ["postać", "kształt", "rodzaj"],
        "zakres": ["zasięg", "rozmiar", "pole"],
        "uwaga": ["spostrzeżenie", "komentarz", "refleksja"],
        "stosunek": ["relacja", "proporcja", "związek"],
        "rola": ["funkcja", "zadanie", "miejsce"],
        "wysiłek": ["trud", "staranie", "próba"],
        "kierunek": ["droga", "kurs", "trend"],
        "różnica": ["odmienność", "rozbieżność", "dysproporcja"],
        "podstawa": ["fundament", "baza", "grunt"],
        "granica": ["krawędź", "bariera", "limit"],
        "trudność": ["przeszkoda", "bariera", "problem"],
        "umiejętność": ["talent", "zdolność", "sprawność"],
        "propozycja": ["oferta", "sugestia", "wniosek"],
        "ocena": ["opinia", "sąd", "werdykt"],
        "działanie": ["czynność", "akcja", "operacja"],
        "podejście": ["nastawienie", "postawa", "metoda"],
        "wskazywać": ["pokazywać", "sygnalizować", "sugerować"],
        "zapewniać": ["gwarantować", "dawać", "obiecywać"],
        "stanowić": ["tworzyć", "być", "składać się na"],
        "wymagać": ["potrzebować", "oczekiwać", "żądać"],
        "uzyskać": ["zdobyć", "osiągnąć", "otrzymać"],
        "osiągnąć": ["zdobyć", "uzyskać", "dojść do"],
        "utrzymywać": ["podtrzymywać", "zachowywać", "kontynuować"],
        "stosować": ["używać", "wykorzystywać", "posługiwać się"],
        "zawierać": ["mieścić", "obejmować", "mieć w sobie"],
        # === v0.12.0 expansion ===
        "szybko": ["prędko", "sprawnie", "błyskawicznie"],
        "wolno": ["powoli", "niespiesznie", "leniwie"],
        "często": ["wielokrotnie", "regularnie", "nierzadko"],
        "rzadko": ["sporadycznie", "oikāzjonalnie", "od czasu do czasu"],
        "dużo": ["wiele", "mnóstwo", "sporo"],
        "mało": ["niewiele", "trochę", "odrobinę"],
        "zawsze": ["stale", "ciągle", "niezmiennie"],
        "nigdy": ["w żadnym wypadku", "pod żadnym pozorem"],
        "czasem": ["od czasu do czasu", "niekiedy", "okazjonalnie"],
        "bardzo": ["niezwykle", "nad wyraz", "ogromnie"],
        "pewien": ["określony", "dany", "konkretny"],
        "cały": ["pełny", "kompletny", "zupełny"],
        "pierwszy": ["początkowy", "wstępny", "inauguracyjny"],
        "ostatni": ["końcowy", "finalny", "zamykający"],
        "jasny": ["zrozumiały", "klarowny", "czytelny"],
        "ciemny": ["mroczny", "ponury", "zaciemniony"],
        "głęboki": ["dogłębny", "gruntowny", "intensywny"],
        "płytki": ["powierzchowny", "pobieżny", "banalny"],
        "bogaty": ["zasobny", "obfity", "pełny"],
        "biedny": ["ubogi", "skromny", "skąpy"],
        "sukces": ["powodzenie", "tryumf", "osiągnięcie"],
        "porażka": ["niepowodzenie", "klęska", "fiasko"],
        "nadzieja": ["oczekiwanie", "szansa", "perspektywa"],
        "obawa": ["lęk", "strach", "niepokój"],
        "prawda": ["fakt", "rzeczywistość", "istota"],
        "błąd": ["pomyłka", "niedociągnięcie", "potknięcie"],
        "plan": ["zamiar", "projekt", "zamierzenie"],
        "odpowiedź": ["reakcja", "replika", "odzew"],
        "pytanie": ["zapytanie", "kwestia", "zagadnienie"],
        "decyzja": ["postanowienie", "wybór", "rozstrzygnięcie"],
        "osiągać": ["zdobywać", "dochodzić do", "uzyskiwać"],
        "tworzyć": ["budować", "kreować", "konstruować"],
        "zmieniać": ["modyfikować", "przerabiać", "korygować"],
        "badać": ["sprawdzać", "analizować", "docierać"],
        "popierać": ["wspierać", "promować", "faworyzować"],
        "przedstawiać": ["prezentować", "pokazywać", "opisywać"],
        "umożliwiać": ["pozwalać", "dawać szansę", "zapewniać"],
        "potwierdzać": ["zaświadczać", "uwierzytelniać", "attestować"],
        "obejmować": ["zawierać", "obejmować siebie", "pokrywać"],
    },

    "sentence_starters": {
        "To": ["Owo", "Takie", "Taki"],
        "On": ["Człowiek", "Osoba", "Podmiot"],
        "Ona": ["Osoba", "Specjalistka", "Kobieta"],
        "Oni": ["Ci", "Zespół", "Ludzie ci"],
        "My": ["Nasz zespół", "Grupa", "Wszyscy"],
        "Ten": ["Ów", "Taki", "Dany"],
        "Ta": ["Owa", "Dana", "Taka"],
        "W": ["Wewnątrz", "Podczas", "W trakcie"],
        "Dla": ["Aby", "W celu", "Na rzecz"],
        "Także": ["Również", "Oprócz tego", "Poza tym"],
        # === v0.10.0 ===
        "Zatem": ["Więc", "Dlatego", "W związku z tym"],
        "Choć": ["Mimo że", "Chociaż", "Pomimo"],
        "Niemniej": ["Jednak", "Ale", "Mimo to"],
        # === v0.11.0 massive expansion ===
        "Istotne jest": ["Ważne jest", "Kluczowe jest", "Należy wiedzieć"],
        "Z kolei": ["Natomiast", "Tymczasem", "A"],
        "Poza tym": ["Oprócz tego", "Do tego", "Dodatkowo"],
        "Mimo że": ["Chociaż", "Choć", "Pomimo że"],
        "Wiadomo": ["Oczywiste jest", "Jasne jest", "Znane jest"],
        "Okazuje się": ["Wygląda na to", "Jak się okazało", "Widać"],
        "Nie sposób": ["Trudno", "Nie da się", "Nie można"],
        "Warto dodać": ["Przy okazji", "Poza tym", "Do tego"],
        "Trzeba": ["Należy", "Warto", "Potrzeba"],
        "Wynika stąd": ["Z tego wynika", "Stąd", "Dlatego"],
        "Przystępując do": ["Zaczynając", "Biorąc się za", "Rozpoczynając"],
        "Bez wątpienia": ["Z pewnością", "Na pewno", "Jasne jest"],
        "Jak się okazuje": ["Wygląda na to", "Wydaje się", "Widać"],
        "Biorąc pod uwagę": ["Zważywszy na", "Mając na uwadze", "W świetle"],
        "Podobnie": ["Tak samo", "Analogicznie", "W ten sam sposób"],
        "Naturalnie": ["Oczywiście", "Rzecz jasna", "Jak wiadomo"],
        "Na dobrą sprawę": ["Tak naprawdę", "W istocie", "Właściwie"],
        "Tymczasem": ["Z kolei", "A", "Natomiast"],
        "Wręcz": ["Nawet", "Co więcej", "Ba"],
        "Ściśle mówiąc": ["Dokładniej", "Ściślej", "Precyzyjniej"],
        # === v0.12.0 expansion ===
        "Co istotniejsze": ["Co ważniejsze", "Jeszcze ważniejsze"],
        "Generalnie": ["Ogólnie", "W ogóle", "Zasadniczo"],
        "Faktycznie": ["Rzeczywiście", "Naprawdę", "Istotnie"],
        "Pozornie": ["Na pozór", "Z pozoru", "Wydawałoby się"],
        "Zwykle": ["Zazwyczaj", "Na ogół", "Z reguły"],
        "Dziś": ["W dzisiejszych czasach", "Współcześnie", "Obecnie"],
        "Wprawdzie": ["Co prawda", "Owszem", "Jakkolwiek"],
        "Zasadniczo": ["Generalnie", "Ogólnie", "W zasadzie"],
        "Niestety": ["Na nieszczęście", "Szkoda", "Jak na złość"],
        "Na szczęście": ["Całe szczęście", "Dobrze że", "Pomyślnie"],
        "Konkretnie": ["Dokładnie", "Precyzyjnie", "W szczegółach"],
        "Ewidentnie": ["Najwyraźniej", "Bez wątpienia", "Wyraźnie"],
        "Paradoksalnie": ["Wbrew pozorom", "Co dziwne", "Zaskakująco"],
    },

    "colloquial_markers": [
        "szczerze mówiąc", "tak naprawdę", "de facto",
        "w gruncie rzeczy", "w zasadzie", "ogólnie rzecz biorąc",
        "prawdę mówiąc", "bądź co bądź", "co tu dużo mówić",
        "nomen omen", "co ciekawe", "nawiasem mówiąc",
        "jakby nie patrzeć", "koniec końców", "z całą pewnością",
        "jak by to powiedzieć",
        # === v0.10.0 ===
        "no cóż", "w sumie", "serio", "osobiście",
        "bez owijania w bawełnę", "krótko mówiąc",
        "żeby nie kłamać", "nie będę ukrywać", "no właśnie",
        "a propos",
        # === v0.11.0 massive expansion ===
        "powiem wprost", "ręka na sercu", "z ręką na sercu",
        "jak na moje", "z doświadczenia wiem", "nie od dziś wiadomo",
        "nie ukrywam", "muszę przyznać", "co tu kryć",
        "właściwie", "tak czy owak", "z grubsza rzecz biorąc",
        "między nami mówiąc", "powiedzmy sobie", "co więcej",
        "na chłopski rozum", "z całym szacunkiem", "najprościej mówiąc",
        "żeby było jasne", "nie ma co ukrywać", "o ile się nie mylę",
        "rzekłbym", "gdyby mnie ktoś pytał", "swoją drogą",
        "na marginesie", "w pewnym sensie", "wyczuwam tu",
        "jak to mówią", "niejako", "de iure",
        "de facto mówiąc", "krótko i na temat",
        # === v0.12.0 expansion ===
        "postawmy sprawę jasno", "powiedzmy sobie wprost",
        "nic nie upiększając", "mówiąc bez ogródek",
        "ujmując to inaczej", "co tu dużo mówić",
        "nie od parady", "sam się zastanawiam",
        "powiem tak", "jeśli mam być szczery",
        "z pełną odpowiedzialnością", "nie da się ukryć że",
        "na dobrą sprawę", "co ciekawe jednak",
        "przyznam szczerze", "patrząc z dystansu",
        "nie od rzeczy", "jak na ironię",
        "przyznajmy to sobie", "szczerze powiedziawszy",
    ],

    "abbreviations": [
        "dr", "prof.", "mgr", "inż.", "np.", "itd.", "itp.",
        "wg", "zob.", "tzw.", "ok.", "mln", "mld",
        "ul.", "al.", "pl.", "ks.", "bp.", "abp.",
        "pkt", "str.", "rys.", "tab.", "rozdz.",
        # === v0.10.0 ===
        "ust.", "poz.", "dz.", "nr", "art.", "par.",
        "red.", "przyp.", "wyd.", "oprac.", "tłum.",
        # === v0.11.0 massive expansion ===
        "tj.", "tzn.", "m.in.", "jw.", "ds.",
        "śp.", "im.", "cdn.", "br.", "bm.",
        "godz.", "ob.", "dot.", "zał.", "św.",
        "gen.", "kpt.", "mjr", "płk", "ppłk",
        "sierż.", "st.", "mł.", "asp.", "kom.",
        "woj.", "pow.", "gm.", "dyr.", "kier.",
    ],

    "perplexity_boosters": [
        "ni stąd ni zowąd", "nolens volens", "de facto",
        "bądź co bądź", "ni mniej ni więcej", "co tu dużo mówić",
        "paradoksalnie", "kuriozalnie", "ironicznie",
        "poniekąd", "niejako", "do pewnego stopnia",
        "co prawda", "owszem", "jakkolwiek", "atoli",
        "wszelako", "niemniej jednak",
        # === v0.10.0 ===
        "nie da się ukryć", "jak wiadomo",
        "trzeba przyznać", "obiektywnie rzecz biorąc",
        "wbrew pozorom", "powiedzmy sobie szczerze",
        "niezaprzeczalnie", "nade wszystko",
        # === v0.11.0 massive expansion ===
        "w tym cały ambaras", "ani chybi", "mniej więcej",
        "tak czy siak", "od biedy", "z natury rzeczy",
        "w pewnym sensie", "poniekąd owszem", "mimo woli",
        "siłą rzeczy", "w mniejszym lub większym stopniu",
        "z braku laku", "jak gdyby nigdy nic",
        "całkiem możliwe", "niewykluczone", "być może",
        "prawdę powiedziawszy", "powiedzmy", "istotnie",
        "bynajmniej", "byle jak", "z lekka",
        "najwyraźniej", "przypuszczalnie", "domniemanie",
        "hipotetycznie", "rzekomo", "ponoć",
        "zdawałoby się", "jakby mimochodem", "niby to",
        "w rzeczy samej",
        # === v0.12.0 expansion ===
        "wprost przeciwnie", "z całą pewnością",
        "jak się rzekło", "skoro już o tym mowa",
        "nie przesadząc", "bez przesady",
        "właściwie mówiąc", "nie będąc złośliwym",
        "wedle wszelkiego prawdopodobieństwa",
        "w mniejszym lub większym stopniu",
        "jak można się spodziewać", "delikatnie mówiąc",
        "pod pewnym względem", "jak się okazuje",
        "jak widać gołym okiem", "niech zgadnę",
        "z całym przekonaniem", "na pociechę",
        "co bardziej zdumiewające", "jak można się domyślać",
    ],

    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    "conjunctions": ["i", "ale", "lub", "ani", "bo", "więc"],

    "split_conjunctions": [
        " i ", " ale ", " jednak ", " podczas gdy ",
        " chociaż ", " ponieważ ", " gdyż ",
        # === v0.10.0 ===
        " niemniej ", " mimo to ", " natomiast ",
        " aczkolwiek ", " zatem ", " toteż ",
        # === v0.11.0 massive expansion ===
        " wobec czego ", " dlatego też ", " w efekcie ",
        " lecz ", " zaś ", " wprawdzie ",
        " co prawda ", " tymczasem ", " w związku z czym ",
        " za to ", " w rezultacie ", " mimo że ",
        " o tyle ", " skoro ", " albowiem ",
    ],
}
