"""Nyelvi csomag: Magyar (Hungarian)."""

LANG_HU = {
    "code": "hu",
    "name": "Hungarian",
    "native_name": "Magyar",

    # Trigramok nyelvfelismeréshez
    "trigrams": [
        "sze", "nak", "nek", "egy", "ogy", "meg", "tet", "ell",
        "min", "hoz", "hez", "höz", "ása", "ése", "ban", "ben",
        "ért", "unk", "ink", "val", "vel", "nak", "ott", "ett",
        "ült", "ség", "ság", "tel", "len", "ala",
    ],

    # Megállószavak (ne cseréljük)
    "stop_words": {
        "a", "az", "egy", "és", "van", "hogy", "nem", "is",
        "volt", "de", "meg", "ez", "ezt", "azt",
        "lesz", "mint", "már", "csak", "még", "vagy",
        "ha", "sem", "neki", "fel", "ki", "be", "le",
        "én", "te", "ő", "mi", "ti", "ők", "önt",
        "itt", "ott", "milyen", "hol",
        "mikor", "miért", "hogyan", "minden", "sok",
        "kevés", "nagy", "kis", "jó",
    },

    # Bürokratikus szavak
    "bureaucratic": {
        "implementálni": ["bevezetni", "megvalósítani", "alkalmazni"],
        "optimalizálni": ["javítani", "fejleszteni", "tökéletesíteni"],
        "evaluálni": ["értékelni", "megítélni", "elbírálni"],
        "generálni": ["létrehozni", "termelni", "készíteni"],
        "iniciálni": ["elindítani", "kezdeményezni", "megkezdeni"],
        "facilitálni": ["könnyíteni", "elősegíteni", "segíteni"],
        "priorizálni": ["elsőbbséget adni", "fontossági sorrendbe helyezni"],
        "kommunikálni": ["közölni", "tájékoztatni", "beszélni"],
        "finalizálni": ["befejezni", "véglegesíteni", "lezárni"],
        "szignifikáns": ["jelentős", "fontos", "lényeges"],
        "fundamentális": ["alapvető", "lényegi", "sarkalatos"],
        "esszenciális": ["elengedhetetlen", "nélkülözhetetlen", "fontos"],
        "adekvát": ["megfelelő", "alkalmas", "helyes"],
        "primér": ["elsődleges", "fő", "legfontosabb"],
        "szukcesszív": ["fokozatos", "lépésről lépésre", "folyamatos"],
        "integrálni": ["beépíteni", "egyesíteni", "beilleszteni"],
        "manifesztálni": ["megnyilvánítani", "mutatni", "kifejezni"],
        "etablálni": ["megalapítani", "létrehozni", "felállítani"],
        "analizálni": ["elemezni", "vizsgálni", "tanulmányozni"],
        "specifikálni": ["meghatározni", "pontosítani", "részletezni"],
        "identifikálni": ["azonosítani", "felismerni", "megtalálni"],
        "verifikálni": ["ellenőrizni", "igazolni", "megerősíteni"],
        "koordinálni": ["összehangolni", "megszervezni", "egyeztetni"],
        "kompenzálni": ["kárpótolni", "kiegyenlíteni", "pótolni"],
        "intenzifikálni": ["fokozni", "erősíteni", "növelni"],
        "redukálni": ["csökkenteni", "mérsékelni", "kisebbíteni"],
        "transzformálni": ["átalakítani", "megváltoztatni", "átformálni"],
        "akkumulálni": ["felhalmozni", "összegyűjteni", "gyűjteni"],
        "anticipálni": ["előre jelezni", "megelőzni", "várni"],
        "artikulálni": ["kifejezni", "megfogalmazni", "kimondani"],
        "delegálni": ["átruházni", "rábízni", "megbízni"],
        "demonstrálni": ["bemutatni", "szemléltetni", "bizonyítani"],
        "eliminálni": ["kiiktatni", "eltávolítani", "megszüntetni"],
        "expandálni": ["bővíteni", "kiterjeszteni", "növelni"],
        "formulálni": ["megfogalmazni", "megalkotni", "szövegezni"],
        "garantálni": ["szavatolni", "biztosítani", "kezeskedni"],
    },

    # Bürokratikus kifejezések
    "bureaucratic_phrases": {
        "tekintettel arra": ["figyelembe véve", "miatt", "mert"],
        "keretein belül": ["során", "részeként", "közben"],
        "azzal a céllal": ["azért, hogy", "abból a célból"],
        "összhangban áll": ["megfelel", "egyezik", "illeszkedik"],
        "meg kell jegyezni": ["fontos, hogy", "érdemes tudni"],
        "nagy jelentőséggel bír": ["fontos", "lényeges", "számít"],
        "kulcsszerepet játszik": ["fontos", "meghatározó"],
        "azzal a feltétellel": ["ha", "amennyiben", "feltéve, hogy"],
        "hiányában": ["nélkül", "híján"],
        "rendelkezésre bocsátani": ["adni", "nyújtani", "biztosítani"],
        "figyelembe venni": ["mérlegelni", "számolni vele"],
        "intézkedéseket tenni": ["cselekedni", "tenni", "lépni"],
        "annak következtében": ["ezért", "emiatt", "ennek folytán"],
        "arra tekintettel": ["figyelembe véve", "tekintve", "mivel"],
        "ennek értelmében": ["eszerint", "így", "tehát"],
        "jelen pillanatban": ["most", "jelenleg", "éppen"],
        "a továbbiakban": ["ezentúl", "ezután", "a jövőben"],
        "mindezek fényében": ["mindezek alapján", "tehát", "ezért"],
    },

    # AI-összekötő szavak
    "ai_connectors": {
        "Ezen felül": ["Emellett", "Ráadásul", "Továbbá"],
        "Mindazonáltal": ["Mégis", "Ennek ellenére", "De"],
        "Következésképpen": ["Ezért", "Tehát", "Így"],
        "Ezt követően": ["Ezután", "Utána", "Majd"],
        "Továbbá": ["Emellett", "Ráadásul", "Ezen felül"],
        "Ezzel szemben": ["Viszont", "De", "Ellenben"],
        "Ebben az összefüggésben": ["Itt", "Ebben az esetben"],
        "Összefoglalva": ["Röviden", "Egyszóval", "Mindent egybevetve"],
        "Ki kell emelni": ["Fontos, hogy", "Megjegyzendő"],
        "Végezetül": ["Végül", "Befejezésül", "Zárszóként"],
        "Szintén": ["Ugyancsak", "Hasonlóképpen", "Éppúgy"],
        "Ennélfogva": ["Ezért", "Tehát", "Így"],
        "Egyidejűleg": ["Ezzel egy időben", "Ugyanakkor", "Közben"],
        "Különösen": ["Főleg", "Elsősorban", "Kiváltképp"],
        "Lényegében": ["Alapjában véve", "Magában", "Tulajdonképpen"],
        "Végső soron": ["Végül is", "A végén", "Visszatekintve"],
        "Megjegyzendő": ["Figyelemre méltó", "Fontos tudni"],
        "Nem utolsó sorban": ["Emellett", "Továbbá", "Ráadásul"],
        "Mint már említettük": ["Ahogy mondtuk", "Ahogy szó volt róla"],
        "Ehhez képest": ["Viszont", "Ellenben", "Ugyanakkor"],
        "Ebből kifolyólag": ["Ezért", "Emiatt", "Ebből adódóan"],
    },

    # Szinonimák
    "synonyms": {
        "fontos": ["lényeges", "jelentős", "meghatározó", "kulcsfontosságú"],
        "nagy": ["jelentős", "tekintélyes", "hatalmas"],
        "kicsi": ["csekély", "apró", "elhanyagolható"],
        "gyors": ["fürge", "sebes", "villám"],
        "lassú": ["lomha", "vontatott", "mérsékelt"],
        "jó": ["kiváló", "remek", "kitűnő"],
        "rossz": ["gyenge", "silány", "hiányos"],
        "lehetőség": ["alkalom", "esély", "mód"],
        "probléma": ["gond", "nehézség", "kihívás"],
        "megoldás": ["válasz", "kiút", "orvoslás"],
        "eredmény": ["kimenetel", "hozam", "következmény"],
        "terület": ["szféra", "mező", "szektor"],
        "módszer": ["eljárás", "mód", "megközelítés"],
        "folyamat": ["menet", "lefolyás", "procedúra"],
        "szempont": ["nézőpont", "aspektus", "megvilágítás"],
        "ok": ["indok", "motívum", "kiváltó tényező"],
        "cél": ["szándék", "célkitűzés", "feladat"],
        "feladat": ["munka", "kötelesség", "megbízás"],
        "előny": ["haszon", "erősség", "pozitívum"],
        "hátrány": ["gyengeség", "negatívum", "kár"],
        "elemzés": ["vizsgálat", "tanulmány", "kiértékelés"],
        "minőség": ["szint", "színvonal", "fokozat"],
        "hatékony": ["eredményes", "sikeres", "célravezető"],
        "összetett": ["bonyolult", "sokrétű", "komplex"],
        "modern": ["korszerű", "mai", "jelenkori"],
        "tényező": ["elem", "összetevő", "körülmény"],
        "stratégia": ["terv", "taktika", "irányvonal"],
        "környezet": ["háttér", "közeg", "keret"],
        "nézőpont": ["szemszög", "látásmód", "vélemény"],
        "helyzet": ["állapot", "viszony", "körülmény"],
        "szerep": ["funkció", "feladat", "rendeltetés"],
        "szerkezet": ["felépítés", "struktúra", "váz"],
        "fejlődés": ["haladás", "növekedés", "előrelépés"],
        "tapasztalat": ["gyakorlat", "ismeret", "jártasság"],
        "hatás": ["befolyás", "kihatás", "erő"],
    },

    # Alternatív mondatkezdések
    "sentence_starters": {
        "Ez": ["Mindez", "Ilyen", "Ezen"],
        "A": ["Egy", "Ez a", "Az adott"],
        "Az": ["Ez", "Ezen", "Az adott"],
        "Mi": ["Csapatunk", "Mindannyian", "Az ember"],
        "Egy": ["Valamely", "Bizonyos", "Adott"],
        "De": ["Viszont", "Ellenben", "Ám"],
        "Ezért": ["Emiatt", "Ebből kifolyólag", "Tehát"],
        "Ha": ["Amennyiben", "Abban az esetben", "Feltéve"],
        "Bár": ["Habár", "Noha", "Jóllehet"],
        "Aztán": ["Ezután", "Később", "Majd"],
        "Természetesen": ["Magától értetődően", "Nyilván", "Persze"],
        "Itt": ["Ezen a ponton", "Ebben az esetben"],
        "Gyakran": ["Sokszor", "Nemritkán", "Rendszeresen"],
        "Ma": ["Manapság", "Napjainkban", "Jelenleg"],
        "Csak": ["Csupán", "Mindössze", "Pusztán"],
    },

    # Társalgási jelölők
    "colloquial_markers": [
        "őszintén szólva", "valójában", "elvileg", "lényegében",
        "magunk között szólva", "mellesleg", "szigorúan véve",
        "ha engem kérdeznek", "mondjuk úgy", "na jó",
        "hogy úgy mondjam", "legyünk őszinték", "végeredményben",
        "vicces, de", "meglepő módon", "érdekes módon",
        "röviden", "szóval", "mindenesetre",
        "úgy értem", "tudod", "nézd",
        "egyébként", "zárójelben", "ami azt illeti",
    ],

    # Rövidítések
    "abbreviations": [
        "pl.", "azaz", "stb.", "ill.", "kb.", "vö.",
        "Dr.", "Prof.", "Nr.", "u.", "millió", "mrd.",
        "ún.", "tkp.", "ti.", "kv.", "ld.",
        "mfm.", "bp.", "btk.", "kft.", "rt.",
    ],

    # Perplexitásnövelők
    "perplexity_boosters": [
        "kétségkívül", "mindazonáltal", "mégiscsak", "jószerével",
        "valószínűleg", "netán", "semmiképpen",
        "ámde", "kétségtelenül", "valóban", "korántsem",
        "elvégre", "jobbára", "nyilvánvalóan",
        "nemegyszer", "olykor", "alighanem",
        "voltaképpen", "lényegileg", "úgyszólván",
        "köztudomásúan", "meglehet", "ellenkezőleg",
        "ráadásul", "főképp", "mindenekelőtt",
    ],

    # Célprofilok
    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    # Kötőszavak összekapcsolásra
    "conjunctions": ["és", "de", "vagy", "mert", "tehát", "ugyanis"],

    # Kötőszavak szétválasztásra
    "split_conjunctions": [
        " és ", " de ", " viszont ", " miközben ",
        " holott ", " mert ", " ugyanis ",
        ", és ", ", de ", ", viszont ",
        ", miközben ", ", holott ",
        ", mert ", ", ugyanis ",
        "; ", " – ", " — ",
    ],
}
