"""Taalpakket: Nederlands (Dutch)."""

LANG_NL = {
    "code": "nl",
    "name": "Dutch",
    "native_name": "Nederlands",

    # Trigrammen voor taaldetectie
    "trigrams": [
        "een", "van", "het", "de ", "aar", "en ", "aan", "ver",
        "oor", "ing", "der", "ter", "sch", "ijk", "ond", "erd",
        "dat", "ste", "die", "ere", "gen", "ige", "nde", "ren",
        "est", "eni", "eer", "ove", "eri", "and",
    ],

    # Stopwoorden (niet vervangen)
    "stop_words": {
        "de", "het", "een", "van", "in", "is", "dat", "op",
        "aan", "met", "en", "er", "voor", "zijn", "was", "die",
        "niet", "maar", "ook", "als", "nog", "dan", "naar",
        "uit", "om", "bij", "over", "tot", "door", "te",
        "zo", "wel", "al", "kan", "hun", "dit", "had",
        "ik", "je", "hij", "zij", "wij", "we", "ze",
        "haar", "hem", "ons", "wat", "wie", "hoe", "waar",
        "meer", "veel", "geen", "alle", "deze", "heeft",
    },

    # Bureaucratisch taalgebruik
    "bureaucratic": {
        "implementeren": ["invoeren", "uitvoeren", "toepassen"],
        "optimaliseren": ["verbeteren", "aanpassen"],
        "evalueren": ["beoordelen", "toetsen", "bekijken"],
        "genereren": ["opwekken", "maken", "creëren"],
        "initiëren": ["starten", "beginnen", "op gang brengen"],
        "faciliteren": ["mogelijk maken", "ondersteunen"],
        "prioriteren": ["voorrang geven", "op volgorde zetten"],
        "communiceren": ["meedelen", "overleggen", "zeggen"],
        "finaliseren": ["afronden", "voltooien"],
        "significant": ["aanzienlijk", "merkbaar", "flink"],
        "fundamenteel": ["wezenlijk", "essentieel", "grondig"],
        "essentieel": ["noodzakelijk", "onmisbaar", "belangrijk"],
        "inherent": ["eigen aan", "onlosmakelijk"],
        "adequaat": ["passend", "geschikt", "toereikend"],
        "primair": ["in de eerste plaats", "hoofdzakelijk"],
        "successievelijk": ["geleidelijk", "stap voor stap"],
        "integreren": ["opnemen", "samenvoegen", "inbouwen"],
        "manifesteren": ["tonen", "laten zien", "openbaren"],
        "etableren": ["vestigen", "oprichten", "instellen"],
        "analyseren": ["onderzoeken", "bekijken", "ontleden"],
        "specificeren": ["aangeven", "bepalen", "omschrijven"],
        "identificeren": ["herkennen", "vaststellen", "vinden"],
        "verifiëren": ["controleren", "nagaan", "bevestigen"],
        "coördineren": ["afstemmen", "organiseren", "regelen"],
        "compenseren": ["vergoeden", "goedmaken"],
        "legitimeren": ["rechtvaardigen", "wettigen"],
        "intensiveren": ["versterken", "opvoeren"],
        "reduceren": ["verminderen", "verlagen", "beperken"],
        "transformeren": ["omvormen", "veranderen", "hervormen"],
        "accumuleren": ["ophopen", "verzamelen"],
        "anticiperen": ["vooruitlopen", "verwachten", "inspelen op"],
        "articuleren": ["verwoorden", "uitdrukken", "formuleren"],
        "autoriseren": ["machtigen", "toestemming geven"],
        "classificeren": ["indelen", "rangschikken", "ordenen"],
        "combineren": ["samenvoegen", "verbinden", "koppelen"],
        "concentreren": ["richten", "bundelen", "focussen"],
        "construeren": ["bouwen", "samenstellen", "opbouwen"],
        "consulteren": ["raadplegen", "overleggen"],
        "definiëren": ["bepalen", "omschrijven", "vastleggen"],
        "delegeren": ["overdragen", "uitbesteden"],
        "demonstreren": ["aantonen", "laten zien", "tonen"],
        "differentiëren": ["onderscheiden", "verschil maken"],
        "distribueren": ["verdelen", "verspreiden", "uitdelen"],
        "documenteren": ["vastleggen", "beschrijven", "registreren"],
        "domineren": ["overheersen", "beheersen"],
        "elimineren": ["verwijderen", "uitschakelen", "wegnemen"],
        "expanderen": ["uitbreiden", "groeien", "vergroten"],
        "expliceren": ["uitleggen", "verduidelijken", "toelichten"],
        "formuleren": ["verwoorden", "opstellen", "samenstellen"],
        "functioneren": ["werken", "draaien", "lopen"],
        "garanderen": ["waarborgen", "verzekeren", "beloven"],
        "illustreren": ["verduidelijken", "toelichten", "laten zien"],
    },

    # Bureaucratische zinnen
    "bureaucratic_phrases": {
        "met betrekking tot": ["over", "wat betreft", "aangaande"],
        "ten aanzien van": ["over", "wat betreft", "voor"],
        "in het kader van": ["bij", "tijdens", "binnen"],
        "met het oog op": ["voor", "om te", "gericht op"],
        "op grond van": ["vanwege", "door", "wegens"],
        "ten behoeve van": ["voor", "om te helpen"],
        "in overeenstemming met": ["volgens", "conform", "zoals"],
        "het dient te worden opgemerkt": ["let op", "merk op", "belangrijk"],
        "van groot belang": ["belangrijk", "cruciaal"],
        "een cruciale rol spelen": ["belangrijk zijn", "centraal staan"],
        "onder de voorwaarde dat": ["als", "mits", "op voorwaarde dat"],
        "bij gebrek aan": ["zonder", "bij afwezigheid van"],
        "ter beschikking stellen": ["aanbieden", "geven", "leveren"],
        "in aanmerking nemen": ["rekening houden met", "meewegen"],
        "tot stand brengen": ["realiseren", "bereiken", "maken"],
        "maatregelen treffen": ["handelen", "ingrijpen", "actie ondernemen"],
        "in acht nemen": ["naleven", "respecteren"],
        "naar aanleiding van": ["vanwege", "door", "naar aanleiding van"],
        "op de hoogte stellen": ["informeren", "melden", "vertellen"],
        "ten gevolge van": ["door", "als gevolg van", "vanwege"],
    },

    # AI-verbindingswoorden
    "ai_connectors": {
        "Bovendien": ["Daarnaast", "Ook", "Verder"],
        "Desalniettemin": ["Toch", "Maar", "Echter"],
        "Derhalve": ["Daarom", "Dus", "Vandaar"],
        "Dientengevolge": ["Daardoor", "Dus", "Daarom"],
        "Voorts": ["Verder", "Daarnaast", "Ook"],
        "In tegenstelling tot": ["Anders dan", "Maar", "Terwijl"],
        "In dit verband": ["Hierbij", "Hiermee", "Hier"],
        "Samenvattend": ["Kort gezegd", "Kortom", "Al met al"],
        "Het is vermeldenswaard": ["Opvallend is", "Belangrijk is"],
        "Tot slot": ["Ten slotte", "Afsluitend", "Als laatste"],
        "Tevens": ["Ook", "Daarnaast", "Bovendien"],
        "Aldus": ["Zo", "Op die manier", "Derhalve"],
        "Bijgevolg": ["Dus", "Daardoor", "Daarom"],
        "Eveneens": ["Ook", "Net zo", "Evenzo"],
        "Dienovereenkomstig": ["Overeenkomstig", "Zoals verwacht", "Daarom"],
        "Tegelijkertijd": ["Intussen", "Ondertussen", "Daarbij"],
        "In het bijzonder": ["Vooral", "Met name", "Specifiek"],
        "In wezen": ["In de kern", "Eigenlijk", "In feite"],
        "Uiteindelijk": ["Ten slotte", "Uiteindelijk", "Op het eind"],
        "In essentie": ["In de kern", "Eigenlijk", "Kort gezegd"],
        "Het zij opgemerkt": ["Let op", "Merk op", "Belangrijk"],
        "Niet in de laatste plaats": ["Ook", "Daarnaast", "Bovendien"],
        "Zoals reeds vermeld": ["Zoals gezegd", "Zoals eerder aangegeven"],
        "Vanuit dit perspectief": ["Zo bezien", "Vanuit dat oogpunt"],
        "Desondanks": ["Toch", "Niettemin", "Maar"],
    },

    # Synoniemen
    "synonyms": {
        "belangrijk": ["essentieel", "wezenlijk", "cruciaal", "van belang"],
        "groot": ["aanzienlijk", "fors", "omvangrijk"],
        "klein": ["gering", "beperkt", "minimaal"],
        "snel": ["vlot", "rap", "vlug"],
        "langzaam": ["traag", "geleidelijk", "rustig"],
        "goed": ["prima", "uitstekend", "degelijk"],
        "slecht": ["ontoereikend", "gebrekkig", "zwak"],
        "mogelijkheid": ["optie", "kans", "gelegenheid"],
        "probleem": ["kwestie", "uitdaging", "knelpunt"],
        "oplossing": ["antwoord", "uitweg", "remedie"],
        "resultaat": ["uitkomst", "opbrengst", "effect"],
        "gebied": ["terrein", "domein", "veld"],
        "methode": ["aanpak", "werkwijze", "benadering"],
        "proces": ["verloop", "gang", "procedure"],
        "aspect": ["kant", "facet", "zijde"],
        "reden": ["oorzaak", "aanleiding", "motief"],
        "doel": ["oogmerk", "streven", "doelstelling"],
        "taak": ["opdracht", "klus", "functie"],
        "voordeel": ["pluspunt", "sterkte", "baat"],
        "nadeel": ["minpunt", "zwakte", "keerzijde"],
        "analyse": ["onderzoek", "studie", "evaluatie"],
        "kwaliteit": ["niveau", "gehalte", "waarde"],
        "effectief": ["doeltreffend", "werkzaam", "succesvol"],
        "complex": ["ingewikkeld", "gecompliceerd", "veelzijdig"],
        "modern": ["hedendaags", "eigentijds", "actueel"],
        "factor": ["element", "aspect", "omstandigheid"],
        "strategie": ["aanpak", "plan", "beleid"],
        "context": ["verband", "samenhang", "kader"],
        "perspectief": ["gezichtspunt", "invalshoek", "standpunt"],
        "situatie": ["omstandigheid", "toestand", "positie"],
        "functie": ["rol", "taak", "werking"],
        "structuur": ["opbouw", "indeling", "organisatie"],
        "maatregel": ["stap", "actie", "ingreep"],
        "verschillende": ["diverse", "uiteenlopende", "verscheidene"],
        "noodzakelijk": ["nodig", "vereist", "onmisbaar"],
        "ontwikkeling": ["groei", "vooruitgang", "evolutie"],
        "beslissing": ["keuze", "besluit", "afweging"],
        "ervaring": ["kennis", "praktijk", "beleving"],
        "invloed": ["impact", "effect", "werking"],
    },

    # Alternatieve zinsbeginnnen
    "sentence_starters": {
        "Dit": ["Dat", "Zo iets", "Het"],
        "Het": ["Dit", "Dat", "Er"],
        "Men": ["Wij", "Je", "De mensen"],
        "De": ["Een", "Deze", "Die"],
        "Er": ["Daar", "Het", "Hier"],
        "Wij": ["We", "Ons team", "Men"],
        "In": ["Binnen", "Tijdens", "Bij"],
        "Voor": ["Om", "Ten behoeve van", "Wat betreft"],
        "Ook": ["Tevens", "Eveneens", "Daarnaast"],
        "Deze": ["Die", "Dergelijke", "Zulke"],
        "Echter": ["Maar", "Toch", "Desondanks"],
        "Daarom": ["Vandaar", "Om die reden", "Dus"],
        "Wanneer": ["Als", "Zodra", "Op het moment dat"],
        "Hoewel": ["Ofschoon", "Ondanks dat", "Al"],
        "Vervolgens": ["Daarna", "Dan", "Aansluitend"],
        "Uiteraard": ["Natuurlijk", "Vanzelfsprekend", "Logisch"],
        "Reeds": ["Al", "Inmiddels", "Intussen"],
        "Hier": ["Op deze plek", "Hierbij", "In dit geval"],
    },

    # Spreektaalmarkeringen
    "colloquial_markers": [
        "eerlijk gezegd", "eigenlijk", "in principe", "op zich",
        "onder ons gezegd", "trouwens", "strikt genomen",
        "als je het mij vraagt", "zeg maar", "nou ja",
        "zogezegd", "laten we eerlijk zijn", "uiteindelijk",
        "grappig genoeg", "verrassend genoeg", "opvallend genoeg",
        "kortom", "enfin", "hoe dan ook", "per slot van rekening",
        "ik bedoel", "weet je", "snap je", "tja",
        "overigens", "tussen haakjes", "even terzijde",
        "als ik zo vrij mag zijn", "in alle eerlijkheid",
        "om maar even te zeggen", "laat ik het zo zeggen",
    ],

    # Afkortingen
    "abbreviations": [
        "bijv.", "d.w.z.", "o.a.", "enz.", "resp.", "ca.", "vgl.",
        "dr.", "prof.", "nr.", "str.", "mln.", "mrd.",
        "evt.", "incl.", "excl.", "i.v.m.", "m.b.t.",
        "t.o.v.", "t.a.v.", "a.u.b.", "z.s.m.", "div.",
        "e.d.", "m.a.w.", "n.a.v.", "i.h.b.", "zgn.",
    ],

    # Perplexiteitsboosters
    "perplexity_boosters": [
        "welhaast", "daarentegen", "nichtans", "zogezegd",
        "vermoedelijk", "eventueel", "hoegenaamd",
        "nochthans", "inderdaad", "weliswaar", "geenszins",
        "allesbehalve", "veeleer", "dienovereenkomstig",
        "deswege", "anderzijds", "waarachtig", "onmiskenbaar",
        "klaarblijkelijk", "alleszins", "enigermate",
        "ongetwijfeld", "ontegenzeggelijk", "nochtans",
        "hoe dan ook", "kortweg", "goeddeels",
    ],

    # Doelprofielen
    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    # Voegwoorden voor samenvoeging
    "conjunctions": ["en", "maar", "of", "want", "omdat", "dus"],

    # Voegwoorden voor opsplitsing
    "split_conjunctions": [
        " en ", " maar ", " echter ", " waarbij ",
        " terwijl ", " hoewel ", " want ",
        ", en ", ", maar ", ", echter ",
        ", waarbij ", ", terwijl ", ", hoewel ",
        ", want ", ", omdat ",
        "; ", " – ", " — ",
    ],
}
