"""Språkpaket: Svenska (Swedish)."""

LANG_SV = {
    "code": "sv",
    "name": "Swedish",
    "native_name": "Svenska",

    # Trigram för språkdetektering
    "trigrams": [
        "för", "och", "det", "att", "som", "den", "har", "med",
        "ing", "ter", "ade", "och", "era", "lla", "nde", "tta",
        "gen", "lig", "äll", "ver", "and", "örf", "isk", "var",
        "arn", "ens", "ill", "sta", "nin", "kan",
    ],

    # Stoppord (ersätt inte)
    "stop_words": {
        "och", "att", "det", "som", "är", "var", "den", "för",
        "med", "har", "inte", "men", "ett", "av", "på", "till",
        "kan", "ska", "om", "från", "så", "vi", "de", "jag",
        "han", "hon", "sig", "sin", "sitt", "sina", "här",
        "där", "alla", "andra", "denna", "detta", "dessa",
        "vad", "vem", "hur", "när", "mer",
    },

    # Byråkratiska ord
    "bureaucratic": {
        "implementera": ["genomföra", "införa", "tillämpa"],
        "optimera": ["förbättra", "justera", "finslipa"],
        "evaluera": ["bedöma", "granska", "utvärdera"],
        "generera": ["skapa", "framställa", "alstra"],
        "initiera": ["starta", "inleda", "sätta igång"],
        "facilitera": ["underlätta", "möjliggöra"],
        "prioritera": ["ge företräde", "sätta först"],
        "kommunicera": ["meddela", "prata", "förmedla"],
        "finalisera": ["slutföra", "avsluta", "färdigställa"],
        "signifikant": ["betydande", "märkbar", "tydlig"],
        "fundamental": ["grundläggande", "väsentlig"],
        "essentiell": ["nödvändig", "viktig", "oumbärlig"],
        "adekvat": ["lämplig", "tillräcklig", "passande"],
        "primärt": ["i första hand", "huvudsakligen", "främst"],
        "successivt": ["stegvis", "efter hand", "gradvis"],
        "integrera": ["sammanfoga", "införliva", "bygga in"],
        "manifestera": ["visa", "uppenbara", "uttrycka"],
        "etablera": ["upprätta", "grunda", "inrätta"],
        "analysera": ["undersöka", "granska", "studera"],
        "specificera": ["ange", "bestämma", "precisera"],
        "identifiera": ["känna igen", "fastställa", "hitta"],
        "verifiera": ["kontrollera", "bekräfta", "styrka"],
        "koordinera": ["samordna", "avstämma"],
        "kompensera": ["ersätta", "gottgöra", "uppväga"],
        "intensifiera": ["förstärka", "öka", "trappa upp"],
        "reducera": ["minska", "sänka", "begränsa"],
        "transformera": ["omvandla", "förändra", "omforma"],
        "ackumulera": ["samla", "hopa", "ackumulera"],
        "anticipera": ["förutse", "vänta sig", "förekomma"],
        "artikulera": ["uttrycka", "formulera", "framföra"],
        "delegera": ["överlåta", "fördela", "överföra"],
        "demonstrera": ["visa", "påvisa", "bevisa"],
        "eliminera": ["ta bort", "avlägsna", "undanröja"],
        "expandera": ["utöka", "utvidga", "växa"],
        "formulera": ["uttrycka", "utforma", "gestalta"],
        "garantera": ["säkerställa", "trygga", "borga för"],
    },

    # Byråkratiska fraser
    "bureaucratic_phrases": {
        "med avseende på": ["angående", "gällande", "om"],
        "i enlighet med": ["enligt", "i linje med"],
        "inom ramen för": ["i", "under", "inom"],
        "i syfte att": ["för att", "med mål att"],
        "på grund av": ["eftersom", "därför att", "för att"],
        "med hänsyn till": ["med tanke på", "givet"],
        "det bör framhållas": ["det är viktigt", "notera att"],
        "av stor betydelse": ["viktig", "avgörande"],
        "spela en avgörande roll": ["vara viktig", "vara central"],
        "under förutsättning att": ["om", "förutsatt att"],
        "i brist på": ["utan", "i avsaknad av"],
        "ställa till förfogande": ["ge", "erbjuda", "tillhandahålla"],
        "ta i beaktande": ["beakta", "ta hänsyn till"],
        "vidta åtgärder": ["handla", "agera", "ingripa"],
        "komma till stånd": ["hända", "bli till", "genomföras"],
        "ta ställning till": ["bedöma", "avgöra"],
        "göra en bedömning av": ["bedöma", "utvärdera"],
        "i det avseendet": ["i det hänseendet", "här", "på den punkten"],
    },

    # AI-kopplingar
    "ai_connectors": {
        "Dessutom": ["Också", "Därtill", "Utöver det"],
        "Icke desto mindre": ["Ändå", "Trots det", "Likväl"],
        "Följaktligen": ["Därför", "Alltså", "Således"],
        "Till följd av detta": ["Därför", "På grund av det"],
        "Vidare": ["Dessutom", "Också", "Därtill"],
        "I motsats till": ["Till skillnad från", "Men", "Däremot"],
        "I detta sammanhang": ["Här", "I det här fallet"],
        "Sammanfattningsvis": ["Kort sagt", "Sammantaget"],
        "Det bör framhållas": ["Viktigt är", "Notera att"],
        "Avslutningsvis": ["Till sist", "Slutligen", "Till slut"],
        "Likaså": ["Också", "Dessutom", "Likaledes"],
        "Således": ["Därför", "Alltså", "Följaktligen"],
        "Samtidigt": ["Parallellt", "Under tiden", "Dessutom"],
        "I synnerhet": ["Särskilt", "Framför allt", "Speciellt"],
        "I huvudsak": ["Främst", "I stort", "Huvudsakligen"],
        "Slutligen": ["Till sist", "Sist men inte minst"],
        "Det ska noteras": ["Observera", "Märk väl", "Notera"],
        "I det stora hela": ["Övergripande", "På det hela taget"],
        "Sålunda": ["Så", "Alltså", "Därför"],
        "Med andra ord": ["Det vill säga", "Annorlunda uttryckt"],
        "Inte minst": ["Också", "Dessutom", "Framför allt"],
        "Därutöver": ["Dessutom", "Utöver det", "Också"],
    },

    # Synonymer
    "synonyms": {
        "viktig": ["betydelsefull", "väsentlig", "central", "avgörande"],
        "stor": ["betydande", "avsevärd", "omfattande"],
        "liten": ["ringa", "obetydlig", "begränsad"],
        "snabb": ["rask", "kvick", "flink"],
        "långsam": ["trög", "seg", "maklig"],
        "bra": ["utmärkt", "duglig", "gedigen"],
        "dålig": ["bristfällig", "undermålig", "svag"],
        "möjlighet": ["chans", "tillfälle", "alternativ"],
        "problem": ["svårighet", "utmaning", "hinder"],
        "lösning": ["svar", "utväg", "bot"],
        "resultat": ["utfall", "slutresultat", "effekt"],
        "område": ["fält", "domän", "sfär"],
        "metod": ["tillvägagångssätt", "arbetssätt", "angreppssätt"],
        "process": ["förlopp", "gång", "förfarande"],
        "aspekt": ["sida", "dimension", "vinkel"],
        "orsak": ["anledning", "grund", "skäl"],
        "mål": ["syfte", "ändamål", "målsättning"],
        "uppgift": ["uppdrag", "arbete", "funktion"],
        "fördel": ["plus", "styrka", "vinst"],
        "nackdel": ["minus", "svaghet", "baksida"],
        "analys": ["granskning", "undersökning", "studie"],
        "kvalitet": ["standard", "nivå", "grad"],
        "effektiv": ["verkningsfull", "framgångsrik", "träffsäker"],
        "komplex": ["invecklad", "sammansatt", "mångfacetterad"],
        "modern": ["nutida", "aktuell", "samtida"],
        "faktor": ["omständighet", "element", "drivkraft"],
        "strategi": ["plan", "taktik", "angreppssätt"],
        "kontext": ["sammanhang", "omgivning", "bakgrund"],
        "perspektiv": ["synvinkel", "infallsvinkel", "ståndpunkt"],
        "situation": ["läge", "tillstånd", "förhållande"],
        "funktion": ["roll", "uppgift", "verkan"],
        "struktur": ["uppbyggnad", "indelning", "ordning"],
        "utveckling": ["framsteg", "tillväxt", "förändring"],
        "erfarenhet": ["kunskap", "vana", "praxis"],
        "inverkan": ["påverkan", "effekt", "inflytande"],
    },

    # Alternativa meningsinledningar
    "sentence_starters": {
        "Det": ["Detta", "Så", "Här"],
        "Man": ["Vi", "En", "Folk"],
        "Den": ["En", "Denna", "Vederbörande"],
        "Vi": ["Vårt team", "Man", "Alla"],
        "I": ["Inom", "Under", "Vid"],
        "För": ["Till", "I syfte att", "Med tanke på"],
        "Även": ["Dessutom", "Likaså", "Också"],
        "Denna": ["Den här", "En sådan", "Nämnda"],
        "Dock": ["Men", "Emellertid", "Likväl"],
        "Därför": ["Av den anledningen", "Alltså", "Följaktligen"],
        "När": ["Då", "I det ögonblick", "Så snart"],
        "Trots": ["Även om", "Oaktat", "Fastän"],
        "Sedan": ["Därefter", "Efteråt", "Sedan dess"],
        "Naturligtvis": ["Självklart", "Förstås", "Givetvis"],
        "Här": ["På denna punkt", "I detta fall"],
    },

    # Talspråksmarkörer
    "colloquial_markers": [
        "ärligt talat", "egentligen", "i princip", "i grund och botten",
        "mellan oss sagt", "förresten", "strängt taget",
        "om du frågar mig", "liksom", "typ", "asså",
        "så att säga", "faktiskt", "i slutändan",
        "lustigt nog", "överraskande nog", "märkligt nog",
        "kort sagt", "i alla fall", "hur som helst",
        "jag menar", "vet du", "eller hur",
        "för övrigt", "bara så du vet", "om jag ska vara ärlig",
    ],

    # Förkortningar
    "abbreviations": [
        "t.ex.", "d.v.s.", "bl.a.", "osv.", "resp.", "ca.", "jfr.",
        "dr.", "prof.", "nr.", "st.", "milj.", "mdr.",
        "ev.", "inkl.", "exkl.", "ang.", "m.m.",
        "s.k.", "m.fl.", "o.s.v.", "f.d.", "fr.o.m.",
        "t.o.m.", "p.g.a.", "e.d.",
    ],

    # Perplexitetsboostare
    "perplexity_boosters": [
        "förvisso", "nämligen", "rentav", "sålunda",
        "förmodligen", "eventuellt", "ingalunda",
        "likväl", "onekligen", "visserligen", "huruvida",
        "snudd på", "bevisligen", "ovedersägligen",
        "hursomhelst", "tveklöst", "otvivelaktigt",
        "framförallt", "allena", "jämväl", "fördenskull",
        "dessbättre", "dessvärre", "förty", "givetvis",
    ],

    # Målprofiler
    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    # Konjunktioner för sammanslagning
    "conjunctions": ["och", "men", "eller", "för", "eftersom", "så"],

    # Konjunktioner för uppdelning
    "split_conjunctions": [
        " och ", " men ", " dock ", " varvid ",
        " medan ", " trots att ", " för att ",
        ", och ", ", men ", ", dock ",
        ", medan ", ", trots att ",
        ", eftersom ", ", så att ",
        "; ", " – ", " — ",
    ],
}
