"""Українськiй мовний пакет."""

LANG_UK = {
    "code": "uk",
    "name": "Українська",

    # Часті тріграми для визначення мови
    "trigrams": [
        " на", "на ", " не", "не ", " пр", " за", "що ", "ого", "ння",
        "ани", "ати", "ств", " ко", "про", " ви", "ій ", "нн ", "від",
        " ро", "ськ", " по", " до", " як", "ть ", "ів ", "ний", " бу",
        "ні ", "ого", " ма", "ові", "ії ", "ком", "ста", "пер", "ере",
        "при", " мо", "ами", "ень", " де", "тор", "ик ", "ист", "ван",
    ],

    # Стоп-слова
    "stop_words": {
        "і", "в", "на", "з", "по", "для", "не", "від", "за", "до",
        "що", "це", "як", "але", "а", "то", "все", "так", "його",
        "вона", "він", "ми", "ви", "вони", "її", "їх", "був", "бути",
        "б", "же", "чи", "або", "ні", "о", "об", "при", "через",
        "після", "перед", "між", "без", "під", "над", "у", "во",
        "вже", "ще", "також", "тільки", "якщо", "коли", "де", "хто",
        "цей", "ця", "ці", "той", "та", "ті", "свій", "свої",
        "мій", "моя", "мої", "ваш", "ваша", "ваші", "наш",
        "який", "яка", "яке", "які", "котрий", "котра",
    },

    # Канцеляризми → прості заміни
    "bureaucratic": {
        "даний": ["цей", "цей"],
        "дана": ["ця", "ця"],
        "дане": ["це", "це"],
        "здійснювати": ["робити", "проводити"],
        "здійснити": ["зробити", "провести"],
        "здійснює": ["робить", "проводить"],
        "здійснюється": ["робиться", "відбувається"],
        "здійснення": ["проведення", "виконання"],
        "функціонувати": ["працювати", "діяти"],
        "функціонує": ["працює", "діє"],
        "функціонування": ["робота", "дія"],
        "реалізовувати": ["робити", "виконувати"],
        "реалізувати": ["зробити", "виконати"],
        "реалізація": ["виконання", "створення"],
        "надавати": ["давати", "передавати"],
        "надає": ["дає", "передає"],
        "забезпечувати": ["давати", "створювати"],
        "забезпечує": ["дає", "створює"],
        "забезпечення": ["створення", "підтримка"],
        "характеризуватися": ["вирізнятися", "мати"],
        "характеризується": ["вирізняється", "має"],
        "зумовлювати": ["визначати", "спричиняти"],
        "зумовлює": ["визначає", "спричиняє"],
        "зумовлений": ["спричинений", "пов'язаний з"],
        "засобом": ["за допомогою", "через"],
        "внаслідок": ["через", "тому що"],
        "з метою": ["для", "щоб"],
        "на підставі": ["за", "на основі"],
        "зважаючи": ["через", "тому що"],
        "у процесі": ["при", "під час"],
        "в обов'язковому порядку": ["обов'язково", "неодмінно"],
        "належним чином": ["правильно", "як треба"],
        "відповідний": ["потрібний", "підходящий"],
        "відповідним чином": ["правильно", "підходяще"],
        "будь-яким чином": ["якось", "будь-як"],
        "значною мірою": ["багато в чому", "сильно"],
        "достатньою мірою": ["достатньо", "цілком"],
        "повною мірою": ["повністю", "цілком"],
        "найбільш": ["особливо", "надзвичайно"],
        "найменш": ["найменше", "найслабше"],
        "потенційний": ["можливий", "імовірний"],
        "безпосередньо": ["прямо", "одразу"],
        "надалі": ["потім", "далі"],
        "надзвичайно": ["дуже", "вкрай"],
        "суттєво": ["сильно", "помітно"],
        "розташовувати": ["мати", "володіти"],
        "ускладнено": ["складно", "важко"],
        "негайно": ["одразу", "зараз же"],
        "доцільно": ["розумно", "має сенс"],
        "недоцільно": ["не варто", "немає сенсу"],
        "належить": ["потрібно", "слід"],
        "вищезазначений": ["цей", "зазначений вище"],
        "вищезгаданий": ["цей", "згаданий вище"],
        "нижченаведений": ["наступний", "такий"],
        # === v0.11.0 massive expansion ===
        "акумулювати": ["збирати", "накопичувати"],
        "акумулює": ["збирає", "накопичує"],
        "анулювати": ["скасувати", "відкликати"],
        "анулює": ["скасовує", "відкликає"],
        "апелювати": ["звертатися", "посилатися"],
        "апелює": ["звертається", "посилається"],
        "апробувати": ["перевірити", "випробувати"],
        "апробує": ["перевіряє", "випробовує"],
        "аргументувати": ["обґрунтувати", "пояснити"],
        "аргументує": ["обґрунтовує", "пояснює"],
        "базуватися": ["будуватися", "спиратися"],
        "базується": ["будується", "спирається"],
        "верифікувати": ["перевірити", "підтвердити"],
        "верифікує": ["перевіряє", "підтверджує"],
        "візуалізувати": ["показати", "зобразити"],
        "візуалізує": ["показує", "зображає"],
        "генерувати": ["створювати", "породжувати"],
        "генерує": ["створює", "породжує"],
        "детермінувати": ["визначати", "задавати"],
        "детермінує": ["визначає", "задає"],
        "диференціювати": ["розрізняти", "розділяти"],
        "диференціює": ["розрізняє", "розділяє"],
        "домінувати": ["переважати", "панувати"],
        "домінує": ["переважає", "панує"],
        "дублювати": ["повторювати", "копіювати"],
        "дублює": ["повторює", "копіює"],
        "ідентифікувати": ["визначити", "виявити"],
        "ідентифікує": ["визначає", "виявляє"],
        "ілюструвати": ["показувати", "демонструвати"],
        "ілюструє": ["показує", "підтверджує"],
        "імплементувати": ["впровадити", "застосувати"],
        "імплементує": ["впроваджує", "застосовує"],
        "ініціювати": ["почати", "запустити"],
        "ініціює": ["починає", "запускає"],
        "інспектувати": ["перевіряти", "оглядати"],
        "інспектує": ["перевіряє", "оглядає"],
        "інтегрувати": ["об'єднувати", "включати"],
        "інтегрує": ["об'єднує", "включає"],
        "інтерпретувати": ["тлумачити", "пояснювати"],
        "інтерпретує": ["тлумачить", "пояснює"],
        "інформувати": ["повідомляти", "сповіщати"],
        "інформує": ["повідомляє", "сповіщає"],
        "класифікувати": ["розділяти", "групувати"],
        "класифікує": ["розділяє", "групує"],
        "компенсувати": ["відшкодувати", "заповнити"],
        "компенсує": ["відшкодовує", "заповнює"],
        "конкретизувати": ["уточнити", "пояснити"],
        "конкретизує": ["уточнює", "пояснює"],
        "консолідувати": ["об'єднувати", "зміцнювати"],
        "консолідує": ["об'єднує", "зміцнює"],
        "констатувати": ["зазначати", "фіксувати"],
        "констатує": ["зазначає", "фіксує"],
        "контролювати": ["стежити", "перевіряти"],
        "контролює": ["стежить", "перевіряє"],
        "координувати": ["узгоджувати", "налагоджувати"],
        "координує": ["узгоджує", "налагоджує"],
        "коригувати": ["виправляти", "поправляти"],
        "коригує": ["виправляє", "поправляє"],
        "ліквідувати": ["усунути", "прибрати"],
        "ліквідує": ["усуває", "прибирає"],
        "лімітувати": ["обмежувати", "стримувати"],
        "лімітує": ["обмежує", "стримує"],
        "локалізувати": ["знайти", "визначити місце"],
        "локалізує": ["знаходить", "визначає місце"],
        "максимізувати": ["збільшити", "підсилити"],
        "максимізує": ["збільшує", "підсилює"],
        "мінімізувати": ["зменшити", "знизити"],
        "мінімізує": ["зменшує", "знижує"],
        "модернізувати": ["оновити", "покращити"],
        "модернізує": ["оновлює", "покращує"],
        "модифікувати": ["змінити", "поправити"],
        "модифікує": ["змінює", "поправляє"],
        "мотивувати": ["спонукати", "надихати"],
        "мотивує": ["спонукає", "надихає"],
        "нівелювати": ["згладжувати", "зменшувати"],
        "нівелює": ["згладжує", "зменшує"],
        "оптимізувати": ["покращити", "налаштувати"],
        "оптимізує": ["покращує", "налаштовує"],
        "позиціонувати": ["розміщувати", "виставляти"],
        "позиціонує": ["розміщує", "виставляє"],
        "пролонгувати": ["продовжити", "подовжити"],
        "пролонгує": ["продовжує", "подовжує"],
        "регламентувати": ["визначати правила", "встановлювати порядок"],
        "регламентує": ["визначає правила", "встановлює порядок"],
        "регулювати": ["налаштовувати", "керувати"],
        "регулює": ["налаштовує", "керує"],
        "резюмувати": ["підсумувати", "узагальнити"],
        "резюмує": ["підсумовує", "узагальнює"],
        "санкціонувати": ["дозволити", "схвалити"],
        "санкціонує": ["дозволяє", "схвалює"],
        "систематизувати": ["упорядкувати", "привести до ладу"],
        "систематизує": ["упорядковує", "приводить до ладу"],
        "стабілізувати": ["зміцнити", "вирівняти"],
        "стабілізує": ["зміцнює", "вирівнює"],
        "стимулювати": ["спонукати", "підштовхувати"],
        "стимулює": ["спонукає", "підштовхує"],
        "структурувати": ["упорядкувати", "організувати"],
        "структурує": ["упорядковує", "організовує"],
        "трансформувати": ["змінити", "переробити"],
        "трансформує": ["змінює", "переробляє"],
        "фіксувати": ["зазначати", "записувати"],
        "фіксує": ["зазначає", "записує"],
        "формулювати": ["висловлювати", "викладати"],
        "формулює": ["висловлює", "викладає"],
        # --- Прикметники / прислівники ---
        "актуальний": ["важливий", "нагальний"],
        "актуальна": ["важлива", "нагальна"],
        "аналогічний": ["схожий", "такий самий"],
        "аналогічна": ["схожа", "така сама"],
        "безальтернативний": ["єдиний", "неминучий"],
        "деструктивний": ["руйнівний", "шкідливий"],
        "додатковий": ["ще один", "добавочний"],
        "додаткова": ["ще одна", "добавочна"],
        "ідентичний": ["однаковий", "точно такий самий"],
        "ідентична": ["однакова", "точно така сама"],
        "індивідуальний": ["особистий", "власний"],
        "індивідуальна": ["особиста", "власна"],
        "колосальний": ["величезний", "грандіозний"],
        "колосальна": ["величезна", "грандіозна"],
        "комплексний": ["складний", "багатосторонній"],
        "комплексна": ["складна", "багатостороння"],
        "конструктивний": ["корисний", "діловий"],
        "конструктивна": ["корисна", "ділова"],
        "масштабний": ["великий", "обширний"],
        "масштабна": ["велика", "обширна"],
        "негативний": ["поганий", "від'ємний"],
        "негативна": ["погана", "від'ємна"],
        "оперативно": ["швидко", "без зволікань"],
        "перспективний": ["обіцяючий", "майбутній"],
        "перспективна": ["обіцяюча", "майбутня"],
        "позитивний": ["хороший", "додатний"],
        "позитивна": ["хороша", "додатна"],
        "пріоритетний": ["головний", "першочерговий"],
        "пріоритетна": ["головна", "першочергова"],
        "специфічний": ["особливий", "характерний"],
        "специфічна": ["особлива", "характерна"],
        "стратегічний": ["важливий", "ключовий"],
        "стратегічна": ["важлива", "ключова"],
        "суттєвий": ["помітний", "серйозний"],
        "суттєва": ["помітна", "серйозна"],
        "унікальний": ["єдиний у своєму роді", "неповторний"],
        "унікальна": ["єдина у своєму роді", "неповторна"],
        "фундаментальний": ["основний", "базовий"],
        "фундаментальна": ["основна", "базова"],
        # --- Іменники ---
        "аспект": ["бік", "грань"],
        "аспекти": ["боки", "грані"],
        "дефіцит": ["нестача", "брак"],
        "імплементація": ["впровадження", "застосування"],
        "компетенція": ["вміння", "навичка"],
        "компетенції": ["вміння", "навички"],
        "моніторинг": ["спостереження", "відстеження"],
        "парадигма": ["модель", "підхід"],
        "потенціал": ["можливості", "сила"],
        "пріоритет": ["головне", "першочергове"],
        "тенденція": ["тренд", "напрямок"],
        "тенденції": ["тренди", "напрямки"],
        "трансформація": ["зміна", "перебудова"],
        "фактор": ["причина", "обставина"],
        "фактори": ["причини", "обставини"],
        "ефективність": ["результативність", "віддача"],
        # === v0.12.0 expansion ===
        "адаптувати": ["пристосувати", "підлаштувати"],
        "адаптує": ["пристосовує", "підлаштовує"],
        "активізувати": ["посилити", "пожвавити"],
        "активізує": ["посилює", "пожвавлює"],
        "делегувати": ["доручити", "передати"],
        "делегує": ["доручає", "передає"],
        "демонструвати": ["показувати", "являти"],
        "демонструє": ["показує", "являє"],
        "деталізувати": ["уточнити", "розписати"],
        "деталізує": ["уточнює", "розписує"],
        "діагностувати": ["визначити", "виявити хворобу"],
        "діагностує": ["визначає", "виявляє"],
        "дискутувати": ["обговорювати", "сперечатися"],
        "дискутує": ["обговорює", "сперечається"],
        "документувати": ["записувати", "занотовувати"],
        "документує": ["записує", "занотовує"],
        "експлуатувати": ["використовувати", "вживати"],
        "експлуатує": ["використовує", "вживає"],
        "елімінувати": ["усунути", "видалити"],
        "елімінує": ["усуває", "видаляє"],
        "ескалувати": ["загострити", "посилити"],
        "ескалує": ["загострює", "посилює"],
        "фасилітувати": ["полегшити", "сприяти"],
        "фасилітує": ["полегшує", "сприяє"],
        "фінансувати": ["оплачувати", "спонсорувати"],
        "фінансує": ["оплачує", "спонсорує"],
        "фокусувати": ["зосереджувати", "спрямовувати"],
        "фокусує": ["зосереджує", "спрямовує"],
        "формалізувати": ["оформити", "узаконити"],
        "формалізує": ["оформлює", "узаконює"],
        "гарантувати": ["забезпечити", "запевнити"],
        "гарантує": ["забезпечує", "запевняє"],
        "гармонізувати": ["узгодити", "привести у відповідність"],
        "гармонізує": ["узгоджує", "приводить у відповідність"],
        "ігнорувати": ["не зважати", "пропускати"],
        "ігнорує": ["не зважає", "пропускає"],
        "каталогізувати": ["описати", "переписати"],
        "каталогізує": ["описує", "переписує"],
        "кваліфікувати": ["визначити як", "оцінити"],
        "кваліфікує": ["визначає як", "оцінює"],
        "конвертувати": ["перетворити", "обміняти"],
        "конвертує": ["перетворює", "обмінює"],
        "культивувати": ["плекати", "виховувати"],
        "культивує": ["плекає", "виховує"],
        "легітимізувати": ["узаконити", "визнати законним"],
        "легітимізує": ["узаконює", "визнає законним"],
        "маніпулювати": ["підлаштовувати", "керувати приховано"],
        "маніпулює": ["підлаштовує", "керує приховано"],
        "маркувати": ["позначати", "ставити мітку"],
        "маркує": ["позначає", "мітить"],
        "нейтралізувати": ["знешкодити", "усунути вплив"],
        "нейтралізує": ["знешкоджує", "усуває вплив"],
        "нормалізувати": ["привести до ладу", "впорядкувати"],
        "нормалізує": ["приводить до ладу", "впорядковує"],
        "орієнтувати": ["спрямовувати", "направляти"],
        "орієнтує": ["спрямовує", "направляє"],
        "пріоритезувати": ["визначити головне", "розставити пріоритети"],
        "пріоритезує": ["визначає головне", "розставляє пріоритети"],
        "прогнозувати": ["передбачати", "очікувати"],
        "прогнозує": ["передбачає", "очікує"],
        "пропагувати": ["поширювати", "просувати"],
        "пропагує": ["поширює", "просуває"],
        "проєктувати": ["створювати план", "планувати"],
        "проєктує": ["створює план", "планує"],
        "рекомендувати": ["порадити", "запропонувати"],
        "рекомендує": ["радить", "пропонує"],
        "репрезентувати": ["представляти", "втілювати"],
        "репрезентує": ["представляє", "втілює"],
        "ротувати": ["змінювати по черзі", "чергувати"],
        "ротує": ["змінює по черзі", "чергує"],
        "сертифікувати": ["підтвердити якість", "засвідчити"],
        "сертифікує": ["підтверджує якість", "засвідчує"],
        "сигналізувати": ["повідомляти", "вказувати"],
        "сигналізує": ["повідомляє", "вказує"],
        "символізувати": ["означати", "уособлювати"],
        "символізує": ["означає", "уособлює"],
        "синхронізувати": ["узгодити в часі", "звести докупи"],
        "синхронізує": ["узгоджує в часі", "зводить докупи"],
        "специфікувати": ["уточнити", "визначити детально"],
        "специфікує": ["уточнює", "визначає детально"],
        "тестувати": ["перевіряти", "випробовувати"],
        "тестує": ["перевіряє", "випробовує"],
        "транслювати": ["передавати", "поширювати"],
        "транслює": ["передає", "поширює"],
        "утилізувати": ["переробити", "позбутися"],
        "утилізує": ["переробляє", "позбувається"],
        # --- Прикметники / прислівники (v0.12.0) ---
        "автономний": ["самостійний", "незалежний"],
        "автономна": ["самостійна", "незалежна"],
        "альтернативний": ["інший", "запасний"],
        "альтернативна": ["інша", "запасна"],
        "домінантний": ["панівний", "провідний"],
        "домінантна": ["панівна", "провідна"],
        "екстраординарний": ["надзвичайний", "винятковий"],
        "ексклюзивний": ["виключний", "єдиний"],
        "ексклюзивна": ["виключна", "єдина"],
        "категоричний": ["рішучий", "безапеляційний"],
        "категорична": ["рішуча", "безапеляційна"],
        "радикальний": ["докорінний", "рішучий"],
        "радикальна": ["докорінна", "рішуча"],
        "систематичний": ["послідовний", "планомірний"],
        "систематична": ["послідовна", "планомірна"],
        "превентивний": ["попереджувальний", "запобіжний"],
        "превентивна": ["попереджувальна", "запобіжна"],
        "прецедентний": ["показовий", "типовий"],
        "прецедентна": ["показова", "типова"],
        "тактичний": ["практичний", "прикладний"],
        "тактична": ["практична", "прикладна"],
        "пропорційний": ["відповідний", "співмірний"],
        "пропорційна": ["відповідна", "співмірна"],
        "раціональний": ["розумний", "розсудливий"],
        "раціональна": ["розумна", "розсудлива"],
        "релевантний": ["доречний", "стосовний"],
        "релевантна": ["доречна", "стосовна"],
        # --- Іменники (v0.12.0) ---
        "альтернатива": ["заміна", "інший варіант"],
        "контекст": ["обставини", "умови"],
        "концепція": ["ідея", "задум"],
        "критерій": ["мірило", "ознака"],
        "критерії": ["мірила", "ознаки"],
        "резонанс": ["відгук", "відлуння"],
        "конфігурація": ["налаштування", "будова"],
        "кореляція": ["зв'язок", "залежність"],
        "номенклатура": ["перелік", "список"],
        "специфіка": ["особливість", "своєрідність"],
        "інфраструктура": ["основа", "база"],
        "методологія": ["підхід", "метод"],
        # --- v0.27.0 expansion: дієслова ---
        "забезпечувати": ["давати", "гарантувати"],
        "забезпечує": ["дає", "гарантує"],
        "здійснювати вплив": ["впливати", "діяти"],
        "зумовлювати": ["спричиняти", "викликати"],
        "зумовлює": ["спричиняє", "викликає"],
        "обумовлювати": ["пояснювати", "визначати"],
        "обумовлює": ["пояснює", "визначає"],
        "уможливлювати": ["дозволяти", "давати можливість"],
        "уможливлює": ["дозволяє", "дає можливість"],
        "передбачати": ["очікувати", "планувати"],
        "передбачає": ["очікує", "планує"],
        "характеризувати": ["описувати", "окреслювати"],
        "характеризує": ["описує", "окреслює"],
        "ідентифікувати": ["розпізнати", "визначити"],
        "ідентифікує": ["розпізнає", "визначає"],
        "акумулювати": ["накопичувати", "збирати"],
        "акумулює": ["накопичує", "збирає"],
        "верифікувати": ["перевірити", "підтвердити"],
        "верифікує": ["перевіряє", "підтверджує"],
        "імплементувати": ["впровадити", "запустити"],
        "імплементує": ["впроваджує", "запускає"],
        "оптимізувати": ["покращити", "вдосконалити"],
        "оптимізує": ["покращує", "вдосконалює"],
        "трансформувати": ["перетворити", "змінити"],
        "трансформує": ["перетворює", "змінює"],
        "генерувати": ["створювати", "породжувати"],
        "генерує": ["створює", "породжує"],
        "демонструвати": ["показувати", "являти"],
        "демонструє": ["показує", "являє"],
        "ініціювати": ["розпочати", "запустити"],
        "ініціює": ["розпочинає", "запускає"],
        "модифікувати": ["змінити", "переробити"],
        "модифікує": ["змінює", "переробляє"],
        "стимулювати": ["підштовхувати", "заохочувати"],
        "стимулює": ["підштовхує", "заохочує"],
        "інтегрувати": ["поєднати", "об'єднати"],
        "інтегрує": ["поєднує", "об'єднує"],
        "координувати": ["узгоджувати", "керувати"],
        "координує": ["узгоджує", "керує"],
        "формулювати": ["виражати", "описувати"],
        "формулює": ["виражає", "описує"],
        # --- v0.27.0 expansion: прикметники ---
        "оптимальний": ["найкращий", "найвдаліший"],
        "оптимальна": ["найкраща", "найвдаліша"],
        "системний": ["цілісний", "упорядкований"],
        "системна": ["цілісна", "упорядкована"],
        "стратегічний": ["довгостроковий", "ключовий"],
        "стратегічна": ["довгострокова", "ключова"],
        "пріоритетний": ["першочерговий", "головний"],
        "пріоритетна": ["першочергова", "головна"],
        "превентивний": ["запобіжний", "попереджувальний"],
        "превентивна": ["запобіжна", "попереджувальна"],
        "інтенсивний": ["активний", "потужний"],
        "інтенсивна": ["активна", "потужна"],
        "консолідований": ["об'єднаний", "зведений"],
        "консолідована": ["об'єднана", "зведена"],
        "репрезентативний": ["представницький", "показовий"],
        "репрезентативна": ["представницька", "показова"],
        "ексклюзивний": ["виключний", "особливий"],
        "ексклюзивна": ["виключна", "особлива"],
        "перманентний": ["постійний", "тривалий"],
        "перманентна": ["постійна", "тривала"],
        "домінуючий": ["переважний", "панівний"],
        "домінуюча": ["переважна", "панівна"],
        "маргінальний": ["другорядний", "периферійний"],
        "маргінальна": ["другорядна", "периферійна"],
        "деструктивний": ["руйнівний", "шкідливий"],
        "деструктивна": ["руйнівна", "шкідлива"],
        "конструктивний": ["корисний", "плідний"],
        "конструктивна": ["корисна", "плідна"],
        "латентний": ["прихований", "непомітний"],
        "латентна": ["прихована", "непомітна"],
        # --- v0.27.0 expansion: іменники ---
        "парадигма": ["модель", "зразок"],
        "тенденція": ["тренд", "напрямок"],
        "перспектива": ["можливість", "майбутнє"],
        "прерогатива": ["право", "привілей"],
        "компетенція": ["обізнаність", "вміння"],
        "компетенції": ["знання", "вміння"],
        "детермінанта": ["чинник", "визначальний фактор"],
        "симптоматика": ["ознаки", "прояви"],
        "пролонгація": ["продовження", "подовження"],
        "сегментація": ["поділ", "розподіл"],
        "диверсифікація": ["урізноманітнення", "розширення"],
        "валідація": ["перевірка", "підтвердження"],
        "кон'юнктура": ["обстановка", "ситуація"],
        "номінація": ["назва", "найменування"],
        "генерація": ["створення", "продукування"],
        "інтерпретація": ["тлумачення", "пояснення"],
        "модернізація": ["оновлення", "осучаснення"],
        "локалізація": ["розміщення", "місцезнаходження"],
        "дислокація": ["розташування", "місцезнаходження"],
        "індикатор": ["показник", "мірило"],
        "ресурсозабезпечення": ["постачання ресурсів", "наповнення ресурсами"],
        "функціонал": ["можливості", "набір функцій"],
        "дефініція": ["визначення", "означення"],
        "пріоритет": ["першочерговість", "головне"],
        "пріоритети": ["першочергові завдання", "головне"],
        "менеджмент": ["управління", "керівництво"],
        "маркетинг": ["просування", "збут"],
        "моніторинг": ["стеження", "нагляд"],
    },

    # Фразові канцеляризми
    "bureaucratic_phrases": {
        "є одним із": ["— один із", "один із"],
        "є одним з": ["— один з", "один з"],
        "являє собою": ["— це", "це"],
        "являють собою": ["— це", "це"],
        "надавати сприяння": ["допомагати", "сприяти"],
        "надає сприяння": ["допомагає", "сприяє"],
        "приймати рішення": ["вирішувати", "обирати"],
        "прийняти рішення": ["вирішити", "обрати"],
        "здійснювати оплату": ["платити", "оплачувати"],
        "справляти вплив": ["впливати", "діяти"],
        "справляє вплив": ["впливає", "діє"],
        "у тому випадку, якщо": ["якщо", "коли"],
        "у тому випадку якщо": ["якщо", "коли"],
        "у зв'язку з тим, що": ["тому що", "оскільки"],
        "у зв'язку з тим що": ["тому що", "оскільки"],
        "з причини того, що": ["тому що", "оскільки"],
        "зважаючи на те, що": ["тому що", "оскільки"],
        "володіти здатністю": ["могти", "вміти"],
        "володіє здатністю": ["може", "вміє"],
        "на даний час": ["зараз", "тепер"],
        "на теперішній час": ["зараз", "тепер"],
        "на сьогоднішній день": ["сьогодні", "зараз"],
        "на поточний момент": ["зараз", "поки"],
        "у кінцевому рахунку": ["у підсумку", "зрештою"],
        "у кінцевому підсумку": ["у підсумку", "зрештою"],
        "протягом тривалого часу": ["давно", "довго"],
        "у рамках": ["у", "в"],
        "відповідно до": ["за", "згідно з"],
        "з точки зору": ["для", "з погляду"],
        "необхідно зазначити": ["важливо", "варто сказати"],
        "необхідно підкреслити": ["важливо", "варто зазначити"],
        "слід зазначити": ["важливо", "варто сказати"],
        "варто зазначити, що": ["важливо, що", "зауважимо, що"],
        "не можна не зазначити": ["варто сказати", "важливо"],
        "важливо підкреслити, що": ["важливо, що", "варто сказати, що"],
        # === v0.11.0 massive expansion ===
        "для того, щоб": ["щоб", "для"],
        "для того щоб": ["щоб", "для"],
        "мати місце": ["відбуватися", "бути"],
        "має місце": ["відбувається", "є"],
        "відіграє ключову роль": ["важливий", "сильно впливає"],
        "несе відповідальність": ["відповідає", "відповідальний"],
        "проводити аналіз": ["аналізувати", "розбирати"],
        "проводить аналіз": ["аналізує", "розбирає"],
        "проводити моніторинг": ["стежити", "відстежувати"],
        "проводить моніторинг": ["стежить", "відстежує"],
        "з урахуванням того, що": ["враховуючи, що", "раз"],
        "на підставі вищесказаного": ["тому", "отже"],
        "приділяти увагу": ["звертати увагу", "займатися"],
        "приділяє увагу": ["звертає увагу", "займається"],
        "слід мати на увазі": ["врахуйте", "пам'ятайте"],
        "в якості прикладу": ["наприклад", "скажімо"],
        # === v0.12.0 expansion ===
        "брати участь у": ["долучатися до", "бути в"],
        "бере участь у": ["долучається до", "є частиною"],
        "вести діяльність": ["працювати", "займатися"],
        "веде діяльність": ["працює", "займається"],
        "виступати у ролі": ["бути", "діяти як"],
        "виступає у ролі": ["є", "діє як"],
        "дотримуватися думки": ["вважати", "думати"],
        "дотримується думки": ["вважає", "думає"],
        "здійснювати контроль": ["контролювати", "стежити"],
        "здійснює контроль": ["контролює", "стежить"],
        "здійснювати вплив на": ["впливати на", "діяти на"],
        "здійснює вплив на": ["впливає на", "діє на"],
        "нести відповідальність за": ["відповідати за", "бути відповідальним за"],
        "виявляти бажання": ["хотіти", "бажати"],
        "виявляє бажання": ["хоче", "бажає"],
        "у відповідності до": ["відповідно до", "згідно з"],
        "у відповідності з": ["відповідно до", "згідно з"],
        "за відсутності": ["без", "коли немає"],
        "за наявності": ["якщо є", "коли є"],
        "в частині": ["щодо", "стосовно"],
        "на предмет": ["щодо", "про"],
        "за рахунок": ["завдяки", "через"],
        "у свою чергу": ["зі свого боку", "натомість"],
        "в обсязі": ["на суму", "у розмірі"],
        "мати можливість": ["могти", "бути в змозі"],
        "має можливість": ["може", "здатний"],
        "в силу того, що": ["тому що", "оскільки"],
        "з огляду на те, що": ["оскільки", "враховуючи що"],
        "з огляду на": ["враховуючи", "через"],
        "на користь": ["для", "задля"],
        "в цілях": ["для", "заради"],
        # --- v0.27.0 expansion ---
        "здійснювати планування": ["планувати", "продумувати"],
        "здійснює планування": ["планує", "продумує"],
        "здійснювати перевірку": ["перевіряти", "звіряти"],
        "здійснює перевірку": ["перевіряє", "звіряє"],
        "здійснювати підготовку": ["готувати", "готуватися"],
        "здійснює підготовку": ["готує", "готується"],
        "здійснювати відбір": ["обирати", "відбирати"],
        "здійснює відбір": ["обирає", "відбирає"],
        "здійснювати доставку": ["доставляти", "привозити"],
        "здійснює доставку": ["доставляє", "привозить"],
        "здійснювати оцінку": ["оцінювати", "визначати"],
        "здійснює оцінку": ["оцінює", "визначає"],
        "здійснювати пошук": ["шукати", "розшукувати"],
        "здійснює пошук": ["шукає", "розшукує"],
        "вносити корективи": ["правити", "змінювати"],
        "вносить корективи": ["править", "змінює"],
        "надавати допомогу": ["допомагати", "підтримувати"],
        "надає допомогу": ["допомагає", "підтримує"],
        "прийти до висновку": ["зрозуміти", "усвідомити"],
        "приходить до висновку": ["розуміє", "усвідомлює"],
        "підлягає розгляду": ["розглядається", "буде розглянуто"],
        "з метою забезпечення": ["щоб забезпечити", "для"],
        "з метою реалізації": ["щоб реалізувати", "для"],
        "з метою покращення": ["щоб покращити", "для"],
        "з метою підвищення": ["щоб підвищити", "для"],
        "з метою оптимізації": ["щоб оптимізувати", "для"],
        "є результатом": ["виникає через", "пояснюється"],
        "є наслідком": ["виникає через", "пов'язано з"],
        "є свідченням": ["показує", "доводить"],
        "є підтвердженням": ["підтверджує", "доводить"],
        "є запорукою": ["забезпечує", "гарантує"],
        "ставити за мету": ["прагнути", "мати на меті"],
        "ставить за мету": ["прагне", "хоче"],
        "мати місце бути": ["відбуватися", "траплятися"],
        "вживати заходів": ["діяти", "робити"],
        "вживає заходів": ["діє", "робить"],
        "здійснювати діяльність": ["працювати", "діяти"],
        "здійснює діяльність": ["працює", "діє"],
        "має на меті": ["прагне", "хоче"],
        "полягає в тому, що": ["означає, що", "тобто"],
        "полягає в тому що": ["означає, що", "тобто"],
        "зводиться до того, що": ["означає, що", "тобто"],
        "виходячи з вищевикладеного": ["тому", "отже"],
        "беручи до уваги": ["враховуючи", "зважаючи на"],
    },

    # Слова-зв'язки, типові для ШІ → заміни
    "ai_connectors": {
        "Однак": ["Але", "Втім", "Проте", "Щоправда"],
        "Проте": ["Але", "Втім", "Однак", "Щоправда"],
        "Тим не менш": ["Але", "Все ж", "І все-таки", "Щоправда"],
        "Разом з тим": ["Але", "При цьому", "Хоча"],
        "Крім того": ["Ще", "Також", "І ще", "Плюс"],
        "Більш того": ["І ще", "До того ж", "Плюс"],
        "Окрім цього": ["Ще", "Також", "І"],
        "Таким чином": ["У підсумку", "Тому", "Отже", "Тож"],
        "Отже": ["Значить", "Тому", "Тож"],
        "Безумовно": ["Звісно", "Так", "Точно"],
        "Безсумнівно": ["Звісно", "Точно", "Так"],
        "На завершення": ["Підсумовуючи", "Наостанок", "Наприкінці"],
        "Передусім": ["Спочатку", "По-перше", "Для початку"],
        "В першу чергу": ["Спочатку", "Передусім", "Для початку"],
        "Не менш важливо": ["Важливо й те", "Також важливо", "І ще"],
        "З іншого боку": ["А ось", "Натомість", "Зате"],
        "Загалом": ["У цілому", "Якщо коротко", "Взагалі"],
        "Зокрема": ["Наприклад", "Скажімо", "Приміром"],
        "Варто підкреслити": ["Важливо", "Зауважимо", "Відзначимо"],
        "Необхідно розуміти": ["Важливо розуміти", "Врахуйте", "Майте на увазі"],
        "Важливо враховувати": ["Врахуйте", "Майте на увазі", "Не забувайте"],
        "Підсумовуючи": ["У підсумку", "Якщо коротко", "Загалом"],
        "Виходячи з цього": ["Тому", "Тож", "Значить"],
        "Як наслідок": ["Тому", "Через це", "У підсумку"],
        # === v0.11.0 massive expansion ===
        "Слід зауважити": ["Варто сказати", "Помітно", "І ось що"],
        "Варто зазначити": ["Важливо", "Майте на увазі", "Зауважимо"],
        "Слід зазначити, що": ["Варто сказати, що", "Цікаво, що", "Важливо, що"],
        "Необхідно відзначити": ["Варто сказати", "Зауважимо", "Важливо"],
        "Необхідно підкреслити": ["Варто підкреслити", "Важливо", "Примітно"],
        "По-перше": ["Спочатку", "Для початку", "Передусім"],
        "По-друге": ["Далі", "Також", "На додаток"],
        "По-третє": ["І ще", "Нарешті", "Наостанок"],
        "В цілому": ["Загалом", "У цілому", "Якщо загально"],
        "Слід підкреслити": ["Важливо", "Зауважимо", "Відзначимо"],
        "Також варто": ["Ще корисно", "Не завадить", "Плюс до цього"],
        "Важливо розуміти, що": ["Майте на увазі, що", "Врахуйте, що", "Пам'ятайте, що"],
        "Варто врахувати": ["Врахуйте", "Не забувайте", "Майте на увазі"],
        "Наступним кроком": ["Далі", "Після цього", "Потім"],
        "В кінцевому підсумку": ["Наприкінці", "Наостанок", "Зрештою"],
        "В кінцевому рахунку": ["Зрештою", "Наостанок", "У підсумку"],
        "В результаті": ["Як наслідок", "Через це", "Відтак"],
        "Зверніть увагу": ["Подивіться", "Зауважте", "Примітно"],
        "Не менш важливим": ["Важливим є також", "Також суттєвим", "І ще важливо"],
        "Як бачимо": ["Як видно", "Ясно", "Очевидно"],
        "Як доводить практика": ["На практиці", "Як показує досвід", "У реальності"],
        # === v0.12.0 expansion ===
        "У даному контексті": ["Тут", "У цьому разі", "Якщо говорити про це"],
        "Водночас": ["Разом із тим", "Паралельно", "Одночасно"],
        "Відповідно": ["Тому", "Отже", "Значить"],
        "Зрештою": ["У підсумку", "Наприкінці", "Врешті-решт"],
        "Щоправда": ["Але", "Втім", "Хоча"],
        "Натомість": ["Замість цього", "А от", "Зате"],
        "Наразі": ["Зараз", "Тепер", "На цей момент"],
        "Попри це": ["Хоча", "Незважаючи на це", "Але"],
        "Тож": ["Тому", "Відтак", "Отже"],
        "Відтак": ["Тому", "Тож", "Через це"],
        "Утім": ["Але", "Однак", "Та все ж"],
        "Згідно з цим": ["Тому", "Відповідно", "Через це"],
        "У такий спосіб": ["Так", "Цим шляхом", "Таким чином"],
        "З огляду на це": ["Тому", "Через це", "Враховуючи це"],
        "Поза тим": ["Крім того", "Ще", "До того ж"],
        "Понад те": ["Більше того", "До того ж", "Крім того"],
        "Принагідно": ["До речі", "Між іншим", "До слова"],
        "Вочевидь": ["Мабуть", "Схоже", "Напевно"],
        "Вірогідно": ["Мабуть", "Здається", "Схоже на те"],
        "Імовірно": ["Мабуть", "Можливо", "Здається"],
        "Нарешті": ["Зрештою", "Наостанок", "У кінці кінців"],
        "Практично": ["Фактично", "По суті", "Майже"],
        "Головним чином": ["Переважно", "В основному", "Передусім"],
        "У першу чергу": ["Спочатку", "Передусім", "Перш за все"],
        "Цілком очевидно": ["Зрозуміло", "Ясно", "Без сумніву"],
        "Невипадково": ["Не дарма", "Закономірно", "Цілком зрозуміло"],
        "Характерно, що": ["Помітно, що", "Варто сказати, що", "Цікаво, що"],
        "Примітно, що": ["Цікаво, що", "Варто зазначити, що", "Помітно, що"],
        "Саме тому": ["Ось чому", "Через це", "Тому"],
        "Не дивно, що": ["Зрозуміло, що", "Цілком логічно, що", "Очевидно, що"],
        # --- v0.27.0 expansion ---
        "У контексті цього": ["Щодо цього", "Стосовно цього", "У зв'язку з цим"],
        "Необхідно наголосити": ["Варто наголосити", "Підкреслимо", "Зауважимо"],
        "З іншого боку": ["Натомість", "А от", "Водночас"],
        "Саме тому що": ["Тому що", "Адже", "Бо"],
        "Особливо варто": ["Окремо слід", "Найбільше варто", "Зокрема"],
        "Не менш важливо": ["Також важливо", "Ще одне", "Крім того"],
        "Таким чином можна": ["Тож можна", "Значить можна", "Отже можна"],
        "Очевидно, що": ["Зрозуміло, що", "Ясно, що", "Помітно, що"],
        "Безсумнівно": ["Безперечно", "Звісно", "Ясна річ"],
        "Беззаперечно": ["Безумовно", "Без сумніву", "Це точно"],
        "Що стосується": ["Щодо", "Якщо говорити про", "Стосовно"],
        "В свою чергу": ["Натомість", "Зі свого боку", "А от"],
        "Разом із тим": ["Але", "Водночас", "Попри це"],
        "Тим часом": ["А поки", "А тим часом", "Паралельно"],
        "Передусім": ["Насамперед", "Спочатку", "Перш за все"],
        "За умови": ["Якщо", "Коли", "При"],
        "В умовах": ["За", "Коли є", "При"],
        "Як зазначалося": ["Як уже казали", "Як бачимо", "Як відомо"],
        "Як зазначалося раніше": ["Як ми казали", "Як вже було", "Раніше ми писали"],
        "Безумовно важливо": ["Безперечно важливо", "Вкрай важливо", "Точно варто"],
        "Слід акцентувати": ["Наголосимо", "Підкреслимо", "Варто виділити"],
        "Характерною рисою є": ["Відмінна риса —", "Особливість —", "Вирізняється тим, що"],
    },

    # Синоніми для усунення повторів
    "synonyms": {
        "важливий": ["значущий", "суттєвий", "ключовий", "вагомий"],
        "важлива": ["значуща", "суттєва", "ключова", "вагома"],
        "важливе": ["значуще", "суттєве", "ключове", "вагоме"],
        "важливо": ["суттєво", "значуще", "принципово"],
        "великий": ["чималий", "значний", "солідний"],
        "велика": ["чимала", "значна", "солідна"],
        "маленький": ["невеликий", "компактний", "малий", "скромний"],
        "гарний": ["чудовий", "гідний", "якісний", "непоганий"],
        "гарно": ["чудово", "непогано", "гідно", "на рівні"],
        "поганий": ["слабкий", "невдалий", "кепський"],
        "погано": ["слабко", "невдало", "кепсько"],
        "допомагати": ["сприяти", "підтримувати", "допомогти"],
        "допомагає": ["сприяє", "підтримує", "дає можливість"],
        "дозволяє": ["дає можливість", "допомагає", "забезпечує"],
        "використовувати": ["застосовувати", "задіяти", "брати"],
        "використовує": ["застосовує", "задіює", "бере"],
        "отримувати": ["здобувати", "набувати", "діставати"],
        "отримує": ["здобуває", "набуває", "дістає"],
        "створювати": ["формувати", "розробляти", "будувати"],
        "створює": ["формує", "розробляє", "будує"],
        "змінювати": ["перетворювати", "модифікувати", "правити"],
        "змінює": ["перетворює", "модифікує", "править"],
        "показувати": ["демонструвати", "відображати", "розкривати"],
        "показує": ["демонструє", "відображає", "розкриває"],
        "працювати": ["діяти", "трудитися", "функціонувати"],
        "працює": ["діє", "трудиться", "функціонує"],
        "швидко": ["стрімко", "оперативно", "скоро"],
        "повільно": ["поступово", "неквапливо", "плавно"],
        "часто": ["нерідко", "регулярно", "то й діло"],
        "багато": ["чимало", "достатньо", "доволі"],
        "дуже": ["вельми", "вкрай", "доволі"],
        "потрібно": ["варто", "слід", "необхідно"],
        "можна": ["допустимо", "реально", "цілком можливо"],
        "наприклад": ["скажімо", "приміром", "припустимо"],
        "тому": ["через це", "з цієї причини", "відтак"],
        "також": ["теж", "разом з тим", "ще"],
        "зараз": ["тепер", "наразі", "у цей момент"],
        "різний": ["різноманітний", "всілякий", "неоднаковий"],
        "основний": ["головний", "ключовий", "центральний"],
        "значний": ["суттєвий", "помітний", "чималий"],
        "ефективний": ["дієвий", "продуктивний", "результативний"],
        "ефективно": ["дієво", "продуктивно", "результативно"],
        "проблема": ["питання", "труднощі", "завдання"],
        "результат": ["підсумок", "наслідок", "плід"],
        "процес": ["хід", "перебіг", "дія"],
        "спосіб": ["метод", "шлях", "підхід"],
        "мета": ["завдання", "намір", "ціль"],
        "можливість": ["шанс", "варіант", "опція"],
        # === v0.11.0 massive expansion ===
        "новий": ["свіжий", "сучасний", "оновлений"],
        "нова": ["свіжа", "сучасна", "оновлена"],
        "нове": ["свіже", "сучасне", "оновлене"],
        "старий": ["давній", "попередній", "колишній"],
        "стара": ["давня", "попередня", "колишня"],
        "сильний": ["потужний", "міцний", "вагомий"],
        "сильна": ["потужна", "міцна", "вагома"],
        "слабкий": ["незначний", "кволий", "посередній"],
        "слабка": ["незначна", "квола", "посередня"],
        "правильний": ["вірний", "коректний", "точний"],
        "правильна": ["вірна", "коректна", "точна"],
        "правильно": ["вірно", "коректно", "точно"],
        "неправильний": ["хибний", "невірний", "некоректний"],
        "цікавий": ["захопливий", "привабливий", "примітний"],
        "цікава": ["захоплива", "приваблива", "примітна"],
        "цікаво": ["захопливо", "привабливо", "примітно"],
        "простий": ["нескладний", "легкий", "елементарний"],
        "проста": ["нескладна", "легка", "елементарна"],
        "просто": ["нескладно", "легко", "елементарно"],
        "складний": ["непростий", "багатогранний", "важкий"],
        "складна": ["непроста", "багатогранна", "важка"],
        "складно": ["непросто", "важко", "нелегко"],
        "різко": ["раптово", "стрімко", "круто"],
        "добре": ["непогано", "ладно", "гідно"],
        "перший": ["початковий", "стартовий", "вступний"],
        "перша": ["початкова", "стартова", "вступна"],
        "останній": ["кінцевий", "заключний", "фінальний"],
        "остання": ["кінцева", "заключна", "фінальна"],
        "повний": ["цілковитий", "абсолютний", "вичерпний"],
        "повна": ["цілковита", "абсолютна", "вичерпна"],
        "повністю": ["цілковито", "цілком", "абсолютно"],
        "частково": ["почасти", "деякою мірою", "не цілком"],
        "головний": ["основний", "центральний", "провідний"],
        "головна": ["основна", "центральна", "провідна"],
        "один": ["єдиний", "окремий", "поодинокий"],
        "однак": ["але", "втім", "зате"],
        "особливо": ["зокрема", "передусім", "надто"],
        "більше": ["понад", "дедалі більше", "більшою мірою"],
        "менше": ["меншою мірою", "не так багато", "менш"],
        "точно": ["безумовно", "напевно", "безсумнівно"],
        "приблизно": ["близько", "орієнтовно", "десь"],
        "завжди": ["постійно", "щоразу", "незмінно"],
        "ніколи": ["жодного разу", "в жодному разі", "зроду"],
        "іноді": ["часом", "інколи", "подеколи"],
        "раніше": ["до того", "перед цим", "свого часу"],
        "пізніше": ["потім", "згодом", "далі"],
        "відразу": ["одразу", "миттю", "негайно"],
        "вже": ["на цей момент", "на цю пору", "уже"],
        "ще": ["досі", "поки що", "все ще"],
        "здатний": ["спроможний", "готовий", "може"],
        "здатна": ["спроможна", "готова", "може"],
        "необхідний": ["потрібний", "обов'язковий", "конче потрібний"],
        "необхідна": ["потрібна", "обов'язкова", "конче потрібна"],
        "конкретний": ["певний", "визначений", "чіткий"],
        "конкретна": ["певна", "визначена", "чітка"],
        "загальний": ["спільний", "цілісний", "глобальний"],
        "загальна": ["спільна", "цілісна", "глобальна"],
        "сучасний": ["теперішній", "актуальний", "нинішній"],
        "сучасна": ["теперішня", "актуальна", "нинішня"],
        "типовий": ["характерний", "звичайний", "класичний"],
        "типова": ["характерна", "звичайна", "класична"],
        "реальний": ["справжній", "дійсний", "фактичний"],
        "реальна": ["справжня", "дійсна", "фактична"],
        "реально": ["справді", "дійсно", "фактично"],
        "думати": ["вважати", "гадати", "міркувати"],
        "думає": ["вважає", "гадає", "міркує"],
        "знати": ["розуміти", "усвідомлювати", "бути в курсі"],
        "знає": ["розуміє", "усвідомлює", "в курсі"],
        "робити": ["виконувати", "здійснювати", "чинити"],
        "робить": ["виконує", "здійснює", "чинить"],
        "говорити": ["казати", "стверджувати", "зазначати"],
        "говорить": ["каже", "стверджує", "зазначає"],
        "бачити": ["спостерігати", "помічати", "виявляти"],
        "бачить": ["спостерігає", "помічає", "виявляє"],
        "розуміти": ["усвідомлювати", "збагнути", "осягати"],
        "розуміє": ["усвідомлює", "збагнув", "осягає"],
        "починати": ["розпочинати", "стартувати", "братися"],
        "починає": ["розпочинає", "стартує", "береться"],
        "закінчувати": ["завершувати", "доводити до кінця", "фіналізувати"],
        "закінчує": ["завершує", "доводить до кінця", "фіналізує"],
        "давати": ["надавати", "забезпечувати", "постачати"],
        "дає": ["надає", "забезпечує", "постачає"],
        "брати": ["використовувати", "застосовувати", "залучати"],
        "бере": ["використовує", "застосовує", "залучає"],
        "розвиток": ["зростання", "прогрес", "еволюція"],
        "система": ["механізм", "структура", "комплекс"],
        "аналіз": ["дослідження", "розбір", "огляд"],
        "рівень": ["ступінь", "міра", "щабель"],
        "якість": ["рівень", "клас", "ґатунок"],
        "кількість": ["обсяг", "число", "маса"],
        "ситуація": ["обстановка", "стан справ", "становище"],
        "інформація": ["дані", "відомості", "факти"],
        "досвід": ["практика", "навички", "багаж знань"],
        "питання": ["тема", "аспект", "момент"],
        "область": ["сфера", "галузь", "царина"],
        "умова": ["передумова", "вимога", "обставина"],
        "частина": ["елемент", "складова", "компонент"],
        "група": ["команда", "колектив", "об'єднання"],
        "період": ["час", "етап", "проміжок"],
        "причина": ["чинник", "привід", "підстава"],
        "вплив": ["дія", "ефект", "тиск"],
        "увага": ["інтерес", "фокус", "акцент"],
        "зміна": ["перетворення", "трансформація", "корекція"],
        "завдання": ["задача", "доручення", "місія"],
        "рішення": ["вирішення", "відповідь", "вихід"],
        "успіх": ["досягнення", "перемога", "здобуток"],
        "ідея": ["задум", "концепція", "думка"],
        "факт": ["обставина", "дійсність", "реалія"],
        "дія": ["вчинок", "крок", "акт"],
        "ціна": ["вартість", "коштовність", "плата"],
        "значення": ["сенс", "роль", "вага"],
        "вибір": ["рішення", "альтернатива", "опція"],
        "різниця": ["відмінність", "зазор", "невідповідність"],
        "проект": ["планування", "ініціатива", "програма"],
        "підхід": ["метод", "стратегія", "тактика"],
        "набір": ["комплект", "пакет", "добірка"],
        "ресурс": ["запас", "джерело", "засіб"],
        "висновок": ["підсумок", "резюме", "узагальнення"],
        # === v0.12.0 expansion ===
        "шукати": ["розшукувати", "відшуковувати", "вишукувати"],
        "шукає": ["розшукує", "відшуковує", "вишукує"],
        "вважати": ["гадати", "міркувати", "мати на увазі"],
        "відчувати": ["переживати", "сприймати", "чути"],
        "відчуває": ["переживає", "сприймає", "чує"],
        "пропонувати": ["радити", "висувати", "рекомендувати"],
        "пропонує": ["радить", "висуває", "рекомендує"],
        "залишати": ["лишати", "покидати", "полишати"],
        "залишає": ["лишає", "покидає", "полишає"],
        "вирішувати": ["розв'язувати", "долати", "залагоджувати"],
        "вирішує": ["розв'язує", "долає", "залагоджує"],
        "підтримувати": ["допомагати", "сприяти", "берегти"],
        "підтримує": ["допомагає", "сприяє", "береже"],
        "зберігати": ["тримати", "утримувати", "беречи"],
        "зберігає": ["тримає", "утримує", "береже"],
        "обирати": ["вибирати", "добирати", "відбирати"],
        "обирає": ["вибирає", "добирає", "відбирає"],
        "переконувати": ["доводити", "запевняти", "умовляти"],
        "переконує": ["доводить", "запевняє", "умовляє"],
        "зростати": ["збільшуватися", "посилюватися", "нарощуватися"],
        "зростає": ["збільшується", "посилюється", "нарощується"],
        "зменшувати": ["скорочувати", "понижувати", "звужувати"],
        "зменшує": ["скорочує", "понижує", "звужує"],
        "впливати": ["діяти", "позначатися", "відбиватися"],
        "впливає": ["діє", "позначається", "відбивається"],
        "досягати": ["здобувати", "набувати", "виборювати"],
        "досягає": ["здобуває", "набуває", "виборює"],
        "забувати": ["випускати з пам'яті", "не тямити", "нехтувати"],
        "забуває": ["випускає з пам'яті", "не тямить", "нехтує"],
        "чекати": ["очікувати", "сподіватися", "виглядати"],
        "чекає": ["очікує", "сподівається", "виглядає"],
        "відповідь": ["реакція", "репліка", "відгук"],
        "помилка": ["хиба", "огріх", "недолік"],
        "користь": ["вигода", "зиск", "перевага"],
        "праця": ["робота", "діяльність", "зусилля"],
        "порада": ["рада", "рекомендація", "підказка"],
        "перевага": ["плюс", "козир", "сильна сторона"],
        "недолік": ["вада", "хиба", "мінус"],
        "зусилля": ["старання", "намагання", "спроби"],
        "довіра": ["віра", "упевненість", "надія"],
        "загроза": ["небезпека", "ризик", "виклик"],
        "стан": ["становище", "положення", "обстановка"],
        "напрямок": ["курс", "вектор", "шлях"],
        "межа": ["кордон", "грань", "край"],
        "суть": ["зміст", "сутність", "головне"],
        "крок": ["захід", "вчинок", "рух"],
        "правило": ["принцип", "норма", "закон"],
        "приклад": ["зразок", "випадок", "ілюстрація"],
        "місце": ["точка", "позиція", "локація"],
        "швидкий": ["стрімкий", "прудкий", "хуткий"],
        "швидка": ["стрімка", "прудка", "хутка"],
        "повільний": ["неквапний", "млявий", "в'ялий"],
        "повільна": ["неквапна", "млява", "в'яла"],
        "яскравий": ["виразний", "помітний", "барвистий"],
        "яскрава": ["виразна", "помітна", "барвиста"],
        "темний": ["похмурий", "тьмяний", "непроглядний"],
        "світлий": ["ясний", "сяйний", "чистий"],
        "тихий": ["безшумний", "спокійний", "лагідний"],
        "тиха": ["безшумна", "спокійна", "лагідна"],
        "глибокий": ["ґрунтовний", "вдумливий", "детальний"],
        "глибока": ["ґрунтовна", "вдумлива", "детальна"],
        "широкий": ["обширний", "масштабний", "розлогий"],
        "широка": ["обширна", "масштабна", "розлога"],
        "вузький": ["тісний", "обмежений", "звужений"],
        "вузька": ["тісна", "обмежена", "звужена"],
        "високий": ["піднесений", "чималий", "значний"],
        "висока": ["піднесена", "чимала", "значна"],
        "низький": ["невисокий", "малий", "незначний"],
        "низька": ["невисока", "мала", "незначна"],
        "довгий": ["тривалий", "затяжний", "подовжений"],
        "довга": ["тривала", "затяжна", "подовжена"],
        "короткий": ["нетривалий", "стислий", "лаконічний"],
        "коротка": ["нетривала", "стисла", "лаконічна"],
        "чистий": ["прозорий", "незаплямований", "бездоганний"],
        "чиста": ["прозора", "незаплямована", "бездоганна"],
        "спокійний": ["врівноважений", "тихий", "незворушний"],
        "спокійна": ["врівноважена", "тиха", "незворушна"],
    },

    # Альтернативні початки речень
    "sentence_starters": {
        "Це": ["Такий підхід", "Подібне", "Воно", "Все це"],
        "Він": ["Той", "Ця людина", "Фахівець"],
        "Вона": ["Та", "Ця", "Остання"],
        "Вони": ["Ті", "Усі вони", "Ці люди"],
        "Ми": ["Наша команда", "Усі ми", "Команда"],
        "В": ["При", "На", "Серед"],
        "На": ["При", "В", "Для"],
        "Для": ["Заради", "Задля", "Щоб"],
        "При": ["У разі", "Коли", "Якщо"],
        "Також": ["Ще", "На додаток", "Плюс до цього"],
        # === v0.11.0 massive expansion ===
        "Цей": ["Такий", "Подібний", "Той"],
        "Ця": ["Така", "Подібна", "Та"],
        "Ці": ["Такі", "Подібні", "Ті"],
        "Той": ["Цей", "Такий", "Зазначений"],
        "Та": ["Ця", "Така", "Зазначена"],
        "Ті": ["Ці", "Такі", "Зазначені"],
        "Кожен": ["Будь-який", "Всякий", "Кожний окремий"],
        "Кожна": ["Будь-яка", "Всяка", "Кожна окрема"],
        "Усі": ["Кожен", "Будь-який", "Всі без винятку"],
        "Після": ["Вслід за", "По закінченні", "Коли"],
        "Перед": ["До", "Перш ніж", "Напередодні"],
        "Коли": ["Як тільки", "У той момент коли", "Щойно"],
        "Якщо": ["У разі", "Коли", "За умови"],
        "Хоча": ["Незважаючи на те що", "Хай", "Навіть при тому що"],
        "Але": ["Однак", "Втім", "Зате"],
        "І": ["Та й", "Плюс", "На додаток"],
        "Тому": ["Відтак", "Ось чому", "Через це"],
        "Спочатку": ["Для початку", "Передусім", "Першим ділом"],
        "Потім": ["Далі", "Після цього", "Згодом"],
        "Далі": ["Потім", "Згодом", "Слідом"],
        "Втім": ["Хоча", "Щоправда", "Але"],
        "Звісно": ["Зрозуміло", "Ясна річ", "Безумовно"],
        "Очевидно": ["Ясно", "Зрозуміло", "Видно"],
        "Можливо": ["Мабуть", "Імовірно", "Вірогідно"],
        "Сьогодні": ["Наразі", "У наші дні", "Нині"],
        "Тут": ["Ось тут", "У цьому місці", "Саме тут"],
        # === v0.12.0 expansion ===
        "Зрозуміло": ["Ясна річ", "Звісно", "Безперечно"],
        "Мабуть": ["Напевно", "Либонь", "Видно"],
        "Зазвичай": ["Як правило", "Найчастіше", "Здебільшого"],
        "Безперечно": ["Без сумніву", "Поза сумнівом", "Однозначно"],
        "Зважмо": ["Врахуймо", "Зверніть увагу", "Подивимось"],
        "Приміром": ["Наприклад", "Скажімо", "Хоча б"],
        "Насправді": ["По правді кажучи", "Якщо чесно", "Насправжки"],
        "Інакше": ["А то", "Бо інакше", "У протилежному разі"],
        "Крім": ["Окрім", "За винятком", "Не рахуючи"],
        "Завдяки": ["Через", "За допомогою", "Саме через"],
        # --- v0.27.0 expansion ---
        "Безсумнівно": ["Безперечно", "Без двох думок", "Однозначно"],
        "Зрештою": ["Наприкінці", "Наостанок", "Врешті"],
        "Натомість": ["Зате", "Замість того", "А от"],
        "Попри": ["Незважаючи на", "Всупереч", "Хоча"],
        "Нерідко": ["Часто", "Не раз", "Буває"],
        "Подеколи": ["Іноді", "Час від часу", "Буває"],
        "Загальновідомо": ["Усім відомо", "Ні для кого не секрет", "Як відомо"],
        "Однозначно": ["Безперечно", "Точно", "Без сумніву"],
        "Показово": ["Характерно", "Промовисто", "Красномовно"],
        "Принагідно": ["До речі", "Між іншим", "До слова"],
        "Власне": ["По суті", "Якщо точніше", "Справді"],
        "Вочевидь": ["Схоже", "Мабуть", "Напевно"],
        "Нещодавно": ["Останнім часом", "Днями", "Не так давно"],
        "Раніше": ["Колись", "Перед тим", "До того"],
        "Зрозуміло": ["Ясна річ", "Звісно", "Безперечно"],
        "Упродовж": ["Протягом", "У ході", "Під час"],
        "Невдовзі": ["Скоро", "Незабаром", "От-от"],
        "Водночас": ["Одночасно", "Паралельно", "Поряд з цим"],
        "Насамперед": ["Передусім", "Перш за все", "Головне"],
        "Загалом": ["У цілому", "Якщо коротко", "Взагалі"],
        "Типово": ["Зазвичай", "Як правило", "Здебільшого"],
    },

    # Розмовні маркери для chat/web профілів
    "colloquial_markers": [
        "до речі",
        "до слова",
        "насправді",
        "по суті",
        "загалом",
        "між іншим",
        "власне",
        "простіше кажучи",
        "грубо кажучи",
        "якщо коротко",
        # === v0.11.0 massive expansion ===
        "без перебільшень",
        "будьмо чесні",
        "взагалі",
        "взагалі-то",
        "ось у чому річ",
        "головне тут",
        "іншими словами",
        "якщо говорити прямо",
        "якщо подумати",
        "якщо розібратися",
        "є така думка",
        "зауважу",
        "знаєте що",
        "і ось що цікаво",
        "якщо чесно",
        "цікаво",
        "наприклад",
        "коротше кажучи",
        "любопитно",
        "між нами",
        "можна сказати",
        "на ділі",
        "на мій погляд",
        "треба сказати",
        "треба визнати",
        "не буду приховувати",
        "не секрет",
        "ну от",
        "ну і",
        "однозначно",
        "виявляється",
        "відверто кажучи",
        "по-моєму",
        "по правді кажучи",
        "по факту",
        "поклавши руку на серце",
        "прямо скажу",
        "скажімо так",
        "скажу чесно",
        "слухайте",
        "дивіться",
        "власне кажучи",
        "варто зауважити",
        "суть у тому",
        "так чи інакше",
        "тут важливо зрозуміти",
        "факт у тому",
        "чесно кажучи",
        "що важливо",
        "що цікаво",
        "що характерно",
        # === v0.12.0 expansion ===
        "знаєте",
        "розумієте",
        "бачте",
        "от саме",
        "ну як сказати",
        "от і виходить",
        "от я і кажу",
        "можете уявити",
        "скажу вам",
        "повірте",
        "самі подумайте",
        "от вам і відповідь",
        "не повірите",
        "а що поробиш",
        "та годі вже",
        "ну ви зрозуміли",
        "та й годі",
        "хто б міг подумати",
        "а от і ні",
        "от у чому фішка",
        "якщо по-простому",
        "як кажуть",
        "по-людськи кажучи",
        "чесне слово",
        "от так от",
        # --- v0.27.0 expansion ---
        "якщо вдуматися",
        "для ясності",
        "одним словом",
        "як на мене",
        "як бачимо",
        "не приховую",
        "ну що тут скажеш",
        "давайте будемо чесні",
        "якщо без жартів",
        "от де штука",
        "як би це сказати",
        "я б сказав",
        "при всьому цьому",
        "щиро скажу",
    ],

    # Абревіатури
    "abbreviations": [
        "р", "рр", "т.д", "т.п", "т.ч", "і т.д", "і т.п", "ін",
        "пр", "напр", "ред", "рис", "табл", "стор", "див",
        "обл", "грн", "тис", "млн", "млрд",
        "кв", "км", "м", "мм", "см", "кг", "мг", "л", "мл",
        "с", "хв", "год", "ім", "акад", "проф", "доц",
        # === v0.11.0 massive expansion ===
        "м-н", "м-р", "вул", "пл", "просп", "б-р", "пров",
        "п-к", "мікрор-н", "корп", "буд",
        "докт", "канд", "інж", "арх", "асп",
        "ст", "мол", "старш", "молодш",
        "п.", "пн", "вт", "ср", "чт", "пт", "сб", "нд",
        "січ", "лют", "бер", "квіт", "трав", "черв",
        "лип", "серп", "вер", "жовт", "листоп", "груд",
        "міст", "с-ще", "розд", "відд", "упр",
        "дир", "заст", "нач", "гол", "голова",
        "секр", "бухг", "екон", "юрист",
        "коп", "га", "цтн", "тонн",
        "цейнт", "кал", "темп",
        "макс", "мін", "середн", "прибл",
        "оф", "неоф", "держ", "прив",
        "орг", "техн", "мед", "пед",
        "філос", "політ", "№",
    ],

    # Бустери перплексії (рідкісні/незвичайні фрази для підвищення перплексії)
    "perplexity_boosters": [
        "як не крути", "так чи інакше", "хоч як би там було",
        "nolens volens", "de facto", "ipso facto",
        "парадоксально", "цікаво", "іронічно",
        "загалом і вцілому", "по великому рахунку",
        "поклавши руку на серце", "чого вже там",
        "будьмо чесними", "треба визнати", "гріх нарікати",
        "не без підстав", "до слова кажучи",
        "у певному сенсі", "до певної міри",
        "об'єктивно кажучи", "всупереч очікуванням",
        "як не дивно", "при всьому при тому",        # === v0.11.0 massive expansion ===
        "а відтак", "без зайвих слів",
        "будь що буде", "в певному сенсі",
        "в кінці-кінців", "вірите ви чи ні",
        "ось де собака зарита", "ось що я вам скажу",
        "говорячи начистоту", "грубо прикидаючи",
        "якщо розібратися по-хорошому",
        "і ось тут-то", "і ось що примітно",
        "до вашого відому", "як бачите",
        "як водиться", "як мінімум",
        "як на зло", "як показала практика",
        "між нами кажучи", "м'яко висловлюючись",
        "на повірку", "треба гадати",
        "не в образу буде сказано", "не мудруючи лукаво",
        "нічого дивного", "по здоровому роздуму",
        "по совісті кажучи", "правди ради",
        "при ближчому розгляді", "при всьому бажанні",
        "ради справедливості", "ризикну припустити",
        "сказати по честі", "слід визнати",
        "строго між нами", "хочеш не хочеш",
        "це до слова",
        # === v0.12.0 expansion ===
        "а втім, судіть самі", "без перебору",
        "вірте на слово", "гадаю не помилюсь",
        "дивна річ", "до певної міри правда",
        "є підстави вважати", "з власного досвіду скажу",
        "за великим рахунком", "за збігом обставин",
        "за здоровим глуздом", "зовсім не жарт",
        "і це ще не все", "коли добре подумати",
        "кожному своє", "між двох вогнів",
        "на превеликий жаль", "не від доброго життя",
        "не те слово", "ніхто не заперечить",
        "палка в двох кінцях", "при всій повазі",
        "самі розумієте", "скажу без обиняків",
        "схоже на правду", "хоч як не крути",
        "щиро кажучи", "як мовиться",
        "як то кажуть", "от де правда",
        # --- v0.27.0 expansion ---
        "що тут казати", "от де штука",
        "даруйте за прямоту", "не для протоколу",
        "чисто теоретично", "якщо без лукавства",
        "між іншим кажучи", "ну що ж",
        "вірите чи ні", "не жартую",
        "у буквальному сенсі", "без жодного перебільшення",
        "щось мені підказує", "на честь сказати",
        "тут уже нікуди дітися", "от вам і весь казус",
        "як то мовиться", "хоч вір хоч не вір",
        "без обиняків кажучи", "якщо вдуматися",
        "не побоюсь цього слова", "при всьому при цьому",
        "із цікавості зазначу", "ось у чому сіль",
        "отож-бо й воно", "як не верти",
        "не буду мудрувати", "якщо брати ширше",
        "прямо скажемо", "тут уже без варіантів",
        "от тобі й маєш", "хай там як",
        "нема чого лукавити", "до слова сказати",
        "оце так штука", "ну як тут бути",
        "якщо покласти руку на серце", "от тобі на",
    ],

    # Цільові метрики за профілями
    "profile_targets": {
        "chat": {"avg_sentence_len": (8, 18), "max_sentence_len": 30},
        "web": {"avg_sentence_len": (10, 22), "max_sentence_len": 40},
        "seo": {"avg_sentence_len": (12, 25), "max_sentence_len": 45},
        "docs": {"avg_sentence_len": (12, 28), "max_sentence_len": 50},
        "formal": {"avg_sentence_len": (15, 30), "max_sentence_len": 55},
    },

    # Сполучники для склеювання коротких речень
    "conjunctions": ["і", "а", "але", "та", "або", "причому", "хоча"],

    # Сполучники для розбиття довгих речень
    "split_conjunctions": [
        ", і ", ", а ", ", але ", ", однак ", ", хоча ",
        ", причому ", ", при цьому ", ", тому ",
        ", що ", "; ", " — ",
        # === v0.11.0 massive expansion ===
        ", тому що ", ", оскільки ", ", адже ",
        ", якщо ", ", коли ", ", поки ",
        ", хоча би ", ", незважаючи на ", ", замість ",
        ", після чого ", ", в результаті чого ",
        ", тоді як ", ", адже ", ", бо ",
        ", тобто ", ", а саме ", ", інакше ",
        ", отже ", ", значить ", ", виходить ",
        " – ",
    ],
}
