"""Языковой пакет: Итальянский (Italiano)."""

LANG_IT = {
    "code": "it",
    "name": "Italiano",

    "trigrams": [
        "che", "ell", "ion", "ent", "ato", "per", "ment", "azi",
        "con", "one", "zione", "sta", "ere", "non", "ess", "pre",
        "att", "ale", "nte", "ria", "ica", "ura", "ire", "gli",
        "pro", "tra", "ter", "tto", "res", "ost", "ono", "uto",
        "ita", "eri", "ova", "ali", "dei", "ati", "ori", "com",
    ],

    "stop_words": {
        "il", "lo", "la", "i", "gli", "le", "un", "uno", "una",
        "e", "o", "ma", "né", "che", "se", "non", "in",
        "di", "del", "della", "dei", "delle", "al", "alla",
        "con", "per", "da", "su", "tra", "fra",
        "io", "tu", "lui", "lei", "noi", "voi", "loro",
        "è", "sono", "ha", "hanno", "era", "essere", "avere",
        "questo", "questa", "questi", "queste", "quello", "quella",
        "mio", "mia", "tuo", "tua", "suo", "sua", "nostro",
        "più", "meno", "molto", "bene", "come", "dove",
        "tutto", "tutti", "tutta", "tutte", "altro", "altra",
        "già", "ancora", "anche", "solo", "ogni",
        "qui", "là", "quando", "mentre",
        "ci", "si", "mi", "ti", "vi", "ne",
    },

    "bureaucratic": {
        "implementare": ["mettere in atto", "realizzare", "applicare"],
        "ottimizzare": ["migliorare", "perfezionare", "affinare"],
        "finalizzare": ["concludere", "finire", "completare"],
        "concretizzare": ["realizzare", "mettere in pratica"],
        "generare": ["creare", "produrre", "dare"],
        "determinare": ["stabilire", "decidere", "fissare"],
        "significativo": ["notevole", "importante", "rilevante"],
        "fondamentale": ["essenziale", "basilare", "centrale"],
        "primario": ["principale", "primo", "essenziale"],
        "inerente": ["proprio", "legato", "connesso"],
        "esaustivo": ["completo", "dettagliato", "approfondito"],
        "innovativo": ["nuovo", "creativo", "originale"],
        "paradigmatico": ["esemplare", "tipico", "modello"],
        "preponderante": ["principale", "dominante", "maggiore"],
        "onnicomprensivo": ["completo", "totale", "globale"],
        "imprescindibile": ["necessario", "essenziale", "irrinunciabile"],
        "sistematico": ["regolare", "ordinato", "metodico"],
        "paradigma": ["modello", "schema", "quadro"],
        "olistico": ["globale", "complessivo", "d'insieme"],
        "catalizzare": ["stimolare", "accelerare", "innescare"],
        "corroborare": ["confermare", "avvalorare", "sostenere"],
        "concomitante": ["simultaneo", "parallelo", "congiunto"],
        "perenne": ["duraturo", "stabile", "continuo"],
        "trasversale": ["comune", "condiviso", "generale"],
        # === v0.10.0 ===
        "contestualizzare": ["situare", "inquadrare", "collocare"],
        "operativizzare": ["applicare", "mettere in opera", "eseguire"],
        "problematizzare": ["mettere in discussione", "questionare"],
        "dinamizzare": ["attivare", "rilanciare", "stimolare"],
        "razionalizzare": ["semplificare", "snellire", "riorganizzare"],
        "strutturare": ["organizzare", "ordinare", "impostare"],
        "veicolare": ["trasmettere", "diffondere", "portare"],
        "valorizzare": ["dare valore", "promuovere", "esaltare"],
        "esplicitare": ["chiarire", "precisare", "spiegare"],
        "formalizzare": ["ufficializzare", "codificare", "definire"],
        "dispiegare": ["schierare", "estendere", "distribuire"],
        "mobilitare": ["coinvolgere", "impegnare", "radunare"],
        "identificare": ["individuare", "riconoscere", "trovare"],
        "sintetizzare": ["riassumere", "condensare", "raccogliere"],
        "proattivo": ["anticipato", "previdente", "dinamico"],
        "multidisciplinare": ["vario", "diverso", "misto"],
        "ricorrente": ["frequente", "ripetuto", "abituale"],
        "tangibile": ["concreto", "reale", "palpabile"],
        "intrinseco": ["interno", "proprio", "naturale"],
        "preminente": ["superiore", "primo", "dominante"],
        "pertinente": ["adeguato", "appropriato", "rilevante"],
        "performante": ["efficace", "potente", "produttivo"],
        "strutturante": ["organizzativo", "fondativo", "chiave"],
        "impattante": ["incisivo", "forte", "significativo"],
        # === v0.11.0 massive expansion ===
        "delineare": ["tracciare", "descrivere", "definire"],
        "predisporre": ["preparare", "approntare", "organizzare"],
        "configurare": ["impostare", "organizzare", "disporre"],
        "articolare": ["suddividere", "organizzare", "comporre"],
        "elaborare": ["sviluppare", "produrre", "creare"],
        "formulare": ["esprimere", "proporre", "creare"],
        "perseguire": ["cercare", "inseguire", "mirare a"],
        "promuovere": ["sostenere", "incoraggiare", "lanciare"],
        "approfondire": ["esaminare", "studiare", "indagare"],
        "consolidare": ["rafforzare", "solidificare", "stabilizzare"],
        "evidenziare": ["mostrare", "sottolineare", "mettere in luce"],
        "specificare": ["precisare", "indicare", "definire"],
        "verificare": ["controllare", "accertare", "appurare"],
        "monitorare": ["controllare", "sorvegliare", "seguire"],
        "supervisionare": ["sorvegliare", "controllare", "dirigere"],
        "coordinare": ["organizzare", "gestire", "dirigere"],
        "pianificare": ["programmare", "progettare", "organizzare"],
        "progettare": ["pianificare", "ideare", "pensare"],
        "garantire": ["assicurare", "promettere", "dare certezza"],
        "facilitare": ["agevolare", "rendere facile", "aiutare"],
        "standardizzare": ["uniformare", "omologare", "regolarizzare"],
        "centralizzare": ["concentrare", "accentrare", "riunire"],
        "delegare": ["affidare", "demandare", "incaricare"],
        "integrare": ["unire", "incorporare", "completare"],
        "armonizzare": ["accordare", "bilanciare", "equilibrare"],
        "canalizzare": ["indirizzare", "convogliare", "dirigere"],
        "massimizzare": ["aumentare al massimo", "potenziare", "amplificare"],
        "minimizzare": ["ridurre", "limitare", "contenere"],
        "incentivare": ["stimolare", "incoraggiare", "spronare"],
        "sensibilizzare": ["rendere consapevole", "informare", "educare"],
        "finalizzato": ["mirato", "volto", "destinato"],
        "sussidiario": ["complementare", "secondario", "aggiuntivo"],
        "propedeutico": ["preparatorio", "introduttivo", "preliminare"],
        "consequenziale": ["logico", "coerente", "derivato"],
        "precipuo": ["proprio", "tipico", "specifico"],
        "afferente": ["relativo", "riguardante", "attinente"],
        "sovrintendere": ["dirigere", "sorvegliare", "controllare"],
        "demandare": ["affidare", "delegare", "trasferire"],
        "espletare": ["compiere", "eseguire", "svolgere"],
        "ottemperare": ["rispettare", "obbedire", "conformarsi"],
        "adempiere": ["compiere", "eseguire", "rispettare"],
        "coadiuvare": ["aiutare", "assistere", "collaborare"],
        "presiedere": ["dirigere", "guidare", "sovrintendere"],
        "dirimere": ["risolvere", "chiarire", "decidere"],
        "avallare": ["approvare", "confermare", "sostenere"],
        "stigmatizzare": ["criticare", "condannare", "biasimare"],
        "perorare": ["sostenere", "difendere", "invocare"],
        "annoverare": ["includere", "contare", "comprendere"],
        "compendioso": ["breve", "conciso", "sintetico"],
        "circostanziato": ["dettagliato", "preciso", "minuzioso"],
        "sostanziale": ["grande", "notevole", "consistente"],
        "preposto": ["incaricato", "addetto", "responsabile"],
        "contingente": ["temporaneo", "passeggero", "attuale"],
        "perentorio": ["deciso", "categorico", "definitivo"],
        "tassativo": ["obbligatorio", "rigido", "vincolante"],
        "proporzionale": ["adeguato", "commisurato", "equilibrato"],
        "preliminare": ["iniziale", "preparatorio", "preventivo"],
        "univoco": ["chiaro", "netto", "preciso"],
        "dirimente": ["decisivo", "risolutivo", "cruciale"],
        "impellente": ["urgente", "pressante", "incalzante"],
        "cogente": ["vincolante", "obbligatorio", "imperativo"],
        "pregresso": ["precedente", "passato", "anteriore"],
        "prodromico": ["iniziale", "preparatorio", "introduttivo"],
        "recepire": ["accogliere", "adottare", "fare proprio"],
        "disincentivare": ["scoraggiare", "frenare", "ostacolare"],
        "estrinsecare": ["manifestare", "esprimere", "mostrare"],
        "asserire": ["affermare", "dichiarare", "sostenere"],
        "postulare": ["presupporre", "assumere", "richiedere"],
        "enunciare": ["esporre", "dichiarare", "annunciare"],
        "denotare": ["indicare", "mostrare", "rivelare"],
        "sottendere": ["implicare", "presupporre", "comportare"],
        "contemplare": ["prevedere", "considerare", "includere"],
        "sussistere": ["esistere", "esserci", "permanere"],
        "ottemperanza": ["rispetto", "osservanza", "conformità"],
        "fattispecie": ["caso", "circostanza", "situazione"],
        "controparte": ["interlocutore", "corrispondente", "altra parte"],
        "prerogativa": ["diritto", "privilegio", "facoltà"],
        "peculiarità": ["caratteristica", "particolarità", "tratto"],
        "evenienza": ["possibilità", "caso", "circostanza"],
        "criticità": ["problema", "difficoltà", "punto debole"],
        "tempistica": ["tempi", "calendario", "scadenze"],
        "problematica": ["problema", "questione", "difficoltà"],
        "tematica": ["tema", "argomento", "questione"],
        "metodologia": ["metodo", "approccio", "tecnica"],
        "normativa": ["legge", "regola", "disciplina"],
        "potenzialità": ["possibilità", "capacità", "risorsa"],
        "operatività": ["funzionamento", "attività", "lavoro"],
        "fruibilità": ["accessibilità", "disponibilità", "utilizzo"],
        "sostenibilità": ["durabilità", "stabilità", "tenuta"],
        "interoperabilità": ["compatibilità", "integrazione", "connessione"],
        "scalabilità": ["adattabilità", "flessibilità", "espandibilità"],
        "capillarità": ["diffusione", "presenza", "copertura"],
        "incrementare": ["aumentare", "accrescere", "far crescere"],
        "decrementare": ["diminuire", "ridurre", "calare"],
        "esternalizzare": ["affidare fuori", "appaltare", "delegare"],
        "internalizzare": ["gestire internamente", "assumere", "incorporare"],
        "parametrizzare": ["definire i parametri", "misurare", "classificare"],
        "efficientare": ["rendere efficiente", "migliorare", "snellire"],
        "rendicontare": ["riferire", "documentare", "registrare"],
        "protocollare": ["registrare", "catalogare", "archiviare"],
        "normare": ["regolare", "disciplinare", "regolamentare"],
        "disfunzionale": ["inadeguato", "inefficace", "malfunzionante"],
        "propositivo": ["costruttivo", "attivo", "positivo"],
        "pervasivo": ["diffuso", "capillare", "esteso"],
        "iterativo": ["ripetuto", "ciclico", "ricorrente"],
        "funzionale": ["pratico", "utile", "efficace"],
        "strategico": ["chiave", "cruciale", "tattico"],
        "organico": ["completo", "strutturato", "coerente"],
        # === v0.12.0 expansion ===
        "abrogare": ["annullare", "abolire", "sopprimere"],
        "accreditare": ["certificare", "validare", "autorizzare"],
        "afferire": ["riguardare", "riferirsi", "essere attinente"],
        "agevolazione": ["facilitazione", "vantaggio", "beneficio"],
        "allocare": ["assegnare", "distribuire", "destinare"],
        "appurare": ["verificare", "accertare", "chiarire"],
        "attenuare": ["ridurre", "mitigare", "smorzare"],
        "capitalizzare": ["sfruttare", "valorizzare", "mettere a frutto"],
        "circostanziare": ["dettagliare", "precisare", "specificare"],
        "collimare": ["coincidere", "corrispondere", "concordare"],
        "comminare": ["infliggere", "imporre", "assegnare"],
        "compenetrare": ["fondere", "integrare", "unire"],
        "compulsare": ["consultare", "esaminare", "controllare"],
        "concepire": ["ideare", "inventare", "pensare"],
        "condizionare": ["influenzare", "determinare", "limitare"],
        "confutare": ["smentire", "contestare", "negare"],
        "corredare": ["accompagnare", "fornire", "completare"],
        "declinare": ["rifiutare", "respingere", "scartare"],
        "deferire": ["trasmettere", "affidare", "rimettere"],
        "derogare": ["deviare", "cambiare", "modificare"],
        "disapplicare": ["non applicare", "escludere", "omettere"],
        "disattendere": ["ignorare", "trascurare", "non rispettare"],
        "eccepire": ["obiettare", "contestare", "opporsi"],
        "eludere": ["evitare", "aggirare", "sfuggire"],
        "emendare": ["correggere", "modificare", "rettificare"],
        "equiparare": ["parificare", "uguagliare", "pareggiare"],
        "erogare": ["fornire", "distribuire", "concedere"],
        "esperire": ["tentare", "provare", "avviare"],
        "estrinsecabile": ["manifestabile", "esprimibile", "visibile"],
        "fattuale": ["concreto", "reale", "effettivo"],
        "fisiologico": ["naturale", "normale", "atteso"],
        "giuridico": ["legale", "di legge", "normativo"],
        "incardinare": ["inserire", "collocare", "integrare"],
        "interdire": ["vietare", "proibire", "impedire"],
        "interpellare": ["interrogare", "chiedere", "consultare"],
        "invalidare": ["annullare", "rendere nullo", "cancellare"],
        "irrogare": ["comminare", "infliggere", "imporre"],
        "legittimare": ["giustificare", "autorizzare", "validare"],
        "lesionare": ["danneggiare", "ferire", "compromettere"],
        "liquidare": ["pagare", "saldare", "estinguere"],
        "notificare": ["comunicare", "avvisare", "informare"],
        "obliterare": ["cancellare", "eliminare", "annullare"],
        "oneroso": ["costoso", "gravoso", "pesante"],
        "ostacolare": ["impedire", "frenare", "bloccare"],
        "palese": ["evidente", "chiaro", "manifesto"],
        "patrocinare": ["sponsorizzare", "sostenere", "promuovere"],
        "permeare": ["pervadere", "impegnare", "diffondere"],
        "perpetrare": ["compiere", "commettere", "realizzare"],
        "prefigurare": ["prevedere", "anticipare", "immaginare"],
        "prescrivere": ["ordinare", "imporre", "stabilire"],
        "principiare": ["iniziare", "cominciare", "avviare"],
        "profilare": ["delineare", "tracciare", "definire"],
        "promulgare": ["emanare", "pubblicare", "proclamare"],
        "ratificare": ["confermare", "approvare", "validare"],
        "rettificare": ["correggere", "modificare", "emendare"],
        "rimodulare": ["modificare", "adattare", "rivedere"],
        "sanare": ["risolvere", "correggere", "rimediare"],
        "scrutinare": ["esaminare", "analizzare", "vagliare"],
        "segnatamente": ["in particolare", "specialmente", "soprattutto"],
        "sondare": ["esplorare", "indagare", "tastare"],
        "soprassedere": ["rinviare", "sospendere", "rimandare"],
        "sopperire": ["supplire", "compensare", "rimediare"],
        "statuire": ["stabilire", "decretare", "decidere"],
        "stipulare": ["firmare", "concludere", "siglare"],
        "surrogare": ["sostituire", "rimpiazzare", "supplire"],
        "tutelare": ["proteggere", "difendere", "salvaguardare"],
        "valicare": ["superare", "oltrepassare", "scavalcare"],
        "vagliare": ["esaminare", "valutare", "analizzare"],
        "vincolante": ["obbligatorio", "imperativo", "cogente"],
        "antergico": ["sinergico", "collaborativo", "coordinato"],
        "capillare": ["diffuso", "esteso", "ramificato"],
        "contestuale": ["simultaneo", "concomitante", "parallelo"],
        "discrezionale": ["facoltativo", "a scelta", "libero"],
        "esaustivamente": ["completamente", "pienamente", "interamente"],
        "inderogabile": ["obbligatorio", "imprescindibile", "irrinunciabile"],
    },

    "bureaucratic_phrases": {
        "è doveroso sottolineare": ["va detto", "bisogna dire"],
        "nell'ambito di": ["in", "dentro", "durante"],
        "al fine di": ["per", "allo scopo di"],
        "in relazione a": ["riguardo a", "su", "per"],
        "in considerazione di": ["dato", "visto", "considerando"],
        "in maniera significativa": ["molto", "parecchio", "nettamente"],
        "riveste un ruolo cruciale": ["è molto importante", "conta molto"],
        "assume un'importanza": ["è importante", "conta"],
        "risulta necessario": ["bisogna", "serve", "occorre"],
        "per quanto concerne": ["per quanto riguarda", "riguardo a"],
        # === v0.10.0 ===
        "appare evidente che": ["si vede che", "è chiaro che"],
        "alla luce di": ["dato", "visto", "considerando"],
        "ai fini di": ["per", "allo scopo di"],
        "in primo luogo": ["prima di tutto", "anzitutto"],
        "in ultima analisi": ["alla fine", "insomma"],
        "a titolo esemplificativo": ["per esempio", "ad esempio"],
        "tenuto conto di": ["dato", "considerando", "visto che"],
        "con riferimento a": ["riguardo a", "in merito a", "su"],
        "a prescindere da": ["a parte", "senza contare", "indipendentemente"],
        "in virtù di": ["grazie a", "per", "in forza di"],
        "ai sensi di": ["secondo", "in base a", "conformemente a"],
        "nella fattispecie": ["in questo caso", "qui"],
        "in ottemperanza a": ["secondo", "conformemente a", "rispettando"],
        "a fronte di": ["davanti a", "rispetto a", "considerando"],
        "per converso": ["al contrario", "d'altra parte", "invece"],
        "fatto salvo": ["eccetto", "tranne", "a meno che"],
        # === v0.11.0 massive expansion ===
        "è opportuno precisare che": ["va detto che", "bisogna dire che"],
        "si rende necessario": ["bisogna", "occorre", "serve"],
        "con l'intento di": ["per", "allo scopo di", "al fine di"],
        "in ragione di": ["a causa di", "per via di", "per"],
        "a seguito di": ["dopo", "in seguito a", "per"],
        "in merito a": ["riguardo a", "su", "circa"],
        "dal punto di vista di": ["per", "secondo", "rispetto a"],
        "nel contesto di": ["in", "durante", "entro"],
        "a livello di": ["per quanto riguarda", "riguardo a", "in termini di"],
        "è d'uopo": ["è necessario", "bisogna", "serve"],
        "si rende opportuno": ["è bene", "conviene", "è meglio"],
        "in seno a": ["all'interno di", "in", "dentro"],
        "a monte di": ["prima di", "alla base di"],
        "a valle di": ["dopo", "in seguito a", "come risultato di"],
        "preme sottolineare": ["va detto", "è importante dire"],
        "giova ricordare che": ["va ricordato che", "è bene ricordare"],
        "non si può prescindere da": ["è necessario", "bisogna considerare"],
        "si fa presente che": ["si comunica che", "si avvisa che"],
        "con precipuo riferimento a": ["con riguardo a", "riguardo a", "su"],
        "in linea con": ["secondo", "in accordo con", "seguendo"],
        # === v0.12.0 expansion ===
        "ai fini del presente": ["per questo", "allo scopo di"],
        "a tal uopo": ["a tal fine", "per questo", "a questo scopo"],
        "con specifico riguardo a": ["riguardo a", "parlando di"],
        "dar luogo a": ["causare", "provocare", "creare"],
        "in conformità a": ["secondo", "come stabilito da", "conforme a"],
        "in deroga a": ["in eccezione a", "contrariamente a"],
        "in forza di": ["grazie a", "per", "in base a"],
        "in ossequio a": ["secondo", "rispettando", "conformemente a"],
        "in punto di": ["riguardo a", "quanto a", "per ciò che concerne"],
        "mettere in campo": ["usare", "impiegare", "attivare"],
        "nella misura in cui": ["se", "in quanto", "dato che"],
        "non da ultimo": ["inoltre", "anche", "per giunta"],
        "porre in essere": ["realizzare", "attuare", "fare"],
        "prendere atto di": ["riconoscere", "notare", "registrare"],
        "procedere alla": ["fare la", "eseguire la", "avviare la"],
        "salvo quanto previsto": ["tranne dove indicato", "eccetto"],
        "sulla scorta di": ["in base a", "sulla base di", "partendo da"],
        "tenere presente che": ["ricordare che", "considerare che"],
        "ciò premesso": ["detto questo", "fatto sta che"],
        "fatti salvi": ["eccetto", "tranne", "escludendo"],
        "onde evitare": ["per evitare", "al fine di non"],
        "per le finalità di cui": ["per gli scopi di", "per quanto riguarda"],
        "previo accordo": ["dopo aver concordato", "previa intesa"],
        "ad ogni buon conto": ["in ogni caso", "comunque"],
        "si precisa che": ["va detto che", "precisiamo che"],
    },

    "ai_connectors": {
        "Inoltre": ["In più", "Anche", "Per di più", "Poi"],
        "Tuttavia": ["Ma", "Però", "Eppure", "Ciononostante"],
        "Di conseguenza": ["Quindi", "Perciò", "Così", "Dunque"],
        "Ciononostante": ["Ma", "Tuttavia", "Eppure"],
        "Per di più": ["In più", "Inoltre", "Anche"],
        "In definitiva": ["Alla fine", "In conclusione", "Insomma"],
        "A tal proposito": ["A questo punto", "In merito"],
        "È importante sottolineare": ["Va detto", "Bisogna dire"],
        "Vale la pena notare": ["Da notare", "Interessante è"],
        "In conclusione": ["Per concludere", "Alla fine"],
        "Pertanto": ["Quindi", "Perciò", "Dunque"],
        "Altresì": ["Anche", "Inoltre", "Pure"],
        # === v0.10.0 ===
        "Ciò premesso": ["Detto questo", "In ogni caso"],
        "In ogni caso": ["Comunque", "Ad ogni modo"],
        "Parallelamente": ["Allo stesso tempo", "Inoltre"],
        "A maggior ragione": ["Tanto più", "Ancora di più"],
        "Analogamente": ["In modo simile", "Allo stesso modo"],
        "Effettivamente": ["In effetti", "Sì", "È vero"],
        "Indubbiamente": ["Senza dubbio", "Certamente"],
        "Nella fattispecie": ["In questo caso", "Qui"],
        # === v0.11.0 massive expansion ===
        "In aggiunta": ["In più", "Anche", "Poi"],
        "Nondimeno": ["Tuttavia", "Ma", "Eppure"],
        "In sostanza": ["In pratica", "Fondamentalmente", "In breve"],
        "Per quanto riguarda": ["Riguardo a", "In merito a", "Su"],
        "D'altro canto": ["D'altra parte", "Ma", "Tuttavia"],
        "Senza dubbio": ["Certamente", "Sicuramente", "Di certo"],
        "A questo proposito": ["In merito", "Su questo punto", "Riguardo a ciò"],
        "In secondo luogo": ["Poi", "Anche", "Inoltre"],
        "Conseguentemente": ["Di conseguenza", "Quindi", "Perciò"],
        "Contestualmente": ["Allo stesso tempo", "Nello stesso momento", "Intanto"],
        "In primo luogo": ["Prima di tutto", "Anzitutto", "Per cominciare"],
        "In terzo luogo": ["Infine", "Poi", "Ancora"],
        "Da un lato": ["Per certi aspetti", "In parte"],
        "Dall'altro lato": ["D'altra parte", "Però", "Ma"],
        "È altresì rilevante": ["Va anche detto", "Anche"],
        "In ultima istanza": ["Alla fine", "In definitiva", "Insomma"],
        "Più specificamente": ["Nello specifico", "In dettaglio", "Precisamente"],
        "In particolare": ["Nello specifico", "Specialmente", "Soprattutto"],
        # === v0.12.0 expansion ===
        "Detto ciò": ["Però", "Tuttavia", "Comunque"],
        "Ciò nonostante": ["Eppure", "Tuttavia", "Ma"],
        "Per inciso": ["Tra parentesi", "A proposito", "Di sfuggita"],
        "A ben guardare": ["Se si osserva", "Guardando meglio", "In realtà"],
        "A onor del vero": ["Per la verità", "In tutta franchezza"],
        "A tal riguardo": ["In merito", "Su questo", "Riguardo a ciò"],
        "A titolo di esempio": ["Per esempio", "Ad esempio"],
        "Come si può notare": ["Come si vede", "Si nota che"],
        "Da notare che": ["Va notato che", "Si noti che"],
        "Di fatto": ["In pratica", "Concretamente", "Nella realtà"],
        "Ebbene": ["Allora", "Dunque", "Orbene"],
        "In altri termini": ["In altre parole", "Cioè", "Ossia"],
        "In breve": ["In poche parole", "Riassumendo", "Per farla breve"],
        "In buona sostanza": ["In pratica", "Di fatto", "Sostanzialmente"],
        "In effetti": ["Di fatto", "A dire il vero", "Effettivamente"],
        "In ultima analisi": ["Alla fine", "In definitiva", "In conclusione"],
        "Occorre precisare": ["Va precisato", "Bisogna dire"],
        "Per contro": ["Al contrario", "D'altra parte", "Invece"],
        "Però": ["Ma", "Tuttavia", "Eppure"],
        "Più precisamente": ["In modo più preciso", "Nello specifico"],
        "Resta il fatto che": ["Rimane il fatto che", "Si deve ammettere"],
        "Stando così le cose": ["Data la situazione", "Pertanto"],
        "Tutto sommato": ["In fin dei conti", "Tutto considerato"],
        "Va da sé che": ["Naturalmente", "Ovviamente", "Si capisce"],
        "Volendo riassumere": ["In sintesi", "Per riassumere", "In breve"],
    },

    "synonyms": {
        "importante": ["rilevante", "significativo", "essenziale"],
        "grande": ["ampio", "vasto", "considerevole"],
        "piccolo": ["ridotto", "modesto", "esiguo"],
        "veloce": ["rapido", "agile", "pronto"],
        "problema": ["difficoltà", "sfida", "ostacolo"],
        "soluzione": ["risposta", "via d'uscita", "rimedio"],
        "risultato": ["esito", "effetto", "frutto"],
        "metodo": ["approccio", "tecnica", "sistema"],
        "processo": ["procedura", "percorso", "iter"],
        "obiettivo": ["scopo", "traguardo", "meta"],
        "vantaggio": ["beneficio", "plus", "punto di forza"],
        "sviluppo": ["evoluzione", "progresso", "crescita"],
        "analisi": ["studio", "esame", "indagine"],
        "efficace": ["efficiente", "produttivo", "funzionale"],
        "complesso": ["complicato", "articolato", "elaborato"],
        "moderno": ["attuale", "contemporaneo", "odierno"],
        "qualità": ["livello", "standard", "valore"],
        # === v0.10.0 ===
        "essenziale": ["fondamentale", "cruciale", "vitale"],
        "situazione": ["contesto", "caso", "scenario"],
        "strategia": ["piano", "tattica", "approccio"],
        "concetto": ["idea", "nozione", "principio"],
        "struttura": ["quadro", "organizzazione", "impalcatura"],
        "capacità": ["competenza", "abilità", "potenziale"],
        "influenza": ["impatto", "effetto", "peso"],
        "prospettiva": ["visione", "punto di vista", "angolo"],
        "dinamica": ["movimento", "slancio", "tendenza"],
        "elemento": ["componente", "parte", "fattore"],
        "sistema": ["meccanismo", "apparato", "insieme"],
        "risorsa": ["mezzo", "strumento", "fonte"],
        "dimensione": ["aspetto", "sfaccettatura", "lato"],
        "contesto": ["ambiente", "quadro", "sfondo"],
        "sfida": ["prova", "ostacolo", "difficoltà"],
        "evoluzione": ["cambiamento", "progresso", "trasformazione"],
        "contributo": ["apporto", "partecipazione", "aiuto"],
        "esperienza": ["vissuto", "pratica", "know-how"],
        "inoltre": ["anche", "pure", "altresì"],
        "necessario": ["indispensabile", "richiesto", "obbligatorio"],
        # === v0.11.0 massive expansion ===
        "difficile": ["arduo", "complicato", "impegnativo"],
        "facile": ["semplice", "agevole", "elementare"],
        "bello": ["piacevole", "gradevole", "attraente"],
        "brutto": ["sgradevole", "orribile", "spiacevole"],
        "buono": ["valido", "positivo", "eccellente"],
        "cattivo": ["pessimo", "negativo", "scadente"],
        "nuovo": ["recente", "fresco", "inedito"],
        "vecchio": ["antico", "datato", "obsoleto"],
        "forte": ["potente", "robusto", "intenso"],
        "debole": ["fragile", "fiacco", "scarso"],
        "lungo": ["prolungato", "esteso", "duraturo"],
        "breve": ["corto", "conciso", "sintetico"],
        "chiaro": ["limpido", "evidente", "palese"],
        "scuro": ["cupo", "buio", "oscuro"],
        "ricco": ["abbondante", "copioso", "florido"],
        "povero": ["scarso", "misero", "carente"],
        "alto": ["elevato", "superiore", "notevole"],
        "basso": ["ridotto", "inferiore", "contenuto"],
        "giusto": ["corretto", "appropriato", "adatto"],
        "sbagliato": ["errato", "scorretto", "improprio"],
        "possibile": ["fattibile", "realizzabile", "attuabile"],
        "impossibile": ["irrealizzabile", "impraticabile", "utopistico"],
        "necessità": ["bisogno", "esigenza", "urgenza"],
        "opportunità": ["occasione", "possibilità", "chance"],
        "cambiamento": ["modifica", "variazione", "trasformazione"],
        "crescita": ["aumento", "incremento", "espansione"],
        "calo": ["diminuzione", "ribasso", "contrazione"],
        "lavoro": ["attività", "impiego", "occupazione"],
        "progetto": ["piano", "iniziativa", "programma"],
        "accordo": ["intesa", "patto", "convenzione"],
        "decisione": ["scelta", "delibera", "risoluzione"],
        "comunicazione": ["messaggio", "informazione", "avviso"],
        "valutazione": ["giudizio", "stima", "esame"],
        "conoscenza": ["sapere", "competenza", "nozione"],
        "ruolo": ["funzione", "compito", "parte"],
        "impatto": ["effetto", "conseguenza", "ripercussione"],
        "settore": ["ambito", "campo", "area"],
        "aspetto": ["punto", "lato", "dettaglio"],
        "livello": ["grado", "piano", "stadio"],
        "modo": ["maniera", "forma", "stile"],
        "tipo": ["genere", "sorta", "categoria"],
        "area": ["zona", "regione", "settore"],
        "parte": ["porzione", "sezione", "fetta"],
        "fase": ["stadio", "momento", "tappa"],
        "punto": ["aspetto", "questione", "elemento"],
        "dato": ["informazione", "cifra", "indicatore"],
        "azione": ["intervento", "iniziativa", "passo"],
        "effetto": ["conseguenza", "risultato", "esito"],
        "causa": ["motivo", "ragione", "origine"],
        "fine": ["scopo", "obiettivo", "traguardo"],
        "inizio": ["avvio", "partenza", "principio"],
        "termine": ["fine", "conclusione", "scadenza"],
        "condizione": ["stato", "requisito", "circostanza"],
        "proposta": ["offerta", "suggerimento", "idea"],
        "esempio": ["caso", "modello", "campione"],
        "caratteristica": ["proprietà", "tratto", "qualità"],
        "funzione": ["ruolo", "compito", "mansione"],
        "relazione": ["rapporto", "legame", "connessione"],
        "risposta": ["replica", "reazione", "feedback"],
        "domanda": ["richiesta", "quesito", "interrogativo"],
        "attività": ["azione", "operazione", "lavoro"],
        "interesse": ["attenzione", "curiosità", "coinvolgimento"],
        "valore": ["pregio", "merito", "importanza"],
        "rischio": ["pericolo", "minaccia", "insidia"],
        "stato": ["condizione", "situazione", "posizione"],
        "utilizzo": ["uso", "impiego", "applicazione"],
        "miglioramento": ["progresso", "avanzamento", "ottimizzazione"],
        "obiettivamente": ["in realtà", "di fatto", "concretamente"],
        "sostanzialmente": ["in pratica", "di fatto", "essenzialmente"],
        "significativamente": ["notevolmente", "considerevolmente", "molto"],
        "adeguato": ["appropriato", "idoneo", "conforme"],
        "specifico": ["particolare", "preciso", "determinato"],
        "generale": ["complessivo", "globale", "ampio"],
        "particolare": ["specifico", "singolare", "unico"],
        "diverso": ["differente", "vario", "distinto"],
        "simile": ["analogo", "affine", "comparabile"],
        "costante": ["continuo", "stabile", "fisso"],
        "variabile": ["mutevole", "incostante", "instabile"],
        "reale": ["effettivo", "concreto", "vero"],
        "potenziale": ["possibile", "eventuale", "latente"],
        "attuale": ["corrente", "presente", "vigente"],
        "precedente": ["anteriore", "passato", "pregresso"],
        "successivo": ["seguente", "prossimo", "posteriore"],
        "recente": ["ultimo", "fresco", "nuovo"],
        "frequente": ["comune", "abituale", "ricorrente"],
        # === v0.12.0 expansion ===
        "rapido": ["celere", "svelto", "sollecito"],
        "lento": ["graduale", "flemmatico", "posato"],
        "preciso": ["esatto", "accurato", "puntuale"],
        "vago": ["impreciso", "generico", "indefinito"],
        "solido": ["robusto", "stabile", "saldo"],
        "fragile": ["delicato", "vulnerabile", "precario"],
        "ampio": ["esteso", "largo", "vasto"],
        "limitato": ["ristretto", "contenuto", "circoscritto"],
        "provvisorio": ["temporaneo", "transitorio", "passeggero"],
        "definitivo": ["finale", "conclusivo", "irreversibile"],
        "parziale": ["incompleto", "frammentario", "limitato"],
        "integrale": ["completo", "totale", "intero"],
        "evidente": ["palese", "manifesto", "lampante"],
        "frequentemente": ["spesso", "di frequente", "regolarmente"],
        "raramente": ["di rado", "poco", "sporadicamente"],
        "probabilmente": ["forse", "verosimilmente", "presumibilmente"],
        "sicuramente": ["certamente", "di certo", "senza dubbio"],
        "pienamente": ["completamente", "interamente", "del tutto"],
        "leggermente": ["appena", "un po'", "lievemente"],
        "profondamente": ["intensamente", "fortemente", "molto"],
        "considerevole": ["notevole", "consistente", "rilevante"],
        "trascurabile": ["irrilevante", "insignificante", "minimo"],
        "ragione": ["motivo", "causa", "fondamento"],
        "errore": ["sbaglio", "svista", "inesattezza"],
        "successo": ["riuscita", "buon esito", "trionfo"],
        "fallimento": ["insuccesso", "sconfitta", "fiasco"],
        "dubbio": ["incertezza", "perplessità", "esitazione"],
        "certezza": ["sicurezza", "convinzione", "garanzia"],
        "pericolo": ["rischio", "minaccia", "insidia"],
        "limite": ["confine", "soglia", "barriera"],
        "origine": ["provenienza", "fonte", "radice"],
        "scopo": ["fine", "obiettivo", "finalità"],
        "norma": ["regola", "legge", "disposizione"],
        "esigenza": ["necessità", "bisogno", "richiesta"],
        "creare": ["produrre", "realizzare", "generare"],
        "ridurre": ["diminuire", "calare", "abbassare"],
        "aumentare": ["accrescere", "innalzare", "incrementare"],
        "ottenere": ["raggiungere", "conquistare", "conseguire"],
        "fornire": ["dare", "offrire", "mettere a disposizione"],
        "sostenere": ["supportare", "appoggiare", "difendere"],
        "affrontare": ["gestire", "risolvere", "fronteggiare"],
        "confermare": ["ribadire", "avvalorare", "attestare"],
        "prevedere": ["anticipare", "programmare", "aspettarsi"],
        "ampliare": ["estendere", "allargare", "espandere"],
        "coinvolgere": ["includere", "incorporare", "interessare"],
        "rilevare": ["notare", "osservare", "constatare"],
    },

    "sentence_starters": {
        "Questo": ["Tale", "Un tale", "Il presente"],
        "Lui": ["La persona", "Il soggetto", "L'individuo"],
        "Lei": ["La persona", "La specialista", "L'autrice"],
        "Loro": ["Quelli", "Il team", "Queste persone"],
        "Noi": ["Il nostro team", "Il gruppo", "Tutti noi"],
        "Il": ["Un", "Ogni", "Questo"],
        "La": ["Una", "Questa", "Ogni"],
        "Le": ["Delle", "Queste", "Alcune"],
        "In": ["All'interno di", "Durante", "Nel corso di"],
        "Per": ["Al fine di", "Allo scopo di", "In vista di"],
        "Anche": ["Inoltre", "Ugualmente", "Pure"],
        # === v0.10.0 ===
        "Così": ["In questo modo", "Quindi", "Pertanto"],
        "Sebbene": ["Anche se", "Benché", "Nonostante"],
        # === v0.11.0 massive expansion ===
        "Questi": ["Tali", "I presenti", "Siffatti"],
        "Queste": ["Tali", "Siffatte", "Le presenti"],
        "Gli": ["I", "Alcuni", "Certi"],
        "Un": ["Il", "Ogni", "Ciascun"],
        "Una": ["La", "Ogni", "Ciascuna"],
        "I": ["Dei", "Alcuni", "Certi"],
        "Lo": ["Il", "Un", "Questo"],
        "Ci": ["Noi", "Vi", "Esistono"],
        "Si": ["Esso", "La cosa", "Ciò"],
        "È": ["Risulta", "Appare", "Sembra"],
        "Come": ["Così come", "In quanto", "Nel ruolo di"],
        "Quando": ["Nel momento in cui", "Allorché", "Ogni volta che"],
        "Se": ["Nel caso in cui", "Qualora", "Laddove"],
        "Con": ["Mediante", "Attraverso", "Tramite"],
        "Da": ["A partire da", "Fin da", "Sin da"],
        "Non": ["Mai", "In nessun caso", "Per niente"],
        "Dopo": ["In seguito", "Successivamente", "A seguire"],
        "Prima": ["Inizialmente", "All'inizio", "In precedenza"],
        "Quindi": ["Perciò", "Di conseguenza", "Pertanto"],
        "Mentre": ["Nel frattempo", "Intanto", "Durante"],
        "Già": ["Ormai", "A questo punto", "Sin d'ora"],
        "Ancora": ["Tuttora", "Sempre", "Di nuovo"],
        "Questo significa": ["Vuol dire", "In pratica", "Cioè"],
        # === v0.12.0 expansion ===
        "Qui": ["In questo luogo", "A questo punto", "In tale sede"],
        "Oggi": ["Al giorno d'oggi", "Attualmente", "Oggigiorno"],
        "Spesso": ["Frequentemente", "Di frequente", "Molte volte"],
        "Forse": ["Probabilmente", "Può darsi", "Eventualmente"],
        "Certamente": ["Sicuramente", "Senza dubbio", "Di certo"],
        "Ovviamente": ["Chiaramente", "Naturalmente", "Evidentemente"],
        "Generalmente": ["Di solito", "In genere", "Normalmente"],
        "Inizialmente": ["All'inizio", "In principio", "Dapprima"],
        "Infine": ["Alla fine", "Per concludere", "In ultimo"],
        "Apparentemente": ["A quanto pare", "A prima vista", "Sembrerebbe"],
        "Fortunatamente": ["Per fortuna", "Per buona sorte"],
        "Purtroppo": ["Sfortunatamente", "Ahimè", "Malauguratamente"],
        "Precisamente": ["Esattamente", "Proprio", "Per l'appunto"],
    },

    "colloquial_markers": [
        "onestamente", "in realtà", "in fondo",
        "diciamo", "in pratica", "tra l'altro",
        "per essere onesti", "tra di noi", "detto fra noi",
        "curiosamente", "per la verità",
        "a ben vedere", "per così dire",
        "alla fin fine", "in fin dei conti", "a proposito",
        # === v0.10.0 ===
        "insomma", "beh", "mah", "personalmente",
        "francamente", "va be'", "tanto per dire",
        "senza giri di parole", "ad essere sinceri", "ora",
        # === v0.11.0 massive expansion ===
        "a dire il vero", "per carità", "sai",
        "ecco", "cioè", "comunque",
        "praticamente", "fondamentalmente", "sinceramente",
        "in effetti", "guarda", "tipo",
        "magari", "per fortuna", "purtroppo",
        "in poche parole", "tanto", "alla fine",
        "per dire", "figurati", "non a caso",
        "ovviamente", "chiaramente", "evidentemente",
        "per inciso", "tra parentesi", "come dire",
        "in sostanza", "diciamo così", "a essere precisi",
        "per essere chiari", "a voler essere sinceri",
        "da un certo punto di vista",
        # === v0.12.0 expansion ===
        "se devo essere sincero", "la questione è che",
        "chiamiamo le cose col loro nome", "non nascondiamoci",
        "in parole semplici", "con tutto il rispetto",
        "per farla breve", "che dire",
        "sia chiaro", "detto tra noi",
        "se posso permettermi", "non a torto",
        "va detto", "parliamoci chiaro",
        "onestamente parlando", "la verità è che",
        "inutile girarci intorno", "bisogna ammetterlo",
        "a essere franchi", "senza mezzi termini",
    ],

    "abbreviations": [
        "Sig.", "Sig.ra", "Dott.", "Prof.", "ecc.",
        "es.", "vol.", "pag.", "ed.", "cap.", "fig.",
        "S.p.A.", "S.r.l.", "v.", "p.za", "tel.", "rif.",
        "max.", "min.", "ca.", "app.",
        # === v0.10.0 ===
        "N.B.", "P.S.", "n.", "dip.", "dir.",
        "amm.", "gov.", "sez.", "suppl.", "agg.",
        # === v0.11.0 massive expansion ===
        "Avv.", "Ing.", "Arch.", "Geom.", "Rag.",
        "On.", "Ill.mo", "Spett.le", "c.a.", "p.v.",
        "u.s.", "c.m.", "f.to", "all.", "prot.",
        "circ.", "art.", "c.c.", "c.p.", "D.Lgs.",
        "D.P.R.", "lett.", "cc.", "cfr.", "ib.",
        "op. cit.", "par.", "tav.", "tab.", "Comm.",
        "Cav.", "gen.", "c.d.", "sgg.",
    ],

    "perplexity_boosters": [
        "per così dire", "a ben vedere", "in buona sostanza",
        "né più né meno", "di fatto", "ipso facto",
        "paradossalmente", "curiosamente", "ironicamente",
        "a rigore", "in un certo senso",
        "a conti fatti", "tutto sommato", "con riguardo a",
        "detto ciò", "sia come sia", "in ogni caso",
        "per quanto mi riguarda", "a dirla tutta",
        # === v0.10.0 ===
        "sta di fatto che", "comunque sia",
        "per amor del vero", "a onor del vero",
        "non c'è che dire", "a ben guardare",
        "volente o nolente", "come che sia",
        # === v0.11.0 massive expansion ===
        "per quanto ne sappia", "nella misura in cui",
        "a quanto pare", "sembrerebbe che",
        "sotto certi aspetti", "in teoria",
        "stando ai fatti", "in ultima analisi",
        "per certi versi", "da quel che si vede",
        "se non altro", "ammesso e non concesso",
        "a detta di molti", "in buona fede",
        "a tutti gli effetti", "con buona pace di",
        "per quanto possa sembrare strano",
        "in definitiva", "per la precisione",
        "non da ultimo", "a onor di cronaca",
        "per quanto paradossale", "con tutto il rispetto",
        "se vogliamo", "ad essere onesti",
        "con le dovute cautele", "in coscienza",
        "su per giù", "per certi aspetti",
        "a prescindere", "con ogni probabilità",
        "senza ombra di dubbio",
        "a giudicare dalle apparenze",
        # === v0.12.0 expansion ===
        "al netto di tutto", "malgrado tutto",
        "a voler esser pignoli", "ciò nondimeno",
        "ad essere pignoli", "guardando i fatti",
        "se non erro", "a quanto mi risulta",
        "per quel che vale", "fatto sta che",
        "che piaccia o no", "va detto con franchezza",
        "a torto o a ragione", "in fin dei conti",
        "per quanto ne sappia", "non si può negare",
        "stando ai dati", "per quanto strano possa sembrare",
        "non è un caso che", "a voler essere onesti",
    ],

    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 22), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 30), "variance": 0.25},
    },

    "conjunctions": ["e", "ma", "o", "né", "che", "poi"],

    "split_conjunctions": [
        " e ", " ma ", " tuttavia ", " mentre ",
        " sebbene ", " perché ", " poiché ",
        # === v0.10.0 ===
        " ciononostante ", " eppure ", " bensì ",
        " al contrario ", " pertanto ", " giacché ",
        # === v0.11.0 massive expansion ===
        " dunque ", " ovvero ", " oppure ",
        " ossia ", " nondimeno ", " benché ",
        " allorché ", " qualora ", " laddove ",
        " cosicché ", " affinché ", " purché ",
        " nonostante ", " malgrado ", " sicché ",
        " dopodiché ", " altrimenti ", " anziché ",
    ],
}
