"""Языковой пакет: Немецкий (Deutsch)."""

LANG_DE = {
    "code": "de",
    "name": "Deutsch",

    # Триграммы для определения языка
    "trigrams": [
        "der", "die", "und", "den", "das", "ein", "sch", "ich",
        "che", "ine", "ist", "eit", "ung", "uch", "ber", "ter",
        "eni", "ges", "ere", "aus", "für", "gen", "cht", "ent",
        "ver", "ren", "ste", "auf", "ach", "bei", "ier", "tte",
        "lic", "erf", "her", "nic", "nde", "and", "ung", "mit",
    ],

    # Стоп-слова (не заменять)
    "stop_words": {
        "der", "die", "das", "ein", "eine", "und", "oder", "aber",
        "ist", "sind", "war", "hat", "haben", "wird", "werden",
        "kann", "können", "muss", "müssen", "soll", "sollen",
        "in", "an", "auf", "für", "mit", "von", "zu", "bei",
        "nach", "über", "unter", "vor", "aus", "durch", "um",
        "ich", "du", "er", "sie", "es", "wir", "ihr",
        "den", "dem", "des", "einer", "einem", "eines",
        "nicht", "auch", "noch", "schon", "nur", "wenn",
        "als", "wie", "so", "da", "dann", "denn", "weil",
        "dass", "ob", "man", "sich", "hier", "dort",
        "sehr", "mehr", "viel", "gut", "neu", "alle",
        "diese", "dieser", "dieses", "jede", "jeder", "jedes",
        "sein", "seine", "seinem", "seinen", "seiner",
        "ihre", "ihrem", "ihren", "ihrer",
        "was", "wer", "wo", "warum", "welche",
    },

    # Канцеляризмы (бюрократический стиль)
    "bureaucratic": {
        "implementieren": ["umsetzen", "einführen"],
        "Implementierung": ["Umsetzung", "Einführung"],
        "optimieren": ["verbessern", "anpassen"],
        "Optimierung": ["Verbesserung", "Anpassung"],
        "evaluieren": ["bewerten", "prüfen", "beurteilen"],
        "Evaluierung": ["Bewertung", "Prüfung", "Beurteilung"],
        "generieren": ["erzeugen", "erstellen", "schaffen"],
        "initiieren": ["starten", "beginnen", "anstoßen"],
        "adressieren": ["angehen", "behandeln", "lösen"],
        "facilitieren": ["erleichtern", "ermöglichen"],
        "priorisieren": ["vorziehen", "bevorzugen"],
        "kommunizieren": ["mitteilen", "besprechen", "sagen"],
        "finalisieren": ["fertigstellen", "abschließen"],
        "signifikant": ["deutlich", "merklich", "spürbar", "erheblich"],
        "fundamental": ["grundlegend", "wesentlich"],
        "essentiell": ["wichtig", "nötig", "wesentlich"],
        "inhärent": ["eigen", "innewohnend"],
        "konsequent": ["folgerichtig", "durchgehend"],
        "adäquat": ["passend", "angemessen"],
        "primär": ["hauptsächlich", "vor allem"],
        "sukzessive": ["nach und nach", "schrittweise"],
        "marginalisieren": ["verdrängen", "zurückdrängen"],
        "integrieren": ["einbinden", "einbauen"],
        "manifestieren": ["zeigen", "offenbaren"],
        "etablieren": ["einrichten", "aufbauen", "gründen"],
        "Berücksichtigung": ["Beachtung", "Rücksicht"],
        "Sicherstellung": ["Gewährleistung", "Absicherung"],
        "Gewährleistung": ["Sicherung", "Absicherung"],
        "Durchführung": ["Ausführung", "Umsetzung"],
        "Inanspruchnahme": ["Nutzung", "Verwendung"],
        "Beeinträchtigung": ["Störung", "Einschränkung"],
        "Bereitstellung": ["Lieferung", "Beschaffung"],
        "Korrespondenz": ["Schriftverkehr", "Briefwechsel"],
        "Instandhaltung": ["Pflege", "Wartung"],
        "Realisierung": ["Umsetzung", "Verwirklichung"],
        "Konzeptionierung": ["Planung", "Entwurf"],
        "Positionierung": ["Platzierung", "Ausrichtung"],
        "Fokussierung": ["Ausrichtung", "Konzentration"],
        "analysieren": ["untersuchen", "prüfen", "auswerten"],
        "spezifizieren": ["festlegen", "bestimmen", "angeben"],
        "thematisieren": ["ansprechen", "behandeln", "besprechen"],
        "konkretisieren": ["genauer beschreiben", "verdeutlichen"],
        "identifizieren": ["erkennen", "feststellen", "finden"],
        "verifizieren": ["prüfen", "nachprüfen", "bestätigen"],
        "repräsentieren": ["vertreten", "darstellen", "stehen für"],
        "koordinieren": ["abstimmen", "organisieren"],
        "kompensieren": ["ausgleichen", "wettmachen"],
        "legitimieren": ["rechtfertigen", "begründen"],
        "intensivieren": ["verstärken", "steigern"],
        "reduzieren": ["verringern", "senken", "vermindern"],
        "transformieren": ["umwandeln", "verändern", "umgestalten"],
        "sorgfältig": ["gründlich", "gewissenhaft", "genau"],
        "umfassend": ["breit", "vollständig", "gründlich"],
        "angemessen": ["passend", "geeignet", "richtig"],
        "grundlegend": ["wesentlich", "zentral", "elementar"],
        "wesentlich": ["wichtig", "zentral", "bedeutend"],
        "sämtlich": ["alle", "jeder", "gesamt"],
        "zahlreich": ["viele", "reichlich"],
        "diesbezüglich": ["dazu", "hierzu", "in dieser Hinsicht"],
        "entsprechend": ["dementsprechend", "gemäß", "passend"],
        "hinreichend": ["ausreichend", "genug", "genügend"],
        # === v0.11.0 massive expansion ===
        "akquirieren": ["gewinnen", "beschaffen", "anwerben"],
        "akkumulieren": ["ansammeln", "anhäufen", "sammeln"],
        "allokieren": ["zuweisen", "verteilen", "zuordnen"],
        "antizipieren": ["vorwegnehmen", "erwarten", "ahnen"],
        "applizieren": ["anwenden", "einsetzen"],
        "approbieren": ["genehmigen", "billigen"],
        "artikulieren": ["ausdrücken", "formulieren", "sagen"],
        "assimilieren": ["aufnehmen", "angleichen", "eingliedern"],
        "autorisieren": ["ermächtigen", "bevollmächtigen", "freigeben"],
        "avancieren": ["aufsteigen", "vorankommen"],
        "bilateral": ["zweiseitig", "gegenseitig"],
        "deduzieren": ["ableiten", "folgern", "schließen"],
        "definieren": ["bestimmen", "festlegen", "beschreiben"],
        "delegieren": ["übertragen", "abgeben", "weiterleiten"],
        "demonstrieren": ["zeigen", "vorführen", "beweisen"],
        "determinieren": ["bestimmen", "festlegen"],
        "differenzieren": ["unterscheiden", "trennen", "abstufen"],
        "disputieren": ["streiten", "debattieren", "diskutieren"],
        "distribuieren": ["verteilen", "liefern", "ausliefern"],
        "dokumentieren": ["belegen", "festhalten", "aufzeichnen"],
        "dominieren": ["beherrschen", "überwiegen", "vorherrschen"],
        "elaborieren": ["ausarbeiten", "vertiefen"],
        "eliminieren": ["beseitigen", "entfernen", "abschaffen"],
        "emittieren": ["ausstoßen", "ausgeben", "freisetzen"],
        "eskalieren": ["verschärfen", "steigern", "zuspitzen"],
        "expandieren": ["ausweiten", "erweitern", "wachsen"],
        "explizieren": ["erklären", "erläutern", "darlegen"],
        "exzellent": ["ausgezeichnet", "hervorragend", "erstklassig"],
        "formalisieren": ["regeln", "standardisieren"],
        "formulieren": ["ausdrücken", "verfassen", "gestalten"],
        "frequentieren": ["besuchen", "aufsuchen"],
        "fundieren": ["begründen", "untermauern", "stützen"],
        "garantieren": ["sicherstellen", "zusichern", "gewähren"],
        "harmonisieren": ["angleichen", "abstimmen", "vereinheitlichen"],
        "illustrieren": ["veranschaulichen", "zeigen", "darstellen"],
        "implizieren": ["einschließen", "bedeuten", "nahelegen"],
        "indizieren": ["anzeigen", "hinweisen", "deuten"],
        "initialisieren": ["einleiten", "starten", "beginnen"],
        "innovieren": ["erneuern", "modernisieren"],
        "institutionalisieren": ["einrichten", "verankern"],
        "instrumentalisieren": ["benutzen", "ausnutzen"],
        "interagieren": ["zusammenwirken", "austauschen"],
        "interpretieren": ["deuten", "auslegen", "verstehen"],
        "investieren": ["anlegen", "einsetzen", "aufwenden"],
        "justieren": ["einstellen", "ausrichten", "anpassen"],
        "kalkulieren": ["berechnen", "schätzen", "einplanen"],
        "katalogisieren": ["erfassen", "ordnen", "einordnen"],
        "klassifizieren": ["einordnen", "einteilen", "sortieren"],
        "kombinieren": ["verbinden", "verknüpfen", "zusammenführen"],
        "kommentieren": ["erläutern", "anmerken", "besprechen"],
        "konzentrieren": ["bündeln", "fokussieren", "sammeln"],
        "konzipieren": ["planen", "entwerfen", "entwickeln"],
        "korrelieren": ["zusammenhängen", "verbinden"],
        "kultivieren": ["pflegen", "fördern", "hegen"],
        "liberalisieren": ["lockern", "öffnen", "freigeben"],
        "limitieren": ["begrenzen", "einschränken", "beschränken"],
        "lokalisieren": ["orten", "finden", "verorten"],
        "manipulieren": ["beeinflussen", "steuern", "lenken"],
        "maximieren": ["steigern", "erhöhen", "ausbauen"],
        "minimieren": ["verringern", "senken", "verkleinern"],
        "mobilisieren": ["einsetzen", "aufbieten", "aktivieren"],
        "modifizieren": ["ändern", "anpassen", "abwandeln"],
        "motivieren": ["anregen", "anspornen", "antreiben"],
        "navigieren": ["steuern", "lenken", "führen"],
        "negieren": ["verneinen", "ablehnen", "leugnen"],
        "normalisieren": ["regeln", "vereinheitlichen"],
        "objektivieren": ["versachlichen", "neutral betrachten"],
        "operieren": ["arbeiten", "handeln", "wirken"],
        "organisieren": ["ordnen", "planen", "einrichten"],
        "orientieren": ["ausrichten", "anpassen", "leiten"],
        "partizipieren": ["teilnehmen", "teilhaben", "mitwirken"],
        "perpetuieren": ["fortsetzen", "aufrechterhalten"],
        "platzieren": ["setzen", "stellen", "legen"],
        "polarisieren": ["spalten", "entzweien"],
        "postulieren": ["fordern", "verlangen", "behaupten"],
        "praktizieren": ["ausüben", "anwenden", "betreiben"],
        "präsentieren": ["vorstellen", "zeigen", "vorführen"],
        "profilieren": ["hervorheben", "auszeichnen"],
        "profitieren": ["nutzen", "Vorteil haben", "gewinnen"],
        "prognostizieren": ["vorhersagen", "erwarten", "voraussagen"],
        "projizieren": ["planen", "vorausberechnen"],
        "propagieren": ["verbreiten", "fördern", "bewerben"],
        "qualifizieren": ["befähigen", "ausbilden"],
        "quantifizieren": ["beziffern", "messen", "zählen"],
        "ratifizieren": ["bestätigen", "genehmigen"],
        "rationalisieren": ["vereinfachen", "straffen"],
        "reformieren": ["umgestalten", "erneuern", "ändern"],
        "regulieren": ["regeln", "steuern", "lenken"],
        "rekapitulieren": ["zusammenfassen", "wiederholen"],
        "relativieren": ["abschwächen", "einschränken"],
        "restrukturieren": ["umbauen", "umgestalten", "neu ordnen"],
        "revitalisieren": ["beleben", "erneuern", "auffrischen"],
        "sanktionieren": ["genehmigen", "strafen", "bestrafen"],
        "segmentieren": ["aufteilen", "gliedern", "unterteilen"],
        "selektieren": ["auswählen", "aussuchen", "aussortieren"],
        "signalisieren": ["anzeigen", "andeuten", "hinweisen"],
        "simulieren": ["nachahmen", "vortäuschen", "nachbilden"],
        "stabilisieren": ["festigen", "sichern", "stärken"],
        "standardisieren": ["vereinheitlichen", "normen"],
        "stimulieren": ["anregen", "fördern", "anspornen"],
        "strukturieren": ["gliedern", "ordnen", "aufbauen"],
        "substituieren": ["ersetzen", "austauschen"],
        "synthetisieren": ["zusammenfügen", "herstellen"],
        "systematisieren": ["ordnen", "gliedern"],
        "tolerieren": ["dulden", "hinnehmen", "akzeptieren"],
        "visualisieren": ["veranschaulichen", "darstellen", "zeigen"],
        "zentralisieren": ["zusammenlegen", "bündeln"],
        # Additional adjectives
        "ambivalent": ["zwiespältig", "zweideutig"],
        "dezidiert": ["entschieden", "bestimmt", "klar"],
        "divers": ["verschieden", "vielfältig", "unterschiedlich"],
        "effizient": ["leistungsfähig", "wirksam", "sparsam"],
        "eminent": ["herausragend", "bedeutend", "beachtlich"],
        "evident": ["offensichtlich", "klar", "ersichtlich"],
        "exorbitant": ["übermäßig", "maßlos", "enorm"],
        "explizit": ["ausdrücklich", "klar", "deutlich"],
        "implizit": ["stillschweigend", "unausgesprochen"],
        "immanent": ["innewohnend", "eigen", "wesenhaft"],
        "inaugurieren": ["einsetzen", "einweihen"],
        "inadäquat": ["ungeeignet", "unangemessen"],
        "inäquivalent": ["ungleichwertig", "ungleich"],
        "inkludieren": ["einbeziehen", "einschließen"],
        "kongruent": ["übereinstimmend", "deckungsgleich"],
        "konsistent": ["folgerichtig", "schlüssig", "stimmig"],
        "konstruktiv": ["aufbauend", "förderlich", "hilfreich"],
        "kontrovers": ["umstritten", "strittig"],
        "marginal": ["geringfügig", "nebensächlich", "unbedeutend"],
        "obligatorisch": ["verpflichtend", "zwingend", "Pflicht-"],
        "obsolet": ["veraltet", "überholt", "hinfällig"],
        "optional": ["freiwillig", "wahlweise", "möglich"],
        "peripher": ["nebensächlich", "am Rand"],
        "permanent": ["dauerhaft", "ständig", "beständig"],
        "plausibel": ["einleuchtend", "nachvollziehbar", "glaubhaft"],
        "prägnant": ["knapp", "treffend", "kurz und bündig"],
        "präzise": ["genau", "exakt", "treffend"],
        "profund": ["tiefgründig", "gründlich", "fundiert"],
        "prominent": ["bekannt", "angesehen", "herausragend"],
        "redundant": ["überflüssig", "doppelt", "unnötig"],
        "relevant": ["wichtig", "bedeutsam", "zutreffend"],
        "rigoros": ["streng", "hart", "unnachgiebig"],
        "simultan": ["gleichzeitig", "parallel"],
        "stringent": ["streng", "konsequent", "schlüssig"],
        "substanziell": ["wesentlich", "bedeutend", "erheblich"],
        "transparent": ["durchsichtig", "offen", "nachvollziehbar"],
        "trivial": ["belanglos", "unbedeutend", "einfach"],
        "valide": ["gültig", "stichhaltig", "tragfähig"],
        "virulent": ["drängend", "akut", "brisant"],
        # Additional nouns
        "Adaption": ["Anpassung", "Übernahme"],
        "Affinität": ["Neigung", "Nähe", "Verwandtschaft"],
        "Agenda": ["Tagesordnung", "Programm", "Plan"],
        "Ambition": ["Ehrgeiz", "Streben", "Ziel"],
        "Analogie": ["Ähnlichkeit", "Vergleich", "Parallele"],
        "Applikation": ["Anwendung", "Programm", "App"],
        "Assertion": ["Behauptung", "Aussage"],
        "Autonomie": ["Selbstständigkeit", "Unabhängigkeit"],
        "Diversität": ["Vielfalt", "Verschiedenheit"],
        "Effizienz": ["Leistungsfähigkeit", "Wirtschaftlichkeit"],
        "Essenz": ["Kern", "Wesen", "Substanz"],
        "Evidenz": ["Nachweis", "Beweis", "Beleg"],
        "Hypothese": ["Annahme", "Vermutung", "These"],
        "Implikation": ["Auswirkung", "Folge", "Bedeutung"],
        "Infrastruktur": ["Grundlage", "Unterbau"],
        "Innovation": ["Neuerung", "Erfindung", "Neuheit"],
        "Instanz": ["Stelle", "Behörde", "Ebene"],
        "Interaktion": ["Zusammenspiel", "Austausch"],
        "Kapazität": ["Fähigkeit", "Leistung", "Aufnahme"],
        "Kohärenz": ["Zusammenhalt", "Stimmigkeit"],
        "Kompetenz": ["Fähigkeit", "Können", "Sachverstand"],
        "Komponente": ["Bestandteil", "Bauteil", "Element"],
        "Konsequenz": ["Folge", "Auswirkung", "Ergebnis"],
        "Kontingenz": ["Zufälligkeit", "Möglichkeit"],
        "Konvention": ["Regel", "Brauch", "Übereinkunft"],
        "Paradigma": ["Muster", "Vorbild", "Denkmodell"],
        "Parameter": ["Kennwert", "Größe", "Einstellung"],
        "Performanz": ["Leistung", "Können", "Darbietung"],
        "Prämisse": ["Voraussetzung", "Grundlage", "Annahme"],
        "Profession": ["Beruf", "Fach", "Gewerbe"],
        "Progression": ["Fortschritt", "Steigerung"],
        "Proportion": ["Verhältnis", "Anteil"],
        "Provision": ["Vergütung", "Gebühr"],
        "Referenz": ["Bezug", "Verweis", "Empfehlung"],
        "Regulierung": ["Regelung", "Steuerung"],
        "Relevanz": ["Bedeutung", "Wichtigkeit", "Tragweite"],
        "Resonanz": ["Rückmeldung", "Echo", "Anklang"],
        "Revision": ["Überprüfung", "Überarbeitung"],
        "Signifikanz": ["Bedeutsamkeit", "Tragweite"],
        "Spezifikation": ["Angabe", "Vorgabe", "Beschreibung"],
        "Substanz": ["Stoff", "Kern", "Inhalt"],
        "Synergie": ["Zusammenwirken", "Bündelung"],
        "Thematik": ["Thema", "Gegenstand", "Stoff"],
        "Toleranz": ["Duldsamkeit", "Offenheit"],
        "Transformation": ["Wandel", "Umwandlung", "Veränderung"],
        "Transparenz": ["Offenheit", "Durchschaubarkeit"],
        "Validität": ["Gültigkeit", "Stichhaltigkeit"],
        "Varianz": ["Abweichung", "Schwankung", "Streuung"],
        # === v0.12.0 expansion ===
        "abstrahieren": ["verallgemeinern", "vereinfachen"],
        "adaptieren": ["anpassen", "übernehmen", "umstellen"],
        "affirmieren": ["bestätigen", "bejahen", "bekräftigen"],
        "aggregieren": ["zusammenfassen", "bündeln", "sammeln"],
        "amplifizieren": ["verstärken", "vergrößern", "erweitern"],
        "annullieren": ["aufheben", "für ungültig erklären", "streichen"],
        "apostrophieren": ["bezeichnen", "benennen", "nennen"],
        "attestieren": ["bescheinigen", "bestätigen", "bezeugen"],
        "bagatellisieren": ["verharmlosen", "herunterspielen", "kleinreden"],
        "banalisieren": ["vereinfachen", "verflachen"],
        "boykottieren": ["meiden", "ablehnen", "sperren"],
        "budgetieren": ["planen", "einplanen", "veranschlagen"],
        "debattieren": ["besprechen", "erörtern", "diskutieren"],
        "dechiffrieren": ["entschlüsseln", "entziffern", "deuten"],
        "deklarieren": ["erklären", "angeben", "verkünden"],
        "dementieren": ["bestreiten", "widerrufen", "richtigstellen"],
        "demontieren": ["abbauen", "zerlegen"],
        "deregulieren": ["lockern", "freigeben", "entregeln"],
        "designieren": ["bestimmen", "ernennen", "vorsehen"],
        "destabilisieren": ["erschüttern", "schwächen", "ins Wanken bringen"],
        "detektieren": ["orten", "aufspüren", "entdecken"],
        "diagnostizieren": ["feststellen", "erkennen", "bestimmen"],
        "dimensionieren": ["bemessen", "zuschneiden", "auslegen"],
        "disponieren": ["verfügen", "planen", "anordnen"],
        "diversifizieren": ["auffächern", "erweitern", "vielfältig gestalten"],
        "dosieren": ["abmessen", "einteilen", "portionieren"],
        "dramatisieren": ["übertreiben", "aufbauschen", "zuspitzen"],
        "duplizieren": ["verdoppeln", "kopieren", "vervielfachen"],
        "edieren": ["herausgeben", "veröffentlichen", "bearbeiten"],
        "effektuieren": ["bewirken", "ausführen", "durchführen"],
        "egalisieren": ["ausgleichen", "gleichmachen", "angleichen"],
        "eklatant": ["offenkundig", "auffällig", "krass"],
        "engagieren": ["einsetzen", "verpflichten", "beteiligen"],
        "evakuieren": ["räumen", "leeren", "verlegen"],
        "examinieren": ["prüfen", "befragen", "testen"],
        "exemplifizieren": ["veranschaulichen", "verdeutlichen", "belegen"],
        "extrahieren": ["herausziehen", "entnehmen", "gewinnen"],
        "falsifizieren": ["widerlegen", "entkräften"],
        "figurieren": ["auftreten", "erscheinen", "vorkommen"],
        "fokussieren": ["ausrichten", "bündeln", "zielen"],
        "fragmentieren": ["zerteilen", "aufspalten", "zerlegen"],
        "generalisieren": ["verallgemeinern", "ausweiten"],
        "hospitalisieren": ["einweisen", "stationär aufnehmen"],
        "idealisieren": ["verklären", "überhöhen"],
        "ignorieren": ["missachten", "übersehen", "übergehen"],
        "importieren": ["einführen", "beziehen", "hereinholen"],
        "infiltrieren": ["eindringen", "unterwandern", "einschleusen"],
        "informieren": ["benachrichtigen", "unterrichten", "mitteilen"],
        "inspizieren": ["besichtigen", "untersuchen", "kontrollieren"],
        "installieren": ["einbauen", "einrichten", "aufstellen"],
        "intervenieren": ["eingreifen", "einschreiten", "vermitteln"],
        "isolieren": ["abkapseln", "trennen", "absondern"],
        "kanalisieren": ["lenken", "bündeln", "leiten"],
        "kollidieren": ["zusammenstoßen", "sich widersprechen"],
        "kommerzialisieren": ["verwerten", "vermarkten"],
        "kompilieren": ["zusammenstellen", "sammeln", "zusammentragen"],
        "konfiszieren": ["einziehen", "beschlagnahmen"],
        "konfrontieren": ["gegenüberstellen", "entgegenhalten"],
        "konkurrieren": ["wetteifern", "mithalten", "kämpfen"],
        "konservieren": ["erhalten", "bewahren", "haltbar machen"],
        "konstatieren": ["feststellen", "erkennen", "bemerken"],
        "konsultieren": ["befragen", "zurate ziehen", "beraten"],
        "kontaminieren": ["verunreinigen", "verseuchen", "verschmutzen"],
        "kontrollieren": ["überprüfen", "überwachen", "nachsehen"],
        "konvertieren": ["umwandeln", "umrechnen", "wechseln"],
        "kooperieren": ["zusammenarbeiten", "mitarbeiten", "mitwirken"],
        "kritisieren": ["beanstanden", "bemängeln", "tadeln"],
        "kursieren": ["umlaufen", "im Umlauf sein"],
        "legalisieren": ["erlauben", "genehmigen", "zulassen"],
        "liquidieren": ["auflösen", "abwickeln", "beseitigen"],
        "materialisieren": ["verwirklichen", "greifbar machen"],
        "mechanisieren": ["automatisieren", "maschinell herstellen"],
        "moderieren": ["leiten", "führen", "mäßigen"],
        "modellieren": ["formen", "gestalten", "nachbilden"],
        "monopolisieren": ["beherrschen", "allein bestimmen"],
        "multiplizieren": ["vervielfachen", "vermehren"],
        "neutralisieren": ["aufheben", "unwirksam machen", "ausgleichen"],
        "nominieren": ["benennen", "vorschlagen", "bestimmen"],
        "normieren": ["festlegen", "regeln"],
        "notifizieren": ["benachrichtigen", "melden", "anzeigen"],
        "obstruieren": ["behindern", "blockieren", "hemmen"],
        "oszillieren": ["schwanken", "pendeln", "schwingen"],
        "paraphrasieren": ["umschreiben", "neu formulieren"],
        "pausieren": ["unterbrechen", "innehalten", "rasten"],
        "personalisieren": ["anpassen", "individualisieren"],
        "protokollieren": ["aufzeichnen", "festhalten", "niederschreiben"],
        "provozieren": ["herausfordern", "reizen", "aufstacheln"],
        "publizieren": ["veröffentlichen", "herausgeben", "drucken"],
        "reklamieren": ["beanstanden", "beschweren", "monieren"],
        "rekrutieren": ["anwerben", "einstellen", "gewinnen"],
        "renovieren": ["erneuern", "verschönern", "auffrischen"],
        "reservieren": ["vormerken", "freihalten", "buchen"],
        "resümieren": ["zusammenfassen", "bilanzieren"],
        "rotieren": ["kreisen", "wechseln", "drehen"],
        "skizzieren": ["umreißen", "entwerfen", "andeuten"],
        "spekulieren": ["mutmaßen", "vermuten", "annehmen"],
        "subventionieren": ["bezuschussen", "fördern", "unterstützen"],
        "suggerieren": ["nahelegen", "andeuten", "einflüstern"],
        "suspendieren": ["aussetzen", "beurlauben", "zeitweilig aufheben"],
        "taktieren": ["planen", "vorgehen", "abwägen"],
        "terminieren": ["ansetzen", "festlegen", "planen"],
        "thesaurieren": ["ansparen", "ansammeln", "horten"],
        "transferieren": ["übertragen", "verlagern", "verschieben"],
        "validieren": ["bestätigen", "prüfen", "für gültig erklären"],
        "ventilieren": ["erörtern", "besprechen", "durchlüften"],
        "verifiziert": ["geprüft", "bestätigt", "bewiesen"],
    },

    # Фразовые канцеляризмы
    "bureaucratic_phrases": {
        "es ist festzustellen": ["es zeigt sich", "klar ist"],
        "in Anbetracht der Tatsache": ["angesichts", "weil"],
        "unter Berücksichtigung": ["mit Blick auf", "angesichts"],
        "im Rahmen von": ["bei", "während", "innerhalb"],
        "zum Zwecke der": ["für", "um zu"],
        "in Bezug auf": ["zu", "bei", "was betrifft"],
        "hinsichtlich": ["zu", "bei", "was betrifft"],
        "zwecks": ["für", "um zu"],
        "mittels": ["mit", "durch"],
        "aufgrund der Tatsache": ["weil", "da"],
        "im Hinblick auf": ["für", "bezüglich"],
        "es lässt sich konstatieren": ["man sieht", "es zeigt sich"],
        "von großer Bedeutung": ["wichtig", "bedeutend"],
        "eine zentrale Rolle spielen": ["wichtig sein", "zentral sein"],
        "unter der Voraussetzung": ["wenn", "falls", "vorausgesetzt"],
        "in Ermangelung": ["ohne", "mangels"],
        "zur Verfügung stellen": ["bereitstellen", "geben", "bieten"],
        "in Anspruch nehmen": ["nutzen", "verwenden"],
        "zur Kenntnis nehmen": ["beachten", "wissen"],
        "Rechnung tragen": ["berücksichtigen", "beachten"],
        "in Kraft treten": ["gelten", "wirken", "wirksam werden"],
        "Sorge tragen": ["sorgen für", "achten auf"],
        "einen Beitrag leisten": ["beitragen", "helfen"],
        "einen grundlegenden Aspekt": ["eine wichtige Seite", "einen Kernpunkt"],
        "stellt einen grundlegenden Aspekt dar": ["ist ein wichtiger Punkt", "ist zentral"],
        # === v0.11.0 massive expansion ===
        "zum gegenwärtigen Zeitpunkt": ["jetzt", "derzeit", "aktuell"],
        "zu einem späteren Zeitpunkt": ["später", "danach", "irgendwann"],
        "in Erwägung ziehen": ["erwägen", "überlegen", "bedenken"],
        "Stellung nehmen zu": ["sich äußern zu", "kommentieren"],
        "einer Prüfung unterziehen": ["prüfen", "untersuchen", "testen"],
        "einer Lösung zuführen": ["lösen", "klären"],
        "in Abrede stellen": ["bestreiten", "leugnen"],
        "Kenntnis erlangen": ["erfahren", "lernen"],
        "unter Beweis stellen": ["beweisen", "zeigen"],
        "Ausdruck verleihen": ["ausdrücken", "sagen", "zeigen"],
        "in Betracht ziehen": ["bedenken", "erwägen", "überlegen"],
        "zum Ausdruck bringen": ["sagen", "ausdrücken", "zeigen"],
        "in Augenschein nehmen": ["ansehen", "prüfen", "betrachten"],
        "einer Analyse unterziehen": ["analysieren", "untersuchen"],
        "zu dem Schluss kommen": ["folgern", "feststellen", "schließen"],
        "einen Einfluss haben auf": ["beeinflussen", "wirken auf"],
        "in Einklang bringen": ["abstimmen", "angleichen", "vereinen"],
        "zur Anwendung bringen": ["anwenden", "nutzen", "einsetzen"],
        "einen Zusammenhang herstellen": ["verbinden", "verknüpfen"],
        "Bezug nehmen auf": ["sich beziehen auf", "erwähnen"],
        # === v0.12.0 expansion ===
        "in Absprache mit": ["mit", "gemeinsam mit", "nach Rücksprache mit"],
        "in der Absicht": ["um zu", "mit dem Ziel", "mit der Absicht"],
        "unter Einbeziehung": ["mit", "unter Beteiligung", "einschließlich"],
        "mit Nachdruck": ["nachdrücklich", "betont", "energisch"],
        "vor dem Hintergrund": ["angesichts", "wegen", "aufgrund"],
        "zu einem früheren Zeitpunkt": ["vorher", "davor", "früher"],
        "mit der Maßgabe": ["unter der Bedingung", "vorausgesetzt"],
        "in Übereinkunft mit": ["gemäß", "nach", "laut"],
        "unter Bezugnahme auf": ["mit Blick auf", "bezüglich", "zu"],
        "in Abstimmung mit": ["zusammen mit", "abgestimmt mit"],
        "mit Blick auf die Zukunft": ["künftig", "zukünftig", "vorausschauend"],
        "Maßnahmen ergreifen": ["handeln", "eingreifen", "vorgehen"],
        "einer Überprüfung unterziehen": ["überprüfen", "prüfen", "testen"],
        "in Übereinstimmung mit": ["gemäß", "nach", "passend zu"],
        "zum Tragen kommen": ["wirksam werden", "sich zeigen", "greifen"],
        "zum Gegenstand haben": ["behandeln", "betreffen", "sich befassen mit"],
        "zu der Auffassung gelangen": ["meinen", "finden", "der Meinung sein"],
        "einer Bewertung unterziehen": ["bewerten", "beurteilen", "einschätzen"],
        "in Gang setzen": ["starten", "einleiten", "anstoßen"],
        "zum Erliegen bringen": ["stoppen", "stilllegen", "aufhalten"],
        "außer Acht lassen": ["vernachlässigen", "ignorieren", "übersehen"],
        "ins Auge fassen": ["planen", "vorhaben", "erwägen"],
        "zur Diskussion stellen": ["besprechen", "erörtern", "vorlegen"],
        "den Weg ebnen für": ["ermöglichen", "vorbereiten", "bereiten"],
        "zu Protokoll geben": ["festhalten", "vermerken", "aufzeichnen"],
    },

    # ИИ-связки
    "ai_connectors": {
        "Darüber hinaus": ["Außerdem", "Zudem", "Dazu", "Weiters"],
        "Nichtsdestotrotz": ["Trotzdem", "Aber", "Dennoch"],
        "Demzufolge": ["Daher", "Deshalb", "Also", "Somit"],
        "Infolgedessen": ["Deshalb", "Daher", "Also"],
        "Des Weiteren": ["Außerdem", "Zudem", "Dazu"],
        "Im Gegensatz dazu": ["Anders", "Aber", "Dagegen"],
        "In diesem Zusammenhang": ["Dabei", "Hier"],
        "Zusammenfassend lässt sich sagen": ["Kurz gesagt", "Im Ganzen"],
        "Es ist hervorzuheben": ["Wichtig ist", "Bemerkenswert"],
        "Abschließend": ["Zum Schluss", "Am Ende"],
        "Ferner": ["Außerdem", "Auch", "Zudem"],
        "Überdies": ["Außerdem", "Zudem", "Dazu"],
        "Zudem": ["Außerdem", "Auch", "Dazu"],
        "Folglich": ["Daher", "Also", "Deshalb"],
        "Dementsprechend": ["Deshalb", "Daher", "Also"],
        "Gleichzeitig": ["Zugleich", "Dabei", "Nebenbei"],
        "Insbesondere": ["Besonders", "Vor allem", "Gerade"],
        "Im Wesentlichen": ["Im Kern", "Grundsätzlich", "Hauptsächlich"],
        "Schlussendlich": ["Am Ende", "Letztlich", "Schließlich"],
        "Grundsätzlich": ["Im Kern", "Prinzipiell", "Allgemein"],
        # === v0.11.0 massive expansion ===
        "Es ist anzumerken": ["Wichtig ist", "Erwähnenswert", "Beachtenswert"],
        "Es ist festzuhalten": ["Man sieht", "Es zeigt sich", "Klar ist"],
        "Es sei darauf hingewiesen": ["Beachten Sie", "Merken Sie sich", "Wichtig"],
        "Nicht zuletzt": ["Außerdem", "Auch", "Zudem"],
        "Ebenso": ["Genauso", "Auch", "Gleichermaßen"],
        "Gleichwohl": ["Trotzdem", "Dennoch", "Aber"],
        "Gleichermaßen": ["Ebenso", "Genauso", "Auch"],
        "Wie bereits erwähnt": ["Wie gesagt", "Wie schon gesagt", "Nochmals"],
        "Wie oben dargestellt": ["Wie gezeigt", "Wie gesagt"],
        "An dieser Stelle": ["Hier", "Dabei", "Jetzt"],
        "Vor diesem Hintergrund": ["Daher", "Deshalb", "Also"],
        "Unter diesen Umständen": ["Daher", "So", "Also"],
        "Im Hinblick darauf": ["Dafür", "Dazu", "Deswegen"],
        "Zusammenfassend": ["Kurz gesagt", "Alles in allem", "Im Ganzen"],
        "Letzten Endes": ["Am Ende", "Letztlich", "Schließlich"],
        "Es lässt sich feststellen": ["Man sieht", "Es zeigt sich", "Klar ist"],
        "Es bleibt festzuhalten": ["Klar ist", "Fest steht", "Sicher ist"],
        "Von besonderer Bedeutung": ["Besonders wichtig", "Zentral", "Wesentlich"],
        "Im Ergebnis": ["Letztlich", "Am Ende", "So gesehen"],
        "Somit": ["Also", "Daher", "Folglich"],
        # === v0.12.0 expansion ===
        "Ergänzend sei erwähnt": ["Dazu kommt", "Hinzuzufügen ist", "Außerdem"],
        "In der Tat": ["Tatsächlich", "Wirklich", "In Wirklichkeit"],
        "Umgekehrt": ["Andersherum", "Im Gegenteil", "Umgedreht"],
        "Genauer gesagt": ["Präziser", "Im Detail", "Genauer betrachtet"],
        "Unbeschadet dessen": ["Trotzdem", "Dennoch", "Dessenungeachtet"],
        "Im Übrigen": ["Nebenbei", "Außerdem", "Dazu"],
        "Dessen ungeachtet": ["Trotzdem", "Dennoch", "Unabhängig davon"],
        "In Anbetracht dessen": ["Angesichts dessen", "Daher", "Deshalb"],
        "Wie dem auch sei": ["Jedenfalls", "Wie auch immer", "Trotzdem"],
        "Bemerkenswerterweise": ["Auffällig", "Erstaunlicherweise", "Beachtlich"],
        "Ungeachtet dessen": ["Obwohl", "Trotz allem", "Dennoch"],
        "In Summe": ["Alles in allem", "Insgesamt", "Zusammengenommen"],
        "Namentlich": ["Besonders", "Vor allem", "Insbesondere"],
        "Mithin": ["Also", "Somit", "Daraus folgt"],
        "Bemerkenswert ist": ["Auffällig ist", "Erwähnenswert ist", "Wichtig ist"],
        "Demgegenüber": ["Im Vergleich dazu", "Dagegen", "Anders als"],
        "Im Endeffekt": ["Letztlich", "Am Ende", "Schließlich"],
        "Obendrein": ["Zusätzlich", "Außerdem", "Darüber hinaus"],
        "Gewissermaßen": ["Sozusagen", "In gewisser Weise", "Quasi"],
        "Im Vergleich dazu": ["Demgegenüber", "Dagegen", "Anders"],
        "Unstreitig": ["Zweifellos", "Unstrittig", "Sicher"],
        "Neben diesem Aspekt": ["Darüber hinaus", "Zudem", "Außerdem"],
        "Im Großen und Ganzen": ["Insgesamt", "Alles in allem", "Generell"],
        "Wohlgemerkt": ["Beachten Sie", "Bedenken Sie", "Nicht vergessen"],
        "Was dazu kommt": ["Obendrein", "Zudem", "Außerdem"],
    },

    # Синонимы
    "synonyms": {
        "wichtig": ["bedeutend", "wesentlich", "relevant", "zentral"],
        "groß": ["erheblich", "beträchtlich", "umfangreich"],
        "klein": ["gering", "wenig", "niedrig"],
        "schnell": ["rasch", "zügig", "fix"],
        "langsam": ["gemächlich", "träge", "bedächtig"],
        "gut": ["positiv", "gelungen", "brauchbar"],
        "schlecht": ["mangelhaft", "unzureichend", "schwach"],
        "Möglichkeit": ["Option", "Chance", "Gelegenheit"],
        "Problem": ["Schwierigkeit", "Herausforderung", "Hürde"],
        "Lösung": ["Antwort", "Ausweg", "Abhilfe"],
        "Ergebnis": ["Resultat", "Ausgang", "Befund"],
        "Bereich": ["Gebiet", "Feld", "Sektor"],
        "Methode": ["Verfahren", "Ansatz", "Vorgehen"],
        "Prozess": ["Vorgang", "Ablauf", "Verfahren"],
        "Aspekt": ["Seite", "Punkt", "Facette"],
        "Grund": ["Ursache", "Anlass", "Motiv"],
        "Ziel": ["Zweck", "Absicht", "Vorgabe"],
        "Aufgabe": ["Auftrag", "Pflicht", "Job"],
        "Vorteil": ["Nutzen", "Plus", "Stärke"],
        "Nachteil": ["Minus", "Schwäche", "Manko"],
        "Analyse": ["Untersuchung", "Auswertung", "Prüfung"],
        "Qualität": ["Güte", "Niveau", "Standard"],
        "effektiv": ["wirksam", "erfolgreich", "wirkungsvoll"],
        "komplex": ["vielschichtig", "schwierig", "umfangreich"],
        "modern": ["zeitgemäß", "aktuell", "neu"],
        "Faktor": ["Einfluss", "Ursache", "Aspekt"],
        "Strategie": ["Ansatz", "Plan", "Vorgehen"],
        "Kontext": ["Zusammenhang", "Umfeld", "Rahmen"],
        "Perspektive": ["Blickwinkel", "Sichtweise", "Standpunkt"],
        "Situation": ["Lage", "Zustand", "Verhältnisse"],
        "Funktion": ["Aufgabe", "Rolle", "Zweck"],
        "Struktur": ["Aufbau", "Gliederung", "Ordnung"],
        "Niveau": ["Stufe", "Grad", "Stand"],
        "Maßnahme": ["Schritt", "Aktion", "Handlung"],
        "Potential": ["Möglichkeit", "Chance", "Aussicht"],
        "Ressource": ["Mittel", "Quelle", "Vorrat"],
        "Tendenz": ["Trend", "Richtung", "Strömung"],
        "Dimension": ["Größe", "Umfang", "Ausmaß"],
        "Priorität": ["Vorrang", "Vorzug", "Dringlichkeit"],
        "Kriterium": ["Maßstab", "Kennzeichen", "Merkmal"],
        "Initiative": ["Anstoß", "Vorstoß", "Aktion"],
        "verschiedene": ["unterschiedliche", "diverse", "mehrere"],
        "bestehend": ["vorhandene", "aktuelle", "bisherige"],
        "notwendig": ["nötig", "erforderlich", "unverzichtbar"],
        # === v0.11.0 massive expansion ===
        "neu": ["frisch", "modern", "aktuell"],
        "alt": ["früher", "ehemalig", "bisherig"],
        "richtig": ["korrekt", "treffend", "zutreffend"],
        "falsch": ["fehlerhaft", "irrtümlich", "inkorrekt"],
        "stark": ["kräftig", "mächtig", "intensiv"],
        "schwach": ["gering", "dürftig", "matt"],
        "einfach": ["unkompliziert", "simpel", "schlicht"],
        "schwierig": ["knifflig", "heikel", "anspruchsvoll"],
        "häufig": ["oft", "regelmäßig", "vielfach"],
        "selten": ["kaum", "vereinzelt", "ab und zu"],
        "deutlich": ["klar", "offensichtlich", "spürbar"],
        "genau": ["exakt", "präzise", "akkurat"],
        "besonders": ["vor allem", "speziell", "namentlich"],
        "sofort": ["umgehend", "auf der Stelle", "gleich"],
        "bereits": ["schon", "mittlerweile", "inzwischen"],
        "immer": ["stets", "jederzeit", "durchweg"],
        "nie": ["niemals", "zu keiner Zeit", "keineswegs"],
        "manchmal": ["gelegentlich", "zuweilen", "mitunter"],
        "Entwicklung": ["Fortschritt", "Wachstum", "Wandel"],
        "Entscheidung": ["Wahl", "Beschluss", "Festlegung"],
        "Bedeutung": ["Sinn", "Gewicht", "Tragweite"],
        "Leistung": ["Ergebnis", "Arbeit", "Darbietung"],
        "Erfolg": ["Errungenschaft", "Gewinn", "Triumph"],
        "Veränderung": ["Wandel", "Umbruch", "Wechsel"],
        "Erfahrung": ["Praxis", "Wissen", "Kenntnis"],
        "Wirkung": ["Effekt", "Einfluss", "Auswirkung"],
        "Einfluss": ["Wirkung", "Macht", "Druck"],
        "Zusammenhang": ["Verbindung", "Bezug", "Kontext"],
        "Unterschied": ["Abweichung", "Differenz", "Kluft"],
        "Bedingung": ["Voraussetzung", "Anforderung", "Auflage"],
        "Idee": ["Gedanke", "Einfall", "Konzept"],
        "Antwort": ["Reaktion", "Erwiderung", "Rückmeldung"],
        "Hinweis": ["Tipp", "Andeutung", "Zeichen"],
        "Risiko": ["Gefahr", "Wagnis", "Unsicherheit"],
        "verwenden": ["nutzen", "benutzen", "einsetzen"],
        "ermöglichen": ["erlauben", "gestatten", "zulassen"],
        "darstellen": ["zeigen", "bilden", "abbilden"],
        "betrachten": ["ansehen", "beobachten", "mustern"],
        "beeinflussen": ["prägen", "wirken auf", "steuern"],
        "verbessern": ["steigern", "aufwerten", "optimieren"],
        "entwickeln": ["erarbeiten", "ausarbeiten", "aufbauen"],
        "unterstützen": ["helfen", "fördern", "stehen für"],
        "erreichen": ["schaffen", "erzielen", "gewinnen"],
        "anbieten": ["bereitstellen", "liefern", "vorschlagen"],
        # === v0.12.0 expansion ===
        "Wert": ["Bedeutung", "Gewicht", "Stellenwert"],
        "Abschnitt": ["Teil", "Phase", "Etappe"],
        "Gegenstand": ["Thema", "Objekt", "Sache"],
        "Muster": ["Schema", "Vorlage", "Modell"],
        "Haltung": ["Einstellung", "Position", "Standpunkt"],
        "Fähigkeit": ["Talent", "Können", "Geschick"],
        "Menge": ["Anzahl", "Vielzahl", "Masse"],
        "Zugang": ["Eingang", "Eintritt", "Zugriff"],
        "Herausforderung": ["Aufgabe", "Hürde", "Prüfung"],
        "Aussicht": ["Blick", "Erwartung", "Perspektive"],
        "Merkmal": ["Eigenschaft", "Kennzeichen", "Eigenart"],
        "Grundlage": ["Basis", "Fundament", "Ausgangspunkt"],
        "Urteil": ["Bewertung", "Einschätzung", "Meinung"],
        "Vielfalt": ["Fülle", "Reichtum", "Breite"],
        "Wechsel": ["Tausch", "Wandel", "Austausch"],
        "Tätigkeit": ["Arbeit", "Beschäftigung", "Aktivität"],
        "Schritt": ["Stufe", "Phase", "Etappe"],
        "Raum": ["Platz", "Fläche", "Bereich"],
        "Quelle": ["Ursprung", "Herkunft", "Fundort"],
        "Grenze": ["Schranke", "Begrenzung", "Rand"],
        "Nutzen": ["Gewinn", "Ertrag", "Vorteil"],
        "Prüfung": ["Test", "Kontrolle", "Überprüfung"],
        "Anspruch": ["Forderung", "Erwartung", "Verlangen"],
        "spannend": ["aufregend", "fesselnd", "mitreißend"],
        "üblich": ["gewöhnlich", "gebräuchlich", "normal"],
        "bekannt": ["vertraut", "geläufig", "berühmt"],
        "vollständig": ["komplett", "ganz", "lückenlos"],
        "unterschiedlich": ["verschieden", "ungleich", "abweichend"],
        "wahrscheinlich": ["vermutlich", "wohl", "voraussichtlich"],
        "endgültig": ["abschließend", "definitiv", "unumkehrbar"],
        "wirksam": ["wirkungsvoll", "effektiv", "tatkräftig"],
        "bemerkenswert": ["auffällig", "erstaunlich", "beachtlich"],
        "sinnvoll": ["nützlich", "vernünftig", "zweckmäßig"],
        "dringend": ["eilig", "akut", "brennend"],
        "gleichmäßig": ["stetig", "regelmäßig", "einheitlich"],
        "schaffen": ["bewirken", "hervorbringen", "erzeugen"],
        "feststellen": ["bemerken", "erkennen", "entdecken"],
        "aufzeigen": ["darlegen", "verdeutlichen", "offenlegen"],
        "vorschlagen": ["empfehlen", "anregen", "raten"],
        "berücksichtigen": ["beachten", "einbeziehen", "einkalkulieren"],
        "durchführen": ["ausführen", "umsetzen", "bewerkstelligen"],
        "gewährleisten": ["sicherstellen", "garantieren", "verbürgen"],
        "hervorheben": ["betonen", "unterstreichen", "akzentuieren"],
        "einschätzen": ["bewerten", "beurteilen", "taxieren"],
        "zusammenfassen": ["bündeln", "resümieren", "komprimieren"],
        "beschreiben": ["schildern", "darlegen", "umreißen"],
        "Rahmen": ["Umfeld", "Umgebung", "Gerüst"],
        "Überblick": ["Übersicht", "Zusammenfassung", "Rundschau"],
        "Ansatz": ["Herangehensweise", "Weg", "Methode"],
        "Beitrag": ["Anteil", "Zuarbeit", "Mitwirkung"],
    },

    # Альтернативные начала предложений
    "sentence_starters": {
        "Dies": ["Das", "So etwas", "All das"],
        "Es": ["Das", "Man", "Dies"],
        "Man": ["Wir", "Es", "Die Leute"],
        "Der": ["Ein", "Dieser", "Jener"],
        "Die": ["Eine", "Diese", "Jene"],
        "Das": ["Ein", "Dieses", "Jenes"],
        "Wir": ["Unser Team", "Man", "Alle"],
        "In": ["Innerhalb", "Während", "Bei"],
        "Für": ["Zum", "Um", "Was"],
        "Auch": ["Zudem", "Ebenso", "Darüber hinaus"],
        # === v0.11.0 massive expansion ===
        "Dieser": ["Der", "Ein solcher", "Besagter"],
        "Diese": ["Die", "Eine solche", "Besagte"],
        "Dieses": ["Das", "Ein solches", "Besagtes"],
        "Jeder": ["Alle", "Ein jeder", "Sämtliche"],
        "Jede": ["Alle", "Eine jede", "Sämtliche"],
        "Alle": ["Sämtliche", "Jeder", "Die gesamten"],
        "Viele": ["Zahlreiche", "Etliche", "Eine Menge"],
        "Einige": ["Manche", "Mehrere", "Ein paar"],
        "Dabei": ["Hierbei", "Hier", "In dem Fall"],
        "Dennoch": ["Trotzdem", "Gleichwohl", "Nichtsdestotrotz"],
        "Jedoch": ["Aber", "Allerdings", "Doch"],
        "Daher": ["Deshalb", "Aus diesem Grund", "Somit"],
        "Deshalb": ["Daher", "Deswegen", "Aus diesem Grund"],
        "Wenn": ["Falls", "Sofern", "Sobald"],
        "Obwohl": ["Auch wenn", "Wenngleich", "Trotz der Tatsache"],
        "Zunächst": ["Erst einmal", "Als Erstes", "Vor allem"],
        "Anschließend": ["Danach", "Dann", "Im Anschluss"],
        "Schließlich": ["Letztlich", "Am Ende", "Zuletzt"],
        "Außerdem": ["Zudem", "Darüber hinaus", "Zusätzlich"],
        "Allerdings": ["Jedoch", "Aber", "Freilich"],
        "Tatsächlich": ["In der Tat", "Wirklich", "Fürwahr"],
        "Offensichtlich": ["Klar", "Erkennbar", "Sichtlich"],
        "Natürlich": ["Selbstverständlich", "Klar", "Freilich"],
        "Heute": ["Heutzutage", "Aktuell", "Gegenwärtig"],
        "Hier": ["An dieser Stelle", "Dabei", "Hierbei"],
        "Oft": ["Häufig", "Vielfach", "Nicht selten"],
        "Nur": ["Lediglich", "Bloß", "Allein"],
        "So": ["Auf diese Weise", "Derart", "Solchermaßen"],
        "Bereits": ["Schon", "Bereits jetzt", "Mittlerweile"],
        "Doch": ["Aber", "Jedoch", "Allerdings"],
        # === v0.12.0 expansion ===
        "Freilich": ["Allerdings", "Gewiss", "Natürlich"],
        "Bekanntlich": ["Wie man weiß", "Es ist bekannt", "Allgemein"],
        "Immerhin": ["Wenigstens", "Zumindest", "Doch"],
        "Folgerichtig": ["Logischerweise", "Konsequent", "Daher"],
        "Mitunter": ["Manchmal", "Bisweilen", "Gelegentlich"],
        "Unbestritten": ["Zweifellos", "Sicherlich", "Ganz klar"],
        "Vielmehr": ["Eher", "Stattdessen", "Mehr noch"],
        "Vermutlich": ["Wahrscheinlich", "Wohl", "Möglicherweise"],
        "Gewiss": ["Sicher", "Bestimmt", "Zweifellos"],
        "Keineswegs": ["Auf keinen Fall", "Mitnichten", "Ganz und gar nicht"],
        "Letztendlich": ["Am Ende", "Im Endeffekt", "Zu guter Letzt"],
        "Üblicherweise": ["Normalerweise", "In der Regel", "Meistens"],
        "Zugegebenermaßen": ["Eingestanden", "Zugegeben", "Ehrlich gesagt"],
        "Gleichfalls": ["Ebenfalls", "Ebenso", "Auch"],
    },

    # Разговорные маркеры
    "colloquial_markers": [
        "ehrlich gesagt", "im Grunde", "im Prinzip", "genau genommen",
        "unter uns gesagt", "nebenbei", "streng genommen",
        "wenn man so will", "mal ehrlich", "ganz offen",
        "sozusagen", "wohlgemerkt", "im Endeffekt",
        "lustigerweise", "witzigerweise", "überraschenderweise",
        # === v0.11.0 massive expansion ===
        "anders gesagt", "auf den Punkt gebracht", "auf gut Deutsch",
        "bei Licht betrachtet", "besser gesagt", "da fällt mir ein",
        "das heißt", "eigentlich", "einfach ausgedrückt",
        "fair gesagt", "gelinde gesagt", "genauer gesagt",
        "grob gesagt", "gut möglich", "Hand aufs Herz",
        "ich finde", "ich glaube", "im Übrigen",
        "im Ernst", "interessanterweise", "jedenfalls",
        "klar", "komischerweise", "kurzum",
        "leider", "logischerweise", "meiner Meinung nach",
        "meines Erachtens", "mit Verlaub", "na ja",
        "nebenbei bemerkt", "nicht zuletzt", "nun ja",
        "offen gesagt", "sagen wir mal", "salopp gesagt",
        "schlicht und einfach", "schätzungsweise",
        "so gesehen", "sowieso", "tja",
        "typischerweise", "um ehrlich zu sein", "unter dem Strich",
        "vor allem", "was soll ich sagen", "wenn ich ehrlich bin",
        "wenn man es recht bedenkt", "wissen Sie", "zugegeben",
        "zugegebenermaßen", "übrigens",
        # === v0.12.0 expansion ===
        "ganz unter uns", "ganz im Ernst", "nicht wahr",
        "wenn Sie mich fragen", "ich meine", "ich sage mal so",
        "unter vier Augen", "Spaß beiseite", "rein sachlich",
        "wenn ich so sagen darf", "seien wir mal ehrlich",
        "ohne Umschweife", "ohne Schnörkel", "ganz nüchtern betrachtet",
        "ich muss schon sagen", "machen wir uns nichts vor",
        "ganz klar", "soweit ich weiß", "im besten Fall",
        "mal ganz abgesehen davon",
    ],

    # Аббревиатуры
    "abbreviations": [
        "z.B.", "d.h.", "u.a.", "etc.", "bzw.", "ca.", "vgl.",
        "Dr.", "Prof.", "Nr.", "Str.", "Mio.", "Mrd.",
        "Abb.", "Abs.", "Abt.", "Anm.", "Art.", "Bd.", "Bsp.",
        "bzgl.", "ggf.", "Hrsg.", "inkl.", "Jh.", "Kap.",
        "max.", "min.", "Mrd.", "o.Ä.", "s.o.", "s.u.", "usw.",
        # === v0.11.0 massive expansion ===
        "Aufl.", "Bearb.", "Bem.", "bes.", "betr.",
        "Bl.", "Buchst.", "dgl.", "ebd.", "eigtl.",
        "einschl.", "entspr.", "erg.", "evtl.", "exkl.",
        "f.", "ff.", "geb.", "gest.", "gem.",
        "geschr.", "Ggs.", "Hbf.", "i.A.", "i.d.R.",
        "i.e.S.", "i.S.v.", "i.V.m.", "insb.", "Jg.",
        "lfd.", "lt.", "m.a.W.", "m.E.", "m.W.",
        "mtl.", "n.Chr.", "Nr.", "o.g.", "o.J.",
        "p.a.", "Pkt.", "rd.", "Rn.", "S.",
        "sog.", "sp.", "Tel.", "u.U.", "u.v.m.",
        "v.a.", "v.Chr.", "verb.", "vgl.", "vorh.",
        "z.T.", "z.Zt.", "zit.", "zus.", "zzt.",
    ],

    # Бустеры перплексии
    "perplexity_boosters": [
        "quasi", "fürwahr", "meinetwegen", "schlechthin",
        "mutmaßlich", "gegebenenfalls", "just", "just in dem Moment",
        "obendrein", "kurioserweise", "paradoxerweise",
        "nichtsdestoweniger", "strenggenommen", "wenngleich",
        "beileibe", "mitnichten", "keineswegs", "allerdings",
        # === v0.11.0 massive expansion ===
        "alldieweil", "allenthalben", "augenscheinlich",
        "bedauerlicherweise", "bekanntlich", "bestenfalls",
        "bezeichnenderweise", "billigerweise", "dessen ungeachtet",
        "eingestandenermaßen", "ergo", "erstaunlicherweise",
        "freiheraus", "gemäß", "gleichwohl",
        "hinterher betrachtet", "im Nachhinein", "immerhin",
        "indessen", "insgeheim", "jedenfalls",
        "kurzum", "längst", "leider Gottes",
        "mittlerweile", "nämlich", "nebst",
        "notabene", "nota bene", "o Wunder",
        "per se", "prompt", "schier",
        "seltsamerweise", "spöttisch gesagt", "so oder so",
        "trotz alledem", "ohnehin", "unerwartet",
        "unpässlich", "vornehmlich", "wahrhaftig",
        "wohl oder übel", "wohlweislich", "zuguter Letzt",
        "zufälligerweise", "zu guter Letzt",
        # === v0.12.0 expansion ===
        "angeblich", "demnach", "dergestalt",
        "fraglos", "geradezu", "gottlob",
        "heutzutage", "hinlänglich",
        "keinesfalls", "meistenteils", "nebenher",
        "obenhin", "ohnedies", "sattsam",
        "schlichtweg", "soeben", "überaus",
        "unbestreitbar", "zuvorderst", "bekanntermaßen",
    ],

    # Целевые метрики
    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    # Союзы для склейки
    "conjunctions": ["und", "aber", "oder", "denn", "weil", "da"],

    # Союзы для разбивки
    "split_conjunctions": [
        " und ", " aber ", " jedoch ", " wobei ",
        " während ", " obwohl ", " denn ",
        # === v0.11.0 massive expansion ===
        ", und ", ", aber ", ", jedoch ",
        ", wobei ", ", während ", ", obwohl ",
        ", denn ", ", weil ", ", da ",
        ", sodass ", ", sofern ", ", falls ",
        ", weshalb ", ", weswegen ",
        ", nachdem ", ", bevor ", ", obgleich ",
        ", allerdings ", ", hingegen ",
        "; ", " – ", " — ",
    ],
}
