"""Auto-generated collocation data. DO NOT EDIT.

Generated by scripts/gen_collocations.py
"""

from __future__ import annotations

import base64
import zlib

_EN_DATA = (
    "eNp1XVl627iyfrYXcz6Ndno5EAlJjElCzUGOevW35irQuS+J8QPEWCjUBOie0/P1NqVufDv/7/B+"
    "p+Q8lu+30/9+SfJabpA6Sqot3+OjrBNAH1pgKvMCaf2+zd9vx//9o7Xdy3fG4nsB7qnrIbmT5NDB"
    "x0dobV6mMt7evruxhc7sNX1LfYbiZ01fppz/y9QjQZp1mvKIPTgpNC9lGqhLl6m73Ze3eR2px56c"
    "793IFQvW079YiQBDmcZuvFFfBWrTi4a23LvmS2bmLKmmL2tL4+T0PJQv7ienaaBYFye7JlNVTZ/T"
    "9DZ/vahpTn3ntNxp0naCaMM49dgnWjKqu9Dgu9Qr9vF+AwAmzWbqrAjNLc71pVsWqL8pfcsj5jTk"
    "L7JWgGA7UuLwPjdlau4IwbItPP0G8ezCR336z9MHS8snu/d26p5V9xUQmgOiKN99p2SAXbut8/LS"
    "5P69PPPUJJhJnrHDO017n+dZkP37FccdOn90RNrdOWJTMn/nHgYfuguDXrprH5D9e5vHOcvCnyTF"
    "C0+rk5bmzjsGq5Sk5n/CjCWc59zKrpipL45SyZmqopUYcFmAsqnb1AB8A2RkGH7OdAsT+d9/tFP2"
    "gshHvyRp1AANLjm1L69B0jYVbc6PHvpdxiZPY26JGQg4lbIQ8qFIHi65bTPPtH06UN9bmSYCB1i7"
    "qlS6XnPDhQ6Kwf5dL339YQs0wg3sFYKu5gt/ulPsNqUlX9c+lrv26btuAKewjKmPX04Z5qgrK0+9"
    "jmtcYGc1d+nzHWYR0HXsu68MfyCLEkwQYpmMTBlnII/c638UzjTg7onL8Kng/NX1vUyyQAsujcyy"
    "QFDfIy+dfHy2j9emAdrnURs6FCiXeHoMfKZ+lXm1Xs4PXYDQEIwbd9nc0STZyB9TuXZLuvQ5ov+u"
    "qe+uHdXhQ4J9oV09KNiNV+gAs6rQiWc3dxchXOvXLU2tdItZE1HBnB6PghuDG7Mc2+eGFCg4y7qH"
    "CpyMwrdQ37xsy0IXprwogc3AF4A6aBC/10kWNaB9Tz1ypE1Dusn8O2rUeAxg3GangK9APbBCSzfI"
    "Su7rj2YYzMTnU6xuuU/ArPIoI8JDtvPZb3SxDX6W/qmEImCaBl1PQdr8QGKmQ/YcPrZNeIw16nye"
    "DFzSHxmCIs0EBNJ0/20KzusFxiWw9x6WY+3TtqlH6ft1C95WpZ3T+zdMEUBfcLiMNB4B1ln2m6QT"
    "bKKH7gPBcAvfRunJp6NGmmf7+gkSjewL+3wzPkHnBywO99cqfJRJxyDYBdhRftaNwEwnpVKFurlZ"
    "57n+FsBl6i7rpkpplo7LmQGdz1+GDWXsQJ6QhhWFA/BLpkahNM+l6YzBKAxEOSo/ORma/6RBuNnR"
    "wCssXfnegN94Xm6+9uX0csBxbkrfPp4ZDqJeqMxGZDWqPPmDOX96hnONDwerjXN2fF4ftnIBhjlo"
    "82C7WeFqxgIeOfUx1jL5AoXakQcCY8p1JUIvdVHoMsiKwITqmuf1dsszy7k35BTYuQeQpfXuw/Bu"
    "eExF6VDBPN6TzIbX0I0N/KWkqChQ0tpssGo6vYILMCw4XWRRrWPt0E2yfIkOzi3LMjSPN2O4Bj7S"
    "hJsQ5DCeMc9Yp3lV3mnonPPXDxCmYCjasdCczO4Gj1QBkmg3DdX6nDZQGzFYFuAi3XyXYQhsEtdR"
    "kXi6CRQFLit3A1lqbOu+AH2CwK2rAsIQSiSIk5qBzTp2ZQ3pEKAR9CoRCxxk9ikcMJZGmgBZS493"
    "zwBZpGs32CX1Sli7AMM66eyvejjDCdGsPcprOH0KA1cnPSAWbTNS/kuG6+gTVIi0rfcKfFzaV+he"
    "Hlrp3sA4h14UdkuZXZZJl7ng6UQLO5vcc44ZwC0hL02s+4UMEAgWVZECPImKeqgqKcvdqDZUMa0N"
    "N1mVBkW277s0LttOKgEcQD8tQDgssI6/bfICzGd8d7MZjJ84u69wk7L2EcVWR5nIAAM/gr0rOM7d"
    "xGcbyM+m6hs85m9qzIBqHfzrIMOESmdsiRlEQHk2SD8HwbvPy7b9c8z4JqMDHVGhdEV6IYP7u4/Q"
    "lXl6hTXAZ296njkMR58c0YeqhjLdCmqL2wwU5b/vuR9+VjWnpZtFdoex/wF9Z8hCyUB/NM6PgOP4"
    "cePx+AOOHZ10OzoOG5IVk2MAJ1jXTTnu0h9eREMf5QEy37T5PKpQVelez5997MFoutnxHbA0fQE3"
    "gpF3Q6d1B/g796w9xqJRw9pVOczykEhmWBXQghqYM2QasE0zM9M6oxdT2GmDR8I6bvLiIVrn1Ifu"
    "Js+PbqQGVhao10OZslBkQI3HVagNZFNHbyY9lNeRUoDTxLprWCrfbWCrfVtNnA6ccRCE+HTVnR6g"
    "GY6jfgteZYfFch3S2LbCvvwoiL3aFoNZZvNbwECuTA8x1dA6dCwuhr1zqrMiQVcZcV9tsvBcL7yn"
    "N7grjdssYeT7HzXJJttkZNSK5TxAcWHsaI3jQOCQG/9dkeXTaa4HEVmkpnJFKaM25xwjXol8h5gT"
    "WVyA6/WH861rMjX7/2bAOYYodgi3Z97WcnA47IzduzFHXSEzW+y3eSNofpTHo85tgQzebEMSyqrh"
    "a6aMn+W/7yDS/AVfp0tikx3I+dBLXACccWLWYXZBmIOJSqDCLD/2y3GTFwxgdUac+zpHT7Md0Mmd"
    "6t3w+H3MmDq0u/I+MNBarepYR5Cw+FSFU2dq8g+71sEz0LjgB/beM1z63cVq3IwDW9cERBJIHmiO"
    "eua/ZPG+RkstEOmKg5+VJThULs+OB74LaPrmgwwPTpa1FiEiLkLDRHF+5vLrqF8cIkzHue6y75IF"
    "HVOb/11ZLNk7vo6VZHQBbsSkE/voKK+kWKZ5DWCnrFNbY9fUzzyUBqBbmeAUIboCXqBHSJUx5d9K"
    "i9Dpe+kzMEPUerAB0U9/ZIhqJCbWGST8JOJQbs1E6/B3Gs38tqyXS5lGavm62uL3omUqtFfIOr57"
    "f0IPBiFhRfcRjcoUnEHr2Nyp7FUNBLsAa2EcQx4ed1jzzVThHK6L2OLKY+nQ7dM1rAOzLWObsYtn"
    "N/In0CbZwBjgqYh9KYK8h7eChvGD5ucXwv0GFWJjHuTA2s3zVkBhkzDalDo6iurMNADX/ktlzLu2"
    "ogmLM3/NUXHmRwvIYX6UhqH3febRH+oONXdUrQfl/FVe+4T/0l++YrmSBSPRnGTKfxnQ5qabuetn"
    "A6+wWoXdoQoNZVAlRSE9TZtcwcCxHlWboGwOysjt23lec4UkstvzxhSIDOOEPLvFO/8hyU37Ao5X"
    "VOdtNRjFWaERchL0ijSGj5BhlzHXjeW5rFPDzErrXsh6TaW+8svn6RclpX+flNARninlc8DpR59e"
    "IjZjMnaAETgqYBG5dkauOS2ryKKYLpffQWtABPb0VwYG1ebJStU0RfVg1aLaUVcmoNLu0XsJQIAt"
    "Li+vhCUzmgpMo4dT2hjSb+ijrQwnbb+fBfAKToqEfimmU6Zpm15tBnYzaCdDXc0o5kAGLrDfvpY7"
    "Kd2hA4HMDwJt95T1NPKFvRYOm0yxgvJ9I/MmX8O+7ubQHTRuzovMlYqDPj+fjtlmPYdyKmXWcBh0"
    "rLJHgoFuM7Pz0oDAuYvVzPU35I1BHUXoweVY9NaNc9xJoM/c0/SIHO2XQDC3PVvVPgWBWRA2zQVA"
    "7GNmSskrazeapBlP8xI+EEfDPDCLJOzBtiM80HK2Js6S9D6cFOFGj5IM/Vbo3olmzEmQkh68lu2U"
    "cNxN/OjD0XBCecnqDDp5RuDBhknfAzLfu+u2UDhUQpd+LAxMyDd+nBo/yghATyguPY+YoLAL9gL9"
    "XvHEZuFGIiZQUF+XHLyP0ONn6qdX8CcG16Uxd8lB4XTqhGyt1jzm4RX8lDCSdbkHidfF5sIhHwKT"
    "fNLZ4ARl35FYhgmB8XazHgeGQqmlr5Ar6nlK8Np0IDgD+/JKPXHBHUVNXDc9PAlaNXwQEORz+Xgv"
    "SDUOihRCWdDG8alImm7rENySVIrdYtquoCCkOye4TCW1b5Okf0maDtVpHSQoiKCG6Vw/If4wzusc"
    "MJVrOdoIEdQcn53YINABJ02dUSjG5DPBmi8vc0HCOKb0MncfKJTTTay/lL6lhzn+3tDK7cSOhuw3"
    "4p94CGFQAiFBKqP0uA4XOUMprSf27JVUpCgYek773Aor55qlq0epOC/fZfr6oTF7n1CSrXJ8ws51"
    "BlsiRGqtckAx6Kafannct4c6B7a9yCNz3w3Eh+RooHSYYUlbb+ULNiJ3fSdUfUNZYSTKnJZ1ZPik"
    "sPrZJDmtctRJGpQaMXJ0AyxvN3Z00J3pGEEIreaPXs8pRBo8alrVABlboNeZ1eHHCkpkA92BuogU"
    "/lEoSF6fisEm6ImB/FJkziIvfDoCRCuTLxBprCOrBGcFbRee7EsQQoFLMFUIBjvlaqtp6IwaPfMT"
    "+5q4tBGEFkzXLDMsJrA5j3KSCsDeLTXFI/KYkLGriM1YpOCjgqB6kZT1MNFXMhZUC9VMTo2U1Mc0"
    "KHdCbbcpPXMQ1s6CoFqXvrJ4NxFh04l4QeWjWspgOE9TmULdovfsJcmBHSEfGOSajEdeE4rdWsdZ"
    "0miI4aOAkqlp1Nh3FMj7q8iFTSAHSYbeinzfkKmheTWmYgjSTY0EayoEJ0pqvkS7kFJA6Yl1DFCW"
    "QfockWj7flTVUzFg5KYPKiaSTQBMzD0YNt9R1xGmpSA65jtb79Tgqf0wHxslw3cHLWHV7wUxsVWB"
    "uEl2gqFNw52DyH3K7B7It5GPkezeR3NJqsSxquBAnuJrwNBLuYrpab5nrE6Z+0GAZ+nXIQdgbpIw"
    "F0l3/wlzpGRglpRuMwUfjlGgRbxfaS137wNwGFI5WJ7HFB7DpgcgsNxRr1hC+cnkLrKpwKkR5Nmz"
    "QFMe0PQ3qUGGoNQbbyYEptxCcxmpbB4U7NF9yQmBcSGm+VpGaPrgqCuOOwedOZMtaqSmgZyBgb7k"
    "cwHRbCSRooZNoDj1vk/p5GUmKK4l8UIZHGsOsNW9w1jV/KBBkEwzi9gq4JRR5p1F3hXQK907eAO6"
    "nWBu//PukdyAeQ80Ba3iqzM0HNFHR50LHhzE2DCmBkUWtMOK3ALc+7v+9GRYm4c0atgIQ0biDmF0"
    "ZlvVFXeio6HLDobROej92xt2nUDon3wjKB7Vzd17m3SISWxVhtRGBYOBsagRZ/+O6wVnPXoT6+Ih"
    "AwUPM7sEXFpEmzwMiOaay7vG/SPPGzluhbPStj8cgdnFyWONg8bGB/cGTxS3rHNWZcWJ22RtlKHN"
    "ZybVbHKC2RK9/QXHOcceG1YtuqNlseiMUIHZHQIWF2fnsM3C7p0cz2Nb9eAQ0aoPAQ/NBbSWNqvq"
    "nXlUX8TR7N47jHObc92qgpVNEB0ek3R5Yyz0jGjbenTPEgyNJwPM+nkwKOjS6BCaUcsib5N+faR4"
    "dxBreorZouPAEClzcCSaAJG4UQuHIRE5SOkd+TKn/kV7UKS2UwT9aD9GWA1rh7pstPuFjCEjC1Zl"
    "OGQkqGZ42BbAPZbktoTJlBFUyXNXoW631I2qOcSU8u1lMSq57zfc7hTxoCkfI84hWhY0ImjDctc+"
    "YrOcH7T9MP5pU+0h4hXTDbhUTHU0E4gZP0oKGvQhA8Vavnfk0aexRoKIYdgAY9RDHcj6RrFBsCPY"
    "435wTKIQeU8pGDoYPg9cB68RXEENo3UCXUZjIwJ6W1Fz3xSFKsp1WxI73a+2WQYUzcP2+cVIaP2T"
    "ERfjPxgwpnTmdHMvqhpxeuvU4aaiGCVf1va6g36OAYdGUYrB7u1mswZ/iYI0z13E0OvdNUuFWVCu"
    "2+oITy1a3Qbd64xNZE+pO1RtOMXgGAKs6s2YNy2jvQh31itMOLrmxk25/McVxr3PjA1O2oRzFxTp"
    "IFDJeildafpRZmHShMwJFIurWhcZwgjFeuSkK7tdjFbcKP4fTsOeaNjWxNnBGv/JkFhN3Lrxwbjv"
    "kzMDsuEkhWHCJTV3jgakilhDPXGKSDiJl0Ww+gA7SA9hsbNvesLGsoTUUvremwGt1Y9SWsYkvp1F"
    "KF29YfzxOoXpmf2E4/Q9PbJnA2dv9fx7BbnlTM5+vIpDwfRyEJK/R00ayW7Q8GGX9IqJXFVDAG+3"
    "LBI58Hq75+xZ9zKkm0Yk4bSS51zW+0Owih2cHTQrpGKPnL5EkaBkEAMOgsm5o8nKzaMV41Yf1OTO"
    "4ND1IHeVMUukFGJmiCJr+3fdzQ/Gogz4qcUCgzgyVu81AVHkAEmrDy1UVmeCQJB4dEE0J1A8GzCn"
    "CYcRVYJPwaLNhhGNbQqQ+9c4fV1FI+EkeYLSxPoHQ7THRd6Wxvskt1A5DQKaqEScvkicFqfkrFc1"
    "kTCUiJtgFcDoAzcEfXA6SqVnhmxjUioYoCgdhntgJFpR+BMNSWOuKBgUGZJYm5q64Q+GvKIzA1VF"
    "J8aCanKUmionFheKLgAtVpmiBIzWAe1DUK0YCeIvf8QTJKlgWhtyXlwBPXN6gka7yT1WBIqNR1L1"
    "Sh0ZxGHhxazRqw6Eo4UqjU/aT60QshSCWcVwazewABY2IXly6QydWnFfIDDDiqksyAiQHGhYk7gv"
    "EBnz9xwKsL1Qa1Qb317S1LHSfIUiZobVMs5BFBFrON6jW5QLnSgRZuNMgB4NixWxUR4p6YLhgdJ9"
    "N8jBSoXL6FnAXaFyy5ubLDxMWr55UbUlcJ7NI5rzyPGtvT4b4OrXybAYZXA01ARNh8LKKSS3H8Su"
    "yNhjnWjjxY60MKMDOyTQeMnKlvisCKmU6BNjyftKaeCccpPgyEC0kh8Yim4tAiqLvmBySc6tI9Ra"
    "FWRDkIS+6jYlLBAOpbcedqAeDGQdOtmJlPohuhwY/+6WUbVhAq7TKnSh3wUzoHx0mVYRrr7QqS0t"
    "fXDqkWQGKQWCl5ixOdNo/MCAkYzUNWdUPTydX7yMlOArthJPvo7OrTFxgWN0NKvgOkZ7+YGAQjFy"
    "OuVUpKyT0Akmb2lY1VCCUjryoSGbpwSAAiKTursFGtapFQ+hINcprXbPAIF57RqWlqxM9CPu3nuK"
    "k4s9PikWHAGC+CUSZZCWEeTIvaIw5ejkjwVBIM0iQ6N1H3NxnVFF5ngsAbctnS0HDoVnVjcTQ7x/"
    "gqosJZe1fVUIWaTEzXsIHfgBwSwKKeKtJnyYwqyECoB04S5dBdtVKFyBNKb+pc4HBc3eoUBNHiAq"
    "g2ZTiB5+Seo72z0iBszTxMkQHyNvMvTtWziND4yYi5tSeCRppAABlZuaEHNlSJVf+eXf+5aS3LCl"
    "UtuStutxYopE87FiMfJJMTmsj/5hdeoqGiQjVBearz5X1QnkEXkCxNocdE+RVoV6pprypKox0xX6"
    "5WUmHthalYx0crRux+BKyAq4n/YHB4E94+V+YcUGV5EZeIcGehoFp6NA0X57EswZmn6oHqXd+6vL"
    "tJhyCO4FMI1YS6jtBWdBvzFNju7WUR9BH3NdQeA5jT+wS5JbE5yUq4x7TbvYIECMQaGrIsQBHgU2"
    "AvMHB830Js1pWbZFRYg9MdoPAV3LjqhFp1TNo5knDRuUruwpkdqlUWTXQ5ZYjGPAJ/E+zffuscna"
    "mEM8o1JvHI7SWcTJp6w26muh2AZ0lFDIwUGRFh1h5TG4E4PgbhzL0xmWoE2p+ZjAeXx2UxkHvQMi"
    "8GaM9F4PSjMcOHPSJKvnVN8IW6N8W2SNJK+lkSB6DLUZJVvuk1vhKwbDVYln6fSWbd87S6ZUFck0"
    "Z/S81laRo6BmON8LUB2E+u3D7l4BacyPNwlkCEhdu6Ie7CwbE+ShSbQ4ZYMKLbm5j6Uvt1dVcuuN"
    "oJvK/mwSRpJ+WxoPk3kxnffIyfmeWrlgQelnkQAXSum3UPWDnLoaanIQwB8nEU8moZVviCE48Ca1"
    "rgDLuN3yFIOF9gFMvgEUNM7tH7MuT1dX1txTrNjaB/JE0Lq747RtAUnrYUU3Bhc4Uha1ClPqinEX"
    "ZM5fpwvx2XCMIxSiZ3aMZDgyyepinz27wjofXT8pPW0Pl+X3hlXi/M6LwrgmPY1IJMfbvFvh3zPS"
    "itd2ldQcDz6xUAsafk10B4YDMt2mbgUX9LuGdLw9gmuNNw03nVK4iCC7N8QrUwRZl8d2Tfmydn1b"
    "lWNkM0tKaRnjjeVZJFyUNzHA0t1hMdTLkdex/YtcljNK3pQJoiveiS5iwbtijGfhV22AR6I/qKig"
    "qhZIQj7ee3zJQ8q2q8D/vKONdCLiAICMv7Ctv2ath8LUOXHC25aoqHoeas2UgH22zmTmJtdyUX/h"
    "qgVQOW3oug0NBAQxutRECRC404N9z5x3gymEGabUCVj1KF+BvAWHVScptDPioyp0S1S+7CaxrCLv"
    "k2/g+Cj6DTv9mhTzKXCkQy1/UWh+DY+lcDBwuapG9Eg8PNAZ7+665le1BINx+YMdgtEayqVL+/Sa"
    "BiAjVkDvPLl2qdoK6d1kAYCk/1070F0MYTNUW/XoOpVxiUUuOEEOwJZFjW2MiGnHPb5RxtF910Q+"
    "6qvejqC3cK4SJDZlTEIVmj0W2B6df4Bvdc382ooCuAfoatRVotXwhYbkTYKAga9pOYCSgj6AoEXs"
    "9oyU4EsjnILD2d5F0PLzihJuh0ukhe7AkPGenVApy49UqSBtXliRU0h1NyQaoWbYsBmtFVoAZA7Q"
    "YrICe96A2BMpoDfApA1/d0P2VpuJLhU4Etku/gGol/79UbdirHC80vMJ0j4Jqp6tErAXIMmr9xK0"
    "P4HovQSo3voikLSK9PdMfRgmsNfsLAJd7deQhjpAOi43pAsCdqAx/U6NVQDaJ76okrxC89XrPOJz"
    "ar42uv7aaVimZCwHascj3lJo/OTrjVr58EDVO3bnC/is/I2XHyVgQcrjQ1l45Rf2lPgP7MasQKd3"
    "9UN4ITyUOZaYEWgF5QIH9sLjA6R0uFTfIfXyW11WDD2YVVVyhdm+6UZ+mYL2kYJ+JVactkieUI0h"
    "dLcbY6UU4EvJQpKCXIgbiWOGRF5Nnmid6C1CCwoYeense15br/8rY1j0qJIi3bO2tLzKI0Gb9nRP"
    "p+4snD5Pk1GVboPK/ZXwgI9heC50GLTmkL051qkGNiD9SHrHl1Y8KS/qdBaJxq/kdKIF6XuGkp9B"
    "q5hoS8rnIEHf6QkOSWeYozLAEWPy3i/HaqXn0zPQvCFe53MoDuxYtN6AmjwasKCaGmZBRKfYjuig"
    "R8ei9BNgdpxMalg1nF43+lma7U1mUvVeuEmjwmN0xRXvvBMHsLF9BjBeEXAUI4e6ZQ2XXjSHbvcv"
    "GzCO8hTwcFvxGODKiHIIGduBeg6fwBuwow2j1strh7G3vlpnRV78SsOHpls6vSQym6G/GLslB18F"
    "XPt1lojLMS94RFkjH47NL9ItqnL0EiQrA2t7I3+Ttn1WaF6nR6/3XBhCMYlephSfE6Op70uTggqV"
    "2hwqPAkS62Mkuru1VHRPMWJjOggweTCtvOpAWuWkoS8E6AjPCqg96qhAHQ4uIJPqS8JhCAqxqIJ4"
    "3KlVFW864bmBHjIjyU8BNHLgJOlwI+ksUPH4FdNp5W2iX44gwxJLjlYhhT7eXWsU6AzqVx4efXmx"
    "RUoLCq+yUmKPs3sxZxDCFrfSUXAu21avQqRin+FIOgZRPnnmcUX9SvxUDgWDEKgqsL2x6RvywNHv"
    "RVsGSd/9pjTuTjWdOfpjmxxjPW6skwg3eWwieqnOVU68LWKgLWcN90AcsCMf4lgEyQv2B53ZNeM/"
    "V3k2FccKxmjsm8Z9j/m7Bj8CWLEwZJb8oIfomgIY6eKdL9wPWuIoaY5CcsIFOunoiYf6JpbDwbty"
    "DnCblsSHjkHuLnHML1Pjw2AZjtCF8WC4PFc5dcRRyMBHfB/hRndVHR7nziJiFgg+YpBntiiXR8WR"
    "cY5oaPpU4e6DOUZcB8xENuW7vDlitZ82GaGibVb0NVWfeJ+2zYC6ChpTiMSMmSFKsm7GtsY2Ky4J"
    "Xj7LqIaMeHYEb3aE49pGPIyyztAx1rVvPXV1bjXI3TsLGWwDCJR5qjKENo8VWC1izPBe/YvKzP9X"
    "u+cY6Vfotn7PGfJyLxI11N0KPahTlTY0mOD3juIjN+oe9wqcLlC4vaARqwqrFaxeVQFNQLBPrY/o"
    "UyQTqW0QSldOIbqzNMt29YGcq4yN7bnOtObqymRmD3XZ0kpQWETDWNGQvM7EqjZeD8HxNVvxfFK6"
    "coHsFLXXFNBgNJnIccnLd7Yn9hxvSjbzBL1F/HoU4Ds4Fb5gx/dx7fu3kMfmIgpnkQtZluaAiXiD"
    "ghxsevSj403d1MnhwzvaDkFEhr1YMeGGDu+ZB6rHapqd4FEsRZ+bb4AeQ5f4MlQggEtp8UVgyyJB"
    "ELHqYhAhdUwJQUZ7M9rqoB8CqBJG4UJ6a0s23HGbF+N1YRTrwheT2psKV3js6yWCPt82J8xJMKP7"
    "owDJfYgMVDFXBwHrUDAtOlk4DadhP6IiCx2bw7cYxToL/TKiB5Km/TkBvhqj6k5o4rTNQNtJG+MV"
    "YiZGhlhwflWdqoV7bLqb+V27N1qmLUijma2fhtf8JOZY7bv330CMrI75hBtmlBWweu72nlG9yCAv"
    "guOVhNrxGTJkMIeI1etXZdELeZ2peah5iLSR2Gl/DpiN5hQL2vuOjqG9HqQVZkOx1loJdzw4jR0M"
    "j6U4GF3xsXAIfAv9qCRVkA1LM7Hk4hpiQOOaB7hWwasslNizOHYCXEn4VU4VINJ0z64PdZwE6buL"
    "hEwcBQkbgdLf8m6x1IDB9yoFEbKO4hvcv99XkIitgl+admH6LBDMExmkiZkTMvqDQgxcst5j53Qt"
    "7x/xil7GGKiglCuUrvgOHh+TirHkY+qwwvZUAJmSy5DpzTCrM2CmoBwcM2dgVdKbx0BSOkDC+wCC"
    "+IXsD4WAORWLERMMX0zVmTgqiG6gRn18jzuIBE1s4+xYsCwFFENIGg1CNxQfUQmWEMOvFvqHr8HD"
    "fCG4TKw9fjqkR9vJofrBAEXrG0mKlnWhOJkKnPNi4hjH1eT4OJFCwcl8NNCMdQeDtlftA96GGAL0"
    "GlsrH3BSXy1SfBQjE2HzQ4JgKOU2ObySOy2cMgMAhsKhU0CRE/kAmmhLMFegsYyzItUDOpe+lDaK"
    "iZ8CzestMflw+omOoT58c9WnB+jZwPACwIcgFkaogN+GPwli/aeotvA8G6UrHULKwPZNt1xjmyeF"
    "JPrI4wfaab1x4EGIH0BrtfigMKsH+UHWEt8lbegXp/B1Vrm7zj+qE5GP9zGv6CbxZ1U+34n1MAe/"
    "rWqwuHQ3FZE/3umPSvompCm9s9gTY8LXdccShkwmpmcxdFCC3i8bY6YECPB1Zq5yyeECB2NAS00o"
    "dOGLI1SguxFz/fE808mzYgCKfwGK7GKHo4JutHOMJdRGDiMBQ/RP87rEWAc6Pggy+joJEK4GMKCx"
    "tPLLUyQ1rMIEzoL5UypaCqMONCKakTCWPdrSxrdwCsmfTZFo23WmQCkY1FXDkgnaBHsTdkWg7XlC"
    "CHFVqlwX8tfXh9XJMzJ6pXL4XRnNsC2/dwyDGLpg+3WLoJUmi6QtcbWs5yoryFMV7EvEPzmEg4ad"
    "mexiEb6Mg8aBiOLNAeSZW/z4/hRbNZOf0z2aMPkmHwma9eykBkS4ny6Po2fU7+OFjEqRMbSWokJG"
    "pfQbX/Cj5+hgLZQLWIfHxYxIKED/k0iF+NMBX8p7DK1tU4raTW9DjLkeHPP70w7F++T0cB4F1M6l"
    "f+q+Mdl+SNYdkXIMwVVF9msA/jge/TqSx7D9837ryyWRVDgol0VHw3gvK4XwsaupSdMFWrP4KY5e"
    "IexayoL3vUXGZLDtyh9mHiiywTcw+DX3FX+u5EgFw6OGJwPrZToafgcBZ0k19rjnEQMDNUbTP+WZ"
    "1ccj64yKJ5+2mS4+1hn8q1V/yTArdfAa1h2xVYeNBxtczK199A4qHFhJQEPM3aUztO08WBmv6iQ4"
    "LZ+ZLxB9J5zX6GrE16U9faQ0/0iUTgR/E7EDYDNeEo9CAHp9yeyudh31tDKKcppfNj4qbMtvn1f3"
    "dZFz4vvvZtE/CgBimlgF6Cf4ghuA0tc0KeNlZycox4nflGTAhYWzQv5UoUGVW/akaHgVT8spTRny"
    "FweLtqyHsaTxZYfGDEPaREFzl00BYaA3XFNdLLB62Hbk6SGtAbAkth1DQ8Dx0dFILBVcPQ1kuLtB"
    "DaJnxP/IL4Qs95Gd+mJbEwDYSnEfOWOxZbzPKQ7lGYUFf0bpqDk5yuKorOOpFhdHMI0xluRmIN1I"
    "p0K1rkdF7XfA/J4n3z3o7Ud9BKglXSsm22zv5ewtOrdNBkdWQFv6+T9R0xxON1WV+KF7WH82zXNy"
    "Gx7OKPouRvUsTLRI9t0ka4YqiKmbU6FbIepp7sKjaGz0zfGd0RvFgvHDCfg4PF4V4CdXd+/rY6Z4"
    "DP5VyEuiX3ydJNRuLmXEF7HSIvcr8AdMF+DV9J48/RCG/ezFleIDW/mpkISamV19I5uwhI/jTR8U"
    "7wb9sVOxZQZ9nZ95NpcSmb7eKH7UyOKKilT1+FaSd8PsuS5gSm/sxN6RxfhtWuUtRHwB7Q0f/2JL"
    "KUWicgov4M1LrTID1wFI3vQ4cIHq4Wf6IS8k5FLsJk9uw86zuJ3w0aUsSxmcUDEehiQeeeIab5DJ"
    "E5ZTSMOsqel0KY/4MDN5nljnGe0GviJ6cgXILxUBEUwUXCXfHTQtcyphmGOsyJFwmwgDrDmMOj6M"
    "hIFI4XGaBqlG5+bAyfjyzJ4hb6jhKGh0R8sRhVIjblx8M1uFJP2bLfxQ8/8B2t76Gg=="
)  # 1578 pairs

_RU_DATA = (
    "eNqVW2t2GskO/m0vJodnMrM7DEnsXDvOyU4Ag+lgutlC946u9En1VjWZM2dmDPWVSqXSq1Sivw6r"
    "vunb4dewHl7u6MNxeOqPfUtfHu+Wnyb3fYroL4RYDc93i0//5GPDZnjst8PDsMbsxacvxexTv+3P"
    "fde3NLosRvnjsT/0H4R491wsPs2NlR6A2vfN8IsQs4JWR1zsidc1+NmDWkvfPmDYoNnvh2fij2jS"
    "6PSe/jgTs8SwjtJ6tJbn6d8CcaUvLrTCD9D/bI4f6B+SH+3uPGxEBsU6HX0gVP9HOZf1FgXyQB+Y"
    "qyCnAkNS6gxaswIHeQ6b/g1cTU06LK4OZ5uuStQamrhyWEIRrRfRnniEyLX052M6tyWBQGVun9mX"
    "GE3c7oZn+vNMH3CeEaUraLGky7EdtOwCvZkyhxcsafL3bzJ+USKdnFw0wrLh0+iEy2hEzvMCjY73"
    "8jlGkXwvtBc6AznFjDLZBNbdWpL3SN4xr/CUWk6MIGokseL7g/K16a8F1Vzv1W4SlpwFsTGJ1ElO"
    "sscaFrrGmnJydlClSlyzV0mktxihzLq6o3//BA9k06X/PQ6/IY/pCO4QGwNBSLdVP7c0k3R8H+kW"
    "UV0NL6RjG+FyH+skJNO/wW916kWXCYa9wy+3Su6vAg7atsMONnJiCY2GZHBmm6b/N8Or7C/hpMOp"
    "si2fncVH4y2ofwyv8B3u5JOdsq8PshNXtL2p8QnOW7vsLhv7jpWFu2wUUiS9wUms+UuRQULhGk6N"
    "d+CiREKHNeWNJMHaJXvEXjoNYW8Ox7x8wJMszfGCH2jGwsSyp2VN+AbM3MQEvtSWwf28Qm8FfWrD"
    "DnOMeG7Y2xE6scVOvaY3ITYf2P+p7mbjIgW1vnzu3seHB3Caz43itco5pyA87uDfLqqTORXyvOSd"
    "RScm95qsbGvzP2eIdH/LbDTdwSIdJUY25BqcXau3gBnD3MT7QbYfyGB4aOst57OJ38LOSK/6U/CA"
    "KSaz87lJp7TmWYXWcfjKfkflY6N+Eo0H9VUIA+zTq2vHMrOl4r5ieiPcVbyjTRM5qK7dwF9662UV"
    "OOoGHh1+x/ZpxpFlZQb7+h/4sHF5lYFK4+bcRhW5agVn5oezCpZzVTn3Ns0HTA7EjHaEyqNKbcZK"
    "MOEENOkj44GttNCNQsMTFGUDIWCQ92hcLmYhk7xhVmKISgjPe/VgBgrb4LVgWZKtIaOfGGjxh+RB"
    "6b/Pd3PK9uB6T3AT5tktCsSDruK8zjxHsCRZ5nRmcqL5eC1elsiLxA1InWaoj0wxO4553n+mY+5+"
    "dcUqz7QzyZ0n5b6T7IzGN6pErQoD9HCToz9dxo/dW0giv6cc8uT2ZVK7wup/Sb4l/Ns4zbUbjpB1"
    "HPk6umuqDtcpNaz0tAt374FC/FC1HdnprIqteadJdcaVd4I7cRVTeG/OxiInYMbwuYkhg+ezKLLZ"
    "TjPJYgb2fUROHUc1G1tGeguVxjUTk0gFE04gGmdvzBlHZkx69CKTnRhz8juS5kwW9Z9y5rjThyzZ"
    "osna8xWX3Afl58z74r/UdugLFuA19vSnyCfODEw9Zk0N9MHHWJ9f5Zgb8hIfMHzDDtvbkWNq4eF9"
    "cGrw4yZNluewqq64xseDlw57ZQhsjwuyy1JI4l9pc2etR+SVnQzPN4FsvwbK59Kc86iNF5QkHWmg"
    "BJqSGLe1qclDJzcaHEuLbPZBfDGC8K35t6ojkKeEBm9luAm6WJKM5XudGrNZo7/xLjUXyxDIX9+g"
    "UaeQlW80aXwhIyv4mFrjNTp7uXaFrIc91/+G34h8MxORnU503lMTf4A/f62ueNbc2rKVpLDWxbdT"
    "dRHIe15DJK7gg6FqbcfxEynH36wyvzlDs1WnDyNYm6fpzVkfqAs8JftA0KDUhjz8n7sogv6TjhjV"
    "t2U2VyM6R0FXXYnmbyX705g/y+b+lJuhv8/k4w96bXaln1cKwVvEh3wHT6ytrmYSrb8nbWHfd5A5"
    "O9kowTt7d18KTJlXL3NMJL+FMb+o1WUII9POEKFGiNPmYv8LmdzJ7TK5ZyP/Wlq4kEFqncOkBVX6"
    "iPJ6d0Oy0HF9fmavibRp1e+qiMQTVXZHWo/SX1wxn5hoKzprBseBVrUirYyko6U0ZxmC73dsbN8k"
    "2uCFIYoSOZZwMEeOeMLNGwr7O5TDGthJUndYGIgz8gh286ojBQLa7DOoqYG4Itql2mxQivPaKse4"
    "7cByQtZGJ8LxY5VwzVonGpmOBc+gniOfe0Gse5JsR7QnQxi3NORu02KtlXgi728lvQl2X8zgJEhO"
    "TfZ/5pAEV7EXm0/93tJAJF4hHy09YzHf8I4FlWtZB5ezL5D+FhIqjfGNBomLs47UYy1GsJYWzOr4"
    "SCbjHASvTXtxbjpK6zw1rYjM6yjLA1cpblB1/gg2NEI18DgbwWV13nG0JnPviWbWace512SEqr4A"
    "O7m7KiqH0ybX1GLUfCEsaaT2YCBgp0GbWUfh+tculQt+ATU+mvo9vBHYWPURD85LVSjmefVkhF7M"
    "o8QNrU+0lh3NDURUwYiiR4KJ6vZVCsQD37auPqakGPb1rurykeqLSS+NaBIdMNlnevG+Zvl4xHEx"
    "Vuy4oJ5pB25SnBSwb+pwAlIEa21fJQGXpksTgq4qNR138jg4SY25WB6yGcpjEKdF1jYu67FQD2pS"
    "/JtV02iOPMUXJG3OZibmL+hksVrqpRLggHvLbSE+x1FkVOu5hazr4vi89JwnN/nZUjaxpo3/RnU4"
    "uvkVpQfnTf3FSHZh4+RhPZzECKqo9FZW3tTkUaHdCK9w2qespldfJdfaiVgK3hhj6kYENHH13L9G"
    "1+6Lmdp4HGsr79fet0/ufeltlOepjfsvNM036tr6B/FmUml0+rnRx4s/cHZ7RzW69buMqYJ0+cqs"
    "grB3o3ZxRJmumgNNb+ByLvk+jNBYUJJ3XC78+Pwg8J2MWPlKgmCrTToW8vEsg3ScXTWdPyJJbi0e"
    "a5icJ1Qr+Rq2QcrW2dTysqqxnlT+ulpWscgRdoUzoxJtwEXXDCHu/upr8vHYWM0VVtiEszIqqcn4"
    "GK1JijV2pjnVtv/Dsr5zZRjXl5WMGfdnjc4RSt8sHI2pQSNyMI4Hedx8QTDU6nuH957Wyz9G1FLm"
    "qPtGkNXLSrnqVt4aOHJLBVqi8qPqPZ/go+6jS+W0qKEKWdSoRdUP0eoKzubREgd4pMlPI3cnxqjN"
    "Ve83jAllrfrNhnFS8ZFVt9HbRnkE2DMSwwa3nDVezly9ysZrZLlFNyusq48wKebPAmov0nbbpc1j"
    "EoXO7p7h+lLCO0ltXsVqiP81siTleS/viMjbFtlY/tYUyTbgiBueD/qV8jhkEc1wfSJIhCWy6jlA"
    "q7axS4k7kvf53jNk+bAHrUlRVu5Uxe4hxQO/aYeTylatPwsYu8k6RJpERknVrEN3LNF9p/V/a16d"
    "IaLGD3zBGlLW8jpETcixqa2ld74W2UtLWM//TpIg/yRceKFpBWPrn+acbCiyOW/BTdSaWMNJBmlw"
    "mVyBpXXEe6OU1xGkdHgEL416sdiWCAdxZqU1hIvYhzbZjszIpO/yC81H4paYqs+5gc/seHYfp+ZO"
    "IXOPmTZkhQypOgtL6/0y03JtrzwaVztvmegViD3CX8xJrRmS27tezg53qiW+cR4irupiBKGCOzE1"
    "Gu2tTs+jp7NCBs/ZyjfN0LL+IXwvdJzMw1qparnOibuswHJxFBLXTWHC9f9f+YQuvkb6qp2F/O0B"
    "9zzOJC7+/Vv6qrbqq9yMhR+LQpDrOuGyS8SVrotv5SDEZZ1Df/826lKNv3WFGZ8FDQ++r9jvlb/T"
    "OgJ4m+Eb7QSF/BB53Ec6nVVUH17eI9PmTPIiNUzRDKGOF0jX1H/U7DfuRn9nZ3snpsmdiY4iw/xN"
    "In6nw0fVmigbRQDOvr9qawm7NsqHwxhJ56KuexN4wpvYVtBxh/tEdyiVkRPJkn0Wd6N5qbJ01nE/"
    "lFZMtffuoH3c3F8sTyjgqrnzuoubqftlABTIGkX35UEefcJo5yrGKnzUQdd2FyFeEqUksEFjOKxe"
    "KiZN6Py3goOB1C7kjr+wxuW3JxLKSVngAXcivzizihDcUt3CPTeqzzVkq27Q9bGnsTptLkprZuEW"
    "uLyBMyoBdXz2pjeOTTqK3fvtCC/jN8PxXaSvf+PoejfSuEzLKr/2Hn0PMdxXpqXvN7xaGyhTPiYy"
    "ba5NXjUsvL4bbhGeD4iW+7LnqpzF0tdK8bTGc1GX12rUR+1dxBV/t6FbysL6Wqmv31WRxbtyff2R"
    "vrP6rFKbxrFZPfNNei9RJl6V74l2nXV+a56hLbObc3b47c27/jrmJl465zkvCZ4prmb6eIK0YSV+"
    "OvS91LsC52NzzW7KWzNWXEnR227y6jYya6wXcnQ138syGcXFv96byq2YU+5QL6/8rmNRYNPqfj6a"
    "v8Pk4yxP7mJ4jn/RkGF850Wowifj9V+QTSR6ewOBj4gqlGu8ObTQ1g5PIr/cLwVHZuWeYjqOHz/L"
    "0ZliR6ix/h+NnY56"
)  # 408 pairs

_DE_DATA = (
    "eNplVkuWozoMHcNi+uRT9V6/5ZiKAR+MyZNN5zSb6UnWUKPM2FhfyQYMmVSFK6HvlYQ2Thc0WKuL"
    "jx8/y4aG+c8G/Fs+zFcbTLNB/5TaBf/VanPT7rbhn+UEASm7QR9lpW96DDu9a6nZ5WpkdE20yqid"
    "v30EoporKm1gNEfwt7aj94AuZa/mP061PePUkDY1frG5TBBI1xH+KKeRil+a6vnVRD8/S8NO4AN5"
    "Shp4ruFRLw/K+TuNX62EIMrT2IgxPHSk6iASNfqHoQ5W4apVVXK4Ruu0BLPDFrXrBsHM/FrQJXmr"
    "jQ/pZUSvXHgMFDgBFovg8yBgI5T5jJ1gyeL0M8Ma/TDOCXxBJnWvqfOq7+C/4Da5LkV0kGki3aTX"
    "5ucI6pAPReJMSsEPaD/5DP0oJTqkmoHn8kaGi3cr3BAe+C/wBXRruGXVCDOpWECmETEgOUVcpBRC"
    "Uu3c/LpLW86lD4o6afCQSHBZsaXouaaq2vnpmhTSg5Nk58ROYqMFA31r1DcU1x//lVxFi0SKdv5u"
    "NYmPFWu0pMXoKUd9MKl05w1mV9p7TUHUNbW6EgHajyGkqL7Bq/5RIMkFmp9xet3BXCIWcI7/oT3y"
    "OQhi+qtg5+kk49W8GXuX5CU+lQ5D1irLDYdd9L6zy7Rnogd++jD2EkKGuzFMyUmubYg3CcZwyWYF"
    "JIbM2vUo2wdxOYpt3ALnI96R8VFwH6wJxnODfqNFvVjJwKAqg4f5GQ7qd0Xo6EH9sBNPpR8moyxT"
    "SEsfZeaEwVHgEQ03dY/uF4FQOwrwiE2CysUXTuX8zTMRk+rRqqUZOQ4awb2XhC87yc1ol2Ynh1vM"
    "NfdGPIDnOkyC86ZYK53hDWGy11Jngl8DoRxk6ndTKu01oPK2lr2BxDG7WDZL3rkQR2Cg/g2+Yzon"
    "c3+zJRUX7Xbgmf5/VGsjLwljqouK4euD/lOaQvlpjTPx4CGRQuH69bJ1mbtgbayn6WP+MXk8bSOX"
    "lhWwNd0rPy2br1WplhPIjRn0d6NtPMQAwC67StGRG05YJ04YQF3TCT2VIzcYBmh+fXU+7uOlgFGm"
    "uKaJ3DgAh44xUilvorVufoEUK3Os5e0zpZMMtzjh1uKgkVuWOX6NWC6KwH/ccBO/HLD9TQBnsVmc"
    "586pYIb4xipCi9xgh/jKueys6dWDg7VIp5uf/b1OLLn733Dt4+JF8GkCrgj3m+6alp28icScS1M8"
    "3lK7QMchgjj8rlt1c/7vzAjT0+OyR/1AzTLh72WvTbpzp1I5PoM7kM8UCsjYetzPJZPV7T4HsGtG"
    "14WiijdVzMWvGnl/ufRxTSDkaikUDRUTlT/EktLEtOJDv3ESbdIV6gCYpckjuhRkYEPIBXx36sFu"
    "Hx7IAR8bmJ5kDzdjfrV6AbDD/wIwNJ4Q"
)  # 125 pairs

_FR_DATA = (
    "eNptVkuS4zYMXVuHmbJlTzo5Dk1RNrooUsOPqnOjcRazml2WulgeCFKWO71wlfFI4vsA6N1nEw5h"
    "/W3N4fLtz07+0TT7kJRLwP6omA5Zk7JALg2x6wPiuYomRuMSGbvDJvVucgDQd3MwbgjmMKwPTZG8"
    "A/q2oZOJObAL3zdIexc1GadNsfmEpzmZ4liDZhVSMdoAcpRIJVrMi+nZR+DF8mkDjbupm5lMCfbY"
    "qcVTOFgyueRDRORD6VTcEMCMoxGTIifoUuJpXyGl9foz7u4MwdP+Dbm0PsL6TyruCIYMxiJOJiX2"
    "2Kqi9K0B3uQlSPQVWR8LDVuWKjhQ3AV7bvCibCtHReClRH7q/p/fZ9oiXa0EV7FowkLF5rFB7zkm"
    "hs7f/uqQD0SzqXqrQONZX+U5+IlpU9SMithYQIRCBAFGVUOr56g17c/99b2WQmQ1z4WCfZURM2eW"
    "IxQgmEmFH0x7tspEx1+VEpO3pOt7A8eQSXKzu4WyVVYJti/jsbsF5YZnA2nxtKLoBh8ola65NHAL"
    "6Lxda73QN0RNcy3cSaCD89M1yCvzkWB+EgrvO/fT0UDjSJpKAU6vR1woaz6kDq+PlLsZlOSjlHXk"
    "kAseDN5M8KSOgOcJudFm8LEcnHYH6OdkokR/3ONICf3IFV8fiftEjixV9S+oitFrqvpfTrS3Vl19"
    "qLV9OUNOF0OWZxaHYlWoXZ8TWYrV0BMO62NGfLnUYQcjcOdysf1EuY3mFhpYPXrOTAt7UeR0rlNn"
    "f1aI+OUrUCd8fYDJo1MNAs7cTcDvUCZlohGJNC1jeSjdIM9Jyq6csn/Hz3jfDQhqfZh4MNNMgbXI"
    "HIITMdukShzaZtXGJL9nwxMM3f3grb9V28dOK54H6b4+fKjgqePyB7py3yGWxViPRp3a8NmdKqi0"
    "5IOq7ciTYYGi+NVLGEOJYyyths3i0RjV5KX7dHvIQckY4w63hXWfH/UcMbg5IaUJGy+hE21tGVRL"
    "I6bDSA7myMgg1ezZJy3njtwCrsMxMc1MLJ1UFEVUkNt5DrSUIvdPKF8t6QrJiN2gc9dGLPNfWVN3"
    "nk94zLnaw9rD1fiKnroB//wtNw11ArZU7G/qO/srDLY0qbRllSOpq4Wjfha+B+mcCTfiGes8xrit"
    "+cbKy1gZJMvIuG1/XlgIZkE+76ICss+pjTYn41FnK+kuUFAU/aaKXVt/hu01ij7XqQ1pqezDX7Co"
    "zVAoLZ8X6wOe11nJmMJ8wJ24AQE890E8ZRkzkidloVCCn1BabPUiaSVdcyWO0fFXQX4Ccf1XKEO2"
    "TAVq5Icsc1vaB2LAVmS73OQQ4YUKav0ljJ+YcNuHAH8wMbAtW3jqsZRq6PxJUNYJ2ltDa1mBZWtv"
    "ne2vcDQXkJcpuDSC4x8yfv4DO0+BYw=="
)  # 128 pairs

_ES_DATA = (
    "eNptVjmS4zoMje3DdHV7meU4MEnJ6OKi4qKq7ttM2IGDX5NNqot9kABlecaBAj6QBAE8PCgHB3Gn"
    "jcKEy2+/O7183+eGOaNRAwFnAVTwCg19FTwIiB4JyDhX8E3AKSRC+brXjkHMpq21ScZNZvmvoZOx"
    "zccWHYrvxw8Phhhsc7PFFMQxsCPjTdzZMhJ6evkha22iUdfAgTQkGZ9RV+QoCChlUuCwGoBuApW3"
    "iBnMI6AKXQOba6do6s2mvXAKFaLA1ZX3dMDjgCZl9s7gFJdfKqPivDKmMW2z2C+MxqKZty4i3Sbx"
    "1wdkih2yWfP3bUWTiTPdxyGsW6fwEfi2jnyUVvXXvbVmbvm9hJZOWeflKzr0fEqwbQRUYLhX4dhW"
    "a64ObTlB4uN1QX6nUn1vkWIzaI7qCorCHKKk9ijAFb2CCZevditjkYoU7wxlcPnyAyRM7bIxgq/F"
    "DTGD7Dsz2Pl54uXKfln75Y8zkavGG+AjxOUGd8QkBZaj6G6EQwKAVeSUi5eKA9dC6q+R6O4GjcNy"
    "U2jbw4ESwrAKxPyM1HJ89cYClsileuIop5X5YpwpX8Wy7fCXjVgFxAz/3GpxfH4lVZFSKCZwk0Ux"
    "lIwWP0FabGuh08HTKXG0NVGxJin624OB8lC8Rt1JHupyTYafa8F1J/HWCLVl4ek5iBHuYf19pyPA"
    "maYRx5ef+4Sjb4mtMsd7WvVbCM+Mxjfj256el5AECC7WPB58fWZr56pHlsUHZnwTcH0o2MZORlUs"
    "VArLosKIhZkZNVQWxhU4d0CbbGonr9QT/MHt2313HRHCOQXuQkqiLLrlF/V9aA8kVaa8BmvDLoVE"
    "IoQUWvOoqO7oaHhQO1QGLL8dH6L3B7vcmnRMy5+LZQ05buB1f5fHbmjssw0McSRh/QRWPaSnR8+M"
    "ZjuVtHjqZ/2PjfSJ50PaXanzfEhtBPah8e/26tXUmxTOKJBpGZL3M7M7FokVukMiwI8bkTLlKExd"
    "Goce0R4tp72Ok7CzZpSweP1eSIf0455oRmp2egEywxlFn0g4yhoNNbSvLUSPLV02jxWrYohVLqLU"
    "iGQffA7rqpF3LCiifGigeaehbHnSJiRBdBeZzd/3NC/CJXVWnUi1mvCbLpC0dpicyEJabrUNRY28"
    "CFT/I6iPLvKctnI08SKy9NJyxpiL7k229XNowIC+dyc96t3kIP8lpEHFRJGtqVQPM/JkOu3rRAi7"
    "SnwJ+ryv7CB15NTVlA0olDzvgQYqqdYnvNO1hf6B1kahHwiaBmkI0UlQGkfMUtP6KzHWuULHwwzc"
    "Qad9AkshbVqkQ6sUkNCuc98tX7o3TKcSb+cUJVIh6t7l5jtt5PcG9GxiG86v/wOhi2mT"
)  # 126 pairs

_IT_DATA = (
    "eNpVkkFywyAMRdf2YTqJkx5IwbJHM4CoAC96+gqEmekuehbS/1/JF/sTBRep7Hl5f32v9otCYikQ"
    "Cyp8D+ikOgLf0DbQwXGHgLEYfq1JMO5t4o6OMnG0ARMHylWgT5jMcXaE8bfhxwpXY77yaYKsVkFQ"
    "CveHRvA48D/JGHOrn6PeScg6XmvQ3saSQCFnAm6GF+1j/XPCua1gNJGxmKABVL4u7AE91wOUHMJW"
    "b1YnkGKp9FLoQKEWFt/+cwFbpetnVqeA5jJP0HVNGuA8iWXg7caxBhTzni/yNSVeMmedSx/yNtfp"
    "PkcFFlQvHCyF1+ogfAhMlvMUWj7cHzSfJ4EKj5EvGIO2lWK3pm2+ye9nR1l+Kpg1zd8vB0WLRrtV"
    "G/UvjzXV1nOROu8P9augh9v9o7eDXoDGv2FxULOdZqd2hYxnnddqe/UMIVGX/AfUYOkI"
)  # 38 pairs

_PT_DATA = (
    "eNpNUkFywyAMPJvHZJLYPfQ5CsiOZkB4AHs6/U3SQ2d67S1XPlZhcJqTrZVYLbsYjOhm5CuEboYZ"
    "bTcc3lT9Izf7kIATCjg0cFzYgENOUEZ7lbyTowY1xfzlt8EKOTRkQICzShg6u0wCFvJSCTXo5J9d"
    "HJG28rSVhkKr+60GjTHW9gifWKSGTVXf6jFglbkPBGEM+Yc1FQlHNQeMSQRAQs7fVWmvLK6Cac+R"
    "DAbYG+f/RoLXQbhUEVMANtgMyve2ZdhxB+QD1bs3iPPDYainjXjOq7crFR99F5coqlK+rZv9g9Ii"
    "Vrcmioj860hXxW4xIBeATlty+ZZIV4HIGCZZKT74dWc6q2Zk7K6LA5ZvCSBCfoikOT8udj/fsGew"
    "J8Wym0v6vj4JLyl9yFuxNWR0ssu+WCZASYX0YregZTlKcD6Y2p99oVopNksLYXEep4VqdkfJmmV6"
    "t/2oWGLHTtxKJHh/eP8DWCrpAw=="
)  # 36 pairs

_PL_DATA = (
    "eNp1ksFuwyAMhs/wMFO7Zg9EAWUuCSBIhPCxUrVnqPYYu/a25L3mQNZkh12Q/GH/9m9wqg05iemD"
    "BddNd9a8vPEk5ocVCxAUN9x0o0SXnuTEvVOX6UZFSsuMl1LX7CiCmK/CwpL9unETnAFCR96Dphit"
    "kKgt6NK2suTna05FrwI6L1Hq0rcSH0RyRbnGysVhuvudcNQ2UnjgmIKQi7sxibaMeeLnUEAdckec"
    "8i6BXnhn3fxJaFH0gawT3Hz9c3sWarO8Ye86GLIpzQ9cjfND/zF+4tS0o73sIQm78gyZ3Lpzp/t1"
    "kwWSgGiDI6WafeAQBzdQ8nN7xxU9H+3IE0vZghmLUmJB9EK+1wFYRGrdfn8VaxIKpVofMBtyrMp7"
    "oGYJW/ol6lcDE0w3XCV7oBvMDKzNPaxrQK2oKmKOg4G+fp7RmoElUItZsQ6wTCurmR/Rxu59"
)  # 34 pairs

_UK_DATA = (
    "eNp9WFtW40oM/HY2cv/mwEwCZHd5AAP3cIafezLbMHkax3a2YO/oVpXU7XYS+OHhVqvVUqkkdbdo"
    "m7bqlln32jbZw4/JqN22x+4967iw0befo/aQtVW747fuT3b/Yzrijlm7aw/dEuJvWMm7RbfC2sOo"
    "XX+1dj9q6zbP2lO3arfdnCvtWit3OIMrW5x6okl2uk6b8DSe3+6h6Qlfxjxj8OWXa266Of5oXKtZ"
    "Tk24Ek5c4tuttJ1gYdM9405zSd7I6mfYdXSH3Pkth98eRt1LW3BzW7ZF+5nhvBPsKHHDWTbVibSk"
    "+42fXG/XWD/izzU8id3zbgnRRfcfFi7W4Z81XLK3D7ae9ydYfEpc5g/0Ny7RPWJLqdjMIDEd9U4I"
    "NvC2RVvjvkV7ggz8B+fqWkEGCiGhf0pIwJ84tJvhtg2W8Jd2rNtdxkDhjy1+Qh5QEUJqmLhmWP/B"
    "1SoFA/tyBbnQv1M6mWINrv8vflcwgD9zws1luzeoIxgy+GnG4AJE63BUWxkcKMjFBfZvulXvbJzD"
    "y1KSEYKuWzqMeDrptFKucacQhE/86aFBYOfSWQWZXBqPkDnI+VBc4rz59XU4rSRaurfvpOCsHWKm"
    "iCrMLuUJJmvgqS00RJBw7Yl6qANe4L2IC8a1e8c2AQZIhrcqQ4bSFGdQAudEH3na1ZaqhoxPRQFS"
    "SFwc+wLjLLRT+m9LQOHmmyhzkdxLB69cukJMZsJIlG8oawg4SOKT3un+RJlBGkxEBu0HjxEMfxsI"
    "TJL324cLR8z8EioghSxI9Cb+EOwZiI9UW8jWXQrm6qtV+az6zhKSXHCxHWx2rLB/oTwC5ViEzfdr"
    "pdmit5do38ijIsVv1id2n23ia8ta5mKUug32BFsgU7iBdqfpSGsKfeobkSTCoDSVrrHQgA/D04AY"
    "JtlWXhYV7yzxM4OEKN3+ypUedRK5e9NZUisF3PPIfySkcCNPrOHqIo0buIFnQqtj5sM5gV4a8Inj"
    "nNGQkaZBsFZWbqG6j//4S4zyjrWop3G7fspzvtB7rnvEPzWSD8Wj+2ssdE3uCpXejBQ+pwu57Twi"
    "oAUWA49buBl9t09tWIgzauf5jSzxnOeVGfHXVN6pLeaTwF8MdRKwBy8RKnUfxndD3JzRW6L1lntY"
    "t+vhDkEzhk/ZgT5ACir64dIHz55Hk5HScCsg1meyKaXHXEhY07np4KlROsa9aFWiuCT+B508T3JH"
    "XiAvzkTOi9TOSF+u94ZnN+onPAmM2w3JstP8vjOcqOfoa9vAUqttk5DZx+sSYm8S2FIavZZ8jfsA"
    "mbSiGrw2kbd+jkhlzm25bvP5tYXIW8ZvLytmilMd2yZmrvRTzXtgDtPZeMmMXkq8iV5Ccd9IY0Xk"
    "ww9v3pCxADAkXiulTtpVyYiSvZLO7ViaBfhwtIsFDgifY5s1U7MRIZEgwLqr1MeDELrFv4xlX4OV"
    "c1WNhdZureJthndOZZTtBv1H61q/8/sNUXkUeQ80GgkdPYPH33RS1o3khnBrBWMfmnYtVzuuE3s8"
    "ZfkZPnr2SHjurT/zWj2djtyZpUC46LWddSF+tuJWDnoe4WCuFnme9pNmx0I9qelO9vRddG682ZgF"
    "MDP68iTa5b013JxUeMNtcIeZjzB3F2PBoFH0m2r42nmRXGU9uaLrFn7S1VjhVr5+q655oX69VP/3"
    "4EORVd5KPcjSOpQl+8BHhXUVRyyD3xJeXdmQpd17C5JFQn39q5/s/ZAPCvKydzbhC3NwH3camKFK"
    "tYYDpw9uGips8sk12xTmDeAo84nJhkSxXUn2yIkWWWnfyNdhiGnUIetOvmjj272zF0c4RpF6jl48"
    "K+9dNBya+drR34/afBISn081hKay9yNh7yADEIxwB6XH1r6M1ZPDiiodsW8cXcPvSc4Do1lgbRts"
    "186mjQEhs9EKmNFEwwXz7iHBLbGQzJeNxuGLFo1bierAS5v+68HrmKWSj48Nh+S3aDP8/irbzr7b"
    "iM92h+G3DiXEhQO98iMUJqZU4oeJBnkr3Bbjwm+XxTa68QH/p+O2VFIXMbvGim3KV6U/CIRHCXN0"
    "EXtn91+uVDY1iU3hnK0umzv33tuUy++aPeyMyaCnjEX3Whd7NvlEWTmtsYwPFSr2cb3G89Gy33GX"
    "TnKJDcb0RaxQzrZ5YmPoUUPPG6bGml2UiKCfG8Ocd9aZ9ve4aB9Czy3ySW9MyXUYJaLsJJn0elmf"
    "8yyHH7VWDaheAD+qmhaCn7pBlc5kzHFt52Xxr9X5a81CX9Uii4yjHwMAoxXWR/FtQyXc7T0v4CKp"
    "R1kgS9jAsbmkupCV6s37KCYd9EVv3kuRHwQA70jllFLbEgzpo4hMz0FuZ/SWPYAl+Gl6RvFu+9PQ"
    "RK/aK12U3joi6cplqAzgf+xXHVOuIHs+lX0EfXZBDGRlWwnhKMjjxk2sbLLE6m78Z8DdYHXlmKoL"
    "n3t4x2CPrcRJ+tKN/pC5S3sAa/6c/+zNsLQ6oPczSQZWfjiTGHjQmPLDm5sqcuwFc7N784Kg5AkN"
    "RuHZrBqR6+2guS5xO7pSNK5K3hh3PHvT8oWcT6SpmU5S1rrNFeWF9ya99bVaX82pmthM4n5gv5Wm"
    "K3ap11Tl/HA/2bvh2egsrypm5u06dHX9v04rjPpwlJYtvZyP8fPw9pXIIfYvStQ4tfm7jz8+LsCN"
    "E3tBevH31l3mrdHvSBJTIl8UYDx2PmddTvbvhumN/P6h9L2q1yP+qUyu015/Zo/p9oS9lsFFmKiM"
    "+1fGvU+yZxa7ZICH8Zgn9Kk3nVIRgeLL2W0aeo74OqmO2N8+x1dXE94I2A425te76UHP/YXM/fBB"
    "PlcdM97TTOr9n03iC0OJBhu14rXPllbf+8cBtbB5FqBJDhHa7v4HJHLo4w=="
)  # 193 pairs


_cache: dict[str, dict[tuple[str, str], float]] = {}

def _decode(b64: str) -> dict[tuple[str, str], float]:
    raw = zlib.decompress(base64.b64decode(b64)).decode("utf-8")
    result: dict[tuple[str, str], float] = {}
    for line in raw.split("\n"):
        if not line:
            continue
        parts = line.split("\t")
        if len(parts) == 3:
            result[(parts[0], parts[1])] = float(parts[2])
    return result

def get_en_collocations() -> dict[tuple[str, str], float]:
    if "en" not in _cache:
        _cache["en"] = _decode(_EN_DATA)
    return _cache["en"]

def get_ru_collocations() -> dict[tuple[str, str], float]:
    if "ru" not in _cache:
        _cache["ru"] = _decode(_RU_DATA)
    return _cache["ru"]

def get_de_collocations() -> dict[tuple[str, str], float]:
    if "de" not in _cache:
        _cache["de"] = _decode(_DE_DATA)
    return _cache["de"]

def get_fr_collocations() -> dict[tuple[str, str], float]:
    if "fr" not in _cache:
        _cache["fr"] = _decode(_FR_DATA)
    return _cache["fr"]

def get_es_collocations() -> dict[tuple[str, str], float]:
    if "es" not in _cache:
        _cache["es"] = _decode(_ES_DATA)
    return _cache["es"]

def get_it_collocations() -> dict[tuple[str, str], float]:
    if "it" not in _cache:
        _cache["it"] = _decode(_IT_DATA)
    return _cache["it"]

def get_pt_collocations() -> dict[tuple[str, str], float]:
    if "pt" not in _cache:
        _cache["pt"] = _decode(_PT_DATA)
    return _cache["pt"]

def get_pl_collocations() -> dict[tuple[str, str], float]:
    if "pl" not in _cache:
        _cache["pl"] = _decode(_PL_DATA)
    return _cache["pl"]

def get_uk_collocations() -> dict[tuple[str, str], float]:
    if "uk" not in _cache:
        _cache["uk"] = _decode(_UK_DATA)
    return _cache["uk"]


_LANG_GETTERS = {
    "en": get_en_collocations,
    "ru": get_ru_collocations,
    "de": get_de_collocations,
    "fr": get_fr_collocations,
    "es": get_es_collocations,
    "it": get_it_collocations,
    "pt": get_pt_collocations,
    "pl": get_pl_collocations,
    "uk": get_uk_collocations,
}


def get_collocations(lang: str) -> dict[tuple[str, str], float]:
    getter = _LANG_GETTERS.get(lang)
    if getter:
        return getter()
    return {}
