"""Türkçe dil paketi."""

LANG_TR = {
    "code": "tr",
    "name": "Turkish",
    "native_name": "Türkçe",

    # Common trigrams for language detection
    "trigrams": [
        "lar", "ler", "bir", "de ", "da ", "ve ", "in ", "an ",
        "en ", "ir ", "ar ", "ini", "ını", "ile", "ası", "esi",
        "lar", "ler", "dır", "dir", "tir", "tır", "yor", "mak",
        "mek", "ama", "eme", "ine", "ını", "ığı", "isi", "üzü",
        "ılı", "ili", "olu", "ülü", "aya", "eye",
    ],

    # Stop words
    "stop_words": {
        "bir", "bu", "şu", "o", "ve", "ile", "için", "de", "da",
        "den", "dan", "ne", "ya", "hem", "ama", "fakat", "ancak",
        "çünkü", "eğer", "gibi", "kadar", "daha", "en", "çok",
        "az", "her", "hiç", "bazı", "tüm", "bütün", "olan",
        "olarak", "üzere", "göre", "karşı", "sonra",
        "önce", "arasında", "üzerinde", "altında", "yanında",
        "içinde", "dışında", "hakkında", "tarafından", "dolayı",
        "rağmen", "beri", "boyunca", "ise", "ki", "mi", "mı",
        "mu", "mü", "bile", "sadece", "yalnız",
    },

    # Bureaucratic / overly formal words -> simpler alternatives
    "bureaucratic": {
        "kullanmak": ["kullanmak", "yararlanmak"],
        "istifade etmek": ["yararlanmak", "faydalanmak"],
        "icra etmek": ["yapmak", "uygulamak"],
        "tatbik etmek": ["uygulamak", "yapmak"],
        "teşvik etmek": ["özendirmek", "desteklemek"],
        "başlatmak": ["başlamak", "açmak"],
        "nihayetlendirmek": ["bitirmek", "sonlandırmak"],
        "ikmal etmek": ["tamamlamak", "bitirmek"],
        "tahakkuk ettirmek": ["gerçekleştirmek", "başarmak"],
        "teyit etmek": ["doğrulamak", "onaylamak"],
        "tetkik etmek": ["incelemek", "araştırmak"],
        "temin etmek": ["sağlamak", "bulmak"],
        "iktisap etmek": ["elde etmek", "almak"],
        "tahakkuk etmek": ["gerçekleşmek", "olmak"],
        "inşa etmek": ["kurmak", "yapmak"],
        "tanzim etmek": ["düzenlemek", "hazırlamak"],
        "terakkî etmek": ["ilerlemek", "gelişmek"],
        "idame ettirmek": ["sürdürmek", "devam ettirmek"],
        "ıslah etmek": ["düzeltmek", "iyileştirmek"],
        "takviye etmek": ["güçlendirmek", "pekiştirmek"],
        "kavramak": ["anlamak", "algılamak"],
        "idrak etmek": ["anlamak", "kavramak"],
        "hükmetmek": ["karar vermek", "yargılamak"],
        "mukabele etmek": ["karşılık vermek", "yanıtlamak"],
        "talep etmek": ["istemek", "rica etmek"],
        "müracaat etmek": ["başvurmak", "dilekçe vermek"],
        "tasdik etmek": ["onaylamak", "kabul etmek"],
        "ruhsat vermek": ["izin vermek", "onaylamak"],
        "tebliğ etmek": ["bildirmek", "haber vermek"],
        "rapor etmek": ["bildirmek", "aktarmak"],
        "irtibat kurmak": ["iletişime geçmek", "bağlantı kurmak"],
        "iştirak etmek": ["katılmak", "dahil olmak"],
        "teşrik-i mesai etmek": ["iş birliği yapmak", "birlikte çalışmak"],
        "hizmet etmek": ["katkıda bulunmak", "yardımcı olmak"],
        "vuku bulmak": ["olmak", "meydana gelmek"],
        "mevcut olmak": ["var olmak", "bulunmak"],
        "tenkis etmek": ["azaltmak", "kısmak"],
        "artırmak": ["çoğaltmak", "yükseltmek"],
        "tevsi etmek": ["genişletmek", "büyütmek"],
        "daraltmak": ["küçültmek", "azaltmak"],
        "birleştirmek": ["bir araya getirmek", "kaynaştırmak"],
        "tahlil etmek": ["çözümlemek", "incelemek"],
        "takdir etmek": ["değer biçmek", "beğenmek"],
        "tadil etmek": ["değiştirmek", "düzeltmek"],
        "tebdil etmek": ["değiştirmek", "dönüştürmek"],
        "tayin etmek": ["belirlemek", "atamak"],
        "ithal etmek": ["getirmek", "almak"],
        "ilga etmek": ["kaldırmak", "iptal etmek"],
        "tevzi etmek": ["dağıtmak", "paylaştırmak"],
        "idare etmek": ["yönetmek", "çekip çevirmek"],
        "tedvir etmek": ["yürütmek", "işletmek"],
        "murakabe etmek": ["denetlemek", "kontrol etmek"],
        "tensip etmek": ["uygun görmek", "seçmek"],
        "arz etmek": ["sunmak", "göstermek"],
        "muamele etmek": ["işlem yapmak", "davranmak"],
        "muhafaza etmek": ["korumak", "saklamak"],
        "iade etmek": ["geri vermek", "geri göndermek"],
        "intikal etmek": ["geçmek", "aktarılmak"],
        "istimal etmek": ["kullanmak", "değerlendirmek"],
        "farz etmek": ["varsaymak", "kabul etmek"],
        "hususiyle": ["özellikle", "bilhassa"],
        "binaenaleyh": ["bu nedenle", "dolayısıyla"],
        "maamafih": ["bununla birlikte", "yine de"],
        "bilahare": ["daha sonra", "ardından"],
        "muahede": ["anlaşma", "sözleşme"],
        "mütalaa etmek": ["düşünmek", "değerlendirmek"],
        "ihtiva etmek": ["içermek", "kapsamak"],
        "tefrik etmek": ["ayırmak", "ayrım yapmak"],
        "tahsis etmek": ["ayırmak", "vermek"],
        "teftiş etmek": ["denetlemek", "kontrol etmek"],
        "temadi etmek": ["sürmek", "devam etmek"],
        "tebaruz etmek": ["öne çıkmak", "belirmek"],
        "tekerrur etmek": ["tekrarlanmak", "yinelenmek"],
        "teferruat": ["ayrıntı", "detay"],
        "mukâyese etmek": ["karşılaştırmak", "kıyaslamak"],
        "müsaade etmek": ["izin vermek", "bırakmak"],
        "muvaffak olmak": ["başarmak", "becerebilmek"],
        "müracaat": ["başvuru", "dilekçe"],
        "tashih etmek": ["düzeltmek", "onarmak"],
        "teşebüs etmek": ["girişmek", "başlamak"],
        "istihsal etmek": ["üretmek", "elde etmek"],
        "tenvir etmek": ["aydınlatmak", "bilgilendirmek"],
        "istişare etmek": ["danışmak", "fikir almak"],
        "tedavi etmek": ["iyileştirmek", "sağaltmak"],
        "istihdam etmek": ["çalıştırmak", "görevlendirmek"],
        "ibraz etmek": ["göstermek", "sunmak"],
        "ihdas etmek": ["oluşturmak", "kurmak"],
        "istinas etmek": ["dayanmak", "güvenmek"],
        "terfi ettirmek": ["yükseltmek", "terfi vermek"],
        "tekamul": ["gelişme", "ilerleme"],
        "münhasıran": ["yalnızca", "sadece"],
        "mahiyet": ["nitelik", "içyüz"],
        "ahval": ["durumlar", "koşullar"],
        "mütemadiyen": ["sürekli", "durmadan"],
        "müteakiben": ["ardından", "hemen sonra"],
        "mütecaviz": ["saldırgan", "agresif"],
        "salahiyet": ["yetki", "hak"],
        "havi": ["içeren", "kapsayan"],
        "celp etmek": ["çekmek", "getirmek"],
        "der meyan etmek": ["belirtmek", "söylemek"],
        "tahtına": ["yerine", "karşılığında"],
        "meşru": ["yasaya uygun", "haklı"],
        "intibak etmek": ["uyum sağlamak", "alışmak"],
        "icraat": ["çalışma", "faaliyet"],
        "tedbir almak": ["önlem almak", "hazırlık yapmak"],
        "müzakere etmek": ["görüşmek", "müzâkere yapmak"],
        "meblag": ["tutar", "miktar"],
        "mukâvele": ["sözleşme", "anlaşma"],
        "mütevelli": ["sorumlu", "yönetici"],
        "hükümsüz kılmak": ["geçersiz saymak", "iptal etmek"],
        "beyan etmek": ["açıklamak", "bildirmek"],
        "istikamet": ["yön", "doğrultu"],
        "tazyik etmek": ["baskı yapmak", "zorlama yapmak"],
        "tevâzü": ["alçakgönüllülük", "mütevazılık"],
        "feragat etmek": ["vazgeçmek", "bırakmak"],
        "mütehâkim olmak": ["hâkim olmak", "egemen olmak"],
        "müesses": ["kurulu", "görevli"],
        "sarf etmek": ["harcamak", "kullanmak"],
        "mütearife": ["açık gerçek", "bedihiyet"],
        "ilân etmek": ["duyurmak", "açıklamak"],
        "infaz etmek": ["uygulamak", "yerine getirmek"],
        "tahkik etmek": ["soruşturmak", "araştırmak"],
    },

    # Bureaucratic phrases -> simpler versions
    "bureaucratic_phrases": {
        "onayınıza sunulmuştur": ["onayınıza sunuyoruz", "onayınızı bekliyoruz"],
        "gereğini arz ederim": ["gereğini rica ederim", "yapılmasını istiyorum"],
        "bilgilerinize sunulur": ["bilginize", "size bildiriyoruz"],
        "yukarıda belirtilen hususlar": ["yukarıda söylenen konular", "anlattığımız konular"],
        "ilgi yazınız gereğince": ["yazdığınız gibi", "yazınıza göre"],
        "söz konusu husus": ["bu konu", "bahsedilen mesele"],
        "mezkûr tarihte": ["belirtilen tarihte", "o tarihte"],
        "muktezası gereğince": ["gereği doğrultusunda", "gerektiği şekilde"],
        "zikredilen hususlar": ["adı geçen konular", "söylenen şeyler"],
        "meri mevzuat çerçevesinde": ["yürürlükteki yasalara göre", "geçerli kurallara göre"],
        "sair hükümler saklı kalmak kaydıyla": [
            "diğer kurallar geçerli olmak üzere",
            "geri kalanı saklı kalmak şartıyla",
        ],
        "mezkûr kanun hükmünde": ["söz konusu yasa uyarınca", "o yasaya göre"],
        "yukarıda arz edilen": ["yukarıda anlatılan", "yukarıda belirtilen"],
        "bilgi edinilmesi hususunda": ["bilmeniz için", "haberiniz olsun diye"],
        "gereği bilgilerinize": ["bilginize", "bilmeniz için"],
        "emrilerinize arz olunur": ["bilginize sunuyoruz", "arz ediyoruz"],
        "yapılmasını teminen": ["yapılması için", "sağlamak amacıyla"],
        "bahse konu olan": ["söz konusu", "sözü edilen"],
        "tarafınızca uygun görüldüğü takdirde": [
            "siz uygun görürseniz",
            "onaylarsanız",
        ],
        "iş bu yazımız ile": ["bu yazıyla", "bu mektupla"],
        "netice itibarıyla": ["sonuç olarak", "sonunda"],
        "hususun bilgilerinize sunulmasını": [
            "konuyu bilmenizi",
            "durumdan haberdar olmanızı",
        ],
        "ivedilikle gereğinin yapılması": [
            "hemen yapılması",
            "acilen halledilmesi",
        ],
        "mevzubahis olan": ["konu olan", "söz edilen"],
        "vaki olan başvuru": ["yapılan başvuru", "gelen başvuru"],
        "tedbirler alınması hususunda": ["önlem alınması için", "tedbir almak üzere"],
        "lüzumu hâlinde": ["gerekirse", "gerektiğinde"],
        "mutabık kalınması hâlinde": ["anlaşılırsa", "uzlaşma sağlanırsa"],
        "aşağıda belirtilen hususlar": ["aşağıda yazılanlar", "aşağıdaki konular"],
        "yukarıda izah edilen": ["yukarıda açıklanan", "anlatıldığı gibi"],
        "hususun takdirlerine arz olunmasını": [
            "değerlendirmenize sunuyoruz",
            "bilginize sunuyoruz",
        ],
        "yazımıza cevaben": ["yazınıza yanıt olarak", "mektubunuza karşılık"],
        "aşağıdaki şekilde işlem yapılması": ["aşağıdaki gibi yapılması", "şu şekilde uygulanması"],
        "muhatap kurum tarafından": ["ilgili kurum tarafından", "karşı taraftan"],
        "gereğinin ifası hususunda": ["gereğinin yapılması için", "gereken adımların atılması"],
        "müddetinde eda edilmesi": ["süresinde tamamlanması", "zamanında yapılması"],
        "tedabir ittihaz olunması": ["önlem alınması", "tedbir alınması"],
        "maslahatgüzarlar aracılığıyla": ["diplomatik yollarla", "aracılar yoluyla"],
        "itina gösterilmesi rica olunur": [
            "özen gösterilmesini rica ediyoruz",
            "dikkatli davranılmasını istiyoruz",
        ],
        "müştereken hareket edilmesi": ["birlikte hareket edilmesi", "ortak çalışılması"],
        "tahsil edilmesi gereken": ["alınması gereken", "toplanması gereken"],
        "ilgililerin bilgisine sunulur": ["ilgililere bildirilir", "ilgili kişilere duyurulur"],
        "hak ve mükellefiyetleri": ["hak ve yükümlülükleri", "haklar ve ödevler"],
        "yükümlülüklerin ifasını": [
            "ödevlerin yerine getirilmesini",
            "sorumlulukların yerine getirilmesini",
        ],
        "tarafsızlığın muktezasınca": ["tarafsızlık gereği", "tarafsız şekilde"],
        "mücbir sebep hali dışında": ["zorunlu durumlar hariç", "olağanüstü durumlar dışında"],
        "teşkilâtın idamesi bakımından": ["kurumun devamı açısından", "yapının sürmesi için"],
    },

    # AI connector phrases -> replacements
    "ai_connectors": {
        "bununla birlikte": ["ama", "yine de", "ne var ki"],
        "buna rağmen": ["ama", "yine de", "gene de"],
        "bunun yanı sıra": ["ayrıca", "üstelik", "buna ek olarak"],
        "dahası": ["üstelik", "hem de", "bir de"],
        "buna ek olarak": ["ayrıca", "üstelik", "bir de"],
        "dolayısıyla": ["bu yüzden", "o nedenle", "bu sebeple"],
        "bu sebepten ötürü": ["bu yüzden", "o nedenle", "bundan dolayı"],
        "yani": ["kısacası", "başka bir deyişle", "özetle"],
        "başka bir deyişle": ["yani", "diğer bir ifadeyle", "kısacası"],
        "şüphesiz": ["elbette", "kesinlikle", "kuşkusuz"],
        "kuşkusuz": ["elbette", "şüphesiz", "hiç şüphe yok"],
        "sonuç olarak": ["özetle", "kısacası", "son söz olarak"],
        "nihayetinde": ["sonunda", "en sonunda", "neticede"],
        "her şeyden önce": ["öncelikle", "ilk olarak", "en başta"],
        "öte yandan": ["diğer taraftan", "buna karşılık", "ama"],
        "bunun aksine": ["tam tersine", "aksine", "buna karşın"],
        "genel olarak": ["genelde", "çoğunlukla", "genellikle"],
        "özellikle": ["bilhassa", "başta", "en çok"],
        "dikkat çekici olan": ["göze çarpan", "önemli olan", "ilginç olan"],
        "önemli olan şu ki": ["asıl mesele şu", "kilit nokta şu", "esas olan"],
        "özetle": ["kısaca", "toparlarsak", "kısa ve öz"],
        "bunun sonucunda": ["sonuç olarak", "bu yüzden", "neticesinde"],
        "özünde": ["temelde", "aslında", "esasen"],
        "kayda değer biçimde": ["önemli ölçüde", "belirgin şekilde", "fark edilir biçimde"],
        "buna göre": ["buna uygun olarak", "buna bağlı olarak", "ona göre"],
        "doğal olarak": ["elbette", "tabii ki", "hâliyle"],
        "alternatif olarak": ["başka bir seçenek olarak", "ya da", "yoksa"],
        "görünüşe göre": ["anlaşılan", "belli ki", "galiba"],
        "daha önce belirtildiği gibi": [
            "daha önce dediğimiz gibi",
            "önceki söylediğimiz üzere",
            "yukarıda da geçtiği gibi",
        ],
        "genel itibarıyla": ["bütünüyle", "toptan bakınca", "kabaca"],
        "toparlayacak olursak": ["özetlersek", "sonuç olarak", "genel değerlendirme yaparsak"],
        "kesinlikle": ["şüphesiz", "mutlaka", "tartışmasız"],
        "açıkça": ["belli ki", "görünür biçimde", "net biçimde"],
        "aynı zamanda": ["bir yandan da", "hem de", "üstelik"],
        "tersine": ["aksine", "tam tersi", "bilakis"],
        "benzer şekilde": ["aynı biçimde", "tıpkı öyle", "buna benzer olarak"],
        "temelden": ["kökten", "baştan", "esastan"],
        "hiç kuşkusuz": ["kesinlikle", "şüphesiz", "mutlaka"],
        "bu bağlamda": ["burada", "bu durumda", "bu açıdan"],
        "bu konuda": ["bu hususta", "bu mesele hakkında", "bununla ilgili"],
        "bunu dikkate alarak": ["bunu göz önünde bulundurarak", "buna istinaden", "buna dayanarak"],
        "aslında": ["gerçekte", "işin aslı", "doğrusu"],
        "ilginç olan şu ki": ["enteresan olan", "dikkat çekici olan", "şaşırtıcı olan"],
        "aynı şekilde": ["benzer biçimde", "tıpkı böyle", "aynen öyle"],
        "bu arada": ["bu esnada", "o sırada", "bu süreçte"],
        "daha da önemlisi": ["asıl önemli olan", "en önemlisi", "hele hele"],
        "somut olarak": ["net olarak", "açık biçimde", "spesifik olarak"],
        "doğaldır ki": ["elbette", "tabii", "hâliyle"],
        "ancak şunu belirtmek gerekir ki": [
            "ama şunu söylemek lazım",
            "fakat şunu da eklemeliyim",
            "bir şey daha var",
        ],
        "özellikle vurgulanmalıdır ki": [
            "bilhassa belirtmeliyim ki",
            "altını çizerek söylemeliyim",
            "önemle diyeyim ki",
        ],
        "tüm bunların ışığında": [
            "bütün bunlardan yola çıkarak",
            "bunlar göz önünde tutulursa",
            "bunlara bakarak",
        ],
        "şrafa koymak yerine": [
            "bir kenara bırakmak yerine",
            "yok saymak yerine",
            "görmezden gelmek yerine",
        ],
        "işin özüne bakarsak": ["esasa bakarsak", "asıl meseleye gelirsek", "konuya girirsek"],
        "peki ama şu var": [
            "ama bir şey var",
            "ne var ki",
            "fakat dikkat çeken bir şey",
        ],
        "ısrarla ifade edersek": [
            "bir kez daha söyleyelim",
            "tekrarlamak gerekirse",
            "yineleyerek söyleyelim",
        ],
        "ilk bakışta": ["görünüşte", "dışarıdan bakınca", "yüzeysel olarak"],
        "gelin görün ki": ["ama ne yazık ki", "ancak", "ne var ki"],
        "ne ilginçtir ki": ["enteresan olan", "şaşırtıcı biçimde", "dikkat çekici olan"],
        "hakkını teslim edelim": ["dürüst olalım", "adil olmak gerekirse", "kabul etmek lazım"],
        "en kötü senaryoda": ["en kötü ihtimalle", "en kötüsünde", "en olumsuz durumda"],
        "bir başka deyişle": ["yani", "kısaca", "başka bir anlatımla"],
        "tartışılması gereken": [
            "konuşulması gereken",
            "ele alınması gereken",
            "üzerinde durulması gereken",
        ],
        "bunun dışında": ["bundan başka", "bir de", "ayrıca"],
        "değerlendirildiğinde": ["ele alındığında", "incelendiğinde", "bakıldığında"],
        "nitekim": ["zaten", "nitekim öyle", "beklenildiği gibi"],
        "tümüyle": ["tamamen", "bütünüyle", "baştan aşağı"],
        "ne hazindir ki": ["ne yazık ki", "üzülerek söyleyeyim", "maalesef"],
    },

    # Synonyms for repetition reduction
    "synonyms": {
        "önemli": ["mühim", "kilit", "kritik", "hayati"],
        "büyük": ["kocaman", "devasa", "iri", "geniş"],
        "küçük": ["ufak", "minik", "cüce", "dar"],
        "iyi": ["güzel", "hoş", "harika", "mükemmel"],
        "kötü": ["berbat", "fena", "boktan", "rezil"],
        "hızlı": ["çabuk", "süratli", "tez", "acil"],
        "yavaş": ["ağır", "tembel", "sakin", "aheste"],
        "yeni": ["taze", "çağdaş", "modern", "son model"],
        "eski": ["kadim", "antik", "köhne", "geçmiş"],
        "güzel": ["hoş", "şık", "zarif", "alımlı"],
        "çirkin": ["biçimsiz", "betebeniz", "yakışıksız", "göze batmayan"],
        "güçlü": ["sağlam", "kuvvetli", "dayanıklı", "kudretli"],
        "zayıf": ["cılız", "güçsüz", "dermansız", "kırılgan"],
        "zor": ["güç", "çetin", "sarp", "ağır"],
        "kolay": ["basit", "zahmetsiz", "rahat", "yalın"],
        "başlamak": ["girişmek", "açmak", "koyulmak", "el atmak"],
        "bitmek": ["sona ermek", "tamamlanmak", "kapanmak", "noktalanmak"],
        "çalışmak": ["emek vermek", "uğraşmak", "didinmek", "mesai yapmak"],
        "söylemek": ["demek", "ifade etmek", "belirtmek", "dile getirmek"],
        "düşünmek": ["kafa yormak", "değerlendirmek", "tartmak", "kafasını kurcalamak"],
        "görmek": ["izlemek", "gözlemlemek", "bakmak", "fark etmek"],
        "almak": ["edinmek", "kapmak", "tutmak", "ele geçirmek"],
        "vermek": ["sunmak", "uzatmak", "bırakmak", "teslim etmek"],
        "gitmek": ["yola çıkmak", "yönelmek", "ayrılmak", "hareket etmek"],
        "gelmek": ["varmak", "ulaşmak", "çıkagelmek", "görünmek"],
        "bilmek": ["anlamak", "kavramak", "farkında olmak", "haberdar olmak"],
        "sevmek": ["hoşlanmak", "bayılmak", "tutulmak", "hayran olmak"],
        "istemek": ["arzu etmek", "dilemek", "talep etmek", "arzulamak"],
        "yapabilmek": ["becermek", "başarabilmek", "üstesinden gelmek", "hakkından gelmek"],
        "yer": ["mekân", "konum", "alan", "nokta"],
        "zaman": ["vakit", "süre", "dönem", "an"],
        "kişi": ["insan", "birey", "şahıs", "fert"],
        "iş": ["görev", "meslek", "uğraş", "faaliyet"],
        "sorun": ["mesele", "sıkıntı", "dert", "problem"],
        "çözüm": ["çare", "hal", "yol", "reçete"],
        "sonuç": ["netice", "çıktı", "ürün", "etki"],
        "neden": ["sebep", "gerekçe", "kök", "kaynak"],
        "yöntem": ["yol", "usul", "teknik", "strateji"],
        "fikir": ["düşünce", "görüş", "kanı", "tasarım"],
        "hedef": ["amaç", "gaye", "ulaşılmak istenen", "niyet"],
        "geliştirme": ["iyileştirme", "ilerleme", "yapım", "tasarım"],
        "araştırma": ["inceleme", "soruşturma", "analiz", "çalışma"],
        "rapor": ["bildiri", "sunum", "bülten", "özet"],
        "toplantı": ["görüşme", "buluşma", "oturum", "miting"],
        "plan": ["program", "taslak", "tasarı", "proje"],
        "karar": ["hüküm", "tercih", "yargı", "seçim"],
        "başarı": ["zafer", "kazanım", "muvaffakiyet", "erişim"],
        "başarısızlık": ["hezimet", "fiyasko", "hüsran", "çuvallamak"],
        "değişim": ["dönüşüm", "evrilme", "geçiş", "farklılaşma"],
        "artış": ["yükseliş", "tırmanış", "çoğalma", "büyüme"],
        "azalış": ["düşüş", "gerileme", "daralma", "erime"],
        "fırsat": ["şans", "imkân", "olanak", "vesile"],
        "mücadele": ["savaşım", "uğraş", "çaba", "kavga"],
        "bilgi": ["veri", "malumat", "enformasyon", "haber"],
        "konu": ["mesele", "gündem", "husus", "mevzu"],
        "durum": ["hâl", "koşul", "vaziyet", "tablo"],
        "ülke": ["memleket", "yurt", "vatan", "devlet"],
        "hükümet": ["yönetim", "idare", "otorite", "iktidar"],
        "toplum": ["halk", "cemiyet", "camia", "kamu"],
        "kültür": ["medeniyet", "gelenek", "değerler", "miras"],
        "bilim": ["fen", "ilim", "akademi", "araştırma"],
        "eğitim": ["öğretim", "tahsil", "terbiye", "yetişme"],
        "sağlık": ["afiyet", "esenlik", "zindelik", "sıhhat"],
        "yemek": ["yiyecek", "aş", "gıda", "sofra"],
        "su": ["akarsu", "sıvı", "içecek"],
        "ev": ["konut", "yuva", "mesken", "bark"],
        "yol": ["cadde", "güzergâh", "patika", "rota"],
        "kitap": ["eser", "yapıt", "cilt", "yayın"],
        "konuşma": ["söylev", "sohbet", "muhabbet", "laf"],
        "savaş": ["muharebe", "çatışma", "harb", "dövüş"],
        "barış": ["sulh", "huzur", "sükûnet", "selamet"],
        "özgürlük": ["hürriyet", "bağımsızlık", "serbestlik", "kurtuluş"],
        "adalet": ["hak", "doğruluk", "dürüstlük", "hakkaniyet"],
        "eğilim": ["trend", "yöneliş", "meyil", "eğret"],
        "bakış açısı": ["pencere", "gözlük", "perspektif", "açı"],
        "değer": ["kıymet", "anlam", "fayda", "bedel"],
        "yapı": ["iskelet", "çatı", "kurgu", "mimarlik"],
        "çevre": ["ortam", "etraf", "atmosfer", "ambiyans"],
        "tasarım": ["dizayn", "biçim", "görüntü", "estetik"],
        "veri": ["bilgi", "sayılar", "rakam", "enformasyon"],
        "kullanıcı": ["müşteri", "kişi", "faydalanan", "yürüüyen"],
        "performans": ["başarım", "verim", "gösterim", "aktivite"],
        "tepki": ["geri dönüş", "reaksiyon", "karşılık", "cevap"],
        "tartışma": ["tartışı", "diyalog", "müneşa", "ateşli konuşma"],
        "denge": ["uyum", "istikrar", "parallellik", "eşitlenme"],
        "risk": ["tehlike", "tehdit", "dezavantaj", "saklı tehlike"],
        "maliyet": ["masraf", "harcama", "gider", "bedel"],
        "ekonomi": ["ticaret", "mali tablo", "para düzen", "hazine"],
        "ağ": ["bağlantı", "şebeke", "network", "ilişki ağı"],
        "öngörü": ["tahmin", "kestirim", "vizyon", "önsezi"],
        "proje": ["girişim", "atılım", "iş", "çalışma"],
        "içerik": ["malzeme", "metin", "muhteva", "dolgu"],
        "süreç": ["hakikat", "tren", "akış", "dönüşüm"],
        "yaklaşım": ["tutum", "tavır", "yönelim", "bakış"],
        "esneklik": ["cilkallık", "uyum kabiliyeti", "kıvraklık", "oynak-lık"],
        "şeffaflık": ["açıklık", "görünürlük", "berraklık", "dürüstlük"],
        "motivasyon": ["heves", "istek", "güdü", "azim"],
        "kapasite": ["hacim", "güç", "yetkinlik", "oylum"],
        "potansiyel": ["güç", "olabilirlik", "yetenek", "gelecek vaadi"],
        "empati": ["duygudaşlık", "anlama", "hissetme", "hassasiyet"],
        "algı": ["farkındalık", "kavrama", "sezgi", "bilinç"],
        "geri bildirim": ["yorum", "değerlendirme", "görüş", "eleştiri"],
        "destek": ["yardım", "dayanışma", "arka", "kalkan"],
        "iletişim": ["haberleşme", "diyalog", "temas", "bağlantı"],
        "temel": ["esas", "kök", "ana", "dayanak"],
        "konsept": ["düşünce", "tasarı", "ana fikir", "tema"],
        "istikrar": ["süreklilik", "kararlılık", "durağanlık", "sağlamlık"],
        "yetenek": ["kabiliyet", "beceri", "hüner", "maharet"],
        "inceleme": ["irdeleme", "tetkik", "gözlem", "analiz"],
        "şirket": ["firma", "işletme", "kuruluş", "ticarethane"],
        "bütçe": ["kezik", "keziye", "maliyet planı", "para planı"],
        "strateji": ["yöntem", "taktik", "plan", "yaklaşım"],
        "hassasiyet": ["duyarlılık", "incelik", "titizlik", "narin"],
        "tecrübe": ["yaşantı", "birikim", "deneyim", "görgü"],
        "muhteva": ["iç", "öz", "ne var ne yok", "dolu"],
        "safhalar": ["aşamalar", "basamaklar", "adımlar", "kademeler"],
        "derece": ["seviye", "kademe", "düzey", "aşama"],
        "tür": ["çeşit", "cins", "tip", "kategori"],
        "itibar": ["saygınlık", "güvenilirlik", "nam", "prestij"],
    },

    # Sentence starters -> alternatives
    "sentence_starters": {
        "Bu": ["Şu", "O", "Söz konusu"],
        "Bu durum": ["Şu durum", "O durum", "Mevcut durum"],
        "O": ["Kendisi", "Bahsi geçen", "Söz konusu kişi"],
        "Onlar": ["Kendileri", "Bu kişiler", "Adı geçenler"],
        "Biz": ["Ekibimiz", "Hepimiz", "Grubumuz"],
        "Ben": ["Şahsen", "Bence", "Kendim"],
        "Ve": ["Ayrıca", "Üstelik", "Bunun yanında"],
        "Ama": ["Ancak", "Ne var ki", "Yine de"],
        "Ayrıca": ["Bunun yanı sıra", "Üstelik", "Dahası"],
        "Eğer": ["Şayet", "Diyelim ki", "Varsayalım ki"],
        "Çünkü": ["Zira", "Nedeni şu ki", "Şundan dolayı"],
        "Yani": ["Kısacası", "Bir başka deyişle", "Özetle"],
        "Örneğin": ["Mesela", "Söz gelimi", "Diyelim"],
        "Aslında": ["Gerçekte", "İşin doğrusu", "Hakikatte"],
        "Elbette": ["Tabii ki", "Doğal olarak", "Hiç kuşkusuz"],
        "Son zamanlarda": ["Son günlerde", "Yakın dönemde", "Bu aralar"],
        "Şimdi": ["Şu anda", "Hâlihazırda", "Bugün"],
        "Öncelikle": ["İlk olarak", "Her şeyden önce", "Evvela"],
        "Sonra": ["Ardından", "Akabinde", "Müteakiben"],
        "Son olarak": ["Nihayetinde", "En sonunda", "Bitirirken"],
        "Genellikle": ["Çoğunlukla", "Ekseriyetle", "Tipik olarak"],
        "Özellikle": ["Bilhassa", "Hele hele", "Başta"],
        "Sonuçta": ["Neticede", "Eninde sonunda", "Nihayetinde"],
        "Gerçekten": ["Hakikaten", "Sahiden", "Cidden"],
        "Temelde": ["Esasen", "Özünde", "Aslına bakarsanız"],
        "Neyse ki": ["Şükür ki", "İyi ki", "Bereket versin"],
        "Maalesef": ["Ne yazık ki", "Üzülerek", "Yazık ki"],
        "İlginç bir şekilde": ["Enteresan olarak", "Şaşırtıcı biçimde", "Dikkat çekici olarak"],
        "Kesinlikle": ["Mutlaka", "Tartışmasız", "Şüphesiz"],
        "Dikkat çekici olan": ["Göze çarpan", "İlginç olan", "Dikkat çeken"],
        "Her ne kadar": ["Ne kadar olsa da", "Her ne olursa olsun", "Olsa BILE"],
        "Dolayısıyla": ["Bu yüzden", "O nedenle", "Sonuçta"],
        "Gerçekten de": ["Sahiden", "Cidden", "Hakikaten"],
        "Başlı başına": ["Tek başına", "Kendi başına", "Salt olarak"],
        "Hemen belirtmek gerekir ki": [
            "Şunu hemen söyleyeyim",
            "Hemen ekleyeyim",
            "Bir şey eklemeliyim",
        ],
        "Düzgün bir dilde": ["Açık bir ifadeyle", "Sade bir dille", "Yalın bir anlatımla"],
        "Aşikar olanşudur ki": ["Ortada olan", "Belli olan", "Görünen"],
        "Dönüp bakıldığında": ["Geriye bakınca", "Geçmişe bakarsak", "Geçmiş düşünüldüğünde"],
        "Doğrusunu söylemek gerekirse": [
            "Açık konuşmam gerekirse",
            "Dürüst olmam gerekirse",
            "Samimi olarak",
        ],
        "Tabii ki": ["Elbette", "Doğal olarak", "Hiç kuşkusuz"],
        "Durum böyle olunca": ["Hal böyle olunca", "Bu durumda", "Böyle olunca"],
        "Büyük resme bakıldığında": ["Geniş açıdan bakarsak", "Makro açıdan", "Uzaktan bakarsak"],
        "Tuhaf olan şu ki": ["Garip olan", "Acayip olan", "İlginç olan"],
    },

    # Colloquial markers for chat/web profiles
    "colloquial_markers": [
        "bu arada",
        "aslında",
        "açıkçası",
        "kısacası",
        "basitçe söylemek gerekirse",
        "ilginç olan şu ki",
        "yalın hâliyle",
        "mesele şu ki",
        "gerçek şu ki",
        "ortaya çıktığı üzere",
        "en nihayetinde",
        "özetle",
        "her hâlükârda",
        "asıl önemli olan",
        "doğrusu",
        "hani",
        "zaten",
        "inan bana",
        "aramızda kalsın",
        "velhasıl",
        "bir düşünsen",
        "gerçekten",
        "demek istediğim",
        "yanlış anlama",
        "bu arada söyleyeyim",
        "parantez içinde",
        "tabii ki",
        "kesinlikle",
        "Allah bilir",
        "vallahi",
        "açık konuşmak gerekirse",
        "kıssadan hisse",
        "Türkçesiyle",
        "olan şu ki",
        "genel olarak",
        "abartısız",
        "hikâye şu ki",
        "mevzu şu ki",
        "pratikte",
        "bana sorarsanız",
        "bir düşünsenize",
        "hani derler ya",
        "doğru söylemek gerekirse",
        "yani şöyle diyelim",
        "kıssa dan hisse",
        "inanın bana",
        "siz düşünün",
        "bir bakmmışsınız",
        "işin gerçeği",
        "hani şey",
        "açık konuşmak lâzım",
        "meseleyi şöyle anlatayım",
        "dikkat edin",
        "bunu da belirteyim",
        "yemiş de yemiş",
        "şimdi bakın",
        "bir de şu açıdan bakalım",
        "kabul etmek lâzım",
        "hani bilirsiniz",
    ],

    # Abbreviations (don't split sentences after these)
    "abbreviations": [
        "Dr", "Prof", "Doç", "Yrd", "Öğr", "Gör",
        "Av", "Müh", "Mim", "Ecz",
        "Bşk", "Gn", "Alb", "Bnb", "Yzb", "Üçvş", "Çvş",
        "Cad", "Sok", "Mah", "Bul",
        "No", "Tel", "Faks",
        "vb", "vs", "bkz", "çev", "ed",
        "km", "cm", "mm", "kg", "mg", "ml",
        "Ltd", "Şti", "A.Ş", "T.C",
        "a.g.e", "a.g.m",
        "ör", "örn",
        "Hz", "yy",
    ],

    # Perplexity boosters (rare/unusual phrases to raise perplexity)
    "perplexity_boosters": [
        "tabiri caizse",
        "onun deyimiyle",
        "şöyle ya da böyle",
        "göründüğü kadarıyla",
        "her ne açıdan bakılırsa bakılsın",
        "en azından",
        "hakkını yemeyelim",
        "bundan bağımsız olarak",
        "söylemeye gerek yok",
        "her şeyden evvel",
        "ne olursa olsun",
        "kader bu ya",
        "hiç beklenmedik anda",
        "malumunuz",
        "beklentilerin aksine",
        "kaçınılmaz olarak",
        "hakkıyla",
        "farklı bir pencereden",
        "hengâmenin ortasında",
        "hiç kuşku yok ki",
        "bilhassa",
        "bu durum gerektiriyor ki",
        "anlaşıldığı kadarıyla",
        "olayların kalbinde",
        "gerçekçi olmak gerekirse",
        "med ve cezir arasında",
        "dönüm noktasında",
        "zaman zaman",
        "rastlantı değil",
        "aslına bakarsanız",
        "bir başka açıdan",
        "her durumda",
        "böylesi koşullar altında",
        "şaşılacak bir şey değil",
        "ironik biçimde",
        "eşit ölçüde",
        "sonuçta",
        "daha da şaşırtıcısı",
        "hassas olmak gerekirse",
        "böyle diyenler var",
        "farklılıklar göz önünde tutulursa",
        "kesin olan şudur ki",
        "kuşku götürmez biçimde",
        "hiç çekinmeden",
        "daha ince bir ifadeyle",
        "meselenin özünde",
        "genellikle söylendiği gibi",
        "ihtiyatla yaklaşırsak",
        "belirtmeden geçemeyeceğimiz",
        "abartma sayılmayacak şekilde",
        "utanıp sıkılmadan",
        "belki de rastlantı değildir ki",
        "bilinen bir gerçek olarak",
        "konunun derinine inildiğinde",
        "konuyla doğrudan bağlantılı olarak",
        "tarih boyunca göründüğü gibi",
        "nasıl olursa olsun",
        "olayların akışına bakılırsa",
        "dönüşüm sürecinde",
        "tarihsel bir perspektiften",
    ],

    # Profile metric targets
    "profile_targets": {
        "chat": {"avg_sentence_len": (6, 16), "max_sentence_len": 25},
        "web": {"avg_sentence_len": (8, 20), "max_sentence_len": 35},
        "seo": {"avg_sentence_len": (10, 22), "max_sentence_len": 40},
        "docs": {"avg_sentence_len": (10, 25), "max_sentence_len": 45},
        "formal": {"avg_sentence_len": (12, 28), "max_sentence_len": 50},
    },

    # Conjunctions for joining short sentences
    "conjunctions": ["ve", "ama", "ya da", "bu yüzden", "oysa", "üstelik", "çünkü"],

    # Split conjunctions for breaking long sentences
    "split_conjunctions": [
        ", ama", ", ve", ", bununla birlikte", ", buna rağmen",
        ", öte yandan", ", diğer taraftan", ", ancak",
        ", bu yüzden", ", ki", ". ", " — ",
        ", çünkü", ", zira", ", aksi takdirde",
        ", hatta", ", olsa bile", ", yine de",
        ", veya", ", sonra", ", önce",
        ", -dığında", ", -a kadar", ", bu arada",
        ", -dığı zaman", ", yani", ", şöyle ki",
        ", ayrıca", ", ne de", ", -den ziyade",
        ", dolayısıyla", ", böylece", ", bu nedenle",
        ", o hâlde", ", buna ek olarak", ", bunun yanı sıra",
        ", yerine", ", özellikle", ", kısacası",
        " – ",
    ],
}
