"""한국어 언어 팩."""

LANG_KO = {
    "code": "ko",
    "name": "Korean",
    "native_name": "한국어",

    # Common trigrams for language detection
    "trigrams": [
        "의 ", "는 ", "이 ", "을 ", "에 ", "을 ", "가 ", "한 ",
        "하는", "으로", "에서", "하고", "있는", "하여", "되는", "것이",
        "고 ", "다 ", "로 ", "지 ", "인 ", "된 ", "들 ", "수 ",
        "습니", "니다", "있다", "하다", "으며", "대한", "이다", "에게",
        "따라", "그리", "또한", "해서", "때문", "위해",
    ],

    # Stop words
    "stop_words": {
        "이", "그", "저", "것", "수", "등", "들", "및", "에", "의",
        "가", "를", "으로", "에서", "와", "과", "도", "는", "은", "을", "로", "한", "하다", "있다", "되다", "이다", "에게", "부터",
        "까지", "만", "이나", "나", "또는", "또한", "그리고", "하지만",
        "그러나", "그래서", "때문에", "위해", "대해", "통해", "따라",
        "의한", "더", "매우", "아주", "너무", "정말", "아직", "이미",
        "바로", "다시", "다른", "모든", "어떤", "같은", "그런",
    },

    # Bureaucratic / overly formal words -> simpler alternatives
    "bureaucratic": {
        "활용하다": ["쓰다", "이용하다"],
        "사용하다": ["쓰다", "이용하다"],
        "실시하다": ["하다", "진행하다"],
        "실행하다": ["하다", "진행하다"],
        "촉진하다": ["밀다", "도와주다"],
        "개시하다": ["시작하다", "열다"],
        "종료하다": ["끝내다", "마치다"],
        "완료하다": ["끝내다", "마무리하다"],
        "달성하다": ["이루다", "해내다"],
        "확인하다": ["살피다", "체크하다"],
        "검토하다": ["살펴보다", "따져보다"],
        "제공하다": ["주다", "내놓다"],
        "취득하다": ["얻다", "따다"],
        "실현하다": ["이루다", "해내다"],
        "구축하다": ["만들다", "세우다"],
        "수립하다": ["세우다", "만들다"],
        "추진하다": ["밀고 나가다", "진행하다"],
        "유지하다": ["지키다", "이어가다"],
        "개선하다": ["고치다", "나아지다"],
        "향상시키다": ["올리다", "높이다"],
        "파악하다": ["알아내다", "이해하다"],
        "인식하다": ["알다", "깨닫다"],
        "판단하다": ["결정하다", "보다"],
        "대응하다": ["맞서다", "처리하다"],
        "요구하다": ["요청하다", "바라다"],
        "신청하다": ["요청하다", "내다"],
        "승인하다": ["허락하다", "OK하다"],
        "허가하다": ["허락하다", "OK하다"],
        "통보하다": ["알리다", "전하다"],
        "보고하다": ["알리다", "전하다"],
        "연락하다": ["알리다", "말하다"],
        "참여하다": ["함께하다", "참가하다"],
        "협력하다": ["함께하다", "돕다"],
        "기여하다": ["도움이 되다", "보탬이 되다"],
        "발생하다": ["생기다", "일어나다"],
        "존재하다": ["있다", "살다"],
        "삭감하다": ["줄이다", "깎다"],
        "증가하다": ["늘다", "오르다"],
        "확대하다": ["넓히다", "키우다"],
        "축소하다": ["줄이다", "작게 하다"],
        "통합하다": ["합치다", "하나로 묶다"],
        "분석하다": ["살펴보다", "따져보다"],
        "평가하다": ["매기다", "가늠하다"],
        "수정하다": ["고치다", "바꾸다"],
        "변경하다": ["바꾸다", "바뀌다"],
        "설정하다": ["정하다", "잡다"],
        "도입하다": ["들이다", "가져오다"],
        "폐지하다": ["없애다", "없앨"],
        "적용하다": ["쓰다", "붙이다"],
        "배포하다": ["나눠주다", "뿌리다"],
        "조정하다": ["맞추다", "다듬다"],
        "관리하다": ["맡다", "돌보다"],
        "운영하다": ["돌리다", "이끌다"],
        "감시하다": ["지켜보다", "살피다"],
        "지정하다": ["정하다", "고르다"],
        "표시하다": ["보여주다", "나타내다"],
        "처리하다": ["다루다", "해결하다"],
        "보존하다": ["간직하다", "남기다"],
        "복구하다": ["되돌리다", "살리다"],
        "이행하다": ["옮기다", "실천하다"],
        "활성화하다": ["살리다", "키우다"],
        "상정하다": ["생각하다", "가정하다"],
        "말씀드리다": ["말하다", "전하다"],
        "말씀하시다": ["말하다", "이야기하다"],
        "여쭈다": ["묻다", "물어보다"],
        "드시다": ["먹다", "마시다"],
        "계시다": ["있다", "살다"],
        "존재하시다": ["있다", "계시다"],
        "견해하다": ["견디다", "버티다"],
        "종사하다": ["일하다", "맡다"],
        "확립하다": ["정하다", "굳히다"],
        "준비하다": ["마련하다", "챙기다"],
        "의뢰하다": ["부탁하다", "맡기다"],
        "확보하다": ["마련하다", "얻다"],
        "등록하다": ["넣다", "신청하다"],
        "배제하다": ["빼다", "없애다"],
        "산정하다": ["계산하다", "따져보다"],
        "관할하다": ["담당하다", "맡다"],
        "확정하다": ["정하다", "결정하다"],
        "형성하다": ["만들다", "이루어지다"],
        "제어하다": ["조절하다", "잡다"],
        "실증하다": ["시험하다", "검증하다"],
        "강화하다": ["단단히 하다", "더 강하게 하다"],
        "채택하다": ["골라 쓰다", "선택하다"],
        "금번": ["이번", "이번에"],
        "난처": ["곤란", "문제"],
        "우려하다": ["걱정하다", "염려하다"],
        "요청하다": ["부탁하다", "말씀드리다"],
        "요망하다": ["바라다", "내심 바라다"],
        "요건": ["조건", "필요한 것"],
        "유연하게": ["마름대로", "늘릎하게"],
        "약간": ["조금", "몇 가지"],
        "종래": ["그동안", "지금까지"],
        "해당하다": ["들어맞다", "맞다"],
        "가동하다": ["움직이다", "돌아가다"],
        "수집하다": ["모으다", "거두다"],
        "거점": ["중심지", "베이스"],
        "개념": ["생각", "컨셉"],
        "편의성": ["편함", "쓰기 좋음"],
        "개요": ["요약", "정리"],
        "특기할 만한": ["눈뜨이는", "줄만한"],
        "대체로": ["대략", "대충"],
        "진력하다": ["힘쓰다", "열심히 하다"],
        "대처하다": ["처리하다", "맞대응하다"],
        "직접적으로": ["바로", "다이렉트로"],
        "승지하다": ["알다", "이해하다"],
        "촉구하다": ["재촉하다", "다그치다"],
        "문의하다": ["묻다", "여쫓다"],
        "교부하다": ["주다", "건네다"],
        "대응전략": ["대처방법", "맞대응 방식"],
        "출발하다": ["떠나다", "나서다"],
        "도로에 그치다": ["무의미하다", "헛수고다"],
        "합의하다": ["동의하다", "맞추다"],
        "수습하다": ["정리하다", "매듭짓다"],
        "해석하다": ["풀이하다", "뜻 새기다"],
        "조작하다": ["다루다", "돌리다"],
        "소멸하다": ["사라지다", "없어지다"],
        "연마하다": ["갈고닦다", "배우다"],
        "추출하다": ["뽑다", "골라내다"],
        "망라하다": ["모두 담다", "다 포함하다"],
    },

    # Bureaucratic phrases -> simpler versions
    "bureaucratic_phrases": {
        "확인해 주시겠습니까": ["확인 좀 해주세요", "체크해 주세요"],
        "검토해 주시면 감사하겠습니다": ["검토 부탁드려요", "살펴봐 주세요"],
        "번거로우시겠지만": ["죄송하지만", "미안하지만"],
        "양해해 주시기 바랍니다": ["이해해 주세요", "양해 부탁해요"],
        "잘 부탁드리겠습니다": ["잘 부탁해요", "부탁합니다"],
        "~의 관점에서": ["~에서 보면", "~의 면에서"],
        "~에 기초하여": ["~을 바탕으로", "~에 따라"],
        "~을 고려하여": ["~을 생각해서", "~을 바탕으로"],
        "~에 있어서": ["~에서", "~에서는"],
        "~에 관하여": ["~에 대해", "~의 건으로"],
        "~에 대해서는": ["~대해서는", "~에 관해서는"],
        "전술한 바와 같이": ["앞서 말한 것처럼", "아까 말한 대로"],
        "하기와 같이": ["아래와 같이", "다음과 같이"],
        "~의 건에 대하여": ["~에 대해", "~의 이야기인데요"],
        "대단히 죄송합니다만": ["죄송하지만", "미안하지만"],
        "바쁘신 중에 죄송합니다만": ["바쁘시겠지만", "바쁜데 미안해요"],
        "수령하여 주십시오": ["받아 주세요", "확인해 주세요"],
        "열람하여 주십시오": ["봐 주세요", "확인해 주세요"],
        "그 뜻을 숙지하여 주십시오": ["알아두세요", "기억해 두세요"],
        "만전을 기하다": ["철저히 준비하다", "빈틈없이 대비하다"],
        "일정한 성과를 거두다": ["성과를 내다", "잘 되다"],
        "예의 주시하다": ["주목하다", "눈여겨보다"],
        "선처하다": ["잘 처리하다", "봐주다"],
        "유감으로 생각하다": ["아쉽게 생각하다", "미안하게 생각하다"],
        "소정의 절차를 거쳐": ["정해진 절차를 거쳐", "필요한 과정을 밟아"],
        "신속히 대응하다": ["빨리 대응하다", "바로 대처하다"],
        "해당 사항에 관하여": ["이 건에 대해", "이것에 대해"],
        "적절하게 처리하다": ["잘 대응하다", "제대로 처리하다"],
        "일람하여 주십시오": ["읽어 주세요", "살펴봐 주세요"],
        "급히 연락드립니다": ["급하게 말씀드립니다", "급한 이야기인데요"],
        "전달 드릴 말씀이 있습니다": ["드릴 말씀이 있어요", "이야기할 게 있어요"],
        "양해해 주시기 바랄 따름입니다": ["이해해 주시면 감사하곊습니다", "이해해 주세요"],
        "선처를 부탁드립니다": ["잘 처리해 주세요", "잘 부탁드립니다"],
        "바쁜 와중에 송구합니다만": ["바쁘신데 죄송합니다", "바쁜데 미안해요"],
        "미리 양해 부탁드립니다": ["미리 알려드립니다", "사전에 알아두세요"],
        "지속적으로 대응하여 주시기 바랍니다": ["계속 잘 부탁드립니다", "앞으로도 잘 부탁드립니다"],
        "해주실 수 있을까요": ["해주실 수 있나요", "해주시겠어요?"],
        "신속히 사과 말씀드립니다": ["빨리 사과드립니다", "죄송합니다"],
        "조회하여 주십시오": ["확인해 주세요", "찾아봐 주세요"],
        "모쌍 감사드립니다": ["정말 감사합니다", "감사드려요"],
        "각고의 노력을 다하시며": ["열심히 해주셔서", "고생 많으셨어요"],
        "고생이 많으셨습니다": ["수고하셨어요", "고생하셨네요"],
        "부덕한 점이 있습니다만": ["부족한 점이 있지만", "모자라지만"],
        "총력을 기해 주십시오": ["최선을 다해 주세요", "힘써 주세요"],
        "해당 사안에 관하여": ["이 건에 대해", "이것에 대해서"],
        "투명성을 확보하다": ["투명하게 하다", "보이게 하다"],
        "신속히 대응하여 주시기 바랍니다": ["빨리 대응해 주세요", "가능한 한 빨리 부탁드립니다"],
    },

    # AI connector phrases -> replacements
    "ai_connectors": {
        "그럼에도 불구하고": ["하지만", "그래도", "그런데도"],
        "그렇지만": ["하지만", "그래도", "근데"],
        "그에 더하여": ["게다가", "그리고", "더불어"],
        "더 나아가": ["그리고", "게다가", "더해서"],
        "덧붙여": ["그리고", "또", "거기에"],
        "따라서": ["그래서", "그러므로", "그러니까"],
        "그러므로": ["그래서", "그러니까", "그런 까닭에"],
        "즉": ["다시 말하면", "요약하면", "풀어 말하면"],
        "바꿔 말하면": ["다시 말해", "요는", "쉽게 말하면"],
        "의심할 여지 없이": ["분명히", "틀림없이", "확실히"],
        "틀림없이": ["분명히", "확실히", "당연히"],
        "결론적으로": ["정리하면", "결국", "끝으로"],
        "최종적으로": ["결국", "마지막에는", "결국에는"],
        "무엇보다 먼저": ["먼저", "우선", "처음에"],
        "한편으로는": ["반면에", "반대로", "다른 한편"],
        "이와 대조적으로": ["반대로", "반면에", "달리"],
        "일반적으로 말하면": ["보통은", "대체로", "대개"],
        "특히": ["특별히", "그중에서도", "무엇보다"],
        "주목할 만한 것은": ["중요한 건", "눈여겨볼 건", "핵심은"],
        "중요한 것은": ["핵심은", "중요한 건", "포인트는"],
        "요약하면": ["정리하면", "짧게 말하면", "간단히 하면"],
        "결과적으로": ["그 결과", "그래서", "덕분에"],
        "본질적으로는": ["기본적으로는", "근본적으로는", "핵심적으로는"],
        "현저하게": ["크게", "상당히", "눈에 띄게"],
        "그에 따라": ["그래서", "그에 맞춰", "그 결과"],
        "당연히": ["물론", "두말할 나위 없이", "말할 것도 없이"],
        "대안으로": ["다른 방법으로", "아니면", "또는"],
        "아마도": ["어쩌면", "혹시", "아마"],
        "앞서 말했듯이": ["아까 말한 것처럼", "전에도 말했지만", "앞서 말한 대로"],
        "대체적으로 말하면": ["전체적으로는", "대략적으로", "대충 말하면"],
        "총괄하면": ["정리하면", "전체를 보면", "다 합치면"],
        "확실히": ["분명히", "틀림없이", "진짜로"],
        "분명히": ["확실히", "명백히", "어떻게 봐도"],
        "동시에": ["한편", "함께", "같은 시간에"],
        "반대로": ["거꾸로", "오히려", "도리어"],
        "마찬가지로": ["비슷하게", "같은 식으로", "이와 같이"],
        "근본적으로": ["뿌리부터", "기본부터", "본질에서"],
        "궁극적으로": ["결국", "마지막에는", "최종적으로는"],
        "의심의 여지가 없이": ["확실히", "분명히", "당연히"],
        "이 맥락에서": ["여기서는", "이 경우에는", "이 점에서"],
        "이 점에 대해서": ["이에 관해서는", "이 건에서는", "여기서는"],
        "그것을 받아들여": ["그래서", "그 후", "그를 바탕으로"],
        "사실상": ["실제로는", "진짜로는", "솔직히"],
        "흥미롭게도": ["재미있게도", "의외로", "신기하게도"],
        "같은 방식으로": ["마찬가지로", "이와 같이", "비슷하게"],
        "그 사이에": ["그동안", "그 중간에", "그때까지"],
        "더 중요한 것은": ["더 핵심은", "무엇보다 중요한 건", "특히 중요한 건"],
        "구체적으로 말하면": ["구체적으로는", "예를 들면", "분명히 말하면"],
        "당연한 일이지만": ["물론", "역시", "예상대로"],
        "떠올려 보면": ["생각해 보면", "되돌아보면", "돌이켜보면"],
        "대체로 말하면": ["대충 말하면", "전체적으로는", "전반적으로"],
        "의외로": ["띌밖에", "예상치 못하게", "뜻밖에"],
        "그건 그렇고": ["그건 그렇다 치고", "그건 제쳐두고", "그것은 코가"],
        "이른바": ["즉", "다시 말해서", "뭐냐하면"],
        "이런 관점에서": ["이런 시선에서", "이 관점으로 보면", "이런 각도에서"],
        "단서를 붙이자면": ["단", "다만", "조건이 있다면"],
        "근저에 있는 것은": ["밑바탕에 있는 것은", "핵심에 있는 것은", "근본은"],
        "그 이면에는": ["실은", "그 뒤에는", "모르는 사이에"],
        "앞의 논의를 바탕으로": [
            "아까 이야기를 바탕으로",
            "앞의 논의를 받아서",
            "이전 논의를 고려하면",
        ],
        "보충하면": ["덧붙이면", "하나 더 말하면", "참고로"],
        "애초에 논하자면": ["애초 이야기를 하자면", "그 근본을 따져보면", "처음으로 돌아가면"],
        "현실적 문제로": ["실제로는", "현실은", "실정은"],
        "바로 이 점이야말로": ["여기가 핵심인데", "이 포인트가 바로", "여기가 햇심이고"],
        "긍정적으로 보면": ["좋게 보면", "애써서 좋게 보면", "긍정의 얌경으로"],
        "의심스러운 것은": ["수상한 점은", "의문이 드는 건", "이상한 것은"],
        "납득이 가는 것은": ["이해가 되는 것은", "공감할 수 있는 것은", "맞는 말인 것은"],
        "중요한 것은 두말할 나위 없이": [
            "중요한 건 당연한데",
            "중요한 것만큼은",
            "두말 할 필요도 없이",
        ],
    },

    # Synonyms for repetition reduction
    "synonyms": {
        "중요하다": ["핵심적이다", "필수적이다", "빠질 수 없다", "꼭 필요하다"],
        "크다": ["거대하다", "넓다", "방대하다", "큼직하다"],
        "작다": ["조그맣다", "소소하다", "미미하다", "조촐하다"],
        "좋다": ["훌륭하다", "멋지다", "괜찮다", "탁월하다"],
        "나쁘다": ["형편없다", "별로다", "안 좋다", "엉망이다"],
        "빠르다": ["신속하다", "쏜살같다", "재빠르다", "급하다"],
        "느리다": ["더디다", "굼뜨다", "천천히다", "느긋하다"],
        "새롭다": ["신선하다", "최신이다", "참신하다", "새로이"],
        "오래되다": ["낡다", "옛날이다", "역사적이다", "레트로다"],
        "아름답다": ["예쁘다", "멋지다", "근사하다", "화려하다"],
        "강하다": ["튼튼하다", "든든하다", "파워풀하다", "건장하다"],
        "약하다": ["연약하다", "힘없다", "허약하다", "무르다"],
        "어렵다": ["힘들다", "까다롭다", "복잡하다", "만만치 않다"],
        "쉽다": ["간단하다", "수월하다", "거뜬하다", "누워서 떡 먹기다"],
        "시작하다": ["출발하다", "개막하다", "착수하다", "열다"],
        "끝나다": ["마치다", "마무리되다", "종결되다", "완결되다"],
        "일하다": ["근무하다", "노동하다", "맡다", "뛰다"],
        "말하다": ["이야기하다", "전하다", "얘기하다", "발언하다"],
        "생각하다": ["고민하다", "고려하다", "떠올리다", "숙고하다"],
        "보다": ["살펴보다", "관찰하다", "목격하다", "바라보다"],
        "가져가다": ["챙기다", "들다", "잡다", "취하다"],
        "주다": ["건네다", "전하다", "내놓다", "제시하다"],
        "가다": ["떠나다", "향하다", "나아가다", "출발하다"],
        "오다": ["도착하다", "찾아오다", "나타나다", "방문하다"],
        "알다": ["이해하다", "깨닫다", "파악하다", "인지하다"],
        "좋아하다": ["선호하다", "즐기다", "애호하다", "반하다"],
        "원하다": ["바라다", "희망하다", "갈망하다", "꿈꾸다"],
        "할 수 있다": ["가능하다", "해낼 수 있다", "능숙하다", "자격이 되다"],
        "장소": ["곳", "위치", "지점", "자리"],
        "시간": ["때", "시기", "타이밍", "순간"],
        "사람": ["인물", "개인", "이", "분"],
        "일": ["업무", "작업", "임무", "직무"],
        "문제": ["과제", "이슈", "난관", "사안"],
        "해결": ["풀기", "극복", "대처", "처리"],
        "결과": ["성과", "산출", "실적", "효과"],
        "원인": ["이유", "배경", "요인", "근원"],
        "방법": ["방식", "수단", "접근법", "기법"],
        "생각": ["의견", "아이디어", "발상", "견해"],
        "목표": ["목적", "목적지", "타겟", "지향점"],
        "개발": ["제작", "구축", "만들기", "설계"],
        "연구": ["조사", "리서치", "탐구", "분석"],
        "보고": ["알림", "공지", "리포트", "통지"],
        "회의": ["미팅", "모임", "협의", "토론"],
        "계획": ["플랜", "일정", "전략", "청사진"],
        "결정": ["결론", "판단", "선택", "정함"],
        "성공": ["달성", "쾌거", "대박", "승리"],
        "실패": ["좌절", "미스", "불발", "낙방"],
        "변화": ["전환", "바뀜", "이동", "변동"],
        "증가": ["상승", "늘어남", "확대", "급증"],
        "감소": ["하락", "줄어듦", "축소", "급감"],
        "기회": ["찬스", "가능성", "계기", "호기"],
        "도전": ["챌린지", "시련", "과제", "난제"],
        "정보": ["데이터", "자료", "소식", "지식"],
        "주제": ["토픽", "화제", "의제", "테마"],
        "상태": ["컨디션", "형편", "상황", "양상"],
        "나라": ["국가", "국토", "조국", "본국"],
        "정부": ["행정부", "당국", "관청", "공공"],
        "사회": ["세상", "공동체", "세간", "커뮤니티"],
        "문화": ["전통", "풍토", "유산", "문명"],
        "과학": ["사이언스", "학문", "기술", "연구"],
        "교육": ["학습", "배움", "지도", "훈련"],
        "건강": ["컨디션", "체력", "건전", "웰빙"],
        "음식": ["요리", "먹거리", "식사", "식품"],
        "물": ["수분", "음료", "생수"],
        "집": ["주택", "가정", "거처", "살림집"],
        "길": ["도로", "경로", "방향", "루트"],
        "책": ["도서", "서적", "출판물", "읽을거리"],
        "대화": ["이야기", "토크", "수다", "담소"],
        "전쟁": ["분쟁", "싸움", "충돌", "교전"],
        "평화": ["화평", "안정", "평온", "안녕"],
        "자유": ["해방", "독립", "풀림", "리버티"],
        "정의": ["공정", "공평", "올바름", "페어"],
        "동향": ["트렌드", "흐름", "추이", "방향"],
        "시각": ["관점", "시선", "앵글", "보는 눈"],
        "가치": ["의미", "쓸모", "메리트", "보람"],
        "구조": ["틀", "골격", "짜임새", "스트럭쳐"],
        "환경": ["분위기", "맥락", "여건", "조건"],
        "디자인": ["설계", "레이아웃", "꺼함새", "외형"],
        "데이터": ["자료", "사진", "정보량", "숫자"],
        "사용자": ["쓰는 사람", "고객", "이용자", "유저"],
        "실적": ["성과", "트랙 레코드", "실력", "경력"],
        "반응": ["리액션", "응답", "대꽉", "피드백"],
        "논의": ["토론", "디스커션", "대화", "협의"],
        "균형": ["밸런스", "웠만함", "조화", "맞쵤"],
        "리스크": ["위험성", "우려점", "불안 요소", "무리"],
        "비용": ["돈", "값", "매가", "지출"],
        "경제": ["돈벌이", "재정", "시장", "살림"],
        "네트워크": ["인맥", "연결", "커넥션", "망"],
        "전망": ["예측", "비전", "내다보기", "앞날"],
        "프로젝트": ["기획", "사업", "작업", "건"],
        "콘텐츠": ["내용물", "소재", "거리", "실질"],
        "프로세스": ["과정", "절차", "단계", "흐름"],
        "접근법": ["다가가기", "대하는 방식", "어프로치", "태도"],
        "퍼포먼스": ["활약상", "실력 발휘", "성과", "활약"],
        "유연성": ["유동적", "늘를 수 있는", "플렉시블", "신축성"],
        "투명성": ["눈에 보이게", "오픈함", "명확함", "개방적"],
        "동기부여": ["의지", "의욕", "열정", "원동력"],
        "대응력": ["대처 능력", "순발력", "수습력", "장악력"],
        "가능성": ["가망성", "장래성", "보람", "장점"],
        "공감": ["자극", "동조", "따뜰함", "곱씨뛰"],
        "인지": ["이해", "알아보기", "의식", "알려짐"],
        "피드백": ["의견", "반응", "목소리", "후기"],
        "서포트": ["도움", "응원", "지원", "백업"],
        "커뮤니케이션": ["소통", "대화", "전달", "나눔"],
        "기초": ["밑바탕", "토대", "근본", "베이스"],
        "컨셉스트": ["아이디어", "실마리", "원래 생각", "컨셈"],
        "안정성": ["물반엿", "그라지 않음", "틀틀함", "단단함"],
        "능력": ["솔씨", "실력", "도량", "기량"],
        "조사": ["리서치", "따져보기", "체크", "확인"],
        "기업": ["회사", "업체", "사업체", "법인"],
        "예산": ["돈", "자금", "다섯밀터", "비용"],
        "전략": ["작전", "그림", "수단", "로드맵"],
        "정밀도": ["디테일", "세밀함", "품질", "레벨"],
        "경험": ["경력", "체험", "느낌", "맛보기"],
        "내용": ["메인", "소개", "요점", "내막"],
        "과정": ["단계", "절차", "도중", "흐름"],
        "종류": ["타입", "종류별", "카테고리", "종"],
        "평판": ["리뷰", "후기", "평가", "세간의 소리"],
    },

    # Sentence starters -> alternatives
    "sentence_starters": {
        "이것은": ["그것은", "저것은", "이건"],
        "이": ["그", "저", "해당"],
        "그것은": ["이것은", "저것은", "그건"],
        "그는": ["그 사람은", "저 사람은", "본인은"],
        "그녀는": ["그 분은", "저 사람은", "본인은"],
        "나는": ["저는", "제가", "본인은"],
        "우리는": ["저희는", "우리 팀은", "모두는"],
        "그리고": ["그러고", "게다가", "또한"],
        "하지만": ["그런데", "그래도", "그렇지만"],
        "또한": ["그리고", "게다가", "더불어"],
        "만약": ["혹시", "만일", "가령"],
        "왜냐하면": ["그건 왜냐면", "이유는", "그 까닭은"],
        "예를 들어": ["가령", "구체적으로", "한 예로"],
        "사실은": ["실은", "솔직히", "따지고 보면"],
        "최근": ["요즘", "근래", "요사이"],
        "지금": ["현재", "이 순간", "오늘날"],
        "먼저": ["우선", "처음에", "일단"],
        "다음으로": ["이어서", "그다음", "후속으로"],
        "마지막으로": ["끝으로", "최종적으로", "결론적으로"],
        "일반적으로": ["보통은", "대체로", "통상적으로"],
        "결국": ["마침내", "최종적으로", "끝내"],
        "실제로": ["진짜로", "현실적으로", "사실상"],
        "기본적으로": ["근본적으로", "원칙적으로", "본래"],
        "다행히": ["고맙게도", "운 좋게도", "다행스럽게도"],
        "안타깝게도": ["아쉽게도", "불행히도", "유감스럽게도"],
        "그런 와중에": ["그 와중에도", "그와 동시에", "이런 상황 속에서"],
        "과감히": ["단호히", "풀어 말하면", "그냥"],
        "결국에는": ["끝에 가서는", "마침내는", "돌고 돌면"],
        "이미": ["벨써", "전에", "진운"],
        "사라면사라": ["그만큼", "그러니까", "그래서야"],
        "점차적으로": ["조금씩", "천천히", "조금씩 점점"],
        "기억에 새로운": ["얼마 전의", "최근의", "아직 새로운"],
        "얼핫 보면": ["첫눈에는", "겉보기에는", "한눈에"],
        "처음부터": ["기본부터", "시작부터", "처음 말에부터"],
        "그때마다": ["그럴 때마다", "그러면 항상", "그러면 늘"],
        "어떤 종류의": ["어떤 의미에서의", "일종의", "모종의"],
        "한마디로 말하기 어렵지만": [
            "단순하게 말하기 어렵지만",
            "뭉뚝그려 말하기 힘들지만",
            "간단하지는 않지만",
        ],
        "계기는": ["시작은", "계기라고 하면", "첫 발단은"],
        "적어도": ["최소한", "하다못해", "그래도"],
    },

    # Colloquial markers for chat/web profiles
    "colloquial_markers": [
        "그런데 말이야",
        "사실은",
        "솔직히 말하면",
        "간단히 말해서",
        "쉽게 말하면",
        "재미있는 건",
        "심플하게",
        "요는",
        "진짜는",
        "결국에는",
        "뭐",
        "어쨌든",
        "솔직히",
        "이래저래",
        "어찌됐든",
        "핵심은",
        "포인트는",
        "다시 말하면",
        "달리 말하면",
        "오해하지 마",
        "그러고 보니",
        "그건 그렇고",
        "물론이지",
        "당연하지",
        "역시나",
        "그러니까",
        "그런 셈이지",
        "의외로",
        "어느 정도",
        "결국은",
        "솔직하게 말해",
        "한마디로",
        "개인적으로는",
        "진짜로",
        "정말로",
        "원래",
        "아무튼",
        "확실히",
        "실제로는",
        "솔까말",
        "잘 들어봐",
        "너 말대로 생각하면",
        "사실 별거 아니야",
        "그것 보무 누구나",
        "이렇게 보면",
        "사실 이게 맞거든",
        "솔직히 말해서",
        "어디 보자",
        "어떻게 보면",
        "여기서 중요한 건",
        "생각해 보니까",
        "어쩌면",
        "재밌는 게",
        "이 부분이 핵심인데",
        "아직도 기억나는데",
        "지금 와서 보니까",
        "개인적으로 느끼기로는",
        "모르긴 하지만",
        "그런 느낌이야",
    ],

    # Abbreviations (don't split sentences after these)
    "abbreviations": [
        "씨", "님", "군", "양",
        "Dr", "Mr", "Ms", "Prof",
        "No", "Vol", "Fig",
        "km", "cm", "mm", "kg", "mg", "ml",
        "만", "억", "조",
        "주", "사", "법",
        "etc", "e.g", "i.e",
        "℃", "％",
        "약", "제", "대",
        "vs",
        "a.m", "p.m",
        "Jr", "Sr",
        "Corp", "Inc", "Ltd",
        "co", "dept",
    ],

    # Perplexity boosters (rare/unusual phrases to raise perplexity)
    "perplexity_boosters": [
        "말하자면",
        "그의 말을 빌리자면",
        "어떤 형태로든",
        "보아하니",
        "모든 기준으로 볼 때",
        "최소한",
        "공정하게 말하면",
        "그것과는 별개로",
        "굳이 말할 필요도 없이",
        "우선 먼저",
        "어쨌든 간에",
        "운명의 장난인지",
        "갑자기",
        "알다시피",
        "예상과 달리",
        "필연적으로",
        "마땅히",
        "다른 관점에서",
        "그 소용돌이 속에서",
        "의심할 바 없이",
        "특히나",
        "그것이 요구되는 바이며",
        "이해되는 한에서는",
        "사건의 와중에",
        "현실적으로 보면",
        "기복 속에서",
        "기로에 서서",
        "때때로",
        "우연의 일치가 아니라",
        "실제로는",
        "다른 각도에서 보면",
        "어떤 경우에도",
        "이런 상황에서",
        "놀랍지도 않지만",
        "아이러니하게도",
        "동등하게",
        "최종적으로는",
        "더욱 놀라운 것은",
        "정확히 말하자면",
        "이렇게 말하는 사람도 있다",
        "세부사항에 눈을 돌리면",
        "사실상의 확신으로",
        "의심의 여지없이",
        "가벼이 말할 수 없지만",
        "더 정확한 표현을 쓰자면",
        "결과론의 정체는",
        "말이 나온 김에",
        "오해를 무륦쓰고 말하자면",
        "말을 되돌리자면",
        "한울타리에서는",
        "단순하게 말하자면",
        "보는 눈을 바꾸면",
        "굳이 말하자면",
        "큰 시각에서 보면",
        "일반적인 표현이지만",
        "경험에 비춰보면",
        "설명을 덧붙이면",
        "어쩜면 의문인데",
        "외과수술적으로도",
    ],

    # Profile metric targets
    "profile_targets": {
        "chat": {"avg_sentence_len": (5, 14), "max_sentence_len": 22},
        "web": {"avg_sentence_len": (7, 18), "max_sentence_len": 30},
        "seo": {"avg_sentence_len": (8, 20), "max_sentence_len": 35},
        "docs": {"avg_sentence_len": (8, 22), "max_sentence_len": 40},
        "formal": {"avg_sentence_len": (10, 25), "max_sentence_len": 45},
    },

    # Conjunctions for joining short sentences
    "conjunctions": ["그리고", "하지만", "또는", "그래서", "한편", "그렇지만", "게다가"],

    # Split conjunctions for breaking long sentences
    "split_conjunctions": [
        ", 하지만", ", 그리고", ", 그럼에도", ", 에도 불구하고",
        ", 한편", ", 다른 한편으로", ", 다만",
        ", 그래서", ", 라는", ". ", " ― ",
        ", 왜냐하면", ", 그건", ", 그렇지 않으면",
        ", 설령", ", 하더라도", ", 그렇지만",
        ", 혹은", ", 한 후", ", 하기 전에",
        ", 할 때", ", 까지", ", 그런데",
        ", 할 때면", ", 즉", ", 라는 것은",
        ", 게다가", ", 도 아니고", ", 라기보다는",
        ", 따라서", ", 이렇게", ", 그래서",
        ", 그러므로", ", 더불어", ", 거기에 더해",
        ", 대신에", ", 특히", ", 다시 말해",
        " – ",
    ],
}
