"""حزمة اللغة العربية."""

LANG_AR = {
    "code": "ar",
    "name": "Arabic",
    "native_name": "العربية",

    # Common trigrams for language detection
    "trigrams": [
        "ال ", " ال", "في ", " في", "من ", " من", "على", " عل",
        "لى ", "ان ", " ان", "ما ", " ما", "ات ", "ية ", "ين ",
        "ها ", " وا", "وال", "لا ", " لا", "ذا ", "هذا", " هذ",
        "ون ", "ام ", " با", "بال", "لل ", " لل", "عة ", "مة ",
        "تي ", "ري ", "دي ", " إل", "إلى", "كا ", " كا", "نا ",
    ],

    # Stop words
    "stop_words": {
        "في", "من", "على", "إلى", "عن", "مع", "هذا", "هذه", "ذلك",
        "تلك", "التي", "الذي", "الذين", "اللتان", "هو", "هي", "هم",
        "هن", "نحن", "أنا", "أنت", "أنتم", "كان", "كانت", "يكون",
        "تكون", "ليس", "ليست", "أن", "إن", "لا", "لم", "لن", "قد",
        "ما", "هل", "أو", "ثم", "بل", "لكن", "و", "ف", "ب", "ل",
        "ك", "حتى", "كل", "بعض", "غير", "بين", "عند", "فوق", "تحت",
        "أمام", "خلف", "بعد", "قبل", "مثل", "منذ", "حول", "خلال",
        "أي", "كيف", "أين", "متى", "لماذا", "ماذا", "كم",
    },

    # Bureaucratic / overly formal words -> simpler alternatives
    "bureaucratic": {
        "يستخدم": ["يستعمل", "يوظّف"],
        "استخدام": ["استعمال", "توظيف"],
        "يُنفّذ": ["يعمل", "يطبّق"],
        "تنفيذ": ["تطبيق", "إنجاز"],
        "يُسهّل": ["يساعد", "ييسّر"],
        "تسهيل": ["مساعدة", "تيسير"],
        "يبدأ": ["يشرع", "ينطلق"],
        "يُنهي": ["يوقف", "يختم"],
        "إنهاء": ["إيقاف", "ختام"],
        "لاحقاً": ["بعدها", "فيما بعد"],
        "بالتالي": ["لذا", "وعليه"],
        "علاوة على ذلك": ["كذلك", "وأيضاً"],
        "مع ذلك": ["لكن", "رغم ذلك"],
        "بالرغم من": ["رغم", "على الرغم من"],
        "المذكور آنفاً": ["السابق", "المشار إليه"],
        "من الآن فصاعداً": ["من الآن", "بدءاً من اليوم"],
        "سابقاً": ["قبل ذلك", "من قبل"],
        "يسعى": ["يحاول", "يجتهد"],
        "مسعى": ["محاولة", "جهد"],
        "يتحقّق": ["يتأكّد", "يتثبّت"],
        "يحصل على": ["يأخذ", "ينال"],
        "ينشر": ["يوزّع", "يبثّ"],
        "يُعدّد": ["يسرد", "يحصي"],
        "يوضّح": ["يشرح", "يبيّن"],
        "إيضاح": ["شرح", "تبيين"],
        "يُحدّد": ["يرسم", "يعيّن"],
        "يُثبت": ["يبرهن", "يدلّل"],
        "يُحسّن": ["يطوّر", "يرفع مستوى"],
        "يُفاقم": ["يزيد سوءاً", "يضاعف"],
        "يُخفّف": ["يقلّل", "يحدّ من"],
        "يُديم": ["يواصل", "يستمرّ في"],
        "يُعلن": ["يصرّح", "ينشر"],
        "يشترط": ["يتطلّب", "يلزم"],
        "غالباً": ["في الغالب", "في أكثر الأحيان"],
        "تقريباً": ["حوالي", "ما يقارب"],
        "كافٍ": ["يكفي", "مناسب"],
        "غير كافٍ": ["لا يكفي", "ناقص"],
        "عديد": ["كثير", "وافر"],
        "جوهري": ["أساسي", "مهمّ"],
        "كبير": ["ضخم", "واسع"],
        "يُبرهن": ["يُظهر", "يُدلّل"],
        "يستلزم": ["يتطلّب", "يحتاج"],
        "منهجية": ["طريقة", "أسلوب"],
        "فرد": ["شخص", "إنسان"],
        "أفراد": ["أشخاص", "ناس"],
        "بشأن": ["عن", "حول"],
        "يتعلّق بـ": ["يخصّ", "يرتبط بـ"],
        "من أجل": ["لكي", "حتى"],
        "قبل": ["سابقاً", "مسبقاً"],
        "ينجز": ["يكمل", "ينهي"],
        "وفقاً لذلك": ["لذا", "بناءً عليه"],
        "يجمع": ["يحشد", "يكدّس"],
        "ملائم": ["مناسب", "موافق"],
        "يُدير": ["يشرف على", "يتولّى"],
        "مفيد": ["نافع", "مجدٍ"],
        "إجمالي": ["كلّي", "شامل"],
        "يُخصّص": ["يوزّع", "يفرز"],
        "تخصيص": ["توزيع", "إفراز"],
        "بديل": ["خيار آخر", "حلّ بديل"],
        "يدمج": ["يوحّد", "يمزج"],
        "يتوقّع": ["يستشرف", "يرقب"],
        "توقّع": ["استشراف", "ترقّب"],
        "جهاز": ["أداة", "آلة"],
        "مُلحق": ["إضافة", "تذييل"],
        "قابل للتطبيق": ["مناسب", "ملائم"],
        "يوزّع": ["يقسّم", "يجزّئ"],
        "يُبلغ": ["يُعلم", "يُخطر"],
        "يُعبّر": ["يقول", "يصوغ"],
        "يستوعب": ["يمتصّ", "يتشرّب"],
        "يزيد": ["يرفع", "يعزّز"],
        "يستسلم": ["يذعن", "ينصاع"],
        "يُصنّف": ["يبوّب", "يرتّب"],
        "توقّف": ["انقطاع", "كفّ"],
        "يتفادى": ["يتجنّب", "يتحاشى"],
        "يندمج": ["يتّحد", "يتمازج"],
        "مُدرك": ["واعٍ", "منتبه"],
        "يتعاون": ["يشترك", "يتكاتف"],
        "كُفء": ["قادر", "مؤهّل"],
        "عنصر": ["جزء", "مكوّن"],
        "شامل": ["كامل", "متكامل"],
        "إلزامي": ["واجب", "مفروض"],
        "مُتعدّد": ["كثير", "متنوّع"],
        "مُحتمل": ["ممكن", "وارد"],
        "مُعتبر": ["كبير", "لا بأس به"],
        "مُتاح": ["موجود", "في المتناول"],
        "مُستدام": ["دائم", "مستمرّ"],
        "مُتوقّع": ["منتظَر", "مرتقب"],
        "مُستحسن": ["يُفضَّل", "الأفضل"],
        "يُرسي": ["يضع", "يؤسّس"],
        "يُعيد هيكلة": ["يعيد ترتيب", "ينظّم من جديد"],
        "يُصادق": ["يوافق", "يقرّ"],
        "يُدشّن": ["يفتتح", "يطلق"],
        "يُلغي": ["يبطل", "يحذف"],
        "يُرجئ": ["يؤجّل", "يؤخّر"],
        "يُقيّد": ["يحدّ", "يضيّق"],
        "يُعارض": ["يرفض", "يخالف"],
        "يُصدر": ["يُنتج", "يُخرج"],
        "يُراجع": ["يدقّق", "يتفحّص"],
        "يُنسّق": ["يرتّب", "ينظّم"],
        "يُطوّر": ["يحسّن", "يرقّي"],
        "يتضمّن": ["يشمل", "يحتوي على"],
        "يُنجز": ["يتمّ", "يُكمل"],
        "مُفصّل": ["مفصَّل", "دقيق"],
        "جذري": ["عميق", "شامل"],
        "مُتكامل": ["كامل", "تامّ"],
        "مُؤقّت": ["لفترة", "مرحلي"],
        "يُقرّ": ["يعترف", "يوافق"],
        "يتابع": ["يستمرّ في", "يلاحق"],
        "يُوثّق": ["يسجّل", "يدوّن"],
        "يتخطّى": ["يتجاوز", "يعبر"],
        "يستحسن": ["يفضّل", "يستصوب"],
        "مُتخصّص": ["خبير", "متمرّس"],
        "يُساهم": ["يشارك في", "يسهم في"],
        "يتعهّد": ["يلتزم", "يتكفّل"],
        "يُبادر": ["يسبق", "يأخذ زمام"],
        "يستقطب": ["يجذب", "يجتذب"],
        "مُتسارع": ["سريع", "متزايد"],
        "يُواكب": ["يتابع", "يسايِر"],
        "يتصدّى": ["يواجه", "يقاوم"],
        "يستدرك": ["يتدارك", "يصحّح"],
        "يرصد": ["يتتبّع", "يلاحظ"],
        "يُفعّل": ["ينشّط", "يشغّل"],
        "يُلزم": ["يوجب", "يفرض"],
        "يُحيل": ["يوجّه", "ينقل"],
        "يُنوّه": ["يشير", "يلفت النظر"],
        "يُعقد": ["يُقام", "ينظَّم"],
        "يستعرض": ["يعرض", "يقدّم"],
        "يتبنّى": ["يعتمد", "يأخذ بـ"],
        "يترتّب": ["ينتج", "ينجم"],
        "مُلتزم": ["متمسّك", "حريص"],
        "يتعاطى": ["يتعامل", "يتناول"],
        "يُقدّر": ["يثمّن", "يحترم"],
        "يتخلّى": ["يتنازل", "يستغني"],
        "يُعزّز": ["يقوّي", "يدعم"],
        "يُعاين": ["يكشف", "يفحص"],
        "يُباشر": ["يبدأ", "يشرع في"],
        "يُواظب": ["يداوم", "يستمرّ"],
        "يستنبط": ["يستخلص", "يستنتج"],
        "مُتواضع": ["بسيط", "قليل"],
    },

    # Bureaucratic phrases -> simpler versions
    "bureaucratic_phrases": {
        "من المهمّ الإشارة إلى أنّ": ["تجدر الإشارة إلى", "يُلاحظ أنّ"],
        "تجدر الإشارة إلى أنّ": ["يُلاحظ أنّ", "نشير إلى أنّ"],
        "من الجدير بالذكر أنّ": ["يُذكر أنّ", "نلاحظ أنّ"],
        "غنيّ عن القول أنّ": ["من الواضح أنّ", "بالطبع"],
        "في حال": ["إذا", "عندما"],
        "نظراً لأنّ": ["لأنّ", "بسبب أنّ"],
        "في ضوء حقيقة أنّ": ["لأنّ", "بما أنّ"],
        "لغرض": ["من أجل", "بهدف"],
        "فيما يتعلّق بـ": ["بخصوص", "عن"],
        "بالنسبة إلى": ["أمّا عن", "فيما يخصّ"],
        "وفقاً لـ": ["حسب", "تبعاً لـ"],
        "بالتزامن مع": ["مع", "إلى جانب"],
        "في الوقت الراهن": ["الآن", "حالياً"],
        "في الوقت الحالي": ["الآن", "حالياً"],
        "في المناخ الحالي": ["اليوم", "حالياً"],
        "في واقع الأمر": ["في الحقيقة", "فعلاً"],
        "بحكم": ["بسبب", "بفضل"],
        "على أساس": ["بناءً على", "استناداً إلى"],
        "في غالبية الحالات": ["عادةً", "في الغالب"],
        "عدد كبير من": ["كثير من", "عدّة"],
        "كمّية كبيرة من": ["الكثير من", "قدر وافر من"],
        "على مقربة من": ["قرب", "بالقرب من"],
        "لديه القدرة على": ["يستطيع", "يقدر على"],
        "قادر على": ["يستطيع", "بإمكانه"],
        "يأخذ بعين الاعتبار": ["يراعي", "يأخذ في الحسبان"],
        "يتّخذ قراراً": ["يقرّر", "يحسم"],
        "يتوصّل إلى نتيجة": ["يستنتج", "يخلص إلى"],
        "يتوصّل إلى توافق": ["يتّفق", "يصل إلى اتّفاق"],
        "نتيجةً لذلك": ["بسبب ذلك", "لهذا السبب"],
        "كوسيلة لـ": ["من أجل", "بهدف"],
        "في نهاية المطاف": ["في النهاية", "أخيراً"],
        "في الوقت نفسه": ["في آنٍ واحد", "بالتوازي"],
        "بناءً على افتراض أنّ": ["إذا افترضنا", "بافتراض أنّ"],
        "مهما يكن من أمر": ["على أيّ حال", "رغم ذلك"],
        "يضع حدّاً لـ": ["يُنهي", "يوقف"],
        "بواسطة": ["عبر", "من خلال"],
        "على الرغم من أنّ": ["رغم أنّ", "مع أنّ"],
        "خلال فترة": ["أثناء", "في أثناء"],
        "للسبب القائل بأنّ": ["لأنّ", "بما أنّ"],
        "من وجهة نظر": ["حسب رأي", "في نظر"],
        "على سبيل المثال لا الحصر": ["مثلاً", "كمثال"],
        "يُعدّ من الأمور الجوهرية": ["مهمّ جدّاً", "أساسي"],
        "في إطار السعي إلى": ["سعياً إلى", "بهدف"],
        "يتوجّب علينا الإشارة إلى": ["نشير إلى", "ينبغي ذكر"],
        "لا يسعنا إلّا أن": ["لا بدّ أن", "يجب أن"],
        "ينبغي الأخذ بعين الاعتبار": ["يجب مراعاة", "لا بدّ من التنبّه إلى"],
        "بصورة متزامنة": ["في الوقت نفسه", "معاً"],
        "في ضوء المعطيات": ["بحسب الوقائع", "بناءً على الأدلّة"],
        "بموجب الاتّفاق": ["حسب الاتّفاق", "وفق ما اتُّفق عليه"],
        "في سياق الحديث عن": ["بخصوص", "عند الحديث عن"],
        "بغية تحقيق": ["من أجل", "بهدف"],
        "في مستهلّ": ["في بداية", "أوّل"],
        "على صلة وثيقة بـ": ["مرتبط بـ", "له علاقة بـ"],
        "بمقتضى": ["بموجب", "حسب"],
        "لا يخفى على أحد أنّ": ["من الواضح أنّ", "الجميع يعلم أنّ"],
        "يُمكن القول بأنّ": ["يبدو أنّ", "نقول إنّ"],
        "على النحو التالي": ["كالآتي", "هكذا"],
        "فيما يلي": ["أدناه", "التالي"],
        "ممّا سبق ذكره": ["كما ذكرنا", "ممّا قلناه"],
    },

    # AI connector phrases -> replacements
    "ai_connectors": {
        "ومع ذلك": ["لكن", "غير أنّ", "إلّا أنّ"],
        "بالرغم من ذلك": ["لكن", "رغم ذلك", "مع هذا"],
        "بالإضافة إلى ذلك": ["كذلك", "وأيضاً", "إلى جانب ذلك"],
        "فضلاً عن ذلك": ["وكذلك", "وأيضاً", "إضافة إلى ذلك"],
        "وبالتالي": ["لذا", "ومن ثمّ", "وعليه"],
        "لذلك": ["لهذا", "ومن ثمّ", "وعليه"],
        "وهكذا": ["بهذا", "بهذه الطريقة", "وبذلك"],
        "بلا شكّ": ["بالطبع", "حتماً", "بالتأكيد"],
        "ممّا لا شكّ فيه": ["بالتأكيد", "من الواضح", "حتماً"],
        "في الختام": ["خلاصة القول", "إجمالاً", "في النهاية"],
        "ختاماً": ["في النهاية", "وأخيراً", "خلاصة القول"],
        "أوّلاً وقبل كلّ شيء": ["أوّلاً", "في البداية", "الأهمّ"],
        "من ناحية أخرى": ["لكن", "في المقابل", "بينما"],
        "على النقيض من ذلك": ["لكن", "عكس ذلك", "بالعكس"],
        "بشكل عامّ": ["عموماً", "إجمالاً", "في العموم"],
        "على وجه الخصوص": ["خصوصاً", "تحديداً", "بالذات"],
        "من الجدير بالملاحظة": ["يُلاحظ أنّ", "تجدر الإشارة", "نلفت إلى"],
        "من الأهمّية بمكان": ["من المهمّ", "ينبغي", "يجب"],
        "باختصار": ["بإيجاز", "في كلمات قليلة", "خلاصة القول"],
        "نتيجة لذلك": ["لذا", "بسبب هذا", "ممّا أدّى إلى"],
        "في جوهر الأمر": ["ببساطة", "في الأساس", "في صلب الموضوع"],
        "بشكل ملحوظ": ["كثيراً", "بدرجة كبيرة", "بوضوح"],
        "من المسلّم به": ["بالطبع", "من الواضح", "لا ريب"],
        "كبديل": ["أو", "بدلاً من ذلك", "وإلّا"],
        "على ما يبدو": ["يبدو أنّ", "ظاهرياً", "كما يظهر"],
        "كما ذُكر سابقاً": ["كما أشرنا", "كما قلنا", "سابقاً"],
        "كما ورد آنفاً": ["كما ذكرنا", "كما سبق", "آنفاً"],
        "بصورة عامّة": ["عموماً", "تقريباً", "غالباً"],
        "في المجمل": ["إجمالاً", "عموماً", "على العموم"],
        "بالتأكيد": ["حتماً", "قطعاً", "من المؤكّد"],
        "من الواضح": ["جليّاً", "بوضوح", "ظاهراً"],
        "في الوقت ذاته": ["بالتوازي", "معاً", "في آنٍ واحد"],
        "على العكس": ["بالمقابل", "عكس ذلك", "بينما"],
        "بالمثل": ["كذلك", "على نحو مماثل", "بالطريقة نفسها"],
        "جوهرياً": ["أساساً", "في العمق", "في الصميم"],
        "بلا ريب": ["بالتأكيد", "دون شكّ", "حتماً"],
        "في هذا السياق": ["هنا", "في هذا الإطار", "ضمن هذا"],
        "في هذا الصدد": ["بخصوص هذا", "حول هذا", "عن هذا"],
        "بدوره": ["ثمّ", "بعد ذلك", "تالياً"],
        "في الحقيقة": ["فعلاً", "واقعاً", "حقّاً"],
        "من المثير للاهتمام": ["الطريف أنّ", "اللافت أنّ", "الغريب أنّ"],
        "وبالمثل": ["كذلك", "على غرار ذلك", "مثله"],
        "في غضون ذلك": ["في هذه الأثناء", "وفي الوقت نفسه", "بينما"],
        "والأهمّ من ذلك": ["والأبرز", "والأكثر أهمّية", "وما يهمّ أكثر"],
        "وعلى وجه التحديد": ["تحديداً", "بالتحديد", "بالضبط"],
        "بطبيعة الحال": ["من الطبيعي", "كما هو متوقّع", "بالتأكيد"],
        "ممّا يعني أنّ": ["أي أنّ", "بمعنى أنّ", "وهذا يدلّ على"],
        "على ضوء ما سبق": ["بناءً على ذلك", "استناداً لما ذُكر", "تبعاً لذلك"],
        "بالدرجة الأولى": ["أوّلاً", "قبل كلّ شيء", "في المقام الأوّل"],
        "من حيث المبدأ": ["مبدئياً", "كقاعدة عامّة", "نظرياً"],
        "بالقدر نفسه": ["بنفس الدرجة", "بالمثل", "كذلك"],
        "على نحو استثنائي": ["بشكل خاصّ", "بصورة فريدة", "استثنائياً"],
        "في واقع الحال": ["في الحقيقة", "عملياً", "واقعاً"],
        "يتجلّى ذلك في": ["يظهر ذلك في", "يتّضح من", "نرى ذلك في"],
        "ليس ذلك فحسب": ["وليس هذا فقط", "بل أيضاً", "والأكثر من ذلك"],
        "الأمر الذي يستدعي": ["ما يتطلّب", "ممّا يوجب", "وهذا يدعو إلى"],
        "من هذا المنطلق": ["انطلاقاً من هذا", "بناءً على ذلك", "لهذا السبب"],
        "بصرف النظر عن": ["بغضّ النظر عن", "بعيداً عن", "دون اعتبار لـ"],
        "من باب أولى": ["من الأحرى", "أولى بنا", "والأجدر"],
        "من زاوية أخرى": ["من جانب آخر", "من منظور مختلف", "بنظرة مغايرة"],
        "وممّا يؤكّد ذلك": ["والدليل على ذلك", "وما يثبته", "وتأكيداً لذلك"],
        "في خاتمة المطاف": ["في النهاية", "ختاماً", "في آخر الأمر"],
        "تأسيساً على ذلك": ["بناءً على ذلك", "وفقاً لذلك", "اعتماداً على ذلك"],
        "على نحو متزايد": ["أكثر فأكثر", "بشكل متصاعد", "باطّراد"],
        "ثمّة حاجة ماسّة إلى": ["نحتاج كثيراً إلى", "لا بدّ من", "من الضروري"],
    },

    # Synonyms for repetition reduction
    "synonyms": {
        "مهمّ": ["أساسي", "جوهري", "ضروري", "حيوي"],
        "صغير": ["ضئيل", "قليل", "محدود", "يسير"],
        "جيّد": ["حسن", "ممتاز", "رائع", "طيّب"],
        "سيّئ": ["رديء", "ضعيف", "مُتدنٍّ", "فاسد"],
        "سريع": ["عاجل", "خاطف", "متسارع", "وشيك"],
        "بطيء": ["متمهّل", "متأنٍّ", "خامل", "ثقيل"],
        "جديد": ["حديث", "مستحدَث", "عصري", "طازج"],
        "قديم": ["عتيق", "سابق", "تاريخي", "موروث"],
        "جميل": ["حسن", "بديع", "فاتن", "رائع"],
        "قبيح": ["بشع", "منفّر", "كريه", "سمج"],
        "قويّ": ["متين", "صلب", "راسخ", "شديد"],
        "ضعيف": ["هزيل", "واهن", "هشّ", "خائر"],
        "صعب": ["شاقّ", "عسير", "معقّد", "متعذّر"],
        "سهل": ["يسير", "بسيط", "هيّن", "ميسور"],
        "ينتهي": ["يكتمل", "يختم", "ينقضي", "يتوقّف"],
        "يعمل": ["يشتغل", "يزاول", "يمارس", "ينشط"],
        "يقول": ["يذكر", "يصرّح", "يعبّر", "يفيد"],
        "يفكّر": ["يتأمّل", "يتدبّر", "يمعن", "يتروّى"],
        "يرى": ["يلاحظ", "يشاهد", "يعاين", "يدرك"],
        "يأخذ": ["يتناول", "يقتني", "ينتزع", "يحوز"],
        "يعطي": ["يمنح", "يقدّم", "يهب", "يجود"],
        "يذهب": ["ينصرف", "يتوجّه", "يرحل", "يمضي"],
        "يأتي": ["يحضر", "يصل", "يقدم", "يوافي"],
        "يعرف": ["يدرك", "يعلم", "يدري", "يفقه"],
        "يحبّ": ["يودّ", "يعشق", "يهوى", "يفضّل"],
        "يريد": ["يرغب", "يودّ", "يبتغي", "يتمنّى"],
        "يستطيع": ["يقدر", "بوسعه", "بمقدوره", "يتمكّن"],
        "مكان": ["موقع", "موضع", "بقعة", "محلّ"],
        "وقت": ["زمن", "حين", "فترة", "أوان"],
        "شخص": ["إنسان", "فرد", "امرؤ", "نفس"],
        "عمل": ["شغل", "وظيفة", "مهنة", "حرفة"],
        "مشكلة": ["إشكالية", "معضلة", "عقبة", "أزمة"],
        "حلّ": ["معالجة", "تسوية", "علاج", "مخرج"],
        "نتيجة": ["حصيلة", "مخرج", "عاقبة", "ثمرة"],
        "سبب": ["دافع", "باعث", "عامل", "علّة"],
        "طريقة": ["أسلوب", "منهج", "وسيلة", "سبيل"],
        "فكرة": ["رأي", "خاطرة", "تصوّر", "مفهوم"],
        "هدف": ["غاية", "مقصد", "مرمى", "مسعى"],
        "تطوير": ["تحسين", "تنمية", "ترقية", "إصلاح"],
        "دراسة": ["بحث", "تحليل", "استقصاء", "فحص"],
        "تقرير": ["بيان", "إفادة", "تحليل", "عرض"],
        "اجتماع": ["لقاء", "جلسة", "مؤتمر", "ندوة"],
        "خطّة": ["استراتيجية", "برنامج", "مخطّط", "تصوّر"],
        "قرار": ["حكم", "فصل", "بتّ", "توجيه"],
        "نجاح": ["فلاح", "توفيق", "تفوّق", "إنجاز"],
        "فشل": ["إخفاق", "خيبة", "انهيار", "تعثّر"],
        "تغيير": ["تبديل", "تعديل", "تحويل", "تحوّل"],
        "زيادة": ["ارتفاع", "نموّ", "تصاعد", "تضخّم"],
        "نقص": ["عجز", "شحّ", "قصور", "تراجع"],
        "فرصة": ["مناسبة", "سانحة", "إمكانية", "حظّ"],
        "تحدٍّ": ["صعوبة", "عقبة", "اختبار", "امتحان"],
        "معلومات": ["بيانات", "معطيات", "تفاصيل", "حقائق"],
        "موضوع": ["مسألة", "قضية", "شأن", "أمر"],
        "حال": ["وضع", "ظرف", "حالة", "شأن"],
        "بلد": ["دولة", "وطن", "قطر", "إقليم"],
        "حكومة": ["سلطة", "إدارة", "نظام", "دولة"],
        "مجتمع": ["جماعة", "أمّة", "بيئة", "وسط"],
        "ثقافة": ["حضارة", "تراث", "موروث", "هويّة"],
        "علم": ["معرفة", "فنّ", "تخصّص", "عِلم"],
        "تعليم": ["تدريس", "تربية", "إعداد", "تأهيل"],
        "صحّة": ["عافية", "سلامة", "لياقة", "معافاة"],
        "طعام": ["غذاء", "أكل", "قوت", "مأكولات"],
        "ماء": ["مياه", "سائل", "شراب"],
        "بيت": ["منزل", "مسكن", "دار", "مأوى"],
        "طريق": ["درب", "سبيل", "مسار", "ممرّ"],
        "كتاب": ["مؤلَّف", "مصنَّف", "إصدار", "أثر"],
        "كلام": ["حديث", "قول", "خطاب", "تصريح"],
        "حرب": ["نزاع", "صراع", "قتال", "معركة"],
        "سلام": ["أمان", "هدوء", "طمأنينة", "وئام"],
        "حرّية": ["استقلال", "تحرّر", "انعتاق", "إرادة"],
        "عدالة": ["إنصاف", "قسط", "مساواة", "حقّ"],
        "حقّ": ["صواب", "استحقاق", "أحقّية", "عدل"],
        "واجب": ["التزام", "فرض", "مسؤولية", "تكليف"],
        "أمل": ["رجاء", "تطلّع", "تفاؤل", "طموح"],
        "خوف": ["رهبة", "فزع", "قلق", "وجَل"],
        "سعادة": ["فرح", "بهجة", "سرور", "مسرّة"],
        "حزن": ["أسى", "كآبة", "غمّ", "كدر"],
        "قوّة": ["طاقة", "جبروت", "بأس", "عزيمة"],
        "تأثير": ["أثر", "مفعول", "وقع", "انعكاس"],
        "وسيلة": ["أداة", "طريقة", "آلية", "ذريعة"],
        "مجال": ["حقل", "ميدان", "نطاق", "ساحة"],
        "مرحلة": ["طور", "فترة", "حقبة", "خطوة"],
        "دور": ["مهمّة", "وظيفة", "شأن", "إسهام"],
        "رأي": ["وجهة نظر", "موقف", "اعتقاد", "قناعة"],
        "ظاهرة": ["حادثة", "مظهر", "واقعة", "ملمح"],
        "بنية": ["تركيبة", "هيكل", "إطار", "قالب"],
        "إطار": ["سياق", "نطاق", "حدود", "بنية"],
        "منصّة": ["موقع", "قاعدة", "ملتقى", "مِنبر"],
        "مسار": ["درب", "خطّ", "اتّجاه", "منحى"],
        "شراكة": ["تعاون", "تحالف", "ائتلاف", "مشاركة"],
        "استقرار": ["ثبات", "هدوء", "رسوخ", "توازن"],
        "تنافس": ["منافسة", "سباق", "مزاحمة", "تسابق"],
        "رفاهية": ["ازدهار", "رخاء", "يسر", "نعيم"],
        "وعي": ["إدراك", "انتباه", "تيقّظ", "بصيرة"],
        "إبداع": ["ابتكار", "خلق", "تجديد", "اختراع"],
        "كفاءة": ["مهارة", "جدارة", "أهليّة", "براعة"],
        "مرونة": ["ليونة", "طواعية", "تكيّف", "انسياب"],
        "شفافية": ["وضوح", "صراحة", "انكشاف", "جلاء"],
        "استدامة": ["ديمومة", "استمرارية", "بقاء", "دوام"],
        "بيئة": ["محيط", "وسط", "ظروف", "أجواء"],
        "طموح": ["تطلّع", "حلم", "رغبة", "همّة"],
        "خبرة": ["تجربة", "دراية", "ممارسة", "كفاءة"],
        "قيادة": ["ريادة", "زعامة", "إدارة", "توجيه"],
        "مبادرة": ["خطوة", "مشروع", "بادرة", "عمل"],
        "تواصل": ["اتّصال", "تفاعل", "ترابط", "حوار"],
        "تضامن": ["تكاتف", "تآزر", "وحدة", "تلاحم"],
        "ازدهار": ["نموّ", "رخاء", "تقدّم", "انتعاش"],
        "عقلانية": ["رشد", "تعقّل", "حصافة", "منطقية"],
        "مناخ": ["أجواء", "طقس", "بيئة", "ظروف"],
        "منظومة": ["نظام", "شبكة", "تركيبة", "مجموعة"],
        "حوار": ["نقاش", "محادثة", "تبادل", "مداولة"],
        "توازن": ["اعتدال", "تكافؤ", "تناسب", "تعادل"],
        "سلطة": ["نفوذ", "هيمنة", "صلاحية", "ولاية"],
        "اقتصاد": ["معيشة", "تدبير", "مالية", "موارد"],
        "تربية": ["تنشئة", "إعداد", "تعليم", "تهذيب"],
        "مصير": ["مآل", "عاقبة", "نهاية", "قدر"],
        "هويّة": ["أصالة", "ذاتية", "شخصية", "انتماء"],
        "إنجاز": ["تحقيق", "عمل", "كسب", "اكتساب"],
        "عراقة": ["أصالة", "عمق", "تاريخ", "تراث"],
        "ذكاء": ["فطنة", "نباهة", "دهاء", "حنكة"],
        "شجاعة": ["جرأة", "إقدام", "بسالة", "بطولة"],
        "صبر": ["تحمّل", "جَلَد", "أناة", "مثابرة"],
        "كرم": ["سخاء", "عطاء", "جود", "بذل"],
        "تواضع": ["بساطة", "خفض جناح", "لين", "دماثة"],
        "حكمة": ["رشاد", "رويّة", "دراية", "بصيرة"],
        "إخلاص": ["وفاء", "تفانٍ", "صدق", "نزاهة"],
    },

    # Sentence starters -> alternatives
    "sentence_starters": {
        "هذا": ["ذلك", "ذاك", "ما سبق"],
        "هذه": ["تلك", "هنا", "ما ذُكر"],
        "هو": ["الشخص", "المذكور", "ذاك"],
        "هي": ["المذكورة", "تلك", "هنا"],
        "هم": ["أولئك", "الفريق", "هؤلاء"],
        "نحن": ["فريقنا", "جميعنا", "كلّنا"],
        "في": ["ضمن", "خلال", "أثناء"],
        "أيضاً": ["كذلك", "إضافةً", "فوق ذلك"],
        "هناك": ["ثمّة", "يوجد", "توجد"],
        "كلّ": ["جميع", "كافّة", "سائر"],
        "بعض": ["عدّة", "جملة من", "طائفة من"],
        "معظم": ["أغلب", "جُلّ", "غالبية"],
        "واحد": ["أحد", "فرد", "عنصر"],
        "إذا": ["لو", "في حال", "متى ما"],
        "عندما": ["حين", "إذ", "لمّا"],
        "بينما": ["في حين", "على حين", "فيما"],
        "بعد": ["عقب", "إثر", "في أعقاب"],
        "خلال": ["أثناء", "في غضون", "طوال"],
        "لأنّ": ["بما أنّ", "إذ", "نظراً لأنّ"],
        "حتى": ["إلى أن", "ريثما", "كي"],
        "رغم أنّ": ["مع أنّ", "ولو أنّ", "على الرغم من أنّ"],
        "لكن": ["غير أنّ", "إلّا أنّ", "بيد أنّ"],
        "و": ["كما", "إضافةً إلى", "فضلاً عن"],
        "أو": ["وإلّا", "بدلاً من ذلك", "أم"],
        "لذا": ["وعليه", "ومن ثمّ", "لهذا"],
        "الآن": ["حالياً", "في هذه اللحظة", "اليوم"],
        "ثمّ": ["بعد ذلك", "لاحقاً", "تالياً"],
        "أوّلاً": ["في البداية", "بادئ ذي بدء", "للبدء"],
        "الحقيقة": ["الواقع", "الصحيح", "ما حدث فعلاً"],
        "للأسف": ["مع الأسف", "مؤسفاً", "يا للأسف"],
        "لحسن الحظّ": ["ولحسن الطالع", "والحمد لله", "من حسن الحظّ"],
        "بالفعل": ["حقّاً", "فعلاً", "صدقاً"],
        "على الأرجح": ["غالباً", "في الغالب", "المحتمل"],
        "للمرّة الأولى": ["أوّل مرّة", "ابتداءً", "كبداية"],
        "في المقابل": ["بالمقارنة", "على الجهة الأخرى", "في الجانب الآخر"],
        "في السابق": ["سابقاً", "قديماً", "فيما مضى"],
        "حديثاً": ["مؤخّراً", "في الآونة الأخيرة", "قريباً"],
        "عادةً": ["في العادة", "كالمعتاد", "كما جرت العادة"],
        "ربّما": ["لعلّ", "قد", "من الممكن"],
        "في الأصل": ["أصلاً", "في الأساس", "منذ البداية"],
    },

    # Colloquial markers for chat/web profiles
    "colloquial_markers": [
        "بالمناسبة",
        "في الواقع",
        "بصراحة",
        "ببساطة",
        "باختصار شديد",
        "الطريف أنّ",
        "بكلّ بساطة",
        "المسألة هي",
        "الحقيقة أنّ",
        "كما اتّضح",
        "في نهاية الأمر",
        "إجمالاً",
        "بكلّ الأحوال",
        "المهمّ أنّ",
        "في الحقيقة",
        "يعني",
        "أصلاً",
        "صدّقني",
        "بيني وبينك",
        "خلاصة القول",
        "لو فكّرت فيها",
        "عن جدّ",
        "ما أقصده",
        "لا تفهمني غلط",
        "على فكرة",
        "بين قوسين",
        "طبعاً",
        "أكيد",
        "الله يعلم",
        "والله",
        "بكلّ صدق",
        "الخلاصة",
        "بالعربي",
        "اللي صار",
        "على العموم",
        "بلا مبالغة",
        "الحكاية إنّ",
        "الموضوع إنّ",
        "عملياً",
        "من وجهة نظري",
        "دعني أوضّح",
        "لنكن صريحين",
        "الأمر ببساطة",
        "لا تستغرب",
        "هل تعلم",
        "صدّق أو لا تصدّق",
        "بكلّ وضوح",
        "الغريب في الأمر",
        "اللافت للنظر",
        "من تجربتي",
        "المثير أنّ",
        "بمنتهى الصراحة",
        "دعنا نعترف",
        "لنضع الأمور في نصابها",
        "في رأيي الشخصي",
        "لا أبالغ إن قلت",
        "ما يهمّ هنا",
        "انتبه لهذا",
        "العبرة أنّ",
    ],

    # Abbreviations (don't split sentences after these)
    "abbreviations": [
        "د", "أ", "م", "ص", "هـ", "ق", "ج",
        "أ.د", "أ.م", "م.م",
        "ب.م", "ب.ظ",
        "كم", "كغ", "مل", "سم", "مم",
        "ق.م", "ب.م",
        "ت", "تل",
        "ش", "ع",
        "ر.ع", "ر.س", "ر.ق",
        "ج.م", "د.ك", "د.إ", "ل.ل", "ل.س",
        "شركة", "مؤسسة", "جمعية",
        "ص.ب",
        "هاتف", "فاكس",
        "ج.ع", "ج.أ",
        "وحدة", "طن", "لتر",
        "كلم", "م²", "م³",
        "ق.ع",
        "إلخ",
    ],

    # Perplexity boosters (rare/unusual phrases to raise perplexity)
    "perplexity_boosters": [
        "إن جاز التعبير",
        "على حدّ تعبيره",
        "بشكل أو بآخر",
        "في ما يبدو",
        "بكلّ المقاييس",
        "على أقلّ تقدير",
        "من باب الإنصاف",
        "بمعزل عن ذلك",
        "من نافلة القول",
        "بادئ ذي بدء",
        "كيفما اتّفق",
        "شاءت الأقدار أن",
        "على حين غرّة",
        "كما هو معلوم",
        "خلافاً للمتوقّع",
        "لا محالة",
        "بحقّ وحقيق",
        "على صعيد آخر",
        "في خضمّ ذلك",
        "لا ريب في أنّ",
        "لا سيّما",
        "ممّا يستدعي",
        "وبحسب ما يُفهم",
        "في غمرة الأحداث",
        "على أرض الواقع",
        "بين مدٍّ وجزر",
        "على المحكّ",
        "بين الحين والآخر",
        "ليس من قبيل المصادفة",
        "في حقيقة الأمر",
        "من جهة أخرى",
        "على أيّ حال",
        "في ظلّ هذه الظروف",
        "ربّما لا غرابة في",
        "من المفارقات أنّ",
        "على حدّ سواء",
        "في نهاية المطاف",
        "والأعجب من ذلك",
        "لو شئنا الدقّة",
        "ثمّة من يقول",
        "مع مراعاة الفوارق",
        "في حكم المؤكّد",
        "لا جَرَم أنّ",
        "دونما تحفّظ",
        "بعبارة أدقّ",
        "في صميم المسألة",
        "كما يقال عادةً",
        "من باب التحفّظ",
        "حريّ بنا أن نذكر",
        "ليس من المبالغة القول",
        "على استحياء",
        "ربّما ليس من قبيل الصدفة",
        "كما لا يخفى",
        "في ثنايا الموضوع",
        "بقدر ما يتعلّق الأمر",
        "في معرض الحديث",
        "مهما يكن الأمر",
        "على وقع الأحداث",
        "في غمرة التحوّلات",
        "من منظور تاريخي",
    ],

    # Profile metric targets
    "profile_targets": {
        "chat": {"avg_sentence_len": (6, 16), "max_sentence_len": 25},
        "web": {"avg_sentence_len": (8, 20), "max_sentence_len": 35},
        "seo": {"avg_sentence_len": (10, 22), "max_sentence_len": 40},
        "docs": {"avg_sentence_len": (10, 25), "max_sentence_len": 45},
        "formal": {"avg_sentence_len": (12, 28), "max_sentence_len": 50},
    },

    # Conjunctions for joining short sentences
    "conjunctions": ["و", "لكن", "أو", "لذا", "بينما", "رغم أنّ", "إذ"],

    # Split conjunctions for breaking long sentences
    "split_conjunctions": [
        "، و", "، لكن", "، ومع ذلك", "، رغم أنّ",
        "، بينما", "، في حين", "، إلّا أنّ",
        "، لذا", "، التي", "؛ ", " — ",
        "، لأنّ", "، بما أنّ", "، ما لم",
        "، حتى لو", "، ولو أنّ", "، رغم",
        "، سواء", "، بعد أن", "، قبل أن",
        "، حين", "، حتى", "، حيث",
        "، عندما", "، أي أنّ", "، إذ",
        "، فضلاً عن", "، ولا", "، إذ إنّ",
        "، وبالتالي", "، وهكذا", "، ومن ثمّ",
        "، وبذلك", "، إضافةً إلى", "، علاوةً على",
        "، بدلاً من", "، وتحديداً", "، أي",
        " – ",
    ],
}
