"""Jazykový balíček: Čeština (Czech)."""

LANG_CS = {
    "code": "cs",
    "name": "Czech",
    "native_name": "Čeština",

    # Trigramy pro detekci jazyka
    "trigrams": [
        "pro", "ost", "ní ", "ení", "pře", "ová", "ání", "sta",
        "kte", "ter", "ent", "pod", "ých", "ých", "jak", "ého",
        "ale", "tov", "ová", "rod", "spo", "ská", "čes", "aby",
        "při", "pra", "hod", "ran", "lem", "ist",
    ],

    # Stop slova (nenahrazovat)
    "stop_words": {
        "a", "ale", "ani", "ano", "asi", "aby", "bez", "být",
        "co", "do", "ho", "jak", "je", "jeho", "její", "jen",
        "tak", "kde", "když", "mezi", "mít", "na", "nad", "ne",
        "nebo", "než", "nic", "no", "od", "on", "ona", "ono",
        "pak", "po", "pod", "pro", "proto", "před", "při",
        "se", "si", "jsou", "ten", "ta", "to", "ty",
        "už", "ve", "za", "ze", "že", "jsem", "jsi",
        "jsme", "jste", "byl", "byla", "bylo", "byli",
        "bude", "budou", "může", "mohou", "musí",
    },

    # Byrokratický jazyk
    "bureaucratic": {
        "implementovat": ["zavést", "uskutečnit", "provést"],
        "optimalizovat": ["zlepšit", "vylepšit", "upravit"],
        "evaluovat": ["hodnotit", "posoudit", "zhodnotit"],
        "generovat": ["vytvářet", "tvořit", "produkovat"],
        "iniciovat": ["zahájit", "spustit", "nastartovat"],
        "facilitovat": ["usnadnit", "umožnit"],
        "prioritizovat": ["upřednostnit", "dát přednost"],
        "komunikovat": ["sdělit", "domluvit se", "říci"],
        "finalizovat": ["dokončit", "uzavřít", "dohotovit"],
        "signifikantní": ["významný", "výrazný", "podstatný"],
        "fundamentální": ["základní", "zásadní", "podstatný"],
        "esenciální": ["nezbytný", "podstatný", "klíčový"],
        "adekvátní": ["přiměřený", "vhodný", "odpovídající"],
        "primárně": ["především", "hlavně", "v prvé řadě"],
        "sukcesivně": ["postupně", "krok za krokem"],
        "integrovat": ["začlenit", "zapojit", "zabudovat"],
        "manifestovat": ["projevit", "ukázat", "odhalit"],
        "etablovat": ["zavést", "založit", "vytvořit"],
        "analyzovat": ["rozebrat", "prozkoumat", "studovat"],
        "specifikovat": ["upřesnit", "určit", "vymezit"],
        "identifikovat": ["rozpoznat", "zjistit", "nalézt"],
        "verifikovat": ["ověřit", "zkontrolovat", "potvrdit"],
        "koordinovat": ["sladit", "zorganizovat", "řídit"],
        "kompenzovat": ["vyrovnat", "nahradit", "vynahradit"],
        "legitimizovat": ["ospravedlnit", "zdůvodnit"],
        "intenzifikovat": ["zesílit", "zvýšit", "posílit"],
        "redukovat": ["snížit", "omezit", "zmenšit"],
        "transformovat": ["přeměnit", "změnit", "přetvořit"],
        "akumulovat": ["hromadit", "shromažďovat", "nahromadit"],
        "anticipovat": ["předvídat", "očekávat", "předjímat"],
        "artikulovat": ["vyjádřit", "formulovat", "vyslovit"],
        "delegovat": ["přenést", "svěřit", "předat"],
        "demonstrovat": ["ukázat", "předvést", "dokázat"],
        "eliminovat": ["odstranit", "vyloučit", "zlikvidovat"],
        "expandovat": ["rozšířit", "zvětšit", "rozrůst se"],
        "formulovat": ["vyjádřit", "sestavit", "utvořit"],
        "garantovat": ["zaručit", "zajistit", "ručit za"],
    },

    # Byrokratické fráze
    "bureaucratic_phrases": {
        "s ohledem na": ["vzhledem k", "kvůli", "s přihlédnutím k"],
        "v rámci": ["v", "během", "v průběhu"],
        "za účelem": ["aby", "pro", "s cílem"],
        "v souladu s": ["podle", "v duchu", "dle"],
        "je třeba poznamenat": ["je důležité", "stojí za zmínku"],
        "má velký význam": ["je důležitý", "je klíčový"],
        "hrát klíčovou roli": ["být důležitý", "být zásadní"],
        "za předpokladu, že": ["pokud", "jestliže"],
        "při absenci": ["bez", "v nepřítomnosti"],
        "dát k dispozici": ["poskytnout", "nabídnout"],
        "vzít v úvahu": ["zohlednit", "vzít v potaz"],
        "přijmout opatření": ["jednat", "zakročit", "zasáhnout"],
        "s přihlédnutím k": ["vzhledem k", "s ohledem na"],
        "v návaznosti na": ["kvůli", "v důsledku", "na základě"],
        "docílit výsledku": ["dosáhnout", "docílit", "dokázat"],
        "na základě": ["kvůli", "podle", "díky"],
        "zaujmout stanovisko": ["rozhodnout se", "vyjádřit se"],
        "v tomto ohledu": ["v této věci", "zde", "tady"],
    },

    # AI konektory
    "ai_connectors": {
        "Navíc": ["Kromě toho", "Také", "Dále"],
        "Nicméně": ["Přesto", "Ale", "Avšak"],
        "V důsledku toho": ["Proto", "Tedy", "Tudíž"],
        "Následně": ["Poté", "Potom", "Pak"],
        "Dále": ["Kromě toho", "Rovněž", "Také"],
        "Na rozdíl od": ["Oproti", "Ale", "Naproti tomu"],
        "V této souvislosti": ["Přitom", "Zde", "V tomto případě"],
        "Shrneme-li": ["Stručně řečeno", "Celkově vzato"],
        "Je třeba zdůraznit": ["Důležité je", "Stojí za zmínku"],
        "Závěrem": ["Na závěr", "Nakonec", "Konečně"],
        "Rovněž": ["Také", "Taktéž", "Též"],
        "Tudíž": ["Proto", "Tedy", "Z toho důvodu"],
        "Současně": ["Zároveň", "Přitom", "Mezitím"],
        "Zejména": ["Především", "Zvláště", "Obzvláště"],
        "V podstatě": ["V jádru", "Vlastně", "V zásadě"],
        "Nakonec": ["Na závěr", "Konečně", "Závěrem"],
        "Dlužno podotknout": ["Nutno říci", "Stojí za zmínku"],
        "V neposlední řadě": ["Také", "Navíc", "Kromě toho"],
        "Jak již bylo zmíněno": ["Jak bylo řečeno", "Jak víme"],
        "Přesto": ["Nicméně", "Avšak", "I tak"],
        "Tím pádem": ["Proto", "Takže", "Z toho plyne"],
    },

    # Synonyma
    "synonyms": {
        "důležitý": ["podstatný", "klíčový", "zásadní", "významný"],
        "velký": ["značný", "rozsáhlý", "obsáhlý"],
        "malý": ["nepatrný", "drobný", "omezený"],
        "rychlý": ["svižný", "hbitý", "pohotový"],
        "pomalý": ["loudavý", "zdlouhavý", "pozvolný"],
        "dobrý": ["kvalitní", "zdařilý", "solidní"],
        "špatný": ["nekvalitní", "nedostatečný", "slabý"],
        "možnost": ["příležitost", "šance", "varianta"],
        "problém": ["potíž", "obtíž", "výzva"],
        "řešení": ["odpověď", "východisko", "náprava"],
        "výsledek": ["výstup", "závěr", "efekt"],
        "oblast": ["obor", "sféra", "odvětví"],
        "metoda": ["postup", "způsob", "přístup"],
        "proces": ["průběh", "děj", "postup"],
        "aspekt": ["hledisko", "stránka", "rozměr"],
        "důvod": ["příčina", "podnět", "pohnutka"],
        "cíl": ["účel", "záměr", "úmysl"],
        "úkol": ["úloha", "povinnost", "práce"],
        "výhoda": ["přínos", "plus", "přednost"],
        "nevýhoda": ["slabina", "minus", "nedostatek"],
        "analýza": ["rozbor", "studie", "zkoumání"],
        "kvalita": ["úroveň", "jakost", "standard"],
        "efektivní": ["účinný", "výkonný", "produktivní"],
        "složitý": ["komplikovaný", "náročný", "spletitý"],
        "moderní": ["současný", "aktuální", "nový"],
        "faktor": ["činitel", "prvek", "okolnost"],
        "strategie": ["plán", "postup", "taktika"],
        "kontext": ["souvislost", "rámec", "prostředí"],
        "perspektiva": ["pohled", "úhel pohledu", "hledisko"],
        "situace": ["stav", "poměry", "okolnosti"],
        "funkce": ["úloha", "role", "činnost"],
        "struktura": ["stavba", "uspořádání", "organizace"],
        "vývoj": ["rozvoj", "pokrok", "proměna"],
        "zkušenost": ["praxe", "znalost", "poznatek"],
        "vliv": ["dopad", "účinek", "působení"],
    },

    # Alternativní začátky vět
    "sentence_starters": {
        "To": ["Toto", "Takové", "Ono"],
        "Je": ["Jedná se", "Bývá", "Stává se"],
        "Tento": ["Ten", "Daný", "Onen"],
        "Tato": ["Ta", "Taková", "Zmíněná"],
        "My": ["Náš tým", "Lidé", "Všichni"],
        "V": ["Uvnitř", "Během", "Při"],
        "Pro": ["Kvůli", "Za účelem", "Aby"],
        "Také": ["Rovněž", "Taktéž", "Též"],
        "Avšak": ["Ale", "Ovšem", "Jenže"],
        "Proto": ["Z toho důvodu", "Tudíž", "Tedy"],
        "Pokud": ["Jestliže", "Kdyby", "V případě, že"],
        "Ačkoli": ["Přestože", "I když", "Třebaže"],
        "Poté": ["Následně", "Potom", "Pak"],
        "Samozřejmě": ["Přirozeně", "Pochopitelně", "Jasně"],
        "Zde": ["Na tomto místě", "Tady", "V tomto bodě"],
    },

    # Hovorové výrazy
    "colloquial_markers": [
        "upřímně řečeno", "vlastně", "v zásadě", "v podstatě",
        "mezi námi", "mimochodem", "přesně vzato",
        "když se mě ptáte", "tak nějak", "no",
        "takříkajíc", "buďme upřímní", "nakonec",
        "vtipné je", "překvapivě", "pozoruhodně",
        "zkrátka", "prostě", "ať tak či tak",
        "myslím", "víte co", "hele",
        "ostatně", "jen tak na okraj", "po pravdě",
        "abych tak řekl", "to je jasné", "no řekněme",
    ],

    # Zkratky
    "abbreviations": [
        "např.", "tj.", "mj.", "atd.", "resp.", "cca.", "srov.",
        "dr.", "prof.", "č.", "ul.", "mil.", "mld.",
        "příp.", "vč.", "tzn.", "popř.", "apod.",
        "tzv.", "atp.", "event.", "aj.", "pozn.",
        "obr.", "tab.", "kap.",
    ],

    # Perplexitní boostery
    "perplexity_boosters": [
        "vpravdě", "jaksi", "zcela", "vskutku",
        "patrně", "případně", "naprosto",
        "nicméně", "bezpochyby", "ovšemže", "zdaleka",
        "koneckonců", "vesměs", "dozajista",
        "nezřídka", "namnoze", "krom toho",
        "nepochybně", "nesporně", "kupříkladu",
        "nemluvě o", "leckdy", "zhusta", "namátkou",
        "naproti tomu", "ostatně", "konečně",
    ],

    # Cílové profily
    "profile_targets": {
        "chat": {"avg_len": (6, 16), "variance": 0.5},
        "web": {"avg_len": (8, 20), "variance": 0.4},
        "seo": {"avg_len": (10, 24), "variance": 0.3},
        "docs": {"avg_len": (10, 26), "variance": 0.3},
        "formal": {"avg_len": (12, 28), "variance": 0.25},
    },

    # Spojky pro spojování
    "conjunctions": ["a", "ale", "nebo", "protože", "neboť", "tedy"],

    # Spojky pro rozdělení
    "split_conjunctions": [
        " a ", " ale ", " avšak ", " přičemž ",
        " zatímco ", " ačkoli ", " protože ",
        ", a ", ", ale ", ", avšak ",
        ", přičemž ", ", zatímco ", ", ačkoli ",
        ", protože ", ", neboť ",
        "; ", " – ", " — ",
    ],
}
