"""Русский языковой пакет."""

LANG_RU = {
    "code": "ru",
    "name": "Русский",

    # Частые триграммы для определения языка
    "trigrams": [
        " не", "не ", " на", "на ", " по", "ени", "ост", "ать", "ова",
        "ани", "ого", "про", "ста", " ко", "ни ", " пр", "ить", "ого",
        "ель", " в ", " и ", "ие ", "ия ", "ной", "ть ", " за", " от",
        "что", "сто", " об", "ком", "ый ", "ого", " до", "ать", "нос",
        "ван", "ска", " вы", "ной", " ра", " с ", "ого", "при", "ого",
        "ров", "ных", "ние", "ого", " мо", "ого", "тор", "ого", "ого",
    ],

    # Стоп-слова (не заменяемые при дедупликации)
    "stop_words": {
        "и", "в", "на", "с", "по", "для", "не", "от", "за", "к", "из",
        "до", "что", "это", "как", "но", "а", "то", "все", "так", "его",
        "она", "он", "мы", "вы", "они", "её", "ее", "их", "был", "быть",
        "бы", "же", "ли", "или", "да", "нет", "о", "об", "при", "через",
        "после", "перед", "между", "без", "под", "над", "у", "во", "со",
        "уже", "ещё", "еще", "тоже", "также", "только", "если", "когда",
        "где", "кто", "чем", "чего", "которые", "который", "которая",
        "которое", "этот", "эта", "эти", "тот", "та", "те", "свой",
        "свои", "мой", "моя", "мои", "ваш", "ваша", "ваши", "наш",
    },

    # Канцеляризмы → простые замены
    # Формат: "канцеляризм" -> ["замена1", "замена2"]
    "bureaucratic": {
        "данный": ["этот", "этот"],
        "данная": ["эта", "эта"],
        "данное": ["это", "это"],
        "осуществлять": ["делать", "проводить"],
        "осуществить": ["сделать", "провести"],
        "осуществляет": ["делает", "проводит"],
        "осуществляется": ["делается", "происходит"],
        "осуществление": ["проведение", "выполнение"],
        "функционировать": ["работать", "действовать"],
        "функционирует": ["работает", "действует"],
        "функционирование": ["работа", "действие"],
        "реализовывать": ["делать", "выполнять"],
        "реализовать": ["сделать", "выполнить"],
        "реализация": ["выполнение", "создание"],
        "предоставлять": ["давать", "передавать"],
        "предоставить": ["дать", "передать"],
        "предоставляет": ["даёт", "передаёт"],
        "обеспечивать": ["давать", "создавать"],
        "обеспечивает": ["даёт", "создаёт"],
        "обеспечение": ["создание", "поддержка"],
        "характеризоваться": ["отличаться", "иметь"],
        "характеризуется": ["отличается", "имеет"],
        "обуславливать": ["определять", "вызывать"],
        "обуславливает": ["определяет", "вызывает"],
        "обусловлен": ["вызван", "связан с"],
        "посредством": ["с помощью", "через"],
        "вследствие": ["из-за", "потому что"],
        "в целях": ["для", "чтобы"],
        "на основании": ["по", "на основе"],
        "ввиду": ["из-за", "потому что"],
        "в процессе": ["при", "во время"],
        "в обязательном порядке": ["обязательно", "непременно"],
        "надлежащим образом": ["правильно", "как нужно"],
        "соответствующий": ["нужный", "подходящий"],
        "соответствующим образом": ["правильно", "подходяще"],
        "каким-либо образом": ["как-то", "как-нибудь"],
        "в значительной степени": ["во многом", "сильно"],
        "в значительной мере": ["во многом", "сильно"],
        "в незначительной степени": ["немного", "слегка"],
        "в достаточной мере": ["достаточно", "вполне"],
        "в полной мере": ["полностью", "целиком"],
        "должным образом": ["правильно", "как нужно"],
        "наиболее": ["особенно", "крайне"],
        "наименее": ["меньше всего", "самый малый"],
        "потенциальный": ["возможный", "вероятный"],
        "непосредственно": ["прямо", "сразу"],
        "в дальнейшем": ["потом", "дальше"],
        "чрезвычайно": ["очень", "крайне"],
        "существенно": ["сильно", "заметно"],
        "располагать": ["иметь", "обладать"],
        "располагает": ["имеет", "есть"],
        "затруднительно": ["сложно", "трудно"],
        "незамедлительно": ["сразу", "немедленно"],
        "целесообразно": ["разумно", "имеет смысл"],
        "нецелесообразно": ["не стоит", "нет смысла"],
        "надлежит": ["нужно", "следует"],
        "вышеуказанный": ["этот", "указанный выше"],
        "вышеупомянутый": ["этот", "упомянутый выше"],
        "нижеследующий": ["следующий", "такой"],
        "нижеизложенный": ["описанный ниже", "следующий"],
        # === v0.11.0 massive expansion ===
        "аккумулировать": ["собирать", "накапливать"],
        "аккумулирует": ["собирает", "накапливает"],
        "аннулировать": ["отменить", "отозвать"],
        "аннулирует": ["отменяет", "отзывает"],
        "апеллировать": ["обращаться", "ссылаться"],
        "апеллирует": ["обращается", "ссылается"],
        "апробировать": ["проверить", "испытать"],
        "апробирует": ["проверяет", "испытывает"],
        "аргументировать": ["обосновать", "объяснить"],
        "аргументирует": ["обосновывает", "объясняет"],
        "базироваться": ["строиться", "опираться"],
        "базируется": ["строится", "опирается"],
        "верифицировать": ["проверить", "подтвердить"],
        "верифицирует": ["проверяет", "подтверждает"],
        "визуализировать": ["показать", "изобразить"],
        "визуализирует": ["показывает", "изображает"],
        "воспрепятствовать": ["помешать", "остановить"],
        "востребованный": ["нужный", "популярный"],
        "генерировать": ["создавать", "порождать"],
        "генерирует": ["создаёт", "порождает"],
        "дезавуировать": ["отвергнуть", "отменить"],
        "детерминировать": ["определять", "задавать"],
        "детерминирует": ["определяет", "задаёт"],
        "дифференцировать": ["различать", "разделять"],
        "дифференцирует": ["различает", "разделяет"],
        "доминировать": ["преобладать", "главенствовать"],
        "доминирует": ["преобладает", "главенствует"],
        "дублировать": ["повторять", "копировать"],
        "дублирует": ["повторяет", "копирует"],
        "задекларировать": ["объявить", "заявить"],
        "идентифицировать": ["определить", "выявить"],
        "идентифицирует": ["определяет", "выявляет"],
        "иллюстрировать": ["показывать", "демонстрировать"],
        "иллюстрирует": ["показывает", "подтверждает"],
        "имплементировать": ["внедрить", "применить"],
        "имплементирует": ["внедряет", "применяет"],
        "индицировать": ["показывать", "указывать"],
        "инициировать": ["начать", "запустить"],
        "инициирует": ["начинает", "запускает"],
        "инспектировать": ["проверять", "осматривать"],
        "инспектирует": ["проверяет", "осматривает"],
        "интегрировать": ["объединять", "включать"],
        "интегрирует": ["объединяет", "включает"],
        "интерпретировать": ["толковать", "объяснять"],
        "интерпретирует": ["толкует", "объясняет"],
        "информировать": ["сообщать", "уведомлять"],
        "информирует": ["сообщает", "уведомляет"],
        "классифицировать": ["разделять", "группировать"],
        "классифицирует": ["разделяет", "группирует"],
        "комментировать": ["пояснять", "объяснять"],
        "комментирует": ["поясняет", "объясняет"],
        "компенсировать": ["возместить", "восполнить"],
        "компенсирует": ["возмещает", "восполняет"],
        "конкретизировать": ["уточнить", "пояснить"],
        "конкретизирует": ["уточняет", "поясняет"],
        "консолидировать": ["объединять", "укреплять"],
        "консолидирует": ["объединяет", "укрепляет"],
        "констатировать": ["отмечать", "фиксировать"],
        "констатирует": ["отмечает", "фиксирует"],
        "контролировать": ["следить", "проверять"],
        "контролирует": ["следит", "проверяет"],
        "координировать": ["согласовывать", "налаживать"],
        "координирует": ["согласовывает", "налаживает"],
        "корректировать": ["поправлять", "исправлять"],
        "корректирует": ["поправляет", "исправляет"],
        "ликвидировать": ["устранить", "убрать"],
        "ликвидирует": ["устраняет", "убирает"],
        "лимитировать": ["ограничивать", "сдерживать"],
        "лимитирует": ["ограничивает", "сдерживает"],
        "локализовать": ["найти", "определить место"],
        "локализует": ["находит", "определяет место"],
        "максимизировать": ["увеличить", "усилить"],
        "максимизирует": ["увеличивает", "усиливает"],
        "минимизировать": ["уменьшить", "снизить"],
        "минимизирует": ["уменьшает", "снижает"],
        "модернизировать": ["обновить", "улучшить"],
        "модернизирует": ["обновляет", "улучшает"],
        "модифицировать": ["изменить", "поправить"],
        "модифицирует": ["изменяет", "поправляет"],
        "мотивировать": ["побуждать", "вдохновлять"],
        "мотивирует": ["побуждает", "вдохновляет"],
        "нивелировать": ["сглаживать", "уменьшать"],
        "нивелирует": ["сглаживает", "уменьшает"],
        "нормализовать": ["привести в норму", "выровнять"],
        "нормализует": ["приводит в норму", "выравнивает"],
        "оптимизировать": ["улучшить", "настроить"],
        "оптимизирует": ["улучшает", "настраивает"],
        "организовывать": ["устраивать", "налаживать"],
        "организовать": ["устроить", "наладить"],
        "ориентировать": ["направлять", "нацеливать"],
        "ориентирует": ["направляет", "нацеливает"],
        "позиционировать": ["размещать", "выставлять"],
        "позиционирует": ["размещает", "выставляет"],
        "постулировать": ["утверждать", "заявлять"],
        "постулирует": ["утверждает", "заявляет"],
        "превалировать": ["преобладать", "доминировать"],
        "превалирует": ["преобладает", "главенствует"],
        "предопределить": ["решить заранее", "задать"],
        "предопределяет": ["задаёт", "решает заранее"],
        "пролонгировать": ["продлить", "продолжить"],
        "пролонгирует": ["продлевает", "продолжает"],
        "регламентировать": ["определять правила", "устанавливать порядок"],
        "регламентирует": ["определяет правила", "устанавливает порядок"],
        "регулировать": ["настраивать", "управлять"],
        "регулирует": ["настраивает", "управляет"],
        "резюмировать": ["подытожить", "обобщить"],
        "резюмирует": ["подытоживает", "обобщает"],
        "санкционировать": ["разрешить", "одобрить"],
        "санкционирует": ["разрешает", "одобряет"],
        "сигнализировать": ["показывать", "говорить о"],
        "сигнализирует": ["показывает", "говорит о"],
        "систематизировать": ["упорядочить", "привести в порядок"],
        "систематизирует": ["упорядочивает", "приводит в порядок"],
        "стабилизировать": ["укрепить", "выровнять"],
        "стабилизирует": ["укрепляет", "выравнивает"],
        "стимулировать": ["побуждать", "подталкивать"],
        "стимулирует": ["побуждает", "подталкивает"],
        "структурировать": ["упорядочить", "организовать"],
        "структурирует": ["упорядочивает", "организует"],
        "трансформировать": ["изменить", "переделать"],
        "трансформирует": ["изменяет", "переделывает"],
        "утилизировать": ["использовать", "перерабатывать"],
        "утилизирует": ["использует", "перерабатывает"],
        "фиксировать": ["отмечать", "записывать"],
        "фиксирует": ["отмечает", "записывает"],
        "формализовать": ["оформить", "закрепить"],
        "формализует": ["оформляет", "закрепляет"],
        "формулировать": ["выражать", "излагать"],
        "формулирует": ["выражает", "излагает"],
        "функционал": ["возможности", "набор функций"],
        "эксплуатировать": ["использовать", "применять"],
        "эксплуатирует": ["использует", "применяет"],
        "элиминировать": ["устранить", "убрать"],
        "элиминирует": ["устраняет", "убирает"],
        # --- Прилагательные / наречия ---
        "актуальный": ["важный", "насущный"],
        "актуальная": ["важная", "насущная"],
        "акцентированный": ["чёткий", "выразительный"],
        "аналогичный": ["похожий", "такой же"],
        "аналогичная": ["похожая", "такая же"],
        "безальтернативный": ["единственный", "неизбежный"],
        "безотлагательный": ["срочный", "неотложный"],
        "беспрецедентный": ["небывалый", "исключительный"],
        "вариативный": ["разнообразный", "гибкий"],
        "гипотетический": ["предполагаемый", "возможный"],
        "двусторонний": ["обоюдный", "взаимный"],
        "декларативный": ["формальный", "показной"],
        "деструктивный": ["разрушительный", "вредный"],
        "детализированный": ["подробный", "развёрнутый"],
        "диверсифицированный": ["разнообразный", "разноплановый"],
        "дискуссионный": ["спорный", "обсуждаемый"],
        "доминирующий": ["главный", "преобладающий"],
        "дополнительный": ["ещё один", "добавочный"],
        "дополнительная": ["ещё одна", "добавочная"],
        "достоверный": ["надёжный", "правдивый"],
        "заблаговременно": ["заранее", "вовремя"],
        "идентичный": ["одинаковый", "точно такой же"],
        "идентичная": ["одинаковая", "точно такая же"],
        "изначально": ["с самого начала", "поначалу"],
        "индивидуальный": ["личный", "собственный"],
        "индивидуальная": ["личная", "собственная"],
        "категорически": ["решительно", "наотрез"],
        "колоссальный": ["огромный", "грандиозный"],
        "колоссальная": ["огромная", "грандиозная"],
        "комплексный": ["сложный", "многосторонний"],
        "комплексная": ["сложная", "многосторонняя"],
        "конструктивный": ["полезный", "дельный"],
        "конструктивная": ["полезная", "дельная"],
        "корректный": ["правильный", "верный"],
        "корректная": ["правильная", "верная"],
        "критический": ["решающий", "опасный"],
        "критическая": ["решающая", "опасная"],
        "масштабный": ["крупный", "обширный"],
        "масштабная": ["крупная", "обширная"],
        "многоаспектный": ["многосторонний", "сложный"],
        "негативный": ["отрицательный", "плохой"],
        "негативная": ["отрицательная", "плохая"],
        "объективный": ["беспристрастный", "честный"],
        "объективная": ["беспристрастная", "честная"],
        "оперативно": ["быстро", "без задержек"],
        "парадоксальный": ["странный", "противоречивый"],
        "перманентный": ["постоянный", "непрерывный"],
        "перманентная": ["постоянная", "непрерывная"],
        "перспективный": ["многообещающий", "будущий"],
        "перспективная": ["многообещающая", "будущая"],
        "позитивный": ["положительный", "хороший"],
        "позитивная": ["положительная", "хорошая"],
        "потенциальная": ["возможная", "вероятная"],
        "превалирующий": ["основной", "преобладающий"],
        "прерогатива": ["право", "привилегия"],
        "приоритетный": ["главный", "первоочередной"],
        "приоритетная": ["главная", "первоочередная"],
        "пролонгированный": ["продлённый", "затяжной"],
        "репрезентативный": ["показательный", "типичный"],
        "систематический": ["постоянный", "регулярный"],
        "систематическая": ["постоянная", "регулярная"],
        "специфический": ["особый", "характерный"],
        "специфическая": ["особая", "характерная"],
        "стратегический": ["важный", "ключевой"],
        "стратегическая": ["важная", "ключевая"],
        "субъективный": ["личный", "предвзятый"],
        "субъективная": ["личная", "предвзятая"],
        "существенный": ["заметный", "серьёзный"],
        "существенная": ["заметная", "серьёзная"],
        "тотальный": ["полный", "всеобщий"],
        "тотальная": ["полная", "всеобщая"],
        "тривиальный": ["простой", "обычный"],
        "тривиальная": ["простая", "обычная"],
        "уникальный": ["единственный в своём роде", "неповторимый"],
        "уникальная": ["единственная в своём роде", "неповторимая"],
        "фактический": ["настоящий", "действительный"],
        "фактическая": ["настоящая", "действительная"],
        "фундаментальный": ["основной", "базовый"],
        "фундаментальная": ["основная", "базовая"],
        "эквивалентный": ["равный", "равнозначный"],
        "эксклюзивный": ["исключительный", "особый"],
        "эксклюзивная": ["исключительная", "особая"],
        # --- Существительные ---
        "аспект": ["сторона", "грань"],
        "аспекты": ["стороны", "грани"],
        "детерминанта": ["причина", "фактор"],
        "дефицит": ["нехватка", "недостаток"],
        "дискурс": ["обсуждение", "разговор"],
        "диспропорция": ["несоразмерность", "перекос"],
        "имплементация": ["внедрение", "применение"],
        "инструментарий": ["набор инструментов", "средства"],
        "компетенция": ["умение", "навык"],
        "компетенции": ["умения", "навыки"],
        "конъюнктура": ["обстановка", "условия"],
        "менталитет": ["склад ума", "мышление"],
        "мониторинг": ["наблюдение", "отслеживание"],
        "номенклатура": ["список", "перечень"],
        "парадигма": ["модель", "подход"],
        "перспектива": ["будущее", "шанс"],
        "перспективы": ["будущее", "шансы"],
        "потенциал": ["возможности", "сила"],
        "прецедент": ["случай", "пример"],
        "приоритет": ["главное", "первоочередное"],
        "приоритеты": ["главное", "первоочередные задачи"],
        "проблематика": ["проблемы", "вопросы"],
        "тенденция": ["тренд", "направление"],
        "тенденции": ["тренды", "направления"],
        "трансформация": ["изменение", "перестройка"],
        "фактор": ["причина", "обстоятельство"],
        "факторы": ["причины", "обстоятельства"],
        "эффективность": ["результативность", "отдача"],
        # === v0.12.0 expansion ===
        # --- Глаголы ---
        "адаптировать": ["приспособить", "подстроить"],
        "адаптирует": ["приспосабливает", "подстраивает"],
        "актуализировать": ["обновить", "освежить"],
        "актуализирует": ["обновляет", "освежает"],
        "артикулировать": ["выразить", "сформулировать"],
        "ассоциироваться": ["связываться", "напоминать"],
        "ассоциируется": ["связывается", "напоминает"],
        "варьировать": ["менять", "изменять"],
        "варьируется": ["меняется", "колеблется"],
        "воздействовать": ["влиять", "действовать на"],
        "воздействует": ["влияет", "действует на"],
        "декомпозировать": ["разбить", "разложить"],
        "демонстрировать": ["показывать", "проявлять"],
        "демонстрирует": ["показывает", "проявляет"],
        "дестабилизировать": ["расшатать", "нарушить"],
        "детализировать": ["уточнить", "расписать"],
        "детализирует": ["уточняет", "расписывает"],
        "диагностировать": ["определить", "выявить"],
        "диагностирует": ["определяет", "выявляет"],
        "дискредитировать": ["подорвать доверие", "опорочить"],
        "документировать": ["записывать", "фиксировать"],
        "документирует": ["записывает", "фиксирует"],
        "игнорировать": ["не замечать", "пропускать"],
        "игнорирует": ["не замечает", "пропускает"],
        "инвестировать": ["вкладывать", "вложить"],
        "инвестирует": ["вкладывает", "вносит"],
        "калькулировать": ["подсчитать", "рассчитать"],
        "квалифицировать": ["оценить", "отнести к"],
        "квалифицирует": ["оценивает", "относит к"],
        "коммуницировать": ["общаться", "связываться"],
        "конвертировать": ["преобразовать", "перевести"],
        "конвертирует": ["преобразует", "переводит"],
        "концентрировать": ["собирать", "сосредоточивать"],
        "концентрирует": ["собирает", "сосредоточивает"],
        "концентрироваться": ["сосредоточиться", "сфокусироваться"],
        "концентрируется": ["сосредоточивается", "фокусируется"],
        "культивировать": ["развивать", "взращивать"],
        "культивирует": ["развивает", "взращивает"],
        "легитимизировать": ["узаконить", "признать законным"],
        "манипулировать": ["управлять хитростью", "воздействовать"],
        "манипулирует": ["управляет хитростью", "воздействует"],
        "наличествовать": ["иметься", "быть"],
        "наличествует": ["имеется", "есть"],
        "популяризировать": ["распространять", "продвигать"],
        "популяризирует": ["распространяет", "продвигает"],
        "практиковать": ["применять", "использовать"],
        "практикует": ["применяет", "использует"],
        "прогнозировать": ["предсказывать", "ожидать"],
        "прогнозирует": ["предсказывает", "ожидает"],
        "проецировать": ["переносить", "распространять"],
        "проецирует": ["переносит", "распространяет"],
        "протоколировать": ["записывать", "вести записи"],
        "протоколирует": ["записывает", "ведёт записи"],
        "реорганизовать": ["перестроить", "переделать"],
        "реорганизует": ["перестраивает", "переделывает"],
        "резервировать": ["бронировать", "откладывать"],
        "резервирует": ["бронирует", "откладывает"],
        "сертифицировать": ["подтвердить", "удостоверить"],
        "сертифицирует": ["подтверждает", "удостоверяет"],
        "символизировать": ["означать", "олицетворять"],
        "символизирует": ["означает", "олицетворяет"],
        "синхронизировать": ["согласовать", "совместить"],
        "синхронизирует": ["согласовывает", "совмещает"],
        "стандартизировать": ["привести к единому виду", "выровнять"],
        "стандартизирует": ["приводит к единому виду", "выравнивает"],
        "транслировать": ["передавать", "распространять"],
        "транслирует": ["передаёт", "распространяет"],
        "унифицировать": ["привести к единому виду", "уравнять"],
        "унифицирует": ["приводит к единому виду", "уравнивает"],
        "финансировать": ["оплачивать", "спонсировать"],
        "финансирует": ["оплачивает", "спонсирует"],
        "экстраполировать": ["распространить", "перенести"],
        "экстраполирует": ["распространяет", "переносит"],
        "затрагивать": ["касаться", "задевать"],
        "затрагивает": ["касается", "задевает"],
        "абстрагироваться": ["отвлечься", "отстраниться"],
        "абстрагируется": ["отвлекается", "отстраняется"],
        "активизировать": ["оживить", "усилить"],
        "активизирует": ["оживляет", "усиливает"],
        "конфронтировать": ["противостоять", "сталкиваться"],
        "легализовать": ["узаконить", "разрешить"],
        "легализует": ["узаконивает", "разрешает"],
        "лоббировать": ["продвигать", "проталкивать"],
        "лоббирует": ["продвигает", "проталкивает"],
        "монополизировать": ["захватить", "подчинить себе"],
        "нейтрализовать": ["обезвредить", "устранить"],
        "нейтрализует": ["обезвреживает", "устраняет"],
        "парализовать": ["обездвижить", "остановить"],
        "парализует": ["обездвиживает", "останавливает"],
        "тиражировать": ["копировать", "распространять"],
        "тиражирует": ["копирует", "распространяет"],
        "фокусироваться": ["сосредоточиться", "направить внимание"],
        "фокусируется": ["сосредоточивается", "направляет внимание"],
        # --- Прилагательные / наречия (v0.12.0) ---
        "альтернативный": ["другой", "иной"],
        "альтернативная": ["другая", "иная"],
        "амбициозный": ["смелый", "дерзкий"],
        "амбициозная": ["смелая", "дерзкая"],
        "автономный": ["самостоятельный", "независимый"],
        "автономная": ["самостоятельная", "независимая"],
        "базисный": ["основной", "опорный"],
        "базисная": ["основная", "опорная"],
        "глобальный": ["мировой", "всеобщий"],
        "глобальная": ["мировая", "всеобщая"],
        "диаметральный": ["прямо противоположный", "полярный"],
        "интенсивный": ["усиленный", "активный"],
        "интенсивная": ["усиленная", "активная"],
        "кардинальный": ["коренной", "решительный"],
        "кардинальная": ["коренная", "решительная"],
        "концептуальный": ["теоретический", "общий"],
        "концептуальная": ["теоретическая", "общая"],
        "маргинальный": ["крайний", "побочный"],
        "оптимальный": ["лучший", "наилучший"],
        "оптимальная": ["лучшая", "наилучшая"],
        "пассивный": ["бездеятельный", "вялый"],
        "пассивная": ["бездеятельная", "вялая"],
        "превентивный": ["предупредительный", "упреждающий"],
        "превентивная": ["предупредительная", "упреждающая"],
        "прагматичный": ["практичный", "трезвый"],
        "прагматичная": ["практичная", "трезвая"],
        "радикальный": ["решительный", "коренной"],
        "радикальная": ["решительная", "коренная"],
        "рациональный": ["разумный", "толковый"],
        "рациональная": ["разумная", "толковая"],
        "релевантный": ["подходящий", "уместный"],
        "релевантная": ["подходящая", "уместная"],
        "тактический": ["оперативный", "текущий"],
        "тактическая": ["оперативная", "текущая"],
        "хронический": ["постоянный", "застарелый"],
        "хроническая": ["постоянная", "застарелая"],
        "латентный": ["скрытый", "незаметный"],
        "латентная": ["скрытая", "незаметная"],
        "адекватный": ["соразмерный", "подходящий"],
        "адекватная": ["соразмерная", "подходящая"],
        "априорный": ["заранее известный", "заведомый"],
        "априори": ["заранее", "изначально"],
        "номинальный": ["формальный", "условный"],
        "номинальная": ["формальная", "условная"],
        "периферийный": ["боковой", "второстепенный"],
        "периферийная": ["боковая", "второстепенная"],
        "пропорциональный": ["соразмерный", "равномерный"],
        "пропорциональная": ["соразмерная", "равномерная"],
        "перманентно": ["постоянно", "всё время"],
        "фрагментарный": ["отрывочный", "неполный"],
        "фрагментарная": ["отрывочная", "неполная"],
        "тотально": ["полностью", "начисто"],
        "имплицитный": ["скрытый", "подразумеваемый"],
        "эксплицитный": ["явный", "открытый"],
        "когерентный": ["связный", "согласованный"],
        "детерминирующий": ["определяющий", "задающий"],
        "инертный": ["вялый", "бездеятельный"],
        "инертная": ["вялая", "бездеятельная"],
        # --- Существительные (v0.12.0) ---
        "сегмент": ["часть", "участок"],
        "спектр": ["круг", "набор"],
        "формат": ["вид", "форма"],
        "категория": ["группа", "разряд"],
        "спецификация": ["описание", "требования"],
        "инфраструктура": ["основа", "база"],
        "контингент": ["группа", "состав"],
        "конфигурация": ["настройка", "устройство"],
        "методология": ["подход", "способ"],
        "концепция": ["идея", "замысел"],
        "платформа": ["основа", "площадка"],
        "ресурс": ["средство", "запас"],
        "контекст": ["обстановка", "условия"],
        "критерий": ["мерило", "признак"],
        "критерии": ["мерила", "признаки"],
        "динамика": ["движение", "ход"],
        "механизм": ["устройство", "способ"],
        "регламент": ["правила", "порядок"],
        "альтернатива": ["другой вариант", "замена"],
        "аналогия": ["сходство", "подобие"],
        "деградация": ["упадок", "ухудшение"],
        "дилемма": ["затруднение", "выбор"],
        "доктрина": ["учение", "принцип"],
        "доминанта": ["главное", "основа"],
        "компонент": ["часть", "элемент"],
        "специфика": ["особенность", "своеобразие"],
        "стратегия": ["план", "подход"],
        "тактика": ["приём", "способ"],
        "феномен": ["явление", "событие"],
        "экспансия": ["расширение", "рост"],
        "экспертиза": ["проверка", "оценка"],
    },

    # Фразовые канцеляризмы (многословные)
    "bureaucratic_phrases": {
        "является одним из": ["— один из", "один из"],
        "является": ["—", "это"],
        "являются": ["—", "это"],
        "представляет собой": ["— это", "это"],
        "представляют собой": ["— это", "это"],
        "оказывать содействие": ["помогать", "содействовать"],
        "оказывает содействие": ["помогает", "содействует"],
        "принимать решение": ["решать", "выбирать"],
        "принять решение": ["решить", "выбрать"],
        "производить оплату": ["платить", "оплачивать"],
        "оказывать влияние": ["влиять", "воздействовать"],
        "оказывает влияние": ["влияет", "воздействует"],
        "приходить к выводу": ["делать вывод", "понимать"],
        "в том случае, если": ["если", "когда"],
        "в том случае если": ["если", "когда"],
        "в связи с тем, что": ["потому что", "так как"],
        "в связи с тем что": ["потому что", "так как"],
        "по причине того, что": ["потому что", "так как"],
        "по причине того что": ["потому что", "так как"],
        "ввиду того, что": ["потому что", "так как"],
        "ввиду того что": ["потому что", "так как"],
        "обладать способностью": ["мочь", "уметь"],
        "обладает способностью": ["может", "умеет"],
        "в настоящее время": ["сейчас", "теперь"],
        "в настоящий момент": ["сейчас", "теперь"],
        "на сегодняшний день": ["сегодня", "сейчас"],
        "на текущий момент": ["сейчас", "пока"],
        "в конечном счёте": ["в итоге", "в конце концов"],
        "в конечном счете": ["в итоге", "в конце концов"],
        "в конечном итоге": ["в итоге", "в результате"],
        "на протяжении длительного времени": ["давно", "долго"],
        "в рамках": ["в", "по"],
        "в соответствии с": ["по", "согласно"],
        "в соответствии со": ["по", "согласно"],
        "с точки зрения": ["по", "для"],
        "необходимо отметить": ["важно", "стоит сказать"],
        "необходимо подчеркнуть": ["важно", "стоит отметить"],
        "следует отметить": ["важно", "стоит сказать"],
        "стоит отметить, что": ["важно, что", "заметим, что"],
        "нельзя не отметить": ["стоит сказать", "важно"],
        "важно подчеркнуть, что": ["важно, что", "стоит сказать, что"],
        "не стоит забывать о том, что": ["помните, что", "учтите, что"],
        "обратите внимание на то, что": ["учтите, что", "заметьте, что"],
        # === v0.11.0 massive expansion ===
        "в данном контексте": ["здесь", "в этом случае"],
        "в данной ситуации": ["тут", "в этом случае"],
        "в качестве примера": ["к примеру", "например"],
        "в контексте данного вопроса": ["в этом вопросе", "здесь"],
        "в первую очередь необходимо": ["прежде всего нужно", "сначала стоит"],
        "в связи с вышеизложенным": ["поэтому", "из-за этого"],
        "в случае необходимости": ["если нужно", "при необходимости"],
        "взять на себя обязательство": ["обязаться", "пообещать"],
        "выступать в качестве": ["быть", "работать как"],
        "давать оценку": ["оценивать", "судить"],
        "для того, чтобы": ["чтобы", "для"],
        "для того чтобы": ["чтобы", "для"],
        "задействовать ресурсы": ["использовать", "привлечь"],
        "играть ключевую роль": ["быть важным", "сильно влиять"],
        "играет ключевую роль": ["важен", "сильно влияет"],
        "иметь место": ["происходить", "быть"],
        "имеет место": ["происходит", "есть"],
        "имеет место быть": ["есть", "бывает"],
        "на данном этапе": ["сейчас", "пока"],
        "на основе вышесказанного": ["поэтому", "итак"],
        "несмотря на тот факт, что": ["хотя", "несмотря на то, что"],
        "нести ответственность": ["отвечать", "быть ответственным"],
        "несёт ответственность": ["отвечает", "ответственен"],
        "носить характер": ["быть", "иметь вид"],
        "носит характер": ["по сути", "напоминает"],
        "обращать внимание на тот факт, что": ["заметьте, что", "учтите, что"],
        "относительно данного вопроса": ["по этому вопросу", "об этом"],
        "по данному вопросу": ["об этом", "по этому поводу"],
        "по мере необходимости": ["если нужно", "при надобности"],
        "подвергать анализу": ["анализировать", "изучать"],
        "подвергает анализу": ["анализирует", "изучает"],
        "предпринимать действия": ["действовать", "делать"],
        "предпринимать меры": ["решать", "действовать"],
        "предпринять попытку": ["попробовать", "попытаться"],
        "придавать значение": ["ценить", "считать важным"],
        "придаёт значение": ["ценит", "считает важным"],
        "приобретать особую актуальность": ["становиться важным", "набирать вес"],
        "приступить к реализации": ["начать", "взяться за"],
        "проводить анализ": ["анализировать", "разбирать"],
        "проводит анализ": ["анализирует", "разбирает"],
        "проводить мониторинг": ["следить", "отслеживать"],
        "проводит мониторинг": ["следит", "отслеживает"],
        "с учётом того, что": ["учитывая, что", "раз"],
        "с учетом того, что": ["учитывая, что", "раз"],
        "следует иметь в виду": ["учтите", "помните"],
        "ставить перед собой задачу": ["стремиться", "хотеть"],
        "уделять внимание": ["обращать внимание", "заниматься"],
        "уделяет внимание": ["обращает внимание", "занимается"],
        # === v0.12.0 expansion ===
        "осуществлять деятельность": ["работать", "заниматься делом"],
        "осуществляет деятельность": ["работает", "занимается делом"],
        "принимать во внимание": ["учитывать", "помнить о"],
        "принимает во внимание": ["учитывает", "помнит о"],
        "выразить несогласие": ["возразить", "не согласиться"],
        "выражает несогласие": ["возражает", "не соглашается"],
        "произвести впечатление": ["впечатлить", "поразить"],
        "производит впечатление": ["впечатляет", "поражает"],
        "оказывать поддержку": ["поддерживать", "помогать"],
        "оказывает поддержку": ["поддерживает", "помогает"],
        "производить замену": ["заменять", "менять"],
        "производит замену": ["заменяет", "меняет"],
        "выдвигать предположение": ["предполагать", "допускать"],
        "выдвигает предположение": ["предполагает", "допускает"],
        "вносить коррективы": ["поправлять", "менять"],
        "вносит коррективы": ["поправляет", "меняет"],
        "принимать участие": ["участвовать", "быть частью"],
        "принимает участие": ["участвует", "задействован"],
        "давать возможность": ["позволять", "помогать"],
        "даёт возможность": ["позволяет", "помогает"],
        "ставить задачу": ["поручать", "просить"],
        "вести деятельность": ["работать", "заниматься"],
        "ведёт деятельность": ["работает", "занимается"],
        "выполнять функции": ["работать как", "служить"],
        "выполняет функции": ["работает как", "служит"],
        "иметь возможность": ["мочь", "быть в состоянии"],
        "имеет возможность": ["может", "в состоянии"],
        "влечёт за собой": ["ведёт к", "вызывает"],
        "влечет за собой": ["ведёт к", "вызывает"],
        "выступать в роли": ["быть", "работать как"],
        "выступает в роли": ["является", "работает как"],
        "вносить вклад": ["помогать", "участвовать"],
        "вносит вклад": ["помогает", "участвует"],
        "занимать позицию": ["считать", "стоять на том"],
        "занимает позицию": ["считает", "стоит на том"],
        "набирать обороты": ["ускоряться", "расти"],
        "набирает обороты": ["ускоряется", "растёт"],
        "иметь в виду": ["подразумевать", "помнить"],
        "имеет в виду": ["подразумевает", "помнит"],
        "давать характеристику": ["описывать", "характеризовать"],
        "даёт характеристику": ["описывает", "характеризует"],
        "терпеть неудачу": ["проваливаться", "не справляться"],
        "терпит неудачу": ["проваливается", "не справляется"],
    },

    # Слова-связки, типичные для ИИ → замены
    "ai_connectors": {
        "Однако": ["Но", "Впрочем", "При этом", "Правда"],
        "Тем не менее": ["Но", "Всё же", "И всё-таки", "Правда"],
        "Вместе с тем": ["Но", "При этом", "Хотя"],
        "Кроме того": ["Ещё", "Также", "И ещё", "Плюс"],
        "Более того": ["И ещё", "К тому же", "Плюс"],
        "Помимо этого": ["Ещё", "Также", "И"],
        "Помимо того": ["Ещё", "Также", "И"],
        "Таким образом": ["В итоге", "Поэтому", "Так что", "Итого"],
        "Следовательно": ["Значит", "Поэтому", "Так что"],
        "Безусловно": ["Конечно", "Да", "Точно"],
        "Несомненно": ["Конечно", "Точно", "Да"],
        "В заключение": ["Итого", "Подводя итог", "В конце"],
        "В заключении": ["Итого", "Подводя итог", "В конце"],
        "Прежде всего": ["Сначала", "Во-первых", "Для начала"],
        "В первую очередь": ["Сначала", "Прежде всего", "Для начала"],
        "Не менее важно": ["Важно и то", "Также важно", "И ещё"],
        "С другой стороны": ["А вот", "Зато", "С другой же стороны"],
        "В целом": ["В общем", "Если коротко", "В общем-то"],
        "В частности": ["Например", "Скажем", "К примеру"],
        "Стоит подчеркнуть": ["Важно", "Заметим", "Отметим"],
        "Необходимо понимать": ["Важно понимать", "Учтите", "Имейте в виду"],
        "Важно учитывать": ["Учтите", "Имейте в виду", "Не забывайте"],
        "Подводя итог": ["В итоге", "Суммируя", "Если коротко"],
        "Исходя из вышесказанного": ["Поэтому", "Так что", "Итого"],
        "Исходя из этого": ["Поэтому", "Так что", "Значит"],
        "Как следствие": ["Поэтому", "Из-за этого", "В итоге"],
        # === v0.11.0 massive expansion ===
        "Бесспорно": ["Да", "Конечно", "Это так"],
        "В данном случае": ["Тут", "Здесь", "В этом случае"],
        "В действительности": ["На самом деле", "По факту", "В реальности"],
        "В конечном итоге": ["В итоге", "В конце концов", "Напоследок"],
        "В результате": ["Итог —", "Из-за этого", "Поэтому"],
        "В свою очередь": ["А", "При этом", "Со своей стороны"],
        "В сущности": ["По сути", "В общем-то", "На деле"],
        "В то же время": ["Параллельно", "Одновременно", "При этом"],
        "Вдобавок": ["Ещё", "Плюс", "И вдобавок"],
        "Впоследствии": ["Потом", "Позже", "Затем"],
        "Вышесказанное": ["Всё это", "Сказанное", "Это"],
        "Действительно": ["Правда", "В самом деле", "Да"],
        "Естественно": ["Конечно", "Разумеется", "Ясное дело"],
        "Зачастую": ["Часто", "Нередко", "Бывает"],
        "Значит": ["Выходит", "Получается", "То есть"],
        "Иными словами": ["Проще говоря", "То есть", "Другими словами"],
        "К сожалению": ["Увы", "Жаль", "К несчастью"],
        "К счастью": ["К радости", "По счастью", "Хорошо, что"],
        "Как правило": ["Обычно", "Чаще всего", "В большинстве случаев"],
        "Между тем": ["А пока", "Тем временем", "При этом"],
        "На самом деле": ["По правде", "Вообще-то", "В реальности"],
        "Наконец": ["В конце", "Под конец", "Наружу"],
        "Напротив": ["Наоборот", "А вот нет", "Совсем не так"],
        "Нередко": ["Часто", "Бывает", "Время от времени"],
        "Неудивительно, что": ["Понятно, почему", "Логично, что", "Ожидаемо"],
        "Очевидно": ["Ясно", "Понятно", "Видно"],
        "По существу": ["По делу", "По сути", "В общем"],
        "Показательно, что": ["Важно, что", "Примечательно, что", "Заметно, что"],
        "Разумеется": ["Конечно", "Ясное дело", "Естественно"],
        "Само собой": ["Конечно", "Ясно", "Понятное дело"],
        "Соответственно": ["Поэтому", "Значит", "Отсюда"],
        "Тогда как": ["В то время как", "А вот", "Хотя"],
        "Характерно, что": ["Типично, что", "Показательно, что", "Заметно, что"],
        "Что касается": ["Если говорить о", "Насчёт", "Про"],
        # === v0.12.0 expansion ===
        "В этой связи": ["Поэтому", "Из-за этого", "Отсюда"],
        "Вполне закономерно": ["Логично", "Понятно", "Ожидаемо"],
        "Главным образом": ["В основном", "Прежде всего", "Больше всего"],
        "Другими словами": ["Проще говоря", "То есть", "Иначе говоря"],
        "Из этого следует": ["Значит", "Поэтому", "Отсюда"],
        "Как бы то ни было": ["В любом случае", "Так или иначе", "Как ни крути"],
        "Как уже отмечалось": ["Как сказано выше", "Мы уже говорили", "Напомню"],
        "Конечно же": ["Разумеется", "Ясное дело", "Само собой"],
        "Между прочим": ["Кстати", "К слову", "Замечу"],
        "Можно утверждать": ["Похоже", "Видимо", "Скорее всего"],
        "Наряду с этим": ["Вместе с тем", "А ещё", "Плюс"],
        "Не в последнюю очередь": ["Также важно", "Не менее важно", "И ещё"],
        "Не вызывает сомнений": ["Ясно", "Очевидно", "Понятно"],
        "Не стоит забывать": ["Помните", "Учтите", "Не забывайте"],
        "Необходимо учесть": ["Учтите", "Важно помнить", "Имейте в виду"],
        "Нужно заметить": ["Замечу", "Скажу", "Отмечу"],
        "Одним словом": ["Короче", "В общем", "Проще говоря"],
        "По большому счёту": ["В целом", "Если честно", "Вообще-то"],
        "По всей видимости": ["Видимо", "Похоже", "Скорее всего"],
        "По меньшей мере": ["Как минимум", "Хотя бы", "Не меньше"],
        "По сути дела": ["По сути", "В общем-то", "На деле"],
        "При всём при том": ["И всё равно", "Но при этом", "Однако"],
        "При этом": ["Но", "И", "А"],
        "Примечательно": ["Любопытно", "Интересно", "Занятно"],
        "Равным образом": ["Так же", "Аналогично", "Подобно"],
        "С одной стороны": ["С одного бока", "Если посмотреть", "Отчасти"],
        "С учётом сказанного": ["Учитывая это", "С оглядкой на это", "Помня об этом"],
        "Симптоматично": ["Показательно", "Характерно", "Типично"],
        "Стоит заметить": ["Замечу", "Отмечу", "Скажу"],
        "Тем самым": ["Этим", "Таким путём", "Так"],
        "Фактически": ["На деле", "По факту", "В реальности"],
        "Что немаловажно": ["И это важно", "Что тоже важно", "Причём"],
        "В дополнение к этому": ["Ещё", "А ещё", "Плюс"],
        "Вне всякого сомнения": ["Точно", "Без сомнений", "Однозначно"],
        "Стоит упомянуть": ["Скажу ещё", "Замечу", "Добавлю"],
        "Нет сомнений в том, что": ["Ясно, что", "Понятно, что", "Точно"],
        "Как известно": ["Известно", "Все знают", "Давно понятно"],
        "Общеизвестно": ["Все знают", "Давно известно", "Понятно"],
        "Резюмируя": ["Итог", "Если коротко", "Подводя итог"],
        "Само собой разумеется": ["Конечно", "Ясное дело", "Естественно"],
    },

    # Синонимы для устранения повторов
    # Формат: слово -> [синонимы]
    "synonyms": {
        "важный": ["значимый", "существенный", "ключевой", "весомый"],
        "важная": ["значимая", "существенная", "ключевая", "весомая"],
        "важное": ["значимое", "существенное", "ключевое", "весомое"],
        "важные": ["значимые", "существенные", "ключевые", "весомые"],
        "важно": ["существенно", "значимо", "принципиально"],
        "большой": ["крупный", "значительный", "немалый", "солидный"],
        "большая": ["крупная", "значительная", "немалая", "солидная"],
        "большое": ["крупное", "значительное", "немалое", "солидное"],
        "маленький": ["небольшой", "компактный", "малый", "скромный"],
        "маленькая": ["небольшая", "компактная", "малая", "скромная"],
        "хороший": ["отличный", "достойный", "качественный", "неплохой"],
        "хорошая": ["отличная", "достойная", "качественная", "неплохая"],
        "хорошо": ["отлично", "неплохо", "достойно", "на уровне"],
        "плохой": ["слабый", "неудачный", "скверный", "посредственный"],
        "плохо": ["слабо", "неудачно", "скверно"],
        "помогать": ["содействовать", "способствовать", "помочь"],
        "помогает": ["содействует", "способствует", "даёт возможность"],
        "позволяет": ["даёт возможность", "помогает", "обеспечивает"],
        "использовать": ["применять", "задействовать", "брать"],
        "использует": ["применяет", "задействует", "берёт"],
        "получать": ["обретать", "приобретать", "добывать"],
        "получает": ["обретает", "приобретает", "добывает"],
        "создавать": ["формировать", "разрабатывать", "строить"],
        "создаёт": ["формирует", "разрабатывает", "строит"],
        "создает": ["формирует", "разрабатывает", "строит"],
        "менять": ["изменять", "преобразовывать", "модифицировать"],
        "меняет": ["изменяет", "преобразует", "модифицирует"],
        "показывать": ["демонстрировать", "отображать", "раскрывать"],
        "показывает": ["демонстрирует", "отображает", "раскрывает"],
        "работать": ["действовать", "трудиться", "функционировать"],
        "работает": ["действует", "трудится", "функционирует"],
        "быстро": ["стремительно", "оперативно", "скоро"],
        "медленно": ["постепенно", "неспешно", "плавно"],
        "часто": ["нередко", "регулярно", "то и дело"],
        "много": ["немало", "достаточно", "изрядно"],
        "очень": ["весьма", "крайне", "довольно"],
        "нужно": ["стоит", "следует", "необходимо"],
        "можно": ["допустимо", "реально", "вполне возможно"],
        "например": ["скажем", "к примеру", "допустим"],
        "поэтому": ["потому", "из-за этого", "по этой причине"],
        "также": ["тоже", "вместе с тем", "ещё"],
        "сейчас": ["теперь", "на данный момент", "в этот момент"],
        "различный": ["разный", "всевозможный", "разнообразный"],
        "различные": ["разные", "всевозможные", "разнообразные"],
        "основной": ["главный", "ключевой", "центральный"],
        "основная": ["главная", "ключевая", "центральная"],
        "значительный": ["существенный", "заметный", "немалый"],
        "эффективный": ["действенный", "продуктивный", "результативный"],
        "эффективно": ["действенно", "продуктивно", "результативно"],
        "определённый": ["конкретный", "некоторый", "заданный"],
        "определенный": ["конкретный", "некоторый", "заданный"],
        "проблема": ["вопрос", "трудность", "задача"],
        "проблемы": ["вопросы", "трудности", "задачи"],
        "результат": ["итог", "исход", "плод"],
        "результаты": ["итоги", "исходы", "плоды"],
        "процесс": ["ход", "течение", "действие"],
        "способ": ["метод", "путь", "подход"],
        "цель": ["задача", "замысел", "намерение"],
        "возможность": ["шанс", "вариант", "опция"],
        # === v0.11.0 massive expansion ===
        "абсолютно": ["полностью", "совершенно", "целиком"],
        "активно": ["деятельно", "энергично", "интенсивно"],
        "аналогично": ["так же", "подобно", "похоже"],
        "безусловно": ["конечно", "точно", "несомненно"],
        "бесспорно": ["однозначно", "без сомнений", "точно"],
        "быстрый": ["стремительный", "скорый", "оперативный"],
        "быстрая": ["стремительная", "скорая", "оперативная"],
        "великий": ["выдающийся", "грандиозный", "громадный"],
        "великая": ["выдающаяся", "грандиозная", "громадная"],
        "вероятно": ["скорее всего", "видимо", "похоже"],
        "видеть": ["замечать", "наблюдать", "различать"],
        "видит": ["замечает", "наблюдает", "различает"],
        "влияние": ["воздействие", "эффект", "давление"],
        "вместе": ["совместно", "сообща", "дружно"],
        "возникать": ["появляться", "зарождаться", "образовываться"],
        "возникает": ["появляется", "зарождается", "образуется"],
        "вопрос": ["тема", "дело", "задача"],
        "высокий": ["большой", "немалый", "серьёзный"],
        "высокая": ["большая", "немалая", "серьёзная"],
        "главный": ["ключевой", "основной", "центральный"],
        "главная": ["ключевая", "основная", "центральная"],
        "говорить": ["рассказывать", "утверждать", "заявлять"],
        "говорит": ["рассказывает", "утверждает", "заявляет"],
        "готовить": ["подготавливать", "составлять", "делать"],
        "готовит": ["подготавливает", "составляет", "делает"],
        "давать": ["передавать", "вручать", "предлагать"],
        "даёт": ["передаёт", "вручает", "предлагает"],
        "делать": ["выполнять", "совершать", "проводить"],
        "делает": ["выполняет", "совершает", "проводит"],
        "длинный": ["протяжённый", "продолжительный", "долгий"],
        "длинная": ["протяжённая", "продолжительная", "долгая"],
        "думать": ["полагать", "считать", "размышлять"],
        "думает": ["полагает", "считает", "размышляет"],
        "единственный": ["один", "уникальный", "неповторимый"],
        "единственная": ["одна", "уникальная", "неповторимая"],
        "жить": ["обитать", "существовать", "пребывать"],
        "живёт": ["обитает", "существует", "пребывает"],
        "заниматься": ["увлекаться", "трудиться над", "работать над"],
        "занимается": ["увлекается", "трудится над", "работает над"],
        "знать": ["понимать", "осознавать", "разбираться в"],
        "знает": ["понимает", "осознаёт", "разбирается в"],
        "изменение": ["перемена", "сдвиг", "трансформация"],
        "изменения": ["перемены", "сдвиги", "трансформации"],
        "интересный": ["увлекательный", "занимательный", "любопытный"],
        "интересная": ["увлекательная", "занимательная", "любопытная"],
        "искать": ["разыскивать", "подыскивать", "выискивать"],
        "ищет": ["разыскивает", "подыскивает", "выискивает"],
        "каждый": ["любой", "всякий", "каждый отдельный"],
        "каждая": ["любая", "всякая", "каждая отдельная"],
        "качество": ["уровень", "класс", "добротность"],
        "количество": ["число", "объём", "масса"],
        "конечно": ["разумеется", "безусловно", "ясное дело"],
        "короткий": ["краткий", "сжатый", "лаконичный"],
        "короткая": ["краткая", "сжатая", "лаконичная"],
        "красивый": ["привлекательный", "эстетичный", "изящный"],
        "красивая": ["привлекательная", "эстетичная", "изящная"],
        "легко": ["просто", "без труда", "непринуждённо"],
        "лучший": ["оптимальный", "идеальный", "первоклассный"],
        "лучшая": ["оптимальная", "идеальная", "первоклассная"],
        "место": ["точка", "участок", "зона"],
        "мнение": ["точка зрения", "позиция", "взгляд"],
        "момент": ["миг", "точка", "мгновение"],
        "направление": ["курс", "вектор", "путь"],
        "настоящий": ["подлинный", "истинный", "реальный"],
        "настоящая": ["подлинная", "истинная", "реальная"],
        "начинать": ["приступать", "браться", "стартовать"],
        "начинает": ["приступает", "берётся", "стартует"],
        "находить": ["обнаруживать", "отыскивать", "выявлять"],
        "находит": ["обнаруживает", "отыскивает", "выявляет"],
        "новый": ["свежий", "современный", "недавний"],
        "новая": ["свежая", "современная", "недавняя"],
        "область": ["сфера", "отрасль", "направление"],
        "общий": ["совместный", "единый", "коллективный"],
        "общая": ["совместная", "единая", "коллективная"],
        "огромный": ["колоссальный", "громадный", "гигантский"],
        "огромная": ["колоссальная", "громадная", "гигантская"],
        "определять": ["выяснять", "устанавливать", "задавать"],
        "определяет": ["выясняет", "устанавливает", "задаёт"],
        "опыт": ["практика", "навык", "стаж"],
        "особенно": ["в первую очередь", "прежде всего", "в особенности"],
        "ответ": ["отклик", "реакция", "решение"],
        "план": ["стратегия", "замысел", "проект"],
        "подход": ["метод", "стратегия", "тактика"],
        "полностью": ["целиком", "всецело", "от и до"],
        "помощь": ["поддержка", "содействие", "подмога"],
        "понимать": ["осознавать", "разбираться", "улавливать"],
        "понимает": ["осознаёт", "разбирается", "улавливает"],
        "правильный": ["верный", "точный", "корректный"],
        "правильная": ["верная", "точная", "корректная"],
        "предлагать": ["рекомендовать", "советовать", "выдвигать"],
        "предлагает": ["рекомендует", "советует", "выдвигает"],
        "простой": ["лёгкий", "несложный", "элементарный"],
        "простая": ["лёгкая", "несложная", "элементарная"],
        "просто": ["элементарно", "легко", "без труда"],
        "развивать": ["совершенствовать", "наращивать", "укреплять"],
        "развивает": ["совершенствует", "наращивает", "укрепляет"],
        "развитие": ["рост", "прогресс", "продвижение"],
        "решать": ["устранять", "разрешать", "справляться с"],
        "решает": ["устраняет", "разрешает", "справляется с"],
        "решение": ["ответ", "выход", "вариант"],
        "роль": ["задача", "функция", "место"],
        "связь": ["контакт", "коммуникация", "связка"],
        "сильный": ["мощный", "крепкий", "твёрдый"],
        "сильная": ["мощная", "крепкая", "твёрдая"],
        "сложный": ["трудный", "непростой", "замысловатый"],
        "сложная": ["трудная", "непростая", "замысловатая"],
        "случай": ["эпизод", "инцидент", "ситуация"],
        "событие": ["происшествие", "случай", "факт"],
        "события": ["происшествия", "случаи", "факты"],
        "совсем": ["абсолютно", "вовсе", "полностью"],
        "состояние": ["положение", "кондиция", "форма"],
        "старый": ["прежний", "давний", "бывалый"],
        "старая": ["прежняя", "давняя", "бывалая"],
        "строить": ["сооружать", "возводить", "мастерить"],
        "строит": ["сооружает", "возводит", "мастерит"],
        "считать": ["полагать", "думать", "рассматривать"],
        "считает": ["полагает", "думает", "рассматривает"],
        "только": ["лишь", "исключительно", "всего лишь"],
        "требовать": ["настаивать", "запрашивать", "предъявлять"],
        "требует": ["настаивает", "запрашивает", "предъявляет"],
        "увеличивать": ["наращивать", "повышать", "усиливать"],
        "увеличивает": ["наращивает", "повышает", "усиливает"],
        "уменьшать": ["снижать", "сокращать", "урезать"],
        "уменьшает": ["снижает", "сокращает", "урезает"],
        "управлять": ["руководить", "вести", "направлять"],
        "управляет": ["руководит", "ведёт", "направляет"],
        "условие": ["требование", "обстоятельство", "предпосылка"],
        "условия": ["требования", "обстоятельства", "предпосылки"],
        "успех": ["победа", "триумф", "достижение"],
        "хотеть": ["желать", "стремиться", "мечтать"],
        "хочет": ["желает", "стремится", "мечтает"],
        "человек": ["личность", "индивид", "персона"],
        "люди": ["народ", "общество", "публика"],
        # === v0.12.0 expansion ===
        "писать": ["сочинять", "составлять", "набирать"],
        "пишет": ["сочиняет", "составляет", "набирает"],
        "читать": ["изучать", "просматривать", "знакомиться с"],
        "читает": ["изучает", "просматривает", "знакомится с"],
        "брать": ["забирать", "хватать", "подбирать"],
        "берёт": ["забирает", "хватает", "подбирает"],
        "идти": ["двигаться", "шагать", "направляться"],
        "идёт": ["движется", "шагает", "направляется"],
        "ждать": ["ожидать", "дожидаться", "выжидать"],
        "ждёт": ["ожидает", "дожидается", "выжидает"],
        "дорогой": ["ценный", "недешёвый", "затратный"],
        "дорогая": ["ценная", "недешёвая", "затратная"],
        "дешёвый": ["недорогой", "бюджетный", "доступный"],
        "дешёвая": ["недорогая", "бюджетная", "доступная"],
        "широкий": ["обширный", "размашистый", "просторный"],
        "широкая": ["обширная", "размашистая", "просторная"],
        "узкий": ["тесный", "ограниченный", "камерный"],
        "узкая": ["тесная", "ограниченная", "камерная"],
        "глубокий": ["основательный", "серьёзный", "проникновенный"],
        "глубокая": ["основательная", "серьёзная", "проникновенная"],
        "тихий": ["негромкий", "бесшумный", "спокойный"],
        "тихая": ["негромкая", "бесшумная", "спокойная"],
        "громкий": ["звучный", "раскатистый", "оглушительный"],
        "громкая": ["звучная", "раскатистая", "оглушительная"],
        "тёплый": ["мягкий", "уютный", "ласковый"],
        "тёплая": ["мягкая", "уютная", "ласковая"],
        "холодный": ["прохладный", "ледяной", "морозный"],
        "холодная": ["прохладная", "ледяная", "морозная"],
        "чистый": ["опрятный", "незапятнанный", "безупречный"],
        "чистая": ["опрятная", "незапятнанная", "безупречная"],
        "умный": ["сообразительный", "толковый", "смышлёный"],
        "умная": ["сообразительная", "толковая", "смышлёная"],
        "добрый": ["отзывчивый", "душевный", "сердечный"],
        "добрая": ["отзывчивая", "душевная", "сердечная"],
        "спокойный": ["невозмутимый", "уравновешенный", "безмятежный"],
        "спокойная": ["невозмутимая", "уравновешенная", "безмятежная"],
        "странный": ["необычный", "чудной", "диковинный"],
        "странная": ["необычная", "чудная", "диковинная"],
        "обычный": ["привычный", "рядовой", "заурядный"],
        "обычная": ["привычная", "рядовая", "заурядная"],
        "яркий": ["сочный", "выразительный", "насыщенный"],
        "яркая": ["сочная", "выразительная", "насыщенная"],
        "причина": ["повод", "основание", "предпосылка"],
        "причины": ["поводы", "основания", "предпосылки"],
        "система": ["устройство", "порядок", "структура"],
        "информация": ["сведения", "данные", "факты"],
        "внимание": ["интерес", "взгляд", "фокус"],
        "действие": ["поступок", "шаг", "ход"],
        "действия": ["поступки", "шаги", "ходы"],
        "ситуация": ["положение", "обстановка", "расклад"],
        "уровень": ["степень", "планка", "ступень"],
        "жизнь": ["быт", "существование", "судьба"],
        "время": ["пора", "период", "момент"],
        "работа": ["труд", "дело", "занятие"],
        "смысл": ["суть", "значение", "толк"],
        "идея": ["мысль", "задумка", "замысел"],
        "часть": ["доля", "кусок", "фрагмент"],
        "конец": ["финал", "завершение", "итог"],
        "начало": ["старт", "зарождение", "исток"],
        "разница": ["отличие", "различие", "контраст"],
        "ошибка": ["промах", "оплошность", "просчёт"],
        "ошибки": ["промахи", "оплошности", "просчёты"],
        "выбор": ["отбор", "подбор", "решение"],
        "путь": ["дорога", "маршрут", "курс"],
        "сила": ["мощь", "энергия", "крепость"],
        "бояться": ["опасаться", "страшиться", "тревожиться"],
        "боится": ["опасается", "страшится", "тревожится"],
        "любить": ["обожать", "ценить", "питать слабость к"],
        "любит": ["обожает", "ценит", "питает слабость к"],
        "верить": ["доверять", "полагаться", "рассчитывать на"],
        "верит": ["доверяет", "полагается", "рассчитывает на"],
        "расти": ["увеличиваться", "подниматься", "набирать"],
        "растёт": ["увеличивается", "поднимается", "набирает"],
        "падать": ["снижаться", "уменьшаться", "сокращаться"],
        "падает": ["снижается", "уменьшается", "сокращается"],
        "появляться": ["возникать", "обнаруживаться", "объявляться"],
        "появляется": ["возникает", "обнаруживается", "объявляется"],
    },

    # Альтернативные начала предложений (когда подряд начинаются одинаково)
    "sentence_starters": {
        "Это": ["Такой подход", "Подобное", "Оно", "Всё это"],
        "Он": ["Тот", "Этот человек", "Специалист"],
        "Она": ["Та", "Эта", "Последняя"],
        "Они": ["Те", "Все они", "Эти люди"],
        "Мы": ["Наша команда", "Все мы", "Команда"],
        "В": ["При", "На", "Среди"],
        "На": ["При", "В", "Для"],
        "Для": ["Ради", "В целях", "Чтобы"],
        "При": ["В случае", "Когда", "Если"],
        "Также": ["Ещё", "Вдобавок", "Плюс к этому"],
        "Кроме": ["Помимо", "Вдобавок к", "Сверх"],
        # === v0.11.0 massive expansion ===
        "Этот": ["Такой", "Данный", "Подобный"],
        "Эта": ["Такая", "Подобная", "Та"],
        "Эти": ["Такие", "Подобные", "Те"],
        "Тот": ["Этот", "Такой", "Указанный"],
        "Та": ["Эта", "Такая", "Указанная"],
        "Те": ["Эти", "Такие", "Указанные"],
        "Каждый": ["Любой", "Всякий", "Каждый отдельный"],
        "Каждая": ["Любая", "Всякая", "Каждая отдельная"],
        "Все": ["Каждый", "Любой", "Все без исключения"],
        "Вся": ["Целая", "Полная", "Каждая часть"],
        "Весь": ["Целый", "Полный", "Каждый"],
        "Его": ["Чей-то", "Того", "Собственный"],
        "Её": ["Того", "Чью-то", "Собственную"],
        "Их": ["Тех", "Чьи-то", "Чужие"],
        "Наш": ["Общий", "Командный", "Совместный"],
        "Наша": ["Общая", "Командная", "Совместная"],
        "После": ["Вслед за", "По окончании", "Когда"],
        "Перед": ["До", "Прежде чем", "Накануне"],
        "Когда": ["Как только", "В тот момент когда", "Едва"],
        "Если": ["В случае", "Когда", "При условии"],
        "Хотя": ["Несмотря на то что", "Пусть", "Даже при том что"],
        "Потому": ["Ведь", "Так как", "Оттого"],
        "Потому что": ["Ведь", "Так как", "Поскольку"],
        "Но": ["Однако", "Впрочем", "Зато"],
        "И": ["Да и", "Плюс", "Вдобавок"],
        "Или": ["Либо", "А может", "Иначе"],
        "Поэтому": ["Оттого", "Вот почему", "Из-за этого"],
        "Сначала": ["Для начала", "Прежде всего", "Первым делом"],
        "Затем": ["Потом", "После этого", "Далее"],
        "Далее": ["Потом", "Затем", "Следом"],
        "Впрочем": ["Хотя", "Правда", "Но"],
        "Тем временем": ["А пока", "Между тем", "Параллельно"],
        "Никогда": ["Ни разу", "Ни при каких обстоятельствах"],
        "Всегда": ["Постоянно", "Неизменно", "Каждый раз"],
        "Часто": ["Нередко", "Регулярно", "Раз за разом"],
        "Иногда": ["Порой", "Время от времени", "Бывает"],
        "Обычно": ["Как правило", "Чаще всего", "В норме"],
        "Возможно": ["Наверное", "Может быть", "Вероятно"],
        "Именно": ["Как раз", "Точно", "Конкретно"],
        "Только": ["Лишь", "Исключительно", "Всего лишь"],
        "Сегодня": ["На данный момент", "В наши дни", "Нынче"],
        "Здесь": ["Тут", "В этом месте", "Вот тут"],
        "Там": ["В том месте", "Вон там", "В той точке"],
        # === v0.12.0 expansion ===
        "Нужно": ["Стоит", "Надо", "Следует"],
        "Можно": ["Реально", "Есть шанс", "Допустимо"],
        "Важно": ["Существенно", "Принципиально", "Главное —"],
        "Необходимо": ["Надо", "Нужно", "Стоит"],
        "Следует": ["Стоит", "Надо бы", "Нужно"],
        "Стоит": ["Имеет смысл", "Разумно", "Полезно"],
        "Каждый раз": ["Всякий раз", "Раз за разом", "Снова и снова"],
        "Первый": ["Начальный", "Стартовый", "Открывающий"],
        "Первая": ["Начальная", "Стартовая", "Открывающая"],
        "Многие": ["Немало людей", "Ряд", "Целый ряд"],
        "Некоторые": ["Кое-кто", "Часть", "Отдельные"],
        "Между": ["Посреди", "Среди", "В промежутке"],
        "Вместо": ["Взамен", "На замену", "В обмен на"],
        "Снова": ["Опять", "Вновь", "Ещё раз"],
        "Ведь": ["Всё-таки", "Ну", "Же"],
        "Пока": ["Покамест", "До тех пор", "Тем временем"],
        "Почти": ["Едва ли не", "Практически", "Чуть ли не"],
        "Вряд ли": ["Навряд ли", "Едва ли", "Сомнительно"],
        "Конечно": ["Разумеется", "Безусловно", "Ясно"],
    },

    # Разговорные маркеры для chat/web профилей
    "colloquial_markers": [
        "кстати",
        "к слову",
        "на самом деле",
        "по сути",
        "в общем-то",
        "между прочим",
        "собственно",
        "проще говоря",
        "грубо говоря",
        "если коротко",
        # === v0.11.0 massive expansion ===
        "без преувеличения",
        "будем честны",
        "вообще",
        "вообще-то",
        "вот в чём дело",
        "вот и получается",
        "вот что интересно",
        "вот что я скажу",
        "главное тут",
        "грех жаловаться",
        "давайте начистоту",
        "другими словами",
        "если говорить прямо",
        "если подумать",
        "если разобраться",
        "если уж на то пошло",
        "есть такое мнение",
        "забавно",
        "замечу",
        "знаете что",
        "и вот ещё что",
        "и что характерно",
        "если честно",
        "интересно",
        "к примеру",
        "короче говоря",
        "любопытно",
        "между нами",
        "можно сказать",
        "на деле",
        "на мой взгляд",
        "надо сказать",
        "надо признать",
        "не буду скрывать",
        "не секрет",
        "ну вот",
        "ну и",
        "ну что сказать",
        "однозначно",
        "оказывается",
        "откровенно говоря",
        "по-моему",
        "по правде говоря",
        "по факту",
        "положа руку на сердце",
        "послушайте",
        "прямо скажу",
        "скажем так",
        "скажу честно",
        "слушайте",
        "смотрите",
        "собственно говоря",
        "стоит заметить",
        "суть в том",
        "так или иначе",
        "тут важно понять",
        "тут вот какое дело",
        "факт в том",
        "честно говоря",
        "что важно",
        "что интересно",
        "что характерно",
        # === v0.12.0 expansion ===
        "а тут ещё",
        "был бы смех",
        "в двух словах",
        "вдруг оказалось",
        "вообще говоря",
        "вот и думай",
        "вот и выходит",
        "вот так вот",
        "всё дело в том",
        "да и вообще",
        "другое дело",
        "если вдуматься",
        "если присмотреться",
        "есть ощущение",
        "зато",
        "и тут",
        "иначе говоря",
        "казалось бы",
        "к тому же",
        "кое-что",
        "ладно бы",
        "между тем",
        "на первый взгляд",
        "не поспоришь",
        "ну вот представьте",
        "обратите внимание",
        "попросту говоря",
        "само по себе",
        "скажу так",
        "так вот",
    ],

    # Аббревиатуры для токенизатора (не разбивать предложения после них)
    "abbreviations": [
        "г", "гг", "т.д", "т.п", "т.е", "и т.д", "и т.п", "др",
        "пр", "проч", "напр", "ред", "рис", "табл", "стр", "см",
        "ок", "обл", "р", "руб", "коп", "тыс", "млн", "млрд",
        "кв", "км", "м", "мм", "см", "кг", "мг", "л", "мл",
        "с", "мин", "ч", "сут", "им", "акад", "проф", "доц",
        "канд", "д-р", "Inc", "Ltd", "Corp",
    ],

    # Бустеры перплексии (редкие/необычные фразы для повышения перплексии)
    "perplexity_boosters": [
        "как ни крути", "так или иначе", "как бы то ни было",
        "nolens volens", "de facto", "ipso facto",
        "парадоксально", "любопытно", "иронично",
        "по большому счёту", "в целом и общем",
        "положа руку на сердце", "чего уж там",
        "будем честны", "надо признать", "грех жаловаться",
        "не без оснований", "к слову сказать",
        "в известном смысле", "до известной степени",
        "объективно говоря", "вопреки ожиданиям",
        "как ни странно", "при всём при том",
        # === v0.11.0 massive expansion ===
        "а ведь", "без лишних слов",
        "будь что будет", "было бы смешно если бы не было так грустно",
        "в каком-то смысле", "в конце-то концов",
        "в лучшем случае", "в некотором роде",
        "в определённом смысле", "в противном случае",
        "верите вы или нет", "вне всякого сомнения",
        "возьмём на заметку", "вот ведь незадача",
        "вот где собака зарыта", "вот что я вам скажу",
        "говоря начистоту", "грубо прикидывая",
        "если разобраться по-хорошему", "если уж совсем честно",
        "и вот тут-то", "и вот что примечательно",
        "и ладно бы", "из ряда вон",
        "к вашему сведению", "как бы там ни было",
        "как видите", "как водится",
        "как знать", "как минимум",
        "как назло", "как показала практика",
        "кто бы мог подумать", "между делом",
        "между нами говоря", "мягко выражаясь",
        "на поверку", "на самом-то деле",
        "надо полагать", "не в обиду будет сказано",
        "не мудрствуя лукаво", "не секрет что",
        "не тут-то было", "невольно напрашивается",
        "нелишне будет заметить", "нет-нет да и",
        "ничего удивительного", "но вот что интересно",
        "ну кто бы сомневался", "оно и понятно",
        "от греха подальше", "по гамбургскому счёту",
        "по здравому размышлению", "по зрелом размышлении",
        "по совести говоря", "правды ради",
        "при ближайшем рассмотрении", "при всём желании",
        "при всём уважении", "ради справедливости",
        "рискну предположить", "с другой стороны",
        "сказать по чести", "следует признать",
        "стоит ли говорить", "строго между нами",
        "тут уж ничего не попишешь", "хочешь не хочешь",
        "шутки шутками", "это к слову",
        # === v0.12.0 expansion ===
        "благо", "вот уж точно",
        "в порядке вещей", "в самый раз",
        "видит бог", "во что бы то ни стало",
        "вот так номер", "вот так штука",
        "всему своё время", "где уж тут",
        "говоря по совести", "дело житейское",
        "дело нехитрое", "для верности",
        "думается мне", "есть над чем задуматься",
        "за неимением лучшего", "задним числом",
        "и то хлеб", "каково",
        "куда ни кинь", "на вкус и цвет",
        "на свой страх и риск", "надо же",
        "начистоту", "нежданно-негаданно",
        "по части", "под стать",
        "при случае", "само собой разумеется",
        "скажем прямо", "стоит ли удивляться",
        "странное дело", "так уж повелось",
        "того и гляди", "хоть куда",
        "что и говорить", "что скрывать",
    ],

    # Целевые метрики по профилям
    "profile_targets": {
        "chat": {"avg_sentence_len": (8, 18), "max_sentence_len": 30},
        "web": {"avg_sentence_len": (10, 22), "max_sentence_len": 40},
        "seo": {"avg_sentence_len": (12, 25), "max_sentence_len": 45},
        "docs": {"avg_sentence_len": (12, 28), "max_sentence_len": 50},
        "formal": {"avg_sentence_len": (15, 30), "max_sentence_len": 55},
    },

    # Союзы для склеивания коротких предложений
    "conjunctions": ["и", "а", "но", "да", "или", "причём", "притом", "хотя"],

    # Союзы для разбивки длинных предложений
    "split_conjunctions": [
        ", и ", ", а ", ", но ", ", однако ", ", хотя ",
        ", причём ", ", притом ", ", при этом ", ", поэтому ",
        ", что ", "; ", " — ",
        # === v0.11.0 massive expansion ===
        ", потому что ", ", так как ", ", поскольку ",
        ", если ", ", когда ", ", пока ",
        ", хотя бы ", ", несмотря на ", ", вместо ",
        ", после чего ", ", в результате чего ",
        ", тогда как ", ", ведь ", ", ибо ",
        ", то есть ", ", а именно ", ", иначе ",
        ", следовательно ", ", значит ", ", выходит ",
        ", вместе с тем ", ", кроме того ",
        " – ",
    ],
}
