"""Wiktionary offline synonyms — auto-generated.

DO NOT EDIT MANUALLY. Regenerate via:
    python scripts/parse_wikt_dump.py
"""
from __future__ import annotations

# RU: 127,385 words, 213,069 synonyms
RU_WIKT_SYNONYMS: dict[str, list[str]] = {
    "а вдобавок": ["кроме того"],
    "а вдруг": ["а может быть", "мало ли"],
    "а ведь": ["хотя", "хоть", "а между тем"],
    "а вот и": ["нет"],
    "а джорно": ["а джурно"],
    "а джурно": ["а джорно"],
    "а именно": ["то есть", "то бишь"],
    "а как же": ["а то как же", "конечно", "разумеется"],
    "а можа": ["ану ж"],
    "а не то": ["а то", "в противном случае", "иначе"],
    "а ну": ["а ну-ка", "ну-ка"],
    "а ну-ка": ["ну-ка", "ну-ко", "ну-кась", "ну-кася"],
    "а оно": ["а то"],
    "а так как": ["по причине"],
    "а то": ["а не то", "отож", "да", "несомненно", "вне сомнений", "безусловно", "конечно", "определённо", "без базара"],
    "а то как же": ["а как же", "конечно", "разумеется"],
    "а то нет": ["конечно"],
    "а толку что": ["а толку-то"],
    "а толку-то": ["а толку что"],
    "а туда же": ["а всё туда же"],
    "а ты трусы накрахмалил": ["а ты шнурки накрахмалил", "а ты уши накрахмалил", "а ты чёлку накрахмалил", "а ты пейсы накрахмалил"],
    "а чего ж": ["а что ж"],
    "а что ж": ["а чего ж"],
    "а что же": ["а что ж"],
    "а-": ["не-", "без-"],
    "а-а-а": ["ааа", "а-а-а-а", "о-о-о"],
    "а-а-а-а": ["ааа", "а-а-а", "о-о-о"],
    "а-ля": ["подобно", "наподобие", "словно", "по образцу"],
    "а-ля фуршет": ["фуршет", "аляфуршет"],
    "а-мольный": ["ля-минорный"],
    "аа": ["какать"],
    "ааа": ["а-а-а", "а-а-а-а", "о-о-о"],
    "аажим": ["удаан"],
    "аазаз": ["азаз"],
    "аален": ["ален"],
    "аангич": ["морянка", "савка", "саутка"],
    "аанта": ["аханта", "анта", "анте"],
    "ааргау": ["аргау"],
    "аарон": ["арон"],
    "аароново согласие": ["аароновщина", "онуфриевщина"],
    "аароновщина": ["аароново согласие", "онуфриевщина"],
    "аах": ["аакта"],
    "аахен": ["ахен"],
    "аахенский": ["ахенский"],
    "аб": ["автоблокировка"],
    "аб ово": ["начинать от яйца", "танцевать от печки"],
    "аб-": ["а-"],
    "абаас": ["абас"],
    "абабак": ["бабка", "падабабак"],
    "абавайн": ["волидайн", "волидон"],
    "абадийлик": ["абадият", "мангулик"],
    "абадияб": ["ахираб"],
    "абадият": ["абад"],
    "абажур": ["плафон", "колпак"],
    "абаз": ["абас", "аббаси"],
    "абази": ["абаз", "аббаси"],
    "абазин": ["абазинец"],
    "абазинский язык": ["абазинский"],
    "абаим": ["обаим"],
    "абайламастан": ["абайламыйча"],
    "абайламыйча": ["абайламастан"],
    "абайларга": ["сагаерга"],
    "абака": ["абага"],
    "абакумыч": ["фомка"],
    "абалон": ["галиотис", "морское ушко"],
    "абармид": ["абармит"],
    "абарогноз": ["абарогнозия"],
    "абарогнозия": ["абарогноз"],
    "абас": ["абаас"],
    "абасг": ["абазг", "массагет"],
    "абатец": ["абатчанин"],
    "абатмент": ["переходник"],
    "абатчанин": ["абатец"],
    "абатъ": ["аббатъ"],
    "аббаси": ["абази", "абаз"],
    "аббатиса": ["настоятельница"],
    "аббатисса": ["аббатиса"],
    "аббатствовав": ["аббатствовавши"],
    "аббатствовавши": ["аббатствовав"],
    "аббатъ": ["абатъ"],
    "аббация": ["опатия"],
    "аббревиатура": ["сокращение"],
    "аббревиация": ["сокращение"],
    "аббревиировав": ["аббревиировавши"],
    "аббревиировавши": ["аббревиировав"],
    "аббревиировать": ["сокращать"],
    "аббревиироваться": ["сократиться"],
    "абвахта": ["гауптвахта"],
    "абгаль": ["апкалл", "апкаллу"],
    "абд": ["банда", "асир"],
    "абдес": ["авдес", "авдест", "абдест"],
    "абджад": ["консонантное письмо"],
    "абдикация": ["отречение"],
    "абдомен": ["брюшко"],
    "абдоминализация": ["абдоминоперикардиостомия"],
    "абдоминальный": ["брюшной", "вентральный"],
    "абдон": ["авдон", "абдя", "абда", "авдя", "авда"],
    "абдраганъ": ["испугъ", "страхъ", "боязнь"],
    "абдулла": ["абдуллах", "абдалла", "абдаллах"],
    "абдуллах": ["абдулла"],
    "абдулло": ["абдулла", "абдалла", "абдаллах"],
    "абдурауп": ["абдурауф"],
    "абдурауф": ["абдурауп"],
    "абевега": ["алфавит", "буквица", "азбука"],
    "абелев": ["абелевский"],
    "абелева группа": ["коммутативная группа"],
    "абелево кольцо": ["коммутативное кольцо"],
    "абельмош": ["мускусная трава"],
    "аберрационный": ["искажённый"],
    "аберрация": ["заблуждение", "искажение", "девиация", "перверсия", "извращение"],
    "аберрировав": ["аберрировавши"],
    "аберрировавши": ["аберрировав"],
    "абессив": ["лишительный падеж", "изъятельный падеж", "каритив"],
    "абетка": ["азбука"],
    "абецедарий": ["алфавит"],
    "абзац": ["параграф", "отступ", "красная строка"],
    "абзелиловский район": ["абзелил"],
    "абзор": ["афзор"],
    "абзый": ["абый"],
    "абигейл": ["авигея", "абигайль"],
    "абие": ["тотчас", "сразу", "тут же", "внезапно", "вдруг", "опять", "снова"],
    "абиетиновый": ["абьетиновый"],
    "абинец": ["абинчанин"],
    "абиотичен": ["неорганичен"],
    "абиотический": ["абиотичный", "неживой", "безжизненный", "неорганический"],
    "абиотичный": ["абиотический"],
    "абисинец": ["етиопец"],
    "абиссаль": ["абиссальная зона", "абиссальная область"],
    "абиссальный": ["глубоководный"],
    "абиссинец": ["хабеша", "эфиоп", "аксумит", "абик", "абиссинская кошка"],
    "абиссиния": ["адова"],
    "абиссинка": ["хабеша", "эфиопка", "аксумитка", "абиссинская кошка"],
    "абиссинский": ["эфиопский"],
    "абитура": ["абитуха", "абита", "абитень", "абитурь"],
    "абитуриент": ["абитура"],
    "абитуриентка": ["выпускница"],
    "абитурский": ["абитуриентский"],
    "абихто": ["хоть би хто", "будь-хто", "хто-будь", "хоч хто", "хай там хто", "хто-небудь", "хтось", "хто завгодно", "хто попало", "хто попаде", "хто хочешь", "хто хочете", "хто припало", "хто припаде", "хто прийдеться"],
    "абичий": ["будь-чий", "чий-будь", "хай чий", "хоч чий", "чий-небудь", "чийсь"],
    "абищо": ["хоть би що", "будь-що", "хоч що", "хай там що", "що-небудь", "щось", "що завгодно", "що попало", "що попаде", "що хочешь", "що хочете", "що припало", "що припаде", "що прийдеться", "що б то не було"],
    "аблактировав": ["аблактировавши"],
    "аблактировавши": ["аблактировав"],
    "аблактирование": ["аблактировка"],
    "аблактировка": ["аблактирование"],
    "аблатив": ["элатив", "элятив", "исходный падеж", "отложительный падеж"],
    "аблаут": ["апофония"],
    "аблировав": ["аблировавши"],
    "аблировавши": ["аблировав"],
    "абляционный": ["теплозащитный"],
    "абнормалан": ["неправилан", "необичан", "грдобан", "неприродан", "болестан", "нездрав", "абнорман", "ненормалан"],
    "або": ["турку"],
    "аболиция": ["аброгация"],
    "абоминация": ["бделигма"],
    "абонат": ["клиент", "подписник"],
    "абонемент": ["подписка", "проездной билет", "проездной", "транспортная карта"],
    "абонементный билет": ["абонемент"],
    "абонент": ["подписчик"],
    "абонент не абонент": ["абонент недоступен"],
    "абонент недоступен": ["абонент не абонент"],
    "абонентский ящик": ["ящик"],
    "абонирам": ["записвам"],
    "абонировав": ["абонировавши"],
    "абонировавши": ["абонировав"],
    "абонирование": ["абонировка"],
    "абонировать": ["подписываться", "подписаться", "занимать", "занять", "заказать", "арендовать"],
    "абонироваться": ["купить", "подписаться"],
    "абонировка": ["абонирование"],
    "аборальный": ["каудальный"],
    "абордировав": ["абордировавши"],
    "абордировавши": ["абордировав"],
    "абордувати": ["брати на абордаж"],
    "абориген": ["автохтон", "коренной житель", "туземец", "местный"],
    "аборигенский": ["туземный"],
    "аборт": ["плодоизгнание", "прерывание беременности", "выкидыш"],
    "абортировав": ["абортировавши"],
    "абортировавши": ["абортировав"],
    "абортмахер": ["абортщик", "подпольный акушёр"],
    "абоский": ["туркуский"],
    "абрадировав": ["абрадировавши"],
    "абрадировавши": ["абрадировав"],
    "абразивно-аккумулятивный": ["абразионно-аккумулятивный"],
    "абразивостойкость": ["абразивоустойчивость"],
    "абразионно-аккумулятивный": ["абразивно-аккумулятивный"],
    "абрамит": ["абраамит", "аврамит", "абрагамит"],
    "абрахам": ["авраам"],
    "абреже": ["экстензо"],
    "абрек": ["горец", "беглец", "кавказец"],
    "абречка": ["нежеланная", "изгнанница", "разбойница", "грабительница", "убивица"],
    "абрикоз": ["абрикос", "априкос"],
    "абрикоса": ["абрикос"],
    "абрикосный": ["абрикосовый"],
    "абрикосовый": ["абрикосный"],
    "абрис": ["брульон", "кроки", "эскиз", "набросок", "конфигурация", "силуэт", "контур", "топоплан"],
    "аброгация": ["аннуляция"],
    "абруптив": ["абруптивный согласный", "эйективный согласный"],
    "абрупция": ["умолчание", "ретиценция"],
    "абруццо": ["абруцци"],
    "абрютировав": ["абрютировавши"],
    "абрютировавши": ["абрютировав"],
    "абрютировать": ["отуплять", "оскотинивать"],
    "абсент": ["зелёная фея", "зелёная муза", "зелёная ведьма", "зелёная богиня", "зелёный дьявол", "безумие в бутылке"],
    "абсольвент": ["выпускник"],
    "абсолют": ["идеал", "логос", "первооснова", "совершенство", "творец", "завершённость", "стопроцентность", "безусловность"],
    "абсолютизировав": ["абсолютизировавши"],
    "абсолютизировавши": ["абсолютизировав"],
    "абсолютизированный": ["идеализированный"],
    "абсолютировав": ["абсолютировавши"],
    "абсолютировавши": ["абсолютировав"],
    "абсолютистський": ["самодержавницький", "автократичний"],
    "абсолютная монархия": ["абсолютизм"],
    "абсолютнейший": ["полнейший", "совершеннейший"],
    "абсолютний": ["необмежений", "повний"],
    "абсолютно": ["совершенно", "совсем", "полностью"],
    "абсолютный": ["подавляющий", "идеальный", "безупречный", "совершенный", "образцовый", "высшей пробы", "полный", "глубокий"],
    "абсолютный нуль": ["абсолютный ноль", "термодинамическая смерть"],
    "абсорбер": ["скруббер"],
    "абсорбировав": ["абсорбировавши"],
    "абсорбировавши": ["абсорбировав"],
    "абсорбированный": ["поглощённый"],
    "абсорбировать": ["поглощать", "адсорбировать"],
    "абсорбироваться": ["впитываться", "поглотиться"],
    "абсорбируемый": ["поглощаемый"],
    "абсорбция": ["абсорбирование", "поглощение"],
    "абстенционист": ["бойкотист"],
    "абстинентный синдром": ["синдром отмены"],
    "абстрагировав": ["абстрагировавши"],
    "абстрагировавши": ["абстрагировав"],
    "абстрагированность": ["отвлечённость"],
    "абстрагировать": ["обобщать", "типизировать", "схематизировать", "формализовать"],
    "абстрагироваться": ["отвлекаться", "отвлечься"],
    "абстракт": ["абстракция", "отвлечённость"],
    "абстрактивизм": ["абстракционизм", "абстрактное искусство"],
    "абстрактно": ["отвлечённо", "условно", "теоретически", "умозрительно"],
    "абстрактно-формальный": ["бессодержательный"],
    "абстрактное": ["абстракция", "абстракт"],
    "абстрактное существительное": ["отвлечённое существительное"],
    "абстрактный": ["отвлечённый", "расплывчатый", "размытый", "умозрительный", "спекулятивный"],
    "абстракционизм": ["абстрактное искусство", "абстрактивизм"],
    "абстракционизъм": ["абстрактно изкуство"],
    "абстракция": ["абстрагирование"],
    "абсурд": ["нелепость", "бессмысленность", "глупость", "несуразица", "абсурдность", "чепуха", "бред", "нонсенс", "парадокс", "абсурдизм"],
    "абсурдизм": ["абсурд"],
    "абсурдно": ["бессмысленно"],
    "абсурдност": ["абсурд", "глупост", "безсмислица", "безсмислие", "нелепост", "нелепица", "нелогичност", "парадокс"],
    "абсурдность": ["нелепость", "бессмысленность"],
    "абсурдный": ["нелепый", "бессмысленный", "нелогичный", "вздорный"],
    "абсцедировав": ["абсцедировавши"],
    "абсцедировавши": ["абсцедировав"],
    "абсцес": ["гнойник", "гнойница", "загнояване"],
    "абсцесс": ["гнойник"],
    "абсцизин": ["абсцизовая кислота", "дормин"],
    "абсцизовая кислота": ["абк", "дормин", "абсцизин"],
    "абу-даби": ["абу-заби"],
    "абуз": ["злоупотребление", "нарушение", "мошенничество", "скам"],
    "абулия": ["безволие"],
    "абур": ["анбур"],
    "абутилон": ["канатник"],
    "абхаз": ["абхазец"],
    "абхазец": ["абхаз"],
    "абхазия": ["республика абхазия", "абхазская автономная республика"],
    "абхазо-адыгский": ["абхазско-адыгский"],
    "абхазская автономная республика": ["абхазия"],
    "абхазско-адыгский": ["абхазо-адыгский"],
    "абхидхарма": ["абхидхамма"],
    "абшид": ["абшит"],
    "абшит": ["абшид"],
    "абы": ["лишь бы"],
    "абы как": ["тяп-ляп", "кое-как", "небрежно", "как-нибудь"],
    "абый": ["ага"],
    "абырой": ["намыс", "бедел"],
    "абьюз": ["абуз", "абьюз-тим"],
    "абьюзивные отношения": ["нездоровые отношения"],
    "абэномика": ["абээкономика"],
    "абээкономика": ["абэномика"],
    "ав": ["аф", "гав", "вау", "тяф"],
    "ава": ["аватар", "аватара", "аватарка", "авка", "юзерпик"],
    "ава-перец": ["ава-ава", "кава-кава"],
    "авалокитешвара": ["ченрезиг", "падмапани", "манипадма", "шадакшари"],
    "авангард": ["авангардия", "авангвардия", "авангардизм"],
    "авангардизм": ["модернизм", "лидерство"],
    "авангардия": ["авангард", "авангвардия"],
    "авангардный": ["передовой", "авангардистский", "предварительный"],
    "авангвардия": ["авангард", "авангардия"],
    "аванзал": ["аванзала", "антикамера"],
    "аванзала": ["аванзал"],
    "аванлык": ["аванлых"],
    "аванпост": ["форпост", "сторожевой отряд"],
    "аванпроект": ["черновик", "набросок", "эскиз"],
    "аванс": ["задаток", "предоплата"],
    "авансирам": ["предплащам"],
    "авансировав": ["авансировавши"],
    "авансировавши": ["авансировав"],
    "авансированный": ["субсидированный", "предоплаченный"],
    "авансом": ["вперёд", "заранее"],
    "авансы поют романсы": ["финансы поют романсы"],
    "авантажно": ["благопристойно", "прилично"],
    "авантажность": ["привлекательность"],
    "авантажный": ["выгодный", "благоприятный", "предпочтительный", "видный", "казистый", "вальяжный", "представительный", "презентабельный", "величавый"],
    "авантитул": ["выходной лист", "фортитул"],
    "авантурин": ["авантюрин"],
    "авантюрин": ["авантурин", "искряк"],
    "авантюрист": ["делец-авантюрист", "приключенец"],
    "авантюристически": ["авантюристски", "авантюристично"],
    "авантюристический": ["авантюристский"],
    "авантюристичний": ["авантюристський"],
    "авантюристично": ["авантюристски", "авантюристически"],
    "авантюристка": ["авантюрьера"],
    "авантюристски": ["по-авантюристски", "авантюристично", "авантюристически", "авантюрно"],
    "авантюристский": ["авантюристический", "авантюрный"],
    "авантюрничав": ["авантюрничавши"],
    "авантюрничавши": ["авантюрничав"],
    "авантюрничать": ["авантюрить"],
    "авантюрно": ["рискованно", "авантюристично", "спешно"],
    "авантюрно-детективный": ["детективно-авантюрный"],
    "авантюрность": ["авантюризм"],
    "авантюрьера": ["авантюристка"],
    "авар": ["обр"],
    "авариец": ["аварийщик"],
    "аварийно": ["непредвиденно", "неудачно", "нештатно", "форс-мажорно", "экстренно", "опасно"],
    "аварийно химически опасное вещество": ["ахов"],
    "аварийно-высокий": ["высокоаварийный"],
    "аварийный": ["неисправный"],
    "аварийщик": ["авариец"],
    "авария": ["повреда"],
    "аварско-андийско-дидойский": ["аваро-андийско-дидойский", "аваро-андо-дидойский"],
    "аватар": ["воплощение", "инкарнация", "лик", "олицетворение", "аватарка", "иконка"],
    "аватара": ["аватар"],
    "аватарка": ["ава"],
    "авачинская сопка": ["авача"],
    "аввал": ["якум"],
    "авганец": ["афганец"],
    "авганистан": ["афганистан"],
    "авгиевы конюшни": ["хлев", "непаханое поле", "конь не валялся"],
    "авгур": ["гадатель", "прорицатель", "птицегадатель", "прозорливец", "гаруспик"],
    "август": ["ава", "густа", "густя", "гутя"],
    "августа": ["ава", "густа", "густя", "устя", "гуся", "гутя", "ага"],
    "августинизм": ["августинство"],
    "августинство": ["августинизм"],
    "авдей": ["авдий"],
    "авдес": ["абдес", "авдест", "абдест"],
    "авдест": ["авдес", "абдест", "абдес"],
    "авджия": ["ловец"],
    "авдий": ["авдей"],
    "авдиометр": ["аудиометр"],
    "авдитор": ["аудитор"],
    "авдон": ["абдон", "авдя", "авда", "абдя", "абда"],
    "авдотья": ["дуня", "евдокия"],
    "авелит": ["авелианин", "авелонит", "абелит"],
    "авенида": ["проспект", "авеню"],
    "авеню": ["проспект", "аллея"],
    "аверсивный": ["неприятный", "отвратительный"],
    "аверсия": ["анакоэносис"],
    "авестизм": ["зороастризм"],
    "авжеж": ["атож"],
    "авзония": ["италия"],
    "авиа-": ["аэро-"],
    "авиаагентство": ["аэроагентство"],
    "авиабаза": ["аэродром"],
    "авиабой": ["воздушный бой"],
    "авиабомба": ["аэробомба"],
    "авиабомбовый": ["аэробомбовый"],
    "авиавыставка": ["авиасалон", "авиасмотрины"],
    "авиадвигатель": ["авиамотор", "аэромотор"],
    "авиадебошир": ["авиахулиган"],
    "авиадискаунтер": ["лоукостер"],
    "авиазвено": ["авиационное звено"],
    "авиаинцидент": ["авиапроисшествие"],
    "авиакатастрофа": ["авиакрушение", "самолётокрушение"],
    "авиакомпания": ["авиафирма", "авиаперевозчик"],
    "авиакорреспонденция": ["авиапочта"],
    "авиакосмический": ["авиационно-космический"],
    "авиакрейсер": ["авианосец"],
    "авиалиния": ["авиатрасса"],
    "авиаматка": ["гидроавианосец", "гидрокрейсер", "авианосец", "воздушный"],
    "авиамаяк": ["аэромаяк"],
    "авиамобильный": ["аэромобильный"],
    "авиамотор": ["авиадвигатель", "авиационный двигатель", "авиационный мотор"],
    "авианесущий": ["авианосный"],
    "авианесущий крейсер": ["авиакрейсер", "авианосец"],
    "авианосец": ["авиакрейсер", "авианесущий крейсер"],
    "авиаопрыскиватель": ["аэроопрыскиватель"],
    "авиаопыление": ["авиаопыливание"],
    "авиаотрасль": ["авиастроение"],
    "авиаотряд": ["ао"],
    "авиаперевозчик": ["авиакомпания"],
    "авиаперелёт": ["авиаполёт", "авиаперевозка"],
    "авиапокрышка": ["аэропокрышка"],
    "авиапочта": ["аэропочта", "воздушная почта"],
    "авиапредприятие": ["авиационное предприятие"],
    "авиаразведка": ["аэроразведка"],
    "авиарежим": ["автономный режим", "режим полёта"],
    "авиасалон": ["авиавыставка", "авиасмотрины"],
    "авиасев": ["аэросев"],
    "авиасмотрины": ["авиавыставка", "авиасалон"],
    "авиаспортивный клуб": ["авиаспортклуб"],
    "авиаспортклуб": ["аэроклуб"],
    "авиасъёмка": ["аэросъёмка"],
    "авиатакси": ["аэротакси"],
    "авиатендер": ["гидроавианосец"],
    "авиатор": ["воздухоплаватель", "лётчик", "пилот"],
    "авиаторша": ["пилотесса"],
    "авиатранспортирование": ["аэротранспортирование"],
    "авиатрисса": ["авиаторша"],
    "авиаудар": ["авиационный удар", "авианалёт"],
    "авиафирма": ["авиакомпания"],
    "авиафоторазведка": ["аэрофоторазведка"],
    "авиахимический": ["авиационно-химический"],
    "авиахищничество": ["авиабраконьерство"],
    "авиахулиган": ["авиадебошир"],
    "авиационка": ["авиапром", "авиапромышленность", "венгерка", "авиатопливо", "авиапушка"],
    "авиационная бомба": ["авиабомба"],
    "авиационник": ["авиационщик"],
    "авиационно-метеорологический": ["авиаметеорологический"],
    "авиационно-ракетный": ["авиаракетный"],
    "авиационно-строительный": ["самолетостроительный"],
    "авиационное звено": ["авиазвено"],
    "авиационное предприятие": ["авиапредприятие"],
    "авиационный отряд": ["авиаотряд"],
    "авиационщик": ["авиационник"],
    "авиация": ["воздухоплавание", "аэронавтика", "воздушный флот"],
    "авиация общего назначения": ["аон"],
    "авиашоу": ["аэрошоу"],
    "авигея": ["абигаил", "абигейл", "абигаиль", "абигал", "абигайл", "абигайль", "эбигейл"],
    "авизировав": ["авизировавши"],
    "авизировавши": ["авизировав"],
    "авизирование": ["авизование"],
    "авизировать": ["авизовать"],
    "авизовав": ["авизовавши"],
    "авизовавши": ["авизовав"],
    "авизование": ["авизирование"],
    "авизовать": ["авизировать"],
    "авионика": ["авиационная электроника"],
    "авифауна": ["орнитофауна"],
    "авишка": ["авишник"],
    "авишник": ["авишка"],
    "авксанометр": ["ауксанометр"],
    "авксентий": ["аксён", "аксентий"],
    "авокадо": ["персея американская", "аллигаторова груша"],
    "авометр": ["ампервольтомметр", "мультиметр"],
    "авось": ["небось", "авось-либо", "бог даст", "дай бог", "может быть"],
    "авось-либо": ["авось"],
    "авоська": ["сетка"],
    "авоськать": ["авосьничать"],
    "авосьничать": ["авоськать"],
    "авраам": ["абрахам"],
    "авраамово дерево": ["витекс священный", "монашеский перец", "целомудренник"],
    "аврал": ["штурмовщина"],
    "авралив": ["авраливши"],
    "авраливши": ["авралив"],
    "аврально": ["срочно"],
    "авранг": ["тахт"],
    "аврелия": ["аурелия"],
    "аврикула": ["первоцвет медвежье ушко", "медвежье ушко", "первоцвет ушковидный"],
    "аврипигмент": ["аурипигмент", "арреник", "опермент"],
    "австерия": ["аустерия", "трактир", "харчевня", "закусочная"],
    "австр": ["аустер", "нот", "зюйд"],
    "австралийский союз": ["австралия"],
    "австралийский тунец": ["южный голубой тунец", "южноавстралийский синепёрый тунец"],
    "австралийско-российский": ["российско-австралийский"],
    "австралия": ["австралийский союз", "австралия и океания"],
    "австриец": ["австрияк"],
    "австрийка": ["австриячка"],
    "австрийская республика": ["австрия"],
    "австрийский": ["австрийско-венгерско-славянский", "австро-венгерско-славянский"],
    "австрийский художник": ["алоизыч"],
    "австрийско-венгерско-славянский": ["австро-венгерско-славянский"],
    "австрийско-советский": ["австро-советский"],
    "австрический": ["аустрический"],
    "австрия": ["австрийская республика"],
    "австро-венгерско-славянский": ["австрийско-венгерско-славянский"],
    "австро-венгрия": ["австро-венгерская империя", "австрия", "лоскутная империя", "лоскутная монархия"],
    "австро-германский": ["австро-немецкий"],
    "австро-итало-французский": ["австро-франко-итальянский"],
    "австро-советский": ["австрийско-советский"],
    "австро-франко-итальянский": ["австро-итало-французский"],
    "австроазиатский": ["аустроазиатский"],
    "автапоморфия": ["аутапоморфия"],
    "автаркия": ["изоляционизм"],
    "автентик": ["аутентик"],
    "автентичен": ["истински", "действителен", "неподправен", "достоверен", "точен"],
    "автентичный": ["аутентичный"],
    "авто-": ["само-", "автомобильный", "автоматический", "автобусный", "автогенный"],
    "авто-машина": ["авто", "автомашина"],
    "автоавария": ["дорожно-транспортное происшествие"],
    "автоагрессия": ["аутоагрессия", "аутодеструкция"],
    "автоаларм": ["автосигнализация"],
    "автоаллергенный": ["аутоаллергенный"],
    "автоарфа": ["автохарп"],
    "автобан": ["автострада"],
    "автобензовоз": ["автобензоцистерна"],
    "автобензоцистерна": ["автобензовоз"],
    "автобетоновоз": ["бетоновоз"],
    "автобиографически": ["автобиографично"],
    "автобиографично": ["автобиографически"],
    "автобитумовоз": ["автомобиль-битумовоз"],
    "автоблокировка": ["аб", "автоматическая блокировка"],
    "автобрекчия": ["автомагматическая брекчия"],
    "автоброневой": ["автомобильно-броневой"],
    "автобронзант": ["автозагар"],
    "автовагон": ["автомотрисса"],
    "автовакцина": ["аутовакцина"],
    "автовоз": ["автомобилевоз"],
    "автовор": ["автоугонщик"],
    "автогазозаправка": ["автогазозаправочная станция", "газозаправка"],
    "автогамия": ["аутогамия", "самооплодотворение"],
    "автогамный": ["аутогамный"],
    "автогенез": ["аутогенез"],
    "автогенератор": ["генератор с самовозбуждением"],
    "автогенная сварка": ["газовая сварка"],
    "автогетеротроф": ["миксотроф"],
    "автогидроподъёмник": ["автомобиль-вышка", "автовышка", "агп"],
    "автогипноз": ["самогипноз"],
    "автогир": ["автожир", "гирокоптер", "гироплан"],
    "автогражданка": ["осаго"],
    "автограм": ["автограф"],
    "автограмма": ["аутограмма"],
    "автогужбаза": ["автогужевой", "база"],
    "автодафе": ["аутодафе"],
    "автодача": ["автодом"],
    "автодворник": ["автощётка"],
    "автодело": ["автомобилизм"],
    "автодермопластика": ["аутодермопластика"],
    "автодиагностика": ["самодиагностика"],
    "автодигестия": ["самопереваривание", "аутодигестия"],
    "автодидакт": ["самоучка"],
    "автодидактика": ["самообучение", "самообразование"],
    "автодидактический": ["самообучающий"],
    "автодом": ["кемпер", "автодача", "караван"],
    "автодополнение": ["автокомплит"],
    "автодуальность": ["самодвойственность"],
    "автожир": ["гироплан", "гирокоптер", "ротаплан", "автогир"],
    "автозаводец": ["торпедовец"],
    "автозагар": ["автобронзант", "крем-автозагар"],
    "автозак": ["пативэн"],
    "автозаправка": ["автозаправочная станция", "азс", "бензоколонка"],
    "автозаправочная станция": ["азс", "автозаправка"],
    "автоидентификация": ["аутоидентификация"],
    "автоиммунный": ["аутоиммунный"],
    "автоинвазия": ["аутоинвазия"],
    "автоиндустрия": ["автопромышленность"],
    "автоинфекция": ["аутоинфекция"],
    "автоирония": ["самоирония"],
    "автокар": ["автотележка"],
    "автокартограф": ["стереокартограф", "стереопланиграф", "стереоавтограф"],
    "автокатализ": ["аутокатализ"],
    "автокатафалк": ["катафалк"],
    "автокатод": ["автоэмиссионный катод"],
    "автокефалия": ["автокефальность"],
    "автокефальность": ["автокефалия"],
    "автокефальный": ["независимый", "самовозглавляемый", "самоуправляемый"],
    "автоклавировав": ["автоклавировавши"],
    "автоклавировавши": ["автоклавировав"],
    "автокластит": ["тектоническая брекчия"],
    "автокластический": ["аутокластический", "обломочный", "брекчиевый", "щебнистый"],
    "автокод": ["язык ассемблера", "ассемблер"],
    "автокодировщик": ["автоэнкодер"],
    "автоконфигурировав": ["автоконфигурировавши"],
    "автоконфигурировавши": ["автоконфигурировав"],
    "автокормушка": ["самокормушка"],
    "автократ": ["диктатор", "самодержец"],
    "автократия": ["самовластие"],
    "автокунилингус": ["автокуннилингус", "аутокунилингус", "аутокуннилингус"],
    "автокуннилингус": ["автокунилингус", "аутокунилингус", "аутокуннилингус"],
    "автоледи": ["водительница"],
    "автолиз": ["аутолиз", "самопереваривание"],
    "автолизировав": ["автолизировавши"],
    "автолизировавши": ["автолизировав"],
    "автолизировать": ["аутолизировать"],
    "автолизный": ["аутолизный"],
    "автолиния": ["ал"],
    "автолитический": ["аутолитический"],
    "автолихач": ["лихач"],
    "автологический": ["автологичный", "гомологический", "гомологичный", "рефлексивный", "самоприменимый"],
    "автомагистраль": ["автострада"],
    "автомат": ["штурмовая винтовка", "телефонная будка", "таксофон"],
    "автоматизировав": ["автоматизировавши"],
    "автоматизировавши": ["автоматизировав"],
    "автоматизм": ["автоматичность"],
    "автоматическая блокировка": ["аб", "автоблокировка"],
    "автоматически": ["непроизвольно", "машинально", "безотчётно", "бессознательно", "механически", "механично", "автоматично", "невольно", "автоматом", "автопилотом", "неумышленно"],
    "автоматический определитель номера": ["аон"],
    "автоматично": ["автоматически"],
    "автоматичность": ["автоматизм"],
    "автоматичный": ["автоматический"],
    "автомедон": ["автомедонт"],
    "автомеханохория": ["механохория"],
    "автомиктический": ["аутомиктический"],
    "автомобил": ["кола"],
    "автомобиле-час": ["автомобилечас"],
    "автомобилевоз": ["автовоз"],
    "автомобилеразгрузчик": ["автоопрокидыватель"],
    "автомобилестроение": ["автостроение"],
    "автомобилестроительный": ["автостроительный"],
    "автомобилечас": ["автомобиле-час"],
    "автомобилизировав": ["автомобилизировавши"],
    "автомобилизировавши": ["автомобилизировав"],
    "автомобилизм": ["автодело", "автоспорт"],
    "автомобиль-бетоносмеситель": ["автобетоносмеситель"],
    "автомобиль-битумовоз": ["автобитумовоз"],
    "автомобиль-кран": ["автокран"],
    "автомобиль-мусоровоз": ["мусоровоз"],
    "автомобиль-фургон": ["автофургон"],
    "автомобиль-цементовоз": ["автоцементовоз"],
    "автомобильная дорога": ["автострада", "автотрасса", "автобан"],
    "автомобильная пробка": ["дорожный затор", "пробка", "затор"],
    "автомобильный катализатор": ["каталитический конвертер"],
    "автомодерация": ["автомодерирование", "самомодерирование"],
    "автоморфный": ["идиоморфный"],
    "автомутаген": ["аутомутаген"],
    "автонастройка": ["самонастройка"],
    "автоним": ["экзоним"],
    "автономия": ["самоуправление"],
    "автономная нервная система": ["вегетативная нервная система"],
    "автономная область": ["автономный регион"],
    "автономная республика крым": ["крым", "арк"],
    "автономность": ["независимость", "самостоятельность"],
    "автономный": ["независимый", "самостоятельный", "самоуправляющийся"],
    "автоокисление": ["самоокисление", "автооксидация"],
    "автооксидация": ["аутооксидация"],
    "автоориентация": ["аутоориентация"],
    "автоответ": ["автоответчик"],
    "автоответчик": ["автоответ"],
    "автопарковка": ["автостоянка"],
    "автоперевод": ["самоперевод", "машинный перевод"],
    "автопередвижка": ["автомастерская"],
    "автопиар": ["самореклама"],
    "автопилот": ["стабилизатор", "авторулевой", "гирорулевой"],
    "автоплоидия": ["аутоплоидия"],
    "автопокрышка": ["автомобильная шина"],
    "автополиплоид": ["аутополиплоид"],
    "автополиплоидия": ["аутополиплоидия"],
    "автополиплоидный": ["аутополиплоидный"],
    "автопомощь": ["помощь на дороге"],
    "автопортрет": ["селфи"],
    "автопоэз": ["аутопоэз", "самосозидание"],
    "автопреступник": ["автоугонщик"],
    "автопрокладчик": ["одограф"],
    "автопромышленность": ["автоиндустрия", "автопром"],
    "автопутешественник": ["автотурист"],
    "автор": ["создатель", "творец", "сочинитель", "разработчик", "задумщик", "организатор"],
    "автор-исполнитель": ["бард"],
    "авторадиограмма": ["ауторадиограмма"],
    "авторадиография": ["ауторадиография"],
    "авторазбор": ["авторазборка"],
    "авторегрессионный": ["авторегрессивный"],
    "авторедукция": ["саморедукция"],
    "авторезина": ["резина", "шина"],
    "авторемзавод": ["авторемонтный", "завод"],
    "автореферентность": ["самореферентность"],
    "автореферентный": ["самореферентный"],
    "авторецептор": ["ауторецептор"],
    "авторизировав": ["авторизировавши"],
    "авторизировавши": ["авторизировав"],
    "авторизировать": ["авторизовать"],
    "авторизовав": ["авторизовавши"],
    "авторизовавши": ["авторизовав"],
    "авторизовать": ["авторизировать"],
    "авторизовывав": ["авторизовывавши"],
    "авторизовывавши": ["авторизовывав"],
    "авторикша": ["моторикша"],
    "авторитарный": ["самодержавный", "деспотический"],
    "авторитет": ["влияние", "престиж"],
    "авторитетный": ["влиятельный", "признанный", "уважаемый", "повелительный", "властный", "веский"],
    "авторка": ["авторша", "авторесса"],
    "авторобот": ["рихтовка"],
    "авторское право": ["копирайт", "интеллектуальная собственность"],
    "авторство": ["сочинительство"],
    "авторствовав": ["авторствовавши"],
    "авторствовавши": ["авторствовав"],
    "авторствовать": ["писать", "писательствовать", "сочинять", "придумывать", "изрекать", "вещать"],
    "авторулевой": ["гирорулевой"],
    "авторут": ["автобан", "автострада", "хайвей"],
    "авторучка": ["самописка"],
    "автосамосвал": ["самосвал"],
    "автосемантический": ["аутосемантический", "знаменательный", "категорематический", "категорематичный", "полнозначный"],
    "автосеротерапия": ["аутосеротерапия"],
    "автосигнализация": ["сигналка", "сигнашка"],
    "автосиндез": ["самоконъюгация"],
    "автоскейлинг": ["автомасштабирование"],
    "автоскрепление": ["автофретаж", "самоскрепление"],
    "автосохранение": ["автосейв", "видеоигра", "контрольная точка", "чекпоинт"],
    "автоспора": ["апланоспора"],
    "автоспорт": ["автомобилизм"],
    "автостанция": ["автопредприятие", "автовокзал"],
    "автостарт": ["автозапуск"],
    "автостартёр": ["стартёр"],
    "автостерильность": ["самобесплодность"],
    "автостерильный": ["самостерильный"],
    "автостоп": ["стоп"],
    "автостопер": ["автостопщик"],
    "автостоповец": ["автостопщик"],
    "автостопщик": ["автостопер", "стопщик"],
    "автострада": ["автомагистраль", "автобан", "автотрасса", "хайвэй"],
    "автосуггестия": ["аутосуггестия", "самовнушение"],
    "автотерапия": ["аутотерапия"],
    "автотип": ["аутотип"],
    "автотолерантность": ["аутотолерантность"],
    "автотомия": ["аутотомия"],
    "автотрансплантат": ["аутотрансплантат"],
    "автотранспорт": ["автомобильный транспорт"],
    "автотранспортная компания": ["автотранспортное предприятие"],
    "автотранспортное предприятие": ["автотранспортная компания"],
    "автотрансфузия": ["аутотрансфузия", "аутогемотрансфузия"],
    "автотрасса": ["автомагистраль"],
    "автотроф": ["продуцент"],
    "автотуракъ": ["автодуракъ"],
    "автофелляция": ["самоминет", "аутофелляция"],
    "автофилия": ["аутофилия"],
    "автофон": ["идиофон"],
    "автофретаж": ["автоскрепление", "самоскрепление"],
    "автофура": ["автофургон"],
    "автохарп": ["автоарфа"],
    "автохлам": ["автолом", "драндулет"],
    "автохтонный": ["аборигенный", "местный", "аутохтонный", "индигенный"],
    "автоцистерна": ["автомобиль-цистерна"],
    "автоцитотоксин": ["аутоцитотоксин"],
    "авточасть": ["автозапчасть"],
    "автошлях": ["дорога", "шлях", "траса"],
    "автоэвакуатор": ["эвакуатор", "машина-эвакуатор", "тягач-эвакуатор"],
    "автоэкологический": ["аутоэкологический"],
    "автоэкология": ["аутоэкология"],
    "автоэнкодер": ["автокодировщик"],
    "автоэпитаксия": ["гомоэпитаксия"],
    "автоэтноним": ["эндоэтноним"],
    "авузлук": ["авузлух"],
    "авуч": ["увуц", "увуч"],
    "авыл": ["йурт"],
    "авыраерга": ["начарланырга", "начараерга"],
    "авырга": ["амырга"],
    "авырту": ["сызлау"],
    "авыру": ["чирле", "сырхау", "хаста", "чир"],
    "ага": ["да", "хорошо", "договорились", "ладно", "окей", "ого", "надо же", "опля", "ха"],
    "агавный": ["агавовый"],
    "агакати": ["егекати"],
    "агальматолит": ["восковой камень", "жировик"],
    "агама": ["адмил", "акма"],
    "агамия": ["агамогенез", "безбрачие"],
    "агапэ": ["любовь к ближнему"],
    "агар": ["агар-агар", "китайский желатин", "японский желатин", "бенгальский рыбий клей", "целентанг"],
    "агар-агар": ["агар"],
    "агарик": ["лиственничная губка"],
    "агариковый": ["шампиньоновый"],
    "агарырга": ["аксылланырга"],
    "агарь": ["хагар"],
    "агарянец": ["агарянин", "турчин"],
    "агарянин": ["измаилит", "араб"],
    "агарянка": ["арабка"],
    "агарянски": ["мюсюлмански"],
    "агат": ["моховик", "моховой камень", "уголь", "ночь"],
    "агата": ["агафья", "агафия"],
    "агафа": ["агафья", "агафия"],
    "агафия": ["агаша", "агафа", "агата", "агафья"],
    "агафон": ["агатон", "агапон", "гапон"],
    "агафья": ["агаша", "агафия", "агафа", "агата"],
    "агач": ["километар"],
    "агач-кумуз": ["кумуз"],
    "аггадический": ["агадический"],
    "аггел": ["демон"],
    "агглютинировав": ["агглютинировавши"],
    "агглютинировавши": ["агглютинировав"],
    "аггравировав": ["аггравировавши"],
    "аггравировавши": ["аггравировав"],
    "агда": ["агдака"],
    "агевзия": ["агевстия"],
    "агендерность": ["небинарная гендерная система"],
    "агенезия": ["аплазия"],
    "агенс": ["субъект действия", "каузатор"],
    "агент": ["представитель", "уполномоченный", "проводник", "разведчик", "шпион", "резидент", "информатор", "сыщик", "детектив", "осведомитель", "слухач", "соглядатай", "топтун", "шпик", "филёр"],
    "агентесса": ["шпионка", "сексотка"],
    "агентив": ["дательно-винительный падеж"],
    "агентин": ["агент"],
    "агентировав": ["агентировавши"],
    "агентировавши": ["агентировав"],
    "агенция": ["агентство", "представителство", "бюро"],
    "агиографический": ["доксологический", "поэтически-прославляющий"],
    "агиология": ["агиография"],
    "агионим": ["агиоантропоним"],
    "агиопульмонография": ["апг"],
    "агиофобия": ["иерофобия"],
    "агитатор": ["пропагандист", "ажитатор", "проповедник"],
    "агитаторский": ["агитационный", "пропагандистский"],
    "агитаторша": ["пропагандистка"],
    "агитациски": ["агитационен"],
    "агитация": ["пропаганда"],
    "агитбригада": ["агитколлектив", "агитпропбригада", "агитационно-художественная бригада"],
    "агитировав": ["агитировавши"],
    "агитировавши": ["агитировав"],
    "агитирование": ["агитация"],
    "агитклип": ["агитролик"],
    "агитпроп": ["агитация", "пропаганда", "агитпропотдел"],
    "агитпроповский": ["агитационно-пропагандистский"],
    "агитпункт": ["агитационный", "пункт"],
    "агитролик": ["агитклип"],
    "аглавра": ["агравла"],
    "аглая": ["глаша", "аглаша"],
    "агликон": ["генин"],
    "аглинский": ["английский", "аглийский", "аглицкий", "англинский", "англицкий"],
    "аглицкий": ["английский", "аглийский", "аглинский", "англинский", "англицкий"],
    "агломерационно-обогатительный": ["обогатительно-агломерационный"],
    "агломерировав": ["агломерировавши"],
    "агломерировавши": ["агломерировав"],
    "агломерирование": ["агломерация", "укрупнение"],
    "агломерит": ["агломерат"],
    "аглофабрика": ["агломерационная фабрика"],
    "агнец": ["ягнёнок", "барашек"],
    "агнец божий": ["ангел", "ангел во плоти", "ангел кротости", "агнец послушный", "агнец непорочный"],
    "агнец непорочный": ["агнец божий"],
    "агни-йога": ["живая этика"],
    "агонизирам": ["умирам", "издъхвам"],
    "агонизировав": ["агонизировавши"],
    "агонизировавши": ["агонизировав"],
    "агонировав": ["агонировавши"],
    "агонировавши": ["агонировав"],
    "агонировать": ["агонизировать"],
    "агонист": ["боец"],
    "агонистарх": ["агонофет"],
    "агонистик": ["циркумцеллион"],
    "агонофет": ["агонистарх", "афлофет", "эсимнет"],
    "агор": ["агорот"],
    "агорафобия": ["местобоязнь"],
    "агорот": ["агор"],
    "агп": ["автомат гашения поля"],
    "аграмантный": ["аграмантовый"],
    "аграмантовый": ["аграмантный"],
    "аграмба": ["агримба"],
    "агранулоцитоз": ["алейкия", "анейтрофилёз", "гранулофтиз"],
    "агранулярный": ["гладкий", "незернистый"],
    "аграрен": ["земеделски", "землен", "селски"],
    "аграрий": ["аграрник"],
    "аграрник": ["аграрий"],
    "аграрно-промышленный": ["агропромышленный"],
    "аграрный": ["сельскохозяйственный"],
    "аграрный цех": ["агроцех"],
    "аграфа": ["аграф"],
    "агрегат": ["установка", "конструкция", "комплекс", "машина", "множество"],
    "агрегатировав": ["агрегатировавши"],
    "агрегатировавши": ["агрегатировав"],
    "агрегатно-модульный": ["модульно-агрегатный"],
    "агрегатно-поточный": ["поточно-агрегатный"],
    "агрегация": ["агрегирование"],
    "агрегировав": ["агрегировавши"],
    "агрегировавши": ["агрегировав"],
    "агрегирование": ["агрегация", "соединение", "суммирование", "укрупнение", "слипание", "встраивание"],
    "агрегировать": ["объединять", "объединить", "суммировать", "соединять", "соединить"],
    "агреман": ["агремент"],
    "агресия": ["нападение", "завоевание", "настъпление", "нашествие", "окупация", "експанзия", "нахлуване", "нахълтване", "навлизане"],
    "агрессивная реклама": ["агрессивный маркетинг"],
    "агрессивное большинство": ["агрессивно-послушное большинство"],
    "агрессивный": ["воинственный", "напористый", "наступательный"],
    "агрессировав": ["агрессировавши"],
    "агрессировавши": ["агрессировав"],
    "агрессия": ["нападение"],
    "агрессор": ["забияка"],
    "агрив": ["агривши"],
    "агривши": ["агрив"],
    "агрикультура": ["агрокультура", "земледелие"],
    "агрикультурный": ["агрокультурный", "земледельческий"],
    "агрипния": ["асомния", "инсомния", "бессонница", "диссомния"],
    "агрить": ["провоцировать", "злить", "раздражать"],
    "агриться": ["злиться", "сердиться"],
    "агробизнес": ["сельхозбизнес"],
    "агровуз": ["сельхозакадемия"],
    "агрокультурный": ["сельскохозяйственный"],
    "агромелиорация": ["мелиорация"],
    "агронаука": ["агрономия"],
    "агроначальник": ["агрочиновник"],
    "агрономив": ["агрономивши"],
    "агрономивши": ["агрономив"],
    "агрономша": ["агрономка"],
    "агропредприятие": ["агрохозяйство"],
    "агропром": ["агропромышленный комплекс", "апк"],
    "агропромисловий": ["аграрно-промисловий"],
    "агропромкомитет": ["агропром"],
    "агропромобъединение": ["агропром", "агропромкомплекс"],
    "агропромснаб": ["агроснаб"],
    "агропромстрой": ["агрострой"],
    "агропромхимия": ["агрохимобъединение"],
    "агропромышленный": ["аграрно-промышленный"],
    "агропромышленный комплекс": ["апк", "агропром"],
    "агрорайон": ["агрорегион"],
    "агрорегион": ["агрорайон"],
    "агроснаб": ["агропромснаб"],
    "агрострахование": ["сельхозстрахование"],
    "агрострой": ["агропромстрой"],
    "агротехникум": ["сельхозтехникум"],
    "агротип": ["земтип"],
    "агрофитоценоз": ["агроценоз"],
    "агрохимобъединение": ["агропромхимия"],
    "агрохозяйство": ["агропредприятие"],
    "агроценоз": ["агрофитоценоз"],
    "агрочиновник": ["агроначальник"],
    "агу": ["агу-гу"],
    "агукав": ["агукавши"],
    "агукавши": ["агукав"],
    "агукнув": ["агукнувши"],
    "агукнувши": ["агукнув"],
    "агуленьки": ["агулечки", "агунюшки", "агушеньки"],
    "агулечки": ["агуленьки", "агунюшки", "агушеньки"],
    "агунюшки": ["агуленьки", "агулечки", "агушеньки"],
    "агути": ["горбатый заяц", "золотистый заяц"],
    "агушеньки": ["агуленьки", "агулечки", "агунюшки"],
    "агъац": ["агъач"],
    "агъыз": ["авуз", "авыз"],
    "ад": ["преисподняя", "бездна", "пекло", "тартар", "тартарары", "геенна", "геенна огненная", "тьма кромешная", "печь огненная", "царство теней", "подземное царство", "адея", "хаос", "ужас"],
    "ад в груди": ["ад в душе"],
    "ад в душе": ["ад в груди"],
    "ад кромешный": ["кромешный ад"],
    "ада": ["аделаида"],
    "ададывэс": ["дадывэс"],
    "адак": ["уэш", "эше"],
    "адамава": ["адамауа"],
    "адамант": ["алмаз"],
    "адамантинома": ["адамантобластома", "аденоамелобластома", "амелобластома"],
    "адамантобласт": ["амелобласт", "энамелобласт"],
    "адамантовый": ["алмазный", "бриллиантовый"],
    "адамауа": ["адамава"],
    "адамит": ["адамитянин", "богомил"],
    "адамова смоква": ["банан райский"],
    "адамово дерево": ["павловния"],
    "адамово яблоко": ["кадык", "маклюра", "оранжевый"],
    "адамсит": ["дигидрофенарсазинхлорид"],
    "адаптациогенез": ["адаптиогенез"],
    "адаптациоморфоз": ["адаптиоморфоз"],
    "адаптация": ["подстраивание", "приспосабливание", "подгонка"],
    "адаптер": ["переходник", "звукосниматель"],
    "адаптивность": ["приспосабливаемость"],
    "адаптивный": ["адаптационный"],
    "адаптиогенез": ["адаптациогенез"],
    "адаптиоморфоз": ["адаптациоморфоз"],
    "адаптировав": ["адаптировавши"],
    "адаптировавши": ["адаптировав"],
    "адаптировать": ["приспособлять", "приспособить", "настраивать", "настроить", "подстраивать", "подлаживать"],
    "адаптироваться": ["приспособиться", "подстроиться", "привыкнуть", "свыкнуться", "притерпеться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться", "приспосабливаться"],
    "адаптируемость": ["приспособляемость", "приживаемость"],
    "адвайта-веданта": ["майявада"],
    "адвент": ["пришествие"],
    "адвентивний": ["чужий", "невластивий"],
    "адвентивный": ["чужеродный", "неаборигенный", "инвазионный"],
    "адвербиализировав": ["адвербиализировавши"],
    "адвербиализировавши": ["адвербиализировав"],
    "адвербиализовав": ["адвербиализовавши"],
    "адвербиализовавши": ["адвербиализовав"],
    "адвербиализовывав": ["адвербиализовывавши"],
    "адвербиализовывавши": ["адвербиализовывав"],
    "адвербиальный": ["наречный"],
    "адверсативный": ["противительный", "неблагоприятный"],
    "адверсив": ["аллатив", "адлатив", "падеж приближения"],
    "адвокат": ["защитник", "заступник", "поборник"],
    "адвокат дьявола": ["укрепитель веры"],
    "адвокатеса": ["адвокатка"],
    "адвокатин": ["адвокат"],
    "адвокатирати": ["адвокатисати"],
    "адвокатисати": ["адвокатирати"],
    "адвокатишка": ["адвокатишко"],
    "адвокатка": ["адвокатеса"],
    "адвокатничав": ["адвокатничавши"],
    "адвокатничавши": ["адвокатничав"],
    "адвокатничать": ["адвокатствовать"],
    "адвокатство": ["заступничество", "защита"],
    "адвокатствовав": ["адвокатствовавши"],
    "адвокатствовавши": ["адвокатствовав"],
    "адвокатствовать": ["адвокатничать"],
    "адгезив": ["клей"],
    "адгезиметр": ["адгезиометр"],
    "адгезиометр": ["адгезиметр"],
    "адгезия": ["сцепление", "прилипание"],
    "адгерент": ["сообщник", "пособник"],
    "адгуус": ["амьтан"],
    "адденда": ["аддендум"],
    "аддендум": ["адденда"],
    "адджинаг": ["адджынад"],
    "аддикция": ["зависимость"],
    "аддисонова болезнь": ["болезнь аддисона", "гипокортицизм"],
    "аддуктор": ["приводящая мышца"],
    "адекватно": ["подходяще", "соответствующе", "достойно", "подобающе"],
    "адекватность": ["соответствие", "достаточность", "пригодность"],
    "адекватный": ["соответствующий", "равный", "тождественный"],
    "аделаида": ["алиса"],
    "аделамс": ["шумордамс", "прядомс", "ётафтомс", "кулофтомс", "стожамс", "шавомс"],
    "адениловая кислота": ["аденозинмонофосфорная кислота"],
    "адениловый": ["аденозинмонофосфорный"],
    "аденозиндифосфат": ["аденозиндифосфорная кислота"],
    "аденозиндифосфорная кислота": ["аденозиндифосфат"],
    "аденозинмонофосфат": ["амф", "адениловая кислота", "аденозинмонофосфорная кислота"],
    "аденозинтрифосфат": ["аденозинтрифосфорная кислота", "атф", "аденилпирофосфорная кислота"],
    "аденозинтрифосфорная кислота": ["аденозинтрифосфат"],
    "аденоканкроид": ["аденоакантома"],
    "аденокарцинома": ["железистый рак"],
    "аденомер": ["концевой отдел железы"],
    "аденофора": ["бубенчик"],
    "аденохондрома": ["гамартома"],
    "адессив": ["падеж нахождения", "падеж направления"],
    "адет": ["навик", "обичай", "привичка", "традиция", "тертип", "нрав", "характер"],
    "адех": ["адыг"],
    "аджамия": ["новак"],
    "аджарец": ["аджарели"],
    "аджария": ["аджарская автономная республика"],
    "аджарская автономная республика": ["аджария"],
    "аджигабул": ["кази-магомед"],
    "аджигабульский район": ["аджикабульский район"],
    "аджикабульский район": ["аджигабульский район"],
    "аджь": ["аджя"],
    "адиабата": ["изоэнтропа"],
    "адиабатический": ["адиабатный"],
    "адиабатный": ["адиабатический"],
    "адианоэта": ["амфиболия", "двусмысленность"],
    "адидас": ["адидаски", "адики"],
    "адината": ["импоссибилия"],
    "адипиновая кислота": ["гександиовая кислота"],
    "адипиновый": ["гександиовый"],
    "адипоз": ["ожирение"],
    "адипоцир": ["жировоск"],
    "адлатив": ["аллатив"],
    "адлегласць": ["аддаленасць", "прамежак"],
    "админ": ["сисадмин", "администратор", "системный администратор"],
    "административная единица": ["административно-территориальная единица"],
    "административно-волевой": ["административно-командный", "административно-приказной", "административно-нажимной"],
    "административно-командный": ["административно-приказной", "добровольно-принудительный"],
    "административно-номенклатурный": ["номенклатурно-административный"],
    "административно-отраслевой": ["административно-ведомственный"],
    "административно-приказной": ["административно-командный"],
    "административно-территориальная единица": ["ате"],
    "административно-экономический": ["экономико-административный"],
    "административный": ["организационный", "управленческий"],
    "административный восторг": ["административный зуд", "синдром вахтёра"],
    "административный зуд": ["административный восторг", "синдром вахтёра"],
    "административный округ": ["ао"],
    "администратор": ["распорядитель", "управляющий", "системный администратор", "сисадмин", "админ", "сисоп", "суперпользователь", "рут"],
    "администраторствовав": ["администраторствовавши"],
    "администраторствовавши": ["администраторствовав"],
    "администрационный": ["административный"],
    "администрировав": ["администрировавши"],
    "администрировавши": ["администрировав"],
    "администрирование": ["организация", "управление", "менеджмент"],
    "администрировать": ["управлять", "руководить"],
    "админнадзор": ["адмнадзор"],
    "админресурс": ["административный ресурс"],
    "админушка": ["админ", "администратор"],
    "адмирал-инженер": ["инженер-адмирал"],
    "адмиральски": ["по-адмиральски"],
    "адмиральский час": ["абсолют"],
    "адмиральствовав": ["адмиральствовавши"],
    "адмиральствовавши": ["адмиральствовав"],
    "адмиральша": ["командирша", "бандарша", "бандитка"],
    "адмиттанс": ["комплексная проводимость", "полная проводимость"],
    "адмнадзор": ["админнадзор"],
    "адмтехперсонал": ["административно-технический персонал"],
    "адмчасть": ["административная часть"],
    "аднадушна": ["аднагалосна"],
    "адначасна з": ["адначасова з"],
    "адначасова з": ["адначасна з"],
    "аднексит": ["сальпингоофорит"],
    "адоба": ["адоб", "саман"],
    "адов": ["адский"],
    "адовый": ["адский"],
    "адолескарий": ["адолескария"],
    "адолескария": ["адолескарий"],
    "адольф": ["адик"],
    "адольфович": ["адольфич"],
    "адонай": ["танри"],
    "адонис": ["аполлон", "купидон", "эндимион"],
    "адоптация": ["аффилиация"],
    "адоптировав": ["адоптировавши"],
    "адоптировавши": ["адоптировав"],
    "адоральный": ["оральный", "ростральный", "околоротовой", "приротовой"],
    "адоратер": ["поклонник", "почитатель", "любитель", "обожатель", "адоратёр", "адоратор", "воздыхатель", "кавалер", "ухажёр", "ухаживатель", "хахаль", "бабник", "волокита", "дамский любезник", "дамский угодник"],
    "адоратор": ["поклонник", "почитатель", "кавалер", "воздыхатель", "обожатель", "ухажёр", "ухаживатель", "хахаль", "адоратер", "адоратёр", "волокита", "дамский угодник", "донжуан", "ловелас", "повеса"],
    "адорировав": ["адорировавши"],
    "адорировавши": ["адорировав"],
    "адр": ["американская депозитарная расписка"],
    "адраджэнне": ["рэнесанс"],
    "адраспан": ["гармала", "могильник"],
    "адреналин": ["эпинефрин"],
    "адренокортикотропин": ["кортикотропин", "адренокортикотропный гормон"],
    "адреномиметик": ["адреностимулятор"],
    "адрес": ["местонахождение"],
    "адресант": ["отправитель", "грузоотправитель"],
    "адресантка": ["отправительница"],
    "адресат": ["получатель"],
    "адресовав": ["адресовавши"],
    "адресовавши": ["адресовав"],
    "адресовальный": ["адресопечатающий"],
    "адресовать": ["направлять", "посылать"],
    "адресоваться": ["обращаться", "обратиться"],
    "адресок": ["адрес", "координаты"],
    "адресопечатающий": ["адресовальный"],
    "адрианополь": ["эдирне", "адрианополис"],
    "адриатическое море": ["адриатика"],
    "адская машина": ["снаряд", "бомба", "орудие"],
    "адски": ["сильно", "очень", "безбожно", "безумно", "дико", "дьявольски", "жутко", "зверски", "кошмарно", "страшно", "ужасно", "чертовски", "чудовищно"],
    "адский": ["адовый", "чёртовый", "дьявольский", "мефистофельский", "инфернальный", "злобный", "коварный", "чрезвычайный", "чрезмерный"],
    "адский камень": ["нитрат серебра"],
    "адсорбировав": ["адсорбировавши"],
    "адсорбировавши": ["адсорбировав"],
    "адсорбирование": ["адсорбция"],
    "адсорбировать": ["поглощать", "впитывать", "абсорбировать"],
    "адуляр": ["лунный камень"],
    "адуляция": ["лесть", "угодничество"],
    "адхократия": ["эдхократия"],
    "адхортатив": ["когортатив"],
    "адъективация": ["адъективирование"],
    "адъективировав": ["адъективировавши"],
    "адъективировавши": ["адъективировав"],
    "адъективирование": ["адъективация"],
    "адъюнкт": ["сирконстант"],
    "адъюнктствовав": ["адъюнктствовавши"],
    "адъюнктствовавши": ["адъюнктствовав"],
    "адъютант": ["ординарец", "денщик", "вестовой"],
    "адъютантик": ["адъютант", "адъютантишко"],
    "адъютантка": ["ординарша", "вестовая"],
    "адъютантствовав": ["адъютантствовавши"],
    "адъютантствовавши": ["адъютантствовав"],
    "адыгейск": ["теучежск"],
    "адыгейский": ["черкесский", "адыгейский язык"],
    "адыгейский язык": ["адыгейский"],
    "адыгея": ["республика адыгея"],
    "адью": ["адьё"],
    "адьё": ["адью"],
    "адэкватный": ["соответствующий", "равный", "тождественный"],
    "адюльтер": ["супружеская измена", "прелюбодеяние"],
    "аердомс": ["тумс", "потамс"],
    "аерогара": ["летище"],
    "аероплан": ["самолет"],
    "аеропорт": ["летовище"],
    "аерылгысыз": ["аерылмас"],
    "аж": ["даже", "ажно", "ажник", "целый"],
    "ажгон": ["айован душистый", "индийский тмин"],
    "ажио": ["лаж"],
    "ажиотаж": ["бум", "спрос", "возбуждение", "оживление"],
    "ажиотажный": ["лихорадочный"],
    "ажиотировав": ["ажиотировавши"],
    "ажиотировавши": ["ажиотировав"],
    "ажитация": ["волнение", "возбуждение"],
    "ажитировав": ["ажитировавши"],
    "ажитировавши": ["ажитировав"],
    "ажник": ["даже", "аж", "ажно"],
    "ажно": ["аж", "даже", "прямо"],
    "ажур": ["кружево", "порядок"],
    "ажурний": ["ажуровий"],
    "ажурно": ["ажуром"],
    "ажурный": ["кружевной"],
    "ажуровий": ["ажурний"],
    "ажуром": ["ажурно"],
    "ажюстировав": ["ажюстировавши"],
    "ажюстировавши": ["ажюстировав"],
    "ажюстёр": ["подмастерье"],
    "аз": ["буква", "начало", "основа", "элементарщина", "пропись", "вершок", "зад"],
    "азазель": ["сатана", "дьявол", "люцифер", "мефистофель", "самаэль", "марут", "азаель", "демон", "чёрт"],
    "азак": ["ахыр"],
    "азалия": ["аза", "заля", "зала"],
    "азан": ["эзан"],
    "азанде": ["банда"],
    "азармах": ["азармак"],
    "азарт": ["страсть"],
    "азартная игра": ["гемблинг", "гэмблинг"],
    "азартний": ["завзятий", "пристрасний"],
    "азартничав": ["азартничавши"],
    "азартничавши": ["азартничав"],
    "азартно": ["увлечённо", "страстно"],
    "азартный": ["страстный", "увлекающийся", "рискованный"],
    "азас": ["таска"],
    "азатлыкъ": ["эркинлик", "ихтиярлылыкъ"],
    "азаттык": ["боштондук", "эркиндик"],
    "азбест": ["амиант"],
    "азбука": ["алфавит", "абевега", "букварь", "азы", "основы"],
    "азбука морзе": ["морзянка"],
    "азбуковий": ["азбучний", "абетковий", "абетний"],
    "азбучная истина": ["прописная истина", "трюизм"],
    "азбучний": ["абетковий", "абетний", "азбуковий", "елементарний", "прописний", "простий"],
    "азбучность": ["незамысловатость"],
    "аздингашта": ["муртад"],
    "азер": ["азербайджанец", "азерб", "азербон", "азербот", "азербуд", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азерб": ["азер", "азербайджанец", "азербон", "азербот", "азербуд", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азербайджан": ["азербайджанская республика", "азербайджанская сср", "азсср"],
    "азербайджанец": ["азер", "азерб", "азербон", "азербот", "азербуд", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азербайджано-американский": ["американо-азербайджанский"],
    "азербайджано-российский": ["российско-азербайджанский"],
    "азербайджанская республика": ["азербайджан"],
    "азербайджанская сср": ["азербайджан"],
    "азербайджанский": ["азерский", "азербайджанский язык"],
    "азербайджанский язык": ["азери"],
    "азербон": ["азер", "азербайджанец", "азерб", "азербот", "азербуд", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азербот": ["азер", "азербайджанец", "азерб", "азербон", "азербуд", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азербуд": ["азер", "азербайджанец", "азерб", "азербон", "азербот", "азик", "айзер", "азербейджанец", "закавказский татарин"],
    "азиат": ["азиец", "варвар"],
    "азиатический": ["азиатский"],
    "азиатский нью-йорк": ["город льва"],
    "азиатско-тихоокеанский регион": ["атр"],
    "азиатство": ["азиатчина"],
    "азиатствовав": ["азиатствовавши"],
    "азиатствовавши": ["азиатствовав"],
    "азиатчина": ["азийство", "варварство"],
    "азив": ["навоз"],
    "азивец": ["азовец", "навозовец"],
    "азийство": ["азиатчина"],
    "азик": ["азер", "азерб", "азербайджанец", "азербон", "азербот", "азербуд", "айзер", "азербейджанец", "закавказский татарин"],
    "азимутальний": ["азимутний"],
    "азимутальный": ["азимутный"],
    "азимутний": ["азимутальний"],
    "азимутный": ["азимутальный"],
    "азк": ["автозаправочный комплекс"],
    "азнаур": ["азнаури"],
    "азнаури": ["азнаур"],
    "азобкашида": ["азобдида"],
    "азовец": ["азовчанин", "навозовец", "азивец"],
    "азовское море": ["барэль-азов", "франкское море", "сурожское море", "каффское море", "киммерийское море", "акдениз", "меотское озеро", "меотида"],
    "азовчанин": ["азовец"],
    "азой": ["катархей"],
    "азокраска": ["метилоранж"],
    "азомс": ["мярьгомс", "азомс латта", "пачфтемс", "пачфтемс латта", "азондомс"],
    "азорские острова": ["азоры"],
    "азот": ["ашдод"],
    "азотизация": ["азотирование", "нитрирование"],
    "азотировав": ["азотировавши"],
    "азотировавши": ["азотировав"],
    "азотировать": ["нитрировать"],
    "азотистоводородная кислота": ["азоимид", "азидоводород"],
    "азотистокислый": ["нитрит"],
    "азотоотдающий": ["азототдающий"],
    "азотосодержащий": ["азотсодержащий"],
    "азототдающий": ["азотоотдающий"],
    "азотоусваивающий": ["азотусваивающий"],
    "азотофиксирующий": ["азотфиксирующий"],
    "азотусваивающий": ["азотоусваивающий"],
    "азотфиксация": ["диазотрофия"],
    "азотфиксирующий": ["азотофиксирующий"],
    "азофоска": ["нитроаммофоска"],
    "азс": ["автозаправочная станция", "заправка"],
    "азт": ["азидотимидин"],
    "азу": ["зарядка"],
    "азурит": ["шессилит"],
    "азюлянт": ["беженец"],
    "азям": ["кафтан", "поддёвка", "халат", "балахон", "армяк", "зипун"],
    "аид": ["гадес", "плутон", "дит", "орк", "ад", "геенна", "преисподняя"],
    "аипп": ["сахъат"],
    "аистиный": ["аистовый"],
    "аистник": ["журавельник", "грабельник", "грабельки"],
    "аистовый": ["аистиный"],
    "аистообразные": ["голенастые"],
    "ай": ["ой", "ах"],
    "ай да": ["ну и"],
    "ай-ай-ай": ["ай-ай", "ай-яй-яй"],
    "ай-я-яй": ["ай-ай-ай"],
    "ай-яй-яй": ["ай-ай", "ай-ай-ай", "ой-ой"],
    "айах": ["айак"],
    "айбан": ["жаныбар"],
    "айбеншток": ["эйбеншток"],
    "айболит": ["эскулап"],
    "айвонча": ["шипанг"],
    "айгунь": ["айгун"],
    "айгър": ["жребец"],
    "айда": ["идти", "ехать", "идёмте", "пойдёмте", "айда-те", "айдате", "вперёд", "шагом марш"],
    "айда-те": ["айдате", "айда"],
    "айдате": ["айда-те", "айда", "идёмте", "пойдёмте"],
    "айе-айе": ["руконожка"],
    "айзер": ["азербайджанец", "азер", "азерб", "азербон", "азербот", "азербуд", "азик", "азербейджанец", "закавказский татарин"],
    "айкав": ["айкавши"],
    "айкавши": ["айкав"],
    "айкидоист": ["айкидока"],
    "айкидока": ["айкидоист"],
    "айкидошник": ["айкидоист", "айкидока"],
    "айкнув": ["айкнувши"],
    "айкнувши": ["айкнув"],
    "айлурофилия": ["галеофилия", "гатофилия"],
    "айлурофобия": ["галеофобия", "гатофобия"],
    "аймара": ["аймары"],
    "аймарский": ["аймарский язык"],
    "аймачный": ["аймаковый"],
    "аймиштать": ["аймиштаться"],
    "аймиштаться": ["аймиштать"],
    "айн": ["курилец"],
    "айнакюнь": ["бараски"],
    "айнгум": ["аньюм"],
    "айнштайн": ["эйнштэйн"],
    "айнырга": ["аекланырга"],
    "айнытырга": ["аекларга"],
    "айован": ["ажгон", "индийский тмин", "коптский тмин", "шабрий"],
    "айованец": ["айовец"],
    "айованский": ["айовский"],
    "айовец": ["айованец"],
    "айовский": ["айованский"],
    "айпад": ["айпэд"],
    "айпи": ["айпишник"],
    "айпишник": ["айпи"],
    "айс": ["круто", "классно", "кул", "кульно"],
    "айтилиш": ["талаффуз"],
    "айтишник": ["компьютерщик"],
    "айтишница": ["компьютерщица"],
    "айтмакъ": ["демек"],
    "айтрекинг": ["окулография"],
    "айту": ["деу"],
    "айфон": ["мобильник", "мобильный", "сотик", "сотовый"],
    "айфончик": ["айфон"],
    "айцец": ["бацька"],
    "айырбастату": ["ауыстыру"],
    "айяуаска": ["яге"],
    "ак": ["автомат калашникова", "армейский корпус", "авиационный комплекс", "армия крайова", "акционерная компания", "административный кодекс", "алтайский край", "абсорбционная колонна", "арбитражный комитет"],
    "ак-": ["академ-"],
    "акав": ["акавши"],
    "акавши": ["акав"],
    "академ": ["академка"],
    "академ-": ["ак-"],
    "академиски": ["академски"],
    "академический отпуск": ["академотпуск"],
    "академичка": ["академ", "академка", "академотпуск"],
    "академичный": ["классический", "научный", "теоретический"],
    "академка": ["академ", "академотпуск", "академический отпуск"],
    "академотпуск": ["академический отпуск"],
    "академски": ["академиски"],
    "акадия": ["акади"],
    "акажу": ["кешью", "красное дерево", "анакардиум западный", "индийский орех"],
    "акайрия": ["симптом аствацатурова"],
    "акант": ["медвежья лапа", "аканф"],
    "акантинный": ["шиповидный"],
    "аканье": ["акание"],
    "акапа": ["одиши"],
    "акари": ["мурадханлы"],
    "акариаз": ["акародерматит"],
    "акарин": ["акарина"],
    "акаталаземия": ["акаталазия"],
    "акаталазия": ["акаталаземия"],
    "акатаральный": ["некатаральный"],
    "акать": ["ломать щеку", "ломать щёку", "ломить щеку", "ломить щёку", "чокать"],
    "акаться": ["аркаться"],
    "акафист": ["неседален"],
    "акация серебристая": ["мимоза"],
    "акаэм": ["акм"],
    "аквааэробика": ["гидроаэробика"],
    "аквабайк": ["гидроцикл"],
    "аквабилдинг": ["аквааэробика"],
    "аквадискотека": ["водная дискотека"],
    "аквадистиллятор": ["бидистиллятор"],
    "аквалангист": ["водолаз"],
    "аквалангистка": ["водолазка"],
    "аквамаринний": ["аквамариновий"],
    "аквамариновий": ["аквамаринний"],
    "аквамариновый": ["аквамаринный"],
    "акванавт": ["гидронавт", "океанавт"],
    "акварель": ["акварельная краска"],
    "акварельная краска": ["акварель"],
    "аквариумистика": ["акваристика"],
    "аквацикл": ["гидроцикл", "аквабайк"],
    "акведук": ["водопровод", "водовод"],
    "аквилегия": ["водосбор"],
    "аквилон": ["борей"],
    "аквифер": ["водоносный горизонт"],
    "акдениз": ["средиземное море"],
    "акест": ["ацест", "эгест", "акеста"],
    "акеста": ["эгеста", "акаста", "акест", "сегеста"],
    "акетон": ["поддоспешник"],
    "аки": ["как", "так как", "как бы", "подобно", "словно"],
    "акиба": ["кольчатая нерпа"],
    "аким": ["градоначальник", "губернатор", "мэр"],
    "акинезия": ["акинез"],
    "акинетико-ригидный": ["акинетикоригидный"],
    "акк": ["аккаунт", "учётная запись", "учётка"],
    "аккадийский": ["аккадский"],
    "аккадский": ["аккадийский"],
    "аккадский язык": ["ассиро-вавилонский язык", "аккадийский язык"],
    "аккаунт": ["учётная запись", "учётка", "номер", "код", "акк"],
    "акклиматизация": ["акклиматизирование"],
    "акклиматизировав": ["акклиматизировавши"],
    "акклиматизировавши": ["акклиматизировав"],
    "акклиматизирование": ["акклиматизация"],
    "акклиматизировать": ["приспособить", "приспособлять"],
    "акклиматизироваться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться"],
    "акколада": ["посвящение в рыцари", "благословение", "наставление", "благопожелание", "напутствие"],
    "аккомодация": ["приспосабливание", "приспособление"],
    "аккомодировав": ["аккомодировавши"],
    "аккомодировавши": ["аккомодировав"],
    "аккомпанемент": ["сопровождение", "аранжировка", "подыгрывание", "игра"],
    "аккомпаниаторша": ["аккомпаниатор"],
    "аккомпанировав": ["аккомпанировавши"],
    "аккомпанировавши": ["аккомпанировав"],
    "аккомпанирование": ["подыгрывание"],
    "аккордный": ["аккордовый", "сдельный", "договорной"],
    "аккред": ["аккреда"],
    "аккреда": ["аккред"],
    "аккредитив": ["кредитное письмо", "кредитив"],
    "аккредитировав": ["аккредитировавши"],
    "аккредитировавши": ["аккредитировав"],
    "аккредитировать": ["уполномочить", "уполномочивать", "санкционировать", "регистрировать", "зарегистрировать", "аккредитовать"],
    "аккредитовав": ["аккредитовавши"],
    "аккредитовавши": ["аккредитовав"],
    "аккредитование": ["аккредитация"],
    "аккредитовывав": ["аккредитовывавши"],
    "аккредитовывавши": ["аккредитовывав"],
    "аккрецировав": ["аккрецировавши"],
    "аккрецировавши": ["аккрецировав"],
    "аккузатив": ["винительный падеж"],
    "аккула": ["акула"],
    "аккум": ["аккумулятор"],
    "аккумулировав": ["аккумулировавши"],
    "аккумулировавши": ["аккумулировав"],
    "аккумулирование": ["накапливание", "накопление"],
    "аккумулировать": ["накапливать", "сосредотачивать"],
    "аккумулятивный": ["накапливающий", "накопительный"],
    "аккумулятор": ["сумматор"],
    "аккумуляторный": ["аккумный"],
    "аккумуляционный": ["аккумулятивный"],
    "аккумуляция": ["аккумулирование"],
    "аккурат": ["точь-в-точь", "как раз", "прямо", "сразу", "ровно"],
    "аккуратист": ["педант", "чистюля"],
    "аккуратно": ["прилежно", "точно", "тщательно", "исполнительно", "осторожно", "осмотрительно", "насторожённо", "опасливо", "бережно", "постоянно"],
    "аккуратность": ["точность", "тщательность", "прилежание"],
    "аккуратный": ["исполнительный", "исправный", "прилежный", "точный", "тщательный", "опрятный", "чистоплотный", "чистюля"],
    "аклиматизировав": ["аклиматизировавши"],
    "аклиматизировавши": ["аклиматизировав"],
    "аклинальный": ["аклинический"],
    "акм": ["акаэм"],
    "акмак": ["келесоо"],
    "акмеист": ["адамист"],
    "акмола": ["астана", "акмолинск", "целиноград"],
    "акмолинск": ["астана", "акмола", "целиноград"],
    "акне": ["угри"],
    "акнув": ["акнувши"],
    "акнувши": ["акнув"],
    "ако": ["так как"],
    "аколит": ["причётник", "спутник"],
    "аколуф": ["аколит"],
    "акомпанировав": ["акомпанировавши"],
    "акомпанировавши": ["акомпанировав"],
    "акомпанировать": ["аккомпанировать"],
    "аконит": ["борец"],
    "акп": ["акпп"],
    "акпп": ["автомат", "коробка"],
    "акраб": ["каждум"],
    "акрамя": ["акром"],
    "акредитовав": ["акредитовавши"],
    "акредитовавши": ["акредитовав"],
    "акрида": ["саранча", "кузнечик"],
    "акриец": ["акреанин"],
    "акрил": ["полиакрилат", "акриловая краска", "полиакриламид", "акриловое волокно", "нитрон", "акрилан", "орлон"],
    "акрилзамещённый": ["акрилозамещённый"],
    "акрилозамещённый": ["акрилзамещённый"],
    "акрилонитрилбутадиенстирол": ["асб-пластик"],
    "акрихин": ["мепакрин"],
    "акробат": ["гимнаст"],
    "акробатически": ["акробатично"],
    "акробатично": ["акробатически"],
    "акробатичный": ["акробатический"],
    "акробатка": ["гимнастка"],
    "акробатничав": ["акробатничавши"],
    "акробатничавши": ["акробатничав"],
    "акробатничать": ["акробатствовать", "кривляться", "паясничать", "выделываться", "корячиться"],
    "акробатствовав": ["акробатствовавши"],
    "акробатствовавши": ["акробатствовав"],
    "акрокарпный": ["верхоплодный"],
    "акрокефал": ["акроцефал"],
    "акрокефалия": ["акроцефалия", "акрокрания", "оксицефалия", "пиргоцефалия", "череп башенный"],
    "акром": ["акрамя"],
    "акрон": ["головная лопасть"],
    "акроним": ["аббревиатура"],
    "акропетальный": ["акротонический", "акротонный"],
    "акросера": ["нильская трава"],
    "акросома": ["апикальное тельце", "перфораторий"],
    "акротизм": ["асфигмия"],
    "акротонный": ["акротонический", "акропетальный"],
    "акроцефал": ["акрокефал"],
    "акроцефалия": ["акрокефалия", "акрокрания", "оксицефалия", "пиргоцефалия", "башенный череп"],
    "акрынаерга": ["акрынланырга"],
    "акрынайтырга": ["акрынларга"],
    "аксакал": ["глава рода", "старейшина"],
    "аксакларга": ["аксарга"],
    "аксамит": ["парча", "оксамит", "бархат"],
    "аксамитный": ["аксамитовый"],
    "аксанграв": ["гравис"],
    "аксантегю": ["акут", "оксия", "острое ударение"],
    "акселерация": ["акцелерация"],
    "акселерировав": ["акселерировавши"],
    "акселерировавши": ["акселерировав"],
    "аксентий": ["аксён", "авксентий"],
    "аксерофтол": ["ретинол"],
    "аксессуар": ["причиндал", "принадлежность"],
    "аксиальный": ["осесимметричный"],
    "аксий": ["вардарий", "вардар"],
    "аксиллярный": ["подмышечный", "подкрыльцовый", "пазушный"],
    "аксиния": ["ксения"],
    "аксинья": ["ксения"],
    "аксиологический": ["ценностный"],
    "аксиом": ["аксиома"],
    "аксиома": ["постулат", "истина", "трюизм"],
    "аксиома эскобара": ["теорема эскобара", "эскобар"],
    "аксиоматизация": ["постулирование"],
    "аксиоматизировав": ["аксиоматизировавши"],
    "аксиоматизировавши": ["аксиоматизировав"],
    "аксирис": ["безвкусница"],
    "аксон": ["нейрит"],
    "аксонный": ["аксональный"],
    "аксумит": ["абиссинец", "эфиоп"],
    "аксумитъ": ["абиссинецъ"],
    "аксыл": ["ак", "сары", "сыек"],
    "аксён": ["аксентий", "авксентий"],
    "акт": ["действие", "поступок", "движение", "вмешательство", "документ", "постановление"],
    "акт родченкова": ["закон родченкова"],
    "актант": ["действующее лицо"],
    "актея": ["воронец"],
    "актив": ["костяк", "авуары"],
    "активация": ["активирование"],
    "активизира": ["активира"],
    "активизира се": ["активира се"],
    "активизировав": ["активизировавши"],
    "активизировавши": ["активизировав"],
    "активизированный": ["побуждённый", "пробуждённый", "возбуждённый", "активированный"],
    "активизировать": ["интенсифицировать"],
    "активира": ["активизира"],
    "активира се": ["активизира се"],
    "активировав": ["активировавши"],
    "активировавши": ["активировав"],
    "активирование": ["активация"],
    "активист": ["деятель"],
    "активистка": ["деятельница"],
    "активничав": ["активничавши"],
    "активничавши": ["активничав"],
    "активно": ["усердно", "истово", "живо", "деятельно", "энергично", "инициативно"],
    "активность": ["энергичность", "напористость", "оживлённость", "инициативность", "деятельность", "мероприятие"],
    "активный": ["деятельный", "энергичный", "инициативный", "напористый", "текущий", "продуктивный"],
    "активный залог": ["действительный залог"],
    "активный словарь": ["активный словарный запас"],
    "актинид": ["актиноид"],
    "актинизм": ["актиничность"],
    "актиний": ["эманий"],
    "актинический": ["актиничный"],
    "актиния": ["анемон"],
    "актиноид": ["актиниды", "актинид"],
    "актиномицет": ["лучистый грибок"],
    "актиноморфный": ["полисимметричный"],
    "актировав": ["актировавши"],
    "актировавши": ["актировав"],
    "актирование": ["актировка"],
    "актобе": ["актюбинск"],
    "актовый зал": ["аула"],
    "актор": ["игрок"],
    "актриса": ["артистка", "актёрка"],
    "актриска": ["актрисулька"],
    "актрисулька": ["актриска"],
    "актрыса": ["акцёрка"],
    "актуализация": ["актуализирование"],
    "актуализировав": ["актуализировавши"],
    "актуализировавши": ["актуализировав"],
    "актуализирование": ["актуализация"],
    "актуализировать": ["привлекать", "обновлять"],
    "актуализовав": ["актуализовавши"],
    "актуализовавши": ["актуализовав"],
    "актуально": ["важно", "насущно", "злободневно", "действительно"],
    "актуальность": ["действительность", "современность", "злободневность", "острота", "жизненность", "жгучесть", "насущность", "важность", "резкость", "меткость", "значительность"],
    "актуальный": ["насущный", "важный", "своевременный", "текущий", "свежий", "популярный", "действительный"],
    "актуатор": ["исполнительный механизм"],
    "актёр": ["лицедей", "притворщик", "симулянт"],
    "актёрка": ["актриса"],
    "актёрничав": ["актёрничавши"],
    "актёрничавши": ["актёрничав"],
    "актёрничать": ["актёрствовать", "притворяться"],
    "актёрствовав": ["актёрствовавши"],
    "актёрствовавши": ["актёрствовав"],
    "актёрствовать": ["играть", "притворяться"],
    "акула-аллигатор": ["бляшкошипая акула", "звёздчатошипая акула"],
    "акула-домовой": ["скапаноринх", "митцекурина"],
    "акула-лопата": ["малоголовая молот-рыба", "малая молот-рыба"],
    "акула-людоед": ["кархародон", "белая акула"],
    "акула-молот": ["рыба-молот"],
    "акулий": ["акуловый"],
    "акулина": ["акулька"],
    "акулька": ["акулина"],
    "акуметрия": ["аудиометрия"],
    "акупрессура": ["точечный массаж", "шиацу"],
    "акупунктура": ["иглоукалывание", "иглотерапия", "рефлексотерапия"],
    "акут": ["аксантегю", "знак", "ударение", "острое ударение"],
    "акутовый": ["ударный"],
    "акушерка": ["повитуха"],
    "акушерничав": ["акушерничавши"],
    "акушерничавши": ["акушерничав"],
    "акушерничать": ["акушерствовать"],
    "акушерочка": ["акушерка"],
    "акушерствовав": ["акушерствовавши"],
    "акушерствовавши": ["акушерствовав"],
    "акцентировав": ["акцентировавши"],
    "акцентировавши": ["акцентировав"],
    "акцентировать": ["выделять", "выделить", "подчеркнуть", "подчёркивать", "усилить", "усиливать", "заострить", "заострять"],
    "акцентировка": ["акцентирование"],
    "акцентный стих": ["акцентник"],
    "акцентовав": ["акцентовавши"],
    "акцентовавши": ["акцентовав"],
    "акцентуализировав": ["акцентуализировавши"],
    "акцентуализировавши": ["акцентуализировав"],
    "акцентуировав": ["акцентуировавши"],
    "акцентуировавши": ["акцентуировав"],
    "акцептация": ["принятие"],
    "акцептировав": ["акцептировавши"],
    "акцептировавши": ["акцептировав"],
    "акцептировать": ["акцептовать"],
    "акцептовав": ["акцептовавши"],
    "акцептовавши": ["акцептовав"],
    "акцептовать": ["акцептировать"],
    "акцептор": ["реципиент"],
    "акцизная марка": ["акцизка"],
    "акцизник": ["акцизный"],
    "акциональность": ["действование"],
    "акционер": ["пайщик", "инвестор"],
    "акционерная коммандита": ["коммандита"],
    "акционерная компания": ["ак"],
    "акционерное общество": ["ао"],
    "акционировав": ["акционировавши"],
    "акционировавши": ["акционировав"],
    "акция": ["пай", "доля"],
    "акцёр": ["прытворшчык"],
    "акъл": ["интелект", "разум", "ум"],
    "акътыман": ["очь"],
    "акыллы": ["башлы"],
    "акын": ["певец-акын"],
    "акырырга": ["кычкырырга"],
    "алабай": ["среднеазиатская овчарка", "туркменский волкодав"],
    "алабандин": ["алабандит"],
    "алабута": ["мысай"],
    "алавастр": ["алебастр"],
    "алавит": ["нусайрит"],
    "алавко": ["ала"],
    "алагумни": ["алавумни"],
    "алазани": ["алазань"],
    "алакалуф": ["кауашкар", "кавескар"],
    "алалво": ["алалу"],
    "алама": ["начар", "яман"],
    "аламак": ["альмах"],
    "алан": ["осетин"],
    "аланг-иланг": ["иланг-иланг"],
    "аланг-иланговый": ["иланг-иланговый"],
    "алангъасар": ["аланкасар"],
    "аландские острова": ["аланды"],
    "аланды": ["аландские острова"],
    "алания": ["северная осетия"],
    "аланкасар": ["алангъасар"],
    "аларм": ["смятение", "суматоха", "переполох", "тревога", "крик", "шум"],
    "аларма": ["смятение", "суматоха", "переполох", "тревога", "крик", "шум"],
    "алармизм": ["паникёрство"],
    "алармировав": ["алармировавши"],
    "алармировавши": ["алармировав"],
    "алармировать": ["поднимать тревогу", "поднять тревогу", "тревожить", "потревожить", "беспокоить", "переполошить", "будоражить", "взбудоражить"],
    "алармист": ["паникёр"],
    "алатырь": ["латырь", "алтарь", "всем камням отец", "океан-камень", "окиан-камень", "окиян-камень", "пуп земли"],
    "алацык": ["алачых"],
    "алачак": ["бурыч"],
    "алачых": ["алацык"],
    "албания": ["республика албания"],
    "албано-российский": ["российско-албанский"],
    "алгебраическая система": ["алгебраическая структура"],
    "алгебраический": ["математический"],
    "алгебраичка": ["математичка"],
    "алгебрический": ["алгебраический"],
    "алгия": ["боль"],
    "алгогаллюциноз": ["фантомная боль"],
    "алголь": ["алгол"],
    "алгонквинский": ["алгонкинский"],
    "алгонкинский": ["алгонквинский"],
    "алгоритм": ["инструкция", "способ"],
    "алгоритмизировав": ["алгоритмизировавши"],
    "алгоритмизировавши": ["алгоритмизировав"],
    "алгоритмизовав": ["алгоритмизовавши"],
    "алгоритмизовавши": ["алгоритмизовав"],
    "алгоритмировав": ["алгоритмировавши"],
    "алгоритмировавши": ["алгоритмировав"],
    "алгоритмическая модель": ["алгоритм"],
    "алгорифм": ["алгоритм"],
    "алгофобия": ["альгофобия", "альгинофобия"],
    "алдаларга": ["алдарга"],
    "алдар": ["аьла", "мирза", "тавади"],
    "алдарга": ["алдаларга"],
    "алды": ["ал"],
    "алебардист": ["алебардщик"],
    "алебардник": ["алебардист", "алебардщик"],
    "алебардный": ["алебардовый"],
    "алебардовый": ["алебардный"],
    "алебардщик": ["алебардист"],
    "алебастровый": ["алавастровый"],
    "алевритово-глинистый": ["алевритоглинистый"],
    "алевритоглинистый": ["алевритово-глинистый"],
    "алевши": ["алев"],
    "алегория": ["иносказание", "парабола", "символ", "фигура"],
    "алее": ["алей"],
    "алей": ["алее"],
    "алейка": ["аллейка", "морянка", "саук"],
    "алейкемия": ["лейкемия", "лейкоз", "белокровие"],
    "алейкия": ["агранулоцитоз", "анейтрофилёз", "гранулофтиз"],
    "алейродида": ["белокрылка"],
    "алейчанин": ["алеец"],
    "александр": ["саша"],
    "александра": ["шура", "саша"],
    "александрийка": ["александровка", "александрейка", "касандрейка", "кассандровка", "ксандрейка"],
    "александровск-на-мурмане": ["полярный", "александровск"],
    "александровск-сахалинский": ["александровск"],
    "алексеевна": ["алексевна"],
    "алексей": ["алексий", "алёша", "лёша", "лёха"],
    "алексианин": ["целлит"],
    "алексий": ["алексей"],
    "ален": ["аален"],
    "аленький": ["красненький"],
    "алеппец": ["алеппинец", "халебец"],
    "алеппинец": ["алеппец", "халебец"],
    "алеппо": ["халеб"],
    "алеппский": ["халебский"],
    "алерт": ["воздушная тревога"],
    "алет": ["чеглок элеоноры", "сокол элеоноры"],
    "алеть": ["пунцоветь", "рдеть"],
    "алецитальный": ["олиголецитальный"],
    "алеючи": ["алея"],
    "алея": ["алеючи", "пунцовея", "рдея"],
    "алжир": ["андр"],
    "алиен": ["инопланетянин", "пришелец"],
    "алиенация": ["отчуждение", "отчуждённость"],
    "алиенизм": ["варваризм", "экзотизм", "локализм", "этнографизм"],
    "алиенировать": ["изменить"],
    "алиенист": ["психиатр"],
    "ализарин": ["краплак"],
    "алик": ["алкаш", "алконавт", "выпивоха", "забулдыга", "пропойца", "пьянчуга", "пьянчужка", "пьянь"],
    "аликант": ["аликанте"],
    "аликвотная дробь": ["египетская дробь"],
    "алим": ["галим"],
    "алимпий": ["алипий"],
    "алипий": ["алимпий"],
    "алиссум": ["каменник"],
    "алитировав": ["алитировавши"],
    "алитировавши": ["алитировав"],
    "алитирование": ["алюминирование"],
    "алитус": ["олита"],
    "алифатический": ["ациклический"],
    "алишта": ["облека", "облекло"],
    "алия": ["аля", "алечка"],
    "алкав": ["алкавши"],
    "алкавши": ["алкав"],
    "алкадиен": ["диен"],
    "алкализация": ["подщелачивание"],
    "алкан": ["насыщенный углеводород", "предельный углеводород"],
    "алкание": ["алканье"],
    "алканье": ["алкание"],
    "алкать": ["быть голодным", "голодать", "вожделеть", "жаждать"],
    "алкаш": ["алкоголик", "алик", "алконавт", "пьяница", "пьянчужка"],
    "алкашня": ["алкота"],
    "алкая": ["алча"],
    "алкен": ["олефин"],
    "алкил": ["алкильный радикал"],
    "алкилгалогенид": ["галогеналкан"],
    "алкилировав": ["алкилировавши"],
    "алкилировавши": ["алкилировав"],
    "алкиловая группа": ["алкил", "алкильная группа"],
    "алкильная группа": ["алкил", "алкиловая группа"],
    "алкин": ["ацетиленовый углеводород"],
    "алкион": ["зимородок"],
    "алкоблокиратор": ["алкозамок"],
    "алкоголепотребление": ["винопотребление"],
    "алкоголизировав": ["алкоголизировавши"],
    "алкоголизировавши": ["алкоголизировав"],
    "алкоголизировать": ["споить", "спаивать"],
    "алкоголизм": ["пьянство"],
    "алкоголизовав": ["алкоголизовавши"],
    "алкоголизовавши": ["алкоголизовав"],
    "алкоголиметрия": ["спиртометрия"],
    "алкоголица": ["алкоголичка"],
    "алкоголичка": ["пьяница", "пропойца", "выпивоха", "алкоголица"],
    "алкоголь": ["этиловый спирт", "этанол", "спирт", "спиртной напиток", "вино"],
    "алкогольный": ["спиртовой", "спиртной"],
    "алкогольный абстинентный синдром": ["похмельно-абстинентный синдром"],
    "алкоголят": ["алкоксид"],
    "алкозамок": ["алкоблокиратор"],
    "алкоксид": ["алкоголят"],
    "алкоран": ["коран"],
    "алкота": ["алкашня", "пьянчуга"],
    "алкотестер": ["алкометр"],
    "алкохолизъм": ["пиянство"],
    "алкохолик": ["пияница", "пияч"],
    "аллагь": ["бечед"],
    "аллаиха": ["эликчян"],
    "аллатив": ["аллятив", "адлатив", "адверсив", "вентив", "падеж приближения", "падеж направления", "элатив"],
    "аллах": ["алла"],
    "алле-гоп": ["алле-оп"],
    "аллегоризм": ["аллегоричность"],
    "аллегорический": ["аллегоричный"],
    "аллегорично": ["аллегорически"],
    "аллегоричный": ["аллегорический"],
    "аллегория": ["иносказание"],
    "аллеломорф": ["аллель"],
    "аллеломорфизм": ["аллелизм"],
    "аллель": ["аллеломорф"],
    "аллеманда": ["аллеман"],
    "алленовский": ["вуди-алленовский"],
    "аллергичный": ["аллергенный"],
    "аллес": ["аллес капут"],
    "аллес капут": ["аллес"],
    "аллигаторша": ["крокодилиха"],
    "аллилуйя": ["осанна"],
    "аллилхлорид": ["аллил хлористый"],
    "аллитерировав": ["аллитерировавши"],
    "аллитерировавши": ["аллитерировав"],
    "алло": ["алё", "ало", "алле"],
    "алло-": ["ино-"],
    "аллоантитело": ["изоантитело"],
    "аллогенез": ["алломорфоз"],
    "аллогенный": ["чужеродный", "аллотигенный"],
    "аллокератопластика": ["гомокератопластика"],
    "аллоксан": ["мезоксалиломочевина"],
    "аллолекс": ["аллолекса", "аллолексема"],
    "аллометрия": ["гетерогония"],
    "алломорф": ["алломорфема", "морф", "морфа"],
    "алломорфа": ["алломорфема", "морф", "морфа"],
    "алломорфия": ["алломорфность"],
    "алломорфоз": ["аллогенез"],
    "аллонидан": ["фирефтан"],
    "аллопатия": ["фармакотерапия"],
    "аллоритмия": ["экстрасистолия", "аллоритмический"],
    "аллотетраплоид": ["амфидиплоид"],
    "аллотриоморфность": ["ксеноморфность"],
    "аллотриоморфный": ["ксеноморфный"],
    "аллотриофагия": ["пика", "пикацизм", "парорексия"],
    "аллотропизм": ["аллотропия"],
    "аллотропический": ["аллотропный"],
    "аллотропность": ["аллотропия"],
    "аллофон": ["вариант"],
    "аллофона": ["аллофон", "аллофонема"],
    "аллохтонный": ["переотложенный"],
    "аллоэротизм": ["гетероэротизм"],
    "аллоэтноним": ["экзоэтноним"],
    "аллювиальный": ["наносный"],
    "аллюзивный": ["аллюзионный"],
    "аллюзия": ["отсылка", "намёк"],
    "аллюр": ["побежка", "темп", "скорость"],
    "аллятив": ["латив"],
    "алма-ата": ["алматы"],
    "алма-атинский": ["алматинский"],
    "алмаатинец": ["алматинец"],
    "алмаатинка": ["алматинка"],
    "алмаз": ["адамант", "диамант", "бриллиант", "стеклорез"],
    "алмазец": ["алмазик"],
    "алмалыкец": ["алмалыкчанин"],
    "алман": ["немец"],
    "алмания": ["германия"],
    "алмас": ["бриллиант"],
    "алматинский": ["алма-атинский"],
    "алмаштырырга": ["алыштырырга", "алмашырга"],
    "алмашырга": ["алмаштырырга"],
    "алмэ": ["элмэ"],
    "ало-красный": ["красно-алый"],
    "аловатый": ["красноватый", "алый"],
    "алогический": ["алогичный", "нелогичный"],
    "алогично": ["нелогично"],
    "алогичность": ["нелогичность"],
    "алогичный": ["нелогичный", "иллогичный"],
    "алодея": ["элодея"],
    "алоизыч": ["австрийский художник"],
    "алой": ["алоэ"],
    "аломорфоз": ["алогенез"],
    "алонавт": ["нлонавт"],
    "алопеция": ["атрихия", "атрихоз", "облысение", "пелада", "плешивость"],
    "алоскоп": ["аллоскоп"],
    "алоэ": ["алой", "бессмертник", "сабур"],
    "алпразолам": ["ксанакс", "альпразолам", "золдак"],
    "алсу": ["кызгылт", "красноватый", "кызылсу"],
    "алтаец": ["ойрот"],
    "алтай": ["алтайские горы", "республика алтай", "алтайский край"],
    "алтайский аргали": ["алтайский горный баран", "алтайский баран", "алтайский архар"],
    "алтайский архар": ["алтайский горный баран", "алтайский баран", "алтайский аргали"],
    "алтайский баран": ["алтайский горный баран", "алтайский архар", "алтайский аргали"],
    "алтайский горный баран": ["алтайский архар", "алтайский баран", "алтайский аргали"],
    "алтайский край": ["ак"],
    "алтан": ["балкон"],
    "алтарник": ["алтарщик"],
    "алтарница": ["алтарщица"],
    "алтарь": ["жертвенник", "возвышение", "церковь", "религия"],
    "алтей": ["мальва", "просвирняк", "проскурняк"],
    "алтимат": ["алтимат-фрисби"],
    "алтымыс": ["алтымыш"],
    "алтын": ["алтынник"],
    "алтынник": ["хапуга", "жидомор", "взяточник", "лихоимец", "мздоимец", "мздолюбец", "хапун", "хапала", "алтын"],
    "алтынница": ["копеечница", "гомзиха", "жадюга", "жмотка", "крохоборка", "скаредница", "сквалыжница", "скопидомка", "скряга", "скупердяйка"],
    "алтынничав": ["алтынничавши"],
    "алтынничавши": ["алтынничав"],
    "алтынничать": ["жмотствовать", "скупиться", "скопидомничать", "скряжничать", "скаредничать", "жмотничать", "жмотиться", "жилиться", "скупердяйничать", "сквалыжничать", "крохоборствовать", "жадничать", "крохоборничать", "копеечничать", "скопидомствовать"],
    "алуне": ["макабала"],
    "алфабетизация": ["алфавитизация", "сортировка"],
    "алфавит": ["азбука"],
    "алфавитизация": ["алфабетизация", "сортировка"],
    "алхимист": ["алхимик"],
    "алце пе": ["алце шире"],
    "алце шире": ["алце пе"],
    "алчба": ["алчность", "жадность", "ненасытность", "голод"],
    "алчничав": ["алчничавши"],
    "алчничавши": ["алчничав"],
    "алчно": ["жадно"],
    "алчность": ["жадность", "корыстолюбие", "ненасытность"],
    "алчный": ["жадный", "ненасытный", "стяжательский", "корыстный", "корыстолюбивый"],
    "алый": ["красный", "пунцовый", "рдяный", "ярко-красный"],
    "алым-алёхонек": ["алым-алёшенек"],
    "алым-алёшенек": ["алым-алёхонек"],
    "алырник": ["алырщик"],
    "алыча": ["слива вишнёвоплодная", "слива вишненосная"],
    "алыштырырга": ["алмаштырырга"],
    "алышынырга": ["алмашынырга"],
    "аль денте": ["с сырцом"],
    "аль-кудс": ["иерусалим"],
    "альб": ["альбский ярус"],
    "альбаака": ["базилик"],
    "альбертипия": ["артотипия", "гелиотипия", "коллотипия"],
    "альбигоец": ["катар", "вальденс", "альбанец"],
    "альбин": ["рыбий глаз", "бельш"],
    "альбион": ["англия"],
    "альбит": ["перистерит"],
    "альбитофир": ["кератофир"],
    "альбо": ["или", "либо", "иль", "али", "аль", "алибо"],
    "альбула": ["белая лисица"],
    "альбумин": ["белковина"],
    "альбуминный": ["альбуминовый"],
    "альбуминовый": ["альбуминный"],
    "альбуминоид": ["альбумоид"],
    "альбуминурия": ["протеинурия"],
    "альбуцид": ["сульфацетамид", "сульфаниламид"],
    "альвеола": ["зубной", "лунка", "ацинус"],
    "альвеолоцит": ["альвеоцит", "пневмоцит"],
    "альвеолят": ["альвеолобионт"],
    "альвхейм": ["льюсальвхейм"],
    "альгодисменорея": ["альгоменорея"],
    "альголагния": ["амолагния"],
    "альгология": ["фикология"],
    "альгоменорея": ["альгодисменорея"],
    "альдегидоспирт": ["альдоль"],
    "альдокортин": ["альдостерон", "электрокортин"],
    "альдолаза": ["фруктозобисфосфат-альдолаза"],
    "альдоль": ["альдегидоспирт", "алдол"],
    "альдона": ["алдона"],
    "альдостерон": ["альдокортин", "электрокортин"],
    "альдрин": ["гхдн", "гексахлородиметанонафталин", "альдрекс", "октален", "эрузин", "вератокс", "аглюкон", "картофин", "ггдн"],
    "алькальд": ["мэр"],
    "альковный": ["спальный", "любовный", "эротический"],
    "алькоран": ["коран", "алкоран"],
    "альмак": ["альмах"],
    "альманашник": ["альманачник"],
    "альмах": ["аламак", "альмак"],
    "альмея": ["альма", "алмея"],
    "альмики": ["щелезуб"],
    "альни": ["инда"],
    "альнилам": ["алнилам"],
    "альнитак": ["алнитак"],
    "альпага": ["альпака"],
    "альпака": ["альпага"],
    "альпеншток": ["посох"],
    "альпинарий": ["альпийская горка"],
    "альпинизм": ["горовосхождение"],
    "альпинист": ["горновосходитель", "горовосходитель", "скалолаз"],
    "альпинистка": ["скалолазка"],
    "альсекко": ["асекко"],
    "альсифер": ["алсифер", "сендаст"],
    "альстромерия": ["альстрёмерия", "лилия"],
    "альт": ["альтгорн"],
    "альт-кантри": ["альтернативное кантри"],
    "альтана": ["альтанка"],
    "альтанка": ["альтана"],
    "альтер эго": ["второе я"],
    "альтернатива": ["вариант"],
    "альтернативная медицина": ["нетрадиционная медицина"],
    "альтернативник": ["альтернативщик"],
    "альтернативно": ["иначе", "по-другому"],
    "альтернативный": ["другой", "иной"],
    "альтернативный рок": ["альт-рок"],
    "альтернативщик": ["альтернативник", "альтернативнослужащий"],
    "альтернация": ["чередование"],
    "альтернировав": ["альтернировавши"],
    "альтернировавши": ["альтернировав"],
    "альтернирование": ["кососимметрирование", "антисимметрирование", "альтернация"],
    "альтернировать": ["чередовать"],
    "альтиметр": ["высотомер"],
    "альтруизм": ["забота о ближнем"],
    "альтруистически": ["альтруистично"],
    "альтруистический": ["альтруистичный", "бескорыстный"],
    "альтруистично": ["альтруистически"],
    "альтруистичность": ["альтруизм", "самоотверженность"],
    "альфа-вариант": ["альфа-штамм"],
    "альфа-ветвь": ["альфа-канал", "альфа-ветка"],
    "альфа-галактозидаза": ["мелибиаза"],
    "альфа-излучение": ["альфа-лучи"],
    "альфа-лучи": ["альфа-излучение"],
    "альфа-самец": ["вожак", "альфач"],
    "альфа-частица": ["альфа-луч"],
    "альфа-штамм": ["альфа-вариант"],
    "альфарг": ["сцилла"],
    "альфатер": ["альтфатер"],
    "альфач": ["альфа-самец", "бабник", "женолюб", "ловелас", "волокита"],
    "альфенид": ["нейзильбер", "аргентан"],
    "альферац": ["альферат", "альфер", "сирра", "сиррах", "сирраг", "сира"],
    "альфист": ["альфовец"],
    "альфовец": ["альфист"],
    "альфонс": ["жиголо"],
    "альфреско": ["афреско"],
    "альцгеймер": ["альцхаймер"],
    "альциона": ["алькиона"],
    "альянс": ["союз", "ассоциация", "объединение", "коалиция", "содружество"],
    "алэй": ["алай"],
    "алюминий": ["глиний", "крылатый металл"],
    "алюминировав": ["алюминировавши"],
    "алюминировавши": ["алюминировав"],
    "алюминирование": ["алитирование"],
    "алюминокалиевый": ["алюмокалиевый", "алюминиево-калиевый"],
    "алюминотермия": ["алюмотермия"],
    "алюмоаммонийный": ["алюмоаммониевый"],
    "алюмогидрид": ["аланат"],
    "алюмокалиевый": ["алюминокалиевый", "алюминиево-калиевый"],
    "алюмохромировав": ["алюмохромировавши"],
    "алюмохромировавши": ["алюмохромировав"],
    "алюмохромировать": ["хромоалитировать"],
    "алюмохромовый": ["хромоалюминиевый"],
    "алюмоцинк": ["алюцинк"],
    "алюцинк": ["алюмоцинк"],
    "аля": ["цёраломань"],
    "аля-улю": ["до свидания"],
    "аляпистый": ["аляповатый"],
    "аляповатость": ["безвкусица"],
    "аляповатый": ["грубый", "некрасивый", "топорный", "неизящный", "неуклюжий", "базарный", "грубой", "работы", "грубо", "сделанный", "безвкусно"],
    "аляска": ["парка"],
    "аляскапокс": ["аляскинская оспа"],
    "алё": ["алло", "эй", "ау"],
    "алёна": ["елена"],
    "алёнка": ["алёна"],
    "алёнушка": ["алёночка"],
    "алёхонький": ["краснёхонький"],
    "алёша": ["лёша", "алёшка", "лёшка", "лёха"],
    "алёшка": ["алёша", "лёша", "лёшка"],
    "алёшки": ["цюрупинское", "цюрупинск"],
    "ам": ["ням"],
    "ам-ам": ["ням-ням"],
    "амазонка": ["всадница", "наездница"],
    "амазонская низменность": ["амазония"],
    "амак": ["язна", "домод"],
    "амаликитянин": ["амалик"],
    "амальгамировав": ["амальгамировавши"],
    "амальгамировавши": ["амальгамировав"],
    "амальфиец": ["амальфитанец"],
    "амальфитанец": ["амальфиец"],
    "аманатский": ["аманатный"],
    "аманус": ["алма-даг", "аман"],
    "амапа": ["бразильская гвиана", "португальская гвиана"],
    "амарант": ["щирица", "аксамитник", "бархатник", "бархатка", "петуший гребень", "петушиные гребешки", "кошачий хвост", "лисий хвост", "пурпурное дерево", "фиолетовое дерево"],
    "амарант колосистый": ["щирица запрокинутая"],
    "амарантовые": ["щирицевые"],
    "амарантовый": ["либеральный"],
    "амарсана": ["амурсана"],
    "амат": ["амт", "амамат"],
    "аматол": ["аммотол"],
    "аматор": ["аматёр"],
    "аматузия": ["афродита"],
    "аматус": ["амафонт"],
    "аматьор": ["дилетант", "любител", "новак", "ученик"],
    "аматёрка": ["любительница"],
    "амафонт": ["аматус"],
    "амбазония": ["федеративная республика амбазония", "земля амба", "южный камерун"],
    "амбал": ["амвал", "анбал", "грузчик"],
    "амбар": ["житница", "кладовая", "склад"],
    "амбарец": ["амбарик"],
    "амбаркация": ["погрузка"],
    "амбарная книга": ["гроссбух", "конторская книга"],
    "амбарное": ["амбарщина"],
    "амбарщик": ["кладовщик"],
    "амбарщина": ["амбарное"],
    "амбасада": ["посольство"],
    "амбассадор": ["бренд-амбассадор", "посол бренда", "поборник", "сторонник", "посол"],
    "амбивалентность": ["двойственность"],
    "амбивалентный": ["двойственный", "неоднозначный"],
    "амбиграмма": ["листовертень", "поворотень"],
    "амбидекстрия": ["обоерукость"],
    "амбиполярность": ["двуполярность", "биполярный"],
    "амбиполярный": ["двуполярный", "биполярный"],
    "амбисексуальный": ["двуполый"],
    "амбисинистрия": ["двулеворукость"],
    "амбициозно": ["самолюбиво", "тщеславно", "честолюбиво"],
    "амбициозный": ["честолюбивый", "властолюбивый", "самолюбивый", "высокомерный", "чванный", "надменный", "напыщенный", "тщеславный", "кичливый", "себялюбивый", "спесивый", "чванливый", "гонористый", "притязательный"],
    "амбиционный": ["амбициозный"],
    "амбиция": ["самолюбие", "спесивость", "чванство", "претензия", "притязание"],
    "амблинойя": ["амблиотимия", "амбитимия"],
    "амбра": ["амбергрис", "серый янтарь", "амбре", "благоухание"],
    "амбразура": ["бойница"],
    "амбре": ["аромат", "благовоние", "вонь", "зловоние"],
    "амбреаж": ["съединител", "фрикцион"],
    "амбулакральный": ["амбулякральный"],
    "амбулаторно-курсовой": ["амбулаторно-курсовочный"],
    "амбулаторно-курсовочный": ["амбулаторно-курсовой"],
    "амбурец": ["гамбуржец", "гамбургец"],
    "амбушюр": ["мундштук"],
    "амбьянс": ["антураж", "обстановка", "среда"],
    "амвон": ["возвышение", "помост", "подмостки"],
    "амвросиевка": ["донецко-амвросиевка"],
    "амели": ["амелия", "амелина", "амела", "амель", "амалия", "амаль", "амалье", "амеличка", "амушка", "амочка", "мели"],
    "амелобласт": ["энамелобласт", "адамантобласт"],
    "аменабельность": ["усреднимость"],
    "амер": ["американец", "пиндос"],
    "америка": ["новый свет"],
    "американец": ["америкос", "пиндос", "янки"],
    "американизировав": ["американизировавши"],
    "американизировавши": ["американизировав"],
    "американо-азербайджанский": ["азербайджано-американский"],
    "американо-боннский": ["американо-западногерманский"],
    "американо-западногерманский": ["американо-боннский"],
    "американо-российский": ["российско-американский"],
    "американо-сайгонский": ["американо-южновьетнамский"],
    "американо-южновьетнамский": ["американо-сайгонский"],
    "американоид": ["индеец"],
    "американский": ["американческий", "америкосовский", "пиндосский", "амерский", "амеровский"],
    "американский морской ангел": ["американская скватина"],
    "америкашка": ["американец", "америкос", "пиндос"],
    "америкос": ["америкашка", "пиндос"],
    "америкосовский": ["американский", "пиндосский"],
    "америнд": ["американоид"],
    "амерский": ["пиндосский", "америкосовский"],
    "аметист": ["амефист", "аметистус", "агат пурпурный", "апостольский камень", "архиерейский камень", "вареник", "моховик", "моховой камень"],
    "аметистовый": ["фиолетовый"],
    "амиант": ["асбест"],
    "амигдала": ["миндалина", "миндалевидное тело"],
    "амигдалит": ["мандельштейн", "миндальный камень", "тонзиллит"],
    "амид": ["диярбакыр"],
    "амидировав": ["амидировавши"],
    "амидировавши": ["амидировав"],
    "амидон": ["абидон"],
    "амидопирин": ["пирамидон"],
    "амидофосфат": ["фосфорамидат", "фосфоамидат", "фосфамидат"],
    "амикан": ["хомоты"],
    "амикошонство": ["фамильярность", "запанибратство", "панибратство"],
    "амикошонствовав": ["амикошонствовавши"],
    "амикошонствовавши": ["амикошонствовав"],
    "амикошонствовать": ["панибратствовать", "фамильярничать"],
    "амил": ["пентил"],
    "амилан": ["капрон"],
    "амилен": ["пентен"],
    "амило-": ["амил-"],
    "амилоза": ["растворимый крахмал"],
    "амилоидный": ["крахмаловидный", "крахмалоподобный"],
    "аминазин": ["хлорпромазин"],
    "аминарсон": ["амебарсон", "карбазон", "фенарсон"],
    "аминировав": ["аминировавши"],
    "аминировавши": ["аминировав"],
    "аминоалкоголь": ["аминоспирт"],
    "аминобензол": ["анилин"],
    "аминометан": ["метанамин"],
    "аминоспирт": ["аминоалкоголь"],
    "аминотрансфераза": ["аминофераза"],
    "аминоуксусная кислота": ["глицин", "аминоэтановая кислота"],
    "аминофераза": ["аминотрансфераза"],
    "аминоэтан": ["этиламин"],
    "аминоэтановая кислота": ["аминоуксусная кислота", "глицин"],
    "аминь": ["истинно", "воистину", "подлинно"],
    "амир": ["эмир"],
    "амитал-натрий": ["барбамил"],
    "амитриптилин": ["триптизол"],
    "амиш": ["аманит", "амманит"],
    "амия": ["ильная рыба"],
    "амкаровец": ["амкарец"],
    "аммиакат": ["аммин", "амминокомплекс"],
    "аммиачная селитра": ["нитрат аммония", "аммонийная селитра"],
    "аммин": ["аммиакат"],
    "аммо": ["лекин", "вале", "балки"],
    "аммома": ["салла", "дастор"],
    "аммонизировав": ["аммонизировавши"],
    "аммонизировавши": ["аммонизировав"],
    "аммоний": ["углекислый аммоний"],
    "аммонийфосфат": ["аммофос"],
    "аммонитянин": ["аммонит"],
    "аммонификация": ["гниение"],
    "аммонифицировав": ["аммонифицировавши"],
    "аммонифицировавши": ["аммонифицировав"],
    "аммонов рог": ["аммонит", "гиппокамп", "морской конёк"],
    "аммоноидея": ["аммонит"],
    "аммотол": ["аматол"],
    "аммофила": ["песколюбка"],
    "аммофос": ["аммонийфосфат"],
    "амнезиак": ["амнестик"],
    "амнезировав": ["амнезировавши"],
    "амнезировавши": ["амнезировав"],
    "амнион": ["плодный пузырь"],
    "амниота": ["высшее позвоночное"],
    "амниотический": ["околоплодный"],
    "амниотический мешок": ["околоплодный пузырь"],
    "амнистировав": ["амнистировавши"],
    "амнистировавши": ["амнистировав"],
    "амнистия": ["помилование"],
    "амо": ["куда"],
    "амок": ["паника", "безумие", "бешенство"],
    "амон": ["амон-ра", "ра"],
    "амонгасик": ["амогус"],
    "аморализм": ["аморальность", "аморалия", "имморализм"],
    "аморалист": ["разложенец"],
    "аморалия": ["аморализм", "аморальность", "моральное помешательство"],
    "амораловка": ["аморалка", "аморальщина"],
    "аморально": ["безнравственно", "неэтично"],
    "аморальность": ["безнравственность"],
    "аморальный": ["безнравственный", "неэтичный"],
    "аморей": ["аморит", "сутий"],
    "аморит": ["аморей"],
    "амортизировав": ["амортизировавши"],
    "амортизировавши": ["амортизировав"],
    "аморфа": ["крутик", "безобраза"],
    "аморфизм": ["аморфность", "некристалличность"],
    "аморфно": ["неопределённо", "расплывчато", "размыто"],
    "аморфный": ["расплывчатый", "бесформенный", "неопределённый", "неструктурированный"],
    "амофор": ["омофор", "амафорий"],
    "ампелология": ["витикультура"],
    "ампелотерапия": ["виноградное лечение", "виноградолечение"],
    "ампер-весы": ["токовые весы"],
    "ампер-час": ["кулон"],
    "ампераж": ["сила тока"],
    "ампервольтметр": ["вольтамперметр"],
    "амперсанд": ["знак конъюнкции"],
    "ампир": ["стиль ампир"],
    "амплитуда": ["размах"],
    "амплитудная модуляция": ["ам"],
    "амплитудно-частотный": ["амплитудочастотный"],
    "амплифицировав": ["амплифицировавши"],
    "амплифицировавши": ["амплифицировав"],
    "амплифицировать": ["размножать", "размножить"],
    "амплуа": ["роль", "положение", "позиция"],
    "ампулировав": ["ампулировавши"],
    "ампулировавши": ["ампулировав"],
    "ампулка": ["ампула", "стержень", "стерженёк", "пастик"],
    "ампутация": ["отсечение", "удаление"],
    "ампутировав": ["ампутировавши"],
    "ампутировавши": ["ампутировав"],
    "ампутированный": ["отсечённый", "ампутант"],
    "амс": ["амсу"],
    "амсет": ["имсети", "сети", "мести", "места"],
    "амстафф": ["стаффордшир-терьер"],
    "амстердам": ["амстер"],
    "амсу": ["амс"],
    "амударья": ["окс", "джейхун"],
    "амулет": ["оберег", "талисман", "ладанка", "апотропей"],
    "амуль": ["чарджуй", "чарджоу", "чарджев", "туркменабат", "туркменабад"],
    "амуниция": ["снаряжение", "экипировка"],
    "амуничный": ["амуниционный"],
    "амур": ["эрот", "эрос", "купидон"],
    "амурец": ["амурчанин"],
    "амурив": ["амуривши"],
    "амуривши": ["амурив"],
    "амуриться": ["флиртовать"],
    "амурний": ["любовний"],
    "амурничав": ["амурничавши"],
    "амурничавши": ["амурничав"],
    "амурская область": ["приамурье"],
    "амурчанин": ["амурец"],
    "амурянка": ["амурчанка"],
    "амфетамин": ["бензедрин", "фенамин", "фен", "скорость", "спиды"],
    "амфибия": ["земноводное", "вездеход"],
    "амфиболия": ["анаколуф"],
    "амфидиплоид": ["аллотетраплоид"],
    "амфимакр": ["кретик"],
    "амфимиксис": ["оплодотворение", "сингамия"],
    "амфипод": ["бокоплав"],
    "амфисбена": ["двуходка"],
    "амфитрион": ["хлебосол"],
    "амфифильность": ["дифильность"],
    "амфицельный": ["двояковогнутый"],
    "амфодонт": ["пародонт", "параденциум"],
    "амфодонтоз": ["пародонтоз"],
    "амчанин": ["мчанин", "мценянин", "амченец"],
    "амырга": ["авырга"],
    "амёба": ["ничтожество"],
    "амёбиаз": ["амёбная дизентерия"],
    "амёбоидный": ["амёбовидный", "амёбообразный", "амёбный"],
    "амёбообразный": ["амёбовидный", "амёбоподобный", "неопределённый", "расплывчатый"],
    "амёбоподобный": ["амёбовидный", "амёбообразный"],
    "ан нет": ["вот и нет", "сейчас", "чёрта с два", "не тут-то было", "но нет"],
    "анабазис": ["ежовник"],
    "анабаптизм": ["перекрещенец"],
    "анабаптист": ["перекрещенец"],
    "анабаптистка": ["перекрещенка"],
    "анабас": ["рыба-ползун"],
    "анабиоз": ["криптобиоз", "стазис", "гибернация", "спячка", "диапауза", "заморозка"],
    "анабиозный": ["анабиотический"],
    "анабиотический": ["анабиозный"],
    "анаболизм": ["ассимиляция"],
    "анаболия": ["гиперморфоз"],
    "анаграмматист": ["анаграмщик"],
    "анадиплосис": ["подхват", "эпаналепсис", "анадиплозис"],
    "анадысь": ["надысь", "нагдысь", "ономнясь", "намнясь", "намедни", "на днях"],
    "анаконда": ["водяной удав", "зелёная анаконда", "обыкновенная анаконда", "гигантская анаконда"],
    "анакоэносис": ["аверсия"],
    "анакре": ["гунду"],
    "анакруза": ["анакруса", "затакт"],
    "анакруса": ["анакруза"],
    "анал": ["анальный секс", "содомия"],
    "аналав": ["параман", "параманд"],
    "аналекты": ["хрестоматия", "антология", "избранное", "выписки"],
    "аналив": ["аналивши"],
    "аналивши": ["аналив"],
    "анализ": ["декомпозиция", "разбор"],
    "анализировав": ["анализировавши"],
    "анализировавши": ["анализировав"],
    "анализирование": ["анализ", "разбор"],
    "анализировать": ["изучать", "исследовать", "разбирать", "рассматривать"],
    "анализис": ["анализ"],
    "анализм": ["анальный секс"],
    "аналист": ["аналитик"],
    "аналитизм": ["синтез", "синтетизм"],
    "аналитическая химия": ["химический анализ"],
    "аналитический": ["умозаключительный", "исследовательский", "вдумчивый", "логический", "анализирующий", "голоморфный", "бесконечно", "дифференцируемый"],
    "аналитично": ["аналитически"],
    "аналитичный": ["аналитический"],
    "аналогизировав": ["аналогизировавши"],
    "аналогизировавши": ["аналогизировав"],
    "аналогий": ["аналой", "налой"],
    "аналогировав": ["аналогировавши"],
    "аналогировавши": ["аналогировав"],
    "аналогически": ["аналогично"],
    "аналогично": ["так же", "таким же образом", "похожим образом"],
    "аналогичный": ["сходный", "подобный"],
    "аналогия": ["подобие", "сходство", "уподобление"],
    "аналого-цифровой": ["аналогоцифровой", "цифро-аналоговый"],
    "аналоговый": ["моделирующий"],
    "аналой": ["налой", "аналогий"],
    "анальгезировав": ["анальгезировавши"],
    "анальгезировавши": ["анальгезировав"],
    "анальгезия": ["аналгезия", "аналгия", "обезболивание", "наркоз"],
    "анальгетик": ["болеутоляющее средство"],
    "анальгин": ["метамизол натрия", "метамизол"],
    "анальный": ["ректальный"],
    "анальный секс": ["анализм", "анальный коитус", "анальная пенетрация", "анальное сношение", "заднепроходное сношение", "содомия"],
    "анальцит": ["анальцим"],
    "анальчик": ["анал", "анальный секс"],
    "анамнестический": ["анамнезный"],
    "анамния": ["низшее позвоночное"],
    "анаморфизм": ["гипометаморфизм"],
    "анаморфировав": ["анаморфировавши"],
    "анаморфировавши": ["анаморфировав"],
    "анаморфоз": ["анаморфоза"],
    "ананасний": ["ананасовий"],
    "ананасный": ["ананасовый"],
    "ананасовий": ["ананасний"],
    "ананасовый": ["ананасный"],
    "ананке": ["ананка"],
    "анапест": ["антидактиль"],
    "анаприлин": ["пропранолол"],
    "анапсидный": ["стегальный", "стегокротафический"],
    "анархиствовав": ["анархиствовавши"],
    "анархиствовавши": ["анархиствовав"],
    "анархический": ["анархистский"],
    "анархично": ["анархически"],
    "анархичный": ["анархический", "неорганизованный", "беспорядочный"],
    "анархия": ["либертарианство", "безвластие", "хаос", "беспорядок", "неразбериха"],
    "анархотерроризм": ["анархо-терроризм"],
    "анархоэколог": ["анархо-эколог"],
    "анастасий": ["стася"],
    "анастасия": ["настя", "ася", "стася", "настенька", "настёна", "настик", "настюша", "стасенька", "асенька", "настюха", "настька", "наська"],
    "анастомоз": ["соустье"],
    "анастомозировав": ["анастомозировавши"],
    "анастомозировавши": ["анастомозировав"],
    "анатоксин": ["токсоид"],
    "анатольский": ["малоазиатский"],
    "анатомив": ["анатомивши"],
    "анатомивши": ["анатомив"],
    "анатомик": ["анатом"],
    "анатомировав": ["анатомировавши"],
    "анатомировавши": ["анатомировав"],
    "анатомирование": ["вскрытие", "аутопсия", "некропсия", "секция", "препарирование", "диссекция", "анализ", "разбор", "изучение", "исследование"],
    "анатомировать": ["вскрыть", "вскрывать", "препарировать", "анатомить", "анализировать", "исследовать"],
    "анатомить": ["анатомировать"],
    "анатомическая табакерка": ["лучевая ямка"],
    "анатомка": ["анатомический театр", "анатомичка", "прозекторская"],
    "анатомолокализационизм": ["локализационизм"],
    "анафема": ["отлучение", "негодяй", "негодник"],
    "анафематствовав": ["анафематствовавши"],
    "анафематствовавши": ["анафематствовав"],
    "анафемский": ["отвратительный"],
    "анафемствовав": ["анафемствовавши"],
    "анафемствовавши": ["анафемствовав"],
    "анафемський": ["анахтемський"],
    "анафора": ["единоначатие"],
    "анафоричный": ["анафорический"],
    "анафродизия": ["гиполибидемия"],
    "анахорет": ["затворник", "затворница", "пустынник", "отшельник", "еремит"],
    "анахоретизм": ["самозамуровывание"],
    "анахоретний": ["анахоретський"],
    "анахоретский": ["уединённый", "отшельнический"],
    "анахоретство": ["отшельничество", "затворничество", "одиночество"],
    "анахоретствовав": ["анахоретствовавши"],
    "анахоретствовавши": ["анахоретствовав"],
    "анахоретський": ["анахоретний"],
    "анахронизъм": ["отживялост", "отживелица", "ненавременност"],
    "анахронистический": ["анахронический"],
    "анахроничный": ["анахронический"],
    "анахтема": ["анафема"],
    "анациклус": ["слюногон"],
    "анаша": ["конопля", "гашиш", "марихуана", "балда", "божья травка", "дурдецело", "дурь женатая", "золь", "кенаф", "кеф", "паль", "пахтач", "торч", "турецкий табак", "шмаль"],
    "анаэпифора": ["симплока", "эпанафора"],
    "анаэробионт": ["анаэроб"],
    "анаэробный": ["бескислородный"],
    "анбан": ["унбан", "разбан", "разблокирование"],
    "анбандлинг": ["разукрупнение", "разгруппирование"],
    "анбар": ["амбар"],
    "анбоксинг": ["анпакинг"],
    "анбур": ["абур"],
    "ангажировав": ["ангажировавши"],
    "ангажировавши": ["ангажировав"],
    "ангажированность": ["предвзятость"],
    "ангажированный": ["необъективный", "нанятый"],
    "ангажировка": ["ангажирование"],
    "ангальт-цербст": ["анхальт-цербст"],
    "ангел": ["сефирот", "агнец", "лапушка", "милый", "ласковый"],
    "ангел смерти": ["азраил"],
    "ангелика": ["дудник"],
    "ангелина": ["геля"],
    "ангелицин": ["изопсорален"],
    "ангелов": ["ангельский"],
    "ангелообразный": ["ангеловидный"],
    "ангелъ": ["сефиротъ", "милая", "ласковая"],
    "ангельчик": ["ангелочек"],
    "ангемитонный": ["бесполутоновый"],
    "ангидридный": ["ангидридовый"],
    "ангидридовый": ["ангидридный"],
    "ангидроз": ["анидроз"],
    "ангина": ["тонзиллит"],
    "ангинный": ["ангинозный"],
    "ангинозный": ["ангинный"],
    "ангиогенез": ["сосудообразование", "ангиопоэз", "вазифакция"],
    "ангиоглиома": ["ангиоретикулема"],
    "ангиокардиограмма": ["вазокардиограмма", "кардиоангиограмма", "рентгеновазокардиограмма"],
    "ангиокардиокинография": ["кардиовазокинематография", "киноангиокардиография"],
    "ангиолейомиома": ["ангиомиома"],
    "ангиолейцит": ["лимфангиит", "лимфангит", "лимфангоит"],
    "ангионеврома": ["ангионевромиома", "гломангиома", "гломусангиома"],
    "ангиопатия": ["вазопатия"],
    "ангиопульмонография": ["ангиопневмография"],
    "ангиоретикулема": ["ангиоглиома"],
    "ангиорецептор": ["ангиоцептор"],
    "ангиотензин": ["ангиотонин", "гипертензин"],
    "ангиотонин": ["ангиотензин", "гипертензин"],
    "ангиофиброма": ["ангиома склерозирующая", "гемангиофиброма"],
    "ангиохирургия": ["сосудистая хирургия"],
    "ангиоцептор": ["ангиорецептор"],
    "ангиэктазия": ["ангиоэктазия"],
    "англизировав": ["англизировавши"],
    "англизировавши": ["англизировав"],
    "англизм": ["англицизм"],
    "английская соль": ["магнезия", "горькозём", "горькая соль", "эпсомская соль"],
    "английский": ["аглийский", "аглицкий", "аглинский", "англинский", "англицкий", "английский язык"],
    "английский крем": ["крем англез"],
    "английский цемент": ["цемент кина"],
    "английский язык": ["английский"],
    "англиканец": ["англиканин"],
    "англиканизм": ["англиканство", "англицизм"],
    "англиканин": ["англиканец"],
    "англиканство": ["англиканизм", "англиканское вероисповедание", "англиканское сообщество"],
    "англицизм": ["англизм"],
    "англичанин": ["агличанин"],
    "англичанка": ["агличанка"],
    "англия": ["туманный альбион", "великобритания"],
    "англо-американский": ["британско-американский", "британо-американский"],
    "англо-католический": ["англокатолический"],
    "англо-русский": ["англо-российский", "российско-британский"],
    "англоамериканец": ["англо-американец"],
    "англокатолический": ["англо-католический"],
    "англоман": ["англофил"],
    "англомания": ["англоманство", "англофильство"],
    "англоманствовав": ["англоманствовавши"],
    "англоманствовавши": ["англоманствовав"],
    "англосакский": ["англосаксонский"],
    "англосаксонский": ["древнеанглийский", "древнеанглийский язык"],
    "англосакський": ["англосаксонський"],
    "англофильский": ["англоманский", "проанглийский"],
    "англофильство": ["англомания"],
    "англофильствовав": ["англофильствовавши"],
    "англофильствовавши": ["англофильствовав"],
    "англофобство": ["англофобия"],
    "англофобствовав": ["англофобствовавши"],
    "англофобствовавши": ["англофобствовав"],
    "ангоб": ["побела"],
    "ангола": ["республика ангола"],
    "анголезец": ["анголец"],
    "анголезский": ["ангольский"],
    "анголо-намибийский": ["ангольско-намибийский"],
    "ангольско-намибийский": ["анголо-намибийский"],
    "ангора": ["ангорка"],
    "ангорка": ["ангора"],
    "ангорямс": ["киськорямс", "ватксемс"],
    "ангрусты": ["ангуштри"],
    "ангулярный": ["тенальонный"],
    "ангур": ["инаб"],
    "ангуштар": ["ангуштарин"],
    "ангуштарин": ["ангуштар"],
    "ангх": ["анх", "анк"],
    "анда-санда": ["кейде"],
    "андалузец": ["андалусец", "андалусиец"],
    "андалузия": ["андалусия"],
    "андалузский": ["андалусский", "андалусийский"],
    "андалузький": ["андалуський"],
    "андалусец": ["андалузец", "андалусиец"],
    "андалусийский": ["андалузский", "андалусский"],
    "андалусия": ["андалузия"],
    "андалусский": ["андалузский"],
    "андарз": ["панд"],
    "андеграунд": ["подполье"],
    "андеграундовский": ["андеграундный"],
    "андезито-базальт": ["андезитобазальт"],
    "андезитобазальт": ["андезито-базальт"],
    "андербосс": ["младший босс"],
    "андерграундный": ["андеграундный"],
    "андерсоновский": ["уэс-андерсоновский"],
    "андикитира": ["антикитера"],
    "андон": ["кочхан"],
    "андорра": ["княжество андорра"],
    "андорранец": ["андоррец"],
    "андорранка": ["андоррка"],
    "андорранский": ["андоррский"],
    "андоррец": ["андорранец"],
    "андоррка": ["андорранка"],
    "андоррский": ["андорранский"],
    "андрогинический": ["бисексуальный", "обоеполый"],
    "андрогиния": ["гермафродитизм", "обоеполость"],
    "андрогинность": ["андрогиничность"],
    "андроид": ["робот", "киборг", "дроид"],
    "андроидный": ["абдоминальный", "висцеральный", "кушингоидный"],
    "андроидофон": ["гуглофон"],
    "андрофобия": ["мужененавистничество"],
    "андрюша": ["андрей", "андрюшка", "андрейка"],
    "андхра": ["телугу"],
    "андшпуг": ["аншпуг", "гандшпуг"],
    "андый": ["мондый", "шундый", "тегенди"],
    "андэбусьаа": ["андэмусьаа"],
    "андэмусьаа": ["андэбусьаа"],
    "аневризм": ["аневризма"],
    "аневризма": ["аневризм"],
    "анейтрофилёз": ["агранулоцитоз", "алейкия", "гранулофтиз"],
    "анекдотив": ["анекдотивши"],
    "анекдотивши": ["анекдотив"],
    "анекдотист": ["анекдотчик"],
    "анекдотически": ["анекдотично"],
    "анекдотический": ["смешной", "нелепый", "анекдотичный"],
    "анекдотично": ["анекдотически"],
    "анемичность": ["малокровность", "бледность", "вялость"],
    "анемичный": ["анемический", "малокровный"],
    "анемия": ["малокровие", "немочь", "бессилие"],
    "анемограф": ["анемометр", "ветромер"],
    "анемоклинограф": ["анемоклинометр"],
    "анемоклинометр": ["анемоклинограф"],
    "анемон": ["ветреница", "прострел", "актиния"],
    "анемона": ["ветреница"],
    "анеморумбограф": ["анемограф"],
    "анемостат": ["диффузор"],
    "анемофилия": ["ветроопыление"],
    "анемофильный": ["ветроопыляемый"],
    "анестезин": ["бензокаин"],
    "анестезировав": ["анестезировавши"],
    "анестезировавши": ["анестезировав"],
    "анестезия": ["обезболивание", "наркоз"],
    "анестетик": ["обезболивающее"],
    "анестетический": ["обезболивающий"],
    "анета": ["анетта", "аннета", "аннетта"],
    "анжерец": ["анжеросудженец"],
    "анжеросудженец": ["анжерец"],
    "анжерский": ["анжинский"],
    "анжинский": ["анжерский"],
    "анзерин": ["метилкарнозин"],
    "анзур": ["морской лук"],
    "аниен": ["аньене", "аниене", "анио"],
    "анизогамия": ["гетерогамия"],
    "анизол": ["метоксибензол"],
    "анизометр": ["магнитный анизометр"],
    "анизополиплоидия": ["несбалансированная полиплоидия", "периссоплоидия"],
    "анизотонический": ["ауксотонический"],
    "анизотропический": ["анизотропный"],
    "анизотропия": ["асимметрия", "неоднородность"],
    "анизотропный": ["неоднородный"],
    "аниконический": ["иконоборческий"],
    "анилин": ["фениламин", "аминобензол", "кристалин"],
    "анилингус": ["римминг", "анилинкция", "ани"],
    "анимализм": ["зоолатрия", "анималистика"],
    "анималистика": ["анимализм"],
    "аниматор": ["мультипликатор"],
    "анимационный": ["мультипликационный"],
    "анимация": ["мультипликация", "слайд-шоу", "раскадровка", "анимирование", "оживление", "культурно-массовые мероприятия"],
    "анимашка": ["мульт"],
    "аниме": ["анимеха", "анима"],
    "анимировав": ["анимировавши"],
    "анимировавши": ["анимировав"],
    "анимировано": ["весело", "оживлённо"],
    "анимировать": ["мультиплицировать", "развлекать", "веселить"],
    "анинсталлер": ["деинсталлятор"],
    "анион": ["отрицательный ион"],
    "анионообменник": ["анионнообменник", "анионит"],
    "анисный": ["анисовый"],
    "анисовая": ["анисовая водка", "анисовка"],
    "анк": ["анх", "ангх"],
    "анкета": ["опросник"],
    "анкетировав": ["анкетировавши"],
    "анкетировавши": ["анкетировав"],
    "анконец": ["анконитанин"],
    "анконитанин": ["анконец"],
    "анксиолитик": ["транквилизатор"],
    "анксиолитический": ["противотревожный"],
    "анкус": ["анкас", "анкуша", "стрекало"],
    "анламак": ["анъламах"],
    "анлаут": ["инициаль"],
    "анна": ["аня", "анка", "ася", "нюра", "анюта", "аннушка", "анька", "нюрка"],
    "аннализа": ["анна-лиза"],
    "анналист": ["хронист", "летописец"],
    "анналы": ["хроника", "летопись"],
    "аннамитский": ["аннамский"],
    "аннамский": ["аннамитский"],
    "аннексировав": ["аннексировавши"],
    "аннексировавши": ["аннексировав"],
    "аннексирование": ["аннексия"],
    "аннигилировав": ["аннигилировавши"],
    "аннигилировавши": ["аннигилировав"],
    "аннигилирование": ["аннигиляция"],
    "аннигилировать": ["взаимоуничтожиться", "уничтожить", "уничтожиться"],
    "анноминация": ["парономазия"],
    "аннотация": ["резюме", "абстракт"],
    "аннотировав": ["аннотировавши"],
    "аннотировавши": ["аннотировав"],
    "аннулировав": ["аннулировавши"],
    "аннулировавши": ["аннулировав"],
    "аннулирование": ["отмена", "упразднение"],
    "аннулировать": ["уничтожать", "уничтожить", "отменять", "прекращать", "расторгать", "дезавуировать"],
    "аноа": ["карликовый буйвол"],
    "аноблировав": ["аноблировавши"],
    "аноблировавши": ["аноблировав"],
    "анодировав": ["анодировавши"],
    "анодировавши": ["анодировав"],
    "анодонта": ["беззубка"],
    "аноксемия": ["аноксия"],
    "аноксибиоз": ["анаэробиоз"],
    "аноксия": ["гипоксия", "аноксемия"],
    "аномалия": ["ненормальность"],
    "аномально": ["ненормально"],
    "аномальность": ["аномалия", "ненормальность"],
    "аномальный": ["ненормальный", "необычный", "феноменальный"],
    "аномоцитный": ["ранункулоидный", "беспорядочноклетный"],
    "анона": ["аннона"],
    "анонимец": ["анонимщик"],
    "анонимизировав": ["анонимизировавши"],
    "анонимизировавши": ["анонимизировав"],
    "анонимность": ["безымянность"],
    "анонимные алкоголики": ["аа"],
    "анонимный": ["безымянный", "неизвестный", "неназванный"],
    "анонимщик": ["анонимец", "аноним", "доносчик", "жалобщик"],
    "анонсировав": ["анонсировавши"],
    "анонсировавши": ["анонсировав"],
    "анонсировать": ["анонсить"],
    "анонсный": ["анонсовый"],
    "анонсовый": ["анонсный"],
    "анор": ["нор", "руммон"],
    "анормальность": ["ненормальность"],
    "анормальный": ["аномальный", "ненормальный", "патологический"],
    "анофелес": ["малярийный комар"],
    "анофтальм": ["анофтальмия"],
    "анофтальмия": ["анофтальм"],
    "анпил": ["ванпил"],
    "анпублишив": ["анпублишивши"],
    "анпублишивши": ["анпублишив"],
    "анри": ["генрих", "генри"],
    "ансамблевый": ["ансамбльный"],
    "ансамбль-памятник": ["памятник-ансамбль"],
    "ансамбльный": ["ансамблевый"],
    "ансамбъл": ["единство", "дружност", "целокупност", "група", "трупа"],
    "ансат": ["асат"],
    "ансерин": ["анзерин", "метилкарнозин"],
    "ансырь": ["анцырь"],
    "антабка": ["скобка", "скоба"],
    "антаблемент": ["надстолпие"],
    "антагонизм": ["соперничество", "противостояние", "неприязнь"],
    "антагонизъм": ["противоречие", "непримиримост", "противоположност", "съперничество", "враждебност", "враждуване", "вражда", "омраза", "конфликт", "несъгласие", "борба", "стълкновение", "сблъсък", "двубой"],
    "антагонист": ["супостат"],
    "антагонистический": ["антагонистичный"],
    "антагонистичность": ["непримиримость", "противоположность"],
    "антагонистичный": ["антагонистический"],
    "антанагога": ["паромология", "рекомпенсация"],
    "антанаклаза": ["антанакласис", "антанаклазис"],
    "антанаклазис": ["антанакласис", "антанаклаза"],
    "антанакласис": ["антанаклаза", "антанаклазис"],
    "антананариву": ["тананариве", "тана"],
    "антанта": ["согласие"],
    "антарктический океан": ["южный океан"],
    "антеградный": ["антероградный"],
    "антемис": ["пупавка"],
    "антенна": ["ус", "усик", "сяжка"],
    "антенна-мачта": ["мачта-антенна"],
    "антеннщик": ["грибник"],
    "антероградный": ["антеградный"],
    "антерозоид": ["сперматозоид"],
    "антеролистез": ["антелистез"],
    "антефикс": ["антефикса"],
    "анти-": ["противо-", "контр-", "лже-", "эрзац-", "псевдо-"],
    "антиаварийный": ["противоаварийный"],
    "антиаллергический": ["противоаллергический"],
    "антиамериканец": ["антиамериканист"],
    "антиамериканский": ["антиимпериалистический", "просоветский"],
    "антианглийский": ["антибританский"],
    "антианемический": ["гемоглобиностимулирующий"],
    "антиатом": ["коатом"],
    "антибагдадский": ["антииракский"],
    "антибактериальный": ["противобактериальный"],
    "антибиотикорезистентность": ["антибиотикоустойчивость"],
    "антибиотикорезистентный": ["антибиотикоустойчивый"],
    "антибиотикоустойчивость": ["антибиотикорезистентность"],
    "антибиотикоустойчивый": ["антибиотикорезистентный"],
    "антиблокировочная система": ["абс"],
    "антиблокировочный": ["противоблокировочный"],
    "антибольшевизм": ["антикоммунизм"],
    "антибредтовский олефин": ["або"],
    "антиваксер": ["антивакцинатор", "антивакцинщик", "антипрививочник", "вакцинодиссидент", "вакциноскептик", "вакцинофоб"],
    "антивакцинатор": ["антиваксер", "антивакцинщик", "антипрививочник", "вакцинодиссидент", "вакциноскептик", "вакцинофоб"],
    "антивакцинщик": ["антиваксер", "антивакцинатор", "антипрививочник", "вакцинодиссидент", "вакциноскептик", "вакцинофоб"],
    "антивещество": ["антиматерия", "антитело"],
    "антивибратор": ["гаситель"],
    "антивир": ["антивирус", "антивирусник", "антивирь"],
    "антивирусник": ["антивир", "антивирь"],
    "антивирусный": ["противовирусный"],
    "антивирь": ["антивир", "антивирус", "антивирусник"],
    "антивоенный": ["пацифистский"],
    "антивоспламенитель": ["огнезащитный состав"],
    "антигейский": ["гомофобный"],
    "антигеморрагический": ["противогеморрагический"],
    "антигемофильный глобулин": ["агг"],
    "антигигиенический": ["антигигиеничный"],
    "антигигиеничный": ["антигигиенический"],
    "антигипертензивный": ["гипотензивный"],
    "антиглобализация": ["антиглобализм"],
    "антигомосексуальный": ["гомофобский"],
    "антигормональный": ["противогормональный"],
    "антигравий": ["антигравийка"],
    "антигравийка": ["антигравий"],
    "антигрибковый": ["противогрибковый", "фунгицидный"],
    "антигризутный": ["предохранительный"],
    "антигуманность": ["античеловечность"],
    "антигуманный": ["безжалостный"],
    "антидактиль": ["ямбобой"],
    "антидатировав": ["антидатировавши"],
    "антидатировавши": ["антидатировав"],
    "антидейтрон": ["антидейтон"],
    "антидемократически": ["антидемократично"],
    "антидемократично": ["антидемократически"],
    "антидемократичный": ["антидемократический"],
    "антидепрессант": ["тимолептик", "тимоаналептик"],
    "антидетонационный": ["противодетонационный"],
    "антидиалектически": ["антидиалектично"],
    "антидиалектичный": ["антидиалектический"],
    "антидипломатический": ["недипломатический", "недипломатичный"],
    "антидостижение": ["антирекорд"],
    "антидот": ["противоядие"],
    "антидронный": ["антидроновый", "противодронный", "противодроновый"],
    "антидроновый": ["антидронный", "противодронный", "противодроновый"],
    "антиельцинец": ["антиельцинист"],
    "антиельцинист": ["антиельцинец"],
    "антизаконный": ["незаконный", "противозаконный", "беззаконный", "неправомерный", "противоправный", "бессудный"],
    "антизатратный": ["противозатратный"],
    "антииммигрантский": ["антииммиграционный"],
    "антииммиграционный": ["антииммигрантский"],
    "антиинфекционный": ["противоинфекционный", "противозаразный"],
    "антииракский": ["антибагдадский"],
    "антиисторизм": ["антиисторичность"],
    "антиисторичность": ["антиисторизм"],
    "антик": ["древность", "памятник", "скульптура", "слепок", "редкость", "раритет", "старина"],
    "антикамера": ["аванзал"],
    "антикатод": ["анод"],
    "антикафе": ["тайм-кафе"],
    "антиквар": ["антикварий", "старинщик"],
    "антикварщик": ["антиквар", "антикварий"],
    "антикитера": ["андикитира"],
    "антиклерикальный": ["антицерковный"],
    "антиклимакс": ["нисходящая градация"],
    "антиклиналь": ["антиклинальная складка"],
    "антикоагулянтный": ["противосвёртывающий"],
    "антиковидник": ["ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "антиковидный": ["антикоронавирусный", "противоковидный", "противокоронавирусный"],
    "антикоммунист": ["антимарксист"],
    "антиконгестант": ["деконгестант"],
    "антиконституционно": ["противоконституционно"],
    "антиконституционный": ["неконституционный"],
    "антикоронавирусный": ["антиковидный", "противоковидный", "противокоронавирусный"],
    "антикоррозийный": ["антикоррозионный", "противокоррозийный", "противокоррозионный"],
    "антикоррозионный": ["антикоррозийный", "противокоррозийный", "противокоррозионный"],
    "антилидер": ["антирекордсмен"],
    "антилогичный": ["алогичный", "нелогичный"],
    "антилопа-дукер": ["кустарниковый дукер", "обыкновенный дукер"],
    "антилопа-козлик": ["карликовая антилопа", "антилопа-карлик"],
    "антильские острова": ["антилы"],
    "антимагнетизм": ["ненамагничиваемость"],
    "антимагнитный": ["противомагнитный"],
    "антимагнитский закон": ["закон димы яковлева"],
    "антимайдановский": ["антимайданный"],
    "антималярийный": ["малярийный"],
    "антимаскер": ["антимасочник", "безмасочник"],
    "антимасочник": ["антимаскер", "безмасочник"],
    "антимерия": ["металлага"],
    "антиметабола": ["антиметалепса", "антиметатеза"],
    "антиметалепсис": ["антиметалепса"],
    "антиметатеза": ["антиметабола"],
    "антимикробный": ["противомикробный"],
    "антимондиализм": ["мондиализм"],
    "антимониальный": ["сурьмяный"],
    "антимоний": ["сурьма"],
    "антимония": ["трёп", "болтовня"],
    "антимонополизировав": ["антимонополизировавши"],
    "антимонополизировавши": ["антимонополизировав"],
    "антимонопольный": ["антитрестовский"],
    "антиморальный": ["аморальный", "безнравственный"],
    "антимузыка": ["немузыка", "псевдомузыка"],
    "антинаграда": ["антипремия", "антиприз"],
    "антинаука": ["лженаука", "антисциентизм"],
    "антинаучно": ["ненаучно"],
    "антинаучный": ["ненаучный", "лженаучный"],
    "антиникотинный": ["антиникотиновый"],
    "антиномизм": ["антиномианизм", "анантиизм"],
    "антиномический": ["антиномичный"],
    "антиноцицептивный": ["противоболевой"],
    "антиобщественно": ["противообщественно"],
    "антиокислительный": ["противоокислительный"],
    "антиоксидант": ["антиокислитель", "консервант"],
    "антиосманский": ["антитурецкий"],
    "антиотождествление": ["антитождество"],
    "антипаразитарный": ["противопаразитарный"],
    "антипараллелограмм": ["контрпараллелограмм", "параллелограмм"],
    "антипартизанский": ["противопартизанский"],
    "антипасха": ["неделя", "святой", "фома", "воскресенье", "красный", "горка"],
    "антипат": ["проконсул"],
    "антипатария": ["чёрные кораллы"],
    "антипатия": ["неприязнь", "отвращение"],
    "антипатриотизм": ["антипатриотичность"],
    "антипатриотически": ["антипатриотично"],
    "антипатриотический": ["антипатриотичный"],
    "антипатриотично": ["антипатриотически"],
    "антипатриотичность": ["антипатриотизм"],
    "антипатриотичный": ["антипатриотический"],
    "антипедагогически": ["антипедагогично"],
    "антипедагогический": ["антипедагогичный"],
    "антипедагогично": ["антипедагогически", "непедагогично"],
    "антипедагогичный": ["антипедагогический", "непедагогичный"],
    "антипенный": ["противопенный"],
    "антипереполнение": ["исчезновение порядка"],
    "антиперестроечник": ["антиперестройщик"],
    "антиперестроечный": ["контрперестроечный"],
    "антиперестройщик": ["антиперестроечник"],
    "антиперспирант": ["антитранспирант"],
    "антипирин": ["феназон", "анальгезин", "антипирен"],
    "антипович": ["антипыч"],
    "антипоносный": ["противопоносный"],
    "антипотребительство": ["антиконсьюмеризм"],
    "антиправо": ["произвол"],
    "антипремия": ["антинаграда"],
    "антипрививочник": ["антиваксер", "антивакцинатор", "антивакцинщик", "вакцинодиссидент", "вакциноскептик", "вакцинофоб"],
    "антипрививочный": ["противопрививочный"],
    "антиприз": ["антинаграда", "антипремия"],
    "антипрозопопея": ["анимистическая метафора"],
    "антипростудный": ["противопростудный"],
    "антипсихотик": ["нейролептик"],
    "антипхеньянский": ["антисеверокорейский"],
    "антиракета": ["противоракета"],
    "антиракетный": ["противоракетный"],
    "антиреалистический": ["антиреалистичный"],
    "антиреалистичный": ["антиреалистический"],
    "антирейтинг": ["антитоп"],
    "антирекорд": ["антидостижение"],
    "антирекордсмен": ["антилидер"],
    "антиретровирусный": ["противоретровирусный"],
    "антирост": ["дерост"],
    "антирринум": ["львиный зев"],
    "антирусизм": ["русофобия"],
    "антисамосопряжённый": ["антиэрмитов"],
    "антисандинист": ["контрас"],
    "антисанитарный": ["нездоровый", "негигиеничный", "негигиенический", "антигигиенический"],
    "антисанкция": ["контрсанкция"],
    "антисеверокорейский": ["антипхеньянский"],
    "антисейсмический": ["сейсмостойкий"],
    "антиселевой": ["антиселевый", "противоселевой", "противоселевый"],
    "антиселевый": ["антиселевой", "противоселевой", "противоселевый"],
    "антисемит": ["юдофоб", "жидоед"],
    "антисемитизм": ["юдофобство"],
    "антисемитический": ["антисемитский"],
    "антисемитствовав": ["антисемитствовавши"],
    "антисемитствовавши": ["антисемитствовав"],
    "антисептик": ["бактерицид", "фунгицид"],
    "антисептировав": ["антисептировавши"],
    "антисептировавши": ["антисептировав"],
    "антисептический": ["обеззараживающий", "дезинфицирующий", "антисептирующий"],
    "антисимметризация": ["альтернирование"],
    "антисимметрирование": ["альтернирование", "кососимметрирование", "альтернация"],
    "антисимметрический": ["антисимметричный"],
    "антисимметрический тензор": ["антитензор"],
    "антисимметричность": ["антисимметрия"],
    "антисимметричный": ["антисимметрический"],
    "антисоветан": ["антисоветски"],
    "антисоветчик": ["антисоветист"],
    "антисовпадение": ["противосовпадение"],
    "антиспазматический": ["противоспазматический"],
    "антиспам": ["антиспамер"],
    "антиспамер": ["антиспам"],
    "антиспамовый": ["антиспамерский", "антиспамный"],
    "антиспидовский": ["антиспидовый"],
    "антиспидовый": ["антиспидовский"],
    "антиспутниковый": ["противоспутниковый"],
    "антистеплер": ["расшиватель", "дестеплер"],
    "антистимул": ["контрстимул"],
    "антитанковый": ["противотанковый"],
    "антитезис": ["антитеза"],
    "антителогенез": ["антителообразование"],
    "антитероризъм": ["контратероризъм"],
    "антитерроризм": ["контртерроризм"],
    "антитеррористическая операция": ["ато"],
    "антитетический": ["противоположный", "полярный", "контрастный", "дихотомичный"],
    "антитетичный": ["антитетический"],
    "антитиреоидный": ["тиреостатический"],
    "антитождество": ["антиотождествление"],
    "антитоксический": ["антитоксичный"],
    "антитоксичный": ["антитоксический"],
    "антитонный": ["антиупорядоченный"],
    "антитоп": ["антирейтинг"],
    "антитранспирант": ["антиперспирант"],
    "антитринитарианский": ["антитринитарный"],
    "антитуберкулёзный": ["противотуберкулёзный"],
    "антитурецкий": ["антиосманский"],
    "антиугонный": ["противоугонный"],
    "антиутопично": ["антиутопически"],
    "антиутопичный": ["антиутопический"],
    "антиутопия": ["дистопия"],
    "антифаза": ["противофаза"],
    "антифанат": ["хейтер"],
    "антифат": ["антипатей"],
    "антифашист": ["антифа"],
    "антифебрин": ["ацетанилид"],
    "антифлюс": ["оксинон"],
    "антифолк": ["анфолк"],
    "антифон": ["противогласник"],
    "антифраз": ["антифразис"],
    "антифразис": ["антифраз"],
    "антифургаловский": ["антифургальский"],
    "антифургальский": ["антифургаловский"],
    "антихаризматический": ["антихаризматичный"],
    "антихаризматичный": ["антихаризматический"],
    "антихолинергический": ["холинолитический"],
    "антихрист": ["обманщик", "льстец", "князь этого мира"],
    "антихриста втереть": ["задвинуть сатану", "засадить сатану"],
    "антицеллюлитный": ["противоцеллюлитный"],
    "антицерковный": ["антиклерикальный"],
    "антициклонический": ["антициклональный", "антициклонный"],
    "антициклонный": ["антициклональный"],
    "антицинготный": ["противоцинготный"],
    "антиципировав": ["антиципировавши"],
    "антиципировавши": ["антиципировав"],
    "античеловеческий": ["античеловечный", "антигуманный"],
    "античеловечность": ["антигуманность"],
    "античеловечный": ["античеловеческий", "антигуманный"],
    "античный": ["стародавний"],
    "антишумовой": ["противошумовой"],
    "антиэлектрон": ["позитрон"],
    "антиэстетичность": ["некрасивость", "негармоничность"],
    "антиэстетичный": ["антиэстетический"],
    "антиядерный": ["антиатомный"],
    "антология": ["сборник", "хрестоматия"],
    "антоним": ["противоположность"],
    "антонимически": ["антонимично"],
    "антонимический": ["антонимичный"],
    "антонимично": ["антонимически"],
    "антонимичный": ["антонимический"],
    "антонов огонь": ["гангрена", "заражение крови"],
    "антонович": ["антоныч"],
    "антоновские яблоки": ["антоновка"],
    "антономасия": ["антономазия", "прономинация"],
    "антоха": ["антон"],
    "антохлор": ["ксантеин"],
    "антракозавр": ["эмболомер"],
    "антракт": ["перерыв", "промежуток", "пауза", "передышка"],
    "антрацен": ["трицен", "паранафталин"],
    "антрацитный": ["антрацитовый"],
    "антрацитовый": ["антрацитный"],
    "антре": ["клоунада", "интермедия", "вестибюль", "парадное", "подъезд"],
    "антрепренёр": ["предприниматель"],
    "антрепренёрствовав": ["антрепренёрствовавши"],
    "антрепренёрствовавши": ["антрепренёрствовав"],
    "антресоль": ["этаж", "балкон", "полка"],
    "антрит": ["отоантрит"],
    "антропоген": ["четвертичный период", "антропогеновый период", "антропогеновая система"],
    "антропогенний": ["антропогеновий"],
    "антропогеновый": ["четвертичный"],
    "антропография": ["антропология"],
    "антроподезоксихолевая кислота": ["хенодезоксихолевая кислота"],
    "антропозооноз": ["зооантропоноз"],
    "антропологическая лингвистика": ["антрополингвистика"],
    "антропоморф": ["антропоид"],
    "антропоморфизация": ["очеловечивание", "антропоморфизм"],
    "антропоморфизм": ["олицетворение", "персонификация"],
    "антропоморфит": ["авдиянин", "авдианин"],
    "антропоморфический": ["антропоморфный"],
    "антропоморфный": ["антропоморфический", "человекообразный", "человекоподобный"],
    "антропоним": ["имя собственное", "имя"],
    "антропонимия": ["антропонимикон"],
    "антропософия": ["духоведение"],
    "антропосоциология": ["расово-антропологическая школа"],
    "антропофаг": ["людоед", "каннибал"],
    "антропофагия": ["людоедство", "каннибализм"],
    "антропоцентрический": ["антропоцентричный"],
    "антураж": ["обстановка", "окружение", "контекст", "среда"],
    "антырэчыва": ["антыматэрыя"],
    "антэдьаабоой": ["элмэ", "алмэ"],
    "ану": ["ан"],
    "ану ж": ["а можа"],
    "анубис": ["догеровский павиан", "павиан анубис"],
    "анукет": ["анукис"],
    "анукис": ["анукет"],
    "анфедон": ["агриппиада"],
    "анфельтия": ["анфельция"],
    "анфельция": ["анфельтия"],
    "анфилада": ["череда"],
    "анфологий": ["анфологион", "трефологий", "трефологион", "цветослов", "цветная минея", "праздничная минея"],
    "анфологион": ["анфологий", "трефологий", "трефологион", "цветослов", "цветная минея", "праздничная минея"],
    "анфракс": ["карбункул"],
    "анх": ["анк", "ангх"],
    "анхиз": ["анхис"],
    "анхинга": ["змеешейка"],
    "анхис": ["анхиз"],
    "анхуза": ["воловик"],
    "анхур": ["онурис"],
    "анчах": ["анчэх"],
    "анчоусний": ["анчоусовий"],
    "анчоусный": ["анчоусовый"],
    "анчоусовий": ["анчоусний"],
    "анчоусовый": ["анчоусный"],
    "анчутка": ["чертяка", "беспятый"],
    "анчэх": ["анчах"],
    "аншеф": ["главный", "верховный", "во главе", "главно-"],
    "аншлаг": ["солд-аут", "фурор", "объявление"],
    "аншпуг": ["вага", "гандшпуг"],
    "аньдунец": ["даньдунец"],
    "аньцек вага": ["вага аньцек", "аньцек тяни"],
    "аньцек тяни": ["аньцек вага", "вага аньцек"],
    "аньюм": ["айнгум"],
    "анюта": ["анна", "аня", "нюра", "нюта"],
    "анютины глазки": ["трёхцветка", "полуцвет", "золотуха"],
    "аня": ["анна", "анечка"],
    "ао": ["акционерное общество"],
    "аозт": ["зао"],
    "аомынь": ["макао"],
    "аортальный": ["аортный", "аортовый"],
    "аортовый": ["аортный", "аортальный"],
    "аортоподвздошный": ["аорто-подвздошный"],
    "ап": ["апэшечка"],
    "апав": ["апавши"],
    "апавши": ["апав"],
    "апарт": ["реплика в сторону"],
    "апарт-отель": ["апартамент-отель"],
    "апартамент": ["квартира"],
    "апартеид": ["апартхейд", "сегрегация"],
    "апартхейд": ["апартеид"],
    "апасля": ["пасля"],
    "апатани": ["тании", "нисю", "ни"],
    "апатитец": ["апатитовец"],
    "апатически": ["апатично"],
    "апатический": ["вялый", "равнодушный"],
    "апатичность": ["апатия"],
    "апатичный": ["вялый", "равнодушный"],
    "апатия": ["безразличие", "равнодушие", "скука", "отупение", "отрешённость", "бесстрастность", "лень"],
    "апатозавр": ["бронтозавр"],
    "апатрид": ["аполид", "космополит"],
    "апатридизм": ["аполидизм", "безгражданство"],
    "апать": ["поднимать", "повышать"],
    "апашка": ["бабушка", "старушка", "старуха", "холашка"],
    "апгрейд": ["модернизация", "обновление"],
    "апгрейдив": ["апгрейдивши"],
    "апгрейдивши": ["апгрейдив"],
    "апгрейднув": ["апгрейднувши"],
    "апгрейднувши": ["апгрейднув"],
    "апдейт": ["обновление", "обнова"],
    "апдейтив": ["апдейтивши"],
    "апдейтивши": ["апдейтив"],
    "апеллировав": ["апеллировавши"],
    "апеллировавши": ["апеллировав"],
    "апеллирование": ["воззвание", "апелляция"],
    "апеллировать": ["обжаловать", "взывать", "обращаться"],
    "апеллянт": ["апеллятор"],
    "апеллятив": ["имя нарицательное", "обращение"],
    "апеллятивация": ["деонимизация"],
    "апеллятивизация": ["эпонимизация"],
    "апеллятор": ["апеллянт"],
    "апелляция": ["обжалование"],
    "апельсин": ["померанец"],
    "апельсин-королёк": ["кровавый апельсин"],
    "апельсинный": ["апельсиновый"],
    "апельсиновый сок": ["оранж"],
    "апендицит": ["апендисит"],
    "апериодический": ["апериодичный"],
    "апериодичный": ["апериодический"],
    "апешечка": ["апэшечка", "ап"],
    "апикомплекс": ["споровик"],
    "апис": ["хапис"],
    "апицит": ["петрозит"],
    "апкаллу": ["абгаль", "апкалл"],
    "апл": ["атомная подводная лодка", "английская премьер-лига"],
    "аплазия": ["агенезия"],
    "апликата": ["аппликата"],
    "аплодировав": ["аплодировавши"],
    "аплодировавши": ["аплодировав"],
    "аплодировать": ["рукоплескать", "хлопать", "бить в ладони", "бить в ладоши"],
    "аплодисменти": ["оплески"],
    "аплодисменты": ["рукоплескания"],
    "аплодувати": ["оплескувати"],
    "апломб": ["гонор"],
    "апноэ": ["задержка дыхания"],
    "апнув": ["апнувши"],
    "апнувши": ["апнув"],
    "апнуть": ["повысить", "улучшить", "продвинуть", "поднять"],
    "апогаметия": ["апогамия"],
    "апогей": ["венец", "верх", "вершина", "высший", "ступень", "точка", "кульминация", "пик", "апофеоз", "зенит", "максимум"],
    "аподиктический": ["веский", "убедительный", "неоспоримый"],
    "аподиктичный": ["аподиктический"],
    "апозиопеза": ["апозиопезис"],
    "апозиопезис": ["апозиопеза"],
    "апокалипсец": ["капец"],
    "апокалипсис": ["откровение иоанна богослова", "конец света"],
    "апокалипсический": ["апокалипсный", "апокалиптический"],
    "апокалиптический": ["апокалипсический", "апокалипсный"],
    "апокалиптичный": ["апокалиптический"],
    "апокопа": ["усечение"],
    "апокопировав": ["апокопировавши"],
    "апокопировавши": ["апокопировав"],
    "апокринный": ["апокриновый"],
    "апокриновый": ["апокринный"],
    "апокрифический": ["неканонический", "легендарный", "мифический", "недостоверный", "неофициальный"],
    "апокрифичность": ["недостоверность"],
    "апокрифичный": ["сомнительный", "вымышленный", "недостоверный", "подложный", "фальшивый", "поддельный"],
    "аполид": ["апатрид"],
    "аполитизм": ["аполитичность", "аполитицизм"],
    "аполитичность": ["аполитизм"],
    "аполлинарианство": ["аполлинаризм"],
    "аполлинаризм": ["аполлинарианство"],
    "аполлинополь": ["эдфу"],
    "аполлония": ["аполлиния"],
    "апологетика": ["основное богословие"],
    "апологировав": ["апологировавши"],
    "апологировавши": ["апологировав"],
    "апологировать": ["защищать"],
    "апология": ["оправдание", "оправдывание"],
    "апомиктический": ["апомиктичный"],
    "апомиктичный": ["апомиктический"],
    "апоп": ["апофис"],
    "апоплексический удар": ["инсульт", "апоплексия"],
    "апоплексия": ["удар", "инсульт", "пострел", "кондрашка"],
    "апортировав": ["апортировавши"],
    "апортировавши": ["апортировав"],
    "апосиопеза": ["апозиопеза", "апозиопезис"],
    "апостасия": ["вероотступничество"],
    "апостат": ["вероотступник", "предатель", "отщепенец"],
    "апостериори": ["эмпирически"],
    "апостериорно": ["апостериори"],
    "апостериорный": ["эмпирический", "последующий"],
    "апостильб": ["асб"],
    "апостол": ["последователь", "приверженец", "адепт"],
    "апостолический": ["апостольский"],
    "апостольские братья": ["апостолики"],
    "апостольствовав": ["апостольствовавши"],
    "апостольствовавши": ["апостольствовав"],
    "апострофа": ["метобаз", "метабазис"],
    "апострофировав": ["апострофировавши"],
    "апострофировавши": ["апострофировав"],
    "апотрахеальный": ["паратрахеальный"],
    "апотропей": ["амулет", "ладанка", "оберег", "талисман"],
    "апофазис": ["апофазия", "паралепсис"],
    "апофазия": ["апофазис", "паралепсис"],
    "апофегма": ["афоризм", "апофтегма"],
    "апофеоз": ["обожествление", "деификация", "апофеоза", "кульминация", "вершина", "апогей", "прославление", "восхваление", "славословие", "хвала", "слава", "триумф"],
    "апофермент": ["апоэнзим"],
    "апофиза": ["отросток"],
    "апофиллит": ["рыбий глаз"],
    "апофония": ["аблаут", "чередование"],
    "апофтегма": ["апофегма", "афоризм"],
    "апоцентр": ["апоапсис"],
    "апоэнзим": ["апофермент"],
    "апп": ["прилка", "приложуха"],
    "аппарат": ["механизм", "машина", "структура"],
    "аппаратно-программный": ["программно-аппаратный"],
    "аппаратное обеспечение": ["железо", "хард"],
    "аппаратный": ["приборный", "организационный"],
    "аппаратура": ["оборудование"],
    "аппаратчик": ["функционер"],
    "аппарель": ["рампа", "пандус"],
    "аппеллясьон": ["апелласьон"],
    "аппендикс": ["аппендицит", "шланг", "сосок"],
    "апперцептивный": ["апперцепционный"],
    "апперцепционный": ["апперцептивный"],
    "апперцепция": ["аперцепция"],
    "апперципировав": ["апперципировавши"],
    "апперципировавши": ["апперципировав"],
    "аппетайзер": ["закуска"],
    "аппетит": ["голод"],
    "аппликата": ["апликата"],
    "аппликатура": ["пальцовка"],
    "апплицировав": ["апплицировавши"],
    "апплицировавши": ["апплицировав"],
    "апплодисмент": ["рукоплескание", "апплодирование"],
    "апподжиатура": ["апподжатура", "аподжиатура", "аподжатура"],
    "аппозитивный": ["аппозиционный"],
    "аппозиционный": ["аппозитивный"],
    "аппойнтмент": ["встреча", "свидание", "договорённость", "запись"],
    "аппретировав": ["аппретировавши"],
    "аппретировавши": ["аппретировав"],
    "аппроксимация": ["приближение", "фит", "фитирование"],
    "аппроксимировав": ["аппроксимировавши"],
    "аппроксимировавши": ["аппроксимировав"],
    "аппроксимирование": ["аппроксимация", "приближение"],
    "аппроксимировать": ["фитировать"],
    "апрача": ["апроч"],
    "апрель": ["кветень", "цветень"],
    "априкос": ["абрикос", "дерево", "абрикоз"],
    "априорно": ["априори", "заранее", "предварительно"],
    "априорный": ["изначальный"],
    "апробировав": ["апробировавши"],
    "апробировавши": ["апробировав"],
    "апробирование": ["апробация"],
    "апробировать": ["одобрять", "одобрить"],
    "апроксимировав": ["апроксимировавши"],
    "апроксимировавши": ["апроксимировав"],
    "апропо": ["кстати", "между прочим", "по поводу", "относительно", "насчет", "касательно"],
    "апроприировать": ["приспособлять", "адаптировать"],
    "апрофондировать": ["вдаваться", "углубляться"],
    "апроч": ["апрача"],
    "апрув": ["аппрув"],
    "апрувив": ["апрувивши"],
    "апрувивши": ["апрувив"],
    "апс": ["апсана"],
    "апсана": ["апс"],
    "апсвинг": ["апстрик"],
    "апси": ["апщи"],
    "апсида": ["абсида"],
    "апсилы": ["абсил"],
    "апскейлив": ["апскейливши"],
    "апскейливши": ["апскейлив"],
    "апскертинг": ["апскёртинг"],
    "апстрик": ["апсвинг"],
    "апта": ["жума"],
    "аптекарь": ["фармацевт", "провизор"],
    "аптечница": ["аптекарша"],
    "апхерца": ["апхьарца", "апхярца"],
    "апчхи": ["апчи", "чхи", "пчхи", "апчхуй"],
    "апчхуй": ["апчхи"],
    "апшерон": ["апшеронский", "ярус"],
    "апэшечка": ["апешечка", "ап"],
    "ар": ["сотка"],
    "ар нуво": ["югендстиль", "либерти", "модерн"],
    "ар-нуво": ["модерн"],
    "ара": ["арара", "макао"],
    "араб": ["арап", "мурин", "мавр", "сарацин", "агарянин"],
    "арабеск": ["арабеска", "спираль"],
    "арабесковый": ["арабесочный"],
    "арабесочный": ["арабесковый"],
    "арабиан": ["одногорбый верблюд", "дромадер", "дромедар"],
    "арабидопсис": ["резуховидка"],
    "арабизация": ["арабизирование"],
    "арабизировав": ["арабизировавши"],
    "арабизировавши": ["арабизировав"],
    "арабографичный": ["арабографический"],
    "арабская вязь": ["арабское письмо", "каракули"],
    "арабская республика египет": ["египет", "аре"],
    "арабские цифры": ["индийские цифры", "индо-арабские цифры"],
    "арабские эмираты": ["эмираты", "оаэ"],
    "арабский восток": ["арабский мир", "страны магриба"],
    "арав": ["арван"],
    "аравийский полуостров": ["аравия"],
    "аравитянка": ["арабка"],
    "арагац": ["алагёз"],
    "арагви": ["арагва"],
    "арагон": ["королевство арагон"],
    "арад": ["агай"],
    "араз": ["аракс"],
    "араканец": ["ракхайнец"],
    "аракс": ["арос", "арас", "араз", "ерасх"],
    "араксинский": ["араксский"],
    "араксский": ["араксинский"],
    "арал": ["аралкум", "аральское озеро", "аральское море"],
    "аралашырга": ["катнашырга"],
    "аральское море": ["аралкум", "аральское озеро"],
    "арам": ["ара"],
    "арама": ["пастушковый журавль"],
    "арамеец": ["арамей"],
    "арамей": ["арамеец"],
    "арамейский язык": ["арамейский"],
    "арамид": ["ароматический полиамид"],
    "арамин": ["метараминол"],
    "арамс": ["эвондамс", "появамс", "араламс", "савомс", "эряви"],
    "арангас": ["сайба"],
    "аранжировав": ["аранжировавши"],
    "аранжировавши": ["аранжировав"],
    "аранжировать": ["перекладывать", "переложить", "адаптировать", "импровизировать", "оформлять", "оформить"],
    "арап": ["негр"],
    "арапа заправлять": ["лгать", "врать", "выдумывать", "обманывать", "баснословить", "сочинять", "привирать", "подвирать", "вкручивать", "заливать", "плесть", "брехать", "талалаять", "заправлять арапа", "врать напропалую"],
    "арапайма": ["пираруку"],
    "арапах": ["арапахо"],
    "арапахо": ["арапах"],
    "араписто": ["нахраписто"],
    "арапка": ["негритянка"],
    "арапник": ["арапленик"],
    "арара": ["ара"],
    "арауканский язык": ["мапудунгу", "мапуче"],
    "арафатка": ["куфия", "палестинка"],
    "арахидоновый": ["линолевый", "линоленовый"],
    "арахис": ["земляной орех", "китайский орех"],
    "арахнид": ["паукообразные"],
    "арахнидизм": ["аранейдизм", "арахноизм кожный"],
    "арахнодактилия": ["долихостеномелия"],
    "арахнофобия": ["паукобоязнь"],
    "арахноэнтомоз": ["артроподоз", "арахно-энтомоз"],
    "арба": ["араба", "гарба"],
    "арбажанин": ["арбажец"],
    "арбажец": ["арбажанин"],
    "арбалет": ["самострел"],
    "арбалетчик": ["самострельщик"],
    "арбитр": ["посредник", "третейский судья", "судья", "рефери"],
    "арбитраж": ["третейский суд", "арбитражный суд", "спекуляция", "арбитражная сделка"],
    "арбитражный": ["третейский"],
    "арбитральный": ["произвольный"],
    "арбитър": ["съдник", "помирител", "посредник"],
    "арборетум": ["дендрарий"],
    "арборист": ["древовод"],
    "арбузинец": ["арбузянин"],
    "арбутин": ["арбутозид", "эриколин", "вакцинин"],
    "арг": ["ару"],
    "аргазид": ["аргасовые клещи"],
    "аргал": ["кизяк"],
    "аргали": ["архар"],
    "аргамак": ["ахалтекинец", "ахалтекинская лошадь"],
    "аргандова лампа": ["кенкет", "кинкет"],
    "аргат": ["аргатин"],
    "аргатин": ["аргат"],
    "аргау": ["ааргау"],
    "аргентан": ["нейзильбер", "альфенид"],
    "аргентина": ["серебрянка"],
    "аргентинская республика": ["аргентина"],
    "аргимпаса": ["артимпаса"],
    "аргинин": ["арг"],
    "аргироид": ["аргирофан"],
    "аргирофан": ["аргироид"],
    "аргиш": ["караван", "обоз"],
    "аргия": ["аргея", "агрия"],
    "арго": ["жаргон", "сленг"],
    "арголида": ["арголика", "аргея"],
    "аргос": ["аргус", "арг", "паноптес"],
    "арготический": ["жаргонный", "сленговый"],
    "аргуменат": ["аргумент"],
    "аргумент": ["довод", "доказательство", "соображение", "основание", "обоснование", "резон", "параметр"],
    "аргументационный": ["доказательный"],
    "аргументация": ["аргументирование"],
    "аргументировав": ["аргументировавши"],
    "аргументировавши": ["аргументировав"],
    "аргументированнее": ["аргументированней"],
    "аргументированней": ["аргументированнее"],
    "аргументировать": ["обосновывать", "апеллировать", "доказывать"],
    "аргус": ["аргос", "арг", "паноптес"],
    "ардалион": ["ардальон"],
    "ардовать": ["ордовач"],
    "ардханари": ["ардханаришвара"],
    "ареал": ["местообитание"],
    "ареалогия": ["хорология"],
    "арен": ["ароматический углеводород"],
    "аренда": ["наём", "сдача"],
    "арендатор": ["наниматель"],
    "арендовав": ["арендовавши"],
    "арендовавши": ["арендовав"],
    "арендовать": ["брать в аренду", "взять в аренду", "брать в наём", "взять в наём", "брать в прокат", "взять в прокат", "нанимать", "нанять", "снимать", "снять"],
    "арендовывав": ["арендовывавши"],
    "арендовывавши": ["арендовывав"],
    "ареология": ["марсоведение", "марсология"],
    "ареопаг": ["судилище", "коллегия", "синедрион", "синклит", "присутствие"],
    "арес": ["арей"],
    "арест": ["задержание", "заключение под стражу"],
    "арестант": ["арестованный", "заключённый", "узник", "осуждённый", "зэк", "лагерник", "колодник", "невольник"],
    "арестантка": ["арестованная", "заключённая"],
    "арестантская": ["камера предварительного заключения"],
    "арестовав": ["арестовавши"],
    "арестовавши": ["арестовав"],
    "арестование": ["арест"],
    "арестовывав": ["арестовывавши"],
    "арестовывавши": ["арестовывав"],
    "аржанец": ["тимофеевка"],
    "арзерум": ["эрзурум", "эрзерум"],
    "арзиш": ["нарх"],
    "арзрум": ["эрзурум", "эрзерум", "арзерум"],
    "арианство": ["ариохристианство"],
    "ариведерчи": ["чао"],
    "аридный": ["сухой", "засушливый"],
    "арий": ["индоариец"],
    "арилировав": ["арилировавши"],
    "арилировавши": ["арилировав"],
    "ариллус": ["кровелька", "присемянник", "присеменник"],
    "ариман": ["ахриман", "ангра-майнью"],
    "аримафея": ["рамафа", "раматаин", "рама", "армафем"],
    "ариософия": ["арманизм"],
    "аристарх": ["критик", "педант", "зоил"],
    "аристида": ["триостренница"],
    "аристократизм": ["изысканность", "утончённость"],
    "аристократический": ["благородный"],
    "аристократичность": ["аристократизм"],
    "аристократничав": ["аристократничавши"],
    "аристократничавши": ["аристократничав"],
    "аристократство": ["дворянство", "знать"],
    "аристотелев": ["аристотелевский"],
    "аристотелизм": ["перипатетизм"],
    "аритмический": ["аритмичный", "неритмичный"],
    "аритмичность": ["неритмичность"],
    "аритмичный": ["неритмичный"],
    "арифмометр": ["счётная машина"],
    "ариша": ["арина"],
    "арк": ["крепость", "цитадель"],
    "арка": ["свод", "дуга"],
    "аркав": ["аркавши"],
    "аркавши": ["аркав"],
    "аркадьевич": ["аркадиевич", "аркадьич"],
    "аркалыкец": ["аркалыкчанин"],
    "аркан": ["лассо", "лариат", "осил"],
    "арканив": ["арканивши"],
    "арканивши": ["арканив"],
    "арканиться": ["ерепениться"],
    "аркебуза": ["пищаль"],
    "аркебузировав": ["аркебузировавши"],
    "аркебузировавши": ["аркебузировав"],
    "аркебузировать": ["расстрелять"],
    "аркесилай": ["аркезилай"],
    "аркоидный": ["роландический", "сензоримоторный", "сенсомоторный", "аркообразный"],
    "аркообразный": ["арковидный"],
    "арктида": ["гиперборея"],
    "арктический океан": ["северный ледовитый океан"],
    "арктур": ["альрамех", "азимех", "коланца", "кэса"],
    "аркылы": ["аша"],
    "арм": ["къух"],
    "армавир": ["сардарабад", "октемберян"],
    "арманизм": ["ариософия"],
    "арматура": ["аксессуары", "арматурина"],
    "арматуура": ["арматура"],
    "армеец": ["служивый", "армеут"],
    "армейка": ["армеечка"],
    "армейский": ["военный", "воинский", "войсковой", "боевой", "боевитый", "солдатский"],
    "арменистика": ["арменология", "арменоведение"],
    "армения": ["республика армения"],
    "армерия": ["цейхгауз"],
    "армировав": ["армировавши"],
    "армировавши": ["армировав"],
    "армировка": ["армирование"],
    "армия": ["вооружённые силы", "войско", "пехота", "армейка", "орда", "тьма"],
    "армрестлер": ["рукоборец"],
    "армрестлинг": ["рукоборье", "армспорт"],
    "армспорт": ["армрестлинг", "рукоборье"],
    "армяжный": ["армячный"],
    "армяк": ["кафтан", "поддёвка", "халат", "балахон", "азям"],
    "армянин": ["армяшка", "армянец"],
    "армяно-российский": ["российско-армянский"],
    "армянская сср": ["арсср", "армсср", "армения"],
    "армянский": ["армянский язык"],
    "армянский язык": ["армянский"],
    "арна": ["меланиппа", "ксанф", "херонея"],
    "арнаутка": ["албанка"],
    "арника": ["баранья трава"],
    "арнис": ["эскрима"],
    "арогенез": ["ароморфоз", "анагенез"],
    "ароер": ["ароир"],
    "ароидный": ["аронниковый"],
    "аромакурительница": ["аромалампа"],
    "аромалампа": ["аромакурительница"],
    "аромат": ["благоухание", "благовоние", "своеобразие", "оттенок", "флейвор"],
    "ароматерапия": ["ароматотерапия"],
    "ароматизировав": ["ароматизировавши"],
    "ароматизировавши": ["ароматизировав"],
    "ароматический": ["ароматный", "благоухающий", "ароматизированный"],
    "ароматний": ["запашний"],
    "ароматно": ["душисто", "пахуче"],
    "ароматный": ["душистый", "благоуханный"],
    "ароматобразующий": ["ароматообразующий"],
    "ароматообразующий": ["ароматобразующий"],
    "ароматотерапия": ["ароматерапия"],
    "ароморфа": ["ароморф", "ароморфоз"],
    "ароморфоз": ["арогенез"],
    "аромун": ["цинцар", "македонский", "румын", "куцовлах", "влех"],
    "аронник": ["арум"],
    "аронниковый": ["ароидный"],
    "арочный": ["сводчатый"],
    "арпеджио": ["арпеджо"],
    "арпеджионе": ["арпеджоне"],
    "арпеджировав": ["арпеджировавши"],
    "арпеджировавши": ["арпеджировав"],
    "арпеджо": ["арпеджио"],
    "арпеджоне": ["арпеджионе"],
    "арпи": ["арпа"],
    "арреник": ["аврипигмент", "аурипигмент", "опермент"],
    "арретировав": ["арретировавши"],
    "арретировавши": ["арретировав"],
    "арретирование": ["арретировка", "застопоривание", "стопорение", "фиксация"],
    "аррогантный": ["высокомерный"],
    "арса": ["арсис"],
    "арсания": ["артания"],
    "арсенал": ["ассортимент", "инструментарий"],
    "арсений": ["арсен", "арсентий", "андрей"],
    "арсенопирит": ["мышьяковый колчедан", "миспикель", "тальгеймит"],
    "арсис": ["арса"],
    "арсланкъаплан": ["арслан"],
    "арся": ["ровнай"],
    "арт-тусовка": ["арт-встреча"],
    "артакама": ["апама"],
    "артакия": ["эрдек"],
    "артаксеркс": ["ардашир"],
    "артания": ["арсания", "утания"],
    "артачив": ["артачивши"],
    "артачивши": ["артачив"],
    "артбой": ["артиллерийский бой"],
    "артезианский колодец": ["артезианская скважина"],
    "артель": ["ватага", "бригада", "кооператив", "колхоз", "товарищество", "общество"],
    "артельный": ["артельский", "артельщик"],
    "артельщик": ["артельный"],
    "артемон": ["артамон"],
    "артерия": ["магистраль"],
    "артикль": ["член"],
    "артикул": ["спецификация", "маркировка"],
    "артикулировав": ["артикулировавши"],
    "артикулировавши": ["артикулировав"],
    "артикулятор": ["гнатофор"],
    "артикуляторный": ["артикуляционный"],
    "артикуляция": ["артикулирование", "дикция"],
    "артиллерийская граната": ["осколочный снаряд", "осколочно-фугасный снаряд"],
    "артиллерийский": ["орудийный"],
    "артиллерист": ["бомбардир"],
    "артиллерия": ["артиллерийское орудие", "арта"],
    "артимпаса": ["аргимпаса"],
    "артинец": ["артянин"],
    "артист": ["мастер", "художник"],
    "артист погорелого театра": ["актёр погорелого театра", "актриса погорелого театра"],
    "артистизм": ["артистичность", "изящество", "грациозность", "грация", "мастерство", "виртуозность"],
    "артистически": ["артистично"],
    "артистичный": ["изящный", "грациозный"],
    "артифициальный": ["искусственный", "рукотворный"],
    "артобстрел": ["артиллерийский обстрел"],
    "артос": ["артус"],
    "артотипия": ["альбертипия", "гелиотипия", "коллотипия"],
    "артритический": ["подагрический"],
    "артрогрипоз": ["врождённая амиоплазия", "врождённая артромиодисплазия"],
    "артроспора": ["конидия", "оидия"],
    "артус": ["артур"],
    "артхаус": ["авторское кино"],
    "артянин": ["артинец"],
    "артём": ["тёма", "артемий", "артемон"],
    "артёмовск": ["бахмут", "кипучее"],
    "артёмовская мясорубка": ["бахмутская мясорубка"],
    "артёмовчанин": ["артёмовец"],
    "ару": ["арг"],
    "аруд": ["аруз"],
    "аруз": ["аруд"],
    "арум": ["аронник"],
    "арумынский": ["арумынский язык", "аромунский язык"],
    "арункус": ["волжанка"],
    "арус": ["номзад", "келин"],
    "арфистка": ["арфянка"],
    "арфянка": ["арфистка"],
    "архаизация": ["демодернизация", "устаревание", "деградация"],
    "архаизировав": ["архаизировавши"],
    "архаизировавши": ["архаизировав"],
    "архаизм": ["пережиток"],
    "архаизовав": ["архаизовавши"],
    "архаизовавши": ["архаизовав"],
    "архаизовать": ["архаизировать"],
    "архаизъм": ["старина", "старинност", "старомодност", "отживялост", "отживелица", "изостаналост", "анахронизъм"],
    "архаика": ["древность", "старина"],
    "архаически": ["архаично"],
    "архаический": ["древний", "архаичный", "устарелый", "старомодный", "несовременный", "допотопный"],
    "архаично": ["несовременно", "допотопно", "архаически"],
    "архаичность": ["старомодность"],
    "архаичный": ["архаический", "древний", "старинный", "устаревший", "несовременный", "допотопный"],
    "архалук": ["ахалук", "кафтан", "халат"],
    "архангел": ["ангел"],
    "архангелец": ["архангелогородец"],
    "архангелогородец": ["архангелец", "трескоед", "житник", "кровельщик"],
    "архангелогородчина": ["архангельщина"],
    "архангельск": ["новохолмогоры", "архангельский город", "столица поморья", "столица беломорья"],
    "архангельщина": ["архангелогородчина"],
    "архантроп": ["эректус", "человек прямоходящий"],
    "архар": ["аргали", "горный баран", "аркар", "качкар"],
    "архаромеринос": ["архаро-меринос"],
    "архатроп": ["архантроп"],
    "архе-": ["арх-", "архи-"],
    "архебактерия": ["архея"],
    "архегоний": ["архегония"],
    "архегония": ["архегоний"],
    "археи": ["безъядерный"],
    "архейская эпоха": ["архей"],
    "архейский": ["археозойский"],
    "архейский акрон": ["архей"],
    "архейский эон": ["архей"],
    "археоастрономия": ["астроархеология"],
    "археозой": ["архей"],
    "археозойский": ["архейский"],
    "археолог": ["копатель"],
    "археологиня": ["археологичка"],
    "археологичка": ["археологиня"],
    "археоцит": ["стволовая клетка"],
    "архетип": ["образ"],
    "архея": ["архебактерия"],
    "архи": ["очень", "чересчур", "чрезмерно", "излишне", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "архи-": ["сверх-"],
    "архиатер": ["архиятр", "архиятер", "архиятор"],
    "архибыстро": ["пребыстро"],
    "архив": ["архивохранилище", "архивный фонд"],
    "архиважный": ["сверхважный", "важнейший"],
    "архиварий": ["архивариус"],
    "архивариус": ["архивист", "архиварий"],
    "архиватор": ["компрессор"],
    "архивация": ["архивирование"],
    "архивировав": ["архивировавши"],
    "архивировавши": ["архивировав"],
    "архивист": ["архивариус"],
    "архидиаконский": ["архидьяконский"],
    "архидиаконство": ["архидьяконство"],
    "архидьяконский": ["архидиаконский"],
    "архиепархия": ["архиепископия", "архидиоцез"],
    "архиерей": ["епископ"],
    "архимагир": ["архимагер"],
    "архимандричий": ["архимандритский"],
    "архипастырство": ["архиерейство"],
    "архипастырствовав": ["архипастырствовавши"],
    "архипастырствовавши": ["архипастырствовав"],
    "архипастырь": ["архиерей"],
    "архипелаг": ["остров"],
    "архипелажский": ["архипелагский"],
    "архисема": ["сверхсема"],
    "архисложный": ["сложнейший"],
    "архитектон": ["архитектор"],
    "архитектор": ["зодчий"],
    "архитектура": ["зодчество"],
    "архитектурный": ["зодческий"],
    "архитрав": ["эпистелион", "эпистиль"],
    "архиятер": ["архиатер", "архиятр", "архиятор"],
    "архиятр": ["архиатер", "архиятер", "архиятор"],
    "арцах": ["нагорно-карабахская республика"],
    "арчажник": ["арчажный", "мастер"],
    "арчак": ["ленчик"],
    "арчинский": ["арчинский язык"],
    "арчинский язык": ["арчинский"],
    "аршакид": ["арсакид"],
    "аршин": ["стакан"],
    "аршин с шапкой": ["метр с кепкой", "коротышка"],
    "аршинничав": ["аршинничавши"],
    "аршинничавши": ["аршинничав"],
    "арьергард": ["хвост"],
    "арьсемс": ["арьсекшнемс", "ёрамс"],
    "ас": ["большая медведица"],
    "асабовы": ["персанальны"],
    "асалода": ["задавальненне", "радасць", "уцеха"],
    "асам": ["тухату"],
    "асб": ["асп"],
    "асбест": ["амиант", "горный", "лён", "каменный"],
    "асбестово-бумажный": ["асбобумажный"],
    "асбестодиатомовый": ["асбестотрепельный"],
    "асбестоз": ["диффузный интерстициальный фиброз лёгких"],
    "асбестоизвестковотрепельный": ["вулканитовый"],
    "асбестотрепельный": ["асбестодиатомовый"],
    "асбестофанера": ["асбофанера"],
    "асбестоцемент": ["асбоцемент"],
    "асбоб": ["олат"],
    "асбокартон": ["уралит"],
    "асборезиновый": ["резиноасбестовый"],
    "асбофанера": ["асбестофанера"],
    "асейсмичный": ["асейсмический"],
    "асекко": ["альсекко"],
    "асексуалист": ["асексуал"],
    "асемантический": ["асемантичный", "десемантизированный"],
    "асемантичный": ["асемантический", "десемантизированный"],
    "асенефа": ["асенат"],
    "асеньки": ["ась", "что"],
    "асептический": ["дезинфицированный", "обеззараженный", "стерильный", "стерилизованный"],
    "асептический менингит": ["серозный менингит", "лимфоцитарный менингит"],
    "асессор": ["помощник", "заседатель", "оценщик", "эксперт", "тестировщик"],
    "асиа пиктэ": ["эктэ пиктэ"],
    "асилзода": ["ашроф", "аъён"],
    "асимметрически": ["асимметрично"],
    "асимметрично": ["асимметрически"],
    "асимметричность": ["несимметричность"],
    "асимметричный": ["несимметричный"],
    "асимметрия": ["асимметричность", "несимметричность"],
    "асимптотический": ["асимптотичный"],
    "асимптотический закон": ["закон больших чисел"],
    "асимптотичный": ["асимптотический"],
    "асиндетический": ["бессоюзный"],
    "асиндетон": ["бессоюзие"],
    "асино": ["ксеньевка"],
    "асинхронично": ["асинхронно"],
    "асинхронно": ["разновременно"],
    "асинхронный": ["неодновременный", "несинхронный"],
    "асир": ["ашер"],
    "аскав": ["аскавши"],
    "аскавши": ["аскав"],
    "аскалан": ["ашкелон"],
    "аскалон": ["ашкелон"],
    "аскать": ["просить", "попрошайничать"],
    "аскеза": ["аскетизм"],
    "аскер": ["эскер"],
    "аскерин": ["войник", "солдат", "аскер", "боец"],
    "аскетизм": ["аскеза"],
    "аскетически": ["аскетично"],
    "аскетично": ["аскетически", "скупо", "минималистски", "минималистически"],
    "аскетичность": ["аскетизм"],
    "аскетичный": ["аскетический", "скупой"],
    "аскетский": ["аскетический"],
    "аскнув": ["аскнувши"],
    "аскнувши": ["аскнув"],
    "аскорбинка": ["аскорбиновая кислота"],
    "аскорбиновая кислота": ["аскорбинка"],
    "аскострома": ["псевдотеция"],
    "аскривиец": ["которанин", "каттарец"],
    "аскриптивный": ["предписанный"],
    "аскэр": ["эскэр"],
    "асланцы": ["асламчы"],
    "асмалак": ["галавешка"],
    "асмодей": ["ашмедай", "аэшма-дэв"],
    "асомния": ["бессонница", "агрипния", "инсомния", "диссомния"],
    "асоциальный": ["антиобщественный"],
    "асп": ["фарас", "асб"],
    "аспарагинат": ["аспартат"],
    "аспарагиновая кислота": ["аминоянтарная кислота", "аспартат", "аминобутандиовая кислота"],
    "аспарагус": ["спаржа"],
    "аспект": ["подход", "перспектива", "сторона", "разрез", "глагольный вид", "внешний вид", "пейзаж", "группа", "габитус"],
    "аспектик": ["фактор", "особенность", "свойство", "деталь"],
    "аспектуальный": ["видовой"],
    "асперолит": ["хризоколла", "элит", "демидовит", "тагилит", "эпидот", "клиноцоизит", "пьемонтит", "алланит", "ортит"],
    "асперуго": ["острица"],
    "аспид": ["элапида"],
    "аспидированный": ["чернёный"],
    "аспидиум": ["щитник"],
    "аспидная доска": ["грифельная доска"],
    "аспидовый": ["аспид"],
    "аспидский": ["зловредный", "злобный", "злой", "недобрый", "трудный", "невыносимый"],
    "аспирант": ["претендент", "соискатель"],
    "аспирация": ["стремление", "направленность", "цель", "придыхание", "лениция"],
    "аспирин": ["ацетилсалициловая кислота"],
    "аспирировав": ["аспирировавши"],
    "аспирировавши": ["аспирировав"],
    "аспирированный": ["придыхательный"],
    "аспления": ["алиения"],
    "асры": ["астры"],
    "асс": ["ас"],
    "ассагай": ["ассегай"],
    "ассамблея народа казахстана": ["анк"],
    "ассарий": ["асс"],
    "ассасин": ["гашишин"],
    "ассемблировав": ["ассемблировавши"],
    "ассемблировавши": ["ассемблировав"],
    "ассенизатор": ["золотарь", "говночист", "говновоз"],
    "ассенизировав": ["ассенизировавши"],
    "ассенизировавши": ["ассенизировав"],
    "ассет": ["компонент", "ресурс"],
    "ассигновав": ["ассигновавши"],
    "ассигновавши": ["ассигновав"],
    "ассигнование": ["финансирование"],
    "ассигновать": ["выделить", "асигновать"],
    "ассигновывав": ["ассигновывавши"],
    "ассигновывавши": ["ассигновывав"],
    "ассимилировав": ["ассимилировавши"],
    "ассимилировавши": ["ассимилировав"],
    "ассимилирование": ["ассимиляция"],
    "ассимилятивный": ["ассимиляционный", "конвергентный"],
    "ассимиляторный": ["ассимиляционный", "ассимиляторский"],
    "ассимиляторский": ["ассимиляторный", "ассимиляционный"],
    "ассимиляторствовав": ["ассимиляторствовавши"],
    "ассимиляторствовавши": ["ассимиляторствовав"],
    "ассимиляционный": ["ассимиляторский", "ассимилятивный"],
    "ассимиляция": ["уподобление", "усвоение", "слияние", "поглощение", "приобретение"],
    "ассириец": ["айсор", "ассириянин"],
    "ассирийка": ["ассириянка"],
    "ассириянин": ["ассириец"],
    "ассириянка": ["ассирийка"],
    "ассиро-вавилонский": ["аккадский язык"],
    "ассиролог": ["ассириолог"],
    "ассистировав": ["ассистировавши"],
    "ассистировавши": ["ассистировав"],
    "ассонировав": ["ассонировавши"],
    "ассонировавши": ["ассонировав"],
    "ассортимент": ["коллекция", "номенклатура изделий"],
    "ассоциировав": ["ассоциировавши"],
    "ассоциировавши": ["ассоциировав"],
    "ассоциировать": ["связывать"],
    "ассюрировать": ["застраховать", "страховать", "гарантировать", "обеспечить", "обеспечивать", "уверить", "уверять", "заверить", "заверять"],
    "астаксантин": ["астазантин"],
    "астал": ["сто"],
    "астана": ["акмола", "акмолинск", "целиноград", "нур-султан"],
    "астат": ["астатин"],
    "астатин": ["астат"],
    "астеизм": ["персифляция"],
    "астеничный": ["астенический"],
    "астеризм": ["созвездие", "три звёздочки"],
    "астериск": ["звёздочка", "звездица"],
    "астероид": ["планетоид", "малая планета"],
    "астильбе": ["астильба"],
    "астионим": ["полисоним"],
    "астматически": ["астматично"],
    "астматичный": ["астматический"],
    "астмоидный": ["астмоподобный"],
    "астмоподобный": ["астмоидный"],
    "астралин": ["керосин"],
    "астральный": ["звёздный"],
    "астранция": ["звездовка"],
    "астрапофобия": ["кераунофобия"],
    "астрахан": ["каракуль"],
    "астраханит": ["блёдит"],
    "астраханская селёдка": ["селёдка в корсете"],
    "астраханский государственный университет": ["агу"],
    "астроархеология": ["археоастрономия"],
    "астробиология": ["экзобиология"],
    "астролабия": ["астролаб"],
    "астролатрия": ["звёздопоклонство"],
    "астролябия": ["астролабон"],
    "астролётчик": ["космонавт"],
    "астронавтка": ["космонавтка"],
    "астроним": ["космоним"],
    "астронимика": ["космонимика"],
    "астроном": ["звездочёт"],
    "астрономический компас": ["астрокомпас"],
    "астроплан": ["звездолёт", "планетолёт"],
    "астротруба": ["астрономический телескоп"],
    "астрофизика": ["космофизика"],
    "астрофотография": ["астрография"],
    "астроцветные": ["сростнопыльниковые"],
    "астры": ["асры"],
    "асуан": ["сиене", "сиена", "сун"],
    "асурдиа": ["асурдия"],
    "асурдия": ["асурдиа"],
    "асфальт": ["горная смола", "земляная смола", "минеральная смола", "иудейская смола", "еврейская смола", "жидовская смола", "асфальтобетонная смесь", "асфальтовый бетон", "асфальтобетон"],
    "асфальтировав": ["асфальтировавши"],
    "асфальтировавши": ["асфальтировав"],
    "асфальтный": ["асфальтовый"],
    "асфальтосмолопарафиновые отложения": ["аспо"],
    "асферический": ["несферический"],
    "асферичность": ["несферичность"],
    "асферичный": ["асферический"],
    "асфиксия": ["удушье"],
    "асфодель": ["асфодил", "асфоделус", "асфоделюс"],
    "асфодил": ["асфодель"],
    "асхабадец": ["ашхабадец"],
    "асхистовый": ["ашистовый"],
    "асцит": ["брюшная водянка"],
    "ась": ["аюшки"],
    "асьмеос": ["ми"],
    "асьсэос": ["соос"],
    "ата": ["атай"],
    "атабаск": ["атапаск"],
    "атабаскский": ["атапаскский"],
    "атабасский": ["атапасский"],
    "атабийлик": ["патриархат"],
    "атавистически": ["атавистично"],
    "атавистический": ["атавистичный"],
    "атай": ["ата"],
    "атайка": ["пеганка"],
    "атака": ["нападение", "штурм", "наступ"],
    "атаковав": ["атаковавши"],
    "атаковавши": ["атаковав"],
    "атаковать": ["нападать", "напасть", "наступать", "идти в атаку", "пойти в атаку"],
    "атаковаться": ["атаковываться"],
    "атаковывав": ["атаковывавши"],
    "атаковывавши": ["атаковывав"],
    "атаковываться": ["атаковаться"],
    "атаман": ["предводитель", "глава", "староста", "главарь"],
    "атаманив": ["атаманивши"],
    "атаманивши": ["атаманив"],
    "атаманствовав": ["атаманствовавши"],
    "атаманствовавши": ["атаманствовав"],
    "атанда": ["шухер", "атас"],
    "атапаск": ["атабаск"],
    "атапаскский": ["атабаскский"],
    "атапасский": ["атабасский"],
    "атараксия": ["невозмутимость", "безмятежность", "эвтюмия"],
    "атас": ["берегись", "тревога", "атанда", "полундра", "шухер"],
    "атау": ["утрау"],
    "атеизм": ["безбожие"],
    "атеизъм": ["безбожие", "безбожничество", "безверие"],
    "атеист": ["безбожник", "неверующий", "аметист"],
    "атеистически": ["атеистично"],
    "атеистический": ["безбожный"],
    "атеистка": ["безбожница"],
    "ателье": ["цех", "мастерская", "студия"],
    "атеней": ["атенеум", "афиней"],
    "атенюатор": ["ослаблювач"],
    "атеринка": ["атериновые"],
    "атермальный": ["атермический"],
    "атермический": ["атермальный"],
    "атерома": ["жировик"],
    "атест": ["атестат"],
    "атестат": ["атест"],
    "атилл": ["палаш"],
    "атипический": ["атипичный"],
    "атипичная пневмония": ["атипичка"],
    "атипичный": ["нетипичный"],
    "атк": ["автотранспортная контора", "атп"],
    "аткарец": ["аткарчанин", "аткарянин"],
    "атлант": ["атлас"],
    "атлантида": ["страна атланта"],
    "атлантизировав": ["атлантизировавши"],
    "атлантизировавши": ["атлантизировав"],
    "атлантический океан": ["гесперийское море"],
    "атлас": ["атлант"],
    "атласец": ["атлас"],
    "атласно-белый": ["белоатласный"],
    "атлатль": ["копьеметалка"],
    "атлет": ["силач", "крепыш"],
    "атлетизм": ["атлетичность", "бодибилдинг", "культуризм"],
    "атлетист": ["культурист", "бодибилдер"],
    "атлетически": ["атлетично"],
    "атлетичный": ["атлетический"],
    "атма": ["атман"],
    "атман": ["атма"],
    "атмогенический": ["атмосферический"],
    "атмогенный": ["атмогенический"],
    "атмосфера": ["воздух", "дух", "среда"],
    "атмосферический": ["атмосферный"],
    "атмосферный": ["атмосферический", "внутриатмосферный"],
    "атож": ["авжеж"],
    "атом-акцептор": ["акцептор"],
    "атом-донор": ["донор"],
    "атомарина": ["атомоход"],
    "атомизатор": ["распылитель"],
    "атомизировав": ["атомизировавши"],
    "атомизировавши": ["атомизировав"],
    "атомический": ["атомный"],
    "атомная бомба": ["ядерная бомба"],
    "атомная единица массы": ["дальтон"],
    "атомная подводная лодка": ["апл"],
    "атомная станция теплоснабжения": ["аст"],
    "атомная энергетика": ["ядерная энергетика"],
    "атомник": ["атомщик"],
    "атомное ядро": ["ядро", "атом"],
    "атомность": ["валентность"],
    "атомный номер": ["атомное число"],
    "атомщик": ["атомник", "ядерщик"],
    "атональность": ["атонализм", "атональная музыка", "пантональность", "атоникальность", "атоничность"],
    "атональный": ["атоникальный", "внетональный", "тонально неопределённый"],
    "атонировав": ["атонировавши"],
    "атонировавши": ["атонировав"],
    "атонический": ["слабый", "вялый", "расслабленный"],
    "атос": ["афон"],
    "атофан": ["цинхофен"],
    "атракурия безилат": ["атракурий"],
    "атрамент": ["чорнило"],
    "атрезия": ["заращение", "облитерация"],
    "атрибут": ["свойство", "характеристика"],
    "атрибутика": ["атрибут", "символика"],
    "атрибутировав": ["атрибутировавши"],
    "атрибутировавши": ["атрибутировав"],
    "атрибуция": ["атрибутирование"],
    "атриум": ["атрий"],
    "атропинчик": ["атропин"],
    "атрофировав": ["атрофировавши"],
    "атрофировавши": ["атрофировав"],
    "атрофический кольпит": ["сенильный кольпит"],
    "атрофия": ["атрофация"],
    "атсыз бармак": ["исемсез бармак"],
    "аттапульгит": ["палыгорскит"],
    "аттач": ["аттачмент", "вложение"],
    "аттачмент": ["вложение", "аттач"],
    "атташе": ["дипломат"],
    "аттентат": ["покушение"],
    "аттенция": ["внимание", "забота", "интерес"],
    "аттестат": ["диплом"],
    "аттестация": ["оценка", "отзыв", "характеристика"],
    "аттестовав": ["аттестовавши"],
    "аттестовавши": ["аттестовав"],
    "аттестование": ["аттестация"],
    "аттестовывав": ["аттестовывавши"],
    "аттестовывавши": ["аттестовывав"],
    "аттик": ["эпитимпанум"],
    "аттикизм": ["аттицизм"],
    "аттицизм": ["аттикизм"],
    "аттический": ["изысканный", "утончённый"],
    "аттометр": ["ам"],
    "атторней": ["поверенный", "стряпчий"],
    "аттосекунда": ["ас"],
    "аттрактивный": ["заманчивый", "привлекательный", "притягательный", "обворожительный", "обольстительный", "очаровательный", "прелестный", "соблазнительный", "пленительный", "искусительный", "притягивающий"],
    "аттракция": ["привлекательность"],
    "ату": ["фас", "взять"],
    "ату его": ["ату", "фас"],
    "атукав": ["атукавши"],
    "атукавши": ["атукав"],
    "атукнув": ["атукнувши"],
    "атукнувши": ["атукнув"],
    "атур": ["геннин", "эннин", "эннен"],
    "атф": ["аденозинтрифосфат", "аденозинтрифосфорная кислота", "аденилпирофосфорная кислота"],
    "атырау": ["гурьев"],
    "ать": ["раз"],
    "ать-два": ["раз-два", "сено-солома", "левой-правой"],
    "аугсбургец": ["аугсбуржец"],
    "аудио-": ["звуко-"],
    "аудиоаппаратура": ["аудиотехника"],
    "аудиовариант": ["аудиоверсия"],
    "аудиоверсия": ["аудиовариант"],
    "аудиоданные": ["аудиоинформация"],
    "аудиодескрипция": ["тифлокомментирование"],
    "аудиозапись": ["фонозапись"],
    "аудиоиллюстрация": ["аудиопример"],
    "аудиоинформация": ["аудиоданные"],
    "аудиокарта": ["аудиоплата", "звуковая карта"],
    "аудиокассета": ["компакт-кассета"],
    "аудиокнига": ["аудиобук"],
    "аудиоколонка": ["спикер"],
    "аудиокомпакт": ["аудиодиск", "аудиокомпакт-диск"],
    "аудиокомпакт-диск": ["аудиодиск", "аудиокомпакт"],
    "аудиоплата": ["аудиокарта", "звуковая карта"],
    "аудиопример": ["аудиоиллюстрация"],
    "аудиосистема": ["аудиоцентр"],
    "аудиотехника": ["аудиоаппаратура"],
    "аудиофильм": ["радиоспектакль"],
    "аудировав": ["аудировавши"],
    "аудировавши": ["аудировав"],
    "аудит": ["экспертиза", "переучёт"],
    "аудитор": ["ревизор", "стряпчий", "прокурор"],
    "аудитория": ["слушатели"],
    "аудиция": ["аудирование", "слушание"],
    "ауе": ["арестантский уклад един", "арестантское уркаганское единство"],
    "ауевший": ["ауешник"],
    "аукав": ["аукавши"],
    "аукавши": ["аукав"],
    "аукание": ["ауканье"],
    "ауканье": ["аукание"],
    "аукнув": ["аукнувши"],
    "аукнувши": ["аукнув"],
    "ауксанометр": ["авксанометр"],
    "ауксилий": ["ауксиларий"],
    "ауксоавтотроф": ["ауксоаутотроф"],
    "ауксоавтотрофный": ["ауксоаутотрофный"],
    "ауксоаутотроф": ["ауксоавтотроф"],
    "ауксоаутотрофный": ["ауксоавтотрофный"],
    "ауксотонический": ["анизотонический"],
    "аукуба": ["золотое дерево"],
    "аукционер": ["аукционист"],
    "аукционист": ["лицитатор"],
    "аула": ["актовый зал"],
    "аулак": ["кешесез"],
    "аульчанин": ["аулец"],
    "аумист": ["аумовец"],
    "аумовец": ["аумист"],
    "аурей": ["ауреус"],
    "ауреомицин": ["хлортетрациклин", "биомицин", "дуомицин"],
    "ауреус": ["аурей"],
    "аурипигмент": ["аврипигмент", "арреник", "опермент"],
    "ауру": ["дерт", "кесел"],
    "аусвайс": ["ксива"],
    "ауслаут": ["исход слова"],
    "аустерия": ["австерия", "трактир", "харчевня", "закусочная"],
    "аустрический": ["австрический"],
    "аустроазиатский": ["австроазиатский"],
    "аут": ["вне игры", "отрешённость", "фрустрация", "отключка"],
    "аутапоморфия": ["автапоморфия"],
    "аутентик": ["автентик"],
    "аутентифицировав": ["аутентифицировавши"],
    "аутентифицировавши": ["аутентифицировав"],
    "аутентический": ["аутентичный"],
    "аутентичность": ["подлинность", "достоверность"],
    "аутентичный": ["аутентический", "действительный", "подлинный", "настоящий"],
    "аутив": ["аутивши"],
    "аутивши": ["аутив"],
    "аутизм": ["аутичность"],
    "аутистический": ["аутический"],
    "аутический": ["аутистический", "аутичный"],
    "аутичность": ["аутизм"],
    "ауто-": ["авто-", "само-"],
    "аутоагрегация": ["автоагрегация"],
    "аутоагрессивность": ["автоагрессивность"],
    "аутоагрессия": ["автоагрессия", "аутодеструкция", "самоагрессия"],
    "аутоаллергический": ["автоаллергический", "аутоиммунный"],
    "аутоаллергия": ["эндоаллергия", "аутоагрессия", "аутоиммунитет", "автоаллергия"],
    "аутоанализатор": ["автоанализатор"],
    "аутоантиген": ["эндоантиген"],
    "аутоантитело": ["автоантитело"],
    "аутобактериофаг": ["автобактериофаг"],
    "аутовакцина": ["автовакцина"],
    "аутогамия": ["автогамия"],
    "аутогамный": ["автогамный"],
    "аутогемотрансфузия": ["автотрансфузия", "аутотрансфузия"],
    "аутогенез": ["автогенез"],
    "аутогенная тренировка": ["аутотренинг"],
    "аутография": ["радиоаутография", "ауторадиография"],
    "аутодафе": ["сожжение"],
    "аутодерма": ["аутолоскут"],
    "аутодермопластика": ["автодермопластика"],
    "аутодеструктивное поведение": ["самоповреждающее поведение"],
    "аутодеструктивный": ["самоповреждающий"],
    "аутодеструкция": ["аутоагрессия", "автоагрессия"],
    "аутодетерминанта": ["аутоэпитоп", "аутоиммунный эпитоп"],
    "аутодигестия": ["автодигестия"],
    "аутодифференциация": ["самодифференциация"],
    "аутоидентификация": ["автоидентификация"],
    "аутоиммунизация": ["автоиммунизация"],
    "аутоиммунитет": ["аутоиммунное заболевание"],
    "аутоиммунность": ["аутоиммунитет"],
    "аутоиммунный": ["автоиммунный"],
    "аутоинвазия": ["автоинвазия"],
    "аутоинтоксикация": ["автоинтоксикация"],
    "аутоинфекция": ["автоинфекция"],
    "аутокатализ": ["автокатализ"],
    "аутокаталитический": ["автокаталитический"],
    "аутокатетеризация": ["самокатетеризация"],
    "аутокунилингус": ["аутокуннилингус", "автокунилингус", "автокуннилингус"],
    "аутокуннилингус": ["автокунилингус", "автокуннилингус", "аутокунилингус"],
    "аутолиз": ["автолиз"],
    "аутолизин": ["автолизин"],
    "аутолизировав": ["аутолизировавши"],
    "аутолизировавши": ["аутолизировав"],
    "аутолизировать": ["автолизировать"],
    "аутолизироваться": ["автолизироваться"],
    "аутолизный": ["автолизный"],
    "аутолитический": ["автолитический"],
    "аутолоскут": ["аутодерма"],
    "аутомиксис": ["автомиксис"],
    "аутомиктический": ["автомиктический"],
    "аутомобил": ["ауто"],
    "аутомоносексуализм": ["аутоэротизм", "аутоэрастия", "аутосексуальность", "аутофилия"],
    "аутомутаген": ["автомутаген"],
    "аутооксидация": ["самоокисление", "автооксидация"],
    "аутоориентация": ["автоориентация"],
    "аутоофтальмоскопия": ["аутоофтальмофундоскопия"],
    "аутопептид": ["автопептид"],
    "аутопластика": ["аутотрансплантация"],
    "аутополиплоид": ["автополиплоид"],
    "аутополиплоидия": ["автополиплоидия"],
    "аутополиплоидный": ["автополиплоидный"],
    "аутопоэз": ["автопоэз"],
    "аутопротромбин": ["акцелерин"],
    "аутопсихоз": ["автопсихоз"],
    "аутопсия": ["некропсия", "секция", "анатомирование"],
    "ауторадиограмма": ["авторадиограмма"],
    "ауторадиограф": ["авторадиограф"],
    "ауторадиография": ["авторадиография"],
    "аутореактивность": ["автореактивность"],
    "ауторегуляция": ["саморегуляция"],
    "ауторепликация": ["ауторепродукция"],
    "ауторепродуктивный": ["аутосинтетический", "авторепродуктивный"],
    "ауторецептор": ["авторецептор"],
    "аутосемантический": ["автосемантический", "знаменательный", "категорематический", "категорематичный", "полнозначный"],
    "аутосеротерапия": ["автосеротерапия"],
    "аутосинапс": ["аутосиндез"],
    "аутосиндез": ["автосиндез", "аутосинапсис"],
    "аутосинтез": ["репликация", "ауторепродукция", "редупликация", "автосинтез"],
    "аутосинтетический": ["автосинтетический"],
    "аутосома": ["аутохромосома"],
    "аутостимуляция": ["самостимуляция", "самораздражение"],
    "аутостимуляция сердца": ["атриовентрикулярная стимуляция сердца"],
    "аутосуггестия": ["самовнушение", "автосуггестия"],
    "аутотерапия": ["автотерапия"],
    "аутотип": ["автотип"],
    "аутотолерантность": ["автотолерантность"],
    "аутотомия": ["автотомия", "самокалечение"],
    "аутотрансплантат": ["автотрансплантат"],
    "аутотрансфузия": ["аутогемотрансфузия", "автотрансфузия"],
    "аутотренинг": ["аутогенная тренировка"],
    "аутофагосома": ["аутолизосома"],
    "аутофелляция": ["автофелляция"],
    "аутофилия": ["самолюбование", "нарциссизм", "автофилия"],
    "аутохтонный": ["автохтонный"],
    "аутоцитолиз": ["автоцитолиз"],
    "аутоцитотоксин": ["автоцитотоксин"],
    "аутоэкологический": ["аутэкологический", "автоэкологический"],
    "аутоэкология": ["аутэкология"],
    "аутоэрастия": ["аутофилия"],
    "аутоэротизм": ["онанизм", "мастурбация", "аутоэрастия", "аутомоносексуализм", "аутосексуальность", "аутофилия", "нарциссизм"],
    "аутсорсинг": ["подряд", "аутсорс"],
    "аутэкологический": ["аутоэкологический"],
    "аутэкология": ["аутоэкология"],
    "ауф": ["ого", "вау", "супер"],
    "ауфидерзейн": ["чао", "пока"],
    "аучы": ["сунарчы"],
    "аушки": ["аюшки", "ась"],
    "аф весть": ["ламоксть"],
    "аф эряви": ["тят", "цю"],
    "аф ёру": ["виде", "видекс", "афкукс"],
    "афалина": ["большой дельфин", "бутылконосый дельфин"],
    "афарин": ["маладис"],
    "афган": ["афганистан"],
    "афганец": ["афганистанец", "шурави", "афганская борзая", "афган"],
    "афганистан": ["исламский эмират афганистан", "королевство афганистан", "республика афганистан", "демократическая республика афганистан", "дра", "исламская республика афганистан", "афган"],
    "афгано-советский": ["афганско-советский"],
    "афгано-таджикский": ["таджико-афганский", "таджикско-афганский"],
    "афганская борзая": ["афган", "афганец", "афганка"],
    "афганская война": ["афганистан", "афган"],
    "афганско-советский": ["афгано-советский"],
    "афганско-таджикский": ["афгано-таджикский"],
    "афебрильный": ["безлихорадочный"],
    "афедрон": ["сортир", "отхожее место", "нужник", "уборная", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопка", "жопочка", "попка", "попец", "попочка", "попца"],
    "афелий": ["апогелий"],
    "афенский": ["афинский"],
    "афеня": ["офеня", "варяг", "кантюжник", "ходебщик", "щепетильник"],
    "афера": ["мошенничество", "махинация", "авантюра", "панама", "сделка"],
    "аферез": ["гемаферез"],
    "афереза": ["аферезис"],
    "аферезис": ["афереза"],
    "аферист": ["мошенник", "жулик"],
    "афзор": ["абзор"],
    "афиллофоровые": ["полипоровые"],
    "афина": ["афина паллада"],
    "афинские вечера": ["афинские ночи"],
    "афишировав": ["афишировавши"],
    "афишировавши": ["афишировав"],
    "афиширование": ["афишированье"],
    "афишировать": ["трезвонить", "демонстрировать", "рекламировать", "подчёркивать", "бахвалиться"],
    "афкукс": ["виде", "видекс", "аф ёру"],
    "афон": ["атос"],
    "афония": ["дисфония"],
    "афоризм": ["максима"],
    "афористически": ["афористично"],
    "афористично": ["афористически"],
    "афористичность": ["выразительность", "лаконичность", "лапидарность"],
    "афористичный": ["лаконичный", "краткий", "сжатый", "афористический"],
    "афразийский": ["афроазиатский", "семито-хамитский", "хамито-семитский"],
    "афразийский язык": ["семито-хамитский язык", "хамито-семитский язык"],
    "афразия": ["афазия"],
    "афреско": ["альфреско"],
    "афридии": ["африди"],
    "африка": ["чёрный континент"],
    "африкаанс": ["бурский"],
    "африкандер": ["африканер"],
    "африканер": ["африкандер"],
    "афродизия": ["эротизм"],
    "афродита": ["киприда", "венера", "аматузия"],
    "афророссиянин": ["афрорусский"],
    "афрофобия": ["негрофобия"],
    "афрохтан": ["афроштан"],
    "афроштан": ["афрохтан"],
    "афсона": ["матал"],
    "афта": ["язвочка"],
    "афтоба": ["афтафа"],
    "аффектация": ["кривлянье", "жеманство", "вычурность", "напыщенность", "натянутость"],
    "аффективно-моторный": ["аффектно-моторный"],
    "аффектировав": ["аффектировавши"],
    "аффектировавши": ["аффектировав"],
    "аффектно-моторный": ["аффективно-моторный"],
    "афферентный": ["приносящий", "центростремительный", "чувствительный"],
    "аффидавит": ["аффидевит"],
    "аффидевит": ["аффидавит"],
    "аффилиат": ["аффилейт", "аффилиейт"],
    "аффилиация": ["аффиляция"],
    "аффилиировав": ["аффилиировавши"],
    "аффилиировавши": ["аффилиировав"],
    "аффилировав": ["аффилировавши"],
    "аффилировавши": ["аффилировав"],
    "аффилирование": ["аффилиирование"],
    "аффилировать": ["кооптировать"],
    "аффиляция": ["аффилиация"],
    "аффинировав": ["аффинировавши"],
    "аффинировавши": ["аффинировав"],
    "аффинированный": ["очищенный"],
    "аффинность": ["сродство"],
    "аффицировав": ["аффицировавши"],
    "аффицировавши": ["аффицировав"],
    "аффрикативный": ["аффрикатный"],
    "аффрикатный": ["аффрикативный"],
    "афюн": ["тарёк"],
    "ах вон что": ["ах так", "ах вот как", "ах вот что"],
    "ах вот как": ["ах так", "ах вот что", "ах вон что"],
    "ах вот что": ["ах так", "ах вот как", "ах вон что"],
    "ах так": ["ах вот как", "ах вот что", "ах вон что"],
    "ахав": ["ахавши"],
    "ахавши": ["ахав"],
    "ахайя": ["ахея"],
    "ахалский велаят": ["ашхабадская область"],
    "ахалтекинец": ["аргамак"],
    "ахалухи": ["бешмет"],
    "аханта": ["аанта"],
    "аханье": ["ахание"],
    "ахать": ["охать"],
    "ахборот": ["иттилоот", "хабар", "маълумот"],
    "ахеец": ["ахеянин"],
    "ахен": ["аахен"],
    "ахеронт": ["ахерон", "стикс"],
    "ахея": ["ахайя"],
    "ахи": ["аханье"],
    "ахилл": ["ахиллесово сухожилие", "ахиллово сухожилие"],
    "ахиллес": ["ахилл"],
    "ахиллесово сухожилие": ["ахиллово сухожилие"],
    "ахиллово сухожилие": ["ахиллесово сухожилие"],
    "ахимса": ["ненасилие", "безобидность"],
    "ахмак": ["абдал", "балама", "будала", "серсем", "хапльо"],
    "ахнув": ["ахнувши"],
    "ахнувши": ["ахнув"],
    "ахнуть не успел": ["оглянуться не успел", "глазом моргнуть не успел"],
    "ахондроплазия": ["диафизарная аплазия", "болезнь парро-мари", "врождённая хондродистрофия"],
    "ахриман": ["ариман", "ангро-майнью"],
    "ахромазия": ["ахроматопсия", "монохромазия"],
    "ахроматизировав": ["ахроматизировавши"],
    "ахроматизировавши": ["ахроматизировав"],
    "ахроматизм": ["альбинизм", "ахромазия", "ахроматопия", "ахроматопсия", "монохромазия", "цветовая слепота", "бесцветность"],
    "ахроматический": ["бесцветный", "нецветной", "белый"],
    "ахроматопсия": ["ахромазия"],
    "ахроногнозия": ["ахронозия"],
    "ахронозия": ["ахроногнозия"],
    "ахры": ["ахрысы", "ихтимал", "шаять"],
    "ахрысы": ["ахры", "ихтимал"],
    "ахтер-штевен": ["ахтерштевень"],
    "ахти": ["ахти-хти", "увы"],
    "ахти-хти": ["ахти"],
    "ахтунг": ["внимание", "атас", "осторожно"],
    "ахуй": ["удивление", "недоумение", "ахер", "охуение", "охуенье", "охуевание", "охуеванье", "ступор", "шок"],
    "ахулиард": ["дохулион", "охулион", "зиллион"],
    "ахура мазда": ["ахура-мазда"],
    "ахурамазда": ["ормазд", "ормузд"],
    "ацеллюлярный": ["бесклеточный"],
    "ацервулома": ["псаммома"],
    "ацетальдегид": ["уксусный альдегид", "этаналь"],
    "ацетальфосфатид": ["плазмалоген"],
    "ацетаминофен": ["парацетамол"],
    "ацетат": ["ацетатное волокно"],
    "ацетиламинофенетол": ["фенацетин"],
    "ацетилен": ["этин", "диметенил"],
    "ацетилировав": ["ацетилировавши"],
    "ацетилировавши": ["ацетилировав"],
    "ацетилсалициловая кислота": ["аспирин"],
    "ацетилхолин": ["ацх"],
    "ацетифировав": ["ацетифировавши"],
    "ацетифировавши": ["ацетифировав"],
    "ацетоксильная группа": ["ацетат-ион", "ацетоксигруппа"],
    "ацетолиз": ["ацидолиз"],
    "ацетон": ["диметилкетон", "пропанон"],
    "ацетоновый": ["диметилкетоновый"],
    "ацетофенол": ["метилфенилилкетон"],
    "ацетофенон": ["метилфенилкетон"],
    "ацефалия": ["ацефализм", "безголовость"],
    "ацидиметр": ["кислотомер"],
    "ациклический": ["алифатический"],
    "ацикловир": ["зовиракс"],
    "ацилировав": ["ацилировавши"],
    "ацилировавши": ["ацилировав"],
    "ацильный": ["ациловый"],
    "ациформа": ["аци-форма"],
    "ачарпан": ["ачарпын"],
    "ачарпын": ["ачарпан"],
    "ачдагъа": ["адждагъа", "аджыдахъыр", "аджыдахы", "аздагъа", "ацдагъа"],
    "ачей": ["може", "можливо", "мабуть", "либонь", "певно", "напевно", "допевно", "очевидно", "видно", "видко", "очевидячки", "очевидьки", "пак", "паки", "май"],
    "ачехский": ["ачех"],
    "ачивка": ["ачива", "понт"],
    "ачид": ["тон"],
    "ачиз": ["со"],
    "ачим": ["мон"],
    "ачкъыч": ["ачхыч"],
    "ачлык": ["кытлык", "ачыгу"],
    "ачлыкъ": ["ачлых"],
    "ачлых": ["ачлыкъ"],
    "ачхыч": ["ачкъыч"],
    "ачы": ["аджы"],
    "аш ков": ["аш коза"],
    "аш коза": ["аш ков"],
    "аш мъзярда": ["аф ётка"],
    "аш-су": ["аш", "ашамлык"],
    "ашанти": ["ашантиец"],
    "ашвар": ["швар"],
    "ашвилл": ["эшвилл"],
    "ашдод": ["азот"],
    "ашка": ["ашник", "ашница"],
    "ашказаны": ["карын"],
    "ашкелон": ["аскалан", "аскалон"],
    "ашкеназ": ["аскеназ"],
    "ашкенази": ["ашкеназ", "ашкеназы"],
    "ашкеназка": ["ашкенази"],
    "ашлык": ["иген"],
    "ашмедай": ["асмодей", "сидонай"],
    "ашрам": ["ашрама"],
    "ашрама": ["ашрам"],
    "ашроф": ["асилзода", "аъён"],
    "аштанга-йога": ["раджа-йога"],
    "ашхабад": ["асхабад", "полторацк"],
    "ашхабадец": ["асхабадец"],
    "аще": ["если", "ежели", "коли"],
    "ащемс": ["улемс", "ладямс", "улемс ронговат"],
    "аълтон": ["аълтан"],
    "аъён": ["ашроф", "асилзода"],
    "аьла": ["алдар", "мирза", "тавади"],
    "аэмоциональный": ["безэмоциональный"],
    "аэратор": ["разрыхлитель"],
    "аэрация": ["аэрирование"],
    "аэренхима": ["эренхима"],
    "аэрировав": ["аэрировавши"],
    "аэрировавши": ["аэрировав"],
    "аэрирование": ["аэрация"],
    "аэро-": ["воздухо-", "авиа-"],
    "аэроагентство": ["авиаагентство"],
    "аэроб": ["оксибионт"],
    "аэробика": ["ритмическая гимнастика"],
    "аэробоксинг": ["фитбокс", "кикаэробик"],
    "аэробомба": ["авиабомба"],
    "аэрогенный": ["аэрогеновый"],
    "аэрограф": ["пульверизатор", "краскопульт", "аэрометеорограф"],
    "аэродинамика": ["газодинамика", "гидроаэродинамика"],
    "аэродинамический": ["газодинамический"],
    "аэродром": ["лётное поле"],
    "аэрозоль": ["спрей"],
    "аэроионизировав": ["аэроионизировавши"],
    "аэроионизировавши": ["аэроионизировав"],
    "аэрокоагулятор": ["аэротенк"],
    "аэролак": ["эмалит"],
    "аэромаммография": ["пневмомаммография"],
    "аэрометеорограф": ["аэрограф"],
    "аэромеханика": ["газодинамика", "газовая динамика"],
    "аэромобильный": ["авиамобильный"],
    "аэромост": ["авиасообщение"],
    "аэронавт": ["воздухоплаватель", "лётчик"],
    "аэроопрыскиватель": ["авиаопрыскиватель"],
    "аэропатия": ["метеопатия"],
    "аэроплан": ["самолёт"],
    "аэропланктон": ["аэробиосестон", "атмобиос"],
    "аэроплановый": ["аэропланный"],
    "аэропланъ": ["самолетъ"],
    "аэропорт": ["аэродром", "воздушная гавань", "аэрогавань"],
    "аэропресс": ["френч-пресс"],
    "аэросаккулит": ["аэроцистит"],
    "аэросани": ["снегоход"],
    "аэросев": ["авиасев"],
    "аэросил": ["оксил"],
    "аэростат": ["воздушный шар"],
    "аэротакси": ["авиатакси"],
    "аэротанк": ["аэротенк"],
    "аэротатуировав": ["аэротатуировавши"],
    "аэротатуировавши": ["аэротатуировав"],
    "аэротенк": ["аэротанк", "аэрокоагулятор"],
    "аэротермотерапия": ["аэротеплолечение"],
    "аэротэнк": ["аэротанк"],
    "аэрофил": ["облигатный аэроб"],
    "аэрофоб": ["авиа-трус"],
    "аэрофотоаппарат": ["афа"],
    "аэрофотогеодезия": ["аэрофототопография"],
    "аэрофотослужба": ["афс"],
    "аэрофотосъёмка": ["аэрофотографирование"],
    "аэрофототопография": ["аэрофотогеодезия"],
    "аэроход": ["судно на воздушной подушке", "ховеркрафт"],
    "аэрохоккей": ["настольный хоккей"],
    "аэроцистит": ["аэросаккулит"],
    "аэрошоу": ["авиашоу"],
    "аэроэлектрофорез": ["аэроионофорез"],
    "аэроэмболия": ["воздушная эмболия"],
    "аэс": ["атомная электростанция"],
    "аю-даг": ["аюдаг", "медведь-гора"],
    "аюга": ["живучка"],
    "аюдаг": ["аю-даг", "медведь-гора"],
    "аюшки": ["аушки", "ась"],
    "ба": ["ух ты", "опа", "опа-на"],
    "ба сар бурдан": ["умр дидан", "зистан"],
    "бааба": ["баабай"],
    "баабай": ["эсэгэ"],
    "баабыр": ["тиигир"],
    "баал": ["бел", "бааль", "ваал"],
    "баан": ["банк"],
    "баба": ["женщина", "тётка", "бабец", "смердка", "простолюдинка", "крестьянка", "бабушка", "бабуся", "бабуля", "снежная баба", "снеговик", "каменная баба", "истукан", "тряпка", "акушерка"],
    "баба с яйцами": ["бой-баба", "железная леди", "мужик в юбке", "баба", "тряпка", "буч", "кобёл"],
    "баба-яга": ["бабка-ёжка"],
    "бабай": ["бука", "бармалей", "ростовщик", "чурка"],
    "бабайка": ["бука", "образина", "чудовище", "чудище", "страшилище", "монстр"],
    "бабак": ["байбак", "хомяк"],
    "бабаковий": ["байбаковий"],
    "бабакош": ["пеликан"],
    "бабанка": ["мъжага", "шишко", "здравеняк", "едър"],
    "бабассу": ["бабасу"],
    "бабасу": ["бабассу"],
    "бабах": ["бах", "бум"],
    "бабахав": ["бабахавши"],
    "бабахавши": ["бабахав"],
    "бабахнув": ["бабахнувши"],
    "бабахнувши": ["бабахнув"],
    "бабачок": ["байбачок"],
    "баббитный": ["баббитовый"],
    "бабезиеллёз": ["бабезиоз"],
    "бабезиоз": ["бабезиеллёз"],
    "бабец": ["бабёнка", "тёлка"],
    "бабешки": ["старешки", "вдетинен", "изкуфял"],
    "бабив": ["бабивши"],
    "бабивши": ["бабив"],
    "бабий": ["женский", "бабский"],
    "бабин": ["бабкин", "бабусин", "бабушкин"],
    "бабить": ["повивать", "лекарить", "знахарить"],
    "бабка": ["бабушка", "старуха", "знахарка", "повитуха", "повивальная бабка", "патрульщик"],
    "бабка надвое сказала": ["бабушка надвое сказала"],
    "бабка-повитуха": ["повивальница", "повивальщица", "приемница", "повивальная бабка", "бабка-пупорезница"],
    "бабки зашибать": ["зашибать бабки"],
    "бабки подбивать": ["бабки подводить", "подбивать бабки"],
    "бабкуватий": ["старуватий", "старкуватий", "зморшкуватий"],
    "бабл-гам": ["бабл-гам-поп", "бабл-гам-рок", "жвачка", "жевачка", "жевательная резинка", "бубль-гум"],
    "бабл-гам-поп": ["бабл-гам", "бабл-гам-рок"],
    "бабл-гам-рок": ["бабл-гам", "бабл-гам-поп"],
    "баблос": ["бабки", "бабло", "бабос"],
    "бабничав": ["бабничавши"],
    "бабничавши": ["бабничав"],
    "бабо": ["отац"],
    "бабоа": ["бабуа"],
    "бабораб": ["подкаблучник"],
    "бабочка": ["мотылёк", "чешуекрылое", "галстук-бабочка"],
    "бабский": ["женский"],
    "бабуа": ["бабоа"],
    "бабулька": ["старушенция"],
    "бабуля": ["бабушка"],
    "бабуся": ["бабушка", "бабуля", "бабулечка", "бабусечка", "бабусенька"],
    "бабуша": ["шлёпанцы"],
    "бабушенция": ["бабулька"],
    "бабушка": ["прародительница", "баба", "бабка", "бабуся", "бабуля", "старушка", "старуха", "бабулька", "старушенция"],
    "бабушка все зубы выпердела": ["бабушка зубы выпердела"],
    "бабушка надвое сказала": ["бабка надвое сказала", "вилами на воде писано", "делить шкуру неубитого медведя"],
    "бабушкин": ["бабин", "бабкин", "бабусин"],
    "бабця": ["бабуня"],
    "бабызвындз": ["бабузфий"],
    "бабье лето": ["золотая осень"],
    "бабьё": ["баба"],
    "баварский язык": ["баериш"],
    "бавл": ["шоша", "пешоб", "мезак"],
    "бавовна": ["бавовник", "вибух"],
    "бавовноочисний": ["бавовноочищувальний"],
    "бавовноочищувальний": ["бавовноочисний"],
    "бавур": ["бавыр"],
    "баг": ["дефект", "глюк"],
    "багаж": ["кладь"],
    "багажный": ["вещевой", "грузовой"],
    "баганда": ["ганда"],
    "багарга": ["карарга"],
    "багата": ["шмат"],
    "багатела": ["ситница"],
    "багатий": ["заможний"],
    "багатоводний": ["багатоводий"],
    "багатоголосий": ["багатоголосний"],
    "багатоголосний": ["багатоголосий"],
    "багет": ["карниз", "французская булка"],
    "багетний": ["багетовий"],
    "багетный": ["багетовый"],
    "багетовий": ["багетний"],
    "багетовый": ["багетный"],
    "багнити": ["бруднити"],
    "багнище": ["багно"],
    "багно": ["мочажина"],
    "багновий": ["болотний", "болотяний"],
    "багнюка": ["багнище"],
    "багорик": ["багорчик"],
    "багорчик": ["багорик"],
    "багратионовск": ["прейсиш-эйлау"],
    "багрев": ["багревши"],
    "багревши": ["багрев"],
    "багреть": ["багроветь"],
    "багрец": ["багрянец", "пурпур"],
    "багрець": ["багрянець"],
    "багрив": ["багривши"],
    "багривши": ["багрив"],
    "багровав": ["багровавши"],
    "багровавши": ["багровав"],
    "багровать": ["багрить"],
    "багровев": ["багровевши"],
    "багровевши": ["багровев"],
    "багроветь": ["багреть"],
    "багровий": ["багряний"],
    "багроволикий": ["багроволицый", "багряноликий", "багрянолицый", "краснолицый"],
    "багроволицый": ["краснолицый"],
    "багровощёкий": ["краснощёкий", "алощёкий", "краснолицый"],
    "багровый": ["багряный", "кроваво-красный", "кровавый", "пунцовый", "пурпурный", "порфировый", "алый", "ярко-красный"],
    "багрянев": ["багряневши"],
    "багряневши": ["багрянев"],
    "багрянеть": ["багроветь"],
    "багрянец": ["багрец"],
    "багрянець": ["багрець"],
    "багрянив": ["багрянивши"],
    "багрянивши": ["багрянив"],
    "багрянить": ["багрить", "обагрять", "багреть", "багряниться"],
    "багряница": ["порфира"],
    "багрянка": ["иглянка", "мурекс"],
    "багрянник": ["багряник", "церцис"],
    "багряноликий": ["багроволикий", "багрянолицый", "багроволицый"],
    "багрянородный": ["порфирородный"],
    "багряный": ["багровый", "кроваво-красный", "кровавый", "ярко-красный", "пунцовый", "пурпурный"],
    "багрянь": ["багрянець"],
    "багульник": ["багун", "багула", "боговник", "болиголов", "душица", "клоповник", "лесной розмарин", "рододендрон даурский"],
    "багъыр": ["жез"],
    "багылырга": ["каралырга"],
    "бад": ["биологически активная добавка"],
    "бадава": ["бесплатно"],
    "баден": ["маркграфство баден", "курфюшество баден", "великое герцогство баден", "республика баден", "земля баден", "южный баден"],
    "бадик": ["клюка"],
    "бадлон": ["бодлон", "водолазка", "битловка"],
    "бадминтон": ["юй-мао-цю", "юй-мао-чю"],
    "бадуй": ["бадуи"],
    "бадыга": ["рыгаловка", "тошниловка"],
    "бадьян": ["иллициум"],
    "баерга": ["батарга"],
    "бажати": ["прагнути", "жадати", "зичити"],
    "баз": ["скотный двор"],
    "база": ["фундамент", "основание", "платформа", "базис", "склад", "хранилище", "опорный пункт"],
    "база данных": ["бд", "датабаза"],
    "базалиома": ["карциноид"],
    "базальтовый": ["застывший", "окаменевший"],
    "базар": ["рынок", "ярмарка"],
    "базарив": ["базаривши"],
    "базаривши": ["базарив"],
    "базарить": ["кричать", "болтать", "базланить", "трындеть", "тарахтеть", "тараторить", "трещать", "тереть"],
    "базарная баба": ["хабалка"],
    "базарничав": ["базарничавши"],
    "базарничавши": ["базарничав"],
    "базарно": ["по-базарному"],
    "базарно-рыночный": ["рыночно-базарный"],
    "базарнокарабулакец": ["карабулакец", "карабулаковец"],
    "базарование": ["торгование"],
    "базгальничав": ["базгальничавши"],
    "базгальничавши": ["базгальничав"],
    "базгальничать": ["повесничать", "дурить"],
    "базей": ["василевс", "басилей", "басилевс", "базилевс"],
    "базидиома": ["базидиокарп"],
    "базилевс": ["василевс", "басилей", "базей", "басилевс"],
    "базилианин": ["василианин"],
    "базилик": ["рейхан", "реган"],
    "базиликатец": ["луканец"],
    "базировав": ["базировавши"],
    "базировавши": ["базировав"],
    "базирование": ["базировка", "базированье"],
    "базировать": ["основывать", "располагать", "размещать"],
    "базировка": ["базирование"],
    "базис": ["экономика", "основа", "основание", "фундамент", "база"],
    "базисный": ["базовый", "основной"],
    "базитония": ["базитонический", "базипетальный"],
    "базитонный": ["базитонический", "базипетальный"],
    "базлав": ["базлавши"],
    "базлавши": ["базлав"],
    "базланив": ["базланивши"],
    "базланивши": ["базланив"],
    "базлыкъ": ["базлых"],
    "базлых": ["базлыкъ"],
    "базовик": ["базовичок"],
    "базовичок": ["базовик"],
    "базовый": ["фундаментальный", "опорный", "основной", "типовой", "базисный"],
    "базовый электорат": ["ядерный электорат"],
    "базона": ["вазанда"],
    "базука": ["шайтан-труба"],
    "баив": ["баивши"],
    "баиваться": ["бояться"],
    "баивши": ["баив"],
    "баиньки": ["бай-бай", "баю-бай"],
    "баиньки-баю": ["баю-бай", "баю-баю", "баю-баю-баю", "баюшки-баю", "баю-баюшки-баю"],
    "баир": ["бърдо", "хълм", "връх", "височина"],
    "бай-бай": ["баю-бай", "баю-баю", "баю-баю-баю", "баюшки-баю", "баю-баюшки-баю"],
    "байбак": ["сурок", "степной сурок", "лежебока", "лентяй", "бездельник"],
    "байбаковий": ["бабаковий"],
    "байборив": ["байборивши"],
    "байборивши": ["байборив"],
    "байга": ["байге"],
    "байге": ["байга"],
    "байда": ["фигня", "хренота", "хренотень", "трёп"],
    "байдара": ["байдарка"],
    "байдарка": ["каяк", "байдара"],
    "байдикувати": ["байдики"],
    "байдужний": ["байдужий"],
    "байк": ["бицикл"],
    "байк-фестиваль": ["байкфест"],
    "байк-шоу": ["байкер-шоу"],
    "байка": ["побасенка"],
    "байкал": ["озеро байкал"],
    "байкало-амурская магистраль": ["бам"],
    "байкер": ["мотоциклист"],
    "байкер-шоу": ["байк-шоу"],
    "байкерша": ["мотоциклистка"],
    "байконур": ["байконыр", "ленинск"],
    "байпас": ["шунт"],
    "байрак": ["буерак"],
    "байрам": ["байран", "бейрам"],
    "байрейт": ["байройт", "байрёйт"],
    "байрес": ["буэнос-айрес", "город добрых ветров"],
    "байройт": ["байрёйт", "байрейт"],
    "байрёйт": ["байройт", "байрейт"],
    "байстрюк": ["бастард", "ублюдок"],
    "байт-код": ["псевдокод"],
    "байтер": ["плагиатор"],
    "байтив": ["байтивши"],
    "байтивши": ["байтив"],
    "байтить": ["плагиатить"],
    "байховый": ["рассыпной"],
    "байхуа": ["гоюй", "путунхуа"],
    "байцаа": ["байцай"],
    "байцевав": ["байцевавши"],
    "байцевавши": ["байцевав"],
    "бак": ["ёмкость", "чан"],
    "бакалавр": ["адъюнкт-профессор", "доцент", "бачок", "магл"],
    "бакановый": ["ярко-красный"],
    "бакаут": ["бакаутовое дерево", "железное дерево"],
    "бакаутный": ["бакаутовый"],
    "бакаутовый": ["бакаутный"],
    "бакбо": ["тонкин"],
    "бакелит": ["полиоксибензилметиленгликольангидрид", "карболит"],
    "бакемоно": ["обаке"],
    "бакен": ["бакан"],
    "бакенбарда": ["баки", "бакены"],
    "бакенник": ["бакенщик"],
    "баки": ["бакенбарда", "бакен"],
    "баклава": ["пахлава"],
    "баклага": ["баклажка", "фляга"],
    "баклажан": ["растение", "паслён", "синенькие"],
    "баклажан помидорович": ["сидор поликарпыч", "укроп помидорович", "уксус помидорович"],
    "баклажанный": ["баклажановый"],
    "баклажановый": ["баклажанный"],
    "баклан": ["чувак", "мужчина"],
    "бакланив": ["бакланивши"],
    "бакланивши": ["бакланив"],
    "баклушничав": ["баклушничавши"],
    "баклушничавши": ["баклушничав"],
    "баклушничать": ["бить баклуши"],
    "баклёшка": ["уклейка"],
    "бакминстерфуллерен": ["бакибол"],
    "баконго": ["конго"],
    "бактериальный": ["бактерийный"],
    "бактериемия": ["бактериэмия"],
    "бактеризовав": ["бактеризовавши"],
    "бактеризовавши": ["бактеризовав"],
    "бактериолог": ["микробиолог"],
    "бактериологический": ["бактериальный"],
    "бактериофаготерапия": ["фаготерапия"],
    "бактериофобия": ["бациллофобия", "верминофобия", "вермифобия"],
    "бактериурия": ["бациллурия"],
    "бактерицидный": ["антибактериальный"],
    "бактериэмия": ["бактериемия"],
    "бактерия": ["эубактерия", "эубактерии"],
    "бактриан": ["двугорбый верблюд"],
    "бакун": ["махорка"],
    "бакър": ["мед", "медник"],
    "бакърджия": ["медникар", "казанджия"],
    "бакэмоно": ["обакэ"],
    "бакэнэко": ["бакенеко"],
    "бала-чага": ["балалар"],
    "балабайка": ["балалайка"],
    "балабайт": ["балабуст"],
    "балабан": ["баламан", "дудук", "балобан"],
    "балабол": ["балаболка", "болтун", "пустозвон", "трепач"],
    "балаболив": ["балаболивши"],
    "балаболивши": ["балаболив"],
    "балаболить": ["болтать", "празднословить", "суесловить", "балабонить", "пустословить", "пустозвонить", "молоть языком", "трепаться", "тараторить", "выбалтывать"],
    "балаболка": ["болтун", "болтушка"],
    "балабольство": ["пустозвонство", "болтовня"],
    "балабон": ["балаболка", "колокол"],
    "балабонив": ["балабонивши"],
    "балабонивши": ["балабонив"],
    "балабонить": ["тараторить", "лопотать", "стрекотать", "щебетать", "болтать", "чесать", "молоть", "городить"],
    "балабошив": ["балабошивши"],
    "балабошивши": ["балабошив"],
    "балабуст": ["балабайт"],
    "балаган": ["шутовство"],
    "балаганив": ["балаганивши"],
    "балаганивши": ["балаганив"],
    "балаганничав": ["балаганничавши"],
    "балаганничавши": ["балаганничав"],
    "балаганный": ["шутовской"],
    "балагур": ["шутник", "затейник", "потешник", "весельчак", "забавник"],
    "балагурив": ["балагуривши"],
    "балагуривши": ["балагурив"],
    "балагурство": ["зубоскальство", "шутовство", "насмешничанье", "подшучивание", "насмехательство", "остроумничанье", "хохмачество"],
    "балагурствовав": ["балагурствовавши"],
    "балагурствовавши": ["балагурствовав"],
    "балагурствовать": ["балагурить"],
    "балакав": ["балакавши"],
    "балакавши": ["балакав"],
    "балакать": ["говорить"],
    "балакенский район": ["белоканский район"],
    "балаклава": ["пасамонтана", "пасамонтанья"],
    "балалаечка": ["балалайка"],
    "балалаечник": ["балалайщик"],
    "балалайка": ["балабайка"],
    "балалайщик": ["балалаечник"],
    "баламутив": ["баламутивши"],
    "баламутивши": ["баламутив"],
    "баламутить": ["мутить", "взбалтывать", "смущать"],
    "баламутный": ["беспокойный", "буйный", "взбалмошный"],
    "баланда": ["бурда"],
    "баланец": ["баланс", "равновесие", "баланц"],
    "баланс": ["равновесие", "бухгалтерский баланс"],
    "балансборд": ["индоборд"],
    "балансир": ["баланс"],
    "балансировав": ["балансировавши"],
    "балансировавши": ["балансировав"],
    "балансёрка": ["акробатка", "эквилибристка"],
    "баланц": ["баланс", "баланец"],
    "баларужина": ["баларужинка", "лужа"],
    "балахнинец": ["балахонец"],
    "балахон": ["хламида", "пыльник", "халат"],
    "балахонец": ["балахнинец"],
    "балачак": ["балалык"],
    "балбера": ["ширка", "гагара", "наплав", "фуньга"],
    "балбес": ["обалдуй", "балда"],
    "балбеска": ["балда", "обалдуй"],
    "балбесничав": ["балбесничавши"],
    "балбесничавши": ["балбесничав"],
    "балбесъ": ["балда", "дуракъ", "обалдуй"],
    "балда": ["молот-балда", "молотища", "кувалда", "кулак", "кривулина"],
    "балда ивановна": ["тупица", "балда", "пизда ивановна", "пиздула ивановна"],
    "балда осиновая": ["бестолочь"],
    "балда стоеросовая": ["бестолковщина"],
    "балдев": ["балдевши"],
    "балдевши": ["балдев"],
    "балдеть": ["обалдевать", "тупеть", "тащиться", "кайфовать"],
    "балдой": ["нетрезвый", "хмельной", "поддатый", "бухой", "под банкой", "вполсвиста", "на бровях", "ужратый", "глаза залил", "подшофе"],
    "балдёж": ["кайф"],
    "балдёжник": ["бездельник", "лентяй"],
    "бале": ["оре"],
    "балеарские острова": ["балеары"],
    "балеары": ["балеарские острова"],
    "балерун": ["балерон", "танцор балета", "танцовщик балета", "артист балета", "балетчик"],
    "балет": ["хореография"],
    "балетмейстер": ["хореограф"],
    "балетчица": ["балерина"],
    "баливав": ["баливавши"],
    "баливавши": ["баливав"],
    "балира": ["эмбалира", "андорра", "бабалира", "балир"],
    "балка": ["брус"],
    "балканабад": ["балканабат", "небит-даг", "нефте-даг"],
    "балканист": ["балкановед", "балканолог"],
    "балканистика": ["балкановедение", "балканология"],
    "балканский велаят": ["красноводская область", "балканская область"],
    "балканский полуостров": ["балканы"],
    "балканы": ["стара-планина", "гем", "балканский полуостров"],
    "балкар": ["балкарец"],
    "балкарец": ["балкар"],
    "балкер": ["навалочник", "сухогруз"],
    "балки": ["лекин", "вале", "аммо"],
    "балл": ["оценка", "единица", "пункт", "очко", "деление"],
    "балласт": ["обуза", "балластное сопротивление"],
    "балластировав": ["балластировавши"],
    "балластировавши": ["балластировав"],
    "балластирование": ["балластировка"],
    "балластировка": ["балластирование"],
    "баллиста": ["катапульта"],
    "баллон": ["камера"],
    "баллоник": ["баллонный ключ"],
    "баллонный ключ": ["баллоник"],
    "баллотировав": ["баллотировавши"],
    "баллотировавши": ["баллотировав"],
    "баллотирование": ["баллотировка"],
    "баллотировать": ["голосовать"],
    "баллотировка": ["голосование", "баллотирование", "выборы", "избрание"],
    "балльник": ["табель"],
    "бало": ["мусибат", "фалокат"],
    "баловав": ["баловавши"],
    "баловавши": ["баловав"],
    "баловать": ["изнеживать", "потакать", "баловаться", "шалить"],
    "баловаться": ["шалить", "озорничать", "проказничать", "распутничать", "баловать", "лакомиться"],
    "баловаться под хвостик": ["под хвостик баловаться"],
    "баловень": ["любимец", "баловник", "шалун"],
    "баловень судьбы": ["везунчик", "счастливец", "избранник судьбы"],
    "баловливый": ["баловной"],
    "баловник": ["озорник", "пострелёнок", "проказник", "сорванец", "шалун", "волокита"],
    "баловница": ["шаловница"],
    "баловной": ["озорной", "проказливый", "баловливый", "шкодливый", "озороватый", "избалованный", "набалованный", "шаловливый"],
    "баловство": ["шалость", "озорство", "дурачество", "забава", "игра", "распутство"],
    "балок": ["вагончик"],
    "балочний": ["балковий"],
    "балтачы": ["балта остасы"],
    "балтец": ["балтянин"],
    "балтиец": ["балтфлотец", "прибалтиец", "прибалт"],
    "балтийское море": ["балтика", "варяжское море", "свейское море", "остзейское море", "балтическое море"],
    "балтика": ["балтийское море", "варяжское море"],
    "балтывав": ["балтывавши"],
    "балтывавши": ["балтывав"],
    "балтянин": ["балтец"],
    "балуба": ["луба"],
    "балугъ": ["чавахъ"],
    "балухи": ["баньки"],
    "балцык": ["балчых"],
    "балчук": ["базар", "рынок", "торг"],
    "балычный": ["балыковый"],
    "балыш": ["жаздык"],
    "бальзам на душу": ["как маслом по сердцу"],
    "бальзам-ополаскиватель": ["кондиционер"],
    "бальзамин": ["недотрога"],
    "бальзаминный": ["бальзаминовый"],
    "бальзамировав": ["бальзамировавши"],
    "бальзамировавши": ["бальзамировав"],
    "бальзамирование": ["мумификация", "мумифицирование"],
    "бальзамировать": ["мумифицировать"],
    "бальзамировка": ["бальзамирование"],
    "бальзамировщик": ["бальзамист"],
    "бальзамний": ["бальзамовий"],
    "бальзамный": ["бальзамический"],
    "бальзамовий": ["бальзамний"],
    "бальнеологический": ["бальнеальный", "водолечебный", "грязелечебный"],
    "бальнеология": ["бальнеотерапия", "водолечение", "грязелечение"],
    "бальнеотерапия": ["водолечение"],
    "балюстрада": ["балясник", "обнос", "перила"],
    "балякав": ["балякавши"],
    "балякавши": ["балякав"],
    "балянус": ["морской жёлудь"],
    "балясина": ["перекладина"],
    "балясничав": ["балясничавши"],
    "балясничавши": ["балясничав"],
    "балясы": ["балясина"],
    "бамана": ["бамбара"],
    "бамбара": ["бамана", "банмана", "бамананкан"],
    "бамбошка": ["бомбошка"],
    "бамбучив": ["бамбучивши"],
    "бамбучивши": ["бамбучив"],
    "бамбучить": ["перекуривать"],
    "бамия": ["окра", "гомбо", "дамские пальчики"],
    "бамкав": ["бамкавши"],
    "бамкавши": ["бамкав"],
    "бамканье": ["звяканье"],
    "бамкать": ["звонить", "звякать"],
    "бамкнув": ["бамкнувши"],
    "бамкнувши": ["бамкнув"],
    "бамкнуть": ["звякнуть"],
    "бамр": ["нбамр"],
    "банально": ["заурядно", "обыкновенно"],
    "банальность": ["обыденность", "обычность", "обыкновенность", "типичность", "трюизм", "тривиальность", "клише", "простота", "примитивность"],
    "банальный": ["заурядный", "тривиальный", "обычный", "пошлый", "избитый", "неоригинальный", "совковый"],
    "бананник": ["банан"],
    "бананоед": ["турако"],
    "банг": ["нашъа"],
    "бангалор": ["бенгалуру"],
    "бангалорец": ["бангалурец"],
    "бангалурец": ["бангалорец", "бенгалурец"],
    "бангкок": ["крунгтеп", "азиатская венеция"],
    "бангладеш": ["народная республика бангладеш"],
    "бангладешец": ["бенгалец"],
    "банда": ["шайка", "шайка-лейка", "ватага", "бэнд", "бенд"],
    "бандажировав": ["бандажировавши"],
    "бандажировавши": ["бандажировав"],
    "банданец": ["бандалезец"],
    "бандар-лог": ["бандарлог", "бандерлог"],
    "бандарлог": ["бандар-лог", "бандерлог"],
    "бандарша": ["бандитка"],
    "бандера": ["бандеровцы", "бандерлог", "мазепа", "хохлы"],
    "бандера-смузи": ["коктейль молотова"],
    "бандерлог": ["бандар-лог", "бандарлог"],
    "бандеролировав": ["бандеролировавши"],
    "бандеролировавши": ["бандеролировав"],
    "бандероль": ["бандяк"],
    "бандеромобиль": ["техничка", "бандер-мобиль"],
    "бандерша": ["сутенёрша", "сводня", "бандитка"],
    "банджи-джампинг": ["тарзанка"],
    "бандит": ["гангстер", "разбойник", "ухорез", "бандос", "проказник"],
    "бандитка": ["грабительница", "налётчица"],
    "бандитский": ["разбойничий", "разбойнический", "разбойный", "гангстерский", "пиратский", "воровской"],
    "бандитствовав": ["бандитствовавши"],
    "бандитствовавши": ["бандитствовав"],
    "бандо": ["фероньерка", "бандана"],
    "бандюк": ["бандит", "бандюган"],
    "банебджедет": ["банебджед"],
    "банзай-атака": ["психическая атака", "штыковая атака"],
    "баниан": ["баньян"],
    "баниановый": ["баньяновый"],
    "банив": ["банивши"],
    "банивши": ["банив"],
    "банить": ["блокировать"],
    "банк": ["банчок", "хранилище"],
    "банк-агент": ["банк-корреспондент"],
    "банкаброш": ["банкоброш"],
    "банкаброшница": ["ровничница"],
    "банкетний": ["бенкетний"],
    "банкир": ["банкирчик", "банкирёнок", "банкирёныш", "ростовщик", "банковский", "работник"],
    "банкирша": ["ростовщица"],
    "банкнот": ["банкнота"],
    "банкнота": ["банковский билет", "банковый билет", "банкнот", "купюра", "ассигнация"],
    "банкоброш": ["банкаброш"],
    "банковав": ["банковавши"],
    "банковавши": ["банковав"],
    "банковать": ["метать", "держать банк"],
    "банковская гарантия": ["кредитная гарантия"],
    "банковский конфискат": ["конфискат"],
    "банковый": ["банковский"],
    "банкоматный": ["банкоматовский"],
    "банкоматовский": ["банкоматный"],
    "банкоматский": ["банкоматный"],
    "банкомёт": ["дилер", "крупье"],
    "банкрот": ["должник", "неплательщик", "несостоятельный", "банкрут", "неудачник"],
    "банкротив": ["банкротивши"],
    "банкротивши": ["банкротив"],
    "банкротить": ["обанкрочивать"],
    "банкротный": ["банкротский"],
    "банкротство": ["неплатёжеспособность", "разорение"],
    "банкротствовав": ["банкротствовавши"],
    "банкротствовавши": ["банкротствовав"],
    "банкрут": ["банкрот", "должник", "неплательщик", "несостоятельный", "неудачник"],
    "банкёр": ["банкир", "банковщик", "банкомёт"],
    "банлон": ["водолазка"],
    "банный": ["тёплый", "влажный", "баенный", "баенник", "банный чёрт", "жаркий", "разгорячённый"],
    "банный губернатор": ["банщик", "мишка-банщик"],
    "банчив": ["банчивши"],
    "банчивши": ["банчив"],
    "банчить": ["барыжить", "толкать"],
    "банши": ["баньши"],
    "баньши": ["банши"],
    "баньян": ["баниан", "фикус бенгальский", "индийская смоковница", "фараонова фига", "дерево будды"],
    "баня": ["мыльня", "трёпка", "нагоняй", "выволочка", "разнос"],
    "банялаори": ["баняори"],
    "бапси": ["баки", "баси"],
    "бапски": ["бабин"],
    "баптизм": ["баптистское движение", "баптистское течение"],
    "баптистерий": ["крещальня"],
    "бар": ["биполярное расстройство", "биполярное аффективное расстройство", "маниакально-депрессивное расстройство", "маниакально-депрессивный психоз", "мдп"],
    "бар абас рафтан": ["абас рафтан"],
    "бара": ["болото"],
    "барабан": ["слуховой барабан"],
    "барабанив": ["барабанивши"],
    "барабанивши": ["барабанив"],
    "барабашка": ["домовой", "полтергейст", "домовёнок"],
    "бараболя": ["картопля"],
    "барабошив": ["барабошивши"],
    "барабошивши": ["барабошив"],
    "барабулька": ["султанка"],
    "барабуля": ["козлобородка"],
    "барав": ["баравши"],
    "баравши": ["барав"],
    "барагозив": ["барагозивши"],
    "барагозивши": ["барагозив"],
    "барагозить": ["бычить", "бузить", "буянить", "скандалить", "дебоширить"],
    "барак": ["казарма", "блок", "отделение"],
    "барал я тебя в грызло": ["ебал я тебя в грызло"],
    "баранка": ["рулевое колесо", "руль", "ноль", "нуль"],
    "баранки гну": ["хуй гну", "хуи гну"],
    "барановирус": ["ковид", "коронавирус", "корона", "ковидла", "коронавир"],
    "баранта": ["барымта"],
    "баранчик": ["баранчики"],
    "бараски": ["айнакюнь"],
    "барахлив": ["барахливши"],
    "барахливши": ["барахлив"],
    "барахлить": ["сбоить", "капризничать"],
    "барахло": ["хлам", "пожитки", "вещи", "скарб", "дрянь"],
    "барахолив": ["барахоливши"],
    "барахоливши": ["барахолив"],
    "барахолка": ["толкучка"],
    "барахольщик": ["старьёвщик"],
    "барахольщица": ["старьёвщица"],
    "барахтание": ["барахтанье"],
    "барахтанье": ["барахтание"],
    "барахтаться": ["бултыхаться"],
    "барашек": ["ягнёнок", "бяшка", "куркуль"],
    "барашковый": ["овечий", "каракулевый", "кучевой", "кудрявый", "кучерявый"],
    "барбадос": ["республика барбадос"],
    "барбадосец": ["бажан"],
    "барбакан": ["барбикан"],
    "барбарисный": ["барбарисовый"],
    "барбарисовый": ["барбарисный"],
    "барбат": ["барбет"],
    "барбатзан": ["барбатнавоз"],
    "барбатнавоз": ["барбатзан"],
    "барбекю": ["барбекюшница"],
    "барбекюшница": ["барбекю"],
    "барбершоп": ["цирюльня"],
    "барбет": ["барбат"],
    "барбитуровая кислота": ["малонилмочевина", "солодовый сахар"],
    "барбос": ["дворняга", "дворняжка", "шавка"],
    "барботаж": ["барботирование", "бульбуляция"],
    "барботировав": ["барботировавши"],
    "барботировавши": ["барботировав"],
    "барботирование": ["барботаж"],
    "барботёр": ["пробулькиватель"],
    "барвавець": ["чырванець"],
    "барвити": ["забарвлювати"],
    "барвний": ["барвистий"],
    "баргузин": ["баргузник", "верховик", "север"],
    "бард": ["акын", "автор-исполнитель"],
    "бардак": ["беспорядок", "неразбериха", "публичный дом", "бордель", "дом терпимости", "блудилище"],
    "бардачив": ["бардачивши"],
    "бардачивши": ["бардачив"],
    "бардачок": ["перчаточный ящик"],
    "бардовский": ["авторский"],
    "бардовый": ["бардовский"],
    "баренцево море": ["баренц", "мурманское море", "русское море"],
    "баржевой": ["барженый", "баржевый"],
    "бари-": ["баро-"],
    "барибал": ["чёрный медведь"],
    "барин": ["господин", "богач", "белоручка"],
    "бариста": ["кофевар"],
    "барит": ["тяжелый шпат"],
    "баритися": ["гаятися"],
    "баритовый": ["баристый"],
    "баритоновый": ["баритонный"],
    "барицентр": ["центр масс", "центр инерции", "центр тяжести"],
    "барический": ["барометрический"],
    "баркан": ["баракан"],
    "баркарола": ["гондольера"],
    "баркас": ["гашпиль"],
    "баркентина": ["шхуна-барк"],
    "бармалей": ["негодяй", "говнюк", "исламист"],
    "бармен": ["трактирщик"],
    "бармица": ["койф"],
    "баро": ["учё", "грубо", "взросло"],
    "баро-": ["бари-"],
    "бароаппарат": ["барокамера"],
    "барокко": ["барочный"],
    "барокомплекс": ["бароцентр"],
    "барометр": ["индикатор"],
    "баронша": ["баронесса"],
    "барорецептор": ["прессорецептор", "волюморецептор"],
    "бароскоп": ["штормгласс", "камфоргласс", "склянка фицроя", "штормовая склянка"],
    "бароцентр": ["барокомплекс"],
    "барраж": ["шперрунг"],
    "барражировав": ["барражировавши"],
    "барражировавши": ["барражировав"],
    "барражировать": ["кружить", "кружиться", "крутиться", "вертеться", "ошиваться", "околачиваться"],
    "барражирующий боеприпас": ["дрон-камикадзе"],
    "барракуда": ["морская щука"],
    "баррамунда": ["рогозуб"],
    "баррель": ["бочка"],
    "баррикадировав": ["баррикадировавши"],
    "баррикадировавши": ["баррикадировав"],
    "барс": ["леопард", "снежный барс", "ирбис"],
    "барселона": ["барса"],
    "барски": ["по-барски"],
    "барский": ["господский"],
    "барской курице племянник": ["генеральской курице племянник", "барской курицы племянник"],
    "барствовав": ["барствовавши"],
    "барствовавши": ["барствовав"],
    "барсуков": ["барсуковый", "барсучий", "барсучиный"],
    "барсучонок": ["барсучок"],
    "барт": ["бартоломью", "бартоломей", "варфоломей"],
    "бартер": ["обмен"],
    "бартолинов проток": ["большой подъязычный проток"],
    "бартолинова железа": ["большая железа преддверия"],
    "барунец": ["барунхемчикец"],
    "барунхемчикец": ["барунец"],
    "барух": ["варух", "берехия"],
    "бархат амурский": ["бархатное дерево", "феллодендрон амурский"],
    "бархатец": ["бархатка", "бархотка"],
    "бархатистость": ["бархатность"],
    "бархатка": ["бархотка", "большая буроглазка", "печальная краеглазка", "бархатец"],
    "бархатно": ["бархатисто"],
    "бархатно-чёрный": ["чёрно-бархатный"],
    "бархатное дерево": ["бархат амурский", "пробковое дерево", "феллодендрон амурский"],
    "бархотка": ["бархатка", "чокер"],
    "бархоут": ["вельс"],
    "барчонок": ["барчук"],
    "барчук": ["барчонок"],
    "барщинный": ["барщинский"],
    "барщинский": ["барщинный"],
    "барыга": ["перекупщик", "спекулянт", "торгаш"],
    "барыжив": ["барыживши"],
    "барыживши": ["барыжив"],
    "барыжить": ["торговать"],
    "барыжничав": ["барыжничавши"],
    "барыжничавши": ["барыжничав"],
    "барыжничать": ["барыжить"],
    "барысы": ["бары"],
    "барыш": ["прибыль"],
    "барышничав": ["барышничавши"],
    "барышничавши": ["барышничав"],
    "барышничать": ["перепродавать"],
    "барышный": ["прибыльный"],
    "барышня": ["девушка", "девочка", "дева", "девица", "барыня", "белоручка", "телефонистка"],
    "бас-бустер": ["бас-буст"],
    "бас-буфф": ["бассо буффо", "комический", "бас"],
    "бас-гитара": ["бас"],
    "бас-гитарист": ["басист"],
    "бас-гитаристка": ["басистка"],
    "басал": ["пиёз"],
    "басалык": ["кистень", "молотило", "навязень"],
    "баселард": ["басселард"],
    "басив": ["басивши"],
    "басивши": ["басив"],
    "басик": ["бассейн", "окурок"],
    "басилевс": ["василевс", "басилей", "базей", "базилевс", "ванакс", "архагет", "тагос"],
    "басилей": ["василевс", "басилевс", "базей", "базилевс"],
    "басист": ["бас"],
    "басистий": ["басовитий"],
    "басисто": ["басовито"],
    "басистый": ["басовитый", "басоватый"],
    "баск": ["басконец"],
    "баскет": ["баскетбол"],
    "баский": ["баской", "клёвый", "классный", "шикарный"],
    "баско": ["зыко", "круто", "классно", "красиво", "лепо"],
    "баской": ["баский"],
    "басколог": ["басковед"],
    "баскский": ["басконский", "эускара"],
    "баслык": ["башлых"],
    "басмачествовав": ["басмачествовавши"],
    "басмачествовавши": ["басмачествовав"],
    "баснописец": ["басенник", "фабулист"],
    "баснословие": ["мифология"],
    "баснословно": ["чрезмерно", "чрезвычайно", "очень"],
    "баснословный": ["басенный", "невероятный", "фантастический", "мифический", "стародавний"],
    "баснь": ["басня"],
    "басня": ["баснь"],
    "басоватый": ["басовитый"],
    "басовитий": ["басистий"],
    "басовито": ["басисто"],
    "басовитость": ["басистость"],
    "басовитый": ["басоватый"],
    "басоля": ["басетля"],
    "басорама": ["бусорама", "автобусорама"],
    "басота": ["баса", "казистость"],
    "басселард": ["баселард"],
    "баст": ["бастет"],
    "баста": ["ноггано"],
    "бастард": ["помесь", "гибрид", "ублюдок"],
    "бастер": ["рехоботер"],
    "бастет": ["баст"],
    "бастея": ["рондель"],
    "бастовав": ["бастовавши"],
    "бастовавши": ["бастовав"],
    "басурман": ["басурманин", "иноверец", "нехристь"],
    "басурманин": ["басурман", "иноверец", "нехристь"],
    "басьтыны": ["басьяськыны"],
    "басьяськыны": ["басьтыны"],
    "бат": ["точка акупунктуры", "электрически активная точка", "китайская точка", "точка воздействия"],
    "батаец": ["батайчанин"],
    "батайчанин": ["батаец"],
    "баталия": ["битва", "война", "потасовка", "сражение", "сеча", "брань", "рать", "побоище", "бойня", "драка", "ссора"],
    "батальон": ["баталион", "дивизион", "много"],
    "батальонная тактическая группа": ["бтг"],
    "батареец": ["артиллерист"],
    "батарейка": ["батарея"],
    "батат": ["сладкий картофель"],
    "батенька": ["голубчик", "батя", "батюшка"],
    "батерстец": ["банжулец"],
    "батиграмма": ["эхограмма"],
    "батин": ["папин", "отцов"],
    "батинча": ["кызанак"],
    "батиплан": ["подводный", "самолёт"],
    "батитермограф": ["термобатиграф"],
    "баткеп": ["бэткап"],
    "батлер": ["мажордом"],
    "батлив": ["батливши"],
    "батливши": ["батлив"],
    "батлить": ["баттлить"],
    "батлиться": ["баттлиться"],
    "батн": ["шикам"],
    "батник": ["пайта", "джемпер"],
    "батог": ["трость", "посох", "шпицрутен"],
    "батожилно": ["пужално"],
    "батожьё": ["батог"],
    "батоми": ["батуми"],
    "батон": ["палка", "буханка"],
    "батонив": ["батонивши"],
    "батонивши": ["батонив"],
    "батониться": ["валяться", "бездельничать"],
    "батопорт": ["ботапорт"],
    "батохромный сдвиг": ["батохромный эффект"],
    "батохромный эффект": ["батохромный сдвиг"],
    "батраковав": ["батраковавши"],
    "батраковавши": ["батраковав"],
    "батрахоспермум": ["лягушечник"],
    "батрацкий": ["батрачий"],
    "батрачив": ["батрачивши"],
    "батрачивши": ["батрачив"],
    "батрачий": ["батрацкий"],
    "батрачина": ["батрачество"],
    "баттлив": ["баттливши"],
    "баттливши": ["баттлив"],
    "баттлить": ["батлить"],
    "баттлиться": ["батлиться"],
    "баттон": ["дилер"],
    "баттхёрт": ["бугурт"],
    "батуд": ["батут"],
    "батум": ["батуми"],
    "батуми": ["батоми", "батум"],
    "батун": ["лук-батун", "батун-лук", "татарка", "ботун", "бутун", "ботовик"],
    "батут": ["батуд"],
    "батый": ["бату"],
    "батыр": ["батырь"],
    "батырлык": ["кыюлык"],
    "батька": ["лука"],
    "батькивщина": ["матькивщина"],
    "батькин": ["отцовский", "батин", "папин", "тятин", "батюшкин", "отцов", "отчий"],
    "батько": ["батька", "батя"],
    "батюшка": ["батька", "батя", "отец", "папа", "старик", "старина"],
    "батюшки": ["ах", "ё-моё"],
    "батюшкин": ["отцов", "отцовский", "папин", "папочкин", "папонькин", "папашин", "папанин", "папкин", "батин", "батькин", "батянин", "тятин", "тятькин"],
    "батя": ["папа", "тятя", "отец", "батюшка"],
    "батяня": ["батя"],
    "батёк": ["отец", "тятя", "батя", "батька", "батяня", "папа", "папаша"],
    "баул": ["торба"],
    "бауманка": ["мгту"],
    "бафомет": ["козёл мендеса", "черный козёл", "козёл иуды"],
    "бафф": ["усиление"],
    "бах": ["бабах", "бух", "бац"],
    "бахав": ["бахавши"],
    "бахавши": ["бахав"],
    "бахаизм": ["бехаизм"],
    "бахание": ["баханье", "бабахание", "бабаханье"],
    "баханье": ["бахание", "бабахание", "бабаханье"],
    "бахаса": ["индонезийский язык"],
    "бахать": ["хлопать", "взрывать"],
    "бахбай": ["ат"],
    "бахвал": ["хвастун"],
    "бахвалиться": ["кичиться", "похваляться", "хвалиться", "хвастать", "хвастаться"],
    "бахила": ["бродни", "болотники"],
    "бахмат": ["маштак", "лошадка", "пони"],
    "бахмут": ["артёмовск"],
    "бахмутская мясорубка": ["артёмовская мясорубка"],
    "бахнув": ["бахнувши"],
    "бахнувши": ["бахнув"],
    "бахрейн": ["королевство бахрейн"],
    "бахтарма": ["изнанка", "испод", "мездра", "сторона"],
    "бахус": ["вакх", "дионис", "либер"],
    "бахчевая тля": ["хлопковая тля"],
    "бахшиш": ["пешкаш"],
    "бахшоиш": ["бахшиш"],
    "бац": ["трясь", "бух"],
    "бацав": ["бацавши"],
    "бацавши": ["бацав"],
    "бацилла": ["палочка", "зараза"],
    "бацилловый": ["бактериальный", "бактерийный"],
    "бациллоносительство": ["заразоносительство"],
    "бацнув": ["бацнувши"],
    "бацнувши": ["бацнув"],
    "бацька": ["айцец"],
    "бацян": ["бусел"],
    "бачив": ["бачивши"],
    "бачивши": ["бачив"],
    "бачок": ["магл"],
    "бачхыч": ["басхыч"],
    "баш на баш": ["тож на тож", "так на так"],
    "башар": ["инсон"],
    "башара": ["рухсора", "симо"],
    "башибузук": ["разбойник", "головорез"],
    "башка": ["голова", "бошка", "ум", "головизна"],
    "башкир": ["башкирец"],
    "башкирия": ["башкортостан"],
    "башкирка": ["башкирская лошадь"],
    "башкирский": ["башкирский язык"],
    "башковитый": ["головастый"],
    "башкортостан": ["башкирия"],
    "башкортостанец": ["башкир"],
    "башланув": ["ичленюв"],
    "башлык": ["капюшон"],
    "башлых": ["баслык"],
    "башляв": ["башлявши"],
    "башлявши": ["башляв"],
    "башлять": ["платить", "оплачивать", "финансировать", "выплачивать", "засылать бабки", "греть лапу", "максать"],
    "башмак": ["ботинок"],
    "башмачник": ["сапожник", "чеботарь"],
    "башмачничав": ["башмачничавши"],
    "башмачничавши": ["башмачничав"],
    "башмачок": ["ботиночек", "туфелька"],
    "башня": ["вышка", "каланча", "точечный дом", "свечка", "столбик"],
    "башта": ["башня", "вежа", "батура", "костер"],
    "баштан": ["бахча"],
    "баштанный": ["бахчевой"],
    "бащиния": ["родина", "татковина", "отечество"],
    "баю-бай": ["бай-бай", "баю-баю", "баю-баю-баю", "баюшки-баю", "баю-баюшки-баю", "баиньки-баю"],
    "баю-баю": ["баю-бай", "бай-бай", "баю-баю-баю", "баюшки-баю", "баю-баюшки-баю"],
    "баю-баю-баю": ["баю-бай", "баю-баю", "бай-бай", "баюшки-баю", "баю-баюшки-баю"],
    "баю-баюшки-баю": ["баю-бай", "баю-баю", "баю-баю-баю", "баюшки-баю", "бай-бай"],
    "баюкав": ["баюкавши"],
    "баюкавши": ["баюкав"],
    "баюкать": ["убаюкивать"],
    "баюшки-баю": ["баю-бай", "баю-баю", "баю-баю-баю", "бай-бай", "баю-баюшки-баю"],
    "баяв": ["баявши"],
    "баявши": ["баяв"],
    "баядера": ["баядерка"],
    "баядерка": ["танцовщица", "танцорка", "плясунья"],
    "баян": ["аккордеон", "боян"],
    "баянистый": ["боянистый"],
    "баять": ["говорить", "рассказывать", "толковать"],
    "баяч": ["знахар", "шарлатанин"],
    "бвк": ["белково-витаминный концентрат"],
    "бгт": ["бутилированный гидрокситолуол"],
    "бгъэжъ": ["мэкъухэшъобгъэжъ"],
    "бдев": ["бдевши"],
    "бдевши": ["бдев"],
    "бделигма": ["абоминация"],
    "бделлотерапия": ["гирудотерапия"],
    "бденье": ["бдение"],
    "бдеть": ["бодрствовать"],
    "бджолиний": ["бджоляний"],
    "бджоляний": ["бджолиний"],
    "бдзэжьей": ["бдзэ"],
    "бдительность": ["внимательность", "зоркость"],
    "бдительный": ["наблюдательный", "зоркий", "внимательный", "предусмотрительный", "осмотрительный", "бодрый", "неусыпный", "недремлющий", "заметливый", "осторожный"],
    "бдящий": ["бодрствующий", "неспящий"],
    "бе": ["бэ"],
    "бебехнути": ["бебевхнути"],
    "беби": ["кроха", "крошка", "малыш", "малышка", "девушка", "бейба", "детка"],
    "бебиситтер": ["няня"],
    "бебрикия": ["вифиния"],
    "бевазан": ["бева"],
    "бевзень": ["бевзь", "дурень", "тупиця", "тупак", "недотепа", "нетяма", "недоумок"],
    "бевзь": ["тютя", "йолоп", "бевзень", "вайло", "бовдур"],
    "бег": ["бегание", "полёт"],
    "бег трусцой": ["джоггинг"],
    "бегав": ["бегавши"],
    "бегавши": ["бегав"],
    "беганье": ["бегание"],
    "бегард": ["беггард", "бегинка", "лоллард"],
    "бегательный": ["беговой"],
    "бегемот": ["гиппопотам"],
    "бегемотный": ["бегемотовый"],
    "бегемотовый": ["бегемотный"],
    "бегивав": ["бегивавши"],
    "бегивавши": ["бегивав"],
    "бегинаж": ["бегейнхоф"],
    "бегинка": ["бегард"],
    "беглая речь": ["беглое произношение"],
    "беглец": ["беглый", "сбеглец", "утеклец", "сбеглый", "дезертир", "беженец", "отшельник", "затворник"],
    "бегло": ["быстро", "свободно", "кратко"],
    "беглопоповщина": ["беглопоповство"],
    "беглость": ["проворность", "мимолётность"],
    "беглый": ["бежавший", "быстрый", "поверхностный", "свободный"],
    "беговатец": ["бекабадец"],
    "беговел": ["балансбайк", "велобег", "велокат", "велокетт", "велосамокат", "велоход", "лауфрад", "ранбайк"],
    "бегом": ["спешно", "срочно", "быстро", "стремительно", "молниеносно", "без заминки", "без промедления", "молнией", "мухой", "пулей", "на всех парах"],
    "бегунок": ["замок", "итератор"],
    "бегущая дорожка": ["беговая дорожка", "тредбан"],
    "бегущая строка": ["телеграфный стиль"],
    "беда": ["несчастье", "бедствие", "горе", "бездолье", "гроза", "злополучие", "катастрофа", "напасть", "невзгода", "невзгодье", "безвременье", "неприятность", "злоключение", "неудача", "затруднение"],
    "бедауйе": ["беджа"],
    "бедбит": ["переезд"],
    "бедекер": ["путеводитель"],
    "бедел": ["абырой"],
    "беден как церковная мышь": ["беден как церковная крыса"],
    "бедж": ["беджик", "бейдж", "бейджик", "бэдж"],
    "беджа": ["бедауйе"],
    "бедиз": ["айкел"],
    "бедин": ["худоношинос"],
    "бедлам": ["монастырь", "госпиталь", "психиатрическая лечебница", "психиатрическая больница", "сумасшедший дом", "хаос", "неразбериха"],
    "бедлингтон": ["бедлингтон-терьер"],
    "бедлингтон-терьер": ["бедлингтон"],
    "беднев": ["бедневши"],
    "бедневши": ["беднев"],
    "бедненько": ["бедно"],
    "бедно": ["скудно", "скупо"],
    "бедность": ["безденежье", "стеснённость"],
    "беднота": ["беднячество", "бедность", "нужда", "недостаток"],
    "бедный": ["неимущий", "малоимущий", "нищий", "небогатый", "нуждающийся", "малообеспеченный", "необеспеченный", "голый", "скудный", "несчастный", "жалкий"],
    "бедняга": ["бедолага", "горемыка", "несчастливец", "несчастливица"],
    "бедняжка": ["бедняга", "бедолага"],
    "бедняк": ["неимущий", "бедняга", "бедолага"],
    "беднячество": ["беднота"],
    "бедовав": ["бедовавши"],
    "бедовавши": ["бедовав"],
    "бедовать": ["бедствовать", "горе мыкать"],
    "бедовый": ["залихватский"],
    "бедокур": ["шалун", "озорник", "проказник"],
    "бедокурив": ["бедокуривши"],
    "бедокуривши": ["бедокурив"],
    "бедокурить": ["проказничать", "озоровать", "шалить"],
    "бедолага": ["бедняга", "горемыка", "несчастливец", "несчастливица"],
    "бедолажный": ["несчастный"],
    "бедро": ["ляжка"],
    "бедственно": ["бедно", "плачевно", "горько", "трагично", "трагически"],
    "бедствие": ["трагедия"],
    "бедствовав": ["бедствовавши"],
    "бедствовавши": ["бедствовав"],
    "бедствовать": ["бедовать"],
    "беж": ["бежевый"],
    "бежав": ["бежавши"],
    "бежавши": ["бежав"],
    "бежать": ["нестись", "мчаться", "торопиться", "спешить", "течь", "струиться", "лететь", "идти", "убегать", "убежать", "сбегать", "сбежать", "отступать", "отступить", "ретироваться"],
    "бежать что есть духу": ["бежать сломя голову", "бежать со всех ног"],
    "бежевий": ["беж"],
    "бежево-жёлтый": ["жёлто-бежевый"],
    "бежевый": ["беж"],
    "бежной конец": ["бежный конец"],
    "бежный конец": ["бежной конец"],
    "без": ["в отсутствие", "при отсутствии", "за вычетом"],
    "без бля": ["честное слово", "без дураков", "без б", "без бэ", "без пизды"],
    "без бутылки не разобраться": ["без пол-литры не разобраться", "без пол-литра не разобраться"],
    "без вариантов": ["однозначно", "точно", "несомненно"],
    "без второго слова": ["без дальних слов", "без лишних слов"],
    "без году неделя": ["недавно", "недолго"],
    "без дальних слов": ["без лишних слов"],
    "без дураков": ["серьёзно"],
    "без души": ["без памяти", "безотчётно"],
    "без задней мысли": ["без всякой задней мысли", "по простоте душевной"],
    "без задних ног": ["беспробудно", "мертвецки"],
    "без исключения": ["изъятие", "остаток", "без разбора", "валом", "подряд", "гурт", "конец", "направо", "налево", "разбирать", "огулом", "огульно", "опт", "полностью", "сплошняк"],
    "без лишних слов": ["без дальних слов"],
    "без милосердия": ["немилосердно"],
    "без ничего": ["без всего"],
    "без обид": ["не бери в голову"],
    "без обиняков": ["напрямую", "прямо", "без околичностей", "откровенно"],
    "без оглядки": ["безоглядно", "быстро", "со всех ног", "во весь дух", "во весь опор", "безрассудно"],
    "без околичностей": ["без обиняков"],
    "без пизды": ["истинно", "несомненно", "однозначно", "точно", "стопроцентно", "без балды"],
    "без поллитры не разберёшься": ["китайская грамота", "чёрт ногу сломит"],
    "без просыпу": ["без просыпа", "не приходя в себя", "непрерывно"],
    "без рук": ["без рук без ног"],
    "без рук без ног": ["без рук"],
    "без смерти смерть": ["скоропостижная смерть"],
    "без спроса": ["без спросу", "самовольно", "своевольно"],
    "без спросу": ["без спроса", "самовольно", "своевольно"],
    "без срока": ["бессрочно", "навсегда", "без сроку"],
    "без сроку": ["бессрочно", "навсегда", "без срока"],
    "без труда": ["запросто", "легко"],
    "без труда не выловишь и рыбку из пруда": ["без труда не вытянешь и рыбку из пруда", "без трудностей нет побед"],
    "без труда не вытянешь и рыбку из пруда": ["без труда не выловишь и рыбку из пруда", "без трудностей нет побед"],
    "без умолку": ["неумолкаемо", "неумолчно", "безумолку", "безумолчно", "безостановочно"],
    "без устали": ["не покладая рук", "как заведённый"],
    "без церемоний": ["бесцеремонно", "запросто"],
    "без шуток": ["кроме шуток"],
    "без яиц": ["яиц нет", "яиц нету"],
    "без-": ["бес-"],
    "безалаберничав": ["безалаберничавши"],
    "безалаберничавши": ["безалаберничав"],
    "безалаберность": ["бестолковость", "расхлябанность", "беспорядочность", "безалаберщина"],
    "безалаберный": ["небрежный", "халатный"],
    "безалаберщина": ["неразбериха", "неорганизованность", "безалаберность"],
    "безалкогольный": ["бесспиртовой", "сухой", "антиалкогольный"],
    "безальтернативно": ["альтернативно"],
    "безальтернативный": ["однозначный", "безвариантный"],
    "безант": ["бизантин"],
    "безапелляционно": ["неоспоримо", "категорично", "догматично"],
    "безапелляционность": ["категоричность"],
    "безапелляционный": ["категоричный", "уверенный", "категорический", "решительный"],
    "безатомный": ["безъядерный", "непрерывный"],
    "безбарвий": ["безбарвний"],
    "безбарвний": ["безбарвий"],
    "безбашенный": ["неосторожный", "безрассудный", "беспечный"],
    "безбилетник": ["заяц"],
    "безбожие": ["атеизм"],
    "безбожник": ["атеист", "неверующий"],
    "безбожница": ["атеистка"],
    "безбожничав": ["безбожничавши"],
    "безбожничавши": ["безбожничав"],
    "безбожный": ["атеистический", "иноверческий", "языческий", "бессовестный", "неимоверный"],
    "безбоязненность": ["смелость", "храбрость", "неустрашимость"],
    "безбоязненный": ["бесстрашный", "смелый"],
    "безбрачие": ["агамия", "целибат", "безбрачье"],
    "безбрачье": ["безбрачие", "агамия", "целибат"],
    "безбрежный": ["безграничный"],
    "безбрежье": ["безбрежие"],
    "безвариантный": ["безальтернативный"],
    "безведрие": ["непогода", "ненастье", "безведреница", "непогодь"],
    "безверие": ["атеизм"],
    "безверник": ["безбожник", "атеист"],
    "безверье": ["безверие"],
    "безвестность": ["неизвестность", "неосведомлённость"],
    "безвестье": ["безвестие"],
    "безветренность": ["безветрие"],
    "безветренный": ["тихий", "спокойный"],
    "безветрие": ["безветрица", "безветренность", "тишь", "затишь", "затишье", "штиль"],
    "безвиз": ["безвизовый режим"],
    "безвизовый режим": ["безвиз"],
    "безвинность": ["неповинность", "невинность", "безвиновность"],
    "безвинный": ["невинный", "невиновный"],
    "безвихревой": ["ламинарный"],
    "безвкусие": ["безвкусица"],
    "безвкусица": ["безвкусие"],
    "безвкусница": ["аксирис"],
    "безвкусье": ["безвкусие"],
    "безвластие": ["анархия", "безначалие"],
    "безвластье": ["безвластие"],
    "безводий": ["безводний"],
    "безводица": ["безводье"],
    "безводний": ["безводий"],
    "безводно": ["безвлажно", "сухо", "засушливо"],
    "безводность": ["засушливость", "сухость"],
    "безводье": ["засуха"],
    "безвозбранно": ["беспрепятственно"],
    "безвозбранность": ["невозбранность"],
    "безвозвратные потери": ["людские потери", "человеческие потери", "безвозвратные демографические потери", "безвозвратные потери в живой силе"],
    "безвозмездно": ["бесплатно", "даром", "за так", "за просто так", "задаром", "за здорово живёшь", "за красивые глаза", "за спасибо", "задарма"],
    "безвозмездный": ["бесплатный", "даровой"],
    "безволие": ["робость", "нерешительность", "бесхарактерность"],
    "безволосость": ["лысость", "плешивость"],
    "безволье": ["безволие"],
    "безвольный": ["слабохарактерный", "слабовольный", "мягкотелый", "нерешительный"],
    "безвредный": ["безопасный"],
    "безвременник": ["колхикум", "осенний цвет", "безвременный цвет"],
    "безвременно": ["преждевременно"],
    "безвременный": ["преждевременный", "ранний", "скоропостижный"],
    "безвременье": ["беда", "несчастье", "горе", "неудача", "застой", "затишье", "болото", "межсезонье"],
    "безвыгодно": ["невыгодно", "бескорыстно"],
    "безвыигрышный": ["безуспешный", "неудачный", "провальный", "безнадёжный"],
    "безвылазный": ["невылазный"],
    "безвыходно": ["безвылазно"],
    "безглавый": ["безголовый"],
    "безглагольный": ["безмолвный", "немой", "безропотный", "покорный", "безгласный", "беззвучный", "молчаливый", "бессловесный"],
    "безглагольство": ["молчание"],
    "безглазый": ["слепой"],
    "безгласие": ["безгласность"],
    "безгласно": ["безмолвно", "безропотно"],
    "безголовый": ["полуголовый"],
    "безголосий": ["безголосний"],
    "безголосый": ["беззвучный"],
    "безгражданство": ["апатридизм"],
    "безграмотность": ["неграмотность", "малограмотность", "необразованность", "невежественность"],
    "безграмотный": ["неграмотный", "малограмотный", "полуграмотный"],
    "безграмотство": ["безграмотность"],
    "безгранично": ["неограниченно", "бескрайне", "бесконечно", "беспредельно", "чрезвычайно", "исключительно", "крайне", "безмерно"],
    "безграничный": ["бескрайний", "беспредельный", "необъятный", "безбрежный", "неограниченный", "безмерный", "исключительный", "чрезвычайный", "чрезмерный"],
    "безгреховность": ["безгрешность"],
    "безгреховный": ["безгрешный"],
    "безгрешность": ["безгреховность", "невинность", "невиновность", "негреховность", "безупречность", "непогрешимость", "чистота"],
    "безгрошевий": ["безгрошовий"],
    "безгрудый": ["плоскогрудый"],
    "бездарность": ["бесталанность", "бездарь"],
    "бездарный": ["бесталанный"],
    "бездарь": ["бездарность", "ничтожество"],
    "бездвижность": ["неподвижность"],
    "бездвижный": ["обездвиженный", "парализованный"],
    "бездействие": ["бездеятельность", "пассивность", "ничегонеделание", "безделье", "праздность"],
    "бездействовав": ["бездействовавши"],
    "бездействовавши": ["бездействовав"],
    "бездействовать": ["бездельничать", "бить баклуши", "сидеть сложа руки", "простаивать"],
    "безделие": ["безделье", "праздность"],
    "безделица": ["пустяк", "малость"],
    "безделушка": ["пизделушка"],
    "безделье": ["праздность", "безделие"],
    "бездельник": ["лентяй", "лежебока", "лежебок", "лежень", "лодырь", "лоботряс", "белоручка", "разгильдяй", "дармоед", "повеса", "шалопай", "шаматон", "оболтус", "обалдуй", "трутень"],
    "бездельничав": ["бездельничавши"],
    "бездельничавши": ["бездельничав"],
    "бездельничанье": ["баклушничанье", "лентяйничанье", "лодырничество", "ничегонеделание"],
    "безденежность": ["безденежье"],
    "безденежный": ["безналичный", "бартерный"],
    "безденежье": ["безденежность", "бедность", "нищета"],
    "бездеятельный": ["пассивный"],
    "бездна": ["пропасть", "пучина", "обрыв", "яма", "космос", "ад", "преисподняя"],
    "бездождье": ["засуха"],
    "бездоказательно": ["необоснованно"],
    "бездоказательный": ["голословный", "необоснованный", "безосновательный"],
    "бездокументный": ["бездокументарный"],
    "бездомничав": ["бездомничавши"],
    "бездомничавши": ["бездомничав"],
    "бездомность": ["бездомничество"],
    "бездомный": ["бесхатный", "бессемейный", "сирый", "бродячий", "бомж", "бездомник", "бездомовник"],
    "бездомовник": ["бездомный", "бездомник"],
    "бездомовница": ["бездомница"],
    "бездомовный": ["бездомный", "бездомовый"],
    "бездонье": ["бездонность"],
    "бездорожье": ["распутица"],
    "бездощевий": ["бездощовий"],
    "бездощовий": ["бездощевий"],
    "бездуховка": ["бездуховность"],
    "бездуховность": ["приземлённость", "бездуховка"],
    "бездушие": ["бездушность", "бесчеловечность"],
    "бездушность": ["бессердечность"],
    "бездушный": ["безжизненный", "мёртвый", "неодушевлённый", "бессердечный"],
    "бездушье": ["бездушие"],
    "бездыханно": ["безжизненно", "замертво"],
    "бездыханный": ["мёртвый", "безжизненный", "умерший", "мертвец", "покойник"],
    "безе": ["меренга", "поцелуй"],
    "безенчукец": ["безенчуковец"],
    "безжалостнейший": ["самый", "безжалостный"],
    "безжгутиковый": ["лейшманиальный"],
    "безжизненно": ["мертвенно"],
    "безжизненный": ["мёртвый", "бездушный", "бездыханный", "невыразительный"],
    "безжирный": ["безжировой", "нежирный"],
    "безжировой": ["безжирный"],
    "беззаботно": ["беспечно", "легкомысленно"],
    "беззаветно": ["самоотверженно"],
    "беззаветный": ["бескорыстный", "искренний"],
    "беззаконие": ["беззаконность", "преступление"],
    "беззаконний": ["незаконний", "протизаконний", "протиправний"],
    "беззаконник": ["преступник"],
    "беззаконничав": ["беззаконничавши"],
    "беззаконничавши": ["беззаконничав"],
    "беззаконно": ["незаконно"],
    "беззаконность": ["незаконность", "противозаконность", "противоправность", "беззаконие", "неправомерность"],
    "беззамковый": ["беззамочный"],
    "беззародышевый": ["беззародышный"],
    "беззастенчивый": ["бесцеремонный", "наглый", "бесстыдный"],
    "беззатратный": ["бесплатный"],
    "беззахисний": ["беззбройний", "безпорадний"],
    "беззащитно": ["обезоруживающе"],
    "беззащитность": ["незащищённость", "беспомощность"],
    "беззащитный": ["беспомощный", "незащищённый"],
    "беззвучно": ["тихо", "бесшумно"],
    "беззвучность": ["бесшумность"],
    "беззвучный": ["бесшумный"],
    "беззлобный": ["незлобивый", "добродушный"],
    "беззубка": ["анодонта"],
    "беззубый": ["щербатый", "неопасный", "слабый"],
    "безисключительность": ["безысключительность", "непременность", "непреложность", "всеобщность"],
    "безкойрык": ["кылкойрык"],
    "безкоштовний": ["безплатний"],
    "безкоштовно": ["безплатно", "задарма", "даром"],
    "безлад": ["безладдя"],
    "безлекарственный": ["безмедикаментозный"],
    "безлепестковый": ["безлепестной", "безлепестный", "апеталический", "апетальный"],
    "безлесный": ["безлесый", "лысый"],
    "безлесый": ["безлесный", "лысый"],
    "безликий": ["неясный", "расплывчатый", "заурядный", "невыразительный"],
    "безликость": ["обезличенность", "бесформенность"],
    "безлимит": ["безлимитка"],
    "безлимитка": ["анлим", "безлимит"],
    "безлимитный": ["неограниченный"],
    "безлистный": ["безлистый", "афильный"],
    "безлистый": ["безлистный"],
    "безлихорадочный": ["афебрильный"],
    "безличие": ["безличность"],
    "безличный": ["имперсональный"],
    "безлюдев": ["безлюдевши"],
    "безлюдевши": ["безлюдев"],
    "безлюдно": ["малолюдно", "пустынно"],
    "безлюдный": ["необитаемый", "пустынный", "глухой", "пустой", "пустующий", "обезлюдевший", "опустевший"],
    "безлюдство": ["безлюдье"],
    "безмасочник": ["антимаскер", "антимасочник"],
    "безмедикаментозный": ["безлекарственный"],
    "безмежний": ["необмежений"],
    "безмен": ["кантер", "ручные пружинные весы", "динамометр"],
    "безмерный": ["беспредельный", "бесконечный", "неизмеримый", "чрезмерный", "неумеренный"],
    "безмикробный": ["стерилизованный", "стерильный", "асептический"],
    "безмозглый": ["тупой"],
    "безмолвие": ["беззвучие", "беззвучье", "безмолвье", "молчанье"],
    "безмолвно": ["молчаливо", "молча"],
    "безмолвный": ["молчащий", "молчаливый", "беззвучный"],
    "безмолвствие": ["безмолвие", "молчание", "тишина"],
    "безмолвствовав": ["безмолвствовавши"],
    "безмолвствовавши": ["безмолвствовав"],
    "безмолвствовать": ["молчать", "хранить молчание"],
    "безмолвье": ["безмолвие"],
    "безмужний": ["вдовый"],
    "безмятежно": ["спокойно", "бестревожно", "беззаботно"],
    "безмятежность": ["умиротворённость"],
    "безмятежный": ["спокойный", "бестревожный"],
    "безнадежный": ["безнадёжный"],
    "безнадёга": ["безнадёжность"],
    "безнадёжность": ["пессимизм", "безысходность", "беспросветность"],
    "безнаказанность": ["вседозволенность", "ненаказуемость"],
    "безнал": ["безналичка", "безналичность"],
    "безналичка": ["безнал"],
    "безнарядник": ["безнарядчик"],
    "безнационализм": ["космополитизм"],
    "безначалие": ["безвластие", "безначальство", "анархия", "безначалица", "безурядица", "безначалье"],
    "безначалье": ["безначалие"],
    "безневинний": ["безвинний", "невинний"],
    "безносая": ["смертная", "костлявая", "курносая", "старуха с клюкой", "старуха с косой"],
    "безнравственно": ["аморально"],
    "безнравственность": ["аморальность"],
    "безнравственный": ["аморальный", "порочныый"],
    "безо": ["без"],
    "безобидность": ["безвредность", "безопасность"],
    "безобидный": ["необидный"],
    "безоблачность": ["ясность", "безмятежность"],
    "безоблачный": ["ясный"],
    "безоболочечный": ["безоболочный"],
    "безоболочный": ["безоболочечный"],
    "безобразив": ["безобразивши"],
    "безобразивши": ["безобразив"],
    "безобразие": ["уродливость", "уродство", "безобразность", "мерзость", "безобразье", "бесчинство", "свинство", "непотребство"],
    "безобразник": ["озорник"],
    "безобразничав": ["безобразничавши"],
    "безобразничавши": ["безобразничав"],
    "безобразный": ["бесформенный"],
    "безобразье": ["безобразие"],
    "безоглядно": ["без оглядки"],
    "безоглядный": ["неосмотрительный", "опрометчивый", "всепоглощающий", "необозримый", "беспредельный"],
    "безоговорочно": ["безусловно"],
    "безоговорочный": ["безусловный", "абсолютный", "обязательный", "неукоснительный", "категорический"],
    "безопалубочное формование": ["боф"],
    "безопасный": ["безвредный"],
    "безоружный": ["невооруженный", "беззащитный"],
    "безосновательный": ["беспочвенный", "беспричинный", "необоснованный"],
    "безостановочно": ["постоянно", "беспрерывно", "непрерывно"],
    "безостаточный": ["безостатковый", "безостатный"],
    "безответственный": ["необязательный"],
    "безотлагательно": ["неотлагательно", "неотложно", "немедля", "немедленно"],
    "безотлагательность": ["срочность", "неотложность"],
    "безотлагательный": ["быстрый", "незамедлительный", "неотложный", "неотлагательный", "немедленный", "срочный", "спешный", "экстренный"],
    "безотлучно": ["неотлучно"],
    "безотрывный": ["неотрывный", "непрерывный", "постоянный", "регулярный", "связный"],
    "безотчётно": ["бесконтрольно"],
    "безотчётный": ["бесконтрольный", "бессознательный"],
    "безоценочный": ["беспристрастный", "объективный"],
    "безошибочно": ["непогрешимо"],
    "безошибочность": ["точность", "правильность"],
    "безпалий": ["безпальчий"],
    "безперервний": ["безупинний"],
    "безпересадковий": ["безпересадочний"],
    "безпересадочний": ["безпересадковий"],
    "безпораддя": ["безпорада"],
    "безпорядък": ["безредие", "бъркотия", "разстройство", "неразбория", "безредица", "неуредица", "смут", "смущение", "вълнение", "анархия", "междуцарствие", "хаос", "суматоха"],
    "безпосадочний": ["безпосадковий"],
    "безпощадний": ["нещадний"],
    "безпрецедентний": ["небувалий", "нечуваний", "незнаний", "небачений", "винятковий", "безприкладний"],
    "безприданниця": ["безприданка"],
    "безпробудний": ["непробудний"],
    "безрадостный": ["невесёлый"],
    "безразговорье": ["молчание"],
    "безраздельный": ["нераздельный"],
    "безразличие": ["невнимание", "равнодушие", "безучастие", "апатия"],
    "безразлично": ["равнодушно", "безучастно"],
    "безразличность": ["равнодушие"],
    "безразличный": ["равнодушный", "безучастный", "индифферентный"],
    "безразличье": ["безразличие"],
    "безрассудно": ["легкомысленно"],
    "безрассудность": ["безрассудство"],
    "безрассудство": ["безрассудность", "опрометчивость"],
    "безредица": ["метеж", "смут", "междуособица"],
    "безрезультативный": ["небезрезультативный"],
    "безрезультатно": ["напрасно", "зря", "тщетно", "безуспешно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "безрезультатный": ["напрасный", "тщетный", "безуспешный", "бесплодный", "бесполезный"],
    "безрелигиозный": ["нерелигиозный"],
    "безрогий": ["комолый"],
    "безродный": ["неродовитый", "плебейский"],
    "безрозсудний": ["нерозсудливий"],
    "безропотность": ["покорность", "смирение"],
    "безрукавий": ["безрукавний"],
    "безрукавка": ["жилет", "жилетка"],
    "безрукавный": ["безрукавый"],
    "безрукавый": ["безрукавный"],
    "безрыбица": ["безрыбье"],
    "безрыбье": ["пролов", "недолов", "отсутствие", "нехватка"],
    "безрёберный": ["безреберный"],
    "безсонниця": ["безсоння"],
    "безсоння": ["безсонниця"],
    "безсрамник": ["безобразник", "нахалник", "безочливец"],
    "безстидний": ["безсоромний"],
    "безуважны": ["безудзельны", "абыякавы"],
    "безуглеродистый": ["обезуглероженный"],
    "безудержность": ["неудержимость", "неукротимость"],
    "безудержный": ["необузданный", "неудержимый", "неукротимый"],
    "безуклонный": ["прямой", "горизонтальный"],
    "безукоризненно": ["безупречно"],
    "безукоризненный": ["безукорный", "безупречный", "идеальный", "превосходный"],
    "безукорный": ["безответный"],
    "безумев": ["безумевши"],
    "безумевши": ["безумев"],
    "безумие": ["безумье", "сумасшествие", "помешательство", "душевная болезнь", "безрассудство"],
    "безумица": ["безумница", "безумка"],
    "безумно": ["безрассудно"],
    "безумный": ["сумасшедший", "умалишённый", "невменяемый", "безрассудный", "жуткий", "страшный"],
    "безумолкный": ["безумолчный"],
    "безумствовав": ["безумствовавши"],
    "безумствовавши": ["безумствовав"],
    "безумье": ["безумие", "безрассудство", "неистовство"],
    "безупречно": ["безукоризненно"],
    "безупречность": ["безукоризненность"],
    "безупречный": ["безукоризненный", "совершенный", "идеальный"],
    "безурядица": ["неурядица"],
    "безусловно": ["несомненно", "категорически", "конечно же", "явно", "да", "естественно", "конечно", "однозначно", "очевидно", "разумеется", "само собой разумеется", "всенепременно", "пренепременно", "непременно", "обязательно"],
    "безусловный": ["абсолютный", "безоговорочный"],
    "безуспешно": ["напрасно", "зря", "тщетно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "безуспешный": ["напрасный", "тщетный", "безрезультатный", "бесплодный", "бесполезный"],
    "безустально": ["неутомимо"],
    "безустальный": ["неутомимый"],
    "безустанно": ["без устали"],
    "безусый": ["голоусый", "зелёный", "неопытный"],
    "безутешный": ["неутешный"],
    "безучастие": ["безучастность", "равнодушие"],
    "безучастность": ["безучастие", "безразличие", "отрешённость", "равнодушие"],
    "безучастный": ["безразличный", "равнодушный", "индифферентный", "апатичный"],
    "безучастье": ["безучастие"],
    "безучётный": ["неучётный", "самовольный"],
    "безъязыкий": ["безъязычный"],
    "безъязыкость": ["безъязычие", "безъязычье", "немота", "косноязычие", "косноязычье"],
    "безъязычие": ["безъязычье", "безъязыкость", "косноязычие", "косноязычье", "косноязычность", "немота", "немотность", "немотство"],
    "безъязычье": ["безъязычие"],
    "безызвестный": ["неизвестный"],
    "безымянка": ["безымёнка", "безымённый", "некто", "аноним", "неизвестный"],
    "безымянно": ["безыменно"],
    "безымянность": ["безымённость", "анонимность"],
    "безымянный": ["безымённый", "анонимный", "безвестный", "неизвестный"],
    "безындукционный": ["неиндуктивный"],
    "безынициативный": ["инертный", "пассивный"],
    "безынтересно": ["неинтересно", "безвозмездно", "бескорыстно"],
    "безынтересный": ["неинтересный", "незанимательный"],
    "безыскусно": ["незатейливо", "просто", "естественно", "непосредственно", "простодушно", "наивно"],
    "безыскусственный": ["естественный"],
    "безысходность": ["безвыходность"],
    "безэквивалентный": ["лингвоспецифический", "непереводимый"],
    "безэкипажный": ["беспилотный"],
    "безэкипажный катер": ["бэк"],
    "безэмоционально": ["бесчувственно", "сухо"],
    "безэмоциональный": ["бесстрастный", "невозмутимый"],
    "бей": ["бек", "бег", "правитель", "вождь", "князь", "господин"],
    "бей-бригада": ["зондеркоманда"],
    "бейби": ["детка"],
    "бейдж": ["табличка", "имя", "бедж", "бейджик"],
    "бейлаган": ["ждановск"],
    "бейлаганский район": ["ждановский район"],
    "бейлик": ["бекство", "княжество", "эмират"],
    "бейнет": ["азап", "кебеп", "мехнат"],
    "бейс": ["бейсджампинг"],
    "бейсбол": ["безбол", "безболл"],
    "бейсджампер": ["бейсер"],
    "бейсджампинг": ["бейс"],
    "бейсер": ["бейсджампер"],
    "бейфут": ["ракс-бугель"],
    "бейцевание": ["бейцовка"],
    "бек": ["бай", "бей"],
    "бекабадец": ["беговатец"],
    "бекав": ["бекавши"],
    "бекавши": ["бекав"],
    "бекас-отшельник": ["горный дупель"],
    "бекет": ["аванпост"],
    "бекеша": ["бекеш"],
    "беклярбек": ["наместник", "бейлербей"],
    "бековец": ["бековчанин"],
    "бековчанин": ["бековец"],
    "бекон": ["ветчина", "солонина"],
    "бекорагард": ["танбал"],
    "бекрень": ["бок"],
    "бел": ["бэл"],
    "беларус": ["белорус"],
    "беларусофобия": ["белорусофобия"],
    "беларусь": ["белоруссия", "республика беларусь", "рб"],
    "белая гвардия": ["белая армия"],
    "белая головка": ["белый клевер", "клевер белый", "клевер ползучий", "клевер голландский", "кашка белая", "амория ползучая"],
    "белая горячка": ["алкогольный делирий", "белочка", "белка"],
    "белая жопа": ["белогвардеец"],
    "белая кость": ["голубая кровь"],
    "белая кувшинка": ["одолень-трава", "кувшинка белая"],
    "белгородднестровец": ["аккерманец"],
    "белгородская область": ["белгородчина"],
    "белградец": ["белградчанин"],
    "белградчанин": ["белградец"],
    "белев": ["белевши"],
    "белевши": ["белев"],
    "белегезит": ["велегезит"],
    "бележитост": ["знаменитост", "именитост", "известност", "слава"],
    "бележник": ["книга", "тефтер", "блок"],
    "белейший": ["ослепительно белый"],
    "белемнит": ["чёртов палец"],
    "белен": ["вертеп"],
    "белены объесться": ["сойти с ума"],
    "беленькая": ["лебедь", "четвертной билет"],
    "беленький": ["белый"],
    "белесоватый": ["беловатый", "мутно-белый", "серовато-белый", "тускло-белый"],
    "белеть": ["бледнеть", "седеть", "светлеть", "рассветать", "светать"],
    "белиал": ["велиал", "белиар", "белияал", "велиар", "агриэль", "бериал"],
    "белив": ["беливши"],
    "беливши": ["белив"],
    "белиз": ["белиз-сити"],
    "белизна": ["белость"],
    "белинец": ["чембарец"],
    "белить": ["обелять"],
    "белка": ["векша", "мысь", "веверица", "бельчиха"],
    "белки": ["протеин"],
    "белкин": ["беличий"],
    "белковав": ["белковавши"],
    "белковавши": ["белковав"],
    "белковина": ["альбумин"],
    "белковье": ["белкование"],
    "белладонна": ["красавка обыкновенная", "красуха", "сонная одурь", "бешеная ягода", "вишня бешеная"],
    "беллерофонт": ["гиппоной"],
    "беллетризировав": ["беллетризировавши"],
    "беллетризировавши": ["беллетризировав"],
    "беллетризировать": ["беллетризовать"],
    "беллетризовав": ["беллетризовавши"],
    "беллетризовавши": ["беллетризовав"],
    "бело-голубые": ["динамовец"],
    "бело-жёлтый": ["жёлто-белый"],
    "бело-лазорево-алый": ["бело-сине-красный"],
    "бело-сине-красный": ["бело-лазорево-алый"],
    "белоатласный": ["атласно-белый"],
    "белобилетник": ["белобилетчик"],
    "белобилетчик": ["белобилетник"],
    "белобровый скат": ["мелкошипый скат"],
    "белобрысый": ["белёсый"],
    "беловато-зелёный": ["зелёно-беловатый", "зеленовато-беловатый", "беловато-зеленоватый"],
    "беловец": ["беловчанин"],
    "беловик": ["чистовик"],
    "беловодец": ["беловодчанин"],
    "беловой": ["беловик"],
    "беловчанин": ["беловец"],
    "белогвардеец": ["беляк"],
    "белоглазка": ["глазач", "клепец", "сапа", "сопа"],
    "белоголовая": ["белоглавка", "белоголовка", "белая", "беленькая"],
    "белоголовка": ["белоглавка", "белоголовая", "белая", "беленькая"],
    "белоголовник": ["тысячелистник"],
    "белогородец": ["белгородец"],
    "белогорск": ["куйбышевка-восточная", "карасубазар"],
    "белодеревец": ["белодеревщик"],
    "белодеревщик": ["белодеревец"],
    "белодомовец": ["октябрист"],
    "белодушка": ["каменная куница"],
    "белое": ["белое вино"],
    "белое вино": ["белый"],
    "белое море": ["студёное море", "соловецкое море", "северное море", "спокойное море", "белый залив"],
    "белое пятно": ["терра инкогнита"],
    "белозер": ["белозерец", "белозерянин"],
    "белозерец": ["белозер", "белозерянин"],
    "белозём": ["подзол"],
    "белок": ["протеин", "полипептид"],
    "белокипенный": ["кипенно-белый"],
    "белокопытник": ["камчужная трава", "матерник", "подбел", "царский корень", "царь-трава", "чумная трава", "чумной корень", "мать-и-мачеха"],
    "белокочанная капуста": ["капуста", "капуста белокачанная"],
    "белокрылка": ["алейродида"],
    "белокурый": ["светловолосый", "блондинистый", "светло-русый"],
    "белоликий": ["белолицый"],
    "белолицый": ["белоликий"],
    "беломор": ["беломорец"],
    "беломорец": ["беломор"],
    "беломорит": ["перистерит"],
    "беломорчанин": ["беломорец"],
    "белоозерец": ["белозёр", "белозерец"],
    "белоозеро": ["белозерск", "белое озеро"],
    "белопогонник": ["белогвардеец", "белый", "беляк"],
    "белорус": ["бульбаш"],
    "белорусовед": ["белорусист"],
    "белорусоведческий": ["белорусистский"],
    "белорусофобия": ["беларусофобия"],
    "белоруссия": ["бсср", "бульбондия", "республика беларусь", "беларусь"],
    "белорусская народная республика": ["бнр"],
    "белорусская народная самопомощь": ["бнс"],
    "белорусская сср": ["белоруссия"],
    "белорусский корпус самообороны": ["бкс"],
    "белорусский язык": ["белорусский"],
    "белорусско-российский": ["российско-белорусский"],
    "белорусское оледенение": ["гюнцское оледенение", "варяжское оледенение", "наровское оледенение", "нижнеберезинское оледенение"],
    "белоручка": ["лентяй"],
    "белоручничав": ["белоручничавши"],
    "белоручничавши": ["белоручничав"],
    "белоснежный": ["снежный", "снеговой", "заснеженный", "оснежённый"],
    "белость": ["белизна"],
    "белотал": ["ива прутьевидная", "ива трёхтычинковая", "белолоз"],
    "белоус": ["бородка", "мичка", "сивец"],
    "белохолунинец": ["холуничанин"],
    "белоцветковый": ["молочно-цветковый"],
    "белочек": ["протеинчик"],
    "белочка": ["белка"],
    "белошёрстый": ["белошёрстный"],
    "белояровый": ["белоярский", "белоярый"],
    "белоярый": ["белояровый", "белоярский"],
    "белуга": ["белужина"],
    "белужина": ["белуга"],
    "белые люди": ["белые"],
    "белый": ["светлый", "бледный", "чистый", "легальный", "официальный", "белогвардейский"],
    "белый гриб": ["боровик", "белый"],
    "белый дом": ["вашингтон"],
    "белый друг": ["унитаз", "белый телефон", "холодильник"],
    "белый корм": ["зерно"],
    "белый медведь": ["умка", "ошкуй"],
    "белый офицер": ["белый слон"],
    "белый слон": ["чемодан без ручки"],
    "белый стих": ["верлибр"],
    "белый телефон": ["белый друг"],
    "белый хлеб": ["булка", "пшеничный хлеб"],
    "белый человек": ["белый", "счастливчик", "везунчик"],
    "белый шар": ["белок"],
    "бель": ["белизна", "белость"],
    "бельведер": ["дворец", "замок", "палаццо"],
    "бельгия": ["королевство бельгия"],
    "бельевщица": ["бельёвщица"],
    "бельмо": ["лейкома", "глаз"],
    "бельчиха": ["белка"],
    "белявый": ["белобрысый", "блондин"],
    "беляк": ["белогвардеец"],
    "беляки": ["бурун"],
    "белянин": ["бельчанин"],
    "белянка": ["блондинка"],
    "беляш": ["перемяч"],
    "белёсый": ["белесоватый", "беловатый", "белый", "седой", "тусклый"],
    "белёхонький": ["белёшенький"],
    "белёшенький": ["белёхонький"],
    "бемакон": ["бехонумон", "ломакон"],
    "бемба": ["бавемба", "вавемба", "муемба", "авемба", "чибемба"],
    "бемористон": ["беморхона"],
    "беморхона": ["бемористон"],
    "бемский": ["богемский"],
    "бемузд": ["муфт", "бепул", "ройгон", "беподош"],
    "бенвик": ["байонна"],
    "бенгазец": ["бенгазиец"],
    "бенгазиец": ["бенгазец"],
    "бенгали": ["бенгальский"],
    "бенгалурец": ["бангалорец"],
    "бенгальская свеча": ["бенгальский огонь"],
    "бенгальский огонь": ["бенгальская свеча"],
    "бендер": ["бендеры", "тигина"],
    "бендерец": ["бендерчанин"],
    "бендерчанин": ["бендерец"],
    "бендеры": ["тигина", "бендер"],
    "бенди": ["хоккей с мячом", "русский хоккей"],
    "бендюжник": ["биндюжник"],
    "бенефактив": ["бенефициант"],
    "бенефис": ["успех", "триумф"],
    "бенефициар": ["выгодоприобретатель", "выгодополучатель", "интересант"],
    "бенефициарий": ["выгодоприобретатель"],
    "бенефиций": ["бенефиция"],
    "бенефиция": ["бенефиций"],
    "бенз": ["бензин", "бензик"],
    "бензен": ["бензол"],
    "бензил": ["дифенил-дикетон", "дифенилэтандион", "дибензоил", "дифенилглиоксаль"],
    "бензиламин": ["а-аминотолуол"],
    "бензин": ["бенз", "бензик"],
    "бензин-растворитель": ["уайт-спирит", "бензин-галоша"],
    "бензиномоторный инструмент": ["бензоинструмент"],
    "бензобак": ["топливный бак"],
    "бензобур": ["мотобур"],
    "бензовоз": ["автоцистерна"],
    "бензоилхлорид": ["хлористый бензоил"],
    "бензоин": ["толуэн"],
    "бензокаин": ["анестезин"],
    "бензокоса": ["бензотриммер", "мотокоса", "бензиновый триммер", "бензиновая коса"],
    "бензол": ["бензен"],
    "бензомотор": ["бензиномотор"],
    "бензоножницы": ["мотосекатор"],
    "бензопила": ["мотопила"],
    "бензопирен": ["бензпирен"],
    "бензоспирт": ["газохол"],
    "бензохранилище": ["бензинохранилище"],
    "бензпирен": ["бензопирен"],
    "бенинец": ["дагомеец"],
    "бенинка": ["дагомейка"],
    "беннеттитовый": ["беннетитовый"],
    "бенну": ["бен-бен", "бенбен"],
    "бент": ["яз", "бараж", "преграда", "стена", "дига", "насип", "шлюз"],
    "бентический": ["бентосный"],
    "бенчмарк": ["тест"],
    "беподош": ["бемузд", "муфт", "бепул", "ройгон"],
    "бепул": ["бемузд", "муфт", "ройгон", "беподош"],
    "берасцянка": ["берасцянчык", "зябка", "зябок", "вярэнька", "дуда", "дудачка", "труба"],
    "берат": ["берата"],
    "бервакыт": ["бервакытны"],
    "бергамаск": ["бергамец"],
    "бергамотный": ["бергамотовый"],
    "бергамотовый": ["бергамотный"],
    "бердвотчер": ["бёрдвотчер", "бёрдвочер"],
    "бердвотчинг": ["бёрдвотчинг"],
    "бердовый": ["бердочный", "бёрдовый"],
    "бердышка": ["харамдаг"],
    "бердюжанин": ["бердюжец"],
    "бердюжец": ["бердюжанин"],
    "бердянск": ["новоногайск", "берды", "осипенко"],
    "берег": ["побережье", "суша"],
    "берег слоновой кости": ["республика берег слоновой кости"],
    "береговина": ["береговище", "прибрежье"],
    "береговушка": ["береговая ласточка", "стрижок"],
    "берегти": ["охороняти"],
    "бередив": ["бередивши"],
    "бередивши": ["бередив"],
    "бередить": ["растравлять"],
    "бередя": ["тревожа", "растревоживая"],
    "бережая": ["жеребая"],
    "береженье": ["защита", "охрана"],
    "бережечок": ["бережок"],
    "бережливий": ["економний", "ощадливий"],
    "бережливо": ["расчётливо", "экономно", "бережно"],
    "бережливый": ["расчётливый", "экономный"],
    "бережно": ["заботливо", "осторожно", "расчётливо", "экономно"],
    "бережный": ["заботливый", "внимательный", "осторожный", "осмотрительный", "аккуратный", "расчётливый", "экономный", "бережливый"],
    "бережённый": ["охраняемый", "оберегаемый"],
    "бережёный": ["охраняемый", "оберегаемый"],
    "березина": ["берёза"],
    "березник": ["березняк"],
    "березняк": ["березник"],
    "березнячок": ["березничек"],
    "березозол": ["март", "сухий", "брезень", "апрель", "цветень", "брезозор"],
    "березоль": ["березень"],
    "березянин": ["березовчанин"],
    "берека": ["глоговина", "рябина глоговина"],
    "беременев": ["беременевши"],
    "беременевши": ["беременев"],
    "беременеть": ["брюхатеть", "отяжелевать", "залетать", "понести плод"],
    "беременная": ["в положении", "брюхатая", "чреватая"],
    "беременность": ["интересное положение", "на сносях"],
    "беременный": ["в положении", "брюхатый", "непростый", "берёмый", "вздутый", "пузатый"],
    "беремя": ["бремя", "груз", "беременность"],
    "берест": ["вяз малый", "карагач", "караич", "пробковый ильм", "красный ильм"],
    "береста": ["берёста"],
    "берестьянин": ["берестянин", "брестец", "брестчанин", "брестовчанин"],
    "берестянин": ["берестьянин", "брестец", "брестчанин", "брестовчанин"],
    "берестянка": ["туес"],
    "беречь": ["сберегать", "экономить", "сохранять", "хранить", "защищать", "оберегать", "охранять", "предохранять"],
    "беречь как зеницу ока": ["хранить как зеницу ока", "оберегать как зеницу ока", "беречь паче зеницы ока"],
    "беречься": ["остерегаться"],
    "бери": ["бёрю", "бэри"],
    "бери-бери": ["алиментарный полиневрит"],
    "берингово море": ["камчатское море", "бобровое море"],
    "берклий": ["беркелий"],
    "беркут": ["холзан"],
    "берлин": ["берлина"],
    "берлинская стена": ["антифашистский оборонительный вал", "позорная стена"],
    "бермуды": ["бермудские острова"],
    "бернар": ["бернард", "бернхард", "барни"],
    "бернард": ["бернхард", "барни", "барно", "бернардо", "бернар"],
    "бернардинець": ["бернардин"],
    "бернхард": ["бернард", "барни", "бернар", "бернардо"],
    "бернчанин": ["бернец"],
    "берня": ["верня"],
    "берримон": ["берриец"],
    "берсерк": ["берсеркер", "буй тур", "березарк"],
    "берсеркер": ["берсерк"],
    "бертолетова соль": ["хлорат", "калий"],
    "бертранизм": ["некросадизм"],
    "бертыны": ["берытскыны"],
    "берцо": ["голень"],
    "берш": ["волжский судак"],
    "берытскыны": ["бертыны"],
    "берёза": ["берёзовая каша"],
    "берёзка": ["вьюнок полевой"],
    "берёзовик": ["подберёзовик", "берёзовица"],
    "берёзонька": ["берёзка"],
    "берёста": ["береста", "берёстка", "берёсточка"],
    "бес": ["чёрт", "демон", "лукавый", "имп"],
    "бес-": ["без-"],
    "беседка": ["павильон", "беседа"],
    "беседливый": ["разговорчивый", "словоохотливый", "болтливый"],
    "беседовав": ["беседовавши"],
    "беседовавши": ["беседовав"],
    "беседовать": ["разговаривать"],
    "беседчик": ["шишковист"],
    "бесив": ["бесивши"],
    "бесивши": ["бесив"],
    "бесить": ["сердить", "дразнить", "злить", "выводить из терпения", "действовать на нервы", "выводить из себя", "разъярять", "доводить до белого каления", "подбешивать", "выбешивать"],
    "бескарбонатный": ["безкарбонатный"],
    "бескаркасный": ["безкаркасный"],
    "бескарточный": ["безкарточный"],
    "бескванторный": ["безкванторный"],
    "бесквартирный": ["безквартирный"],
    "бескварцевый": ["безкварцевый"],
    "бескет": ["бескед", "бескид"],
    "бескилевой": ["безкилевой"],
    "бескислотный": ["безкислотный"],
    "бесклапанный": ["безклапанный"],
    "бесклеевой": ["безклеевой"],
    "бесковидный": ["бескоронавирусный"],
    "бескозырный": ["безкозырный"],
    "бескомпрессорный": ["безкомпрессорный"],
    "бескомпромиссно": ["непримиримо", "упорно", "непоколебимо", "твёрдо"],
    "бескомпромиссность": ["неуступчивость"],
    "бескомпромиссный": ["неуступчивый", "неподатливый", "принципиальный"],
    "бесконечно": ["безгранично", "беспредельно", "безмерно", "чрезвычайно"],
    "бесконечность": ["нескончаемость", "безграничность", "бескрайность", "бесчисленность"],
    "бесконечноугольник": ["апейрогон"],
    "бесконкурентный": ["монопольный"],
    "бесконсольный": ["безконсольный"],
    "бесконфликтный": ["мирный", "миролюбивый"],
    "бескордный": ["безкордный"],
    "бескордовый": ["безкордовый"],
    "бескорковый": ["безкорковый"],
    "бескормица": ["бескормщина"],
    "бескормщина": ["бескормица"],
    "бескоронавирусный": ["бесковидный"],
    "бескорыстие": ["бескорыстность"],
    "бескорыстно": ["безвозмездно"],
    "бескорыстность": ["бескорыстие"],
    "бескорыстный": ["бесплатный", "безвозмездный", "альтруистический", "некорыстный", "некорыстолюбивый", "нестяжательный"],
    "бескорыстье": ["бескорыстие"],
    "бескостный": ["безкостный"],
    "бескрайне": ["безгранично", "бескрайно", "беспредельно"],
    "бескрайно": ["безгранично", "бескрайне", "беспредельно"],
    "бескрайный": ["бескрайний", "безграничный", "беспредельный"],
    "бескрасочно": ["бесцветно", "неярко", "тускло"],
    "бескровно": ["ненасильственно", "мирно", "бледно", "землисто", "невыразительно", "слабо"],
    "бескровный": ["бледный"],
    "бескультурный": ["некультурный"],
    "бескультурье": ["дикость", "необразованность", "неотёсанность", "невоспитанность"],
    "бесланец": ["беслановец"],
    "беслановец": ["бесланец"],
    "беснование": ["беснованье"],
    "беснованье": ["беснование"],
    "бесноваться": ["неистовствовать"],
    "бесовка": ["чертовка"],
    "бесовский": ["бесовской", "бесов"],
    "бесовской": ["бесовский"],
    "бесовство": ["неистовость", "бешенство", "ярость", "безумство", "бесовщина", "наваждение", "неистовство", "дьявольщина", "сатанизм", "чертовщина", "ведьмомания"],
    "беспалевно": ["скрытно", "незаметно"],
    "беспалевный": ["незаметный", "безопасный"],
    "беспамятный": ["забывчивый"],
    "беспамятство": ["бесчувствие", "забытьё", "отключка"],
    "беспанцирный": ["беззащитный", "мягкотелый"],
    "беспараметрический": ["непараметрический"],
    "беспардонность": ["нахальство", "наглость", "бесцеремонность", "цинизм", "бесстыдство", "нескромность"],
    "беспардонный": ["бессовестный", "бесстыжий", "беззастенчивый", "разухабистый", "циничный", "бесцеремонный", "нецеремонный", "развязный", "наглый", "нагловатый", "грубый", "нескромный", "нахрапистый"],
    "беспарусный": ["безветрильный"],
    "бесперебойно": ["беспрерывно"],
    "бесперебойный": ["непрерывный", "беспрерывный"],
    "беспеременно": ["безпеременно", "бессменно"],
    "бесперспективный": ["безнадёжный"],
    "бесперспективняк": ["бесперспективность", "безнадёжность", "безнадёга"],
    "беспечность": ["неосторожность", "неосмотрительность", "лёгкость", "легкомыслие", "беззаботность", "опрометчивость", "мальчишество", "бесшабашность", "ветреность", "ротозейство", "нерадение", "легкомысленность", "неосновательность", "успокоенность", "несерьёзность"],
    "беспечный": ["легкомысленный", "беззаботный", "ветреный", "несерьёзный"],
    "беспилотник": ["бпла", "дрон", "робомобиль", "самоуправляемый автомобиль", "автономный автомобиль", "автомобиль с автопилотом", "умный автомобиль"],
    "беспилотный": ["безэкипажный"],
    "беспилотный летательный аппарат": ["беспилотник", "бпла", "бла", "дрон"],
    "беспламенный": ["афлогистический"],
    "бесплатно": ["даром", "за так", "за просто так", "задаром", "задарма", "за здорово живёшь", "за красивые глаза", "безвозмездно", "за спасибо"],
    "бесплатный": ["безоплатный", "дармовой", "даровой", "халявный", "шаровой", "шаровый", "безвозмездный", "безмездный", "невознаграждаемый", "неоплачиваемый"],
    "бесплодие": ["бесплодность", "бесплодье", "инфертильность", "неплодородность", "неплодородие", "неплодородье"],
    "бесплодно": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "зазря"],
    "бесплодный": ["неплодоносный", "неплодородный", "напрасный", "тщетный", "безрезультатный", "безуспешный", "бесполезный"],
    "бесплодье": ["бесплодие"],
    "бесплотность": ["бестелесность"],
    "бесплотный": ["бестелесный", "нематериальный"],
    "бесповоротно": ["окончательно"],
    "бесповоротный": ["окончательный"],
    "бесподлежащный": ["бессубъектный"],
    "бесподобно": ["прекрасно", "превосходно", "несравненно"],
    "бесподобный": ["несравнимый", "превосходный", "отличный", "замечательный", "уникальный"],
    "беспокоив": ["беспокоивши"],
    "беспокоивши": ["беспокоив"],
    "беспокоить": ["досаждать", "мешать", "болеть", "зудеть", "волновать", "тревожить"],
    "беспокоиться": ["волноваться", "тревожиться", "заботиться", "хлопотать", "радеть", "утруждаться", "печься"],
    "беспокойность": ["озабоченность"],
    "беспокойный": ["тревожный", "заботливый", "хлопотливый", "бунтующий", "мятежный"],
    "беспокойство": ["волнение", "переживание", "тревога", "опасение", "беспокой", "беспокоица", "непокой", "заботы", "хлопоты", "суета", "неудобство"],
    "беспокоящийся": ["тревожащийся"],
    "бесполезно": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "бесполезность": ["ненужность", "никчёмность", "тщета", "тщетность"],
    "бесполезный": ["напрасный", "тщетный", "безрезультатный", "безуспешный", "бесплодный", "бессмысленный"],
    "бесполость": ["асексуальность"],
    "беспомощнее": ["беспомощней"],
    "беспомощней": ["беспомощнее"],
    "беспомощность": ["бессилие", "немощь"],
    "беспонтовый": ["безобразный", "безнадёжный"],
    "беспоповщина": ["беспоповство"],
    "беспорочно": ["безгреховно", "непорочно", "честно", "невинно", "чисто"],
    "беспорочный": ["безупречный", "безукоризненный"],
    "беспорточник": ["голодранец", "голоштанник", "оборванец"],
    "беспорядок": ["кавардак", "кутерьма", "хаос", "бардак", "волнения"],
    "беспорядочно": ["как попало", "хаотично", "вразброс", "наобум"],
    "беспорядочность": ["хаотичность"],
    "беспорядочный": ["неупорядоченный", "неорганизованный", "хаотичный", "нестройный", "сбивчивый", "сумбурный"],
    "беспочвенность": ["безосновательность", "необоснованность"],
    "беспочвенный": ["безосновательный", "беспричинный"],
    "беспощадный": ["безжалостный", "жестокий", "нещадный"],
    "бесправие": ["бесправье", "бессудье"],
    "бесправник": ["лишённик"],
    "бесправность": ["бесправие", "бесправье"],
    "бесправный": ["лишённик"],
    "бесправье": ["бесправие"],
    "беспредел": ["произвол", "беззаконие"],
    "беспредельник": ["беспредельщик"],
    "беспредельничав": ["беспредельничавши"],
    "беспредельничавши": ["беспредельничав"],
    "беспредельно": ["безгранично", "неограниченно"],
    "беспредельный": ["бескрайний"],
    "беспредельщик": ["беспредельник"],
    "беспрекословный": ["безоговорочный", "безотговорочный", "безусловный", "лояльный"],
    "беспрепятственно": ["невозбранно"],
    "беспрерывно": ["безостановочно", "непрерывно"],
    "беспрерывный": ["непрерывный"],
    "беспрестанно": ["беспрерывно", "безостановочно"],
    "беспрестанный": ["непрестанный", "непрерывный", "постоянный", "бесконечный", "беспрерывный", "вечный", "неустанный"],
    "беспрефиксный": ["бесприставочный"],
    "беспрецедентность": ["уникальность", "исключительность"],
    "беспрецедентный": ["беспримерный", "небывалый"],
    "бесприбыльный": ["неприбыльный", "нерентабельный"],
    "бесприветность": ["мрачность", "неприветливость", "суровость"],
    "бесприданница": ["бесприданная"],
    "беспризорничав": ["беспризорничавши"],
    "беспризорничавши": ["беспризорничав"],
    "беспризорный": ["безнадзорный", "бездомный"],
    "беспримерный": ["исключительный", "неслыханный"],
    "беспринципность": ["аморальность", "цинизм", "циничность"],
    "беспристрастность": ["беспристрастие", "объективность", "нелицеприятность", "нелицеприятие"],
    "беспристрастный": ["непредвзятый", "непредубеждённый", "справедливый"],
    "беспристрастье": ["беспристрастие"],
    "беспричинно": ["без причины", "безосновательно", "немотивированно"],
    "беспричинный": ["безосновательный", "беспочвенный", "необоснованный"],
    "беспробудно": ["непробудно", "без задних ног"],
    "беспроводной": ["беспроволочный"],
    "беспроигрышный": ["выигрышный"],
    "беспросыпность": ["беспробудность"],
    "беспросыпный": ["беспробудный"],
    "беспутица": ["распутица", "беспутье", "бездорожье"],
    "беспутничав": ["беспутничавши"],
    "беспутничавши": ["беспутничав"],
    "беспутно": ["бессмысленно", "безрассудно", "бесцельно", "разгульно", "развратно"],
    "беспутный": ["безрассудный", "бестолковый", "разгульный", "развратный"],
    "беспутство": ["разврат"],
    "беспутствовав": ["беспутствовавши"],
    "беспутствовавши": ["беспутствовав"],
    "беспутье": ["беспутица", "распутица", "бездорожье"],
    "бессвязица": ["бессвязность"],
    "бессвязно": ["неразборчиво", "туманно", "непонятно"],
    "бессеменной": ["бессемянный"],
    "бессемянный": ["бессеменный", "бессеменной"],
    "бессердечие": ["бессердечность", "бездушие"],
    "бессердечность": ["бессердечие"],
    "бессердечный": ["злой"],
    "бессердечье": ["бессердечие"],
    "бессерный": ["обессеренный"],
    "бессилев": ["бессилевши"],
    "бессилевши": ["бессилев"],
    "бессилив": ["бессиливши"],
    "бессиливши": ["бессилив"],
    "бессилие": ["бессилье", "упадок сил", "апатия"],
    "бессилье": ["бессилие"],
    "бессильный": ["слабый", "беспомощный"],
    "бессимптомно": ["асимптоматически"],
    "бессимптомный": ["асимптоматический"],
    "бессистемность": ["беспорядочность", "хаотичность", "сумбурность", "неупорядоченность", "безалаберность"],
    "бесславив": ["бесславивши"],
    "бесславивши": ["бесславив"],
    "бесславить": ["бесчестить", "обесславливать", "опорочивать", "позорить", "порочить", "посрамлять"],
    "бесславный": ["позорный", "неприличный"],
    "бессловесность": ["молчаливость", "немота", "покорность", "безликость", "послушность"],
    "бессловесный": ["молчаливый", "неразговорчивый", "безответный", "робкий", "безмолвный"],
    "бессмертие": ["бессмертность", "бессмертье"],
    "бессмертник": ["иммортель", "сухоцвет"],
    "бессмертность": ["бессмертие"],
    "бессмертный": ["неумирающий", "непреходящий"],
    "бессмертье": ["бессмертие"],
    "бессмысленник": ["бестолочь"],
    "бессмысленный": ["несмысленный", "заумный", "тарабарский", "абсурдный", "абсурдистский", "неразумный", "нелепый", "напрасный", "ненужный", "пустой", "глупый", "тупой", "идиотский", "идиотический", "дурацкий"],
    "бессмыслив": ["бессмысливши"],
    "бессмысливши": ["бессмыслив"],
    "бесснежие": ["бесснежье"],
    "бесснежность": ["бесснежие"],
    "бессовестничав": ["бессовестничавши"],
    "бессовестничавши": ["бессовестничав"],
    "бессовестно": ["бесстыдно", "бесчестно", "непорядочно", "безбожно"],
    "бессовестный": ["бесстыдный", "бесстыжий", "нещепетильный", "беззастенчивый", "наглый"],
    "бессодержательность": ["пустота"],
    "бессодержательный": ["пустой"],
    "бессознательно": ["неосознанно", "безосознанно", "подсознательно"],
    "бессознательный": ["безотчётный"],
    "бессонница": ["асомния", "агрипния", "инсомния", "диссомния"],
    "бессонье": ["бессонница"],
    "бессоюзие": ["асиндетон", "паратаксис", "опущение союзов"],
    "бесспиртовой": ["безалкогольный"],
    "бесспорно": ["очевидно", "несомненно", "разумеется", "конечно"],
    "бесспорный": ["несомненный", "очевидный"],
    "бессребренник": ["бессребреник"],
    "бессребреннический": ["бессребренический", "бескорыстный"],
    "бессрочка": ["бессрочный протест", "бессрочная блокировка"],
    "бессрочная блокировка": ["бессрочка"],
    "бессрочник": ["вечник", "обессроченный"],
    "бессрочно": ["навсегда", "пожизненно", "навечно", "вечно"],
    "бессточный": ["ареический"],
    "бесстрастие": ["невозмутимость", "бесстрастность", "бесстрастье"],
    "бесстрастность": ["бесстрастие", "самообладание"],
    "бесстрастный": ["бесчувственный", "сухой", "холодный", "невозмутимый", "уравновешенный", "хладнокровный", "беспристрастный", "равнодушный", "безучастный", "бездушный", "апатичный"],
    "бесстрастье": ["невозмутимость", "бесстрастность", "бесстрастие"],
    "бесстрашие": ["доблесть", "храбрость", "отвага", "мужество", "смелость"],
    "бесстрашный": ["смелый", "храбрый", "отважный", "мужественный", "неустрашимый"],
    "бесстрашье": ["бесстрашие", "смелость", "отвага"],
    "бесстыдник": ["нахал", "срамец"],
    "бесстыдница": ["эвкалипт шаровидный", "эвкалипт клейкий", "эвкалипт шариковый"],
    "бесстыдничав": ["бесстыдничавши"],
    "бесстыдничавши": ["бесстыдничав"],
    "бесстыдность": ["бесстыдство"],
    "бесстыдный": ["беззастенчивый", "бесстыжий", "непристойный"],
    "бесстыдство": ["бесстыдность", "бессовестность"],
    "бесстыдствовав": ["бесстыдствовавши"],
    "бесстыдствовавши": ["бесстыдствовав"],
    "бесстыжесть": ["бесстыдность", "беззастенчивость"],
    "бесстыжий": ["беззастенчивый", "бессовестный"],
    "бесстыковой": ["бархатный"],
    "бессудив": ["бессудивши"],
    "бессудивши": ["бессудив"],
    "бессудить": ["осуждать", "корить"],
    "бессудный": ["беззаконный", "самосудный"],
    "бессчастный": ["несчастный"],
    "бессчётный": ["бесчисленный", "неисчислимый", "несметный"],
    "бессяжковые": ["протуры"],
    "бестактность": ["грубость", "неделикатность"],
    "бестактный": ["нетактичный", "бесцеремонный"],
    "бесталанность": ["бездарность", "заурядность"],
    "бесталанный": ["несчастный", "неудачливый", "незадачливый"],
    "бесталантность": ["бездарность"],
    "бесталантный": ["бездарный", "бесталанный"],
    "бестелесность": ["бесплотность"],
    "бестелесный": ["бесплотный"],
    "бестиофилия": ["зооэрастия", "зооэротия", "скотоложество", "содомия", "бестиализм", "зоофилия"],
    "бестиражный": ["мгновенный"],
    "бестолковка": ["бестолочь"],
    "бестолково": ["неразумно", "бессмысленно"],
    "бестолковщина": ["неразбериха", "бестолочь"],
    "бестолковый": ["непонятливый", "несообразительный", "глупый", "безголовый", "безмозглый", "дураковатый", "недалёкий", "несмышлёный", "придурковатый", "простоватый", "простой", "пустоголовый", "скудоумный", "слабоумный", "твердолобый"],
    "бестолковье": ["бестолковость", "глупость"],
    "бестолочь": ["бестолковка", "нескладёха", "бестолкова"],
    "бестревожно": ["тихо", "спокойно"],
    "бестселлер": ["хит"],
    "бестяглый": ["бестягольный"],
    "бестягольный": ["бестяглый"],
    "бесформенный": ["бесформный"],
    "бесхарактерный": ["безвольный", "слабохарактерный"],
    "бесхатный": ["бездомный"],
    "бесхитростность": ["наивность", "безыскусственность", "простота"],
    "бесхитростный": ["наивный", "невинный", "нехитрый", "простодушный", "простой", "простосердечный", "прямодушный", "простоватый", "простодырый", "простосердый", "безыскусный", "безыскусственный", "незамысловатый", "незатейливый", "немудрый"],
    "бесхлебенница": ["бесхлебье", "бесхлебица"],
    "бесхлебица": ["бесхлебье", "бесхлебенница"],
    "бесхлебье": ["бесхлебица", "бесхлебенница"],
    "бесхозный": ["бесхозяйный", "ничейный"],
    "бесхозяйный": ["бесхозный"],
    "бесхребетный": ["беспозвоночный"],
    "бесцарствие": ["бесцаревщина"],
    "бесцветник": ["горянка"],
    "бесцветный": ["ахроматичный", "ахроматический", "бледный", "незаметный", "безличный", "неказистый", "выцветший", "полинявший", "потерявший краски"],
    "бесцельность": ["бесполезность", "тщетность"],
    "бесценный": ["неоценимый"],
    "бесцеремонно": ["развязно", "нагло"],
    "бесцеремонность": ["нецеремонность", "наглость", "нахальность", "развязность", "грубость", "фамильярность", "нескромность", "нахрапистость", "беспардонность", "бессовестность", "циничность", "беззастенчивость", "бесстыжесть"],
    "бесцеремонный": ["развязный", "беззастенчивый", "бестактный"],
    "бесциркуляционный": ["бесциркулярный"],
    "бесчеловечие": ["безжалостность", "беспощадность", "бессердечие", "бессердечность", "бесчеловечность", "жестокосердие", "зверство", "изуверство", "кровожадность", "неистовство", "свирепость", "ожесточение", "озлобление", "жестокость"],
    "бесчеловечнее": ["бесчеловечней"],
    "бесчеловечней": ["бесчеловечнее"],
    "бесчеловечность": ["жестокость", "зверство"],
    "бесчеловечный": ["жестокий", "безжалостный", "беспощадный"],
    "бесчестив": ["бесчестивши"],
    "бесчестивши": ["бесчестив"],
    "бесчестие": ["бесчестье"],
    "бесчестить": ["позорить", "унижать"],
    "бесчестный": ["нечестный", "позорный", "нечестивый", "подлый"],
    "бесчестье": ["бесчестие", "оскорбление", "позор"],
    "бесчинничав": ["бесчинничавши"],
    "бесчинничавши": ["бесчинничав"],
    "бесчинничать": ["бесчинствовать"],
    "бесчинно": ["непристойно"],
    "бесчинствовав": ["бесчинствовавши"],
    "бесчинствовавши": ["бесчинствовав"],
    "бесчисленность": ["бессчётность", "неисчислимость", "многочисленность"],
    "бесчисленный": ["несметный", "бессчётный", "неисчислимый"],
    "бесчувственность": ["наплевательский", "отношение", "пофигизм", "индифферентизм", "индифферентность", "безразличье", "хладнодушие", "тупосердие", "жестокость"],
    "бесчувственный": ["нечувствительный", "без сознания", "безучастный", "равнодушный", "апатичный", "безжалостный", "жестокий"],
    "бесшабашно": ["залихватски"],
    "бесшабашный": ["безрассудный", "беспечный", "безбашенный", "залихватский", "отчаянный", "храбрый"],
    "бесшовный": ["цельнотянутый", "бесстыковой"],
    "бесшумный": ["беззвучный", "тихий"],
    "бесшёрстный": ["бесшёрстый"],
    "бесячий": ["раздражающий"],
    "бет-лехем": ["бейт-лехем", "вифлеем"],
    "бета": ["вита", "бета-версия", "редактор", "корректор"],
    "бета-излучение": ["бета-лучи"],
    "бета-коронавирус": ["бетакоронавирус"],
    "бета-лучи": ["бета-излучение"],
    "бета-нафтол": ["изонафтол", "вета-гидроксинафталин"],
    "бета-радиоактивность": ["бета-активность"],
    "бета-тестирование": ["бета-тест"],
    "бетаин": ["триметилглицин", "триметиламиноуксусная кислота"],
    "бетакоронавирус": ["бета-коронавирус"],
    "беталин": ["кальциферол", "эргокальциферол", "альдевит", "фордетол", "инфадин", "остелин", "ультранол", "вигантол", "витастерол"],
    "бетель": ["паан"],
    "бетив": ["бетивши"],
    "бетивши": ["бетив"],
    "бетиз": ["глупость", "сотиз"],
    "бетон": ["бетонная смесь", "дурак", "тупица"],
    "бетонировав": ["бетонировавши"],
    "бетонировавши": ["бетонировав"],
    "бетонная смесь": ["бетон"],
    "бетонний": ["бетоновий"],
    "бетоновий": ["бетонний"],
    "бетоновозка": ["бетоновоз"],
    "бетономешалка": ["бетоносмеситель"],
    "бетоносмеситель": ["бетономешалка", "бетоносмесительный узел", "растворный узел", "бетоновоз", "бетононасос"],
    "бетоньерка": ["бетономешалка"],
    "бехонумон": ["бемакон", "ломакон"],
    "бечевав": ["бечевавши"],
    "бечевавши": ["бечевав"],
    "бечёвка": ["бечева", "бичёвка", "бичева"],
    "бечёвочка": ["бечёвка", "верёвочка"],
    "бешенный": ["бешеный", "яростный", "неистовый"],
    "бешено": ["исступлённо", "необузданно", "яростно"],
    "бешенство": ["ярость", "агрессия", "гидрофобия", "водобоязнь", "рабиес"],
    "бешенствовав": ["бешенствовавши"],
    "бешенствовавши": ["бешенствовав"],
    "бешеный": ["взбесившийся", "исступлённый", "неистовый", "необузданный", "яростный", "неимоверный", "исключительный"],
    "бешеный принтер": ["госдура", "взбесившийся принтер", "сумасшедший принтер"],
    "бешмет": ["полукафтан", "полукафтанье"],
    "беэр-шева": ["вирсавия"],
    "бзданув": ["бзданувши"],
    "бзданувши": ["бзданув"],
    "бздануть": ["пердануть", "испугаться"],
    "бздев": ["бздевши"],
    "бздевши": ["бздев"],
    "бздение": ["бздёж"],
    "бздеть": ["пукать", "газовать", "трусить", "ссать", "срать"],
    "бздливый": ["пугливый", "боязливый", "опасливый", "ссыкливый", "бздюлявый"],
    "бзднув": ["бзднувши"],
    "бзднувши": ["бзднув"],
    "бзднуть": ["пукнуть", "пёрнуть", "пёрднуть", "испугаться", "соссать"],
    "бздун": ["бздунья"],
    "бздых": ["приезжий"],
    "бздышка": ["приезжая"],
    "бздюха": ["порховка свинцово-серая", "чёртов табак"],
    "бздюхав": ["бздюхавши"],
    "бздюхавши": ["бздюхав"],
    "бздюшка": ["бздюха"],
    "бздёж": ["пердёж", "страх"],
    "бздёх": ["гриб-бздёх", "испуг"],
    "бзик": ["каприз"],
    "бзу": ["джэдкъаз"],
    "бзык": ["слепень"],
    "би-": ["ди-"],
    "би-сплайн": ["бисплайн"],
    "биаксиальный": ["диаксиальный"],
    "бианка": ["бьянка"],
    "биармия": ["бьярмия", "бьярмаланд"],
    "биафра": ["биафрский залив", "республика биафра"],
    "биафрский залив": ["биафра"],
    "биаффинный": ["диаффинный"],
    "бибабо": ["перчаточная кукла"],
    "бибах": ["бибахт"],
    "бибахт": ["бибах"],
    "бибикав": ["бибикавши"],
    "бибикавши": ["бибикав"],
    "бибикалка": ["клаксон"],
    "бибикать": ["сигналить", "гудеть"],
    "бибикнув": ["бибикнувши"],
    "бибикнувши": ["бибикнув"],
    "библ": ["библос", "гебал", "губл", "джебейль", "джубейль"],
    "библида": ["библис"],
    "библиобус": ["автобиблиотека"],
    "библиографировав": ["библиографировавши"],
    "библиографировавши": ["библиографировав"],
    "библиология": ["книговедение", "библеистика"],
    "библиоман": ["библиофил"],
    "библиотека": ["книгохранилище"],
    "библиофил": ["книголюб"],
    "библиофильство": ["библиофилия", "книгособирательство"],
    "библия": ["священное писание", "книга книг"],
    "бибой": ["брейк-дансер", "брейкер", "брейкист"],
    "бибопер": ["бопер"],
    "бивав": ["бивавши"],
    "бивавши": ["бивав"],
    "бивак": ["бивуак"],
    "бивакансия": ["дивакансия"],
    "бивакировав": ["бивакировавши"],
    "бивакировавши": ["бивакировав"],
    "бивакировать": ["бивуакировать"],
    "бивалент": ["гемини"],
    "бивалютный": ["двухвалютный"],
    "бивариантный": ["дивариантный", "двувариантный", "двухвариантный"],
    "бивачный": ["бивуачный", "временный", "неблагоустроенный"],
    "бивектор": ["дивектор"],
    "бивуак": ["бивак"],
    "бивуакировав": ["бивуакировавши"],
    "бивуакировавши": ["бивуакировав"],
    "бивуакировать": ["бивакировать"],
    "бивужо": ["биужо"],
    "бивши": ["бив"],
    "бигарадия": ["померанец", "горький апельсин"],
    "бигармонический": ["двоякогармонический", "бигармоничный"],
    "бигборд": ["билборд"],
    "бигзор": ["бигузор"],
    "бигидрат": ["дигидрат", "гидрогалит"],
    "биговка": ["бигование"],
    "бигос": ["бигус"],
    "биграф": ["двудольный граф"],
    "бигуди": ["папильотка"],
    "бигфут": ["йети", "сасквоч", "снежный человек", "монстр-трак"],
    "бидиалектизм": ["диглоссия"],
    "бидло": ["худоба"],
    "бидон": ["дойка"],
    "бидэшэнгиро шэл": ["енядэша"],
    "биективный": ["взаимно-однозначный"],
    "биекхэскиро биш": ["дэшуеня"],
    "биенье": ["биение"],
    "биза": ["бизе"],
    "бизант": ["визант", "бизантий"],
    "бизань": ["бизань-мачта"],
    "бизарность": ["странность", "причудливость"],
    "бизарный": ["странный", "причудливый"],
    "бизаррия": ["странность", "причудливость"],
    "бизнес": ["предпринимательство", "предприятие", "компания", "деловое сообщество"],
    "бизнес-администрация": ["бизнес-управление"],
    "бизнес-блокнот": ["бизнес-организатор", "органайзер"],
    "бизнес-встреча": ["деловая встреча"],
    "бизнес-гайд": ["бизнес-гид", "бизнес-справочник"],
    "бизнес-гид": ["бизнес-гайд", "бизнес-справочник"],
    "бизнес-журналист": ["бизнес-репортёр"],
    "бизнес-комплекс": ["бизнес-центр"],
    "бизнес-образование": ["бизнес-обучение"],
    "бизнес-обучение": ["бизнес-образование"],
    "бизнес-организатор": ["бизнес-блокнот", "органайзер"],
    "бизнес-репортёр": ["бизнес-журналист"],
    "бизнес-сообщество": ["деловые круги"],
    "бизнес-справочник": ["бизнес-гайд", "бизнес-гид"],
    "бизнес-тур": ["командировка"],
    "бизнес-управление": ["бизнес-администрация"],
    "бизнес-центр": ["бизнес-комплекс"],
    "бизнесмен": ["делец", "коммерсант", "предприниматель"],
    "бизнесменовский": ["бизнесменский"],
    "бизнесменский": ["бизнесменовский"],
    "бизнесменствовав": ["бизнесменствовавши"],
    "бизнесменствовавши": ["бизнесменствовав"],
    "бизнесмент": ["оборотень в погонах"],
    "бизоний": ["бизоновый"],
    "бизоновый": ["бизоний"],
    "бикарбонат": ["гидрокарбонат"],
    "бикле": ["бикте"],
    "бикомпакт": ["компакт"],
    "бикомпактный": ["паракомпактный"],
    "бикомплекс": ["дикомплекс"],
    "бикс": ["биксовый бильярд", "китайский бильярд", "бикса", "биксовка"],
    "бикте": ["бикле"],
    "бикфордов шнур": ["огнепроводный", "шнур"],
    "билабиальный": ["губно-губной", "двугубный"],
    "билатеральность": ["билатеральная симметрия", "двусторонняя симметрия", "зигоморфность"],
    "билборд": ["рекламный", "щит"],
    "билге": ["тамга"],
    "билетик": ["билет", "карточка", "листочек"],
    "билетёр": ["капельдинер"],
    "билиарный": ["желчный"],
    "билив": ["билик"],
    "билин": ["блин", "билен", "богос", "северноагавский"],
    "билингвизм": ["двуязычие"],
    "билингвистический": ["двуязычный"],
    "билинеарный": ["билинейный"],
    "билинейный": ["билинеарный"],
    "биллиард": ["квадрильон", "квадриллион", "зиллион", "тьма", "множество"],
    "биллинг": ["тарификация"],
    "биллион": ["миллиард", "триллион"],
    "биллонный": ["биллоновый"],
    "билль": ["булла"],
    "било": ["клепало"],
    "било шта било": ["пукло куд пукло"],
    "билон": ["биллон"],
    "бильбаец": ["бильбаосец"],
    "бильбаосец": ["бильбаец"],
    "бильгарциоз": ["шистосомоз", "шистосоматоз"],
    "бильдаппарат": ["фототелеграф"],
    "бильдиривчи": ["бильдирчи"],
    "бильдирчи": ["бильдиджи"],
    "бильеду": ["любовная записка"],
    "бильмеден": ["бильмеерек"],
    "бильярд": ["биллиард", "шарокат", "бильярдный стол"],
    "билясувар": ["пушкино"],
    "билясуварский район": ["пушкинский район"],
    "бим": ["тарс"],
    "бим додан": ["тарсондан"],
    "бимодальный": ["двувершинный", "двухмодальный", "димодальный"],
    "бимолекулярный": ["димолекулярный"],
    "бинаризация": ["дихотомизация", "поляризация", "упрощение"],
    "бинарная гендерная система": ["гендерная бинарность"],
    "бинарный": ["двоичный", "двухкомпонентный"],
    "биндер": ["прищепка"],
    "биндюг": ["биндюх", "биндига", "бендига", "хвост", "крепыш", "здоровяк", "бугай", "детина"],
    "биниш": ["чашм", "басир"],
    "бинокуляр": ["стереомикроскоп", "микроскоп"],
    "бинокунанда": ["бинокор"],
    "бином": ["двучлен"],
    "биномный": ["биномиальный"],
    "бинтовав": ["бинтовавши"],
    "бинтовавши": ["бинтовав"],
    "бинтование": ["бинтованье"],
    "бинтовать": ["забинтовывать"],
    "бинтуронг": ["кошачий медведь"],
    "биньян": ["порода"],
    "био": ["биография", "жизнеописание", "жизнеописанье"],
    "биоавтография": ["биоаутография"],
    "биовар": ["биотип"],
    "биогенеалогия": ["филогения", "филогенетика"],
    "биогенез": ["биогенезис"],
    "биогенезис": ["биогенез"],
    "биогеостратон": ["экостратон"],
    "биогеосфера": ["фитогеосфера", "витасфера", "эпигенема"],
    "биогеоценоз": ["экосистема"],
    "биография": ["жизнеописание", "жизнеописанье", "био", "житие", "жизнь"],
    "биогумус": ["вермикомпост"],
    "биодеградация": ["биоразложение"],
    "биодобавка": ["бад", "биостимулятор"],
    "биойогурт": ["бифидойогурт"],
    "биокатализ": ["ферментативный катализ"],
    "биокоррозия": ["биоразрушение"],
    "биолог": ["учитель", "биологии"],
    "биологизировав": ["биологизировавши"],
    "биологизировавши": ["биологизировав"],
    "биологическая мембрана": ["биомембрана"],
    "биологическая статистика": ["биостатистика"],
    "биологически активная добавка": ["бад"],
    "биологический маркер": ["биомаркер"],
    "биологическое оружие": ["биооружие"],
    "биологичка": ["биологиня", "биологица"],
    "биология океана": ["морская биология", "биологическая океанология", "биологическая океанография"],
    "биом": ["биоценоз"],
    "биомагнетизм": ["животный магнетизм"],
    "биомама": ["биомать"],
    "биомать": ["биомама"],
    "биомембрана": ["биологическая мембрана"],
    "биометрика": ["биометрия"],
    "биометрический паспорт": ["биопаспорт"],
    "биометрия": ["биоматематика"],
    "биомиметика": ["бионика"],
    "биомицин": ["хлортетрациклин"],
    "биомодификация": ["кондиционирование"],
    "биомусор": ["биологический мусор"],
    "биономика": ["биономия", "экология"],
    "биономия": ["биономика", "экология"],
    "биоотец": ["биопапа"],
    "биопапа": ["биоотец"],
    "биопотенциал": ["биоток", "биоэлектрический потенциал"],
    "биопунктура": ["фармакопунктура"],
    "биоритм": ["биологический ритм"],
    "биоробот": ["андроид", "зомби"],
    "биос": ["бсвв"],
    "биосигнатура": ["биомаркер"],
    "биосистема": ["экосистема"],
    "биоспелеология": ["спелеобиология"],
    "биостатистика": ["биологическая статистика"],
    "биостратиграфия": ["стратиграфический", "палеонтология"],
    "биосфера": ["естественная среда"],
    "биотин": ["витамин н"],
    "биоток": ["биопотенциал"],
    "биотоп": ["природная зона"],
    "биохимия": ["биологическая химия", "физиологическая химия"],
    "биоценоз": ["ценоз", "биогеоценоз"],
    "биоценология": ["синэкология"],
    "биоэкология": ["экология", "биология"],
    "биоэлемент": ["минеральный элемент"],
    "бипартизм": ["двухпартийность"],
    "бипатрид": ["биполид"],
    "бипедализм": ["бипедия", "двуногость"],
    "бипериодический": ["дипериодический"],
    "бипирамида": ["дипирамида"],
    "бипирамидальный": ["дипирамидальный"],
    "биплан": ["кукурузник"],
    "бипланарный": ["двухплоскостной"],
    "бипланный": ["биплановый"],
    "биплановый": ["бипланный"],
    "бипозитроний": ["дипозитроний"],
    "биполид": ["бипатрид"],
    "биполярка": ["биполярное расстройство"],
    "биполярник": ["маниакально-депрессивный", "биполярщик", "флюгер"],
    "биполярное расстройство": ["бар", "биполярное аффективное расстройство", "маниакально-депрессивный психоз"],
    "биполярный": ["двуполюсный", "двухполюсный", "диполярный"],
    "биполярщик": ["биполярник"],
    "бипотенциальный": ["двухпотенциальный", "иммерсионный"],
    "бипризма": ["бипризма френеля", "бипризма гершеля"],
    "бипротон": ["дипротон"],
    "бирав": ["биравши"],
    "биравши": ["бирав"],
    "бирге": ["биргя"],
    "биргя": ["бирге", "бирга"],
    "бире": ["бу"],
    "биржа": ["торговая площадка", "рынок"],
    "биринчи": ["бурунгъу"],
    "бирка": ["лейб", "метка", "ярлык"],
    "бирковав": ["бирковавши"],
    "бирковавши": ["бирковав"],
    "бирманец": ["мьянмец"],
    "бирманистика": ["бирмановедение"],
    "бирмановедение": ["бирманистика"],
    "биромантичность": ["гетероромантичность", "гоморомантичность"],
    "бирь": ["бир"],
    "бирюк": ["волк", "бука", "нелюдим"],
    "бирюч": ["глашатай", "вестник", "бирич"],
    "бис": ["фора"],
    "бисак": ["бисакодил"],
    "бисанфа": ["редест", "родосто", "текирдаг"],
    "бисау-гвинеец": ["гвинеец"],
    "бисау-гвинейка": ["гвинейка"],
    "бисексуал": ["бисексуалист"],
    "бисексуализм": ["бисексуальность"],
    "бисексуалист": ["бисексуал"],
    "бисексуальный": ["двуполый"],
    "бисер": ["жемчуг", "перл", "жемчужина"],
    "бисиклет": ["велосипед"],
    "бисиклета": ["удар ножницами"],
    "бисировав": ["бисировавши"],
    "бисировавши": ["бисировав"],
    "бискуп": ["епископ"],
    "бислама": ["бичламар"],
    "бислой": ["бимолекулярный липидный слой"],
    "биссос": ["биссус", "виссон"],
    "биссус": ["биссос", "виссон"],
    "бистури": ["скальпель"],
    "бисульфат": ["гидросульфат"],
    "бисульфид": ["дисульфид"],
    "бисульфидный": ["дисульфидный"],
    "бисульфит": ["гидросульфит"],
    "бит": ["разряд"],
    "бит-карта": ["битовая карта"],
    "бит-музыка": ["биг-бит"],
    "битая ссылка": ["потерянная ссылка"],
    "битая хаза": ["битая хата"],
    "битва": ["сражение", "бой"],
    "битиш": ["битис"],
    "биткоин": ["бтк", "биткойн", "биток", "цифровое золото"],
    "биткойн": ["биткоин", "биток"],
    "битловка": ["бодлон", "водолазка", "гольф"],
    "битломан": ["битлопоклонник", "битлопочитатель", "битлолюб", "битловщик", "битлофан", "битлист"],
    "битломанка": ["битлопоклонница", "битловщица"],
    "биток": ["биточек", "бита", "биткоин", "биткойн"],
    "биточек": ["биток"],
    "битрачех": ["битрачэх"],
    "битрубль": ["крипторубль"],
    "битумизация": ["битуминизация"],
    "битуминизация": ["битумизация"],
    "битуминировав": ["битуминировавши"],
    "битуминировавши": ["битуминировав"],
    "битуминозный": ["битумный"],
    "битумный": ["битуминозный"],
    "битый каравай": ["битый пирог", "дутый пирог"],
    "битый-перебитый": ["замордованный", "много", "испытавший", "банальный"],
    "бить": ["ударять", "стучать", "избивать", "хлопать", "грохотать", "раскалывать", "разбивать", "заколачивать", "громить", "разить", "стрелять", "знобить", "извергаться", "взбивать", "брать"],
    "бить баклуши": ["бездельничать", "сачковать", "валять дурака", "считать ворон", "вола гонять"],
    "бить жилу": ["открывать жилу", "метать кровь"],
    "бить ключом": ["бить", "извергаться", "бурлить", "кипеть"],
    "бить по карману": ["разорять", "влетать в копеечку"],
    "бить челом": ["молить"],
    "биться": ["ударяться", "стукаться", "трепыхаться", "колотиться", "трудиться", "корпеть", "драться", "сражаться", "разбиваться", "сходиться"],
    "биться в дёсны": ["долбиться в дёсны", "хлестаться в десну", "шарахаться в десну"],
    "битьё": ["побои", "избиение", "разбивание"],
    "битюг": ["першерон", "ломовик"],
    "бифидойогурт": ["биойогурт"],
    "бифокальный": ["двухфокусный"],
    "бифункциональный": ["двухфункциональный", "дифункциональный"],
    "бихевиоризм": ["бихевиористика"],
    "бихевиористика": ["бихевиоризм"],
    "бихлорид": ["дихлорид"],
    "бихорка": ["фаланга"],
    "бихромат": ["дихромат"],
    "бихроматический": ["дихроматический"],
    "бицентрический": ["дицентрический"],
    "бицепс": ["бицуха"],
    "бицикл": ["дицикл"],
    "бициклический": ["бицикличный", "дициклический"],
    "бицуха": ["бицепс"],
    "бич": ["кнут", "плеть", "плётка", "нагайка", "арапник", "тройчатка", "хлыст", "погонялка", "витень", "пуга", "ременница"],
    "бич-волей": ["пляжный", "волейбол", "бичбол"],
    "бич-пакет": ["бичик"],
    "бичара": ["бич"],
    "бичбол": ["бич-волей", "пляжный", "волейбол"],
    "бичева": ["бечева"],
    "бичевав": ["бичевавши"],
    "бичевавши": ["бичевав"],
    "бичевание": ["порка"],
    "бичеватель": ["изобличитель"],
    "бичевать": ["лупцевать", "сечь", "хлестать", "обличать", "поносить", "разносить", "ругать", "язвить", "бурлачить"],
    "бичявэл": ["бичявэла"],
    "бичян": ["бичянь"],
    "бичянь": ["бичян"],
    "бичёвка": ["бечёвка", "бечева"],
    "бишек": ["ватан"],
    "бишкек": ["пишпек", "фрунзе"],
    "бишлакъ": ["бышлакъ"],
    "бишь": ["там", "точно", "припоминаю"],
    "бияв": ["бьяв"],
    "биёбон": ["бодия"],
    "биёбонгард": ["биёбоннавард"],
    "биёбоннавард": ["биёбонгард"],
    "биёред": ["биёретон", "оред"],
    "бла": ["бпла"],
    "бла-бла-бла": ["ля-ля-ля"],
    "блават": ["волошка", "шовк"],
    "благати": ["просити", "заклинати", "молити"],
    "благий": ["добрый", "хороший", "путный", "полезный", "добродетельный", "доблестный", "злой", "сердитый", "упрямый", "упорный", "своенравный", "неугомонный", "беспокойный", "дурной", "тяжелый"],
    "благим матом": ["неистово", "исступлённо", "истошно", "не благим матом", "лихим матом", "на лихой мат", "поспешно", "мгновенно", "молниеносно", "изо всех сил", "во весь опор", "во весь дух", "во всю прыть"],
    "благировать": ["хвастать", "высмеивать", "лгать", "врать"],
    "благо": ["добро", "польза"],
    "благовейный": ["почтительный"],
    "благоверная": ["супруга", "жена"],
    "благоверный": ["муж"],
    "благовествовав": ["благовествовавши"],
    "благовествовавши": ["благовествовав"],
    "благовестив": ["благовестивши"],
    "благовестивши": ["благовестив"],
    "благовестить": ["благовествовать"],
    "благовестник": ["евангелист"],
    "благовещение": ["евангелие"],
    "благовещенск": ["блага"],
    "благовещенье": ["благовещение"],
    "благовидный": ["миловидный", "благообразный"],
    "благоволение": ["благожелательство", "доброжелательство", "благосклонность", "милость"],
    "благоволенье": ["благоволение"],
    "благоволив": ["благоволивши"],
    "благоволивши": ["благоволив"],
    "благоволительность": ["доброжелательность"],
    "благоволительный": ["доброжелательный", "благосклонный"],
    "благоволить": ["покровительствовать"],
    "благовоние": ["благовонье"],
    "благовонный": ["ароматный", "душистый", "благоухающий"],
    "благовонье": ["благовоние"],
    "благовоспитанность": ["воспитанность"],
    "благовоспитанный": ["воспитанный"],
    "благовременье": ["благовремение"],
    "благоговев": ["благоговевши"],
    "благоговевши": ["благоговев"],
    "благоговейно": ["почтительно", "сверхуважительно"],
    "благоговейный": ["почтительный", "уважительный"],
    "благоговение": ["пиетет", "богобоязненность", "почтение"],
    "благоговеть": ["преклоняться"],
    "благодарение": ["благодарность", "евхаристия"],
    "благодарив": ["благодаривши"],
    "благодаривши": ["благодарив"],
    "благодарный": ["признательный", "стоящий"],
    "благодарствовав": ["благодарствовавши"],
    "благодарствовавши": ["благодарствовав"],
    "благодаря": ["из-за", "из", "от", "по", "за", "по причине", "вследствие", "в результате", "ввиду", "в силу", "при помощи"],
    "благоденствие": ["благополучие", "процветание"],
    "благоденствовав": ["благоденствовавши"],
    "благоденствовавши": ["благоденствовав"],
    "благоденствовать": ["преуспевать", "процветать"],
    "благодетель": ["благотворитель", "покровитель"],
    "благодетельно": ["благоприятно", "благотворно"],
    "благодетельствовав": ["благодетельствовавши"],
    "благодетельствовавши": ["благодетельствовав"],
    "благодетельствовать": ["благотворить"],
    "благодеяние": ["благотворение", "щедрота", "благотворенье", "благодеянье"],
    "благодеянье": ["добро", "услуга", "милость", "щедрота", "благотворение", "благодеяние", "одолженье", "благотворенье"],
    "благодушествовав": ["благодушествовавши"],
    "благодушествовавши": ["благодушествовав"],
    "благодушие": ["мягкосердечность", "доброжелательность"],
    "благодушный": ["мягкосердечный", "доброжелательный", "довольный", "добродушный"],
    "благожелательно": ["доброжелательно"],
    "благожелательность": ["доброжелательность"],
    "благожелательный": ["доброжелательный"],
    "благожелательствовав": ["благожелательствовавши"],
    "благожелательствовавши": ["благожелательствовав"],
    "благозвучие": ["благозвучность"],
    "благозвучный": ["эвфоничный"],
    "благой": ["добрый", "хороший"],
    "благолепие": ["великолепие", "благообразие"],
    "благолепье": ["благолепие"],
    "благонадёжно": ["надёжно", "преданно"],
    "благонадёжность": ["лояльность"],
    "благонадёжный": ["надёжный", "лояльный"],
    "благонамеренный": ["благонадёжный"],
    "благонравие": ["благовоспитанность", "благонравность", "благонравье"],
    "благонравность": ["благонравие"],
    "благонравный": ["благопристойный", "благоприличный", "скромный", "степенный", "чинный"],
    "благонравье": ["благонравие"],
    "благообразие": ["благообразье", "благоличие", "благообразность", "благолепие", "благопристойность"],
    "благополучие": ["благоденствие", "счастье", "довольство", "обеспеченность"],
    "благополучно": ["успешно", "с успехом", "удачно", "счастливо", "благословенно", "безбедно"],
    "благополучность": ["благополучие"],
    "благополучный": ["успешный", "удачный"],
    "благополучье": ["благополучие"],
    "благопоспешав": ["благопоспешавши"],
    "благопоспешавши": ["благопоспешав"],
    "благопоспешествовав": ["благопоспешествовавши"],
    "благопоспешествовавши": ["благопоспешествовав"],
    "благопоспешествовать": ["благопоспешать"],
    "благоприличие": ["благоприличье"],
    "благоприобретав": ["благоприобретавши"],
    "благоприобретавши": ["благоприобретав"],
    "благопристойность": ["благочиние"],
    "благопристойный": ["приличный", "порядочный", "благочинный"],
    "благоприятель": ["друг", "приятель", "товарищ", "доброжелатель"],
    "благоприятно": ["благотворно"],
    "благоприятствовав": ["благоприятствовавши"],
    "благоприятствовавши": ["благоприятствовав"],
    "благоприятствовать": ["содействовать", "способствовать"],
    "благоразумие": ["рассудительность", "осмотрительность", "благоразумность", "здравый смысл", "благоразумье"],
    "благоразумничав": ["благоразумничавши"],
    "благоразумничавши": ["благоразумничав"],
    "благоразумно": ["разумно", "здраво", "трезво", "рассудительно", "целесообразно"],
    "благоразумность": ["благоразумие", "благоразумье"],
    "благоразумье": ["благоразумие"],
    "благорасположение": ["благосклонность"],
    "благорасположенность": ["благоволение", "благожелательность"],
    "благорасположенный": ["доброжелательный", "благосклонный"],
    "благорассудный": ["здравомыслящий", "благорассудительный", "благорассудливый", "здравый"],
    "благорассуждение": ["здравомыслие", "усмотрение", "рассмотрение"],
    "благородив": ["благородивши"],
    "благородивши": ["благородив"],
    "благородие": ["благородье"],
    "благородность": ["благородство"],
    "благородный": ["знатный", "дворянский", "высокородный", "аристократический", "великодушный", "высоконравственный", "инертный"],
    "благородный газ": ["инертный газ", "редкий газ"],
    "благородье": ["благородие"],
    "благосклонно": ["доброжелательно", "милостиво", "благожелательно", "дружелюбно", "дружественно", "дружески", "приязненно"],
    "благосклонность": ["доброжелательность"],
    "благосклонный": ["доброжелательный"],
    "благосклонствовав": ["благосклонствовавши"],
    "благосклонствовавши": ["благосклонствовав"],
    "благословення": ["благословенство"],
    "благословенье": ["благословение"],
    "благословив": ["благословивши"],
    "благословивши": ["благословив"],
    "благословленье": ["благословление"],
    "благословляв": ["благословлявши"],
    "благословлявши": ["благословляв"],
    "благосостоянье": ["благосостояние"],
    "благостыня": ["милость", "милосердие", "благодеяние"],
    "благость": ["доброта", "милосердие", "прощение", "доброжелательность", "благодать"],
    "благотворение": ["благотворительность"],
    "благотворенье": ["благотворение"],
    "благотворив": ["благотворивши"],
    "благотворивши": ["благотворив"],
    "благотворительность": ["благотворительство", "благотворение"],
    "благотворительный": ["милосердный", "сердобольный", "филантропический"],
    "благотворительство": ["благотворительность"],
    "благотворительствовав": ["благотворительствовавши"],
    "благотворительствовавши": ["благотворительствовав"],
    "благотворить": ["благотворительствовать"],
    "благотворно": ["благоприятно"],
    "благоусмотрение": ["решение", "решенье", "благоусмотренье"],
    "благоусмотренье": ["решение", "решенье", "благоусмотрение"],
    "благоустраивав": ["благоустраивавши"],
    "благоустраивавши": ["благоустраивав"],
    "благоустроив": ["благоустроивши"],
    "благоустроивши": ["благоустроив"],
    "благоустройство": ["благоустраивание", "обустройство", "благоустроенность"],
    "благоутробие": ["милосердие"],
    "благоухав": ["благоухавши"],
    "благоухавши": ["благоухав"],
    "благоухание": ["аромат", "благовоние", "прелесть"],
    "благоуханье": ["благоухание"],
    "благоухающий": ["благовонный", "ароматный"],
    "благочестивость": ["религиозность", "набожность", "правоверность", "богоугодность", "смиренность"],
    "благочестивый": ["религиозный", "набожный", "правоверный", "богоугодный", "смиренный"],
    "благочестие": ["благоугодность", "благонравие", "ваше благочестие"],
    "благочестье": ["благочестие"],
    "благочиние": ["благопристойность"],
    "благёр": ["хвастун", "враль", "лгун"],
    "благёрство": ["хвастовство"],
    "бладой": ["младой", "молодой"],
    "блажен": ["блажа", "блашко"],
    "блаженство": ["блаженствие"],
    "блаженствовав": ["блаженствовавши"],
    "блаженствовавши": ["блаженствовав"],
    "блаженствовать": ["наслаждаться"],
    "блажив": ["блаживши"],
    "блаживши": ["блажив"],
    "блажить": ["своенравничать"],
    "блажной": ["сумасбродный", "взбалмошный", "шалый"],
    "блажь": ["дурь", "каприз", "прихоть", "сумасбродство"],
    "блазнь": ["соблазн", "искушение"],
    "блайзер": ["блейзер"],
    "блакитний": ["голубий"],
    "бланбек": ["молокосос", "щенок", "юнец"],
    "бланк-заказ": ["бланк", "заказ"],
    "бланк-фильм": ["бланкфильм"],
    "бланкет": ["фрикасе"],
    "бланкировав": ["бланкировавши"],
    "бланкировавши": ["бланкировав"],
    "бланманже": ["бламанже"],
    "бланш": ["фонарь"],
    "бланшировав": ["бланшировавши"],
    "бланшировавши": ["бланшировав"],
    "бластоидея": ["морские бутоны"],
    "бластома": ["опухоль", "неоплазма", "новообразование"],
    "бластомеротомия": ["бластотомия"],
    "бластопатия": ["бластоз"],
    "бластопор": ["гастропор", "первичный рот"],
    "бластотомия": ["бластомеротомия"],
    "бластула": ["бластосфера"],
    "блатарь": ["блатной"],
    "блатная музыка": ["арго", "криминальный жаргон", "воровской язык", "байковый язык"],
    "блатная песня": ["блатняк", "блатнятина", "русский шансон"],
    "блатняжка": ["блатняга"],
    "блатняк": ["блатной"],
    "блато": ["болото"],
    "блатовав": ["блатовавши"],
    "блатовавши": ["блатовав"],
    "блатхата": ["хаза", "малина"],
    "блауграна": ["блаугранас", "сине-гранатовые"],
    "блашко": ["блажа", "блажен"],
    "блевав": ["блевавши"],
    "блевавши": ["блевав"],
    "блевание": ["блевота", "рвота", "блеванье"],
    "блеванув": ["блеванувши"],
    "блеванувши": ["блеванув"],
    "блевать": ["рыгать", "рвать", "тошнить", "звать ихтиандра", "кормить ихтиандра", "ихтиандра звать", "ихтиандра кормить"],
    "блевота": ["блевание", "рвота", "блевотина"],
    "блевотина": ["блевота"],
    "бледнев": ["бледневши"],
    "бледневши": ["бледнев"],
    "бледнив": ["бледнивши"],
    "бледнивши": ["бледнив"],
    "бледно": ["неярко", "тускло", "неотчётливо", "смутно"],
    "бледно-голубой": ["голубой"],
    "бледно-жёлтый": ["жёлто-бледный"],
    "бледно-зелёный": ["салатный", "фисташковый"],
    "бледно-розовый": ["нежно-розовый"],
    "бледность": ["блёклость", "невыразительность"],
    "бледнота": ["бледность", "матовость", "тусклость", "мутность"],
    "бледный": ["неяркий", "тусклый", "неотчётливый", "неопределённый", "неясный", "смутный", "невыразительный", "бесцветный"],
    "бледный вид и тихая походка": ["бледный вид и макаронная походка"],
    "бледный шар": ["палеостриатум", "паллидум"],
    "блезир": ["удовольствие", "приятность", "забава", "шутка", "потеха", "услада", "плезир", "видимость", "проформа", "фикция", "вид"],
    "блейзер": ["блайзер"],
    "блек-джек": ["двадцать одно"],
    "блеклист": ["чёрный список"],
    "блеклый": ["бледный", "жухлый", "неяркий", "поблеклый", "поблекший", "пожухлый", "тусклый", "увядший", "увялый"],
    "блекотав": ["блекотавши"],
    "блекотавши": ["блекотав"],
    "бленда": ["обманка"],
    "блендер": ["миксер"],
    "блендинг": ["словослияние", "телескопия"],
    "блеск": ["сверкание"],
    "блескучий": ["блестящий"],
    "блеснив": ["блеснивши"],
    "блеснивши": ["блеснив"],
    "блеснув": ["блеснувши"],
    "блеснувши": ["блеснув"],
    "блеснуть": ["сверкнуть", "промелькнуть", "мелькнуть"],
    "блестев": ["блестевши"],
    "блестевши": ["блестев"],
    "блестеть": ["сиять", "сверкать"],
    "блестяще": ["пышно", "роскошно", "блистательно", "превосходно"],
    "блестящий": ["блистающий"],
    "блефанув": ["блефанувши"],
    "блефанувши": ["блефанув"],
    "блефовав": ["блефовавши"],
    "блефовавши": ["блефовав"],
    "блефование": ["блеф"],
    "блехнум колосистый": ["дербянка колосистая"],
    "блеяв": ["блеявши"],
    "блеявши": ["блеяв"],
    "блеянье": ["блеяние"],
    "ближний": ["близкий", "соседний", "недалёкий", "близлежащий", "окрестный", "кратчайший"],
    "ближний восток": ["средний восток"],
    "ближник": ["рукопашник", "милишник"],
    "близив": ["близивши"],
    "близивши": ["близив"],
    "близить": ["приближать"],
    "близиться": ["приближаться", "быть на носу"],
    "близкие": ["семейный круг", "домочадцы"],
    "близкий": ["ближний", "недалёкий", "близлежащий", "короткий"],
    "близко": ["неподалёку", "вблизи", "поблизости", "недалеко", "невдалеке", "рядом", "рукой подать", "интимно", "на короткой ноге"],
    "близко от": ["вблизи", "рядом с", "около", "близ"],
    "близлежащий": ["близкий", "ближний", "недалёкий", "окрестный"],
    "близнячка": ["двойница"],
    "близорукий": ["слепошарый", "недальновидный"],
    "близорукость": ["миопия", "недальновидность", "непроницательность", "ограниченность"],
    "близость": ["секс", "совокупление", "сношение", "соитие"],
    "близший": ["ближайший"],
    "близь": ["близость"],
    "близький": ["недалекий", "приближений", "схожий"],
    "бликовав": ["бликовавши"],
    "бликовавши": ["бликовав"],
    "блин": ["диск"],
    "блин-компот": ["блин", "бляха-муха", "чёрт возьми", "чёрт побери", "муха-бляха", "ёшкин кот", "ёканый бабай", "ёханый бабай", "ёкарный бабай", "японский городовой"],
    "блиндаж": ["убежище"],
    "блиндировав": ["блиндировавши"],
    "блиндировавши": ["блиндировав"],
    "блиндированный": ["бронированный"],
    "блинкин": ["блинкен"],
    "блинковав": ["блинковавши"],
    "блинковавши": ["блинковав"],
    "блинница": ["блинник"],
    "блинообразный": ["плоский", "круглый"],
    "блинтовав": ["блинтовавши"],
    "блинтовавши": ["блинтовав"],
    "блинчик": ["лягушки", "стоунскиппинг"],
    "блискавиця": ["блискавка"],
    "блистав": ["блиставши"],
    "блиставши": ["блистав"],
    "блистательно": ["блестяще", "великолепно", "с блесокм"],
    "блистательный": ["блестящий", "ослепительный", "восхитительный", "превосходный", "блистающий", "сверкающий"],
    "блистать": ["блестеть", "сверкать", "выделяться"],
    "блицкриг": ["молниеносная война"],
    "блог": ["доска обсуждений", "лента сообщений", "интернет-дневник", "веблог"],
    "блог-платформа": ["блогохостинг"],
    "блоггер": ["интернет-журналист"],
    "блоггинг": ["блогинг"],
    "блогер": ["блоггер"],
    "блогерка": ["блогерша"],
    "блогохостинг": ["блог-платформа"],
    "блок": ["полиспаст", "таль", "калитка"],
    "блок-хаус": ["блокхаус"],
    "блок-шот": ["горшок"],
    "блокада": ["осада", "блокада ленинграда", "изоляция", "пробка", "затор"],
    "блокада ленинграда": ["блокада"],
    "блокадопрорыватель": ["блокадный бегун"],
    "блокбастер": ["бестселлер", "шлягер"],
    "блокировав": ["блокировавши"],
    "блокировавши": ["блокировав"],
    "блокирование": ["блокировка"],
    "блокировать": ["останавливать", "преграждать", "прекращать", "объединять"],
    "блокировка": ["блокирование"],
    "блокировщик": ["блокиратор", "блокатор"],
    "блокнот": ["записная книжка", "ноутбук"],
    "блокпост": ["застава", "кпп"],
    "блокшив": ["блокшип"],
    "блокшип": ["блокшив"],
    "блондив": ["блондивши"],
    "блондивши": ["блондив"],
    "блондин": ["белокурый", "светловолосый"],
    "блондинка": ["белянка"],
    "блондирование": ["обесцвечивание", "осветление"],
    "блоха": ["ничтожество", "вошь", "тля", "человечишко"],
    "блохастый": ["блошистый", "блошливый"],
    "блочив": ["блочивши"],
    "блочивши": ["блочив"],
    "блочить": ["блокировать"],
    "блошиный рынок": ["блошиный базар", "вещевой рынок", "развал", "барахолка", "толкучий рынок", "толкучка", "толкучий", "толчок", "толкачик", "толкун"],
    "блошистый": ["блохастый", "блошливый"],
    "блошливый": ["блохастый", "блошистый"],
    "блошница": ["арестантская", "казематка", "камера"],
    "блуд": ["распутство", "разврат", "прихоть"],
    "блудив": ["блудивши"],
    "блудивши": ["блудив"],
    "блудилище": ["бордель", "бардак", "дом терпимости", "капище"],
    "блудить": ["блуждать", "плутать"],
    "блудкавост": ["безвкусица", "безвкусие", "безсмислица", "нелепост", "глупост", "баналност"],
    "блудни": ["блуд", "мотовство"],
    "блудник": ["распутник", "развратник"],
    "блудница": ["шалава", "проститутка"],
    "блудный сын": ["раскаявшийся грешник"],
    "блудодей": ["прелюбодей", "развратник"],
    "блудодеяние": ["блуд", "прелюбодейство", "прелюбодеяние", "любодеяние"],
    "блуждав": ["блуждавши"],
    "блуждавши": ["блуждав"],
    "блужданье": ["блуждание"],
    "блуза": ["блузка"],
    "блузка": ["блуза"],
    "блукав": ["блукавши"],
    "блукавши": ["блукав"],
    "блукать": ["ходить", "гулять", "бродить", "блуждать"],
    "блул": ["кавиц", "пепук", "шви"],
    "блум": ["блюм"],
    "блупер": ["шутер", "бигбой", "подветренный спинакер", "киноляп"],
    "блъха": ["блоха", "бълоха"],
    "блэк": ["блэк-метал"],
    "блэк-метал": ["блэк"],
    "блэкарь": ["блэк-металлист", "блэкушник"],
    "блэкаут": ["обесточка"],
    "блэклист": ["чёрный список"],
    "блю-чипс": ["голубые фишки"],
    "блювал": ["синий кит", "голубой кит", "большой полосатик"],
    "блювота": ["блювотина", "блювання"],
    "блюдо": ["тарелка", "перемена", "кушанье"],
    "блюдолиз": ["лизоблюд", "паразит", "нахлебник"],
    "блюдце": ["тарелочка", "западина", "под", "впадина", "понижение", "котловина", "яма"],
    "блюдъ": ["блюдо"],
    "блюм": ["блум"],
    "блюсти": ["беречь", "охранять", "стеречь", "соблюдать"],
    "блюститель порядка": ["страж закона", "правоохранитель"],
    "блютус": ["синезуб"],
    "бля": ["блядь", "ёбть", "ну"],
    "блядина": ["блядища"],
    "блядовав": ["блядовавши"],
    "блядовавши": ["блядовав"],
    "блядовать": ["блядствовать"],
    "блядонув": ["блядонувши"],
    "блядонувши": ["блядонув"],
    "блядословие": ["словоблудие", "языкоблудие"],
    "блядоёбина": ["блядолюб", "блядодей", "блядомудина"],
    "блядоёбина хуеротая": ["блядомудина пиздокрылая", "блядомудина пиздорылая"],
    "блядский": ["блядиный", "блядовский", "путанский", "сучий", "распущенный", "неподобающий", "лживый", "развратный", "разгульный", "плохой", "ужасный", "нехороший", "противный"],
    "блядство": ["разврат", "распутство", "неразбериха", "непорядок", "хаос", "бардак"],
    "блядствовав": ["блядствовавши"],
    "блядствовавши": ["блядствовав"],
    "блядствовать": ["распутничать", "блядовать"],
    "блядун": ["потаскун", "распутник", "бабник", "ловелас"],
    "блядь": ["пустословие", "пустяки", "блядник", "блядослов"],
    "блядькав": ["блядькавши"],
    "блядькавши": ["блядькав"],
    "блядькнув": ["блядькнувши"],
    "блядькнувши": ["блядькнув"],
    "блякав": ["блякавши"],
    "блякавши": ["блякав"],
    "блякнув": ["блякнувши"],
    "блякнувши": ["блякнув"],
    "блясък": ["лъскавина", "сияние", "лъч", "светлина"],
    "бляха": ["бляшка", "евробляха", "противень", "сковорода", "оплеуха", "пощёчина"],
    "бляха-муха": ["блин", "блин-компот", "чёрт возьми", "чёрт побери", "муха-бляха", "ёшкин кот", "ёканый бабай", "ёханый бабай", "ёкарный бабай", "японский городовой"],
    "бляхер": ["евробляхарь", "евробляхер"],
    "блёв": ["блевание", "блевота", "рвота", "блевотина"],
    "блёкнув": ["блёкнувши"],
    "блёкнувши": ["блёкнув"],
    "блёстка": ["пайетка"],
    "бмп": ["бээмпэ", "бээмпэшка"],
    "бмрт": ["большой морозильный рыболовный траулер"],
    "бнр": ["белорусская народная республика"],
    "бо": ["ибо", "понеже", "потому что", "же", "ведь"],
    "боб": ["борис", "боря", "боба"],
    "бобик": ["боба", "бобочка", "боренька"],
    "бобина": ["моток", "катушка", "ролик"],
    "бобинка": ["катушечка"],
    "бобир": ["йорж"],
    "бобовник": ["лабурнум"],
    "бобр": ["бобёр"],
    "бобрик": ["ёжик"],
    "бобриком": ["под бобрик"],
    "бобровлянин": ["бобровец", "бобровчанин"],
    "бобровчанин": ["бобровец", "бобровлянин"],
    "бобруец": ["бобруйчанин"],
    "бобруйчанин": ["бобруец"],
    "бобтейл": ["староанглийская овчарка"],
    "бобылий": ["холостяцкий"],
    "бобыличий": ["бобылёв", "бобылий", "бобыльский"],
    "бобылёв": ["бобылий", "бобыльский", "бобыличий"],
    "бобылём": ["одиноко"],
    "бобёр": ["бобр"],
    "бов": ["одб"],
    "бог": ["божество", "господь", "всевышний", "божок", "дока", "спец"],
    "бог ведает": ["бог знает"],
    "бог им судья": ["господь им судья"],
    "бог отец": ["господь", "яхве", "иегова"],
    "бог шельму метит": ["бог плута метит"],
    "бога за яйца ухватить": ["ухватить бога за бороду", "ухватить бога за яйца", "бога за яйца поймать"],
    "богаделенка": ["богаделка"],
    "богаделенный": ["богадельный"],
    "богаделка": ["богаделенка"],
    "богадельня": ["дом призрения"],
    "богарадничав": ["богарадничавши"],
    "богарадничавши": ["богарадничав"],
    "богаташ": ["богат", "капиталист", "имотен", "паралия"],
    "богатев": ["богатевши"],
    "богатевши": ["богатев"],
    "богатей": ["богач", "толстосум"],
    "богатейка": ["богачка"],
    "богатейский": ["богаческий"],
    "богатение": ["обогащение"],
    "богатенько": ["богато"],
    "богатеть": ["обогащаться"],
    "богатив": ["богативши"],
    "богативши": ["богатив"],
    "богатить": ["обогащать"],
    "богато": ["безбедно"],
    "богатство": ["состояние", "обилие", "роскошь", "гобзование"],
    "богатый": ["зажиточный", "обеспеченный", "состоятельный", "роскошный", "шикарный", "дорогой", "обильный", "изобильный", "щедрый", "обсыпной", "широкий", "богатей"],
    "богатырка": ["силачка"],
    "богатырша": ["богатырка", "силачка"],
    "богатырь": ["витязь", "силач", "крепыш", "исполин"],
    "богач": ["богатей", "толстосум", "богатый"],
    "богаческий": ["богатейский"],
    "богачество": ["богатство"],
    "богачествовать": ["роскошествовать"],
    "богачка": ["богатейка"],
    "богдан": ["феодот", "деусдедит"],
    "богемничав": ["богемничавши"],
    "богемничавши": ["богемничав"],
    "богемский": ["чешский"],
    "богила": ["бугила"],
    "богиня": ["божество"],
    "богоборец": ["богоборник"],
    "богоборчество": ["богоотступничество", "атеизм"],
    "богобоязливость": ["богобоязненность"],
    "богобоязливый": ["богобоязненный"],
    "богобоязненность": ["богобоязливость"],
    "боговер": ["верователь", "верующий", "теист", "боговерец"],
    "боговерец": ["боговер"],
    "богодул": ["бомж", "бродяга", "пьяница"],
    "боголюб": ["боголюбец"],
    "боголюбский": ["боголюбовский"],
    "богомаз": ["иконописец"],
    "богоматерь": ["богородица", "высочайшая повелительница ангелов", "дева мария", "дева", "мадонна", "матерь божья", "царица небесная"],
    "богомерзкий": ["безбожный", "нечестивый"],
    "богомил": ["богумил"],
    "богомол": ["богомолец"],
    "богомолец": ["богомол", "паломник", "пилигрим"],
    "богомолье": ["паломничество"],
    "богомольнее": ["богомольней"],
    "богомольней": ["богомольнее"],
    "богоносный": ["теофорный"],
    "богооправдание": ["теодицея"],
    "богоотступник": ["вероотступник"],
    "богоотступничество": ["апостасия", "вероотступничество"],
    "богородец": ["богородчанин"],
    "богородица": ["богоматерь", "матерь божья", "дева мария", "дева", "мадонна", "царица небесная", "высочайшая повелительница ангелов"],
    "богородчанин": ["богородец"],
    "богослов": ["теолог", "богословец"],
    "богословие": ["теология", "богословье"],
    "богословский": ["теологический", "богословный"],
    "богословствовав": ["богословствовавши"],
    "богословствовавши": ["богословствовав"],
    "богословье": ["богословие"],
    "богослужебний": ["богослужбовий"],
    "богослужебный": ["литургический"],
    "богослуженье": ["богослужение"],
    "богота": ["санта-фе-де-богота"],
    "боготворив": ["боготворивши"],
    "боготворивши": ["боготворив"],
    "боготец": ["боготинец"],
    "боготинец": ["боготец"],
    "богоугодное заведение": ["благотворительный", "учреждение"],
    "богохульница": ["кощунница"],
    "богохульничав": ["богохульничавши"],
    "богохульничавши": ["богохульничав"],
    "богохульство": ["кощунство", "святотатство"],
    "богохульствовав": ["богохульствовавши"],
    "богохульствовавши": ["богохульствовав"],
    "богочеловек": ["человекобог", "иисус христос", "сын", "бог-сын", "сверхчеловек"],
    "богоявление": ["теофания", "явление", "эпифания", "просвещение"],
    "богумил": ["богомил", "адамит"],
    "богумила": ["богомила"],
    "богумильство": ["богомильство"],
    "богхед": ["торбанит"],
    "бод": ["бит в секунду"],
    "бодав": ["бодавши"],
    "бодавши": ["бодав"],
    "бодайбо": ["бодайбинка"],
    "боданув": ["боданувши"],
    "боданувши": ["боданув"],
    "боданье": ["бодание"],
    "боди": ["комбидрес"],
    "боди-арт": ["боди-пейнтинг"],
    "боди-пейнтинг": ["боди-арт"],
    "бодибилдер": ["культурист"],
    "бодибилдинг": ["атлетизм", "культуризм"],
    "бодил": ["трън", "шип"],
    "бодипейнтинг": ["боди-арт"],
    "бодипозитивист": ["бодипозитивщик"],
    "бодипозитивщик": ["бодипозитивист"],
    "бодиринг": ["хиёр"],
    "бодия": ["биёбон"],
    "бодиягард": ["бодиянишин", "чодирнишин"],
    "бодиянишин": ["бодиягард", "чодирнишин"],
    "бодливый": ["бодучий"],
    "бодлон": ["бадлон", "водолазка"],
    "боднув": ["боднувши"],
    "боднувши": ["боднув"],
    "бодрее": ["лучше"],
    "бодрив": ["бодривши"],
    "бодривши": ["бодрив"],
    "бодрствовав": ["бодрствовавши"],
    "бодрствовавши": ["бодрствовав"],
    "бодрствование": ["бдение"],
    "бодрствованье": ["бодрствование"],
    "бодрствовать": ["бдеть"],
    "бодрый": ["бойкий", "весёлый", "здоровый", "оживлённый", "энергичный", "деятельный"],
    "бодряк": ["бокряк", "здоровяк", "весельчак", "бодрость"],
    "бодрячком": ["бодро", "бодренько"],
    "бодрячок": ["бодряк"],
    "бодун": ["похмелье", "сушняк"],
    "бодучий": ["бодливый"],
    "бодхаконасана": ["поза замкнутого угла", "поза сжатого треугольника"],
    "бодхисатва": ["бодхисаттва", "бодисатва"],
    "бодяжив": ["бодяживши"],
    "бодяживши": ["бодяжив"],
    "боевая готовность": ["боеготовность"],
    "боевая задача": ["тактическая задача"],
    "боевичка": ["военнослужащая"],
    "боевое крещение": ["дебют", "проверка", "экзамен"],
    "боевое отравляющее вещество": ["бов"],
    "боевой": ["военный", "строевой", "воинственный", "активный", "энергичный", "решительный"],
    "боевые действия": ["военные действия", "вооружённая борьба"],
    "боеготовность": ["боевая готовность", "боеспособность"],
    "боеприпас": ["огнеприпас"],
    "боеприпас объёмного взрыва": ["бов", "объёмно-детонирующий боеприпас", "одб"],
    "боерырга": ["кушарга"],
    "боеспособность": ["боеготовность"],
    "боец": ["воин", "воитель", "ратник", "красноармеец", "народоармеец"],
    "боже": ["боже мой"],
    "боже мой": ["боже", "ого"],
    "божедом": ["могильщик", "скудельник", "богадельник"],
    "божена": ["божана"],
    "божеский": ["божественный", "божий", "приемлемый"],
    "божественно": ["изумительно"],
    "божественный": ["прекрасный", "изумительный", "поразительный"],
    "божество": ["бог", "божок", "истукан", "кумир"],
    "божив": ["боживши"],
    "боживши": ["божив"],
    "божий": ["господень", "господний"],
    "божий дом": ["господень дом", "богадельня", "дом престарелых", "дом для престарелых"],
    "божий одуванчик": ["песок сыплется", "старая песочница"],
    "божить": ["блистать"],
    "божник": ["иконник"],
    "божьи люди": ["люди"],
    "божьим матом": ["благим матом", "дурным матом", "лихим матом", "недаровым матом", "непутным матом"],
    "божья коровка": ["кокцинеллида", "баран", "кроткий", "кроткий человек", "овечка", "смиренник", "схимник", "тихоня", "шёлковый"],
    "боз-ар": ["бозар"],
    "бозар": ["боз-ар"],
    "бозджаада": ["тенедос"],
    "боис": ["сабаб"],
    "бой": ["биение", "раскалывание", "разбитие", "осколки", "черепки", "битва", "баталия", "сражение", "дело", "схватка", "матч", "поединок", "боёк"],
    "бой быков": ["коррида", "тавромахия"],
    "бой-баба": ["баба с яйцами", "железная леди", "мужик в юбке"],
    "бой-бэнд": ["бой-бенд", "бойбэнд", "бойбенд"],
    "бой-девка": ["бой-баба"],
    "бойка": ["забивание", "разбивание", "бита"],
    "бойкий": ["быстрый", "ловкий", "расторопный", "проворный", "прыткий", "оживлённый", "динамичный"],
    "бойко": ["ловко", "расторопно", "быстро", "смело", "решительно", "находчиво"],
    "бойкот": ["эмбарго"],
    "бойкотировав": ["бойкотировавши"],
    "бойкотировавши": ["бойкотировав"],
    "бойкотирование": ["бойкот"],
    "бойле": ["шойле"],
    "бойлер": ["водонагреватель"],
    "бойлерная": ["котельная"],
    "бойлукъ": ["ястыкъ"],
    "бойница": ["амбразура"],
    "бойня": ["скотобойня", "резня", "мясорубка"],
    "бойфренд": ["ухажёр", "любовник", "кавалер", "парень", "возлюбленный", "жених", "избранник", "сожитель", "бойф"],
    "бойцовый": ["бойцовский", "боевой"],
    "бок": ["сторона"],
    "бок о бок": ["плечом к плечу"],
    "бокал": ["кубок", "кружка"],
    "бокатий": ["бокастий"],
    "бокинг": ["пауэрбокинг"],
    "боккэн": ["бокуто"],
    "боковик": ["маргиналия", "фонарик"],
    "боковуша": ["боковушка"],
    "бокогрей": ["февраль", "сечень", "снежень"],
    "бокорез": ["кусачки-бокорезы"],
    "бокряк": ["бодряк", "здоровяк"],
    "боксав": ["боксавши"],
    "боксавши": ["боксав"],
    "боксеры": ["хипсы"],
    "боксировав": ["боксировавши"],
    "боксировавши": ["боксировав"],
    "боксовав": ["боксовавши"],
    "боксовавши": ["боксовав"],
    "боксёр": ["мастер кожаной перчатки", "кулачный боец"],
    "боксёрша": ["боксёрка"],
    "бола": ["болас", "болеадорас"],
    "болботав": ["болботавши"],
    "болботавши": ["болботав"],
    "болботать": ["бормотать"],
    "болван": ["идол", "глупец", "дурак", "тупица", "остолоп", "кретин", "бестолочь", "идиот", "пень", "чурбан", "дубина", "балбес", "балда", "обалдуй"],
    "болванчик": ["дурачок"],
    "болгаризм": ["церковнославянизм"],
    "болгария": ["республика болгария"],
    "болгаро-российский": ["российско-болгарский"],
    "болгарский язык": ["болгарский"],
    "болдеринг": ["боулдеринг"],
    "болдинец": ["большеболдинец"],
    "болдырь": ["полукровка", "метис"],
    "боле": ["больше", "более"],
    "болев": ["болевши"],
    "болевой шок": ["травматический шок"],
    "болевши": ["болев"],
    "более": ["больше"],
    "более всего": ["больше", "часть", "случай", "в основном", "всё больше", "главным образом", "по большей части", "преимущество", "предпочтительно", "прежде всего", "преимущественно"],
    "более или менее": ["более-менее", "в некоторой степени", "сравнительно"],
    "более-менее": ["более или менее", "туда-сюда"],
    "болезненная склонность": ["болезненное влечение", "болезненная симпатия"],
    "болезненно": ["больно", "мучительно"],
    "болезненный": ["нездоровый", "хилый", "ненормальный", "мучительный", "больной"],
    "болезнетворность": ["вирулентность", "патогенность"],
    "болезнь": ["недуг", "заболевание", "хворь", "хвороба", "беда"],
    "болезнь аддисона": ["аддисонова болезнь", "гипокортицизм"],
    "болезнь альцгеймера": ["альцгеймер"],
    "болезнь лайма": ["клещевой", "иксодовый", "лаймский", "боррелиоз", "лайм-боррелиоз"],
    "болел": ["болельщик"],
    "болельщик": ["фанат", "болел", "фан"],
    "боленье": ["боление"],
    "болеслав": ["вячеслав"],
    "болеть": ["хворать", "недомогать", "страдать", "переживать", "сочувствовать", "сопереживать", "волноваться", "заботиться", "скорбеть", "жалеть"],
    "болеутоление": ["аналгезия"],
    "болеутоляющий": ["обезболивающий", "противоболевой"],
    "боливарианский": ["боливарский"],
    "болиголов": ["омег"],
    "боллер": ["стритболист"],
    "болник": ["болен", "недъгав"],
    "болона": ["кап"],
    "болониец": ["болонец"],
    "болонка": ["бишон"],
    "болотистость": ["топкость", "заболоченность"],
    "болотистый": ["заболоченный"],
    "болотить": ["заболачивать"],
    "болотный газ": ["метан"],
    "болото": ["бара", "блато", "гадюшник", "обломовщина"],
    "болотоход": ["трактор"],
    "болоховец": ["болоховчанин"],
    "болоховчанин": ["болоховец"],
    "болт": ["прут", "стрела"],
    "болтав": ["болтавши"],
    "болтавши": ["болтав"],
    "болтанка": ["качка"],
    "болтанув": ["болтанувши"],
    "болтанувши": ["болтанув"],
    "болтануть": ["качнуть", "покачать", "взболтнуть"],
    "болтанье": ["болтание"],
    "болтать": ["дрыгать", "качать", "побалтывать", "покачивать", "раскачивать", "трепать", "взбалтывать", "перемешивать", "мешать", "толочь", "разбалтывать", "говорить", "беседовать", "бакланить", "базланить"],
    "болтаться": ["слоняться", "шляться"],
    "болтаться мимо рта": ["соваться мимо рта", "соваться мимо роту", "мимо рта соваться"],
    "болтливость": ["говорливость"],
    "болтливый": ["многословный", "разговорчивый", "словоохотливый", "беседливый"],
    "болтнув": ["болтнувши"],
    "болтнувши": ["болтнув"],
    "болтовня": ["пустословие"],
    "болтология": ["болтовня", "пустословие"],
    "болтун": ["пустомеля", "говорун", "пустослов", "пустобрёх", "пустозвон", "трепач", "трепло"],
    "болтыхав": ["болтыхавши"],
    "болтыхавши": ["болтыхав"],
    "болтыхнув": ["болтыхнувши"],
    "болтыхнувши": ["болтыхнув"],
    "болушлух": ["болушлук"],
    "болховец": ["болховчанин", "болховитянин"],
    "болховитянин": ["болховец", "болховчанин", "болховитин"],
    "болховчанин": ["болховец", "болховитянин"],
    "болшевизъм": ["ленинизъм"],
    "болъон": ["дунгъуз"],
    "болыбэн": ["раё"],
    "боль": ["алгия", "мука", "мучение", "горе", "печаль", "скорбь"],
    "больдурук": ["пустынник"],
    "больная": ["здоровая"],
    "больниц": ["эмнэлэг"],
    "больница": ["стационар"],
    "больничный лист": ["больничный"],
    "больно": ["болезненно", "мучительно", "обидно", "досадно", "горько"],
    "больной": ["заболевший", "нездоровый", "болезненный", "уязвимый", "пациент"],
    "больной на всю голову": ["чокнутый"],
    "больнёхонький": ["больнёшенький"],
    "больнёшенький": ["больнёхонький"],
    "большая вода": ["высокая вода", "полая вода", "половодье"],
    "большая интегральная схема": ["бис"],
    "большая рассия": ["расья", "расеа болш", "чухонская", "большая россия", "чухонская рассия"],
    "большая россия": ["большая земля"],
    "больше": ["поболе", "в основном"],
    "большеберезниковец": ["березниковец"],
    "большеболдинец": ["болдинец"],
    "большеватый": ["великоватый"],
    "большевизировав": ["большевизировавши"],
    "большевизировавши": ["большевизировав"],
    "большевик": ["социал-демократ", "коммунист"],
    "большевистский": ["большевицкий"],
    "большевицкий": ["большевистский"],
    "большеглазый": ["пучеглазый", "лупатый"],
    "большеголовник": ["рапонтикум"],
    "большеголовый": ["головастый"],
    "большегрудый": ["пышногрудый", "полногрудый", "грудастый"],
    "большегруз": ["многотонник", "многотонка"],
    "большегрузный": ["высокотоннажный"],
    "большеземел": ["большеземелец"],
    "большеземелец": ["большеземел"],
    "большеигнатовец": ["игнатовец"],
    "большелобый": ["лобастый"],
    "большемурашкинец": ["мурашкинец"],
    "большемуртинец": ["муртинец"],
    "большеносый": ["крупноносый", "носатый", "носастый"],
    "большенький": ["старшенький"],
    "большерот": ["рыба-пеликан", "опистогнат", "акула-большерот", "большеротая акула", "трегубка", "троегуб"],
    "большеселец": ["большесёл"],
    "большесорокинец": ["сорокинец"],
    "большесёл": ["большеселец"],
    "большечерниговец": ["черниговец"],
    "большое": ["экскременты", "испражнения"],
    "большое видится на расстояньи": ["лицом к лицу лица не увидать"],
    "большое красное пятно": ["бкп"],
    "большое яблоко": ["нью-йорк", "город большого яблока", "столица мира", "город на гудзоне"],
    "большой": ["крупный", "значительный", "многочисленный", "выдающийся", "взрослый", "больший"],
    "большой дом": ["госужас"],
    "большой иргиз": ["иргиз"],
    "большой рот": ["сладкоежка", "обжора"],
    "большой свет": ["высший свет", "двор"],
    "большой террор": ["ежовщина"],
    "болящий": ["больной"],
    "бома": ["загон", "крааль", "поселение"],
    "бомба": ["авиабомба", "граната", "фонтан", "толстуха"],
    "бомбаж": ["вздутие"],
    "бомбанув": ["бомбанувши"],
    "бомбанувши": ["бомбанув"],
    "бомбарда": ["бомбардирский корабль"],
    "бомбардир": ["бонбардир", "певчий", "штурман-бомбардир", "голеадор"],
    "бомбардировав": ["бомбардировавши"],
    "бомбардировавши": ["бомбардировав"],
    "бомбардировать": ["бомбить", "засыпать", "заваливать", "забрасывать"],
    "бомбардировка": ["бомбардирование", "удар", "облучение"],
    "бомбардировщик": ["бомбовоз"],
    "бомбаст": ["эвфуизм"],
    "бомбеец": ["мумбаец"],
    "бомбезный": ["бомбический"],
    "бомбей": ["мумбаи"],
    "бомбейский": ["мумбайский"],
    "бомбер": ["бомбардировщик"],
    "бомбив": ["бомбивши"],
    "бомбивши": ["бомбив"],
    "бомбила": ["таксист", "нелегал"],
    "бомбилья": ["бомбижья"],
    "бомбировка": ["бомбирование"],
    "бомбить": ["таксовать", "качать", "тренировать", "подгорать"],
    "бомбить воронеж": ["выстрелить себе в ногу", "назло соседу отморожу себе уши", "назло маме уши отморожу", "бомбить наш собственный воронеж", "бить по воронежу"],
    "бомбиться": ["бомбардироваться"],
    "бомбицина": ["бумага", "материя", "пергамент"],
    "бомбический": ["бомбезный"],
    "бомбовозный": ["бомбардировочный"],
    "бомбометание": ["бомбёжка", "бомбардировка"],
    "бомбомёт": ["бомбометатель"],
    "бомбошка": ["бамбошка"],
    "бомбувальник": ["бомбардувальник"],
    "бомбувати": ["бомбардувати"],
    "бомбёж": ["бомбардировка", "бомбёжка", "бомбардирование"],
    "бомбёжка": ["бомбардировка", "бомбардирование", "бомбёж"],
    "бомж": ["бездомный"],
    "бомж-отель": ["бомжатник"],
    "бомж-тур": ["бэкпэкинг"],
    "бомжатник": ["бомжовка", "клоповник", "сарай"],
    "бомжатский": ["бомжовый", "бомжовский", "бомжевый", "бомжевский", "бомжиный"],
    "бомжацкий": ["бомжовый", "бомжовский", "бомжевый", "бомжевский", "бомжиный"],
    "бомжевав": ["бомжевавши"],
    "бомжевавши": ["бомжевав"],
    "бомжеватый": ["бомжевидный", "бомжеобразный", "бомжатский", "бомжистый"],
    "бомжевать": ["бичевать"],
    "бомжевидный": ["бомжеобразный", "бомжеватый", "бомжатский", "бомжистый"],
    "бомжевский": ["бомжовский", "бомжовый", "бомжатский", "бомжевый", "бомжиный"],
    "бомжевый": ["бомжовый", "бомжовский", "бомжевский", "бомжатский", "бомжиный"],
    "бомжеобразный": ["бомжевидный", "бомжеватый", "бомжатский", "бомжистый"],
    "бомжив": ["бомживши"],
    "бомживши": ["бомжив"],
    "бомжиный": ["бомжовый", "бомжовский", "бомжевский", "бомжевый", "бомжатский"],
    "бомжистый": ["бомжеватый", "бомжевидный", "бомжеобразный", "бомжатский"],
    "бомжить": ["бомжевать"],
    "бомжиха": ["бомжовка"],
    "бомжовка": ["бомжиха"],
    "бомжовский": ["бомжовый", "бомжатский", "бомжевский", "бомжевый", "бомжиный"],
    "бомжонок": ["беспризорник"],
    "бомонд": ["знать", "высший свет", "элита"],
    "бон": ["заплав"],
    "бонвиван": ["жуир", "гедонист", "эпикуреец", "сибарит", "фат"],
    "бонг": ["бульбулятор"],
    "бонго": ["пятнистая лесная антилопа"],
    "бонд": ["облигация"],
    "бондарив": ["бондаривши"],
    "бондаривши": ["бондарив"],
    "бондарный": ["бочарный"],
    "бондарня": ["бочарня"],
    "бондарь": ["бочар", "бочарь"],
    "бондиана": ["джеймсбондиана", "кинобондиана"],
    "бондив": ["бондивши"],
    "бондивши": ["бондив"],
    "бондовский": ["джеймс-бондовский"],
    "бонза": ["бхикшу", "шишка"],
    "бонитировав": ["бонитировавши"],
    "бонитировавши": ["бонитировав"],
    "бонитировщик": ["бонитер", "таксатор"],
    "бонифратр": ["госпиталит"],
    "бонка": ["бомка", "бонбонка"],
    "бонмо": ["подковырка", "подначка", "шутка", "прикол", "острота", "розыгрыш", "хохма", "насмешка", "мотто"],
    "бонмотист": ["остряк", "острослов", "острословец"],
    "бонна": ["гувернантка"],
    "бонобо": ["карликовый шимпанзе"],
    "бонсай": ["пэньцзин"],
    "бонтон": ["комильфо"],
    "бонус": ["премия"],
    "бонуфуз": ["эътиборнок"],
    "бонхед": ["бон", "скинхед"],
    "бопутатсвана": ["республика бопутатсвана"],
    "бораго": ["огуречник", "бурачник"],
    "боразон": ["эльбор"],
    "боралдай": ["боролдай"],
    "боран": ["бороводород"],
    "борбор": ["байтак", "ордо"],
    "борборит": ["варвелиот", "ворворианин", "варвилит", "барбелит", "стратиотик", "фивионит", "фибионит", "закхеий", "коддианин"],
    "бордантность": ["бордизм"],
    "бордель": ["публичный дом", "дом терпимости", "салон", "блудилище", "бардак"],
    "бордерран": ["визаран"],
    "бордж": ["фарз"],
    "бордизм": ["бордантность"],
    "бордовый": ["тёмно-красный", "бордо"],
    "бордюр": ["поребрик", "бровка", "бордюрный камень", "кайма"],
    "бореал": ["бореальный период"],
    "борелиоза": ["лаймската болест", "лаймска борелиоза", "борелиозис бургдорфери"],
    "борение": ["борьба", "противостояние"],
    "боренье": ["борение"],
    "борец": ["борцун"],
    "боржеминский": ["боржиминский"],
    "боржим": ["божим"],
    "боржимин": ["божимин"],
    "боржиминский": ["боржеминский"],
    "боржовка": ["борщевик", "боржавка", "бурша"],
    "боржом": ["боржоми"],
    "боржоми": ["боржом"],
    "борзевши": ["борзев"],
    "борзинец": ["борзянин"],
    "борзой": ["борзый", "резвый", "наглый"],
    "борзописание": ["кропательство", "графоманство", "стихоплетство", "виршеплетство", "бумагомарание", "щелкопёрство", "стенография", "брахиграфия"],
    "борзописец": ["писака"],
    "борзый": ["быстрый", "резвый", "наглый", "обнаглевший", "самоуверенный"],
    "борзянин": ["борзинец"],
    "борировав": ["борировавши"],
    "борировавши": ["борировав"],
    "борис": ["боря", "бориска", "борискин", "борискинд", "боруля", "борулик", "борюля", "борюлик", "борюня", "борюнчик", "борюся", "борюша", "боряша", "боряшка", "борюха"],
    "борислав": ["боруслав", "бориславка", "слава", "боря", "славик", "боро", "борко", "борис", "славко", "славцьо", "славчик"],
    "бориславич": ["бориславович"],
    "бориславович": ["бориславич"],
    "борисовец": ["борисовчанин"],
    "борисович": ["борисыч"],
    "борисовчанин": ["борисовец"],
    "бористый": ["борчатый"],
    "борисыч": ["борисович"],
    "бормашина": ["стоматологическая бормашина"],
    "бормашинка": ["бормашина"],
    "бормотав": ["бормотавши"],
    "бормотавши": ["бормотав"],
    "бормотать": ["бубнить", "лепетать"],
    "бормотнув": ["бормотнувши"],
    "бормотнувши": ["бормотнув"],
    "бормотушник": ["пьяница", "алкаш"],
    "борная кислота": ["ортоборная кислота"],
    "борнейский": ["калимантанский"],
    "борнео": ["калимантан"],
    "борнеол": ["борнейская камфора"],
    "борня": ["боротьба"],
    "боровар": ["самарбахш"],
    "боровец": ["борович", "боровчанин"],
    "боровик": ["болет", "болетус", "белый гриб", "гриб-боровик"],
    "боровина": ["рендзина"],
    "боровитин": ["боровец", "борович", "боровчанин"],
    "борович": ["боровец", "боровчанин"],
    "бороводород": ["боран"],
    "боровчанин": ["боровец", "боровитин"],
    "боровши": ["боров"],
    "боровщик": ["кормовщик"],
    "борогидрид": ["боранат", "тетрагидридоборат", "тетрагидроборат"],
    "борода": ["раскольник", "отечество", "подбородок"],
    "бородавчастий": ["бородавчатий"],
    "бородавчатий": ["бородавчастий"],
    "бородавчатка": ["рыба-камень", "бугорчатка", "рыба-вурдалак"],
    "бородастый": ["большебородый"],
    "бородатев": ["бородатевши"],
    "бородатевши": ["бородатев"],
    "бородатый": ["старый", "устаревший", "неактуальный", "древний", "стародавний", "дикий", "неухоженный"],
    "бородка": ["бородёнка"],
    "бородобрей": ["барбер", "брадобрей", "парикмахер", "цирюльник"],
    "бородок": ["пробойник"],
    "борозда": ["канавка", "рассечение", "порез"],
    "бороздив": ["бороздивши"],
    "бороздивши": ["бороздив"],
    "бороздильник": ["бороздник", "бороздооткрыватель", "рядовик"],
    "бороздить": ["изборождать"],
    "бороздковый": ["бороздной", "бороздовой"],
    "бороздчатый": ["бороздковый", "изборозженный"],
    "боролдай": ["боралдай"],
    "борона-каток": ["каток-борона"],
    "боронение": ["боронование", "бороньба"],
    "боронив": ["боронивши"],
    "боронивши": ["боронив"],
    "бороновав": ["бороновавши"],
    "бороновавши": ["бороновав"],
    "боронование": ["боронение"],
    "бороновать": ["боронить"],
    "бороновка": ["боронование"],
    "бороньба": ["боронование", "боронованье"],
    "боросодержащий": ["борсодержащий"],
    "боротьба": ["бороття"],
    "бороться": ["конфликтовать", "противостоять", "противоборствовать", "воевать", "сражаться", "биться", "драться", "вести борьбу", "искоренять", "заниматься борьбой", "выступать"],
    "боррелиоз": ["болезнь лайма", "боррелёз"],
    "борсалино": ["федора"],
    "борсодержащий": ["боросодержащий"],
    "бортанув": ["бортанувши"],
    "бортанувши": ["бортанув"],
    "бортник": ["пчеловод"],
    "бортничав": ["бортничавши"],
    "бортничавши": ["бортничав"],
    "бортничать": ["бортничествовать"],
    "бортничество": ["бортевое пчеловодство"],
    "бортничествовав": ["бортничествовавши"],
    "бортничествовавши": ["бортничествовав"],
    "бортничествовать": ["бортничать"],
    "бортовав": ["бортовавши"],
    "бортовавши": ["бортовав"],
    "бортовать": ["толкать на борт", "прижимать к борту", "отталкивать", "толкать"],
    "бортпроводник": ["стюард"],
    "борут": ["доруи милтик"],
    "борцуха": ["борец"],
    "борчлы": ["борчлу"],
    "борщ": ["борщевик сибирский"],
    "борщевик": ["борщевник", "борщ", "боржовка", "боржавка", "бурша"],
    "борщец": ["борщок"],
    "борьба": ["схватка", "ристание", "противоборство", "противостояние", "противодействие", "борение", "состязание", "соревнование"],
    "борьба за македонию": ["македономахия"],
    "босиком": ["боском"],
    "боском": ["босиком"],
    "бослук": ["бошлух"],
    "босния и герцеговина": ["босния", "биг"],
    "босняк": ["боснийский мусульманин"],
    "босо-обувь": ["минималистичный", "обувь"],
    "босоватенький": ["босоватый", "босенький"],
    "босоватый": ["босоватенький"],
    "босой": ["необутый", "босый"],
    "босолапка": ["босоножка"],
    "босоногий": ["босой"],
    "босота": ["голытьба", "голь", "голота"],
    "босс": ["руководитель", "начальник", "шеф"],
    "босфор": ["боспор фракийский"],
    "босхианский": ["босховский"],
    "босховский": ["босхианский"],
    "босый": ["босой"],
    "босый хуй": ["голый вассер"],
    "босяк": ["голодранец", "шпана"],
    "босяцкий": ["босяческий"],
    "ботав": ["ботавши"],
    "ботавши": ["ботав"],
    "ботак": ["тармак"],
    "ботало": ["колокольчик", "колоколок", "колокольцик", "подзвонок"],
    "ботан": ["зубрила"],
    "ботанев": ["ботаневши"],
    "ботаневши": ["ботанев"],
    "ботанизировав": ["ботанизировавши"],
    "ботанизировавши": ["ботанизировав"],
    "ботаник": ["умник", "заучка", "ботан", "зубрила", "зубрилка", "чайник", "профан"],
    "ботаника": ["фитология"],
    "ботанический сад": ["дендрарий"],
    "ботаноид": ["очкозавр"],
    "ботва": ["зелень", "чушь", "ерунда", "нонсенс"],
    "ботик": ["бот"],
    "ботильон": ["полусапожки"],
    "ботинка": ["ботинок", "башмак"],
    "ботинок": ["башмак", "туфля", "полуботинок"],
    "ботиночек": ["ботинок"],
    "ботнув": ["ботнувши"],
    "ботнувши": ["ботнув"],
    "ботнуть": ["стукнуть", "ударить"],
    "ботозаливка": ["заливка"],
    "ботокс": ["ботулотоксин"],
    "ботриоцефалёз": ["дифиллоботриоз", "диботриоцефалёз"],
    "ботсвана": ["республика ботсвана", "бечуаналенд"],
    "боттлер": ["бутилятор"],
    "ботулотоксин": ["ботулинический токсин", "ботокс", "ботулин"],
    "ботун": ["батун", "лук-батун", "батун-лук", "татарка", "бутун", "ботовик"],
    "ботфорт": ["ботфорта"],
    "ботфорта": ["ботфорт"],
    "боулер": ["боулингист"],
    "боулинг": ["боулинг-клуб"],
    "боулинг-клуб": ["боулинг-центр"],
    "боулинг-центр": ["боулинг-клуб"],
    "боулингист": ["боулер"],
    "бохай": ["пархэ"],
    "боцманская команда": ["палубная команда"],
    "боцъо": ["зачъе"],
    "боцюн": ["лелека", "чорногуз", "бусел", "бусол", "боцяг"],
    "боцяг": ["лелека", "чорногуз", "бусел", "бусол", "боцюн"],
    "бочага": ["бочаг", "омут"],
    "бочар": ["бондарь"],
    "бочара": ["бочина"],
    "бочарив": ["бочаривши"],
    "бочаривши": ["бочарив"],
    "бочарничав": ["бочарничавши"],
    "бочарничавши": ["бочарничав"],
    "бочив": ["бочивши"],
    "бочивши": ["бочив"],
    "бочина": ["бочара", "боковина"],
    "бочить": ["бочиться"],
    "бочиться": ["бочить"],
    "бочковатость": ["бочкообразность"],
    "бочковый": ["бочечный"],
    "бочкообразность": ["бочковатость"],
    "бочку катить": ["катить бочку", "бочку гнать", "гнать бочку", "наезжать", "бузить"],
    "бочок": ["бок", "фланг"],
    "бочоночек": ["бочонок"],
    "бошка": ["голова"],
    "боягузливий": ["боязкий"],
    "боязкий": ["боягузливий"],
    "боязливий": ["боязкий"],
    "боязливо": ["робко", "несмело"],
    "боязливость": ["боязнь", "робость", "трусливость"],
    "боязливый": ["пугливый", "трусливый"],
    "боязно": ["страшно"],
    "боязнь": ["робость", "фобия", "страх", "испуг", "ужас", "паника"],
    "боязън": ["страх"],
    "боян": ["баян"],
    "боярин": ["феодал", "помещик", "барин"],
    "боярышник": ["бояра"],
    "бояться": ["пугаться", "страшиться", "опасаться", "трусить", "робеть", "трепетать", "дрожать", "трястись", "холодеть", "дрейфить", "тревожиться", "беспокоиться", "стрематься", "менжеваться"],
    "боёк": ["жало", "бой"],
    "бпла": ["беспилотник", "дрон"],
    "бра": ["настенный", "светильник", "бюстгальтер", "лифчик"],
    "брабант": ["брабан"],
    "брава": ["ключалка", "кофар", "катанец"],
    "бравада": ["молодечество", "лихачество", "бравирование"],
    "бравировав": ["бравировавши"],
    "бравировавши": ["бравировав"],
    "бравированье": ["бравирование"],
    "бравировать": ["хорохориться", "храбриться"],
    "браво": ["здорово", "отважно", "храбро"],
    "бравость": ["молодечество", "удаль", "молодцеватость", "лихость"],
    "бравура": ["бравада"],
    "бравурный": ["бравый", "бодрый"],
    "бравши": ["брав"],
    "брада": ["борода"],
    "брадатый": ["бородатый"],
    "брадиаритмия": ["брадикардия"],
    "брадион": ["тардион", "массивная частица"],
    "брадобрей": ["барбер", "парикмахер", "цирюльник"],
    "брадобритие": ["брадобритье"],
    "брадобритье": ["брадобритие"],
    "бражка": ["брага", "сусло", "самогон", "самогонка", "водка", "пирушка", "попойка", "компания", "тёплая компания", "честная компания", "гопкомпания", "компаша", "компашка", "братия", "шатия"],
    "бражник": ["пьяница", "гуляка", "собутыльник"],
    "бражничав": ["бражничавши"],
    "бражничавши": ["бражничав"],
    "бражничанье": ["бражничество", "бражничание"],
    "бражничать": ["пьянствовать"],
    "бражничество": ["бражничанье", "пьянство"],
    "бразгат": ["бразганне", "бразгатанне", "дзынканне"],
    "бразда": ["борозда", "узда"],
    "браздив": ["браздивши"],
    "браздивши": ["браздив"],
    "браздить": ["бороздить"],
    "бразды": ["удила", "узда", "властные полномочия", "власть"],
    "бразилец": ["бразильянец"],
    "бразилия": ["федеративная республика бразилия"],
    "бразильянец": ["бразилец"],
    "брак": ["супружество", "женитьба"],
    "брак вдогонку": ["залёт", "стимулированный брак"],
    "бракераж": ["отбраковка", "выбраковка"],
    "браковав": ["браковавши"],
    "браковавши": ["браковав"],
    "бракование": ["бракованье"],
    "бракованный": ["дефектный", "испорченный", "некачественный", "невалидный"],
    "браковать": ["отбраковывать"],
    "бракодел": ["портач", "халтурщик"],
    "браконьерив": ["браконьеривши"],
    "браконьеривши": ["браконьерив"],
    "браконьерствовав": ["браконьерствовавши"],
    "браконьерствовавши": ["браконьерствовав"],
    "браконьерствовать": ["браконьерить", "браконьерничать"],
    "бракосочетание": ["свадьба", "женитьба"],
    "бракосочетанье": ["бракосочетание"],
    "бракоша": ["бракуша"],
    "бракуша": ["бракоша"],
    "бралетт": ["бралетте"],
    "брама": ["брахма"],
    "брамаизм": ["брахмаизм"],
    "браман": ["брамин"],
    "браманизм": ["брахманизм"],
    "брамин": ["брахман", "браман"],
    "брандахлыст": ["бурда"],
    "бранденбургец": ["бранденбуржец"],
    "бранденбуржец": ["бранденбургец"],
    "брандмауэр": ["бранд", "защитник", "файрвол", "межсетевой экран"],
    "брандспойт": ["ствол"],
    "бранив": ["бранивши"],
    "бранивав": ["бранивавши"],
    "бранивавши": ["бранивав"],
    "бранивши": ["бранив"],
    "бранител": ["защитник"],
    "бранить": ["ругать", "бичевать", "распекать"],
    "браниться": ["ругаться", "ссориться"],
    "бранливый": ["сварливый", "бранчливый", "бранчивый"],
    "бранник": ["воин", "войник", "ратник"],
    "бранный": ["ругательный", "скверный", "сквернословный", "матерный", "упрекающий", "военный", "боевой"],
    "бранчиво": ["сварливо", "бранчливо"],
    "бранчивый": ["бранчливый", "сварливый"],
    "бранчливо": ["сварливо", "бранчиво"],
    "бранчливый": ["сварливый", "бранчивый"],
    "бранша": ["губа"],
    "брань": ["ругань", "ругательство", "сквернословие", "драка", "колотня", "свалка", "рукопашная", "побоище", "битва", "бой", "война", "сеча"],
    "брань на вороту не виснет": ["брань в боку не болит"],
    "брасовав": ["брасовавши"],
    "брасовавши": ["брасовав"],
    "брасовать": ["брасопить"],
    "брасопив": ["брасопивши"],
    "брасопивши": ["брасопив"],
    "брасопить": ["брасовать"],
    "брасывав": ["брасывавши"],
    "брасывавши": ["брасывав"],
    "братав": ["братавши"],
    "братавши": ["братав"],
    "братан": ["брат", "старший брат", "кузен", "двоюродный брат", "побратим", "единомышленник", "собрат", "мужик", "чувак"],
    "братаниха": ["невестка"],
    "братанье": ["братание"],
    "братать": ["брататься", "сближать", "сплачивать"],
    "брателла": ["браток"],
    "брателло": ["братан", "браток"],
    "брательник": ["младший брат"],
    "братень": ["братик", "братишка", "братушка", "братишечка", "братец", "браток", "браточек", "братуха", "брательник", "брательничек", "братан", "братеня"],
    "братец": ["брат"],
    "братець": ["братик"],
    "братишечка": ["братишка", "братец"],
    "братишка": ["братик", "братан", "брательник", "брателло", "браток", "мальчуган", "дружок"],
    "братия": ["братство", "компания", "команда", "шатия", "компашка", "шобла"],
    "братле": ["браток", "братче", "братец"],
    "братний": ["братнин", "братов"],
    "братнин": ["братов", "братний"],
    "братовав": ["братовавши"],
    "братовавши": ["братовав"],
    "братовбивство": ["братоубивство"],
    "братогубець": ["братовбивця"],
    "браток": ["братишка"],
    "братская могила": ["скудельница", "скудельня"],
    "братский": ["братний", "братнин", "дружественный"],
    "братское очко": ["очко братское"],
    "братство": ["содружество", "союз", "лагерь", "ассоциация", "партия", "отряд", "фракция", "орден"],
    "братський": ["братерський"],
    "братчик": ["брат"],
    "братчина": ["братовщина", "братовщинка"],
    "брать": ["хватать", "захватывать", "схватывать", "поднимать", "доставать", "покупать", "получать", "бить", "рубить", "арестовывать", "овладевать", "извлекать"],
    "брать в голову": ["волноваться", "беспокоиться", "переживать", "тревожиться"],
    "брать верх": ["держать верх"],
    "брать за яйца": ["брать за фаберже", "брать за шкворень"],
    "брать на клык": ["принимать на клык", "на клык принимать", "на клык брать"],
    "брать на себя ответственность": ["обязываться"],
    "брать с потолка": ["брать от балды", "справочник стели"],
    "браться": ["хвататься"],
    "братья наши меньшие": ["животное"],
    "браузер": ["веб-браузер", "веб-обозреватель", "броузер", "навигатор"],
    "браун": ["бровн"],
    "брахидактилия": ["короткопалость"],
    "брахикефал": ["брахицефал"],
    "брахикефалия": ["брахицефалия"],
    "брахиморф": ["эндоморф", "гиперстеник"],
    "брахиопод": ["плеченогий"],
    "брахисинклиналь": ["мульда"],
    "брахискелия": ["брахиподия", "коротконогость"],
    "брахихорей": ["амфибрахий"],
    "брахицефал": ["брахикефал"],
    "брахицефалия": ["брахикефалия", "короткоголовость"],
    "брахман": ["брамин"],
    "брахмачари": ["брахмачарья"],
    "брахмачарья": ["брахмачари"],
    "брахмин": ["брахман"],
    "брачный": ["супружеский", "матримониальный", "свадебный", "венчальный", "подвенечный"],
    "брачующийся": ["брачащийся"],
    "брашинг": ["броссаж"],
    "брашов": ["орашул-сталин", "сталин"],
    "бреве": ["кратка", "бревис", "дуга"],
    "бревий": ["протактиний"],
    "бревно": ["дубина", "чурбан"],
    "бревнотаска": ["лесотаска"],
    "бревноукладчик": ["лесоукладчик"],
    "бревёшко": ["брёвнышко"],
    "брег": ["берег"],
    "бред": ["горячка", "делирий"],
    "бред величия": ["мания величия"],
    "бред преследования": ["персекуторный бред"],
    "бред сивой кобылы": ["сорок бочек арестантов", "чёрт знает что", "чушь собачья", "бред собачий", "бред сумасшедшего"],
    "бреда": ["врун", "враль", "болтун"],
    "бредень": ["невод"],
    "бредив": ["бредивши"],
    "бредивши": ["бредив"],
    "бредить": ["заплетаться", "городить", "сочинять", "увлекаться", "желать", "мечтать"],
    "бредни": ["вздор", "чушь", "выдумка"],
    "бредь": ["бред"],
    "бредятина": ["бред", "вздор", "чушь"],
    "брезгав": ["брезгавши"],
    "брезгавши": ["брезгав"],
    "брезгать": ["гнушаться", "пренебрегать"],
    "брезгливец": ["брезгун"],
    "брезгливица": ["брезгунья"],
    "брезгливость": ["гадливость", "отвращение"],
    "брезговав": ["брезговавши"],
    "брезговавши": ["брезговав"],
    "брезговать": ["брезгать", "гнушаться"],
    "брезгун": ["брезгливец"],
    "брезгунья": ["брезгливица"],
    "брезгуша": ["брезгун", "брезгливец", "брезгунья", "брезгливица"],
    "брезентный": ["брезентовый"],
    "брезень": ["март", "березозол"],
    "брезжащий": ["виднеющийся", "проглядывающий"],
    "брезжив": ["брезживши"],
    "брезживши": ["брезжив"],
    "брезжить": ["проглядывать"],
    "брезжиться": ["брезжить"],
    "брезжущий": ["виднеющийся", "проглядывающий"],
    "брейк": ["брейк-данс"],
    "брейк-бит": ["брейкс"],
    "брейк-данс": ["брейк", "брейкинг", "брейк-танец", "бибоинг"],
    "брейк-дансер": ["брейкер", "брейк-дансист", "брейкист", "брейк-танцор"],
    "брейковский": ["брейковый"],
    "брейковый": ["брейковский"],
    "брейнсторм": ["брейнсторминг", "мозговая атака", "мозговой штурм"],
    "брейнсторминг": ["брейнсторм", "мозговая атака", "мозговой штурм"],
    "брекватер": ["волнолом"],
    "брекет-система": ["брекет"],
    "брекчиевидный": ["брекчиевый", "брекчированный"],
    "брекчированный": ["брекчиевидный", "брекчиевый"],
    "бременив": ["бременивши"],
    "бременивши": ["бременив"],
    "бремя": ["груз", "ноша", "тягость", "обуза", "тяжесть"],
    "бренд": ["торговая марка"],
    "бренд-волл": ["пресс-волл"],
    "брендировав": ["брендировавши"],
    "брендировавши": ["брендировав"],
    "брендированный": ["фирменный"],
    "бренность": ["смертность", "недолговечность", "преходящесть"],
    "бренный": ["глиняный", "непрочный", "слабый", "смертный", "тленный"],
    "бренчав": ["бренчавши"],
    "бренчавши": ["бренчав"],
    "бренчание": ["бренчанье"],
    "бренчанье": ["бренчание"],
    "бренчать": ["дзинькать"],
    "бренье": ["брение"],
    "бренькав": ["бренькавши"],
    "бренькавши": ["бренькав"],
    "бренькать": ["бренчать", "звенеть", "звякать"],
    "бренькнув": ["бренькнувши"],
    "бренькнувши": ["бренькнув"],
    "бренькнуть": ["тренькнуть"],
    "бреславец": ["вроцлавец", "вроцлавянин"],
    "брессаноне": ["бриксен"],
    "брестец": ["брестчанин", "брестовчанин"],
    "брести": ["плестись", "тащиться", "ковылять"],
    "брестовчанин": ["берестьянин", "брестец", "берестянин", "брестчанин"],
    "брестчанин": ["берестьянин", "брестец", "берестянин", "брестовчанин"],
    "брестчанка": ["брестовчанка"],
    "брестянин": ["брестец", "брестчанин", "берестянин"],
    "бретанский": ["бретонский"],
    "бретель": ["бретелька", "лямка"],
    "бретелька": ["бретель"],
    "бретонский": ["бретанский", "бретонский язык"],
    "бретонский язык": ["бретонский"],
    "бретёр": ["дуэлист", "дуэлянт", "поединщик", "задира", "забияка"],
    "бретёрский": ["дуэлянтский"],
    "бретёрствовав": ["бретёрствовавши"],
    "бретёрствовавши": ["бретёрствовав"],
    "брехав": ["брехавши"],
    "брехавши": ["брехав"],
    "брехать": ["лаять", "лгать", "врать", "болтать"],
    "брехло": ["брехун", "лжец", "обманщик"],
    "брехнув": ["брехнувши"],
    "брехнувши": ["брехнув"],
    "брехня": ["брёх", "вздор", "враньё", "лай"],
    "брехунок": ["матюгальник"],
    "брехунья": ["врунья", "обманщица", "лгунья"],
    "брехуха": ["брехунка"],
    "брешанец": ["брешианец"],
    "брешешь": ["враньё", "ложь"],
    "брешианец": ["брешанец"],
    "брешь": ["пробоина", "пролом"],
    "брив": ["бривши"],
    "бривав": ["бривавши"],
    "бривавши": ["бривав"],
    "бривши": ["брив"],
    "бригада": ["артель"],
    "бригадир": ["бугор"],
    "бригадирив": ["бригадиривши"],
    "бригадиривши": ["бригадирив"],
    "бригадирить": ["бригадирствовать"],
    "бригадирствовав": ["бригадирствовавши"],
    "бригадирствовавши": ["бригадирствовав"],
    "бригадирша": ["командирша"],
    "бригадмил": ["бсм"],
    "бригадмилец": ["бригадмил"],
    "бригадный генерал": ["бригадир", "коммодор"],
    "бридочка": ["бретелька", "шнурочек"],
    "бризантний": ["вибухонебезпечний"],
    "бризантный": ["разрывной", "взрывной", "дробящий"],
    "бризер": ["проветриватель"],
    "бризоль": ["отбивная"],
    "брик": ["бриг"],
    "брик-а-брак": ["старьё", "рухлядь", "ветошь", "брикабракист", "старьёвщик"],
    "брика": ["бричка"],
    "брикет": ["кирпичик"],
    "брикетировав": ["брикетировавши"],
    "брикетировавши": ["брикетировав"],
    "бриллиант": ["брильянт", "диамант"],
    "бриллиантик": ["брильянтик"],
    "бриллиантщик": ["ювелир", "брильянтщик"],
    "бриль": ["брыль"],
    "брильянт": ["бриллиант"],
    "брильянтик": ["бриллиантик"],
    "брильянтовый": ["бриллиантовый"],
    "брильянтщик": ["ювелир", "бриллиантщик"],
    "бримада": ["приставание", "притеснение", "придирка"],
    "бриолин": ["бриллиантин", "брильянтин"],
    "бриония": ["переступень"],
    "бристоль": ["бристольский картон"],
    "брит": ["бритт"],
    "британия": ["великобритания", "соединённое королевство", "англия", "альбион", "туманный альбион"],
    "британка": ["англичанка"],
    "британская индия": ["британский радж", "индийская империя"],
    "британский": ["английский"],
    "британский пенни": ["пенс"],
    "бритва оккама": ["лезвие оккама", "скальпель оккама"],
    "бритый": ["выбритый", "обритый", "сбритый"],
    "брить": ["сбривать", "обривать", "отбривать", "срезать"],
    "брифинг": ["пресс-конференция", "инструктаж", "планёрка"],
    "брненец": ["брновец", "брновчанин"],
    "брновец": ["брненец", "брновчанин"],
    "брновчанин": ["брненец", "брновец"],
    "бро": ["братишка", "братан", "брателло", "брательник", "браток", "братуха", "братюня", "товарищ", "приятель", "приятельница"],
    "бровар": ["пивовар", "броварник"],
    "броварник": ["бровар"],
    "бровастий": ["броватий"],
    "бровеносец": ["бровястый", "генсек-бровеносец"],
    "бровеносец в потёмках": ["бровеносец", "генсек-бровеносец", "бровястый"],
    "бровка": ["маленький", "бровь", "барбос"],
    "бровн": ["браун"],
    "бровнианист": ["браунист"],
    "брод": ["отмель", "мель", "мелкота"],
    "бродень": ["бахила"],
    "бродив": ["бродивши"],
    "бродивши": ["бродив"],
    "бродить": ["шататься", "шляться", "блуждать", "брести", "колобродить", "плестись", "тащиться", "тянуться", "расхаживать", "распространяться", "ходить", "кочевать", "скитаться", "бродяжничать", "вертеться"],
    "бродник": ["бордник", "продник", "бронник", "броднич", "бродниц"],
    "бродь": ["благородие"],
    "бродяга": ["скиталец", "бомж", "бездомный", "босяк", "клошар", "дервиш", "путешественник", "пилигрим"],
    "бродяжив": ["бродяживши"],
    "бродяживши": ["бродяжив"],
    "бродяжничав": ["бродяжничавши"],
    "бродяжничавши": ["бродяжничав"],
    "бродяжничать": ["бродяжить", "кочевать", "скитаться", "переезжать", "странствовать", "путешествовать"],
    "брожение": ["ферментация", "возбуждение"],
    "брой": ["число"],
    "брокер": ["маклер"],
    "брокеридж": ["брокерство"],
    "бром": ["микстура павлова", "микстура бехтерева"],
    "бромацетон": ["мартонит"],
    "бромацетофенол": ["бромацетофенон"],
    "бромелайн": ["бромелин"],
    "бромелин": ["бромелайн"],
    "бромид": ["гидробромид", "бромид-ион", "бромид-анион"],
    "бромный": ["бромовый"],
    "бромэтан": ["этилбромид"],
    "бронеавтомобиль": ["броневик", "бронемашина"],
    "бронебойка": ["бронебойное ружьё"],
    "бронебойный": ["веский", "безапелляционный", "убойный", "дубовый", "неубиваемый", "неубиенный"],
    "броневик": ["бронеавтомобиль", "бронемашина", "бронепоезд"],
    "бронедверь": ["бронированная дверь", "железная дверь"],
    "бронежилет": ["броник"],
    "броненосец": ["армадилл"],
    "бронепластина": ["бронеплита"],
    "бронепоезд": ["крепость на колёсах"],
    "бронепробиваемость": ["пробиваемость"],
    "бронестекло": ["пулестойкое", "стекло", "пуленепробиваемое"],
    "бронетанковий": ["панцерниковий"],
    "бронетранспортёр": ["бтр", "бэтээр"],
    "бронещит": ["бронещиток"],
    "бронзант": ["бронзер"],
    "бронзировав": ["бронзировавши"],
    "бронзировавши": ["бронзировав"],
    "бронзироваться": ["бронзоветь"],
    "бронзовав": ["бронзовавши"],
    "бронзовавши": ["бронзовав"],
    "бронзовев": ["бронзовевши"],
    "бронзовевши": ["бронзовев"],
    "броник": ["бронежилет"],
    "бронировав": ["бронировавши"],
    "бронировавши": ["бронировав"],
    "бронирование": ["резервирование"],
    "бронированный": ["броненосный", "броневой", "пуленепробиваемый"],
    "бронировать": ["резервировать"],
    "бронислава": ["бранислава"],
    "бронник": ["бродник"],
    "бронтозавр": ["апатозавр"],
    "бронхолит": ["бронхиальный конкремент"],
    "бронхорасширитель": ["бронходилататор"],
    "броный": ["белый", "светлый"],
    "бронь": ["закрепление", "резервирование", "бронировка", "броня", "доспехи", "панцирь"],
    "броня": ["резервирование"],
    "бросав": ["бросавши"],
    "бросавши": ["бросав"],
    "бросание": ["кидание"],
    "бросанье": ["бросание"],
    "бросать": ["кидать", "швырять", "метать", "отпускать", "забрасывать", "опускать", "погружать", "выбрасывать", "выкидывать", "мусорить", "спускать", "сорить", "раскидывать", "разбрасывать", "качать"],
    "бросаться в глаза": ["привлекать внимание"],
    "бросив": ["бросивши"],
    "бросивши": ["бросив"],
    "бросить": ["кинуть", "запустить", "направить", "устремить", "прекратить", "оставить", "покинуть"],
    "бросить на подвал": ["кинуть на подвал"],
    "броситься": ["спрыгнуть", "кинуться", "устремиться", "рвануться", "ринуться"],
    "броситься в ноги": ["броситься к ногам"],
    "бросок": ["бросание", "кидание"],
    "броссаж": ["брашинг"],
    "броузер": ["веб-браузер", "веб-обозреватель", "браузер", "навигатор"],
    "брошенность": ["покинутость", "одиночество"],
    "брошка": ["брошь"],
    "брошюра": ["буклет"],
    "брошюрка": ["брошюра"],
    "брошюровав": ["брошюровавши"],
    "брошюровавши": ["брошюровав"],
    "брошюрование": ["брошюровка"],
    "брошюроваться": ["брошироваться"],
    "брошюровщик": ["нумеровщик"],
    "брояч": ["суматор"],
    "брудний": ["грязний", "нечистий"],
    "бруксизм": ["одонтеризм"],
    "брульон": ["черновик", "набросок"],
    "бруней": ["государство бруней-даруссалам"],
    "брунжав": ["брунжавши"],
    "брунжавши": ["брунжав"],
    "брунжать": ["звенеть"],
    "брусиловский прорыв": ["брусиловское наступление", "луцкий прорыв"],
    "брусника": ["боровика", "боровка", "борувка", "брувена", "бружиница", "брусена", "брусёна", "брусеня", "бруснига", "брусница", "брусницы", "брусничник", "брусняг", "брусняга", "брушница"],
    "брусница": ["брусника"],
    "брусничник": ["вакциниум"],
    "брусовав": ["брусовавши"],
    "брусовавши": ["брусовав"],
    "брусовый": ["брусовой"],
    "брусок": ["камень", "точильный брусок", "правильный брусок"],
    "брусочник": ["брусница", "брусня", "брусочница"],
    "брусса": ["пруса", "прусса", "бурса"],
    "бруствер": ["насыпь", "вал"],
    "брусяной": ["брусчатый"],
    "брутальный": ["грубый", "жестокий", "мачистский", "суровый", "неотёсанный", "жёсткий", "свирепый", "брутал"],
    "брутто-контракт": ["контракт на транспортную работу"],
    "брънка": ["звено", "халка"],
    "бръснар": ["коафьор", "фризьор", "бербер"],
    "брътвеж": ["брътвене", "бъбрене", "бърборене", "бръщолевене", "дърдорене"],
    "брыжейка": ["мезентерий"],
    "брыжи": ["жабо"],
    "брызгав": ["брызгавши"],
    "брызгавши": ["брызгав"],
    "брызгалка": ["прыскалка", "пшикалка"],
    "брызгать": ["опрыскивать"],
    "брызгивав": ["брызгивавши"],
    "брызгивавши": ["брызгивав"],
    "брызнув": ["брызнувши"],
    "брызнувши": ["брызнув"],
    "брызнуть": ["метнуться"],
    "брыкав": ["брыкавши"],
    "брыкавши": ["брыкав"],
    "брыкание": ["брыканье"],
    "брыканье": ["брыкание"],
    "брыкаться": ["лягаться"],
    "брыкнув": ["брыкнувши"],
    "брыкнувши": ["брыкнув"],
    "брыляв": ["брылявши"],
    "брылявши": ["брыляв"],
    "брысь": ["прочь", "вон", "кыш"],
    "брэнд-менеджер": ["бренд-менеджер"],
    "брюгге": ["северная венеция"],
    "брюггенец": ["брюжец"],
    "брюжец": ["брюггенец"],
    "брюзга": ["ворчун", "ворчунья"],
    "брюзгливо": ["ворчливо"],
    "брюзгливость": ["ворчливость"],
    "брюзгливый": ["ворчливый"],
    "брюзглость": ["обрюзглость"],
    "брюзглый": ["обрюзглый", "обрюзгший", "отёчный"],
    "брюзгнув": ["брюзгнувши"],
    "брюзгнувши": ["брюзгнув"],
    "брюзжав": ["брюзжавши"],
    "брюзжавши": ["брюзжав"],
    "брюзжание": ["брюзжанье"],
    "брюзжанье": ["брюзжание"],
    "брюзжать": ["ворчать", "злиться", "жужжать"],
    "брюква": ["желтуха", "галанка", "бакланка", "баклага", "брюкла", "голань", "ланка", "ландушка", "калива", "буква", "калика", "калига", "каливка", "грыза", "бручка"],
    "брюквенница": ["белянка брюквенная"],
    "брюквица": ["брюковница"],
    "брюки": ["штаны"],
    "брюковка": ["брюквинка", "брюквочка"],
    "брюковница": ["брюквица"],
    "брюнет": ["чернявый", "черноволосый", "темноволосый"],
    "брюнетистый": ["темноволосый"],
    "брюнетка": ["шатенка", "гречка", "гречневая каша", "воронок"],
    "брюссель": ["нато", "европейский союз"],
    "брюхастый": ["брюхатый", "пузатый", "пузастый"],
    "брюхатев": ["брюхатевши"],
    "брюхатевши": ["брюхатев"],
    "брюхатив": ["брюхативши"],
    "брюхативши": ["брюхатив"],
    "брюхатый": ["брюхастый", "пузатый", "пузастый"],
    "брюхач": ["брюхан"],
    "брюхо": ["живот", "пузо", "утроба", "чрево", "днище"],
    "брюхоногие": ["гастропод"],
    "брюхоногий": ["гастропод"],
    "брючина": ["штанина"],
    "брючишки": ["брючонки"],
    "брючонки": ["брючишки"],
    "брюшина": ["перетонеум", "пашина", "подчеревок"],
    "брюшная аорта": ["артерия"],
    "брюшная полость": ["брюхо"],
    "брюшной": ["абдоминальный"],
    "брякав": ["брякавши"],
    "брякавши": ["брякав"],
    "брякнув": ["брякнувши"],
    "брякнувши": ["брякнув"],
    "брякнуть": ["звякнуть", "грохнуть", "ляпнуть", "сморозить", "позвонить"],
    "брянец": ["брянчанин", "брянченин"],
    "брянская область": ["брянщина"],
    "брянчанин": ["брянец", "брянченин"],
    "брянченин": ["брянец", "брянчанин"],
    "бряцав": ["бряцавши"],
    "бряцавши": ["бряцав"],
    "бряцание": ["бряцанье"],
    "бряцанье": ["бряцание"],
    "бряцать": ["дребезжать", "звякать", "дзинькать", "лязгать", "звенеть", "бренчать", "брякать"],
    "брёлка": ["жалейка"],
    "брёх": ["гавканье", "лай", "лаяние", "брехня"],
    "бсм": ["бригадмил"],
    "бсср": ["белоруссия"],
    "бтр": ["бронетранспортер"],
    "бу": ["бомбоубежище", "бушный", "бэушный"],
    "бубен": ["морда", "рожа", "рыло", "харя", "ряха", "пятак", "морда лица"],
    "бубенец": ["бубенчик"],
    "бубенив": ["бубенивши"],
    "бубенивши": ["бубенив"],
    "бубенчик": ["бубенец", "колокольчик", "тестикула", "яичко", "яйцо"],
    "буби": ["бубны", "бубна"],
    "бубка": ["виноградина"],
    "бубль-гум": ["жвачка", "жевачка", "жевательная резинка", "бабл-гам"],
    "бубльгум": ["жвачка", "жевачка", "жевательная резинка", "бабл-гам"],
    "бубна": ["буйна", "кабаниха", "синичка"],
    "бубнение": ["бубненье"],
    "бубненье": ["бубнение"],
    "бубнив": ["бубнивши"],
    "бубнивши": ["бубнив"],
    "бубнить": ["бормотать", "гундосить"],
    "бубновый": ["бубённый"],
    "бубны": ["буби"],
    "бубнёж": ["бубнение"],
    "бугаз": ["тамак"],
    "бугай": ["бык-производитель", "амбал", "выпь"],
    "бугила": ["блекотна", "болиголова", "булиголова", "буглав", "вонючка", "дудва", "мутник", "омег", "свистуля", "сикавка", "цикута"],
    "бугор": ["кочка"],
    "бугорчатка": ["туберкулёз", "чахотка", "рыба-камень", "бородавчатка", "рыба-вурдалак"],
    "бугрив": ["бугривши"],
    "бугривши": ["бугрив"],
    "бугристый": ["неровный", "волнистый"],
    "будапешт": ["город на дунае", "жемчужина дуная"],
    "бударка": ["будара"],
    "буддизм": ["буддаизм", "буддхадхарма"],
    "буддийский": ["буддистский"],
    "буддист-ламаист": ["ламаист"],
    "буде": ["если"],
    "будем посмотреть": ["посмотрим", "увидим"],
    "будень": ["рабочий день"],
    "будет": ["достаточно", "довольно", "хватит"],
    "будетлянин": ["кубофутурист"],
    "будзюцу": ["будо"],
    "будив": ["будивши"],
    "будивши": ["будив"],
    "будинок": ["хата"],
    "будировав": ["будировавши"],
    "будировавши": ["будировав"],
    "будировать": ["дуться", "сердиться", "на", "ссориться", "конфликтовать", "возбуждать", "будоражить", "бередить"],
    "будить": ["пробуждать", "возбуждать", "вызывать", "вызывать к жизни"],
    "будка": ["конура", "ларёк", "киоск", "морда", "ряха", "ряшка"],
    "будний": ["рабочий"],
    "будничность": ["обыденность", "повседневность", "рутинность"],
    "будничный": ["каждодневный", "повседневный", "обыденный"],
    "будоражив": ["будораживши"],
    "будораживши": ["будоражив"],
    "будоражить": ["беспокоить", "возбуждать", "волновать"],
    "будочник": ["городовой"],
    "будра": ["кошачья мята"],
    "будто": ["как", "как будто", "словно", "типа", "вроде", "разве"],
    "будто в воду глядеть": ["как в воду глядеть", "как будто в воду глядеть", "как в воду смотреть", "будто в воду смотреть", "как будто в воду смотреть"],
    "будто в воду смотреть": ["как в воду глядеть", "будто в воду глядеть", "как будто в воду глядеть", "как в воду смотреть", "как будто в воду смотреть"],
    "будуар": ["гостиная"],
    "будучина": ["будущина"],
    "будущее": ["грядущее", "дальнейшее", "предстоящее", "перспектива", "будущность", "будущее время", "футурум"],
    "будущее время": ["футур", "футурум"],
    "будущий": ["грядущий", "дальнейший", "последующий", "предстоящий", "намеченный", "надвигающийся", "наступающий", "преднамеченный", "предположенный", "приближающийся", "обещающий", "чаемый", "следующий"],
    "будущина": ["будучина"],
    "будущность": ["будущее", "грядущее", "перспектива", "участь", "карьера", "успех", "судьба"],
    "будыль": ["бодыль", "купырь", "дудка", "пустосел", "морковник", "булдышка", "голень", "пенёк", "кол", "копыл", "тычок", "торчок", "поторчинка", "тычина", "сошка"],
    "будь другом": ["пожалуйста", "будьте добры"],
    "будь здоров": ["бывай", "пока", "давай", "здравствуй", "ничего себе"],
    "будьте добры": ["пожалуйста", "прошу"],
    "будьте здоровы": ["здоровья"],
    "будяк": ["бодяк", "осот"],
    "будённовец": ["прикумец", "прикумчанин"],
    "буе": ["буенча", "буйлап"],
    "буевец": ["буевлянин"],
    "буевлянин": ["буевец"],
    "буенча": ["буе", "буйлап"],
    "буерак": ["овраг"],
    "буесть": ["отвага", "храбрость", "ярость"],
    "буж": ["сосудорасширитель", "дилататор"],
    "буж-щуп": ["камнеискатель", "камнещуп"],
    "бужировав": ["бужировавши"],
    "бужировавши": ["бужировав"],
    "буздякец": ["буздяковец"],
    "буздяковец": ["буздякец"],
    "бузив": ["бузивши"],
    "бузивши": ["бузив"],
    "бузила": ["бузотёр", "бузотёрша", "бузотёрка", "буян", "дебошир", "дебоширка", "драчун", "драчунья", "задира", "скандалист", "скандалистка", "смутьян", "смутьянка", "смутьянша", "хулиган"],
    "бузина": ["бузовник", "бузник", "бузинник", "буз", "боз"],
    "бузить": ["скандалить", "буйствовать", "бунтовать", "шуметь"],
    "бузливость": ["бузотёрство"],
    "бузов": ["бызув"],
    "бузовав": ["бузовавши"],
    "бузовавши": ["бузовав"],
    "бузотёр": ["бузила", "буян", "дебошир", "драчун", "задира", "скандалист", "склочник", "смутьян", "хулиган"],
    "бузотёрив": ["бузотёривши"],
    "бузотёривши": ["бузотёрив"],
    "бузотёрить": ["скандалить"],
    "бузотёрничав": ["бузотёрничавши"],
    "бузотёрничавши": ["бузотёрничав"],
    "бузотёрствовав": ["бузотёрствовавши"],
    "бузотёрствовавши": ["бузотёрствовав"],
    "бузулукчанин": ["бузулучанин"],
    "бузулучанин": ["бузулукчанин"],
    "бузульник": ["лигулария", "лигулярия"],
    "бузург": ["калон"],
    "буй": ["бакен"],
    "буйвол-рыба": ["иктиобус"],
    "буйлап": ["буенча"],
    "буйнакец": ["темирханшуринец"],
    "буйнакск": ["темир-хан-шура"],
    "буйный": ["бурный", "неистовый", "яростный"],
    "буйство": ["драка", "бунт"],
    "буйствовав": ["буйствовавши"],
    "буйствовавши": ["буйствовав"],
    "буйствовать": ["буянить", "свирепствовать"],
    "букан": ["букашка"],
    "букапив": ["букапивши"],
    "букапивши": ["букапив"],
    "букашка": ["козявка", "сикарашка"],
    "буква": ["литера"],
    "буква в букву": ["буквально", "добуквенно", "дословно", "слово в слово", "до слова", "тик-в-тик", "точка в точку", "точь-в-точь", "тютелька в тютельку"],
    "буквализм": ["буквалистика"],
    "буквалистика": ["буквализм", "формализм"],
    "буквалистический": ["буквалистский"],
    "буквально": ["дословно", "в точности", "прямо-таки", "поистине", "в прямом смысле"],
    "буквальность": ["дословность"],
    "буквальный": ["дословный", "прямой", "точный"],
    "букварь": ["азбука"],
    "буквица": ["заглавная буква", "инициал", "глаголица"],
    "буквоед": ["педант", "формалист", "бюрократ"],
    "буквоедка": ["формалистка"],
    "буквоедский": ["формалистский"],
    "буквоедство": ["формализм"],
    "буквой зю": ["зигзагообразно"],
    "буквопечатающий": ["буквопечатный"],
    "буквопечатный": ["буквопечатающий"],
    "буквосочетание": ["сочетание"],
    "букет": ["совокупность"],
    "букетировав": ["букетировавши"],
    "букетировавши": ["букетировав"],
    "букетный": ["букетовый"],
    "буккальный": ["ротовой"],
    "буккер": ["севозапашник"],
    "буккеровав": ["буккеровавши"],
    "буккеровавши": ["буккеровав"],
    "буккроссинг": ["книговорот"],
    "букле": ["ратин", "эпонж"],
    "буклет": ["листок"],
    "букля": ["локон"],
    "букмарклет": ["закладурка"],
    "буковка": ["буквочка"],
    "буколика": ["пастораль"],
    "буколический": ["пастушеский", "пасторальный", "сельский", "загородный", "мирный", "безмятежный", "умиротворённый", "идиллический"],
    "букридер": ["ридер", "читалка", "электронная книга"],
    "букс": ["самшит"],
    "буксировав": ["буксировавши"],
    "буксировавши": ["буксировав"],
    "буксовав": ["буксовавши"],
    "буксовавши": ["буксовав"],
    "буксовать": ["пробуксовывать", "стопориться", "гальмовать"],
    "булава": ["палица"],
    "булавовидный": ["ропалический"],
    "булавоуска": ["аскалаф"],
    "булавочник": ["булавочница"],
    "булавочница": ["булавочник"],
    "булат": ["вутц", "вуц", "клинок"],
    "булгачив": ["булгачивши"],
    "булгачивши": ["булгачив"],
    "булгуннях": ["бугор пучения", "гидролакколит", "пинго", "тебелер"],
    "булевый": ["булев", "булевский"],
    "булик": ["бульбулятор"],
    "булимия": ["гиперорексия", "кинорексия"],
    "булинь": ["беседочный узел"],
    "булка": ["кирпичик", "белый хлеб", "ягодица"],
    "буллинг": ["травля", "задирание"],
    "буллить": ["травить"],
    "булочная": ["булочная-пекарня", "хлебопекарня"],
    "бултыхав": ["бултыхавши"],
    "бултыхавши": ["бултыхав"],
    "бултыханье": ["бултыхание"],
    "бултыхнув": ["бултыхнувши"],
    "бултыхнувши": ["бултыхнув"],
    "бултыхнуться": ["плюхнуться"],
    "булыга": ["булыжник", "валун"],
    "буль": ["бультерьер"],
    "бульбаш": ["белорус"],
    "бульбулировав": ["бульбулировавши"],
    "бульбулировавши": ["бульбулировав"],
    "бульбулятор": ["бурбулятор", "бонг"],
    "бульвар": ["проспект", "авеню"],
    "бульварный": ["мещанский", "обывательский"],
    "бульдозерист": ["бульдозерщик"],
    "бульйонний": ["бульйоновий"],
    "бульк": ["мыльный пузырь"],
    "булька": ["пузырь"],
    "булькав": ["булькавши"],
    "булькавши": ["булькав"],
    "булькать": ["журчать"],
    "бульки": ["щипцы"],
    "булькнув": ["булькнувши"],
    "булькнувши": ["булькнув"],
    "бум": ["фурор", "ажиотаж"],
    "бумага": ["документ"],
    "бумагокартон": ["бумага", "картон"],
    "бумагокручение": ["квиллинг"],
    "бумаголожество": ["бюрократизм"],
    "бумагомарака": ["бумагомаратель", "писака", "щелкопёр", "графоман"],
    "бумагомаранье": ["бумагомарание"],
    "бумагомаратель": ["бумагомарака", "щелкопёр", "писака"],
    "бумагомарательство": ["бумагомарание"],
    "бумагопрядение": ["хлопкопрядение"],
    "бумагорезальный": ["бумагорезательный"],
    "бумагорезательный": ["бумагорезальный"],
    "бумагорезка": ["шредер"],
    "бумажник": ["портмоне", "лопатник", "кошелёк"],
    "бумажный тигр": ["колосс на глиняных ногах"],
    "бумажонка": ["бумажка", "бумажечка"],
    "бумазея": ["фланель", "бязь", "байка", "бомбазин", "бомбазея", "бамбазея"],
    "бумбокс": ["балалайка", "бумбастик"],
    "бумер": ["бимер", "бэха"],
    "бумкав": ["бумкавши"],
    "бумкавши": ["бумкав"],
    "бумкнув": ["бумкнувши"],
    "бумкнувши": ["бумкнув"],
    "буна": ["бояна"],
    "бунгало": ["хижина", "дача"],
    "бунгарус": ["крайт", "бунгар"],
    "бундес": ["немец", "фриц", "бундесмарка"],
    "бундесбюргер": ["бундес"],
    "бундесмарка": ["немецкая марка"],
    "бундесовский": ["бундесовый"],
    "бундесовый": ["бундесовский"],
    "бундеспрезидент": ["федеральный президент"],
    "бундесрат": ["сортир", "туалет", "сральник", "нужник"],
    "бундестим": ["сборная", "германии", "немецкий"],
    "бунзенит": ["закись никеля"],
    "бункеровав": ["бункеровавши"],
    "бункеровавши": ["бункеровав"],
    "бункеровщик": ["бункеровочное судно"],
    "бунт": ["мятеж", "восстание", "возмущение", "ребелия", "неповиновение", "непокорность", "несогласие"],
    "бунт вторых секретарей": ["революция вторых секретарей"],
    "бунтарка": ["бунтовщица", "мятежница"],
    "бунтарский": ["крамольный"],
    "бунташный": ["бунтарский", "мятежный"],
    "бунтовав": ["бунтовавши"],
    "бунтовавши": ["бунтовав"],
    "бунтовщица": ["бунтарка"],
    "бунчав": ["бунчавши"],
    "бунчавши": ["бунчав"],
    "бунчук": ["туг", "кутас"],
    "буньям": ["буня"],
    "бур": ["сверло", "бурав"],
    "бура": ["декагидрат тетрабората натрия", "тинкал"],
    "буравив": ["буравивши"],
    "буравивши": ["буравив"],
    "буравиться": ["пробиваться", "прорываться"],
    "буравление": ["просверливание", "бурение", "верчение", "разбуравливание", "сверление", "провертывание"],
    "бурак": ["буряк"],
    "буран": ["метель", "вьюга", "пурга"],
    "буранив": ["буранивши"],
    "буранивши": ["буранив"],
    "бурата": ["балка брата", "бурата-сала"],
    "буратино": ["пиноккио"],
    "бурачник": ["огуречная трава", "огуречник"],
    "бурачок": ["кузовок", "туесок"],
    "бург": ["замок", "крепость", "боро"],
    "бурган": ["бурхан"],
    "бургер": ["гамбургер"],
    "бургия": ["свредел"],
    "бургомистр": ["мэр", "градоначальник"],
    "бургонский": ["бургундский"],
    "бургундский": ["бургонский"],
    "бургунское": ["бургонское"],
    "бурда": ["питьё", "пойло", "помои", "напиток", "похлёбка", "баланда", "брандахлыст", "путаница", "вздор", "чепуха"],
    "бурдалю": ["писсуар", "утка", "ночной горшок"],
    "бурдей": ["землянка"],
    "бурдомага": ["бурда"],
    "бурдюк": ["мех"],
    "бурев": ["буревши"],
    "буревши": ["бурев"],
    "бурей": ["бурее"],
    "бурекас": ["бурек"],
    "бурелом": ["буреломник", "ветровал", "буревал", "валежник", "валеж", "лежина", "лежень", "колодник", "выскорь", "выскорьё", "выскорд", "выскирь", "выскирняк", "падинник"],
    "буремний": ["буряний"],
    "буренак": ["бурен", "гъсталак", "шубрак", "храсталак"],
    "буренье": ["бурение"],
    "буржуа": ["буржуй", "буржуин"],
    "буржуазия": ["буржуи"],
    "буржуазно-реформаторский": ["буржуазно-реформистский"],
    "буржуазность": ["буржуйство", "буржуинство"],
    "буржуин": ["буржуй", "буржуа", "богатей", "богач"],
    "буржуинский": ["буржуйский"],
    "буржуй": ["буржуин", "буржуа", "капиталист", "богатей", "толстосум", "эгоист"],
    "буржуйка": ["времянка"],
    "буржуйский": ["буржуинский", "западный"],
    "буржуйство": ["буржуинство"],
    "бурив": ["буривши"],
    "буривав": ["буривавши"],
    "буривавши": ["буривав"],
    "буривши": ["бурив"],
    "бурильщик": ["бурильщица", "буровик"],
    "бурильщица": ["бурильщик", "буровик"],
    "бурить": ["пробуривать"],
    "буриться": ["буравиться", "переть", "переться"],
    "бурка": ["гнедая", "африканерка"],
    "буркав": ["буркавши"],
    "буркавши": ["буркав"],
    "буркалы": ["глаза", "бельмо", "гляделка", "зенки", "шар", "очи"],
    "буркать": ["ворчать", "бубнить"],
    "буркина-фасо": ["верхняя вольта"],
    "буркиниец": ["вольтиец"],
    "буркинийка": ["вольтийка"],
    "буркнув": ["буркнувши"],
    "буркнувши": ["буркнув"],
    "буркнуть": ["пробормотать"],
    "буркотать": ["бурковать", "ворчать", "урчать", "бормотать", "брюзжать", "ворковать"],
    "буркотев": ["буркотевши"],
    "буркотевши": ["буркотев"],
    "бурлак": ["бурлака"],
    "бурлачив": ["бурлачивши"],
    "бурлачивши": ["бурлачив"],
    "бурленье": ["бурление"],
    "бурлеск": ["бурлеска", "преувеличение", "гротеск", "фарс", "ревю", "кабаре"],
    "бурлеска": ["бурлеск"],
    "бурлив": ["бурливши"],
    "бурливость": ["бурность", "шумность", "беспокойность"],
    "бурливши": ["бурлив"],
    "бурный": ["штормовой", "стремительный", "мощный", "страстный", "неистовый", "яростный"],
    "буро-жёлтый": ["жёлто-бурый"],
    "буро-красный": ["красно-бурый"],
    "буробив": ["буробивши"],
    "буробивши": ["буробив"],
    "буробить": ["лгать", "говорить неправду", "говорить чушь", "сочинять небылицы", "фантазировать", "саботировать", "тормозить", "заниматься волокитой", "волокитить"],
    "буровая установка": ["буровой станок", "буровая", "буровая машина"],
    "буровив": ["буровивши"],
    "буровивши": ["буровив"],
    "буровик": ["бурильщик", "бурильщица"],
    "буровой станок": ["буровая", "буровая установка", "буровая машина"],
    "бурса": ["брусса", "прусса", "пруссиада", "плусиада"],
    "бурсак": ["студент", "учащийся"],
    "бурт": ["бурта"],
    "буртовав": ["буртовавши"],
    "буртовавши": ["буртовав"],
    "буруй": ["буру"],
    "бурунгъу": ["биринчи"],
    "бурунди": ["республика бурунди"],
    "бурундучий": ["бурундуковый"],
    "бурундучная руда": ["полосчатая руда"],
    "бурундучный": ["бурундуковый", "бурундучий"],
    "бурушаски": ["буришский", "канджутский", "вершикский"],
    "бурхан": ["бурган"],
    "бурчав": ["бурчавши"],
    "бурчавши": ["бурчав"],
    "бурчание": ["бурчанье", "бормотание", "бормотанье"],
    "бурчанье": ["бурчание"],
    "бурш": ["корпорант"],
    "бурштынавы": ["янтарны"],
    "бурщица": ["бурильщица"],
    "буря": ["ураган", "шторм"],
    "буря в стакане": ["много шума из ничего", "делать из мухи слона"],
    "буряк": ["цукровий"],
    "бурят": ["бурят-монгол"],
    "бурят-монгол": ["бурят"],
    "бурят-монгольский": ["бурятский"],
    "бурятия": ["республика бурятия", "бурятская сср", "бурятская асср", "бурят-монгольская асср", "государство бурят-монголия", "бурят-монгольская автономная область", "монголо-бурятская автономная область"],
    "бурятский": ["бурят-монгольский"],
    "бурятский язык": ["бурятский"],
    "бурёнка": ["корова"],
    "бус": ["бусенник", "бусенок", "бусёнчик", "бусик", "бусовец", "бусовик", "бусяк", "буса", "бусовичок", "бусок", "бусь"],
    "бусак": ["багор"],
    "бусенник": ["коикс"],
    "бусляня": ["буслянё"],
    "буслянё": ["бусляня"],
    "бусол": ["бусул"],
    "буссоль": ["компас"],
    "буст": ["всплеск"],
    "бустер": ["усилитель"],
    "бусул": ["бусол"],
    "бусурман": ["басурман"],
    "бусы": ["ожерелье"],
    "бут": ["бутовый камень"],
    "бута": ["пейсли"],
    "бутадиен": ["дивинил"],
    "бутак": ["бутах"],
    "бутан": ["королевство бутан"],
    "бутаница": ["блъсканица", "навалица", "тъпканица", "бутане", "калабалък", "многолюдие"],
    "бутафория": ["муляж", "фальшь", "показуха", "мишура"],
    "бутафорка": ["бутафорская", "бутафорная"],
    "бутафорная": ["бутафорская", "бутафорка"],
    "бутафорный": ["бутафорский", "ненастоящий", "поддельный", "фальшивый"],
    "бутафорская": ["бутафорная", "бутафорка"],
    "бутафорский": ["бутафорный", "ненастоящий", "поддельный", "фальшивый"],
    "бутен": ["бутилен", "изобутилен"],
    "бутень": ["гонощи", "репный кервель", "купырь", "пестрец", "дикая петрушка"],
    "бутер": ["бутик"],
    "бутерброд": ["бутер", "сандвич"],
    "бутеть": ["полнеть", "толстеть", "жиреть", "тучнеть", "наливаться", "ботеть"],
    "бутив": ["бутивши"],
    "бутивши": ["бутив"],
    "бутик": ["фирменный магазин"],
    "бутилен": ["бутен", "изобутилен"],
    "бутилировав": ["бутилировавши"],
    "бутилировавши": ["бутилировав"],
    "бутилированный гидрокситолуол": ["бгт"],
    "бутилоксианизол": ["боа"],
    "бутилятор": ["боттлер"],
    "бутират": ["оксибат натрия", "оксибутират натрия", "гомк", "лактон", "бут", "бутик", "буратино", "гэбл", "гбл", "бутан", "бдо", "бд"],
    "бутирилхолинэстераза": ["псевдохолинэстераза"],
    "бутирометр": ["лактоскоп", "жиромер"],
    "буткада": ["бутхона"],
    "бутовав": ["бутовавши"],
    "бутовавши": ["бутовав"],
    "бутон": ["прыщ", "волдырь"],
    "бутончик": ["бутон"],
    "буточник": ["будочник"],
    "бутошник": ["будочник"],
    "бутпараст": ["санампараст"],
    "бутринти": ["бутринто", "бутринт"],
    "бутстрап": ["автопоэзис"],
    "бутстреппинг": ["бутстрэппинг"],
    "бутстрэппинг": ["бутстреппинг"],
    "бутуз": ["карапуз", "пузан"],
    "бутузив": ["бутузивши"],
    "бутузивши": ["бутузив"],
    "бутузить": ["мутузить"],
    "бутхона": ["буткада"],
    "буты": ["буцы"],
    "бутылеобразный": ["бутылкообразный"],
    "бутылированный": ["бутилированный"],
    "бутылка": ["башня"],
    "бутылочный": ["бутылочно-зелёный"],
    "бутыль": ["бутель"],
    "бутылёк": ["бутылёчек", "бутылец", "бутылон", "бутыльон"],
    "буфер": ["прослойка", "демпфер", "буферный раствор", "резерв", "дойка", "бампер"],
    "буфер обмена": ["клипборд"],
    "буферизовав": ["буферизовавши"],
    "буферизовавши": ["буферизовав"],
    "буфет": ["горка", "кафе", "стойка"],
    "буфмуслин": ["буф-муслин"],
    "буфтальм": ["бычий глаз"],
    "буффало": ["иктиобус"],
    "буффонадный": ["шутовской"],
    "буффонив": ["буффонивши"],
    "буффонивши": ["буффонив"],
    "буффонский": ["буффонный"],
    "бух": ["бах", "бац"],
    "бухав": ["бухавши"],
    "бухавши": ["бухав"],
    "бухавший": ["гремевший", "грохотавший", "ухавший", "завывавший", "кашлявший"],
    "бухало": ["бухло", "бухалово"],
    "бухаловка": ["пьянка"],
    "бухалово": ["бухло"],
    "буханка": ["кирпичик", "брикет", "уазик"],
    "буханочка": ["буханка"],
    "бухара": ["бохара"],
    "бухарец": ["бухаретин"],
    "бухать": ["греметь", "грохотать", "бахать", "бабахать", "бить", "ударять", "грохать", "трахать", "биться", "ударяться", "грохаться"],
    "бухач": ["выпивка", "бухло", "попойка", "пьянка", "бухаловка", "выпивон", "выпивончик"],
    "бухвостив": ["бухвостивши"],
    "бухвостивши": ["бухвостив"],
    "бухгалтер": ["счетовод"],
    "бухгалтерив": ["бухгалтеривши"],
    "бухгалтеривши": ["бухгалтерив"],
    "бухгалтерить": ["бухгалтерствовать"],
    "бухгалтерия": ["счетоводство"],
    "бухгалтерский баланс": ["баланс"],
    "бухгалтерский учёт": ["бухучёт"],
    "бухгалтерствовав": ["бухгалтерствовавши"],
    "бухгалтерствовавши": ["бухгалтерствовав"],
    "бухгалтерствовать": ["бухгалтерить"],
    "бухгалтерша": ["бухгалтер"],
    "бухикав": ["бухикавши"],
    "бухикавши": ["бухикав"],
    "бухикать": ["кашлять"],
    "бухлишко": ["бухло"],
    "бухло": ["выпивка", "пойло"],
    "бухнув": ["бухнувши"],
    "бухнувши": ["бухнув"],
    "бухнуть": ["ляпнуть", "сморозить", "разбухать"],
    "бухнуть в ноги": ["упасть в ноги", "повалиться в ноги", "валяться в ногах"],
    "бухой": ["пьяный"],
    "бухта": ["гавань", "залив", "губа"],
    "бухта мурманца": ["мурманец"],
    "бухтев": ["бухтевши"],
    "бухтевши": ["бухтев"],
    "бухур": ["лодан"],
    "бухштабировав": ["бухштабировавши"],
    "бухштабировавши": ["бухштабировав"],
    "бухштабировать": ["диктовать"],
    "буц": ["ботинок", "полуботинок", "бутса"],
    "буцав": ["буцавши"],
    "буцавши": ["буцав"],
    "буцать": ["бухать", "бабахать", "фигачить", "мутузить"],
    "буцегарня": ["тюрма"],
    "буцнув": ["буцнувши"],
    "буцнувши": ["буцнув"],
    "буцнуть": ["пнуть", "ударить"],
    "буча": ["скандал", "переполох", "драка", "ссора", "крик", "шум", "буза", "суматоха", "заварушка", "заваруха", "потасовка", "катавасия", "хай", "тарарам", "кипеш"],
    "бучав": ["бучавши"],
    "бучавши": ["бучав"],
    "бучарда": ["отбивной молоток"],
    "бучень": ["шмель"],
    "бучив": ["бучивши"],
    "бучивши": ["бучив"],
    "бучина": ["бук"],
    "бучний": ["гучний"],
    "бушевав": ["бушевавши"],
    "бушевавши": ["бушевав"],
    "бушевание": ["бушеванье"],
    "бушеванье": ["бушевание"],
    "бушевать": ["беситься", "буйствовать", "неистовствовать", "свирепствовать", "яриться"],
    "бушков": ["сьыв"],
    "бушма": ["брюква", "толстуха"],
    "бушмен": ["капоид"],
    "бушприт": ["бугшприт"],
    "бушующий": ["бесящийся", "буйствующий", "неистовствующий", "свирепствующий", "ярящийся"],
    "буьт": ["бит"],
    "буэнос-айрес": ["город добрых ветров", "байрес"],
    "буэносайресец": ["портеньо"],
    "буюмек": ["осьмек"],
    "буява": ["буево", "буйвище", "буявище"],
    "буявый": ["буйный", "наглый", "дерзкий", "развратный"],
    "буян": ["дебошир", "скандалист", "бузила", "бузотёр", "скандальщик", "забияка", "задира", "хулиган"],
    "буянив": ["буянивши"],
    "буянивши": ["буянив"],
    "бхагавадгита": ["бхагавад-гита"],
    "бхикшу": ["саньяси"],
    "бхуджангасана": ["поза кобры", "поза змеи"],
    "бхумихар": ["бхуинхар", "бабхан"],
    "бхэкасана": ["поза лягушки"],
    "български език": ["български"],
    "бълоха": ["блъха", "блоха"],
    "бърборко": ["празнодумец", "празнословец", "дърдорко", "бъбрица", "фарфара"],
    "бързей": ["поток"],
    "бързоходец": ["куриер", "разсилен"],
    "бъркотия": ["неразбория", "безсистемност", "бърканица", "безредие", "неуправия"],
    "бърна": ["устна", "джука"],
    "бърсалка": ["изтривалка", "парцал", "пачавра"],
    "бъта": ["кода", "прокс", "кода бъта"],
    "быв": ["бывши", "будучи", "находившись", "являвшись"],
    "бывав": ["бывавши"],
    "бывавши": ["бывав"],
    "бывайте": ["бывай"],
    "бывалый": ["прежний", "былой", "привычный", "опытный", "искушённый", "матёрый", "тёртый", "многоопытный"],
    "бывальщина": ["быль"],
    "бывать": ["существовать"],
    "бывшая югославская республика македония": ["македония", "республика македония", "бюрм"],
    "бывши": ["быв", "находившись", "являвшись"],
    "бывший": ["прежний", "старый"],
    "быгав": ["быгавши"],
    "быгавши": ["быгав"],
    "быдлив": ["быдливши"],
    "быдливши": ["быдлив"],
    "быдло": ["скот"],
    "быдлотрон": ["лохотрон"],
    "бызув": ["бузов", "бузув"],
    "бык": ["громила", "бугай", "кабан", "медведь", "шестёрка"],
    "бык-производитель": ["бугай"],
    "быковав": ["быковавши"],
    "быковавши": ["быковав"],
    "быковать": ["бычить", "буянить", "рамсить"],
    "была не была": ["пан или пропал", "будь что будет", "где наша не пропадала", "попытка не пытка"],
    "былие": ["быльё"],
    "былинка": ["травинка", "хворостинка"],
    "былинник": ["былинщик"],
    "былинный": ["легендарный"],
    "былинушка": ["былиночка"],
    "былинщик": ["былинник", "сказитель"],
    "былое": ["прошлое"],
    "былой": ["давний", "давнишний", "давнопрошедший", "минувший", "прежний", "прошедший", "прошлый", "стародавний", "ушедший"],
    "быльник": ["полынь"],
    "быльё": ["трава"],
    "быстрев": ["быстревши"],
    "быстревши": ["быстрев"],
    "быстренько": ["быстро", "скоренько", "шустренько"],
    "быстреть": ["ускоряться", "быстриться"],
    "быстрив": ["быстривши"],
    "быстривши": ["быстрив"],
    "быстрина": ["стремнина"],
    "быстрить": ["убыстрять", "ускорять"],
    "быстро": ["живо", "бойко", "бегло", "проворно", "поспешно", "спешно", "скоро", "стремительно", "торопливо", "пулей", "мухой", "молнией", "с полоборота", "с полпинка", "быро"],
    "быстровращательный": ["быстровращающийся"],
    "быстровращающийся": ["быстровращательный"],
    "быстровчанин": ["быстровец"],
    "быстроглазый": ["зоркий", "орлиный глаз", "глаз-алмаз", "глаз-ватерпас"],
    "быстрогорящий": ["быстросгорающий"],
    "быстродействие": ["производительность"],
    "быстроистокец": ["быстрянин"],
    "быстролётный": ["быстрокрылый", "стремительный", "мимолётный"],
    "быстроногий": ["быстрый", "шустрый", "стремительный", "быстроходный", "скороходный", "скоростной", "ходкий", "резвый", "проворный"],
    "быстрота": ["стремительность", "скорость"],
    "быстротечно": ["скоротечно", "стремительно"],
    "быстротечность": ["скоротечность", "стремительность"],
    "быстротечный": ["быстротекущий", "скоротечный"],
    "быстроходный": ["быстрый", "стремительный", "скоростной", "ходкий", "быстроногий", "резвый", "проворный"],
    "быстрые шахматы": ["активные шахматы"],
    "быстрый": ["стремительный", "быстроходный", "скоростной", "ходкий", "быстроногий", "резвый", "проворный", "скорый", "спешный", "торопливый"],
    "быстряк": ["быстрина", "стремнина"],
    "быстрянин": ["быстроистокец"],
    "быт": ["устой", "обиход"],
    "бытовав": ["бытовавши"],
    "бытовавши": ["бытовав"],
    "бытованье": ["бытование"],
    "бытовать": ["водиться"],
    "бытовик": ["бытописатель", "бытописец", "певец быта"],
    "бытовка": ["вагончик", "строительный вагончик", "вагон-дом", "времянка", "балок", "передвижка"],
    "бытовой": ["будничный", "обыденный", "обыкновенный", "повседневный", "прозаический", "жанровый"],
    "бытовщина": ["бытовизм"],
    "бытописатель": ["историк"],
    "быть в дураках": ["остаться в дураках", "опростоволоситься"],
    "быть в лицах": ["остаться в лицах"],
    "быть в моде": ["быть в полной моде"],
    "быть в полной моде": ["быть в моде"],
    "быть в состоянии": ["мочь", "быть в силах"],
    "быть на замечании": ["быть на заметке"],
    "быть на игле": ["сидеть на игле"],
    "быть на кочерге": ["быть на кривой кочерге", "сидеть на кочерге", "сидеть на кривой кочерге"],
    "быть на моде": ["быть в моде"],
    "быть на носу": ["не за горами"],
    "быть по корешам": ["на короткой ноге"],
    "быть у смерти": ["жить у смерти"],
    "быть чем щи наливают": ["быть чем щи разливают"],
    "быть чем щи разливают": ["быть чем щи наливают"],
    "бытьё": ["бытие"],
    "быуай": ["бабай"],
    "быцак": ["бицак", "пычакъ"],
    "бычара": ["бык", "лось", "амбал"],
    "бычачий": ["бычий"],
    "бычив": ["бычивши"],
    "бычивши": ["бычив"],
    "бычить": ["быковать", "наезжать"],
    "бычок-кнут": ["мартовик", "бычок-жаба"],
    "бычок-песочник": ["воронка"],
    "бычок-цуцик": ["мраморный тупоносый бычок"],
    "бычонок": ["бычок"],
    "бьяв": ["абяв", "бияв"],
    "бьянконери": ["старая сеньора"],
    "бэ": ["буки"],
    "бэй": ["бий"],
    "бэк-вокал": ["подпевка"],
    "бэкап": ["резервная копия", "бэкапка"],
    "бэкапив": ["бэкапивши"],
    "бэкапивши": ["бэкапив"],
    "бэкапить": ["бекапить", "букапить"],
    "бэкграунд": ["подготовка", "фон"],
    "бэкграундный": ["неофициальный"],
    "бэкенд-разработчик": ["бэкендер", "бэкендщик"],
    "бэкендер": ["бэкендщик", "бэкенд-разработчик"],
    "бэкендщик": ["бэкендер", "бэкенд-разработчик"],
    "бэкпэкинг": ["бэкпекинг"],
    "бэкроним": ["обратная аббревиатура"],
    "бэкслеш": ["обратная косая черта", "обратный слеш"],
    "бэл": ["бэль"],
    "бэли": ["бели"],
    "бэнг": ["шынгало", "нажужо", "бенг"],
    "бэр": ["биологический эквивалент рентгена", "биологический эквивалент рада", "рентген-эквивалент"],
    "бэрчист": ["берчист"],
    "бэс": ["беш"],
    "бэткап": ["баткеп"],
    "бэушный": ["подержанный", "бу", "бывший в употреблении", "юзаный", "поношенный", "бэушечный"],
    "бэха": ["бмв", "бумер"],
    "бэшка": ["бэшник", "бэшница"],
    "бээмпэшка": ["бмп"],
    "бюгюнь": ["бигин", "бюгюньню"],
    "бюджетировав": ["бюджетировавши"],
    "бюджетировавши": ["бюджетировав"],
    "бюджетник": ["лоукостер"],
    "бюджетный": ["государственный", "недорогой", "дешёвый", "низкозатратный"],
    "бюллетенив": ["бюллетенивши"],
    "бюллетенивши": ["бюллетенив"],
    "бюллетенить": ["быть на больничном"],
    "бюллетень": ["журнал", "сводка", "избирательный бюллетень", "листок нетрудоспособности", "больничный лист", "больничный"],
    "бюльбюль": ["дрозд"],
    "бюргер": ["буржуа", "мещанин"],
    "бюро": ["стол", "контора", "офис"],
    "бюрократ": ["формалист", "буквоед"],
    "бюрократизировав": ["бюрократизировавши"],
    "бюрократизировавши": ["бюрократизировав"],
    "бюрократизировать": ["обюрокрачивать", "обюрократить"],
    "бюрократизироваться": ["обюрокрачиваться", "обюрократиться"],
    "бюрократизм": ["канцелярщина", "волокита"],
    "бюрократизъм": ["канцеларщина", "формализъм", "педантизъм", "буквоедство"],
    "бюрократический": ["канцелярский"],
    "бюрократический футбол": ["отфутболивание", "тягомотина", "волокита", "бюрократизм"],
    "бюрократия": ["чиновничество", "номенклатура", "бюрократизм", "канцелярщина", "волокита"],
    "бюст": ["грудь"],
    "бюстгальтер": ["лифчик", "лиф", "титишник"],
    "бюстье": ["лиф"],
    "бяздомны": ["беспрытульны"],
    "бязь": ["фланель", "бумазея", "байка", "ситец", "миткаль"],
    "бяка": ["кака"],
    "бякав": ["бякавши"],
    "бякавши": ["бякав"],
    "бякнув": ["бякнувши"],
    "бякнувши": ["бякнув"],
    "бямба": ["санчир"],
    "бяс": ["дявол", "демон", "зъл", "дух", "ярост", "унес", "страст", "злоба", "яд", "лудост", "умопомрачение", "помрачение", "буйство", "безчинство"],
    "бясконцы": ["бесканцовы"],
    "бяшка": ["овца", "барашек"],
    "бёздник": ["день рождения"],
    "бёклявюч": ["беклявюч"],
    "бёлек": ["уьлкю"],
    "бёрдвотчер": ["бердвотчер"],
    "бёрдвотчинг": ["бердвотчинг"],
    "бёрдвочер": ["бердвотчер", "бёрдвотчер"],
    "бёрек": ["берек"],
    "бёрю": ["бери"],
    "в адрес": ["по адресу"],
    "в аккурат": ["аккурат", "точно", "в точности", "как раз"],
    "в ахуе": ["в полном ахуе"],
    "в беспорядке": ["как попало", "бессистемно", "хаотично"],
    "в виде": ["вроде", "наподобие"],
    "в виду": ["на глазах"],
    "в возрасте": ["в годах", "в летах", "пожилой"],
    "в высшей степени": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "в глубоком пике": ["в падении", "в глубокой заднице"],
    "в глубь": ["в глубину", "в суть"],
    "в голову напулять": ["напулять в голову"],
    "в гору": ["вверх", "наверх"],
    "в дальнейшем": ["в будущем", "по прошествии времени", "по времени", "спустя время", "напредки", "впредь", "впоследствии", "как-нибудь", "попозже", "впоследствии времени", "опосля", "а там", "на будущее время", "вперед", "позже"],
    "в два счёта": ["моментально", "мгновенно", "в три секунды"],
    "в два хуя": ["в два смычка"],
    "в двух словах": ["вкратце", "кратко", "коротко", "сжато"],
    "в девичестве": ["урождённый"],
    "в дупель": ["зело", "дюже", "очень", "весьма"],
    "в душе": ["про себя", "мысленно", "по натуре", "по призванию"],
    "в дымину": ["в дым"],
    "в жопе свербеть": ["свербеть в жопе", "свербеть в тесной жопе"],
    "в жопу под муда": ["кошке под муда", "доить верблюда"],
    "в жопу пьяный": ["пьяный в стельку", "пьяный в зюзю", "пьяный в пердак", "пьяный в дупель", "пьяный в дупелину", "пьяный в дупло", "пьяный в говно", "пьяный в говнину", "пьяный в говнище"],
    "в зависимости от": ["по"],
    "в заводе нет": ["и в помине"],
    "в затылок": ["вереницей", "цепью", "цепочкой", "гуськом", "друг за другом", "один за другим", "один за одним", "затылок в затылок"],
    "в значительной мере": ["очень", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно"],
    "в зюзю": ["как зюзя", "в хлам", "вусмерть", "в жопу пьяный"],
    "в интересах": ["для", "ради", "на", "за", "во имя", "на благо", "во благо", "в пользу"],
    "в интересе": ["интересное положение", "в положении", "на сносях"],
    "в итоге": ["в результате", "в конце концов"],
    "в каждой бочке затычка": ["каждой бочке затычка"],
    "в каждой избушке свои погремушки": ["под каждой крышей свои мыши", "каждый дом имеет свой содом", "во всякой избушке свои покляпушки", "во всякой избушке свои поскрыпушки", "в каждой избушке свои поебушки", "в каждой избушке свои подъебушки"],
    "в качестве": ["в роли", "как"],
    "в конце концов": ["в конечном счёте", "в результате", "в итоге", "наконец", "когда-нибудь", "со временем", "рано или поздно", "не сегодня-завтра"],
    "в край": ["крайне", "вкрай"],
    "в крысу": ["крадучись", "крадучи", "крадчи"],
    "в курсе": ["в курсях"],
    "в лепёшку расшибиться": ["в лепёшку разбиться", "в лепёшку разойтись", "разбиться в лепёшку", "разойтись в лепёшку", "расшибиться в лепёшку", "вывернуться через жопу", "через жопу вывернуться"],
    "в лицах": ["наглядный", "образный", "наглядно", "образно"],
    "в лоб": ["в лобовую"],
    "в лом": ["лень", "неохота", "в ломы"],
    "в лоскуты": ["в стельку"],
    "в лучшем случае": ["если повезёт"],
    "в любом случае": ["всегда"],
    "в меру": ["умеренно", "достаточно", "хорошо", "сообразно", "в соответствии с", "по мере"],
    "в накладе": ["остаться в накладе"],
    "в натуре": ["действительно", "в самом деле", "нагишом"],
    "в несколько щей": ["в несколько щщей", "в несколько шщей"],
    "в ногу со временем": ["современно"],
    "в обтяжку": ["в облипку"],
    "в общем": ["короче говоря", "словом"],
    "в общем-то": ["в основном", "в сущности", "вообще", "обычно", "короче говоря", "словом"],
    "в оглоблю": ["с оглоблю"],
    "в один голос": ["единодушно"],
    "в один миг": ["в мгновение ока"],
    "в одиночку": ["в одно лицо", "в одно рыло", "в одну каску", "в одного"],
    "в одни щи": ["в одно лицо", "в одного", "в один щ", "в одну щу", "в одну щщу", "в одну шщу"],
    "в одно лицо": ["в одного", "в одно рыло"],
    "в одно рыло": ["в одиночку", "в одно лицо", "в одну каску", "в одного"],
    "в одного": ["в одиночку"],
    "в одночасье": ["единовременно", "сразу", "в мгновение ока", "в один миг"],
    "в основном": ["в главном", "как правило"],
    "в открытую": ["открыто"],
    "в отличие от": ["в противоположность"],
    "в отношении": ["насчёт", "касательно"],
    "в отрыве": ["отдельно", "оторванно", "обособленно", "в стороне"],
    "в охапку": ["обнявшись"],
    "в падлу": ["в лом", "лень", "неохота"],
    "в пандан": ["в дополнение", "подобно", "согласно", "созвучно", "под", "как", "под стать"],
    "в первую голову": ["в первую очередь", "прежде всего", "сначала"],
    "в первую очередь": ["первым делом", "сначала", "сперва", "в первую голову", "сам перво"],
    "в перспективе": ["в будущем"],
    "в пизду": ["совсем", "окончательно", "прочь", "подальше", "вон", "к чёрту", "на хуй"],
    "в пику": ["назло"],
    "в пол": ["макси"],
    "в положении": ["беременная", "брюхатая"],
    "в полукилометре": ["в полкилометре"],
    "в пользу": ["для", "в интересах", "ради", "на", "за", "во имя", "на благо", "во благо"],
    "в помине": ["поминание", "поминовение", "совсем", "вовсе"],
    "в поте лица": ["не покладая рук"],
    "в преддверии": ["накануне"],
    "в принципе": ["в общем", "в общем-то", "в целом", "в общем и целом", "теоретически", "по сути", "по большому счёту"],
    "в пролёте": ["не у дел", "у разбитого корыта"],
    "в противном случае": ["а то", "иначе"],
    "в пух": ["в пух и прах"],
    "в пух и прах": ["в пух", "под орех"],
    "в пылу": ["в горячке"],
    "в пясть": ["в горсть", "в пястку"],
    "в равной степени": ["в одинаковой мере", "в одинаковой степени", "в равной мере", "одинаково", "равно", "так же"],
    "в разгоне": ["отсутствовать"],
    "в разы": ["значительно", "намного", "существенно"],
    "в рай въехать на чужом хую": ["въехать в рай на чужом горбу", "на чужом горбу в рай въехать", "на чужом горбу в рай выехать", "въехать в рай на чужом хую"],
    "в районе": ["примерно", "приблизительно", "около", "где-то"],
    "в рамках": ["в пределах"],
    "в расход": ["на распыл"],
    "в расцвете сил": ["во цвете лет"],
    "в результате": ["в конце концов", "в итоге"],
    "в роли": ["в качестве"],
    "в рот мне ноги": ["офигеть", "ни хрена себе", "ничего себе", "удивительно"],
    "в самом деле": ["на самом деле", "да", "так", "верно", "действительно", "действительно так", "и действительно", "вне сомнения", "вне всякого сомнения", "без обмана", "точно", "точно так", "иначе быть не может", "иначе и быть не может", "всамделе"],
    "в самом соку": ["в расцвете сил"],
    "в самый раз": ["впору", "самое оно", "своевременно"],
    "в свете": ["в связи с", "вследствие"],
    "в связи с": ["вследствие", "в свете"],
    "в сердцах": ["сгоряча", "с сердцов"],
    "в силу": ["на основании", "вследствие", "из-за", "из", "по", "за", "по причине", "в результате", "ввиду", "благодаря", "от"],
    "в складчину": ["на паях"],
    "в случае": ["при условии"],
    "в случае чего": ["если что"],
    "в смысле": ["в отношении", "относительно", "то есть", "в каком смысле"],
    "в соответствии с": ["согласно"],
    "в срок": ["вовремя"],
    "в старину": ["давным-давно"],
    "в стороне": ["поодаль"],
    "в талию": ["приталенно"],
    "в теме": ["в курсе", "в курсе дела", "быть в курсе", "быть в теме", "ловить мышей", "сечь поляну"],
    "в темпе вальса": ["аллюр три креста", "шустро", "резво", "ноги в руки"],
    "в тихом омуте черти водятся": ["тихая вода берега подмывает"],
    "в то время как": ["пока", "но", "однако"],
    "в том числе": ["включая", "в числе прочего"],
    "в точку": ["точно", "в яблочко"],
    "в три погибели": ["неудобно", "тесно"],
    "в тулупах": ["в мундире", "в тулупчиках"],
    "в умат": ["в стельку"],
    "в ус не дуть": ["и в ус не дуть", "в ус себе не дуть", "и в ус себе не дуть", "в хуй не дуть", "и в хуй не дуть"],
    "в утиль": ["на переработку", "на свалку", "в расход"],
    "в форме": ["по форме", "как", "в виде"],
    "в хвост и в гриву": ["и в хвост и в гриву"],
    "в хлам": ["в зюзю", "в стельку", "вдрызг", "в дугу", "в жопу", "в говно", "вдребезги"],
    "в хуй дует": ["в хуй дышит"],
    "в хуй дышит": ["в хуй дует"],
    "в хуй не всраться": ["в хуй не упереться", "на хуй не всраться"],
    "в хуй не дуть": ["в ус не дуть", "и в ус не дуть", "в ус себе не дуть", "и в ус себе не дуть", "и в хуй не дуть"],
    "в хуй не ставить": ["не ставить ни в хуй", "ни в хуй не ставить"],
    "в хуй не упереться": ["в хуй не всраться", "на хуй не всраться"],
    "в целях": ["для", "ради", "из-за", "на", "за", "во имя", "с целью"],
    "в час по чайной ложке": ["через час по чайной ложке"],
    "в частности": ["то бишь", "именно", "то есть"],
    "в честь": ["во имя", "во славу", "ради"],
    "в числе": ["среди", "один из", "ряд"],
    "в чужом пиру похмелье": ["в чужом пиру да похмелье", "с чужого пира похмелье", "на чужом пиру с похмелья"],
    "в чём мать родила": ["голышом", "нагишом", "телешом", "ню", "убого"],
    "в шутку": ["шутки ради", "шутя"],
    "в шуточку": ["в шутку", "шутки ради", "шутя", "шутейно"],
    "в щи": ["в хлам", "вусмерть"],
    "в яблочко": ["в точку"],
    "в ящик глядеть": ["глядеть в ящик", "стоять одной ногой в гробу", "дышать на ладан"],
    "в-": ["за-"],
    "ва-банк": ["по банку"],
    "ваал": ["баал", "бел", "бааль"],
    "вабальнинкас": ["вобольники"],
    "вабив": ["вабивши"],
    "вабивши": ["вабив"],
    "вабить": ["сманивать", "переманивать", "обольщать"],
    "вабний": ["вабливий"],
    "вавакнув": ["вавакнувши"],
    "вавакнувши": ["вавакнув"],
    "вавилонец": ["вавилонянин"],
    "вавилонская блудница": ["дщерь вавилонская", "проститутка"],
    "вавилонянин": ["вавилонец"],
    "вавка": ["ранка"],
    "вага аньцек": ["аньцек вага", "аньцек тяни"],
    "вагабонтин": ["негодяй", "нехранимайко", "негодник", "калпазанин", "скитник", "бездомник", "бродник"],
    "вагальный": ["вазовагальный"],
    "ваган": ["важанин"],
    "ваганный": ["важенный"],
    "вагановка": ["вагановский", "училище"],
    "вагаршак": ["вагарш"],
    "вагина": ["большая вагина"],
    "вагинизм": ["кольпоспазм", "вульвизм"],
    "вагинит": ["кольпит"],
    "вагиноплатье": ["вагино-платье"],
    "вагон-салон": ["салон-вагон"],
    "вагон-самосвал": ["думпкар"],
    "вагон-хоппер": ["окатышевоз"],
    "вагонка": ["шалёвка", "сайдинг"],
    "ваготония": ["парасимпатикотония"],
    "вад": ["вадит"],
    "вада": ["всемирное антидопинговое агентство"],
    "ваджрасана": ["поза алмаза"],
    "вадинец": ["керенец"],
    "вадить": ["водить"],
    "вадкий": ["вадливий"],
    "вадря": ["паро"],
    "вадуц": ["фардуцес"],
    "важенка": ["олениха"],
    "важенный": ["ваганный"],
    "важивав": ["важивавши"],
    "важивавши": ["важивав"],
    "важливий": ["важний"],
    "важная птица": ["шишка"],
    "важнейший": ["наиважнейший"],
    "важний": ["важливий"],
    "важничав": ["важничавши"],
    "важничавши": ["важничав"],
    "важничанье": ["важничание"],
    "важничать": ["высокомерничать", "зазнаваться"],
    "важно": ["напыщенно", "спесиво", "горделиво"],
    "важность": ["значимость", "значение", "значительность", "напыщенность", "величавость"],
    "важный": ["значительный", "значимый", "горделивый", "величавый", "внушительный", "напыщенный", "высокопоставленный", "высокий", "существенный"],
    "ваз": ["жига", "жигули", "жигуль", "лада"],
    "вазифа": ["бурыс"],
    "вазицин": ["пеганин"],
    "вазна": ["ваза"],
    "вазодилататорный": ["сосудорасширяющий", "вазодилаторный"],
    "вазоконстрикторный": ["сосудосуживающий"],
    "вазомотор": ["вазодилататор", "вазоконстриктор"],
    "вазопатия": ["ангиопатия"],
    "вазопрессин": ["аргипрессин"],
    "вазотомия": ["ангиостомия"],
    "вазэктомия": ["мужская стерилизация"],
    "вайб": ["настрой"],
    "вайбер": ["вибер"],
    "вайбхашика": ["сарвастивада"],
    "вайме кожфонь нолдама": ["ваймонь таргама", "тевлавста кожфонь панема"],
    "ваймонь таргама": ["вайме кожфонь нолдама", "тевлавста кожфонь панема"],
    "ваймоса-мяльса": ["ладязь"],
    "вайнах": ["чеченец", "ингуш", "бацбиец"],
    "вайндер": ["автовайндер"],
    "вайп": ["вайпинг"],
    "вайпер": ["вейпер"],
    "вайфай": ["вафля"],
    "вайфу": ["вайфа"],
    "вайшнавизм": ["вишнуизм"],
    "вайю": ["гуахиро"],
    "вакансия": ["каникулы", "вакация"],
    "вакантный": ["свободный", "незанятый", "вакационный", "каникулярный"],
    "вакационный": ["вакантный"],
    "вакация": ["каникулы", "отпуск"],
    "вакрасана": ["поза улитки"],
    "вакса": ["гуталин", "фабра"],
    "ваксация": ["воксация", "ваксинг"],
    "ваксив": ["ваксивши"],
    "ваксивши": ["ваксив"],
    "ваксинг": ["ваксация", "восковой", "эпиляция", "вакс"],
    "вакска": ["малава"],
    "ваксс": ["малас"],
    "ваксса": ["маласа"],
    "ваксста": ["ширде", "бокста"],
    "вакуоль": ["вакуоля"],
    "вакуоля": ["вакуоль"],
    "вакутейнер": ["вакутайнер"],
    "вакуум": ["пустота", "разрежение", "отсутствие", "нехватка", "недостаток", "дефицит"],
    "вакуум-манометр": ["вакуумметр"],
    "вакуум-плотный": ["вакуумно-плотный", "вакуумплотный"],
    "вакуум-формовочный": ["вакуумно-формовочный", "вакуумформовочный"],
    "вакуумировав": ["вакуумировавши"],
    "вакуумировавши": ["вакуумировав"],
    "вакуумплотный": ["вакуум-плотный"],
    "вакуумформовочный": ["вакуум-формовочный", "вакуумно-формовочный"],
    "вакуф": ["вакф"],
    "вакх": ["бахус", "дионис"],
    "вакхальный": ["вакхический"],
    "вакханалия": ["оргия", "разгул", "буйство"],
    "вакханка": ["менада", "бассарида", "фиада", "мималлона", "сладострастница"],
    "вакхический": ["вакхальный", "вакханальный"],
    "вакцина": ["прививка", "антиген"],
    "вакцинация": ["вакцинирование", "прививка"],
    "вакцинировав": ["вакцинировавши"],
    "вакцинировавши": ["вакцинировав"],
    "вакцинирование": ["вакцинация"],
    "вакцинировать": ["прививать", "делать прививку"],
    "вакцинодиссидент": ["антиваксер", "антивакцинатор", "антивакцинщик", "антипрививочник", "вакциноскептик", "вакцинофоб"],
    "вакциноскептик": ["антиваксер", "антивакцинатор", "антивакцинщик", "антипрививочник", "вакцинодиссидент", "вакцинофоб"],
    "вакцинофоб": ["антиваксер", "антивакцинатор", "антивакцинщик", "антипрививочник", "вакцинодиссидент", "вакциноскептик"],
    "валавница": ["валалница"],
    "валалница": ["валавница"],
    "валамон": ["вельмен"],
    "валандав": ["валандавши"],
    "валандавши": ["валандав"],
    "валандаться": ["канителиться", "мешкать"],
    "валах": ["влах", "волох"],
    "валдайчанин": ["валдаец"],
    "валдхорна": ["валдхорн"],
    "валежник": ["валеж"],
    "валенок": ["чёсанец", "валенец", "катанок", "пимок", "катаник", "пима", "пим", "валенуха", "валена", "валежек"],
    "валенсианец": ["валенсиец"],
    "валенсиец": ["валенсианец"],
    "валентина": ["валя", "тина", "валюша", "валечка", "валентиночка", "валюшечка", "валюшка", "валька", "валёк", "валюха"],
    "валентинов день": ["день святого валентина", "день влюблённых"],
    "валеный": ["валяный", "войлочный"],
    "валериана": ["валерьяна"],
    "валерий": ["валера", "лерыч"],
    "валерия": ["лера", "лерочка", "лерка", "лерыч"],
    "валерьевич": ["валериевич", "валерьич"],
    "валерьевна": ["валериевна"],
    "валерьяна": ["валериана", "валерьянка"],
    "валерьянка": ["валерьяна", "валериана"],
    "валерьянович": ["валериянович", "валерьяныч"],
    "валерьяновна": ["валериановна"],
    "валив": ["валивши"],
    "валивав": ["валивавши"],
    "валивавши": ["валивав"],
    "валивши": ["валив"],
    "валидировав": ["валидировавши"],
    "валидировавши": ["валидировав"],
    "валидный": ["достоверный", "допустимый", "приемлемый", "правильный", "действительный"],
    "валить": ["заваливать", "убивать", "сваливать", "переваливать", "перекладывать", "отклонять", "сносить"],
    "валиться": ["заваливаться", "дохнуть"],
    "валиться в ноги": ["бухнуться в ноги"],
    "валкость": ["качкость", "шаткость", "неустойчивость", "зыбкость"],
    "валлиец": ["уэльсец", "кимр"],
    "валлийский": ["уэльский"],
    "валлийский язык": ["уэльский язык", "кимрский язык"],
    "валлорис": ["валорис"],
    "валовой": ["валовый", "общий", "совокупный", "повсеместный", "массовый", "сплошной"],
    "валовой внутренний продукт": ["ввп"],
    "валовый": ["валовой", "совокупный", "повсеместный", "массовый"],
    "валовый внутренний продукт": ["ввп"],
    "валовый доход": ["валовой доход"],
    "валоризация": ["ревальвация"],
    "валтасар": ["вальтасар"],
    "валторна": ["валторнист"],
    "валтузив": ["валтузивши"],
    "валтузивши": ["валтузив"],
    "валтузить": ["избивать", "мутузить"],
    "валтузиться": ["валдохаться"],
    "валун": ["глыба", "булыжник", "булыга"],
    "вальденс": ["леонист", "альбигоец", "гумилиат"],
    "вальдшнеп": ["лесной кулик", "слука"],
    "вальмя": ["валом"],
    "вальнуть": ["завалить", "повалить", "свалить", "обвалить", "обрушить", "уронить", "навалить", "наложить"],
    "вальсировав": ["вальсировавши"],
    "вальсировавши": ["вальсировав"],
    "вальтов гонять": ["стегать", "подстёгивать", "свистеть", "гонять вальтов", "с ума сходить"],
    "вальтрап": ["потник"],
    "вальхалла": ["валгалла"],
    "вальцевав": ["вальцевавши"],
    "вальцевавши": ["вальцевав"],
    "вальцевание": ["вальцовка"],
    "вальцевой": ["вальцовый"],
    "вальцовав": ["вальцовавши"],
    "вальцовавши": ["вальцовав"],
    "вальцовать": ["вальцевать"],
    "вальцовка": ["вальцевание"],
    "вальцювання": ["прокатування"],
    "вальяжный": ["массивный", "прочный", "литой", "чинный", "ленивый", "неторопливый", "раскрепощённый"],
    "валюта": ["денежная единица", "инвалюта"],
    "валютировав": ["валютировавши"],
    "валютировавши": ["валютировав"],
    "валютка": ["валюта", "пункт обмена валюты", "валютообменный", "пункт", "валютник", "обменник"],
    "валютная проститутка": ["интердевочка", "интерпроститутка", "валютница"],
    "валютник": ["пункт обмена валюты", "валютообменный", "пункт", "валютка", "обменник"],
    "валютница": ["интердевочка"],
    "валютно-обменный": ["валютообменный"],
    "валютный": ["денежный"],
    "валютный курс": ["обменный курс"],
    "валютодобывающий": ["валютоёмкий", "валютоносный"],
    "валютоносность": ["валютоёмкость"],
    "валютоносный": ["валютодобывающий", "валютоёмкий"],
    "валютообменный": ["валютно-обменный"],
    "валютоёмкий": ["валютодобывающий", "валютоносный"],
    "валютоёмкость": ["валютоносность"],
    "валяв": ["валявши"],
    "валявши": ["валяв"],
    "валяка": ["ледар"],
    "валяние": ["валка"],
    "валять": ["катать", "раскатывать", "обваливать", "вываливать", "сбивать", "выделывать", "выделываться", "изображать", "играть", "действуй", "давай", "жги", "идти", "уходить", "ехать"],
    "валять дурака": ["дурака валять", "дурачиться", "паясничать", "прикалываться", "плошать", "глупить", "дурить"],
    "вамп": ["женщина-вамп", "леди-вамп", "роковая женщина"],
    "вампир": ["упырь", "вурдалак", "кровопийца", "кровосос", "десмод"],
    "вампиресса": ["вампириха", "вампирка", "вампирша"],
    "вампирив": ["вампиривши"],
    "вампиривши": ["вампирив"],
    "вампириха": ["вампиресса", "вампирка", "вампирша"],
    "вампирка": ["вампиресса", "вампириха", "вампирша"],
    "вампирский": ["вурдалакский"],
    "вампирствовав": ["вампирствовавши"],
    "вампирствовавши": ["вампирствовав"],
    "вампирша": ["вампиресса", "вампириха", "вампирка"],
    "вампука": ["банальность", "пошлость", "кич", "халтура", "пародия"],
    "ван": ["царь", "князь"],
    "ванадзор": ["караклис", "кировакан"],
    "ванаквисль": ["танаквисль", "дон"],
    "ванговав": ["ванговавши"],
    "ванговавши": ["ванговав"],
    "ванговать": ["нагадывать", "предсказывать", "пророчить", "предполагать"],
    "ванда": ["ивана"],
    "вандал": ["варвар", "дикарь", "разрушитель"],
    "вандалив": ["вандаливши"],
    "вандаливши": ["вандалив"],
    "вандализировав": ["вандализировавши"],
    "вандализировавши": ["вандализировав"],
    "вандализовать": ["вандализировать"],
    "вандалостойкий": ["вандалоустойчивый"],
    "вандалоустойчивость": ["вандалоустойчивый"],
    "вандалоустойчивый": ["вандалостойкий"],
    "вандименец": ["тасманиец"],
    "ванечка": ["ванюша"],
    "ваниль": ["ваниль плосколистная"],
    "ванино": ["тишкино"],
    "ванна": ["купальня"],
    "ваномс": ["няемс", "вятемс", "ванфтомс", "варжамс"],
    "вант": ["ванф"],
    "вантуз": ["воздухоотводчик", "присоска", "прочищалка", "квачок"],
    "вануату": ["республика вануату"],
    "ванф": ["сельмованф", "сельмованфкс", "варжафкс", "сельмоваржафкс"],
    "ваншотив": ["ваншотивши"],
    "ваншотивши": ["ваншотив"],
    "ваншотнув": ["ваншотнувши"],
    "ваншотнувши": ["ваншотнув"],
    "ванька": ["извозчик"],
    "ванька-встанька": ["неваляшка", "неваляйка"],
    "ванька-каин": ["ванька каин"],
    "вао": ["восточный административный округ"],
    "вапозон": ["вапоризатор"],
    "вапоризатор": ["испаритель"],
    "варайский": ["варайский язык"],
    "варакав": ["варакавши"],
    "варакавши": ["варакав"],
    "варакать": ["вараксать"],
    "варвар": ["бербер", "дикарь", "вандал"],
    "варваризм": ["ксенизм"],
    "варваризовав": ["варваризовавши"],
    "варваризовавши": ["варваризовав"],
    "варварски": ["дикарски"],
    "варварский": ["грубый", "жестокий", "дикий"],
    "варварство": ["дикость"],
    "варга": ["рот", "горло", "глотка", "пасть", "прогалина"],
    "варганив": ["варганивши"],
    "варганивши": ["варганив"],
    "варганить": ["стряпать"],
    "вардар": ["вардарий", "аксий", "аксьос"],
    "варега": ["варежка", "рукавица"],
    "варежка": ["рукавица", "рукавичка", "варега", "варьга", "вязенка", "деница"],
    "варенец": ["ряженка"],
    "вареник": ["галушка", "аметист"],
    "варенье": ["джем", "конфитюр", "повидло", "варение", "варка"],
    "варжафкс": ["сельмоваржафкс", "ванф", "сельмованф", "сельмованфкс"],
    "вариабельность": ["изменчивость"],
    "вариабельный": ["изменчивый", "непостоянный", "неустойчивый"],
    "вариант": ["вариация", "видоизменение", "модификация", "разновидность", "разночтение", "версия"],
    "вариативность": ["неоднородность", "изменчивость", "разнообразие"],
    "вариативный": ["изменчивый", "различный"],
    "варив": ["варивши"],
    "варивав": ["варивавши"],
    "варивавши": ["варивав"],
    "вариватт": ["варивольт"],
    "варивольт": ["вариватт"],
    "варивши": ["варив"],
    "вариегатный": ["пестролистнный"],
    "вариировав": ["вариировавши"],
    "вариировавши": ["вариировав"],
    "вариироваться": ["варьироваться"],
    "варик": ["вариант", "варикоз"],
    "вариклечко": ["скъперник", "циция", "скръндза", "стипца"],
    "варикоз": ["варикозное расширение вен"],
    "вариообъектив": ["трансфокатор", "зум-объектив"],
    "варисцийский": ["варисский"],
    "варить": ["кипятить", "сваривать"],
    "вариться": ["жариться", "печься"],
    "вария": ["тяжкая", "тяжёлое ударение", "аксанграв", "тупое ударение", "гравис"],
    "варка": ["кипячение", "варение", "вываривание"],
    "варминтинг": ["вармитинг"],
    "вармитинг": ["варминтинг"],
    "варн": ["варнов"],
    "варна": ["сталин"],
    "варналия": ["варненец"],
    "варнацкий": ["варначий"],
    "варначий": ["варнацкий"],
    "варначка": ["каторжница", "каторжанка"],
    "варница": ["солеварня"],
    "варок": ["загон"],
    "варрант": ["доверенность"],
    "варсонофия": ["варсанофия"],
    "варто": ["треба"],
    "варух": ["барух", "берехия"],
    "варфоломеевская ночь": ["резня святого варфоломея"],
    "варшавец": ["варшавянин", "варшавяк"],
    "варшавянин": ["варшавец", "варшавяк"],
    "варьете": ["кабаре"],
    "варьировав": ["варьировавши"],
    "варьировавши": ["варьировав"],
    "варьировать": ["видоизменять", "модифицировать", "видоизменяться", "меняться", "варьироваться"],
    "варьируемость": ["варьирование", "изменчивость"],
    "варьяция": ["вариант", "вариация", "модификация"],
    "варюха": ["любовница"],
    "варя": ["варенька", "варечка"],
    "варяг": ["викинг", "норманн", "нурманн", "легионер", "афеня"],
    "варяжский": ["викингский", "норманнский"],
    "варяжское море": ["балтийское море"],
    "варёная вода": ["кипяток"],
    "васа": ["вакуль"],
    "васаби": ["японский хрен"],
    "васах": ["рим"],
    "василевс": ["басилевс", "басилей", "базей", "базилевс"],
    "василианин": ["базилианин"],
    "василиса": ["василисса"],
    "василь": ["василий", "вася"],
    "васильевич": ["василич", "васильич"],
    "васильевский остров": ["васька"],
    "васильковый": ["ярко-синий", "синий", "небесный", "лазурный"],
    "васильчанин": ["васильсурец"],
    "васкулит": ["ангиит", "артериит"],
    "васкулярный": ["сосудистый"],
    "вась-вась": ["на короткой ноге"],
    "вася пупкин": ["имярек", "пушкин", "джон доу", "пупкин"],
    "васятка": ["васенька"],
    "ватага": ["гурьба", "шайка", "толпа", "артель", "бригада", "кооператив", "товарищество"],
    "ватажок": ["вожак", "атаман", "утаман"],
    "ватвот": ["хаффош"],
    "ватер": ["ватерклозет"],
    "ватер-клозет": ["ватерклозет"],
    "ватерклозет": ["туалет", "ватер-клозет"],
    "ватерпас": ["уровень"],
    "ватерполо": ["водное поло", "водный гандбол"],
    "ватерпруф": ["плащ"],
    "ватикан": ["святой престол", "государство-город ватикан"],
    "ватка": ["ваточка"],
    "ватман": ["ватманская бумага"],
    "ватнайёкюдль": ["ватнайёкудль", "ватна-йокуль", "ватна-йёкудль"],
    "ватная палочка": ["тупфер"],
    "ватник": ["телогрейка"],
    "ватный": ["ваточный"],
    "ватокат": ["бездельник"],
    "ваточный": ["ватный"],
    "ватра": ["багаття", "ватрище", "вогнище"],
    "ватрушка": ["бублик", "тюбинг", "плюшка"],
    "ватсап": ["васап", "ватсапп", "ватцап", "вацап", "вотсап", "уатсап"],
    "ватт": ["вольт-ампер", "вт"],
    "ватт-секунда": ["джоуль"],
    "ватты": ["осушка"],
    "ватутинки": ["новые ватутинки"],
    "вау": ["гав", "ав", "тяф"],
    "ваучеризировав": ["ваучеризировавши"],
    "ваучеризировавши": ["ваучеризировав"],
    "ваучерист": ["ваучерник"],
    "ваучерник": ["ваучерист"],
    "ваучеровладелец": ["ваучеродержатель"],
    "ваучеродержатель": ["ваучеровладелец"],
    "вафельщик": ["вафельник"],
    "вафлив": ["вафливши"],
    "вафливши": ["вафлив"],
    "вафлить": ["медлить", "мешкать", "тормозить", "бездельничать", "страдать фигнёй", "дурью маяться", "пачкать", "портить", "марать", "давать за щеку"],
    "вафлю жевать": ["спать", "тормозить"],
    "вафлёр": ["петух", "козёл"],
    "вафлёрка": ["минетчица", "соска", "вафлистка", "вафлёрша"],
    "вафлёрша": ["минетчица", "соска", "вафлистка", "вафлёрка"],
    "вафот": ["марг", "фавт"],
    "вахлак": ["мужлан", "дубина", "глупец"],
    "вахмистрский": ["вахмистерский"],
    "вахта": ["трифоль"],
    "вахтово-экспедиционный": ["экспедиционно-вахтовый"],
    "ваххабизм": ["салафизм"],
    "ваххабист": ["ваххабит"],
    "ваххабит": ["салафит"],
    "ваш": ["твой"],
    "ваше здоровье": ["за вас"],
    "ваше императорское величество": ["ваше величество"],
    "вашество": ["ваш", "превосходительство"],
    "вашингтон": ["белый дом"],
    "вашингтонский": ["вашингтоновский"],
    "вашингтонский обком": ["дядя сэм"],
    "вашо": ["парнэ"],
    "ваяв": ["ваявши"],
    "ваявши": ["ваяв"],
    "ваяние": ["скульптура", "изваяние"],
    "ваянье": ["ваяние"],
    "ваятель": ["скульптор"],
    "ваятельница": ["скульпторша"],
    "ваять": ["лепить", "делать", "изготовлять", "созидать", "создавать", "творить"],
    "вбегав": ["вбегавши"],
    "вбегавши": ["вбегав"],
    "вбегать": ["забегать"],
    "вбежав": ["вбежавши"],
    "вбежавши": ["вбежав"],
    "вбежать": ["забежать"],
    "вбеле": ["набело"],
    "вбив": ["вбивши"],
    "вбивав": ["вбивавши"],
    "вбивавши": ["вбивав"],
    "вбивши": ["вбив"],
    "вбирав": ["вбиравши"],
    "вбиравши": ["вбирав"],
    "вбирать": ["поглощать", "втягивать"],
    "вбирач": ["абсорбер"],
    "вбить": ["забить", "набрать"],
    "вблизи": ["близко", "неподалёку", "поблизости", "недалеко", "невдалеке"],
    "вбрасывав": ["вбрасывавши"],
    "вбрасывавши": ["вбрасывав"],
    "вбрасывание": ["ввержение", "взбрасывание"],
    "вбрасывать": ["вкидывать", "закидывать", "забрасывать", "зашвыривать"],
    "вброд": ["пешком"],
    "вброс": ["вбрасывание", "забрасывание"],
    "вбросав": ["вбросавши"],
    "вбросавши": ["вбросав"],
    "вбросив": ["вбросивши"],
    "вбросивши": ["вбросив"],
    "вбрызгивав": ["вбрызгивавши"],
    "вбрызгивавши": ["вбрызгивав"],
    "вбрызнув": ["вбрызнувши"],
    "вбрызнувши": ["вбрызнув"],
    "вбухав": ["вбухавши"],
    "вбухавши": ["вбухав"],
    "вбухивав": ["вбухивавши"],
    "вбухивавши": ["вбухивав"],
    "вбухнув": ["вбухнувши"],
    "вбухнувши": ["вбухнув"],
    "вбухнуться": ["вбухаться", "ввалиться"],
    "ввалив": ["вваливши"],
    "вваливав": ["вваливавши"],
    "вваливавши": ["вваливав"],
    "вваливши": ["ввалив"],
    "вварив": ["вваривши"],
    "вваривав": ["вваривавши"],
    "вваривавши": ["вваривав"],
    "вваривши": ["вварив"],
    "введение": ["введенье", "вступление"],
    "введенье": ["введение"],
    "введённый": ["установленный", "вставной", "заданный", "инкорпорированный", "внесённый", "налитый", "подключённый", "открытый", "сконструированный", "построенный", "сделанный", "постановленный", "предписанный", "утверждённый", "принятый"],
    "ввезя": ["ввёзши"],
    "ввек": ["вовек", "никогда"],
    "ввергав": ["ввергавши"],
    "ввергавши": ["ввергав"],
    "ввергать": ["водворять", "вовлекать", "приводить"],
    "ввергаться": ["вторгаться"],
    "ввергнув": ["ввергнувши"],
    "ввергнувши": ["ввергнув"],
    "ввергнуть": ["поместить", "бросить", "погрузить", "повергнуть", "вовлечь", "поверчь", "вверчь", "привести", "вогнать"],
    "ввергнуться": ["вторгнуться"],
    "вверение": ["предоставление", "передача", "доверение"],
    "ввержение": ["ввергание"],
    "вверзив": ["вверзивши"],
    "вверзивши": ["вверзив"],
    "вверзиться": ["упасть", "ввалиться", "вляпаться"],
    "вверив": ["вверивши"],
    "вверивши": ["вверив"],
    "вверить": ["доверить", "поручить", "поверить"],
    "ввернув": ["ввернувши"],
    "ввернувши": ["ввернув"],
    "ввернуться": ["ввинтиться", "вкрутиться"],
    "вверстав": ["вверставши"],
    "вверставши": ["вверстав"],
    "ввертев": ["ввертевши"],
    "ввертевши": ["ввертев"],
    "вверх": ["ввысь", "наверх"],
    "вверх дном": ["кверху дном", "вверх тормашками", "шиворот на выворот", "поставить с ног на голову"],
    "вверх тормашками": ["вверх ногами", "с ног на голову", "кувырком", "головой вниз", "кубарем", "турманом", "шиворот-навыворот"],
    "вверху": ["наверху", "сверху"],
    "вверчивав": ["вверчивавши"],
    "вверчивавши": ["вверчивав"],
    "вверяв": ["вверявши"],
    "вверявши": ["вверяв"],
    "вверять": ["доверять", "поверять"],
    "ввести": ["разместить", "включить", "внедрить"],
    "ввести в заблуждение": ["обмануть"],
    "ввечеру": ["вечером"],
    "ввж": ["жирик"],
    "ввив": ["ввивши"],
    "ввивав": ["ввивавши"],
    "ввивавши": ["ввивав"],
    "ввивши": ["ввив"],
    "ввиду": ["из-за", "из", "от", "по", "за", "благодаря", "по причине", "вследствие", "в результате", "в силу", "с учётом"],
    "ввинтив": ["ввинтивши"],
    "ввинтивши": ["ввинтив"],
    "ввинчивав": ["ввинчивавши"],
    "ввинчивавши": ["ввинчивав"],
    "ввинчивание": ["вворачивание", "вкручивание"],
    "ввод": ["введение"],
    "вводив": ["вводивши"],
    "вводивши": ["вводив"],
    "вводить в заблуждение": ["обманывать"],
    "вводная конструкция": ["вводное слово", "вводное сочетание", "вводное словосочетание"],
    "вводное слово": ["вводная конструкция", "вводное сочетание", "вводное словосочетание"],
    "вводный": ["вступительный", "начальный"],
    "ввоз": ["завоз"],
    "ввозив": ["ввозивши"],
    "ввозивши": ["ввозив"],
    "ввозить": ["привозить", "импортировать"],
    "ввозка": ["ввоз"],
    "ввозный": ["ввозной"],
    "ввозозамещение": ["импортозамещение"],
    "вволакивав": ["вволакивавши"],
    "вволакивавши": ["вволакивав"],
    "вволочив": ["вволочивши"],
    "вволочивши": ["вволочив"],
    "вволочить": ["вволочь"],
    "вволю": ["вдоволь", "вдосталь", "от души", "вволюшку"],
    "вволяти": ["уволяти"],
    "вворачивав": ["вворачивавши"],
    "вворачивавши": ["вворачивав"],
    "вворачивание": ["вкручивание", "ввёртывание"],
    "вворачивать": ["ввёртывать", "ввинчивать", "вкручивать"],
    "вворотив": ["вворотивши"],
    "вворотивши": ["вворотив"],
    "вворотить": ["ввернуть", "вкрутить", "ввинтить"],
    "ввязав": ["ввязавши"],
    "ввязавши": ["ввязав"],
    "ввязнув": ["ввязнувши"],
    "ввязнувши": ["ввязнув"],
    "ввязывав": ["ввязывавши"],
    "ввязывавши": ["ввязывав"],
    "ввёзши": ["ввезя"],
    "ввёрстывав": ["ввёрстывавши"],
    "ввёрстывавши": ["ввёрстывав"],
    "ввёртывав": ["ввёртывавши"],
    "ввёртывавши": ["ввёртывав"],
    "ввёртывать": ["ввинчивать", "вворачивать", "вкручивать"],
    "ввёртываться": ["вворачиваться", "ввинчиваться", "вкручиваться"],
    "вгасання": ["угасання"],
    "вгасити": ["угасити"],
    "вгибав": ["вгибавши"],
    "вгибавши": ["вгибав"],
    "вгибание": ["вгибанье"],
    "вглубь": ["внутрь", "вниз"],
    "вглухую": ["наглухо"],
    "вглядеться": ["всмотреться", "присмотреться"],
    "вглядчиво": ["пристально", "внимательно"],
    "вглядывание": ["вглядыванье"],
    "вглядыванье": ["вглядывание"],
    "вглядываться": ["всматриваться"],
    "вгонка": ["вгон"],
    "вгоняв": ["вгонявши"],
    "вгонявши": ["вгоняв"],
    "вгорячах": ["сгоряча"],
    "вгрызав": ["вгрызавши"],
    "вгрызавши": ["вгрызав"],
    "вгустую": ["густо"],
    "вгую": ["рпа"],
    "вдавав": ["вдававши"],
    "вдававши": ["вдавав"],
    "вдавив": ["вдавивши"],
    "вдавивши": ["вдавив"],
    "вдавленность": ["вогнутость", "вдавлина", "вмятина"],
    "вдавливав": ["вдавливавши"],
    "вдавливавши": ["вдавливав"],
    "вдавлина": ["вмятина"],
    "вдалбливав": ["вдалбливавши"],
    "вдалбливавши": ["вдалбливав"],
    "вдалбливать": ["вбивать", "вколачивать"],
    "вдалеке": ["далеко", "вдали"],
    "вдали": ["в отдалении", "вдалеке", "далеко", "поодаль"],
    "вдаль": ["далеко"],
    "вдарив": ["вдаривши"],
    "вдаривши": ["вдарив"],
    "вдарити": ["ударити"],
    "вдарить": ["ударить", "вмазать"],
    "вдаться": ["войти", "вглубь", "вдавиться", "углубиться", "предаться"],
    "вдв": ["десант", "крылатая гвардия"],
    "вдвигав": ["вдвигавши"],
    "вдвигавши": ["вдвигав"],
    "вдвинув": ["вдвинувши"],
    "вдвинувши": ["вдвинув"],
    "вдвинуть": ["задвинуть", "впихнуть", "всунуть", "вставить", "вместить", "поместить"],
    "вдвое": ["вдвойне", "в два раза", "напополам", "пополам"],
    "вдвойне": ["вдвое", "дважды"],
    "вдвоём": ["наедине"],
    "вдев": ["вдевши"],
    "вдевав": ["вдевавши"],
    "вдевавши": ["вдевав"],
    "вдевание": ["вдеванье"],
    "вдевать": ["продевать"],
    "вдевши": ["вдев"],
    "вделав": ["вделавши"],
    "вделавши": ["вделав"],
    "вделать в фасад": ["заехать в табло"],
    "вделывав": ["вделывавши"],
    "вделывавши": ["вделывав"],
    "вднх": ["ввц"],
    "вдобавок": ["кроме того", "к тому же", "сверх того", "помимо этого", "в дополнение", "в придачу"],
    "вдова": ["вдовушка", "вдовуха", "вдовица", "вдовка"],
    "вдовев": ["вдовевши"],
    "вдовевши": ["вдовев"],
    "вдовица": ["вдова", "вдовушка", "вдовуха", "вдовка"],
    "вдовка": ["вдова", "вдовушка", "вдовуха", "вдовица"],
    "вдоволь": ["вволю", "вдосталь", "достаточно"],
    "вдовство": ["вдовствование"],
    "вдовствовав": ["вдовствовавши"],
    "вдовствовавши": ["вдовствовав"],
    "вдовствование": ["вдовство"],
    "вдовствовать": ["вдоветь"],
    "вдовуха": ["вдова", "вдовушка", "вдовица", "вдовка"],
    "вдовушка": ["вдова", "вдовуха", "вдовица", "вдовка"],
    "вдогон": ["вдогонку", "следом", "вслед", "вослед", "после"],
    "вдолбив": ["вдолбивши"],
    "вдолбивши": ["вдолбив"],
    "вдоль": ["по длине", "продольно"],
    "вдоль и поперёк": ["повсюду", "везде", "как свои пять пальцев"],
    "вдоль по": ["по"],
    "вдосталь": ["вволю", "вдоволь", "досыта", "до отвала"],
    "вдосыть": ["вдоволь", "досыта"],
    "вдох": ["вдыхание", "инспирация"],
    "вдохновение": ["озарение", "воодушевление", "энтузиазм"],
    "вдохновенный": ["воодушевлённый", "окрылённый", "увлечённый", "исполненный", "вдохновение", "одушевлённый"],
    "вдохновенье": ["вдохновение"],
    "вдохновив": ["вдохновивши"],
    "вдохновивши": ["вдохновив"],
    "вдохновитель": ["инициатор", "зачинщик"],
    "вдохновляв": ["вдохновлявши"],
    "вдохновлявши": ["вдохновляв"],
    "вдохновлять": ["окрылять", "воодушевлять"],
    "вдохновлённый": ["воодушевлённый"],
    "вдохнув": ["вдохнувши"],
    "вдохнувши": ["вдохнув"],
    "вдрабадан": ["вдрабаданище", "вдугаря"],
    "вдребезги": ["вдрызг", "совершенно", "окончательно", "полностью"],
    "вдруг": ["неожиданно", "внезапно", "непредсказуемо", "без предупреждения", "сразу", "разом", "зараз", "за один приём", "наконом", "если", "а если", "может статься", "не дай бог"],
    "вдругорядь": ["опять", "снова", "вдругоредь", "вторично", "повторно"],
    "вдрызг": ["вдребезги", "окончательно", "полностью", "совершенно"],
    "вдув": ["вдувши"],
    "вдував": ["вдувавши"],
    "вдувавши": ["вдував"],
    "вдувши": ["вдув"],
    "вдумчивость": ["глубокомысленность"],
    "вдумчивый": ["рассудительный"],
    "вдунув": ["вдунувши"],
    "вдунувши": ["вдунув"],
    "вдупляв": ["вдуплявши"],
    "вдуплявши": ["вдупляв"],
    "вдуплять": ["отдуплять", "врубаться", "въезжать", "допирать", "втыкать", "вкуривать"],
    "вдуть": ["вдунуть", "продать", "впарить", "всучить", "навялить"],
    "вдуть в очко": ["вдуть в жопу"],
    "вдыхав": ["вдыхавши"],
    "вдыхавши": ["вдыхав"],
    "вдыханье": ["вдыхание"],
    "вдыхательный": ["инспираторный"],
    "вдёргивав": ["вдёргивавши"],
    "вдёргивавши": ["вдёргивав"],
    "вдёрнув": ["вдёрнувши"],
    "вдёрнувши": ["вдёрнув"],
    "вдёрнутый": ["вдетый", "продёрнутый"],
    "вдёрнуть": ["вдеть"],
    "веб": ["всемирная паутина"],
    "веб-адрес": ["интернет-адрес"],
    "веб-версия": ["интернет-версия", "онлайн-версия"],
    "веб-дизайнер": ["интернет-дизайнер"],
    "веб-издание": ["интернет-издание", "онлайн-издание"],
    "веб-интерфейс": ["интернет-интерфейс"],
    "веб-камера": ["интернет-камера"],
    "веб-комикс": ["интернет-комикс"],
    "веб-конференция": ["интернет-конференция", "онлайн-конференция"],
    "веб-мастер": ["веб-разработчик"],
    "веб-обозреватель": ["браузер", "веб-браузер", "навигатор"],
    "веб-портал": ["портал", "интернет-портал"],
    "веб-проект": ["интернет-проект", "онлайн-проект"],
    "веб-пространство": ["интернет-пространство"],
    "веб-ресурс": ["интернет-ресурс", "онлайн-ресурс"],
    "веб-рынок": ["интернет-рынок"],
    "веб-сайт": ["сайт"],
    "веб-сервер": ["интернет-сервер"],
    "веб-сервис": ["веб-служба", "онлайн-служба"],
    "веб-система": ["интернет-система", "онлайн-система"],
    "веб-служба": ["онлайн-служба", "веб-сервис"],
    "веб-страница": ["страница", "интернет-страница"],
    "веб-страничка": ["интернет-страничка"],
    "веб-студия": ["интернет-студия"],
    "веб-технологии": ["интернет-технологии"],
    "веб-трафик": ["интернет-трафик"],
    "веб-форум": ["интернет-форум", "форум"],
    "веб-хостинг": ["хостинг", "интернет-хостинг"],
    "вебанув": ["вебанувши"],
    "вебанувши": ["вебанув"],
    "веберметр": ["флюксметр"],
    "вебкам": ["вебкаминг", "вебкам-моделинг"],
    "вебкам-моделинг": ["вебкам", "вебкаминг"],
    "вебкаминг": ["вебкам", "вебкам-моделинг"],
    "веблог": ["блог", "интернет-дневник", "лытдыбр"],
    "вевеляй": ["фельдфебель"],
    "веверица": ["векша", "белка"],
    "вевис": ["евье"],
    "веганство": ["веганизм"],
    "вегас": ["лас-вегас"],
    "вегетарианец": ["травоядный", "добряк"],
    "вегетарианив": ["вегетарианивши"],
    "вегетарианивши": ["вегетарианив"],
    "вегетарианский": ["безобидный", "беззубый"],
    "вегетарианство": ["сыроедение"],
    "вегетарианствовав": ["вегетарианствовавши"],
    "вегетарианствовавши": ["вегетарианствовав"],
    "вегетативная нервная система": ["автономная нервная система", "ганглионарная нервная система", "органная нервная система", "висцеральная нервная система", "чревная нервная система", "внс"],
    "вегетативный": ["растительный", "сорный", "висцеральный"],
    "вегетировав": ["вегетировавши"],
    "вегетировавши": ["вегетировав"],
    "ведав": ["ведавши"],
    "ведавши": ["ведав"],
    "ведаизм": ["ведизм"],
    "ведать": ["знать", "представлять", "понимать", "сознавать", "чувствовать"],
    "ведающий": ["знающий"],
    "ведение": ["управление", "ответственность"],
    "веджвуд": ["веджвудский фарфор"],
    "ведизм": ["ведаизм"],
    "ведмедиха": ["ведмедиця"],
    "ведомо": ["известно", "как известно", "знамо дело"],
    "ведомость": ["пресса", "периодика"],
    "ведомственный": ["местнический", "узковедомственный"],
    "ведомство": ["департамент", "компетенция"],
    "ведомство плаща и кинжала": ["цру", "ведомство рыцарей плаща и кинжала"],
    "ведомство рыцарей плаща и кинжала": ["цру", "ведомство плаща и кинжала"],
    "ведомый": ["известный", "знакомый"],
    "ведрев": ["ведревши"],
    "ведревши": ["ведрев"],
    "ведренев": ["ведреневши"],
    "ведреневши": ["ведренев"],
    "ведренеть": ["проясняться", "разгуливаться"],
    "ведренный": ["безоблачный", "солнечный", "ясный", "погожий"],
    "ведреть": ["проясняться", "разгуливаться"],
    "ведро": ["корзина", "мусорная корзина", "андроид", "ведроид", "корыто", "жестянка", "тарантас", "джабахан", "развалюха", "пепелац"],
    "ведун": ["ведьмак"],
    "ведунья": ["лихая баба"],
    "ведывав": ["ведывавши"],
    "ведывавши": ["ведывав"],
    "ведь": ["поскольку", "ибо", "потому что", "так как", "дык", "бо", "же"],
    "ведьма": ["колдунья"],
    "ведьмак": ["ведун", "колдун"],
    "ведьмачив": ["ведьмачивши"],
    "ведьмачивши": ["ведьмачив"],
    "ведьмин": ["ведьминский", "ведьмовский", "ведьмовской"],
    "ведьминский": ["ведьмовский", "ведьмовской", "ведьмин"],
    "ведьмовский": ["ведьминский", "ведьмовской", "ведьмин"],
    "ведёрко": ["вёдрышко", "ведёрце", "ведёрышко", "ведёрочко", "мигалка"],
    "веерно": ["веерообразно", "последовательно", "поочерёдно"],
    "веерный": ["вееровидный", "веерообразный", "последовательный"],
    "вееровидный": ["веерообразный"],
    "веером": ["полукругом", "пучком"],
    "веерообразный": ["веероподобный"],
    "вежда": ["веко", "глаз", "зрак"],
    "вежество": ["учёность", "образованность"],
    "вежливо": ["учтиво", "любезно", "галантно"],
    "вежливость": ["учтивость", "воспитанность", "обходительность", "корректность", "уважительность", "предупредительность", "любезность", "галантность", "политес"],
    "вежливые люди": ["зелёные человечки"],
    "вежливый": ["учтивый", "воспитанный", "тактичный", "светский"],
    "везде": ["всюду", "повсюду", "повсеместно"],
    "вездесущесть": ["вездесущность", "повсеместность"],
    "вездесущие": ["вездесущность"],
    "вездесущий": ["повсеместный"],
    "вездесущность": ["вездесущесть", "вездесущие"],
    "вездеход-тягач": ["трактор"],
    "везение": ["удача", "счастье", "фортуна", "шанс"],
    "везенье": ["удача"],
    "везикула": ["окаймлённый пузырёк"],
    "везикулит": ["везикулярит"],
    "везикулярит": ["сперматоцистит", "везикулит"],
    "везниковец": ["вязниковец"],
    "везти": ["транспортировать"],
    "везувиан": ["везувианит", "идокраз", "калифорнит"],
    "везун": ["везунок", "везунчик"],
    "везунок": ["везунчик", "счастливец"],
    "везунчик": ["везун", "везунок", "счастливчик", "счастливец", "счастливица"],
    "везучесть": ["удачливость", "везение"],
    "везучий": ["удачливый"],
    "вейвлет": ["всплеск", "вэйвлет", "волночка"],
    "вейдерсы": ["забродник", "забродный комбинезон", "забродный полукомбинезон"],
    "вейк": ["вейкборд", "вейкбординг"],
    "вейкборд": ["вейк"],
    "вейкбордер": ["вейкбордист"],
    "вейкбординг": ["вейкборд", "вейк"],
    "вейкбордист": ["вейкбордер"],
    "вейп": ["электронная сигарета"],
    "вейп-девайс": ["вейп-устройство"],
    "вейп-устройство": ["вейп-девайс"],
    "вейпер": ["вэйпер"],
    "вейпинг": ["вайпинг"],
    "вейпить": ["парить"],
    "вейсманизм": ["неодарвинизм"],
    "вейшнория": ["вайшнория", "вейснория", "вайснория"],
    "век": ["столетие", "сто лет", "жизнь", "период", "эра", "эпоха", "геологический век"],
    "век астреи": ["золотой век"],
    "вековав": ["вековавши"],
    "вековавши": ["вековав"],
    "вековечный": ["извечный", "исконный", "вечный"],
    "вековуха": ["вековуша", "вековушка"],
    "векселетримач": ["векселедержатель", "векселеутримувач"],
    "вектор": ["направление", "цель", "переносчик"],
    "вектор-кардиограмма": ["векторкардиограмма"],
    "вектор-кардиограф": ["векторкардиограф", "векторэлектрокардиограф"],
    "вектор-кардиоскоп": ["векторкардиоскоп", "векторэлектрокардиоскоп"],
    "вектор-сфигмограмма": ["векторсфигмограмма"],
    "вектор-электрокардиограмма": ["векторэлектрокардиограмма", "векторкардиограмма"],
    "вектор-электрокардиограф": ["векторэлектрокардиограф"],
    "векторизованный": ["векторизированный"],
    "векторизовать": ["векторизировать"],
    "векша": ["белка", "мысь", "веверица"],
    "веларий": ["велум"],
    "велаят": ["вилайет"],
    "велев": ["велевши"],
    "велевши": ["велев"],
    "велегезит": ["белегезит"],
    "велегласно": ["громко", "громогласно", "громоподобно", "гулко", "раскатисто", "громозвучно"],
    "велегласность": ["громогласность", "звучность"],
    "велегласный": ["громогласный", "громозвучный"],
    "велелепие": ["великолепие"],
    "велелепость": ["великолепие", "велелепие"],
    "велелепый": ["красивый", "великолепный", "велелепный"],
    "велемудрый": ["премудрый"],
    "веление": ["повеление", "веленье"],
    "веленика": ["ника"],
    "велень": ["веленевая бумага"],
    "веленье": ["веление"],
    "велеречиво": ["красноречиво", "высокопарно", "напыщенно", "выспренно", "фразисто"],
    "велеречивость": ["велеречие", "выспренность", "фразистость", "риторика", "риторичность", "высокопарность", "напыщенность", "фразёрство"],
    "велеречивый": ["витиеватый", "красноречивый", "речистый", "сладкоречивый", "сладкогласный", "высокопарный", "громкий", "напыщенный", "пышный", "трескучий", "риторический", "риторичный", "выспренний", "громкозвучный", "фразистый"],
    "велеречие": ["красноречивость", "красноречие", "речистость", "витийство", "краснословие", "элоквенция", "велеречивость", "выспренность", "фразистость", "риторика", "риторичность", "высокопарность", "напыщенность", "фразёрство"],
    "велеть": ["приказать", "распорядиться", "отдать команду", "скомандовать"],
    "велец": ["вельчанин", "вельчак"],
    "велиал": ["белиал", "белиар", "белияал", "велиар", "агриэль", "бериал"],
    "велив": ["веливши"],
    "веливши": ["велив"],
    "велигер": ["парусник"],
    "велик": ["велосипед", "двухколёсный друг"],
    "великан": ["гигант", "исполин"],
    "великаний": ["великанский"],
    "великанша": ["гигантша"],
    "великая война": ["первая мировая война", "германская", "германская война", "империалистическая война"],
    "великая минская империя": ["империя мин"],
    "великая отечественная война": ["вов", "восточный фронт", "немецко-советская война"],
    "великий": ["большой", "значительный"],
    "великий новгород": ["новгород"],
    "великий пост": ["вп"],
    "великий четверг": ["великий четверток", "страстной четверг", "чистый четверг"],
    "великобританец": ["британец"],
    "великобритания": ["британия", "соединённое королевство", "британский лев", "владычица морей"],
    "великобританский": ["британский"],
    "великогласный": ["громогласный", "слышный", "известный"],
    "великодаровитый": ["щедрый"],
    "великоденный": ["великоденский", "пасхальный", "великодённый"],
    "великоденский": ["великоденный", "великодённый"],
    "великодень": ["великдень"],
    "великодержавный": ["имперский"],
    "великодушествовав": ["великодушествовавши"],
    "великодушествовавши": ["великодушествовав"],
    "великодушие": ["благородство", "щедрость"],
    "великодушничав": ["великодушничавши"],
    "великодушничавши": ["великодушничав"],
    "великодушный": ["бескорыстный", "благородный", "терпеливый", "щедрый"],
    "великодушье": ["великодушие"],
    "великодённый": ["великоденский", "пасхальный", "великоденный"],
    "великое герцогство люксембург": ["люксембург"],
    "великое княжество литовское": ["вкл"],
    "великокняжеский": ["великокняжий"],
    "великолепие": ["блеск", "пышность", "роскошь", "богатство"],
    "великолепно": ["превосходно", "прекрасно", "отлично"],
    "великолепный": ["прекрасный", "роскошный", "изумительный", "отличный", "превосходный"],
    "великолепье": ["великолепие"],
    "великомученик": ["мученик"],
    "великомученица": ["страдалица"],
    "великонький": ["великоватый"],
    "великоросс": ["великорус"],
    "великороссийский": ["великорусский"],
    "великорус": ["великоросс", "великорусс"],
    "великорусс": ["великорус"],
    "великорусский": ["великороссийский", "русский", "москальский"],
    "великосветский": ["придворный", "аристократический"],
    "великотырновец": ["тырновец", "тырновчанин"],
    "великоустюгец": ["великоустюжец"],
    "великоустюгский": ["великоустюжский"],
    "величав": ["величавши"],
    "величаво": ["величественно", "внушительно", "важно", "горделиво", "царственно", "торжественно"],
    "величавши": ["величав"],
    "величавый": ["величественный"],
    "величанье": ["величание"],
    "величать": ["звать", "называть", "именовать"],
    "величина": ["количество", "размер", "объём", "протяжённость", "стоимость", "корифей", "имя", "звезда", "светило", "знаменитость", "физическая величина"],
    "велогонщик": ["велоспортсмен"],
    "велодром": ["велостадион", "велотрек", "циклодром"],
    "велокомпьютер": ["велосчётчик"],
    "велокросс": ["циклокросс"],
    "велопрофессионал": ["велопрофи"],
    "велопрофи": ["велопрофессионал"],
    "велорикша": ["велотакси"],
    "велосипед": ["велик", "вел", "велодрын", "байк", "лисапед", "лисапет"],
    "велосипед-тренажёр": ["велотренажёр"],
    "велосипедив": ["велосипедивши"],
    "велосипедивши": ["велосипедив"],
    "велосипедист": ["хрустик", "велосипедаст"],
    "велосипедить": ["изобретать велосипед"],
    "велосипедки": ["велошорты"],
    "велосипедная дорожка": ["велодорожка"],
    "велотренажёр": ["велосипед-тренажёр"],
    "велошорты": ["велосипедки"],
    "велошоссе": ["велоспорт-шоссе", "шоссейный велоспорт"],
    "велум": ["веларий"],
    "велфер": ["пособие"],
    "вель": ["велью"],
    "вельва": ["ведьма", "чародейка", "колдунья"],
    "вельвет": ["кордюруа"],
    "вельзевул": ["люцифер", "сатана", "дьявол", "мефистофель", "демон", "чёрт", "азазель", "самаэль"],
    "велькро": ["липучка"],
    "вельми": ["очень", "сильно", "шибко", "весьма", "больно", "оченно", "изрядно", "необычайно", "зело", "дюже"],
    "вельф": ["пяшксе", "прява", "пряда", "пряс", "пяк"],
    "вельфке": ["вельф", "вельхкска"],
    "вельхкска": ["вельф", "вельфке"],
    "вельчак": ["вельчанин"],
    "вельчанин": ["велец", "вельчак"],
    "вельш-корги": ["корги"],
    "вельядец": ["вильяндисец", "вильяндинец"],
    "велярный согласный": ["заднеязычный согласный"],
    "вена": ["музыкальная столица мира"],
    "венболезнь": ["вензаболевание"],
    "венгерец": ["венгр", "мадьяр"],
    "венгерская народная республика": ["внр"],
    "венгерский": ["австрийско-венгерско-славянский", "австро-венгерский", "австро-венгерско-славянский"],
    "венгр": ["венгерец", "мадьяр"],
    "венгрия": ["венгерия"],
    "вендетта": ["кровная месть"],
    "вендита": ["вента"],
    "вендор": ["поставщик"],
    "вендор-лиз": ["вендорлиз", "вендор-лизинг", "вендор лиз"],
    "веневитин": ["венёвец", "веневич"],
    "веневич": ["венёвец", "веневитин"],
    "венера": ["афродита", "киприда"],
    "венерация": ["благоговение", "почтение", "пиетет"],
    "венерианец": ["венерианин"],
    "венерин башмачок": ["циприпедиум"],
    "венерин бугорок": ["лобок", "лунный холмик"],
    "венерическая болезнь": ["венерическое заболевание", "гусарская болезнь", "половая инфекция", "зппп", "дурная болезнь", "секретная болезнь"],
    "венесуэла": ["боливарианская республика венесуэла"],
    "венециан": ["домино"],
    "венецианец": ["венецианин"],
    "венецианин": ["венецианец"],
    "венецианский": ["венециянский"],
    "венеция": ["столица моря", "город каналов", "город на воде", "жемчужина адриатики"],
    "веник": ["метла"],
    "вено": ["калым"],
    "венография": ["флебография"],
    "венозный": ["венечный"],
    "венок": ["венец", "вен"],
    "венокол": ["ширяльщик"],
    "веносекция": ["венесекция", "флеботомия"],
    "венотомия": ["флеботомия"],
    "вентерь": ["кубырь", "куток", "мерёжа", "вятель", "вятерь", "фитиль", "крылена", "жак"],
    "вентив": ["аллатив", "терминатив", "энергикус"],
    "вентилировав": ["вентилировавши"],
    "вентилировавши": ["вентилировав"],
    "вентилировать": ["проветривать"],
    "вентиль": ["кран", "задвижка", "клапан", "запорный клапан", "маховик", "маховичок", "барашек", "кнопка", "клавиша", "выключатель", "переключатель", "ключ", "выпрямитель", "элемент", "ячейка"],
    "вентиляция": ["проветривание"],
    "вентральный": ["брюшной", "нижний"],
    "вентрикулярный": ["желудочковый"],
    "вентролог": ["чревовещатель"],
    "венув": ["венувши"],
    "венувши": ["венув"],
    "венчав": ["венчавши"],
    "венчавши": ["венчав"],
    "венчание": ["коронация", "коронование", "возведение на престол", "свадьба", "бракосочетание"],
    "венчанье": ["венчание"],
    "венчать": ["короновать", "венчать на царство"],
    "венчаться": ["короноваться"],
    "венчик": ["венец", "коронка", "ободок", "кольцо", "гайка", "взбивалка"],
    "венчиковидный": ["венчикообразный"],
    "венчикообразный": ["венчиковидный"],
    "веньгав": ["веньгавши"],
    "веньгавши": ["веньгав"],
    "венёвец": ["веневич", "веневитин"],
    "вепрь": ["кабан"],
    "вепс": ["чудь"],
    "веранда": ["терраса", "палатка"],
    "верба": ["вербина", "вербочка", "берёзка", "ёлка", "дубок"],
    "вербализация": ["оглаголивание"],
    "вербализовав": ["вербализовавши"],
    "вербализовавши": ["вербализовав"],
    "вербально": ["словесно"],
    "вербальный": ["словесный", "устный", "глагольный"],
    "вербатим": ["документальный театр"],
    "верблюд": ["велблуд", "вельбуд", "тымень", "корабль пустыни"],
    "верблюдка": ["верблюжатник"],
    "верблюжатина": ["верблюжина"],
    "верблюжатник": ["верблюдка"],
    "верблюжина": ["верблюжатина"],
    "верблюжье сено": ["пальмароза", "камочка", "зольник", "поташник", "курай"],
    "верблюжья колючка": ["янтак"],
    "вербная": ["вход господень в иерусалим", "пальмовое воскресенье", "вербное воскресенье"],
    "вербное воскресенье": ["вход господень в иерусалим", "пальмовое воскресенье", "неделя ваий"],
    "вербный": ["вербовый"],
    "вербовав": ["вербовавши"],
    "вербовавши": ["вербовав"],
    "вербовка": ["набор", "наем"],
    "вербоид": ["статив"],
    "вервь": ["вервие", "ужище"],
    "вергилий": ["виргилий"],
    "вердепешевый": ["лимонно-кремовый"],
    "вердикт": ["приговор"],
    "веребья": ["веребье", "веребушка"],
    "веред": ["нарыв", "фурункул", "чирей"],
    "вередив": ["вередивши"],
    "вередивши": ["вередив"],
    "вередник": ["вереда", "вередун"],
    "верезг": ["визг", "визжание", "верещание"],
    "верезжав": ["верезжавши"],
    "верезжавши": ["верезжав"],
    "вереница": ["череда", "цепочка", "паровозик"],
    "вереницей": ["друг за другом", "один за другим", "цепью", "цепочкой", "чередой", "цугом", "гуськом", "друг за дружкой", "затылок в затылок", "паровозом", "паровозиком", "один за одним", "гусем", "чредой"],
    "верес": ["вереск", "можжевельник"],
    "вересень": ["сентябрь"],
    "вереск": ["верес", "вересок", "верест", "воробьиная гречуха", "ёрник", "липица", "подбрусничник", "рыскун", "эрика"],
    "вересовый": ["можжевеловый"],
    "веретеница": ["медяница", "медянка"],
    "веретенообразный": ["веретеновидный", "веретеноподобный", "фузиформный"],
    "веретье": ["торпище", "дерюга", "ряднина", "верея"],
    "верещав": ["верещавши"],
    "верещавши": ["верещав"],
    "верещанье": ["верещание"],
    "верещати": ["репетувати"],
    "верещать": ["визжать"],
    "верея": ["участок", "клин", "полоса", "веретья"],
    "верзав": ["верзавши"],
    "верзавши": ["верзав"],
    "верзать": ["справлять большую нужду", "ходить по-большому"],
    "верзила": ["каланча", "дылда"],
    "верзохав": ["верзохавши"],
    "верзохавши": ["верзохав"],
    "верив": ["веривши"],
    "веривши": ["верив"],
    "верига": ["бремя", "кандалы", "оковы"],
    "верижка": ["верига", "синджир", "ланец"],
    "веритель": ["доверитель"],
    "верительная грамота": ["кредитивная грамота"],
    "верить": ["веровать", "доверять", "полагаться"],
    "верификация": ["проверка"],
    "верифицировав": ["верифицировавши"],
    "верифицировавши": ["верифицировав"],
    "верка": ["вера"],
    "вермикомпост": ["биогумус"],
    "вермикулярный": ["червеобразный"],
    "вермишель": ["лапша", "паста"],
    "вернее": ["правильнее", "правильнее сказать", "точнее"],
    "вернерит": ["мариалит", "скаполит"],
    "верно": ["правильно", "точно", "преданно"],
    "верноподданность": ["верноподданничество", "верноподданство"],
    "верноподданство": ["верноподданность", "верноподданничество"],
    "верность": ["преданность", "постоянство", "правильность", "точность", "безошибочность"],
    "вернув": ["вернувши"],
    "вернувши": ["вернув"],
    "вернути": ["повернути"],
    "вернуть": ["возвратить", "отдать"],
    "вернуться": ["возвратиться", "воротиться"],
    "верный": ["правильный", "истинный", "точный", "неизбежный", "предсказуемый", "непременный", "характерный", "преданный", "надёжный", "безотказный"],
    "верньер": ["нониус"],
    "вернёмся к нашим баранам": ["вернёмся к нашим мутонам", "вернёмся к нашим стаканам", "вернёмся к нашим тараканам"],
    "веровав": ["веровавши"],
    "веровавши": ["веровав"],
    "верованье": ["верование"],
    "веровать": ["верить"],
    "вероисповедание": ["символ веры", "вероисповеданье", "конфессия", "деноминация"],
    "вероисповеданье": ["символ веры", "вероисповедание", "конфессия", "деноминация"],
    "вероломец": ["веролом", "клятвопреступник", "клятвонарушитель"],
    "вероломно": ["предательски", "изменнически"],
    "вероломный": ["коварный", "предательский", "изменнический"],
    "вероломство": ["вероломность"],
    "вероломствовав": ["вероломствовавши"],
    "вероломствовавши": ["вероломствовав"],
    "веронал": ["барбитал"],
    "вероника": ["ника", "никич"],
    "веронь валфты": ["веронь шудефти", "веронь потяй"],
    "веронь нолдама": ["веронь сявома"],
    "веронь пиди": ["веронь потяй", "веронь сими"],
    "веронь потяй": ["веронь пиди", "веронь сими", "веронь валфты", "пяк кяжи", "пяк кальдяв"],
    "веронь сими": ["веронь пиди", "веронь потяй"],
    "веронь сявома": ["веронь нолдама"],
    "веронь шокши лопа": ["китърва панчф"],
    "веронь шудема": ["верса тума"],
    "веронь шудефти": ["веронь валфты"],
    "вероотступник": ["апостат"],
    "вероподобие": ["правдоподобие"],
    "вероученье": ["вероучение"],
    "вероятно": ["возможно"],
    "вероятность": ["возможность"],
    "вероятный": ["возможный"],
    "верса тума": ["веронь шудема"],
    "версалец": ["реакционер", "контрреволюционер"],
    "версинус": ["синус-верзус"],
    "версификатор": ["рифмоплёт", "виршеплёт", "поэтишка", "стихоплёт"],
    "версификаторство": ["версификация", "стихоплётство", "виршеплётство", "рифмоплётство"],
    "версификация": ["стихосложение", "версификаторство", "стихоплётство", "виршеплётство", "вирши", "стишки", "стишата"],
    "версифицировав": ["версифицировавши"],
    "версифицировавши": ["версифицировав"],
    "версия": ["вариант", "трактовка", "представление", "редакция"],
    "верста": ["верстовой столб", "верзила", "дылда", "каланча", "дядя стёпа", "коломенская верста"],
    "верста коломенская": ["верзила", "каланча"],
    "верстав": ["верставши"],
    "верставши": ["верстав"],
    "верстальщик": ["метранпаж"],
    "верстание": ["верстанье"],
    "верстанье": ["верстание"],
    "вертав": ["вертавши"],
    "вертавши": ["вертав"],
    "вертанув": ["вертанувши"],
    "вертанувши": ["вертанув"],
    "вертать": ["заворачивать", "давать", "гнать"],
    "вертев": ["вертевши"],
    "вертевши": ["вертев"],
    "вертелка": ["крутилка"],
    "вертение": ["верчение"],
    "вертеть": ["вращать", "крутить"],
    "вертеться": ["вращаться", "крутиться", "поворачиваться", "ворочаться", "егозить", "отираться", "околачиваться", "выпутываться", "вспоминать"],
    "вертиголовка": ["вертишейка", "крутилка", "тикун"],
    "вертикаль власти": ["вертухаль власти", "воровская вертухаль"],
    "вертикальный": ["отвесный"],
    "вертихвостка": ["ветреница", "фифа"],
    "вертишейка": ["вертиголовка", "вертошейка", "змееголовка"],
    "вертлюг-сальник": ["сальник-вертлюг"],
    "вертлюжный": ["вертлужный"],
    "вертлявость": ["непоседливость"],
    "вертлявый": ["непоседливый", "юркий", "бойкий", "живой", "оживлённый", "беспокойный", "подвижной", "шебутной", "быстрый", "шустрый", "развязный", "игривый", "суетливый", "легкомысленный", "ветреный"],
    "вертоград": ["сад"],
    "вертодром": ["гелипорт", "хелипорт"],
    "вертолёт": ["винтокрылая машина", "геликоптер", "винтокрыл", "вертушка", "вертуха"],
    "вертопрах": ["ветреник", "бездельник", "лентяй", "пустышка", "лодырь", "свистун", "разгильдяй", "ротозей", "лежебока", "пустельга", "ветрогон", "петиметр", "лежень", "верхогляд", "ветродуй"],
    "вертопрашив": ["вертопрашивши"],
    "вертопрашивши": ["вертопрашив"],
    "вертопрашить": ["вертопрашничать"],
    "вертопрашка": ["ветреница"],
    "вертопрашничав": ["вертопрашничавши"],
    "вертопрашничавши": ["вертопрашничав"],
    "вертопрашничать": ["вертопрашить"],
    "вертун": ["непоседа", "турман", "вертушка"],
    "вертунья": ["непоседа"],
    "вертуха": ["вертунья", "вертихвостка", "егоза"],
    "вертухай": ["надзиратель", "караульный", "надсмотрщик", "попка"],
    "вертухаль власти": ["вертикаль власти", "воровская вертухаль"],
    "вертя": ["крутя", "вращая"],
    "вертячий чёрт": ["егоза", "вилюшка вертячий", "змеиная векша", "голова вертячая"],
    "вертящийся": ["крутящийся"],
    "верующая": ["богомолка"],
    "верующий": ["верящий"],
    "верфь": ["судоверфь", "корабельная верфь", "эллинг"],
    "верфяной": ["верфный"],
    "верх": ["предел", "победа"],
    "верхами": ["верхом"],
    "верхневолжье": ["верхняя волга"],
    "верхнекигинец": ["кигинец"],
    "верхнеломовец": ["верхоломовец"],
    "верхнелужицкий": ["верхнелужицкий язык"],
    "верхнеуфалеец": ["уфалеец"],
    "верхний египет": ["фиваида", "та-шемау"],
    "верхний салтов": ["салтов"],
    "верхняя грань": ["верхняя грань числового множества"],
    "верхняя грань числового множества": ["верхняя грань"],
    "верхняя лупья": ["лупья", "лунья"],
    "верхняя юбка": ["тюник"],
    "верховажанин": ["верховажец"],
    "верховажец": ["верховажанин"],
    "верховенствовав": ["верховенствовавши"],
    "верховенствовавши": ["верховенствовав"],
    "верховик": ["наездник", "всадник", "высотник"],
    "верховная рада": ["вр", "вру", "верховная зрада", "верховный цирк", "верховный совет"],
    "верховный": ["высший", "главный", "наивысший"],
    "верховный главнокомандующий": ["главковерх", "верховный"],
    "верховный совет": ["вс"],
    "верховный тайный совет": ["втс"],
    "верховодец": ["верховод"],
    "верховодив": ["верховодивши"],
    "верховодивши": ["верховодив"],
    "верховой": ["высокий"],
    "верхоглядничав": ["верхоглядничавши"],
    "верхоглядничавши": ["верхоглядничав"],
    "верхоглядство": ["поверхностность"],
    "верхолаз": ["высотник"],
    "верхоломовец": ["верхнеломовец"],
    "верхонка": ["голица"],
    "верхоплодный": ["акрокарпный"],
    "верхосытка": ["закуска", "заедка", "десерт", "лакомство"],
    "верхотоемец": ["верхнетоемец"],
    "верхотура": ["верх", "верха"],
    "верхушка": ["верх", "вершина", "элита", "сливки"],
    "верчение": ["вращение", "кручение"],
    "верченый": ["крученый"],
    "вершенье": ["вершение"],
    "вершив": ["вершивши"],
    "вершивши": ["вершив"],
    "вершина": ["верхушка", "узел", "точка", "кульминация", "апогей"],
    "вершинив": ["вершинивши"],
    "вершинивши": ["вершинив"],
    "вершить": ["завершать", "разрешать", "решать", "распоряжаться", "управлять", "выполнять", "исполнять"],
    "вершковав": ["вершковавши"],
    "вершковавши": ["вершковав"],
    "вершок": ["палец"],
    "верющая грамота": ["верительная грамота"],
    "верющее письмо": ["доверенность"],
    "верющий": ["верительный"],
    "верящий": ["верующий"],
    "верёвка": ["вервие", "вервь", "виселица", "петля"],
    "верёвка плачет": ["виселица плачет"],
    "вес": ["сила тяжести", "масса", "значимость", "авторитет", "весовой коэффициент", "доля", "удельный вес", "гиря", "груз", "стафф"],
    "веселев": ["веселевши"],
    "веселевши": ["веселев"],
    "веселив": ["веселивши"],
    "веселивши": ["веселив"],
    "веселие": ["веселье"],
    "веселиться": ["радоваться", "развлекаться"],
    "веселиця": ["веселка", "райдуга"],
    "веселка": ["райдуга"],
    "веселковий": ["райдужний"],
    "весело": ["оживлённо", "празднично", "радостно"],
    "веселовский": ["весёловский"],
    "веселоебучий": ["весёлый", "жизнерадостный", "задорный"],
    "веселуха": ["веселье"],
    "веселье": ["веселуха", "смешливость", "радость", "праздник", "развлечение"],
    "весельчак": ["забавник", "балагур", "хохотун"],
    "веселяк": ["весел", "духовит", "занимателен", "забавителен"],
    "веселящий": ["радующий", "смешащий"],
    "весенний": ["вешний"],
    "весианин": ["весьегонец", "весьёгонец"],
    "весив": ["весивши"],
    "весивши": ["весив"],
    "весить": ["тянуть", "значить", "занимать", "взвешивать", "вешать"],
    "веситься": ["взвешиваться"],
    "веский": ["весомый", "тяжёлый", "значительный", "убедительный"],
    "веско": ["весомо", "убедительно"],
    "весло": ["винтовка"],
    "весноватый": ["веснушчатый"],
    "весной": ["весною", "по весне"],
    "весною": ["весной", "по весне"],
    "веснушчатый": ["весноватый"],
    "весовой лоскут": ["ветошь"],
    "весок": ["отвес"],
    "весомость": ["вес", "увесистость", "значительность", "важность"],
    "весомый": ["веский", "тяжёлый"],
    "веспер": ["венера"],
    "весталка": ["девственница", "девушка", "дева", "девица", "целка", "скромница", "недотрога", "старая дева"],
    "вестгот": ["визигот", "тервинг"],
    "вестевок": ["вестьке", "вестенге"],
    "вестенге": ["вестьке", "вестевок"],
    "вестернизация": ["западнизация"],
    "вестернизировав": ["вестернизировавши"],
    "вестернизировавши": ["вестернизировав"],
    "вести": ["направлять", "указывать", "руководить", "прокладывать", "проводить", "двигать", "приводить", "иметь преимущество", "следить"],
    "вести к алтарю": ["вести под венец"],
    "вести под венец": ["вести к алтарю"],
    "вести родню": ["водить родню"],
    "вести себя": ["поступать", "держаться"],
    "вестибюль": ["коридор", "передняя"],
    "вестминстер": ["уэстминстер"],
    "вестминстерский": ["уэстминстерский"],
    "вестник": ["предвестник", "провозвестник"],
    "вестникар": ["журналист", "публицист", "кореспондент", "дописник"],
    "вестница": ["вестунья"],
    "вестовой": ["сигнальный", "ординарец"],
    "весточка": ["весть", "известие", "послание"],
    "вестфалия": ["герцогство вестфалия", "королевство вестфалия", "провинция вестфалия"],
    "весть": ["известие", "новость", "сообщение", "молва", "слухи", "сплетни", "толки", "пересуды", "разговоры"],
    "вестьке": ["вестевок", "вестенге"],
    "весь": ["деревня", "селение", "село", "сельцо"],
    "весь в поте и хуй в роте": ["весь в поту и хуй во рту"],
    "весь в поту и хуй во рту": ["весь в поте и хуй в роте"],
    "весьегонец": ["весьёгонец", "весианин"],
    "весьегонка": ["весьёгонка"],
    "весьегонск": ["весьёгонск"],
    "весьма": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "превесьма больно", "оченно", "сверх меры", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени"],
    "весьёгонец": ["весьегонец", "весианин"],
    "весёлка": ["весёлка обыкновенная", "фаллюс нескромный", "сморчок вонючий", "сморчок подагрический"],
    "весёлко": ["весло"],
    "весёловский": ["веселовский"],
    "весёлый": ["смешливый", "радостный", "забавный", "позитивный", "яркий"],
    "вет": ["ветеринар", "ветврач"],
    "ветвив": ["ветвивши"],
    "ветвивши": ["ветвив"],
    "ветвие": ["ветвь", "ветка"],
    "ветвить": ["ответвлять"],
    "ветвиться": ["разветвляться"],
    "ветвление": ["разветвление"],
    "ветврач": ["ветеренар"],
    "ветвь": ["ветка"],
    "ветер": ["дуновение", "ветр"],
    "ветеранка": ["ветеранша"],
    "ветеринар": ["ветврач"],
    "ветеринарка": ["ветклиника"],
    "ветеринарный препарат": ["ветпрепарат"],
    "ветировав": ["ветировавши"],
    "ветировавши": ["ветировав"],
    "ветировать": ["отклонять", "отвергать"],
    "ветка": ["побег", "ветвь", "тема", "топик", "тред"],
    "ветла": ["ива белая", "ива серебристая", "белолоз"],
    "ветловый": ["ветляный"],
    "ветлужанин": ["ветлужец", "ветлужан", "ветлугай"],
    "ветлужец": ["ветлужанин"],
    "вето": ["запрещение", "запрет", "отмена"],
    "ветошник": ["старьевщик"],
    "ветошница": ["старьевщица"],
    "ветошь": ["тряпьё", "рваньё", "рухлядь", "барахло", "старьё", "протирка"],
    "ветошь неучтённая": ["солдат"],
    "ветпрепарат": ["ветеринарный препарат"],
    "ветр": ["ветер"],
    "ветрев": ["ветревши"],
    "ветревши": ["ветрев"],
    "ветренев": ["ветреневши"],
    "ветреневши": ["ветренев"],
    "ветренеть": ["ветреть"],
    "ветреничав": ["ветреничавши"],
    "ветреничавши": ["ветреничав"],
    "ветреничать": ["сумасбродничать", "шалопутничать", "сумасбродствовать", "шалопайничать", "сумасбродить", "папильйонировать", "папильйонничать"],
    "ветреность": ["легкомысленность", "непостоянство", "беззаботность", "легкость", "мальчишество", "неосновательность", "легковесность", "беспечность", "дурашливость", "бездумность", "легкомыслие", "ребячливость", "несерьезность"],
    "ветреный": ["легкомысленный", "непостоянный", "беспечный", "несерьёзный"],
    "ветреть": ["ветренеть"],
    "ветрив": ["ветривши"],
    "ветривши": ["ветрив"],
    "ветрило": ["парус"],
    "ветрище": ["ветрюга", "ветряга"],
    "ветровка": ["штормовка"],
    "ветровое стекло": ["лобовое стекло"],
    "ветрогенератор": ["ветроустановка", "ветроэлектроустановка"],
    "ветрогон": ["ветреник", "бездельник", "лентяй", "пустышка", "лодырь", "свистун", "разгильдяй", "ротозей", "лежебока", "пустельга", "петиметр", "лежень", "верхогляд", "ветродуй", "ветропляс"],
    "ветроизмерение": ["ветромониторинг"],
    "ветромер": ["анемометр"],
    "ветромониторинг": ["ветроизмерение"],
    "ветронепроницаемый": ["ветрозащитный"],
    "ветроопыление": ["анемофилия"],
    "ветроопыляемый": ["анемофильный"],
    "ветропарк": ["ветростанция", "ветроэлектростанция"],
    "ветросиловой": ["ветряной"],
    "ветростанция": ["ветроэлектростанция", "ветропарк"],
    "ветроуказатель": ["колдун", "носок", "буратино", "колбаса"],
    "ветроупорность": ["ветроустойчивость"],
    "ветроустановка": ["ветрогенератор"],
    "ветроустойчивость": ["ветроупорность"],
    "ветроэлектростанция": ["ветропарк", "ветростанция", "вэс"],
    "ветрюга": ["ветрище", "ветряга"],
    "ветряга": ["ветрище", "ветрюга"],
    "ветряная мельница": ["ветряк", "ветродвигатель", "ветряной двигатель", "пропеллер", "воздушный винт", "крыло", "мельница", "флюгер", "фантом", "призрак"],
    "ветряная оспа": ["ветрянка"],
    "ветрянка": ["ветряная оспа"],
    "ветряной": ["ветряный"],
    "ветурин": ["извозчик"],
    "ветхенький": ["ветхонький"],
    "ветхий": ["обветшалый", "изношенный", "ветхозаветный", "устарелый"],
    "ветхозаветность": ["древность"],
    "ветхозаветный": ["древний", "устарелый", "старомодный", "допотопный"],
    "ветхонький": ["ветхенький"],
    "ветшав": ["ветшавши"],
    "ветшавши": ["ветшав"],
    "ветёлка": ["ветла"],
    "вех": ["вёх", "вяха", "цикута", "болиголов"],
    "веха": ["поворотный пункт"],
    "вехотка": ["мочалка", "вехоть", "вихотка", "ветошь", "тряпка"],
    "вечарам": ["увечар", "увечары"],
    "вечер": ["вечерок", "бал", "раут"],
    "вечер в хату": ["добрый вечер"],
    "вечерев": ["вечеревши"],
    "вечеревши": ["вечерев"],
    "вечеринка": ["тусовка", "вечер", "вечерина", "вечеруха", "сейшн"],
    "вечерком": ["вечером"],
    "вечеровав": ["вечеровавши"],
    "вечеровавши": ["вечеровав"],
    "вечером": ["ввечеру", "вечерком"],
    "вечеря": ["ужин"],
    "вечеряв": ["вечерявши"],
    "вечерявши": ["вечеряв"],
    "вечерять": ["ужинать"],
    "вечник": ["бессрочник"],
    "вечно": ["бесконечно", "всегда", "вовек", "от века до века", "во веки", "во веки веков", "постоянно", "то и дело"],
    "вечность": ["бесконечность"],
    "вечный двигатель": ["перпетуум-мобиле"],
    "вечор": ["вчера"],
    "вечёрка": ["вечеринка"],
    "вечёркинец": ["вечёрочник"],
    "вечёрочник": ["вечёркинец"],
    "вешав": ["вешавши"],
    "вешавши": ["вешав"],
    "вешалка": ["плечики", "тремпель", "гардероб"],
    "вешальщик": ["гардеробщик"],
    "вешанье": ["вешание"],
    "вешать": ["подвешивать"],
    "вешать лапшу на уши": ["пускать пыль в глаза", "пудрить мозги", "втирать очки", "арапа заправлять", "водить за нос"],
    "вешать лапшу на хуй": ["вешать лапшу на уши"],
    "вешив": ["вешивши"],
    "вешивав": ["вешивавши"],
    "вешивавши": ["вешивав"],
    "вешивши": ["вешив"],
    "вешка": ["веха"],
    "вешние воды": ["паводок"],
    "вешний": ["весенний"],
    "вещав": ["вещавши"],
    "вещавши": ["вещав"],
    "вещание": ["проповедывание", "предсказание", "прорицание", "пророчество", "предвещание", "предвещение", "предрекание", "изрекание"],
    "вещать": ["транслировать", "прорицать", "предвещать"],
    "вещер": ["вълшебник", "вед", "чародей"],
    "вещественно": ["материально", "осязаемо", "физически"],
    "вещественнозначность": ["действительнозначность"],
    "вещественнозначный": ["действительнозначный"],
    "вещественный": ["материальный", "физический", "предметный", "действительный"],
    "вещество": ["материал", "субстанция"],
    "вещизм": ["мещанство"],
    "вещий": ["провидческий", "прозорливый", "ведающий", "пророческий", "предрекающий", "мудрый"],
    "вещмешок": ["вещевой мешок"],
    "вещун": ["предсказатель", "прорицатель"],
    "вещунья": ["предсказательница", "прорицательница"],
    "вещь в себе": ["вещь сама по себе", "чёрный ящик"],
    "вещьмешок": ["вещевой мешок"],
    "веяв": ["веявши"],
    "веявши": ["веяв"],
    "веяльщик": ["веятель"],
    "веяние": ["дуновение", "тенденция", "поветрие"],
    "веятель": ["раздуватель", "веяльщик"],
    "вжав": ["вжавши"],
    "вжавши": ["вжав"],
    "вжарив": ["вжаривши"],
    "вжаривши": ["вжарив"],
    "вживаться": ["привыкать"],
    "вживив": ["вжививши"],
    "вжививши": ["вживив"],
    "вживить": ["имплантировать"],
    "вживление": ["имплантация"],
    "вживляв": ["вживлявши"],
    "вживлявши": ["вживляв"],
    "вживлять": ["имплантировать"],
    "вживлённый": ["имплантированный", "встроенный"],
    "вживую": ["в реальности", "в действительности", "воочию", "живьём"],
    "вжикав": ["вжикавши"],
    "вжикавши": ["вжикав"],
    "вжикнув": ["вжикнувши"],
    "вжикнувши": ["вжикнув"],
    "вжимав": ["вжимавши"],
    "вжимавши": ["вжимав"],
    "вжимать": ["вдавливать"],
    "вжиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "сжиться", "прижиться", "освоиться"],
    "вжоперти": ["взаперти", "под замком", "в жопе"],
    "вжух": ["бац", "раз", "хуякс"],
    "вз-": ["вс-", "взо-"],
    "взад": ["назад", "обратно"],
    "взаимно": ["обоюдно", "между собой", "заимообразно", "друг друга", "взаимо", "двусторонне", "один другого", "один одного", "двухсторонне"],
    "взаимнообратный": ["взаимно-обратный", "взаимообратный"],
    "взаимность": ["обоюдность"],
    "взаимный": ["обоюдный", "круговой", "общий", "возвратный", "встречный"],
    "взаимовлияв": ["взаимовлиявши"],
    "взаимовлиявши": ["взаимовлияв"],
    "взаимовыгодный": ["обоюдовыгодный"],
    "взаимовыигрышный": ["взаимовыгодный"],
    "взаимовыручка": ["взаимопомощь"],
    "взаимодействие": ["взаимосвязь", "кооперация", "сотрудничество", "содействие"],
    "взаимодействовав": ["взаимодействовавши"],
    "взаимодействовавши": ["взаимодействовав"],
    "взаимодополняв": ["взаимодополнявши"],
    "взаимодополнявши": ["взаимодополняв"],
    "взаимодополняемость": ["комплементарность"],
    "взаимодополняемый": ["взаимодополняющий", "комплементарный"],
    "взаимозаменимый": ["взаимозаменяемый"],
    "взаимозаменяемый": ["взаимозаменимый"],
    "взаимозачёт": ["взаимный зачёт", "клиринг"],
    "взаимоиндуктивность": ["взаимоиндукция"],
    "взаимоиндукция": ["взаимная индукция"],
    "взаимоисключающий": ["противоречивый"],
    "взаимоисключение": ["несовместимость"],
    "взаимоистребление": ["взаимоуничтожение"],
    "взаимообразный": ["заимообразный"],
    "взаимообратный": ["взаимнообратный"],
    "взаимоотношение": ["взаимосвязь", "отношения"],
    "взаимопогашав": ["взаимопогашавши"],
    "взаимопогашавши": ["взаимопогашав"],
    "взаимоподавление": ["интерференция"],
    "взаимопонимание": ["взаимоприятие", "единодушие", "согласие", "эмпатия", "взаимопониманье"],
    "взаимопониманье": ["взаимопонимание"],
    "взаимопроверка": ["проверка"],
    "взаимопроникав": ["взаимопроникавши"],
    "взаимопроникавши": ["взаимопроникав"],
    "взаимосвязав": ["взаимосвязавши"],
    "взаимосвязавши": ["взаимосвязав"],
    "взаимосвязанный": ["единый", "целостный", "коррелирующий"],
    "взаимосвязывав": ["взаимосвязывавши"],
    "взаимосвязывавши": ["взаимосвязывав"],
    "взаимосвязь": ["связь", "корреляция", "взаимозависимость", "взаимовлияние"],
    "взаимоувязав": ["взаимоувязавши"],
    "взаимоувязавши": ["взаимоувязав"],
    "взаимоувязывав": ["взаимоувязывавши"],
    "взаимоувязывавши": ["взаимоувязывав"],
    "взаймы": ["заимообразно", "платно", "возмездно", "с возвратом", "в кредит", "в долг", "в пользование", "временно", "на время"],
    "взалкав": ["взалкавши"],
    "взалкавши": ["взалкав"],
    "взаперти": ["под замком", "запершись"],
    "взапуски": ["наперегонки"],
    "взариться": ["уставиться"],
    "взахлёб": ["страстно", "жадно"],
    "взбадривав": ["взбадривавши"],
    "взбадривавши": ["взбадривав"],
    "взбаламутив": ["взбаламутивши"],
    "взбаламутивши": ["взбаламутив"],
    "взбаламученный": ["замутнённый"],
    "взбаламучивав": ["взбаламучивавши"],
    "взбаламучивавши": ["взбаламучивав"],
    "взбалмошно": ["сумасбродно"],
    "взбалмошность": ["суматошность"],
    "взбалмошный": ["сумасбродный", "неуравновешенный", "суматошный"],
    "взбалтывав": ["взбалтывавши"],
    "взбалтывавши": ["взбалтывав"],
    "взбег": ["взбегание"],
    "взбегав": ["взбегавши"],
    "взбегавши": ["взбегав"],
    "взбежав": ["взбежавши"],
    "взбежавши": ["взбежав"],
    "взбеленив": ["взбеленивши"],
    "взбеленивши": ["взбеленив"],
    "взбеленить": ["разгневить", "разъярить"],
    "взбелениться": ["взбеситься", "разгневаться", "разозлиться", "озлиться"],
    "взбесив": ["взбесивши"],
    "взбесивши": ["взбесив"],
    "взбесившийся принтер": ["госдура", "бешеный принтер", "сумасшедший принтер"],
    "взбзднув": ["взбзднувши"],
    "взбзднувши": ["взбзднув"],
    "взбив": ["взбивши"],
    "взбивав": ["взбивавши"],
    "взбивавши": ["взбивав"],
    "взбивши": ["взбив"],
    "взбираться": ["забираться", "влезать"],
    "взблеск": ["взблескивание"],
    "взблескивав": ["взблескивавши"],
    "взблескивавши": ["взблескивав"],
    "взблеснув": ["взблеснувши"],
    "взблеснувши": ["взблеснув"],
    "взблёскивав": ["взблёскивавши"],
    "взблёскивавши": ["взблёскивав"],
    "взбодрив": ["взбодривши"],
    "взбодривши": ["взбодрив"],
    "взболтав": ["взболтавши"],
    "взболтавши": ["взболтав"],
    "взболтнув": ["взболтнувши"],
    "взболтнувши": ["взболтнув"],
    "взборанивав": ["взборанивавши"],
    "взборанивавши": ["взборанивав"],
    "взбороздив": ["взбороздивши"],
    "взбороздивши": ["взбороздив"],
    "взборонив": ["взборонивши"],
    "взборонивши": ["взборонив"],
    "взборонить": ["взбороновать", "изборонить", "выборонить"],
    "взбороновав": ["взбороновавши"],
    "взбороновавши": ["взбороновав"],
    "взбороновать": ["выборонить", "изборонить", "взборонить"],
    "взбрасывав": ["взбрасывавши"],
    "взбрасывавши": ["взбрасывав"],
    "взбрасывание": ["вскидывание", "взметание", "вбрасывание", "ввод", "вброс"],
    "взбрасывать": ["вскидывать", "взметать", "подкидывать"],
    "взбрасываться": ["вскинуться"],
    "взбредав": ["взбредавши"],
    "взбредавши": ["взбредав"],
    "взбрести": ["взбресть"],
    "взброс": ["взбрасывание"],
    "взбросив": ["взбросивши"],
    "взбросивши": ["взбросив"],
    "взброситься": ["вскинуться"],
    "взбрызгивав": ["взбрызгивавши"],
    "взбрызгивавши": ["взбрызгивав"],
    "взбрызнув": ["взбрызнувши"],
    "взбрызнувши": ["взбрызнув"],
    "взбрыкивав": ["взбрыкивавши"],
    "взбрыкивавши": ["взбрыкивав"],
    "взбрыкнув": ["взбрыкнувши"],
    "взбрыкнувши": ["взбрыкнув"],
    "взбугрив": ["взбугривши"],
    "взбугривши": ["взбугрив"],
    "взбудив": ["взбудивши"],
    "взбудивши": ["взбудив"],
    "взбудить": ["разбудить"],
    "взбудораженный": ["взволнованный", "встревоженный", "растревоженный"],
    "взбудоражив": ["взбудораживши"],
    "взбудораживав": ["взбудораживавши"],
    "взбудораживавши": ["взбудораживав"],
    "взбудораживать": ["будоражить"],
    "взбудораживши": ["взбудоражив"],
    "взбудоражить": ["всполошить", "переполошить"],
    "взбулгачив": ["взбулгачивши"],
    "взбулгачивши": ["взбулгачив"],
    "взбулгачить": ["встревожить", "переполошить"],
    "взбунтовав": ["взбунтовавши"],
    "взбунтовавши": ["взбунтовав"],
    "взбуравив": ["взбуравивши"],
    "взбуравивши": ["взбуравив"],
    "взбурлив": ["взбурливши"],
    "взбурливши": ["взбурлив"],
    "взбуровив": ["взбуровивши"],
    "взбуровивши": ["взбуровив"],
    "взбутетенив": ["взбутетенивши"],
    "взбутетенивав": ["взбутетенивавши"],
    "взбутетенивавши": ["взбутетенивав"],
    "взбутетенивши": ["взбутетенив"],
    "взбухав": ["взбухавши"],
    "взбухавши": ["взбухав"],
    "взбухать": ["набухать", "разбухать", "вздуваться"],
    "взбухнув": ["взбухнувши"],
    "взбухнувши": ["взбухнув"],
    "взбучив": ["взбучивши"],
    "взбучивши": ["взбучив"],
    "взбучка": ["баня", "вздрючка", "вливание", "внушение", "встрёпка", "встряска", "втык", "выволочка", "выговор", "выпалка", "головомойка", "гонка", "жученье", "клочка", "нагонка"],
    "взбушевав": ["взбушевавши"],
    "взбушевавши": ["взбушевав"],
    "взвадец": ["взважанин"],
    "взважанин": ["взвадец"],
    "взвалив": ["взваливши"],
    "взваливав": ["взваливавши"],
    "взваливавши": ["взваливав"],
    "взваливши": ["взвалив"],
    "взварец": ["взвар"],
    "взварив": ["взваривши"],
    "взваривав": ["взваривавши"],
    "взваривавши": ["взваривав"],
    "взваривши": ["взварив"],
    "взвевав": ["взвевавши"],
    "взвевавши": ["взвевав"],
    "взвезя": ["взвёзши"],
    "взвеличав": ["взвеличавши"],
    "взвеличавши": ["взвеличав"],
    "взвернув": ["взвернувши"],
    "взвернувши": ["взвернув"],
    "взвеселив": ["взвеселивши"],
    "взвеселивши": ["взвеселив"],
    "взвеселяв": ["взвеселявши"],
    "взвеселявши": ["взвеселяв"],
    "взвеселять": ["увеселять"],
    "взвесив": ["взвесивши"],
    "взвесивши": ["взвесив"],
    "взвеситься": ["свеситься"],
    "взвесь": ["суспензия", "частицы"],
    "взвешенность": ["сбалансированность", "уравновешенность"],
    "взвешивав": ["взвешивавши"],
    "взвешивавши": ["взвешивав"],
    "взвешивание": ["отвешивание", "пондерация"],
    "взвешиванье": ["взвешивание"],
    "взвешивать": ["вешать", "обдумывать", "оценивать"],
    "взвеяв": ["взвеявши"],
    "взвеявши": ["взвеяв"],
    "взвив": ["взвивши"],
    "взвивав": ["взвивавши"],
    "взвивавши": ["взвивав"],
    "взвиваться": ["взмывать", "взрываться"],
    "взвивши": ["взвив"],
    "взвидев": ["взвидевши"],
    "взвидевши": ["взвидев"],
    "взвизгивав": ["взвизгивавши"],
    "взвизгивавши": ["взвизгивав"],
    "взвизгивание": ["взвизг", "визг"],
    "взвизгиванье": ["взвизгивание"],
    "взвизгнув": ["взвизгнувши"],
    "взвизгнувши": ["взвизгнув"],
    "взвинтив": ["взвинтивши"],
    "взвинтивши": ["взвинтив"],
    "взвинтить": ["вскрутить", "возбудить", "задрать"],
    "взвинченный": ["нервный", "возбуждённый", "нервозный"],
    "взвинчивав": ["взвинчивавши"],
    "взвинчивавши": ["взвинчивав"],
    "взвить": ["взвеять", "взмести"],
    "взвиться": ["взмыть", "взорваться", "заартачиться"],
    "взвихрив": ["взвихривши"],
    "взвихривав": ["взвихривавши"],
    "взвихривавши": ["взвихривав"],
    "взвихривши": ["взвихрив"],
    "взвихряв": ["взвихрявши"],
    "взвихрявши": ["взвихряв"],
    "взводив": ["взводивши"],
    "взводивши": ["взводив"],
    "взвозив": ["взвозивши"],
    "взвозивши": ["взвозив"],
    "взволакивав": ["взволакивавши"],
    "взволакивавши": ["взволакивав"],
    "взволновав": ["взволновавши"],
    "взволновавши": ["взволновав"],
    "взволнованно": ["возбуждённо", "обеспокоенно", "тревожно"],
    "взволнованность": ["волнение"],
    "взволновать": ["поколебать", "возбудить", "встревожить", "растревожить"],
    "взволноваться": ["разбушеваться", "разволноваться", "заволноваться", "взбунтоваться"],
    "взволочив": ["взволочивши"],
    "взволочивши": ["взволочив"],
    "взворачивав": ["взворачивавши"],
    "взворачивавши": ["взворачивав"],
    "взворотив": ["взворотивши"],
    "взворотивши": ["взворотив"],
    "взворошив": ["взворошивши"],
    "взворошивши": ["взворошив"],
    "взвыв": ["взвывши"],
    "взвывав": ["взвывавши"],
    "взвывавши": ["взвывав"],
    "взвывши": ["взвыв"],
    "взвёзши": ["взвезя"],
    "взгадав": ["взгадавши"],
    "взгадавши": ["взгадав"],
    "взгадывав": ["взгадывавши"],
    "взгадывавши": ["взгадывав"],
    "взгляд": ["взор", "точка зрения", "отношение", "воззрение", "сторона", "соображение", "позиция", "перспектива", "убеждение", "заключение"],
    "взглядывав": ["взглядывавши"],
    "взглядывавши": ["взглядывав"],
    "взглядывать": ["посматривать"],
    "взглянув": ["взглянувши"],
    "взглянувши": ["взглянув"],
    "взглянуть": ["посмотреть", "глянуть", "поглядеть", "рассмотреть", "проанализировать"],
    "взговорив": ["взговоривши"],
    "взговоривши": ["взговорив"],
    "взгомозив": ["взгомозивши"],
    "взгомозивши": ["взгомозив"],
    "взгомонив": ["взгомонивши"],
    "взгомонивши": ["взгомонив"],
    "взгомониться": ["переполошиться", "всполошиться"],
    "взгоняв": ["взгонявши"],
    "взгонявши": ["взгоняв"],
    "взгорбив": ["взгорбивши"],
    "взгорбивши": ["взгорбив"],
    "взгорок": ["пригорок"],
    "взгорье": ["холм", "взгорок"],
    "взгорячив": ["взгорячивши"],
    "взгорячивши": ["взгорячив"],
    "взгорячить": ["разгорячить"],
    "взгребав": ["взгребавши"],
    "взгребавши": ["взгребав"],
    "взгрев": ["взгревши"],
    "взгревав": ["взгревавши"],
    "взгревавши": ["взгревав"],
    "взгревши": ["взгрев"],
    "взгремев": ["взгремевши"],
    "взгремевши": ["взгремев"],
    "взгреть": ["согреть", "разогреть", "вздуть", "отдубасить"],
    "взгромождав": ["взгромождавши"],
    "взгромождавши": ["взгромождав"],
    "взгромоздив": ["взгромоздивши"],
    "взгромоздивши": ["взгромоздив"],
    "взгромоздившись": ["взгромоздясь"],
    "взгромоздиться": ["забраться", "залезть"],
    "взгромоздясь": ["взгромоздившись", "взобравшись"],
    "взгрустив": ["взгрустивши"],
    "взгрустивши": ["взгрустив"],
    "взгрустить": ["взгрустнуть"],
    "взгрустнув": ["взгрустнувши"],
    "взгрустнувши": ["взгрустнув"],
    "вздваивав": ["вздваивавши"],
    "вздваивавши": ["вздваивав"],
    "вздвигав": ["вздвигавши"],
    "вздвигавши": ["вздвигав"],
    "вздвинув": ["вздвинувши"],
    "вздвинувши": ["вздвинув"],
    "вздвоив": ["вздвоивши"],
    "вздвоивши": ["вздвоив"],
    "вздев": ["вздевши"],
    "вздевав": ["вздевавши"],
    "вздевавши": ["вздевав"],
    "вздевать": ["воздевать", "надевать", "вдевать"],
    "вздевши": ["вздев"],
    "вздирав": ["вздиравши"],
    "вздиравши": ["вздирав"],
    "вздор": ["враньё", "обман"],
    "вздорив": ["вздоривши"],
    "вздоривши": ["вздорив"],
    "вздорить": ["ссориться", "браниться"],
    "вздорный": ["необоснованный", "выдуманный", "бессмысленный", "конфликтный", "склочный", "скандальный", "сварливый", "вспыльчивый", "драчливый"],
    "вздорожав": ["вздорожавши"],
    "вздорожавши": ["вздорожав"],
    "вздохнув": ["вздохнувши"],
    "вздохнувши": ["вздохнув"],
    "вздохнуть": ["передохнуть", "отдохнуть", "пожалеть", "взгрустнуть"],
    "вздрагивав": ["вздрагивавши"],
    "вздрагивавши": ["вздрагивав"],
    "вздрагиванье": ["вздрагивание"],
    "вздрагивать": ["содрогаться", "дёргаться"],
    "вздрачивав": ["вздрачивавши"],
    "вздрачивавши": ["вздрачивав"],
    "вздремав": ["вздремавши"],
    "вздремавши": ["вздремав"],
    "вздремнув": ["вздремнувши"],
    "вздремнувши": ["вздремнув"],
    "вздремнуть": ["поспать"],
    "вздрог": ["вздрагивание"],
    "вздрогнув": ["вздрогнувши"],
    "вздрогнувши": ["вздрогнув"],
    "вздрогнуть": ["содрогнуться", "дёрнуться", "качнуться", "выпить", "пропустить", "тяпнуть"],
    "вздрочив": ["вздрочивши"],
    "вздрочивши": ["вздрочив"],
    "вздрочнув": ["вздрочнувши"],
    "вздрочнувши": ["вздрочнув"],
    "вздрючив": ["вздрючивши"],
    "вздрючивав": ["вздрючивавши"],
    "вздрючивавши": ["вздрючивав"],
    "вздрючивать": ["задирать", "встряхивать", "трахать"],
    "вздрючивши": ["вздрючив"],
    "вздув": ["вздувши"],
    "вздував": ["вздувавши"],
    "вздувавши": ["вздував"],
    "вздувши": ["вздув"],
    "вздумав": ["вздумавши"],
    "вздумавши": ["вздумав"],
    "вздурив": ["вздуривши"],
    "вздуривши": ["вздурив"],
    "вздуриться": ["обезуметь", "потерять голову", "не помнить себя", "быть не в себе", "закусить удила", "обеспамятеть", "ошалеть", "ополоуметь", "очуметь", "сдуреть", "офонареть", "офигеть", "охренеть", "опсихеть", "сдуриться"],
    "вздутие": ["вздувание", "вздутость", "выпуклость"],
    "вздутость": ["вздутие", "опухоль", "флюс"],
    "вздутый": ["опухший", "набухший"],
    "вздутье": ["вздутие"],
    "вздыбив": ["вздыбивши"],
    "вздыбивши": ["вздыбив"],
    "вздыбливав": ["вздыбливавши"],
    "вздыбливавши": ["вздыбливав"],
    "вздыбливать": ["встопорщивать", "ощетинивать", "взъерошивать", "вздыбливаться"],
    "вздымав": ["вздымавши"],
    "вздымавши": ["вздымав"],
    "вздымание": ["подъятие", "воздевание"],
    "вздыманье": ["вздымание"],
    "вздымать": ["воздымать", "воздевать"],
    "вздыхав": ["вздыхавши"],
    "вздыхавши": ["вздыхав"],
    "вздыханье": ["вздыхание"],
    "вздёргивав": ["вздёргивавши"],
    "вздёргивавши": ["вздёргивав"],
    "вздёрнув": ["вздёрнувши"],
    "вздёрнувши": ["вздёрнув"],
    "вздёрнуться": ["повеситься"],
    "взимав": ["взимавши"],
    "взимавши": ["взимав"],
    "взимание": ["взымание"],
    "взимать": ["взымать", "взыскивать"],
    "взиматься": ["взыматься"],
    "взирав": ["взиравши"],
    "взиравши": ["взирав"],
    "взирать": ["смотреть", "глядеть", "воззирать", "воззревать", "таращить глаза", "таращиться", "уставиться"],
    "взлаивав": ["взлаивавши"],
    "взлаивавши": ["взлаивав"],
    "взламывав": ["взламывавши"],
    "взламывавши": ["взламывав"],
    "взламывать": ["вскрывать"],
    "взлаяв": ["взлаявши"],
    "взлаявши": ["взлаяв"],
    "взлезав": ["взлезавши"],
    "взлезавши": ["взлезав"],
    "взлезание": ["взлезанье"],
    "взлезанье": ["взлезание"],
    "взлелеяв": ["взлелеявши"],
    "взлелеявши": ["взлелеяв"],
    "взлелеять": ["воспитать", "взрастить", "выпестовать", "выносить"],
    "взлетав": ["взлетавши"],
    "взлетавши": ["взлетав"],
    "взлетанье": ["взлетание"],
    "взлетать": ["возлетать", "взмывать", "вырастать"],
    "взлетев": ["взлетевши"],
    "взлетевши": ["взлетев"],
    "взлететь": ["взмыть", "возлететь", "увенчаться успехом"],
    "взлиза": ["залысина", "взлизина"],
    "взлом": ["крэк", "кряк", "хак"],
    "взломав": ["взломавши"],
    "взломавши": ["взломав"],
    "взломаться": ["вскрыться"],
    "взломостойкий": ["взломоустойчивый"],
    "взломщик": ["домушник", "медвежатник"],
    "взлохматив": ["взлохмативши"],
    "взлохмативши": ["взлохматив"],
    "взлохматить": ["взъерошить", "всклокочить"],
    "взлохмачивав": ["взлохмачивавши"],
    "взлохмачивавши": ["взлохмачивав"],
    "взлохмачивание": ["взъерошивание"],
    "взлохмачиваться": ["взъерошиваться"],
    "взлупив": ["взлупивши"],
    "взлупивши": ["взлупив"],
    "взлупцевав": ["взлупцевавши"],
    "взлупцевавши": ["взлупцевав"],
    "взлупцовав": ["взлупцовавши"],
    "взлупцовавши": ["взлупцовав"],
    "взлущив": ["взлущивши"],
    "взлущивши": ["взлущив"],
    "взлюбив": ["взлюбивши"],
    "взлюбивши": ["взлюбив"],
    "взлюбить": ["возлюбить"],
    "взлягивав": ["взлягивавши"],
    "взлягивавши": ["взлягивав"],
    "взлягивать": ["взбрыкивать"],
    "взлягнув": ["взлягнувши"],
    "взлягнувши": ["взлягнув"],
    "взлёт": ["старт"],
    "взлётно-посадочная полоса": ["впп", "взлётка"],
    "взлётно-посадочный": ["посадочно-взлётный"],
    "взлётный": ["взлётка"],
    "взлётывав": ["взлётывавши"],
    "взлётывавши": ["взлётывав"],
    "взлётывать": ["взлетать"],
    "взманив": ["взманивши"],
    "взманивав": ["взманивавши"],
    "взманивавши": ["взманивав"],
    "взманиваться": ["прельщаться"],
    "взманивши": ["взманив"],
    "взматывав": ["взматывавши"],
    "взматывавши": ["взматывав"],
    "взмах": ["взмахивание", "мах"],
    "взмахивав": ["взмахивавши"],
    "взмахивавши": ["взмахивав"],
    "взмахнув": ["взмахнувши"],
    "взмахнувши": ["взмахнув"],
    "взмахнуть": ["махнуть"],
    "взмачивав": ["взмачивавши"],
    "взмачивавши": ["взмачивав"],
    "взмащивав": ["взмащивавши"],
    "взмащивавши": ["взмащивав"],
    "взметав": ["взметавши"],
    "взметавши": ["взметав"],
    "взметаться": ["взмётываться", "взмахиваться"],
    "взметнув": ["взметнувши"],
    "взметнувши": ["взметнув"],
    "взметнуть": ["взметнуться"],
    "взмокав": ["взмокавши"],
    "взмокавши": ["взмокав"],
    "взмокать": ["намокать"],
    "взмокнув": ["взмокнувши"],
    "взмокнувши": ["взмокнув"],
    "взмокрев": ["взмокревши"],
    "взмокревши": ["взмокрев"],
    "взмокреть": ["вспотеть", "взмокнуть"],
    "взмолодив": ["взмолодивши"],
    "взмолодивши": ["взмолодив"],
    "взморник": ["зостера"],
    "взмостив": ["взмостивши"],
    "взмостивши": ["взмостив"],
    "взмоститься": ["взгромоздиться"],
    "взмотнув": ["взмотнувши"],
    "взмотнувши": ["взмотнув"],
    "взмочив": ["взмочивши"],
    "взмочивши": ["взмочив"],
    "взмутив": ["взмутивши"],
    "взмутивши": ["взмутив"],
    "взмучивав": ["взмучивавши"],
    "взмучивавши": ["взмучивав"],
    "взмыв": ["взлетев", "воспарив", "взнёсшись"],
    "взмывав": ["взмывавши"],
    "взмывавши": ["взмывав"],
    "взмывание": ["взёт"],
    "взмывать": ["взлетать", "подниматься", "подыматься", "взвиваться", "усиливаться", "нарастать"],
    "взмывши": ["взмыв"],
    "взмыкивав": ["взмыкивавши"],
    "взмыкивавши": ["взмыкивав"],
    "взмыленный": ["взмылившийся"],
    "взмылив": ["взмыливши"],
    "взмыливав": ["взмыливавши"],
    "взмыливавши": ["взмыливав"],
    "взмыливши": ["взмылив"],
    "взмыть": ["взнестись"],
    "взмётывав": ["взмётывавши"],
    "взмётывавши": ["взмётывав"],
    "взнос": ["плата"],
    "взносив": ["взносивши"],
    "взносивши": ["взносив"],
    "взносить": ["поднимать", "уплачивать"],
    "взнуздав": ["взнуздавши"],
    "взнуздавши": ["взнуздав"],
    "взнуздывав": ["взнуздывавши"],
    "взнуздывавши": ["взнуздывав"],
    "взнуздывать": ["уздать", "обуздывать", "сдерживать", "укрощать", "усмирять"],
    "взныв": ["взнывши"],
    "взнывши": ["взныв"],
    "взогнав": ["взогнавши"],
    "взогнавши": ["взогнав"],
    "взодрав": ["взодравши"],
    "взодравши": ["взодрав"],
    "взопрев": ["взопревши"],
    "взопревши": ["взопрев"],
    "взор": ["взгляд", "глаза", "очи"],
    "взорвав": ["взорвавши"],
    "взорвавши": ["взорвав"],
    "взорвать": ["рассердить", "разозлить", "разъярить"],
    "взорваться": ["рвануть", "сдетонировать"],
    "взрастав": ["взраставши"],
    "взраставши": ["взрастав"],
    "взрастание": ["рост"],
    "взрасти": ["вырасти", "повзрослеть", "развиться"],
    "взрастив": ["взрастивши"],
    "взрастивши": ["взрастив"],
    "взрачный": ["приглядный", "казистый", "видный", "красивый"],
    "взращав": ["взращавши"],
    "взращавши": ["взращав"],
    "взращивав": ["взращивавши"],
    "взращивавши": ["взращивав"],
    "взращивать": ["растить", "выращивать"],
    "взревев": ["взревевши"],
    "взревевши": ["взревев"],
    "взревновав": ["взревновавши"],
    "взревновавши": ["взревновав"],
    "взрезав": ["взрезавши"],
    "взрезавши": ["взрезав"],
    "взрезывав": ["взрезывавши"],
    "взрезывавши": ["взрезывав"],
    "взрив": ["експлозия"],
    "взрослев": ["взрослевши"],
    "взрослевши": ["взрослев"],
    "взросление": ["мужание", "взросленье"],
    "взросленье": ["взросление"],
    "взрослив": ["взросливши"],
    "взросливши": ["взрослив"],
    "взрослый": ["зрелый", "совершеннолетний", "большой"],
    "взрыв": ["грохот"],
    "взрыв на макаронной фабрике": ["я упала с сеновала", "я у мамы дурочка", "не одна я поле кувыркалась", "кононенкино кубло"],
    "взрывав": ["взрывавши"],
    "взрывавши": ["взрывав"],
    "взрывник": ["подрывник", "пиротехник"],
    "взрывобезопасный": ["взрывозащищённый"],
    "взрывчатое вещество": ["вв", "взрывчатка"],
    "взрывши": ["взрыв"],
    "взрыдав": ["взрыдавши"],
    "взрыдавши": ["взрыдав"],
    "взрыдать": ["возрыдать"],
    "взрыдывав": ["взрыдывавши"],
    "взрыдывавши": ["взрыдывав"],
    "взрыкивав": ["взрыкивавши"],
    "взрыкивавши": ["взрыкивав"],
    "взрыкнув": ["взрыкнувши"],
    "взрыкнувши": ["взрыкнув"],
    "взрыхлив": ["взрыхливши"],
    "взрыхливши": ["взрыхлив"],
    "взрыхлить": ["разрыхлить"],
    "взрыхляв": ["взрыхлявши"],
    "взрыхлявши": ["взрыхляв"],
    "взрыхлять": ["рыхлить"],
    "взрябив": ["взрябивши"],
    "взрябивши": ["взрябив"],
    "взрёвывав": ["взрёвывавши"],
    "взрёвывавши": ["взрёвывав"],
    "взъебав": ["взъебавши"],
    "взъебавши": ["взъебав"],
    "взъебать": ["наказать", "победить", "нафитилять", "навтыкать", "вставить по первое число", "вставить пистон", "пропердолить"],
    "взъезжав": ["взъезжавши"],
    "взъезжавши": ["взъезжав"],
    "взъемлив": ["взъемливши"],
    "взъемливши": ["взъемлив"],
    "взъемлить": ["взимать"],
    "взъерепенив": ["взъерепенивши"],
    "взъерепенивши": ["взъерепенив"],
    "взъерошенный": ["встрёпанный", "растрёпанный", "взлохмаченный", "разлохмаченный", "всклокоченный", "всклоченный", "вскосмаченный", "встопорщенный", "вздыбленный", "нечёсаный", "взволнованный", "возбуждённый", "напряжённый", "раздражённый", "рассерженный"],
    "взъерошив": ["взъерошивши"],
    "взъерошивав": ["взъерошивавши"],
    "взъерошивавши": ["взъерошивав"],
    "взъерошивание": ["взлохмачивание"],
    "взъерошивать": ["взлохмачивать", "ощетинивать"],
    "взъерошивши": ["взъерошив"],
    "взъерошить": ["взлохматить", "всклокочить", "ощетинить"],
    "взъершив": ["взъершивши"],
    "взъершивши": ["взъершив"],
    "взъершиться": ["взъерошиться"],
    "взъесться": ["разозлиться", "вскипеть", "вскинуться", "рассвирепеть"],
    "взъехав": ["взъехавши"],
    "взъехавши": ["взъехав"],
    "взъярив": ["взъяривши"],
    "взъяривши": ["взъярив"],
    "взъёб": ["нагоняй", "взбучка", "выговор", "разнос", "пистон", "взъёбка", "разъёб", "распроёб", "распроёбка"],
    "взъёбка": ["нагоняй", "взбучка", "выговор", "разнос", "пистон", "взъёб", "разъёб", "распроёб", "распроёбка"],
    "взъёбывав": ["взъёбывавши"],
    "взъёбывавши": ["взъёбывав"],
    "взъём": ["подъём"],
    "взывав": ["взывавши"],
    "взывавши": ["взывав"],
    "взыванье": ["взывание"],
    "взыграв": ["взыгравши"],
    "взыгравши": ["взыграв"],
    "взыгрывав": ["взыгрывавши"],
    "взыгрывавши": ["взыгрывав"],
    "взымав": ["взымавши"],
    "взымавши": ["взымав"],
    "взымание": ["взимание"],
    "взымать": ["взимать", "взыскивать", "собирать", "брать"],
    "взыск": ["взыскание"],
    "взыскав": ["взыскавши"],
    "взыскавши": ["взыскав"],
    "взыскание": ["взысканье", "взыск"],
    "взыскательно": ["придирчиво"],
    "взыскательный": ["требовательный"],
    "взыскивав": ["взыскивавши"],
    "взыскивавши": ["взыскивав"],
    "взыскующе": ["взыскательно"],
    "взыскующий": ["жаждущий", "ищущий"],
    "взявши": ["взяв"],
    "взятие": ["совлечение", "отторжение", "захват", "завоевание", "отбирание"],
    "взятка": ["подкуп", "леве"],
    "взяткодательство": ["коррупция"],
    "взяткополучатель": ["взяточник", "коррупционер", "коррумпант", "мздоимец"],
    "взяточник": ["мздоимец", "коррупционер"],
    "взяточничав": ["взяточничавши"],
    "взяточничавши": ["взяточничав"],
    "взяточничать": ["взяточничествовать"],
    "взяточничество": ["мздоимство"],
    "взяточничествовав": ["взяточничествовавши"],
    "взяточничествовавши": ["взяточничествовав"],
    "взяточничествовать": ["взяточничать"],
    "взять": ["схватить", "захватить", "поднять", "купить", "потребовать", "оккупировать", "прихватить", "увести", "увезти", "унести", "побить", "съесть", "принять", "отклониться"],
    "взять в оборот": ["взять за бока", "взять за горло", "взять за глотку", "взять за жабры", "за бока взять", "за горло взять", "за глотку взять", "за жабры взять", "взять за фаберже", "за фаберже взять", "взять за яйца", "взять за шкворень", "взять за жопу"],
    "взять верх": ["взять за верх"],
    "взять за жабры": ["прижать к стенке", "схватить за горло"],
    "взять за фаберже": ["взять за яйца", "взять за шкворень"],
    "взять за яйца": ["взять за фаберже", "взять за шкворень", "прищемить яйца", "за шкворень взять", "яйца прищемить"],
    "взять моду": ["найти моду"],
    "взять на абордаж": ["брать на абордаж"],
    "взять на галстук": ["на галстук взять"],
    "взять на заметку": ["взять на карандаш"],
    "взять на карандаш": ["взять на заметку"],
    "взять на клык": ["принять на клык", "на клык принять", "на клык взять"],
    "взять на прицел": ["брать на прицел", "под прицелом"],
    "взяться": ["схватиться", "заняться", "приступить", "появиться", "возникнуть"],
    "взяться за ум": ["поумнеть"],
    "ви-": ["про-"],
    "виабу": ["виабушник", "вап"],
    "виагра": ["силденафил"],
    "вибалок": ["балка"],
    "вибракування": ["вибраковування"],
    "вибратор": ["зуммер"],
    "вибрационный": ["вибрирующий"],
    "вибрационный пресс": ["вибропресс"],
    "вибрация": ["дрожание", "дрожь"],
    "вибрировав": ["вибрировавши"],
    "вибрировавши": ["вибрировав"],
    "вибрисса": ["усы", "усики"],
    "вибробетон": ["бетонная смесь"],
    "вибробункер": ["вибропитатель"],
    "вибромельница": ["вибрационная мельница"],
    "вибромолот": ["вибромолоток"],
    "вибропитатель": ["вибрационный питатель"],
    "вибропогружатель": ["вибрационный погружатель"],
    "вибропресс": ["вибрационный пресс"],
    "вибропрессовальный": ["вибропрессовочный"],
    "вибропрессовочный": ["вибропрессовальный"],
    "вибростимуляция": ["вибромассаж"],
    "вибростойкий": ["стойкий"],
    "виброхвост": ["риппер"],
    "вивав": ["вивавши"],
    "вивавши": ["вивав"],
    "виват": ["да здравствует"],
    "виваче": ["очень живо"],
    "виверна": ["виверн"],
    "виверра": ["цивета"],
    "вивиан": ["вивьен"],
    "вивипария": ["живорождение"],
    "вивисекция": ["живосечение", "насилие", "кровопускание"],
    "вивлиофика": ["библиотека"],
    "вивёр": ["кутила", "гуляка", "жуир"],
    "вигилант": ["виджилант"],
    "вигода": ["зиск", "користь"],
    "вигонь": ["викунья"],
    "вигук": ["крик", "викрик", "погук"],
    "вид": ["облик", "лик", "образ", "картина", "панорама", "поле зрения", "план", "тип", "класс", "разновидность", "категория"],
    "вид на жительство": ["внж"],
    "видав": ["видавши"],
    "видавши": ["видав"],
    "видавший виды": ["зрелый", "опытный", "бывалый", "матёрый", "тёртый", "изношенный", "потрёпанный", "старый", "поюзанный"],
    "видак": ["видеомагнитофон", "видик"],
    "видатний": ["визначний"],
    "видать": ["встречать", "видеть"],
    "видблянин": ["витебчанин", "витеблянин", "витебец"],
    "виде": ["аф мувору", "афкуксонь", "видексонь", "аф ёжу", "нюрьхкяня"],
    "видев": ["видевши"],
    "видевши": ["видев"],
    "видекс": ["виде", "афкукс", "аф ёру"],
    "видение": ["зрение", "смотрение", "восприятие", "воззрение"],
    "виденный": ["виданный"],
    "виденье": ["видение"],
    "видео": ["видос"],
    "видео-арт": ["видеоискусство"],
    "видеоадаптер": ["видеокарта", "видеоплата"],
    "видеоблог": ["влог"],
    "видеоблогер": ["влогер"],
    "видеовыход": ["видеоразъём"],
    "видеоданные": ["видеоинформация"],
    "видеодисплей": ["видеомонитор"],
    "видеодорожка": ["видеопоток"],
    "видеожокей": ["виджей"],
    "видеозал": ["видеосалон", "видеохолл"],
    "видеозапись": ["видеосъёмка", "видеоматериал", "видеоинформация", "видеоданные", "видеофильм"],
    "видеоигра": ["компьютерная игра"],
    "видеоинформация": ["видеоданные", "видеоматериал", "видеозапись"],
    "видеоискусство": ["видео-арт"],
    "видеокамера": ["кинокамера"],
    "видеоканал": ["телеканал", "видеоблог"],
    "видеокарта": ["видеоадаптер", "видеоплата", "видюха", "видяха"],
    "видеоклип": ["видеоролик", "клип"],
    "видеоклубничка": ["видеоэротика"],
    "видеокнига": ["видеокнижка"],
    "видеоконтроль": ["видеомониторинг", "видеонаблюдение"],
    "видеоконференцсвязь": ["вкс"],
    "видеомагнитофон": ["видак", "видик", "видюшник"],
    "видеоматериал": ["видео"],
    "видеомониторинг": ["видеоконтроль", "видеонаблюдение"],
    "видеонаблюдение": ["видеоконтроль", "видеомониторинг"],
    "видеообращение": ["видеообращенье"],
    "видеоокулограф": ["айтрекер"],
    "видеоотрывок": ["видеофрагмент"],
    "видеопират": ["писатель"],
    "видеоплата": ["видеоадаптер", "видеокарта"],
    "видеоплёнка": ["видеолента"],
    "видеоповтор": ["повтор"],
    "видеопорнография": ["видеопорнуха", "видеопорнушка"],
    "видеопроигрыватель": ["видеоплеер"],
    "видеосалон": ["видеозал"],
    "видеосвидетельство": ["видеодоказательство"],
    "видеостриминг": ["видеотрансляция"],
    "видеотерминал": ["терминал", "дисплей"],
    "видеотехнология": ["видеоинструментарий", "видеотехника"],
    "видеоторакоскопия": ["торакоскопия", "втс"],
    "видеотрейлер": ["трейлер"],
    "видеоустройство": ["видеотехника"],
    "видеофрагмент": ["видеоотрывок"],
    "видеоэндоскоп": ["видеоскоп"],
    "видеоэротика": ["видеоклубничка"],
    "видес": ["ваксс", "малас"],
    "видеса": ["ваксса", "маласа"],
    "видеста": ["эльбятьксфтома", "апак", "эльбядемс"],
    "видеть": ["зреть", "замечать", "видать", "лицезреть", "узревать", "считать", "думать", "полагать", "находить", "рассматривать", "смотреть", "усматривать"],
    "видеться": ["виднеться", "замечаться", "обнаруживаться", "наблюдаться", "встречаться"],
    "виджей": ["видеожокей"],
    "виджет": ["элемент", "управления", "интерфейса"],
    "видиво": ["видовище"],
    "видик": ["видеомагнитофон", "видак", "видачок", "видюшник", "видяшник", "видюшничек", "видяшничек", "видеофильм"],
    "видимо": ["зримо", "заметно", "ощутимо", "очевидно", "по-видимому", "вероятно", "видно", "похоже", "вроде как", "по-ходу"],
    "видимость": ["вид", "внешность", "фасад", "фикция", "кажимость", "маска", "зримость", "видность"],
    "видимый": ["очевидный", "явный", "кажущийся", "внешний", "обманчивый"],
    "видин": ["виддин"],
    "видингчек": ["виндингчек"],
    "виднев": ["видневши"],
    "видневши": ["виднев"],
    "видно": ["заметно", "понятно"],
    "видноколо": ["горизонт"],
    "виднокрай": ["горизонт"],
    "виднокруг": ["видноколо", "овид", "небокрай", "горизонт"],
    "видный": ["видимый", "заметный", "различимый", "выдающийся", "авторитетный", "знатный", "известный", "примечательный", "осанистый"],
    "виднёхонький": ["виднёшенький"],
    "виднёхонько": ["виднёшенько"],
    "виднёшенький": ["виднёхонький"],
    "виднёшенько": ["виднёхонько"],
    "видовище": ["видовисько"],
    "видоизменение": ["модификация"],
    "видоизменив": ["видоизменивши"],
    "видоизменивши": ["видоизменив"],
    "видоизменяв": ["видоизменявши"],
    "видоизменявши": ["видоизменяв"],
    "видоизменённый": ["изменённый", "модифицированный"],
    "видоискатель": ["визир"],
    "видос": ["видеоролик"],
    "видоспецифический": ["видоспецифичный"],
    "видоспецифичный": ["видоспецифический"],
    "видушник": ["видеомагнитофон", "видик", "видак", "видюшник", "видяшник"],
    "видывав": ["видывавши"],
    "видывавши": ["видывав"],
    "видюха": ["видеокарта", "видеоадаптер", "видеоплата", "видяха"],
    "видюшник": ["видеомагнитофон", "видик", "видушник", "видяшник"],
    "видяха": ["видеокарта", "видеоадаптер", "видеоплата", "видюха"],
    "видяшник": ["видеомагнитофон", "видик", "видушник", "видюшник"],
    "виела": ["фидель"],
    "виелица": ["вихър", "вихрушка", "буря", "вятър", "фурия"],
    "визави": ["оппонент", "собеседник"],
    "визажист": ["стилист"],
    "визажист-стилист": ["стилист-визажист"],
    "визант": ["бизант"],
    "византийская империя": ["византия", "восточная римская империя", "ромейская империя"],
    "византийщина": ["византизм", "византийство", "византинизм", "великолепие", "излишество", "напыщенность", "помпезность", "пышность", "роскошь", "роскошество"],
    "византинист": ["византист", "византолог"],
    "византинистика": ["византиноведение", "византология"],
    "византиноведение": ["византинистика"],
    "византист": ["византинист"],
    "византия": ["византийская империя", "восточная римская империя", "держава ромеев", "ромейская империя", "романия"],
    "византолог": ["византинист"],
    "визаран": ["бордерран"],
    "визг": ["визжание"],
    "визгля": ["крикун", "визгун", "пискун", "пискля"],
    "визгнув": ["визгнувши"],
    "визгнувши": ["визгнув"],
    "визжав": ["визжавши"],
    "визжавши": ["визжав"],
    "визжанье": ["визжание"],
    "визжать": ["верещать"],
    "визионер": ["духовидец", "ясновидящий", "мистик", "прорицатель", "фантаст", "провидец", "стратег"],
    "визионист": ["вуайерист"],
    "визионёрствовать": ["галлюцинировать", "фантазировать"],
    "визир": ["прицел", "видоискатель"],
    "визировав": ["визировавши"],
    "визировавши": ["визировав"],
    "визирование": ["подписывание", "подписывать", "прицеливание"],
    "визирь": ["вазир", "везир", "советник"],
    "визит": ["посещение"],
    "визитировав": ["визитировавши"],
    "визитировавши": ["визитировав"],
    "визитка": ["сюртук", "визитная карточка"],
    "визитная карточка": ["визитка"],
    "визитёр": ["посетитель", "гость"],
    "визор": ["забрало", "визир", "видоискатель"],
    "визуализатор": ["рендерер"],
    "визуализировав": ["визуализировавши"],
    "визуализировавши": ["визуализировав"],
    "визуализировать": ["визуализовать"],
    "визуализовав": ["визуализовавши"],
    "визуализовавши": ["визуализовав"],
    "визуализовать": ["визуализировать"],
    "визуальный": ["видимый", "зрительный", "внешний"],
    "вииши": ["вий", "эрьгя"],
    "вика": ["горошек"],
    "викентий": ["винцент", "винцентий"],
    "викжелив": ["викжеливши"],
    "викжеливши": ["викжелив"],
    "викжелить": ["викжелять"],
    "викжеляв": ["викжелявши"],
    "викжелявши": ["викжеляв"],
    "викжелять": ["викжелить"],
    "вики": ["сус"],
    "викинг": ["варяг", "норманн"],
    "википедик": ["википедист", "википидор"],
    "википедист": ["википедиец", "википедианец", "википедик"],
    "википедия": ["вп", "педивикия"],
    "википидор": ["википедист", "википедик"],
    "википроект": ["вики-проект"],
    "викисловарь": ["русский викисловарь"],
    "викифицировав": ["викифицировавши"],
    "викифицировавши": ["викифицировав"],
    "виконт": ["вице-граф"],
    "викругляти": ["викруглювати"],
    "виктимный": ["провокационный"],
    "виктория": ["победа", "успех", "удача"],
    "виктория-регия": ["виктория амазонская"],
    "викунья": ["вигонь"],
    "викхарита": ["виргхата"],
    "вилайет": ["ил", "иль", "вилаят", "велаят", "вилоят", "вилайа"],
    "вилами на воде": ["вилами по воде писано", "бабушка надвое сказала", "после дождичка в четверг", "когда рак на горе свистнет"],
    "вилами на воде писано": ["вилами по воде писано", "бабушка надвое сказала", "после дождичка в четверг", "на воде вилами писано"],
    "вилами по воде писано": ["вилами на воде писано", "бабушка надвое сказала"],
    "вилегодец": ["вилежанин"],
    "вилежанин": ["вилегодец"],
    "виленец": ["вильнюсец", "вильнянин", "вильневец", "вильневич"],
    "виленский": ["вильнюсский"],
    "вилия": ["дубовец"],
    "вилка": ["интервал", "диапазон", "границы"],
    "вилкавишкис": ["волковышки"],
    "вилкинз": ["вилкинс", "уилкинс"],
    "вилкинс": ["уилкинс", "вилкинз"],
    "вилковец": ["вилковчанин"],
    "вилковчанин": ["вилковец"],
    "вилла": ["коттедж"],
    "вилневич": ["виленец", "вильнюсец", "вильнянин"],
    "вилок": ["кочан"],
    "вилорог": ["вилорогая антилопа"],
    "вилохвостка": ["двухвостка", "ногохвостка", "коллембола"],
    "вилочка": ["вилочковая кость"],
    "вилочковая железа": ["тимус"],
    "вильгельм": ["уильям", "гийом"],
    "вильгорт": ["выльгорт"],
    "вильдграф": ["вальдграф"],
    "вильневец": ["вильнюсец", "виленец", "вильнянин"],
    "вильно": ["вильна"],
    "вильнув": ["вильнувши"],
    "вильнувши": ["вильнув"],
    "вильнуть": ["мотнуть", "повернуть", "свернуть"],
    "вильнюс": ["вильна", "вильно"],
    "вильнюсец": ["виленец", "вильнянин", "вильневец", "вильневич"],
    "вильнюсский": ["виленский"],
    "вильнянин": ["виленец", "вильневец", "вильнюсец"],
    "вильсон": ["уилсон"],
    "вильтшир": ["уилтшир", "вильтс"],
    "вильям": ["уильям"],
    "вильянди": ["феллин"],
    "вильяндинец": ["вильяндисец", "вельядец"],
    "вильяндисец": ["вильяндинец", "вельядец"],
    "вилюшка": ["вилюга", "извилина", "изворот", "увёртка"],
    "вилюшка вертячий": ["егоза", "вертячий чёрт", "змеиная векша", "голова вертячая"],
    "виляв": ["вилявши"],
    "вилявши": ["виляв"],
    "виляние": ["вихляние", "увиливание"],
    "вилянье": ["виляние"],
    "вилять": ["вихлять"],
    "вилять хвостом": ["увиливать", "заискивать", "угодничать"],
    "вимана": ["колесница", "дворец"],
    "вина": ["виновность", "причина"],
    "винагорода": ["винагородження"],
    "вингер": ["бровочник"],
    "винглет": ["шарклет", "саблет"],
    "винда": ["виндовоз", "шинда", "шиндовс"],
    "виндблок": ["виндстопер"],
    "виндинг чек": ["виндингчек"],
    "виндингчек": ["виндинг чек", "видингчек"],
    "виндовс": ["винда", "виндовоз", "виндоуз", "виндоус", "виндуза", "виндузина", "окошечки"],
    "виндроза": ["поворотный", "ветрячок"],
    "виндроуэр": ["лафетный", "жатка"],
    "виндстопер": ["виндблок"],
    "виндсёрфер": ["виндсёрф", "виндсёрфингист"],
    "виндсёрфингист": ["виндсёрфер"],
    "винегрет": ["мешанина", "ералаш", "микс", "коктейль"],
    "вини": ["пики"],
    "винив": ["винивши"],
    "винивши": ["винив"],
    "винил": ["грампластинка", "пластинка", "поливинилхлорид", "пвх"],
    "винилкожа": ["винилискожа", "дерматин"],
    "винилхлорид": ["хлорвинил", "хлористый винил", "хлорэтилен", "хлорэтен", "этиленхлорид"],
    "винительный": ["аккузативный", "аккузатив"],
    "винительный падеж": ["аккузатив"],
    "винить": ["обвинять", "укорять", "упрекать"],
    "виниться": ["каяться"],
    "винище": ["вино"],
    "винкель": ["винтель", "наугольник", "правило"],
    "винная кислота": ["диоксиянтарная кислота", "тартаровая кислота", "виннокаменная кислота"],
    "винницкая область": ["виннитчина"],
    "винно-водочный": ["алкогольный"],
    "винно-каменный": ["виннокаменный"],
    "винновый": ["пиковый"],
    "виннокаменный": ["винно-каменный"],
    "виннокислый": ["винограднокислый"],
    "винный камень": ["виннокислый калий", "битартрат калия", "крем тартар", "кремортартар", "кремор тартари"],
    "винный уксус": ["оцет", "виноградный уксус"],
    "вино": ["хлебное вино", "водка"],
    "виноватив": ["виновативши"],
    "виновативши": ["виноватив"],
    "виноватиться": ["виниться"],
    "виноватый": ["виновный", "повинный"],
    "виновность": ["вина", "виноватость"],
    "виновный": ["виноватый"],
    "виноградарство": ["виноделие"],
    "виноградовый": ["виноградный"],
    "виноградолечение": ["ампелотерапия"],
    "виноделие": ["винокурение"],
    "виноделье": ["виноделие"],
    "винодельный": ["винодельческий"],
    "винодельня": ["винокурня"],
    "винокур": ["самогонщик"],
    "винокурение": ["самогоноварение", "перегонка"],
    "винокурня": ["ликёро-водочный завод", "спиртзавод"],
    "винопотребление": ["алкоголепотребление"],
    "винотека": ["энотека", "коллекция вин"],
    "виночерпий": ["кравчий", "стольник"],
    "винт": ["болт", "пропеллер", "ротор", "резьба", "круговерть"],
    "винтаж": ["ретро"],
    "винтив": ["винтивши"],
    "винтивши": ["винтив"],
    "винтилово": ["арест", "задержание"],
    "винтить": ["ремонтировать", "чинить", "задерживать", "кружить", "кружиться", "крутить", "крутиться", "юлить", "скрываться", "прятаться", "вкручивать", "валить", "сваливать", "двигать", "смываться"],
    "винтовав": ["винтовавши"],
    "винтовавши": ["винтовав"],
    "винтовка": ["винтовальное ружьё", "винтарь"],
    "винтокрыл": ["гелиплан", "гиродин"],
    "винтообразно": ["спиралеобразно"],
    "винуватиця": ["винуватниця"],
    "винчестер": ["жёсткий диск", "винт"],
    "винчивав": ["винчивавши"],
    "винчивавши": ["винчивав"],
    "виньет": ["виньета"],
    "виньета": ["виньет"],
    "виньетировав": ["виньетировавши"],
    "виньетировавши": ["виньетировав"],
    "виньетка": ["заставка", "виньет", "виньета", "виньетирование"],
    "виола да гамба": ["виола"],
    "виолета": ["виолеточка", "виола", "вита", "вета", "вай"],
    "виолетта": ["виолетточка", "виола", "вита", "вета", "вай"],
    "виолончелистка": ["скрипачка"],
    "вип-персона": ["вип"],
    "випарита-карани": ["стойка на локтях"],
    "випаровування": ["випарування"],
    "випаровувач": ["випарник"],
    "випарування": ["випаровування"],
    "випереджати": ["переганяти"],
    "виперовый": ["гадюковый"],
    "виповский": ["привилегированный", "элитный"],
    "вир": ["водоворот", "омут", "ямина", "быстрина", "глубь", "вырь", "заверть", "водоверть", "водокруть", "суводь", "сувой", "сулой", "вороть", "куновороть", "крутень"],
    "вира": ["вергельд", "вина"],
    "вирабхадрасана": ["поза воина"],
    "виражив": ["вираживши"],
    "вираживши": ["виражив"],
    "виражировав": ["виражировавши"],
    "виражировавши": ["виражировав"],
    "виражить": ["виражировать"],
    "виразниця": ["висловниця"],
    "виракоча": ["кон-тикси-виракоча"],
    "виральный": ["вирусный"],
    "вирашиваизм": ["лингаята"],
    "вирбалис": ["вержболово", "вержболов"],
    "виргинец": ["вирджинец"],
    "виргиния": ["вирджиния"],
    "виргогамия": ["непорочное супружество", "девственный брак"],
    "виргхата": ["викхарита"],
    "вирджинал": ["вёрджинел"],
    "вирджиналист": ["вёрджинелист"],
    "вирджинец": ["виргинец"],
    "вирилизация": ["маскулинизация"],
    "вирильность": ["вирилизация"],
    "вирион": ["вироспора"],
    "вирировав": ["вирировавши"],
    "вирировавши": ["вирировав"],
    "вирмейкер": ["вирусописатель"],
    "вирмейкинг": ["вирмейкерство", "вирусописательство"],
    "вироглавщина": ["вироглавство", "упоритост", "твърдоглавие", "неотстъпчивост", "непослушание"],
    "виртуал": ["вирт"],
    "виртуализировав": ["виртуализировавши"],
    "виртуализировавши": ["виртуализировав"],
    "виртуализировать": ["виртуализовать"],
    "виртуализироваться": ["виртуализоваться"],
    "виртуализовав": ["виртуализовавши"],
    "виртуализовавши": ["виртуализовав"],
    "виртуализовать": ["виртуализировать"],
    "виртуализоваться": ["виртуализироваться"],
    "виртуальная реальность": ["виртуальность", "вр", "виртуал", "виртуалка", "киберпространство"],
    "виртуальный": ["потенциальный", "мысленный", "воображаемый", "нереальный", "симулированный", "эмулированный", "эффективный"],
    "виртуальный мир": ["виртуальная реальность", "всемирная паутина"],
    "виртуальный секс": ["вирт"],
    "виртуоз": ["мастер", "ас", "мастак"],
    "виртуозка": ["искусница", "мастачка", "умелица"],
    "виртуозничав": ["виртуозничавши"],
    "виртуозничавши": ["виртуозничав"],
    "виртуозность": ["мастерство"],
    "виртуозный": ["артистический", "искусный", "ловкий"],
    "виртуозша": ["виртуозка"],
    "вирулентный": ["патогенный", "заразный"],
    "вирус": ["компьютерный вирус", "малварь", "зараза"],
    "вирус иммунодефицита человека": ["вич"],
    "вирус папилломы человека": ["впч", "папилломавирус"],
    "вирусняк": ["вирус", "вирусяка"],
    "вирусописатель": ["вирмейкер"],
    "вирусописательство": ["вирмейкерство", "вирмейкинг"],
    "вирш": ["вирша", "стих", "стихотворение", "стихи"],
    "вирша": ["вирш", "стих", "стихотворение", "стихи"],
    "виршеплёт": ["версификатор"],
    "виршеплётство": ["версификаторство", "стихоплётство", "рифмоплётство"],
    "вирь тракс": ["сярда"],
    "висагинас": ["снечкус"],
    "висев": ["висевши"],
    "висевши": ["висев"],
    "виселица": ["шибеница", "рели", "верёвка", "петля"],
    "висельник": ["удавленник", "преступник", "негодяй", "мерзавец"],
    "висельница": ["виселица", "шибеница"],
    "висенье": ["висение"],
    "висеть": ["выдаваться", "нависать", "выситься", "свешиваться"],
    "висеть на нитке": ["висеть на волоске"],
    "висина": ["височина", "висота", "издигнатина"],
    "виски": ["вискарь", "вискарик", "вискарёк"],
    "вискоза": ["искусственный шёлк"],
    "висла": ["вистула"],
    "вислизати": ["вислизнути"],
    "вислинец": ["вислянин"],
    "вислинка": ["вислянка"],
    "висловниця": ["виразниця"],
    "вислоухий": ["глуповатый", "простоватый"],
    "вислый": ["отвислый"],
    "вислянин": ["вислинец"],
    "вислянка": ["вислинка"],
    "висмутин": ["висмутинит"],
    "виснув": ["виснувши"],
    "виснувши": ["виснув"],
    "виснуть": ["свисать", "свешиваться", "тормозить"],
    "високошановний": ["вельмишановний"],
    "височезний": ["височенний"],
    "височенний": ["височезний"],
    "виссарионович": ["виссарионыч"],
    "виссон": ["биссус"],
    "вистерия": ["глициния"],
    "вистовав": ["вистовавши"],
    "вистовавши": ["вистовав"],
    "висула": ["висла"],
    "висцеральный": ["внутренностный", "внутренний"],
    "висцероптоз": ["спланхноптоз", "энтероптоз"],
    "висцерорецептор": ["интерорецептор", "интероцептор", "проприорецептор", "соматорецептор"],
    "висюлька": ["подвеска"],
    "висяк": ["висячее дело", "глухое дело", "висячка", "глухарь", "нестояк", "нестоякевич", "нестоячка"],
    "висячий": ["подвесной", "висячка"],
    "висячка": ["висяк", "глухарь", "висячее дело", "глухое дело"],
    "вита": ["бета"],
    "витав": ["витавши"],
    "витавши": ["витав"],
    "витализация": ["оживление"],
    "витализировав": ["витализировавши"],
    "витализировавши": ["витализировав"],
    "виталина": ["вита", "лина"],
    "виталия": ["вита"],
    "витальевич": ["виталиевич"],
    "витальность": ["жизнеспособность"],
    "витальный": ["жизненный"],
    "витаминизировав": ["витаминизировавши"],
    "витаминизировавши": ["витаминизировав"],
    "витаминизирование": ["витаминизация"],
    "витаминность": ["витаминозность"],
    "витаминный": ["витаминовый", "витаминозный"],
    "витаминовый": ["витаминный", "витаминозный"],
    "витаминозность": ["витаминность"],
    "витаминозный": ["витаминный", "витаминовый"],
    "витанье": ["витание"],
    "витасфера": ["биогеосфера"],
    "витать": ["парить"],
    "витать в облаках": ["строить воздушные замки", "уноситься в облака"],
    "витвереження": ["витвережування"],
    "витебец": ["витеблянин", "витебчанин", "видблянин"],
    "витеблянин": ["витебец", "витебчанин"],
    "витебчанин": ["витебец", "витеблянин"],
    "витебчанка": ["витеблянка"],
    "витекс священный": ["целомудренник", "авраамово дерево", "монашеский перец"],
    "вителлин": ["ововителлин"],
    "витенька": ["витя", "виктор"],
    "витерит": ["бария карбонат"],
    "витиевато": ["замысловато", "затейливо", "вычурно"],
    "витиеватость": ["цветистость"],
    "витиеватый": ["замысловатый"],
    "витийство": ["красноречие"],
    "витийствовав": ["витийствовавши"],
    "витийствовавши": ["витийствовав"],
    "витийствовать": ["ораторствовать"],
    "витикультура": ["виноградарство"],
    "витилиго": ["лейкодерма"],
    "вития": ["оратор", "ритор", "златоуст", "краснобай"],
    "витло": ["бурма", "винт"],
    "витовкмачити": ["витлумачити"],
    "витой": ["скрученный", "кручёный", "переплетённый", "винтообразный", "спиральный", "спиралеобразный"],
    "виток": ["этап"],
    "витория": ["виктория", "витория-гастейс"],
    "витребенька": ["вигадка", "примха", "забаганка"],
    "витрификация": ["стеклование"],
    "витрифицировав": ["витрифицировавши"],
    "витрифицировавши": ["витрифицировав"],
    "витрифицировать": ["остекловывать", "остекловать", "остекленить"],
    "виттенбержец": ["лютерштадтец"],
    "витька": ["витёк"],
    "витьё": ["свивание"],
    "витютень": ["вяхирь"],
    "витязь": ["богатырь", "воитель"],
    "витёк": ["витька"],
    "вифиния": ["бебрикия"],
    "вифлеем": ["бейт-лахм", "бейт-лехем"],
    "вифлеемец": ["байтлахмец", "бейтлахмец", "вифлеемлянин"],
    "вифлеемлянин": ["вифлеемец"],
    "вифлеемлянка": ["вифлеемка"],
    "вихвалювати": ["вихваляти", "вихвалити"],
    "вихляв": ["вихлявши"],
    "вихлявши": ["вихляв"],
    "вихляй": ["джек"],
    "вихляние": ["вихлянье"],
    "вихлянье": ["вихляние"],
    "вихователь": ["виховач", "виховник"],
    "виховач": ["вихователь", "виховник"],
    "виховниця": ["вихователька"],
    "вихор": ["вихорок", "вихорочек", "вихорчик", "кок"],
    "вихорив": ["вихоривши"],
    "вихоривши": ["вихорив"],
    "вихорчик": ["вихорок"],
    "вихорь": ["вихрь"],
    "вихрастый": ["растрёпанный"],
    "вихревой ток": ["ток фуко"],
    "вихреобразный": ["вихреподобный"],
    "вихреподобный": ["вихреобразный"],
    "вихрив": ["вихривши"],
    "вихривши": ["вихрив"],
    "вихриться": ["завихряться", "взвихряться"],
    "вихрушка": ["вихър", "буря", "виелица", "вятър", "фъртуна"],
    "вихрь": ["циклон", "ротор"],
    "виц": ["анекдот", "смехория"],
    "вица": ["прут", "хворостина", "розга", "лоза", "лозина"],
    "вице-губернатор": ["лейтенант-губернатор"],
    "вице-председатель": ["президент"],
    "вице-президент": ["второе лицо"],
    "вице-сержант": ["вице-старшина"],
    "вице-старшина": ["вице-сержант"],
    "вицилин": ["глобулин", "вилоксазин", "вивалан", "виварит", "эмовит"],
    "вициналь": ["вицинальная пирамида"],
    "вицинальный": ["смежный", "соседний", "геминальный"],
    "вич": ["вирус иммунодефицита человека", "спид"],
    "вич-анализ": ["вич-тест"],
    "вич-инфицированный": ["вич-позитивный", "вич-носитель"],
    "вич-носитель": ["вич-инфицированный"],
    "вич-позитивный": ["вич-инфицированный"],
    "вич-тест": ["вич-анализ"],
    "вичерпний": ["вичерпливий", "повний"],
    "вичуговец": ["вичужанин"],
    "вичужанин": ["вичуговец"],
    "вишенка": ["вишня"],
    "вишенник": ["вишняк", "ивишенник", "ивишень", "подвишенник", "клитопилус"],
    "вишенный": ["вишнёвый"],
    "вишерец": ["маловишерец"],
    "вишерята": ["вишерцы"],
    "вишийский": ["вишистский"],
    "вишистский": ["вишийский"],
    "вишневев": ["вишневевши"],
    "вишневевши": ["вишневев"],
    "вишну": ["венкатешвара"],
    "вишнуизм": ["вайшнавизм"],
    "вишнуит": ["вишнаит"],
    "вишняк": ["вишенник", "ивишенник", "ивишень", "подвишенник"],
    "вишь": ["во как", "во", "вот", "видишь ли", "видите ли"],
    "вищиряти": ["ощиряти"],
    "вказувати": ["указувати"],
    "вкалывав": ["вкалывавши"],
    "вкалывавши": ["вкалывав"],
    "вкапав": ["вкапавши"],
    "вкапавши": ["вкапав"],
    "вкапнув": ["вкапнувши"],
    "вкапнувши": ["вкапнув"],
    "вкапывав": ["вкапывавши"],
    "вкапывавши": ["вкапывав"],
    "вкапывание": ["закапывание"],
    "вкапыванье": ["вкапывание"],
    "вкатав": ["вкатавши"],
    "вкатавши": ["вкатав"],
    "вкатив": ["вкативши"],
    "вкативши": ["вкатив"],
    "вкатнув": ["вкатнувши"],
    "вкатнувши": ["вкатнув"],
    "вкатывав": ["вкатывавши"],
    "вкатывавши": ["вкатывав"],
    "вкатывать": ["закатывать", "вкатываться", "въезжать"],
    "вкатываться": ["закатываться"],
    "вкачав": ["вкачавши"],
    "вкачавши": ["вкачав"],
    "вкачивав": ["вкачивавши"],
    "вкачивавши": ["вкачивав"],
    "вкачивание": ["закачивание", "накачивание", "вливание"],
    "вкачивать": ["закачивать"],
    "вкидав": ["вкидавши"],
    "вкидавши": ["вкидав"],
    "вкидывав": ["вкидывавши"],
    "вкидывавши": ["вкидывав"],
    "вкидываться": ["закидываться"],
    "вкинув": ["вкинувши"],
    "вкинувши": ["вкинув"],
    "вклад": ["вкладывание", "вложение", "депозит", "взнос", "лепта", "роль", "участие"],
    "вкладиш": ["вкладка"],
    "вкладывав": ["вкладывавши"],
    "вкладывавши": ["вкладывав"],
    "вкладыш": ["вкладка"],
    "вклеив": ["вклеивши"],
    "вклеивав": ["вклеивавши"],
    "вклеивавши": ["вклеивав"],
    "вклеивши": ["вклеив"],
    "вклейка": ["вклеивание"],
    "вклепав": ["вклепавши"],
    "вклепавши": ["вклепав"],
    "вклепаться": ["вляпаться", "обознаться"],
    "вклинение": ["вклинивание"],
    "вклинив": ["вклинивши"],
    "вклинивав": ["вклинивавши"],
    "вклинивавши": ["вклинивав"],
    "вклинивание": ["вклинение"],
    "вклиниваться": ["вдаваться", "втискиваться", "вторгаться", "вмешиваться"],
    "вклинивши": ["вклинив"],
    "вклиняв": ["вклинявши"],
    "вклинявши": ["вклиняв"],
    "включав": ["включавши"],
    "включавши": ["включав"],
    "включать дурака": ["дурака включать"],
    "включаться": ["исключаться", "отключаться", "выключаться"],
    "включенье": ["включение"],
    "включив": ["включивши"],
    "включивши": ["включив"],
    "включить": ["добавить"],
    "включить дурака": ["включить дуру", "включить дурочку"],
    "включить мозг": ["включить мозги"],
    "включённость": ["причастность"],
    "включённый": ["подключённый", "соединённый", "врубленный"],
    "вклёпывав": ["вклёпывавши"],
    "вклёпывавши": ["вклёпывав"],
    "вковав": ["вковавши"],
    "вковавши": ["вковав"],
    "вковаться": ["принарядиться", "приодеться"],
    "вковывав": ["вковывавши"],
    "вковывавши": ["вковывав"],
    "вкол": ["укол", "инъекция"],
    "вколачивав": ["вколачивавши"],
    "вколачивавши": ["вколачивав"],
    "вколачивание": ["вбивание", "забивка"],
    "вколачивать": ["вбивать", "вдалбливать"],
    "вколов": ["вколовши"],
    "вколовши": ["вколов"],
    "вколотив": ["вколотивши"],
    "вколотивши": ["вколотив"],
    "вкомкав": ["вкомкавши"],
    "вкомкавши": ["вкомкав"],
    "вкомпоновав": ["вкомпоновавши"],
    "вкомпоновавши": ["вкомпоновав"],
    "вкомпоновывав": ["вкомпоновывавши"],
    "вкомпоновывавши": ["вкомпоновывав"],
    "вконец": ["совершенно", "совсем", "окончательно", "в корень", "вдокон", "до корня", "водерень", "вдовень", "вовсе", "без остатка", "дотла"],
    "вконтакт": ["контакт", "вконтакте", "вк"],
    "вкопав": ["вкопавши"],
    "вкопавши": ["вкопав"],
    "вкопка": ["вкапывание"],
    "вкоренив": ["вкоренивши"],
    "вкоренивши": ["вкоренив"],
    "вкоренившийся": ["укоренившийся"],
    "вкорениться": ["укорениться"],
    "вкореняв": ["вкоренявши"],
    "вкоренявши": ["вкореняв"],
    "вкоренять": ["укоренять"],
    "вкорочувати": ["укорочувати"],
    "вкось": ["косо", "наискось", "вкривь"],
    "вкраивав": ["вкраивавши"],
    "вкраивавши": ["вкраивав"],
    "вкрапив": ["вкрапивши"],
    "вкрапивши": ["вкрапив"],
    "вкрапление": ["включение", "примешивание", "внедрение", "вкапывание", "примесь"],
    "вкрапленник": ["вкрапление", "фенокрист", "фенокристалл"],
    "вкрапленье": ["вкрапление"],
    "вкрапливав": ["вкрапливавши"],
    "вкрапливавши": ["вкрапливав"],
    "вкрапливать": ["вкраплять"],
    "вкрапляв": ["вкраплявши"],
    "вкраплявши": ["вкрапляв"],
    "вкраплять": ["вкрапливать"],
    "вкрапляться": ["вкрапливаться"],
    "вкратце": ["кратко", "конспективно"],
    "вкрашиться": ["закрашиться", "втюриться", "втрескаться"],
    "вкрепив": ["вкрепивши"],
    "вкрепивши": ["вкрепив"],
    "вкрепляв": ["вкреплявши"],
    "вкреплявши": ["вкрепляв"],
    "вкривь и вкось": ["беспорядочно", "вкось и вкривь", "вкривь-вкось", "неправильно", "неверно", "небрежно", "как попало", "как придётся", "как-нибудь", "как бог на душу положит", "шиворот-навыворот", "сикось-накось", "вкось да перекось", "превратно", "вкось и впрямь"],
    "вкроив": ["вкроивши"],
    "вкроивши": ["вкроив"],
    "вкруг": ["вокруг"],
    "вкрутив": ["вкрутивши"],
    "вкрутивши": ["вкрутив"],
    "вкрутиться": ["ввернуться", "ввинтиться"],
    "вкрутую": ["в гору"],
    "вкручивав": ["вкручивавши"],
    "вкручивавши": ["вкручивав"],
    "вкручивать": ["вворачивать"],
    "вкручиваться": ["ввёртываться", "ввинчиваться", "вворачиваться"],
    "вкс": ["воздушно-космические силы", "военно-космические силы", "воздушно-космический самолёт", "мвкс", "орбитальный самолёт", "воздушно-космический летательный аппарат"],
    "вкупе": ["вместе", "в совокупности", "сообща", "совместно"],
    "вкурив": ["вкуривши"],
    "вкуривав": ["вкуривавши"],
    "вкуривавши": ["вкуривав"],
    "вкуривать": ["врубаться", "догонять", "сечь", "улавливать"],
    "вкуривши": ["вкурив"],
    "вкусив": ["вкусивши"],
    "вкусивши": ["вкусив"],
    "вкусить": ["отведать", "испытать", "ощутить", "пережить", "изведать"],
    "вкусна как земляника": ["что малина"],
    "вкусненькое": ["вкусность", "вкусняшка"],
    "вкусно": ["лакомо", "смачно"],
    "вкуснота": ["вкуснятина", "вкуснотища", "вкуснотень"],
    "вкуснотень": ["вкуснятина", "вкуснота"],
    "вкуснотища": ["вкуснятина"],
    "вкусный": ["смачный", "деликатесный", "аппетитный", "красочный"],
    "вкуснямба": ["вкусняшка"],
    "вкуснятина": ["вкуснота"],
    "вкуснятинка": ["вкусняшечка"],
    "вкусняха": ["вкусняшка", "лакомство", "вкусность", "вкуснота", "вкуснятина"],
    "вкусняшка": ["лакомство", "вкусность", "вкуснота", "вкуснятина", "вкусняха"],
    "вкусняшный": ["вкусный"],
    "вкусовщина": ["субъективность", "пристрастность"],
    "вкушав": ["вкушавши"],
    "вкушавши": ["вкушав"],
    "вкушать": ["есть", "кушать", "снедать", "испытывать", "изведывать", "ощущать"],
    "вкушенье": ["вкушение"],
    "влага": ["вода"],
    "влагав": ["влагавши"],
    "влагавши": ["влагав"],
    "влагалище": ["ножны"],
    "влагалищный": ["вагинальный"],
    "влагозащищённый": ["влагонепроницаемый", "влагостойкий", "водонепроницаемый", "водостойкий", "водоупорный", "непромокаемый"],
    "влагоизоляция": ["влагозащита", "гидроизоляция"],
    "влаголюбивость": ["гигрофильность"],
    "влагомер": ["психрометр", "гигрометр"],
    "влагоотталкивающий": ["водоотталкивающий"],
    "влагорегулятор": ["гигростат", "гумидистат"],
    "влагоёмкий": ["водопоглощающий"],
    "влад": ["владислав"],
    "владав": ["владавши"],
    "владавши": ["владав"],
    "владев": ["владевши"],
    "владевши": ["владев"],
    "владелец": ["владетель", "хозяин", "собственник", "обладатель", "властитель", "господин", "барин"],
    "владельческий": ["хозяйский", "собственнический"],
    "владение": ["обладание"],
    "владенье": ["владение"],
    "владетель": ["владыка", "властелин", "властитель", "государь", "монарх", "повелитель", "правитель", "феодал", "владелец", "хозяин"],
    "владеть": ["обладать", "иметь", "распоряжаться"],
    "владеть собой": ["сохранять самообладание"],
    "владивостокец": ["владивостоковец"],
    "владивостоковец": ["владивостокец"],
    "владивостокский городской округ": ["вго"],
    "владик": ["владислав"],
    "владикавказ": ["орджоникидзе", "дзауджикау"],
    "владикавказец": ["орджоникидзевец"],
    "владимира": ["мира"],
    "владимирец": ["володимирец", "володимерец"],
    "владимировец": ["ахтубинец"],
    "владимирская область": ["владимирщина"],
    "владислав": ["ласло"],
    "владыка": ["повелитель", "властелин", "властитель", "господин", "архиерей"],
    "владычество": ["суверенитет"],
    "владычествовав": ["владычествовавши"],
    "владычествовавши": ["владычествовав"],
    "владычица": ["правительница"],
    "влажнев": ["влажневши"],
    "влажневши": ["влажнев"],
    "влажнеть": ["намокать"],
    "влажник": ["влажный корм", "консервы"],
    "влажно": ["сыро", "мокро"],
    "влажность": ["мокрость", "сырость"],
    "влажный": ["сырой", "мокрый"],
    "влазив": ["влазивши"],
    "влазивши": ["влазив"],
    "влазить": ["влезать", "залазить", "залезать"],
    "влак": ["железница", "трен"],
    "вламывав": ["вламывавши"],
    "вламывавши": ["вламывав"],
    "вламываться": ["врываться"],
    "влас": ["власий"],
    "власинка": ["косъм", "косъмче", "влакно", "влакънце"],
    "власниця": ["владниця", "властителька"],
    "властвовав": ["властвовавши"],
    "властвовавши": ["властвовав"],
    "властелин": ["владетель", "повелитель", "владыка"],
    "власти предержащие": ["власть имущие"],
    "властитель": ["властелин", "монарх", "инфлюэнсер"],
    "властник": ["владетел", "властелин", "повелител"],
    "властолюбец": ["властолюб"],
    "властолюбивость": ["властолюбие"],
    "властолюбивый": ["властный"],
    "властолюбие": ["любоначалие"],
    "властолюбье": ["властолюбие"],
    "власть": ["сила", "полномочие", "господство"],
    "власть имущие": ["власти предержащие"],
    "власяница": ["рубище", "вретище"],
    "влах": ["румънец"],
    "влачив": ["влачивши"],
    "влачивши": ["влачив"],
    "влачить": ["волочить", "волочь", "влечь"],
    "влаштувати": ["улаштувати"],
    "влеве": ["слева"],
    "влево": ["налево", "слева", "по левую сторону", "влеве", "ошуюю"],
    "влегав": ["влегавши"],
    "влегавши": ["влегав"],
    "влезав": ["влезавши"],
    "влезавши": ["влезав"],
    "влезать": ["взбираться", "забираться", "проникать", "надевать", "натягивать", "влипать"],
    "влезть": ["взобраться", "проникнуть", "протиснуться", "встрять"],
    "влезть в душу": ["залезть в душу"],
    "влекущий": ["привлекающий", "притягивающий"],
    "влепив": ["влепивши"],
    "влепивши": ["влепив"],
    "влепливав": ["влепливавши"],
    "влепливавши": ["влепливав"],
    "влепляв": ["влеплявши"],
    "влеплявши": ["влепляв"],
    "влетав": ["влетавши"],
    "влетавши": ["влетав"],
    "влетев": ["влетевши"],
    "влетевши": ["влетев"],
    "влететь": ["вбежать", "достаться", "попасть", "нагореть", "получить"],
    "влететь в копеечку": ["ударить по карману"],
    "влечение": ["тяга", "наклонность", "склонность"],
    "влеченье": ["влечение"],
    "влечь": ["влачить", "волочить", "тащить", "тянуть", "манить", "притягивать", "привлекать", "увлекать", "приводить", "вызывать"],
    "влив": ["вливши"],
    "вливав": ["вливавши"],
    "вливавши": ["вливав"],
    "вливание": ["наливание"],
    "вливанье": ["вливание"],
    "вливши": ["влив"],
    "влипав": ["влипавши"],
    "влипавши": ["влипав"],
    "влипнув": ["влипнувши"],
    "влипнувши": ["влипнув"],
    "влияв": ["влиявши"],
    "влиявши": ["влияв"],
    "влияние": ["воздействие", "эффект", "авторитет", "вес", "влиятельность", "связи", "сила"],
    "влиятельный": ["авторитетный", "важный"],
    "влиять": ["обуславливать", "воздействовать"],
    "влксм": ["комсомол", "рксм"],
    "влог": ["видеоблог"],
    "влогер": ["видеоблогер"],
    "влогерша": ["видеоблогерша"],
    "вложение": ["вкладывание"],
    "вложив": ["вложивши"],
    "вложивши": ["вложив"],
    "вложить душу": ["одухотворить", "постараться"],
    "влом": ["вломак", "лень", "ломать"],
    "вломив": ["вломивши"],
    "вломивши": ["вломив"],
    "вломить": ["ударить", "избить", "жахнуть", "наказать", "взгреть"],
    "вломиться": ["ворваться"],
    "влопаться": ["попасть впросак", "попасться", "вляпаться", "влюбиться", "втюриться"],
    "влтава": ["молдава"],
    "влупив": ["влупивши"],
    "влупивши": ["влупив"],
    "влучення": ["улучення"],
    "влчак": ["волкособ"],
    "влъхва": ["мъдрец", "сановник", "гадател", "хитрец"],
    "влюбив": ["влюбивши"],
    "влюбивши": ["влюбив"],
    "влюбиться": ["втюриться", "очароваться"],
    "влюбленье": ["влюбление"],
    "влюбляв": ["влюблявши"],
    "влюблявши": ["влюбляв"],
    "влюблённый": ["любящий"],
    "влягти": ["улягти"],
    "вляпав": ["вляпавши"],
    "вляпавши": ["вляпав"],
    "вляпывав": ["вляпывавши"],
    "вляпывавши": ["вляпывав"],
    "вляпываться": ["влипать", "влопываться"],
    "влёжку": ["лёжа", "лежмя"],
    "вмазав": ["вмазавши"],
    "вмазавши": ["вмазав"],
    "вмазка": ["вмазывание"],
    "вмазывав": ["вмазывавши"],
    "вмазывавши": ["вмазывав"],
    "вмазываться": ["втираться", "влезать без мыла", "колоться", "ширять", "ширяться", "влюбляться"],
    "вмастив": ["вмастивши"],
    "вмастивши": ["вмастив"],
    "вматывав": ["вматывавши"],
    "вматывавши": ["вматывав"],
    "вмв": ["вторая мировая война"],
    "вменив": ["вменивши"],
    "вменивши": ["вменив"],
    "вменить": ["поставить"],
    "вменяв": ["вменявши"],
    "вменявши": ["вменяв"],
    "вменяемый": ["адекватный", "разумный", "понятливый", "понятный", "толковый"],
    "вменять": ["ставить", "приписывать"],
    "вмерзав": ["вмерзавши"],
    "вмерзавши": ["вмерзав"],
    "вмесив": ["вмесивши"],
    "вмесивши": ["вмесив"],
    "вместе": ["сообща", "совместно", "скопом", "в то же время", "одновременно"],
    "вместив": ["вместивши"],
    "вместивши": ["вместив"],
    "вместилище": ["контейнер", "ёмкость", "полость"],
    "вместимость": ["вмещаемость", "ёмкость"],
    "вместительность": ["вместимость"],
    "вместительный": ["ёмкий", "поместительный"],
    "вместить": ["поместить", "уместить", "заключить"],
    "вместиться": ["поместиться", "уместиться", "войти"],
    "вместо": ["взамен", "заместо"],
    "вметав": ["вметавши"],
    "вметавши": ["вметав"],
    "вметнув": ["вметнувши"],
    "вметнувши": ["вметнув"],
    "вмешав": ["вмешавши"],
    "вмешавши": ["вмешав"],
    "вмешаться": ["ввязаться", "сунуться", "втесаться", "втереться", "замешаться", "смешаться", "затеряться", "вступить"],
    "вмешивав": ["вмешивавши"],
    "вмешивавши": ["вмешивав"],
    "вмешивать": ["примешивать", "впутывать", "вовлекать"],
    "вмешиваться": ["встревать", "соваться", "совать нос", "мешаться"],
    "вмещав": ["вмещавши"],
    "вмещавши": ["вмещав"],
    "вмещаться": ["умещаться", "помещаться"],
    "вмещение": ["размещение"],
    "вмиг": ["мгновенно", "мигом", "моментально", "молниеносно", "сразу", "тотчас"],
    "вминав": ["вминавши"],
    "вминавши": ["вминав"],
    "вминать": ["вжимать"],
    "вмн": ["вмсз", "высшая мера социальной защиты", "смертная казнь"],
    "вмовляти": ["умовляти"],
    "вмонтировав": ["вмонтировавши"],
    "вмонтировавши": ["вмонтировав"],
    "вмораживав": ["вмораживавши"],
    "вмораживавши": ["вмораживав"],
    "вморозив": ["вморозивши"],
    "вморозивши": ["вморозив"],
    "вмотав": ["вмотавши"],
    "вмотавши": ["вмотав"],
    "вмочив": ["вмочивши"],
    "вмочивши": ["вмочив"],
    "вмс": ["вмф"],
    "вмуровав": ["вмуровавши"],
    "вмуровавши": ["вмуровав"],
    "вмуровывав": ["вмуровывавши"],
    "вмуровывавши": ["вмуровывав"],
    "вмф": ["вмс"],
    "вмывав": ["вмывавши"],
    "вмывавши": ["вмывав"],
    "вмяв": ["вмявши"],
    "вмявши": ["вмяв"],
    "вмятина": ["выбоина"],
    "вмятость": ["вогнутость", "вмятина"],
    "вмёрзнув": ["вмёрзнувши"],
    "вмёрзнувши": ["вмёрзнув"],
    "вмётывав": ["вмётывавши"],
    "вмётывавши": ["вмётывав"],
    "внаброску": ["внакидку", "внапашку", "внаброс"],
    "внавал": ["внавалку", "беспорядочно", "полно"],
    "внаймы": ["внаём"],
    "внакладе": ["в убытке"],
    "внаклонку": ["наклонившись", "нагнувшись", "согнувшись", "приклонившись", "скосившись", "покосившись"],
    "внапашку": ["внакидку", "внаброску"],
    "внаружу": ["наружу", "вовне", "изнутри"],
    "внатяжку": ["в натяг"],
    "внахлёст": ["внахлёстку"],
    "внахлёстку": ["внахлёст"],
    "вначале": ["первое время", "в первое время", "сначала", "поначалу", "сперва", "прежде"],
    "вне": ["вовне", "снаружи"],
    "вне игры": ["офсайд"],
    "вне-": ["экзо-"],
    "внебалансовый": ["забалансовый"],
    "вневременный": ["вневременной"],
    "внегонадный": ["экстрагонадный"],
    "внедорожник": ["вездеход", "кроссовер"],
    "внедорожный": ["вездеходный"],
    "внедрение": ["введение", "насаждение", "интрузия", "имплантация", "автоинтрузия", "укоренение", "инъекция", "инвагинация", "сеяние", "ввод"],
    "внедрив": ["внедривши"],
    "внедривши": ["внедрив"],
    "внедряв": ["внедрявши"],
    "внедрявши": ["внедряв"],
    "внедрять": ["вводить", "укоренять"],
    "внезапно": ["неожиданно", "вдруг", "внезапу"],
    "внезапность": ["неожиданность"],
    "внезапный": ["неожиданный", "скоропостижный", "непредсказуемый", "непредвиденный", "нечаянный"],
    "внезапу": ["внезапно", "неожиданно", "вдруг"],
    "внеземной": ["инопланетный"],
    "внекабинный": ["наружный"],
    "внеклассовый": ["надклассовый"],
    "внеклеточный матрикс": ["вкм"],
    "внекоитальный": ["некопуляционный"],
    "внекорабельная деятельность": ["вкд"],
    "внелингвистический": ["экстралингвистический"],
    "внелогический": ["нелогичный"],
    "внемленный": ["услышанный"],
    "внемурманский": ["немурманский", "внекольский"],
    "внеплацентарный": ["экстраплацентарный"],
    "внеплодник": ["экзокарпий"],
    "внеправительственный": ["неправительственный"],
    "внеславянский": ["неславянский"],
    "внеслужебность": ["неофициальность"],
    "внесуставной": ["внесуставный"],
    "внесуставный": ["внесуставной"],
    "внеурочный": ["внеклассный", "сверхурочный"],
    "внеутробный": ["постнатальный"],
    "внецензурный": ["неподцензурный"],
    "внечувственный": ["экстрасенсорный"],
    "внешка": ["внешпол"],
    "внешне": ["с виду"],
    "внешнее независимое оценивание": ["вно", "зно"],
    "внешний": ["наружный", "сторонний", "поверхностный"],
    "внешний вид": ["внешность", "облик", "обличие", "обличье", "наружность", "видимость", "экстерьер"],
    "внешний эффект": ["экстерналия"],
    "внешность": ["наружность", "вид", "оболочка", "внешка"],
    "внешняя политика": ["внешпол"],
    "внешпол": ["внешняя политика", "внешка"],
    "внеэмоциональность": ["бесстрастность"],
    "внеэтичный": ["аморальный", "безнравственный"],
    "внеязыковой": ["внеязыковый", "экстралингвистический"],
    "внеязыковый": ["внеязыковой", "экстралингвистический"],
    "вниз": ["книзу"],
    "внизу": ["снизу"],
    "вникав": ["вникавши"],
    "вникавши": ["вникав"],
    "вникание": ["вникновение"],
    "вниканье": ["вникание"],
    "вникать": ["въезжать"],
    "вникновение": ["вникание"],
    "вникнув": ["вникнувши"],
    "вникнувши": ["вникнув"],
    "внимав": ["внимавши"],
    "внимавши": ["внимав"],
    "внимание": ["сосредоточенность", "сфокусированность"],
    "внимательно": ["пристально", "тщательно", "сосредоточенно", "чутко"],
    "внимательный": ["сосредоточенный", "тщательный", "заботливый", "чуткий", "предупредительный", "отзывчивый", "участливый"],
    "внимать": ["слушать", "уступать", "поддаваться", "соглашаться"],
    "вно": ["зно"],
    "вновь": ["заново", "наново", "опять", "снова", "ещё", "ещё раз", "недавно"],
    "внос": ["введение"],
    "вносив": ["вносивши"],
    "вносивши": ["вносив"],
    "внр": ["венгерская народная республика"],
    "внук": ["внучок"],
    "внука": ["внучка"],
    "внутренне": ["мысленно", "внутри"],
    "внутренний": ["сущностный", "содержательный"],
    "внутренний мир": ["душа"],
    "внутренности": ["человек", "кишки", "животное", "потроха", "ливер", "черево", "черева", "осердие", "нутро", "печёнки", "требуха", "нутрянка", "нутряк", "требушина", "осердье"],
    "внутренность": ["внутренний мир"],
    "внутренняя политика": ["внутрипол"],
    "внутри": ["снутри"],
    "внутри-": ["интра-"],
    "внутриатмосферный": ["атмосферный"],
    "внутрибрюшной": ["интраабдоминальный"],
    "внутривидение": ["интроскопия"],
    "внутривлагалищный": ["внутривагинальный", "интравагинальный", "эндовагинальный"],
    "внутригрудной": ["интраторакальный"],
    "внутрижелудочный": ["интрагастральный"],
    "внутризоновый": ["внутризональный"],
    "внутрикапсулярный": ["внутрикапсульный"],
    "внутриконтинентальный": ["внутриматериковый"],
    "внутрикорейский": ["межкорейский"],
    "внутриматериковый": ["внутриконтинентальный"],
    "внутримембранный": ["интрамембранный"],
    "внутриобъектовый": ["внутриобъектный"],
    "внутриплацентарный": ["интраплацентарный"],
    "внутриплодник": ["эндокарпий"],
    "внутриплодный": ["эндокарпный"],
    "внутрипол": ["внутренняя политика"],
    "внутриполостной": ["эктосоматический"],
    "внутрисосудистый": ["интраваскулярный"],
    "внутрь": ["вовнутрь", "извне"],
    "внучатая племянница": ["двоюродная внучка"],
    "внучатый племянник": ["двоюродный внук"],
    "внучек": ["внучок"],
    "внучка": ["внука"],
    "внучок": ["внук", "внучек"],
    "внучонок": ["внучок"],
    "внушав": ["внушавши"],
    "внушавши": ["внушав"],
    "внушать": ["возбуждать", "вызывать", "убеждать"],
    "внушенье": ["внушение"],
    "внушив": ["внушивши"],
    "внушивши": ["внушив"],
    "внушительно": ["впечатляюще"],
    "внушительный": ["солидный", "значительный", "импозантный", "впечатляющий", "большой"],
    "внушённый": ["зомбированный", "неосознанный"],
    "вняв": ["внявши"],
    "внявши": ["вняв"],
    "внятие": ["внимание"],
    "внятно": ["отчётливо", "вразумительно", "ясно", "понятно"],
    "внятный": ["понятный", "ясный", "доступный", "постижимый"],
    "внять": ["услышать", "понять"],
    "во благо": ["для", "в интересах", "ради", "на", "за", "во имя", "на благо", "в пользу"],
    "во весь рот": ["во всю глотку", "во всё горло"],
    "во всеобщее сведение": ["обнародовать", "предать гласности"],
    "во всеоружии": ["во всеоружьи"],
    "во всеуслышание": ["громогласно"],
    "во всю прыть": ["на всех парах"],
    "во всяком случае": ["обязательно"],
    "во всём параде": ["при параде"],
    "во имя": ["для", "в интересах", "ради", "на", "за", "на благо", "во благо", "в пользу", "из-за", "с целью", "в целях"],
    "во славу": ["в честь"],
    "во цвете лет": ["в расцвете сил"],
    "во что бы то ни стало": ["обязательно", "любой ценой", "непременно"],
    "во-первых": ["сначала", "в первую очередь", "перво-наперво", "прежде всего", "первое"],
    "воал": ["було", "фередже", "покривало"],
    "воблоглазый": ["воблоокий"],
    "воблоокий": ["воблоглазый"],
    "вобрав": ["вобравши"],
    "вобравши": ["вобрав"],
    "вов": ["вага", "нява"],
    "вова": ["вовк"],
    "вовек": ["вовеки"],
    "вовеки": ["вовек", "никогда"],
    "вовкулак": ["вовкулака"],
    "вовкулака": ["вовкулак"],
    "вовлекав": ["вовлекавши"],
    "вовлекавши": ["вовлекав"],
    "вовлекаться": ["затягиваться", "втягиваться"],
    "вовлечение": ["вовлеченье"],
    "вовлеченье": ["вовлечение"],
    "вовлечься": ["затянуться", "втянуться"],
    "вовлечённость": ["втянутость", "сопричастность", "заинтересованность"],
    "вовне": ["снаружи", "вне", "изнутри", "наружу", "кнаружи"],
    "вовнутрь": ["внутрь", "извне", "кнутри", "снаружи"],
    "вовочка": ["вова", "володя", "вовка", "володька"],
    "вовремя": ["своевременно"],
    "вовсе": ["совсем", "совершенно", "никакой", "отнюдь", "полностью", "окончательно"],
    "вовсю": ["изо всех сил"],
    "вовчисько": ["вовцюга"],
    "вовчок": ["ведмедик"],
    "вогнав": ["вогнавши"],
    "вогнавши": ["вогнав"],
    "вогнать": ["загнать", "воткнуть", "всадить", "вбить", "заколотить", "вколотить", "вколоть"],
    "вогнать в гроб": ["свести в могилу"],
    "вогнув": ["вогнувши"],
    "вогнувши": ["вогнув"],
    "вогнуть": ["вмять"],
    "вогнуться": ["вдавиться"],
    "вогул": ["манси"],
    "вогулка": ["мансийка"],
    "вода": ["влага", "оксид", "водород", "окись", "гидроксильная кислота", "дигидрид", "кислород", "гидроксид", "гидроокись", "дигидромонооксид", "дигидрогена монооксид", "монооксид дигидрогена", "питьевая вода", "акватория", "источник"],
    "вода камень точит": ["капля камень точит"],
    "водаль ад": ["воддаль ад"],
    "водар": ["духмянасць", "пах"],
    "водворение": ["вселение", "заселение", "поселение", "помещение"],
    "водворенье": ["водворение"],
    "водворив": ["водворивши"],
    "водворивши": ["водворив"],
    "водворяв": ["водворявши"],
    "водворявши": ["водворяв"],
    "воддаль": ["наводдаль", "паводдаль"],
    "водевильный": ["комичный", "опереточный"],
    "воденев": ["воденевши"],
    "воденевши": ["воденев"],
    "воденик": ["водяной"],
    "води в рот набрати": ["тримати язик за зубами"],
    "водив": ["водивши"],
    "водивши": ["водив"],
    "водина": ["помои"],
    "водитель": ["проводник", "водильщик"],
    "водитель ритма": ["пейсмейкер"],
    "водитель ритма сердца": ["очаг автоматизма сердца", "источник ритма сердца"],
    "водитель-лихач": ["лихач"],
    "водитель-профессионал": ["шофёр-профессионал"],
    "водительница": ["автоледи"],
    "водительские права": ["водительское удостоверение", "права"],
    "водительский": ["шофёрский"],
    "водить": ["вести", "вадить"],
    "водить за нос": ["вводить в заблуждение", "дурачить", "пудрить мозги", "вешать лапшу на уши", "верховодить"],
    "водить родню": ["вести родню"],
    "водить хуем по губам": ["дурачить", "водить за нос", "вводить в заблуждение"],
    "водиться": ["обитать", "населять", "жить", "проживать", "иметься", "наличествовать", "быть", "дружить", "приятельствовать", "хороводиться", "якшаться", "знаться"],
    "водица": ["водичка", "водонька", "водочка"],
    "водичечка": ["водица", "водичка"],
    "водичка": ["водица", "водичечка"],
    "водища": ["наводнение", "паводок", "большая вода", "потоп"],
    "водно-энергетический": ["гидроэнергетический"],
    "водноледниковый": ["флювиогляциальный"],
    "воднососудистый": ["водно-сосудистый"],
    "водоблок": ["ватерблок"],
    "водобоязнь": ["бешенство", "гидрофобия"],
    "водоброд": ["барочник", "бурлак"],
    "водоважда": ["водопровод"],
    "водоватый": ["водообразный", "водовидный", "жидковатый", "водянистый"],
    "водоверть": ["водоворот"],
    "водовместилище": ["водохранилище"],
    "водовод": ["водопровод"],
    "водоводец": ["водопроводец", "водоприводец", "водопровод", "водопроводчик"],
    "водоводство": ["гидравлика"],
    "водовоз": ["водовозчик"],
    "водовозница": ["водовозка"],
    "водовозничав": ["водовозничавши"],
    "водовозничавши": ["водовозничав"],
    "водогон": ["девичий корень", "адамов корень", "лепшура", "недоступ", "огненный корень", "переступ", "сальный корень"],
    "водогонка": ["скважина"],
    "водограй": ["фонтан"],
    "водогрей": ["бойлер", "водогрейка", "кипятильник"],
    "водогрейка": ["водогрей", "водогрейня"],
    "водогрейня": ["водогрельня"],
    "водогрельня": ["водогрейня"],
    "водогрязеторфопарафинолечение": ["лечение", "терапия"],
    "водожил": ["жук"],
    "водозабор": ["водозаборное сооружение", "водозаборник"],
    "водоземный": ["земноводный"],
    "водой не разольёшь": ["не разлей вода", "на короткой ноге", "неразлучны"],
    "водок": ["ходок"],
    "водоканал": ["канал"],
    "водоканализационный": ["водопроводно-канализационный"],
    "водокид": ["водобой", "водомёт", "фонтан"],
    "водоклюв": ["капель", "капелица", "капёж", "водоклёв", "водопель", "выбоина"],
    "водокряка": ["трезвенник"],
    "водолажец": ["нововодолажец"],
    "водолаз": ["гидронавт", "ныряльщик"],
    "водолаз-глубоководник": ["глубоководник"],
    "водолазка": ["банлон", "бадлон", "битловка", "гольф"],
    "водолей": ["водолив"],
    "водолечебный": ["гидротерапевтический"],
    "водолечение": ["бальнеотерапия", "гидротерапия"],
    "водолюбивый": ["влаголюбивый"],
    "водомоина": ["промоина", "рытвина", "черторой"],
    "водонагреватель": ["бойлер"],
    "водоносец": ["водонос"],
    "водоноска": ["водоносица"],
    "водоносный": ["водосодержащий", "полноводный"],
    "водоносный горизонт": ["аквифер", "водоносный пласт"],
    "водоосвящение": ["водосвятие", "водоосвященье", "водосвятье"],
    "водоотводный": ["водоотводящий"],
    "водоплавка": ["кутора"],
    "водопляс": ["купальщик", "ныряльщик"],
    "водопоглощаемость": ["водостойкость"],
    "водопроводно-канализационный": ["водоканализационный"],
    "водопроток": ["водосток", "жёлоб"],
    "водопрочный": ["водостойкий"],
    "водоразбавляемый": ["водорастворимый"],
    "водорез": ["ножеклюв", "телорез"],
    "водорезник": ["водорез", "телорез", "телорез обыкновенный", "телорез алоэвидный", "резак", "голорез", "кровавник", "ядрорез", "ногорез", "резун"],
    "водород": ["молекулярный водород", "протон"],
    "водородная бомба": ["термоядерное оружие"],
    "водородный": ["термоядерный"],
    "водорой": ["водороина"],
    "водосбор": ["бассейн"],
    "водосвинка": ["капибара"],
    "водосвятие": ["водоосвящение"],
    "водоскок": ["фонтан", "шадраван"],
    "водоскоп": ["водостой"],
    "водослив": ["водосброс"],
    "водосоп": ["родник", "ключ", "источник"],
    "водостой": ["лужа"],
    "водостойкий": ["гидростойкий", "водонепроницаемый"],
    "водосчётчик": ["водомер", "водоизмеритель"],
    "водотвор": ["водород"],
    "водотерапия": ["водолечение", "гидротерапия"],
    "водотечина": ["водотеча", "водотечь", "водоточина"],
    "водотечник": ["сулык"],
    "водотечь": ["водотеча"],
    "водотленный": ["водогнойный", "неводостойкий"],
    "водоточина": ["водотечина"],
    "водоточный": ["водоточивый"],
    "водоустойчивый": ["водостойкий"],
    "водоустройство": ["водохозяйство"],
    "водофоб": ["гидрофоб", "аквафоб"],
    "водохлёб": ["водоперша", "водопивца", "водопийца", "водопьяница", "водопропоица"],
    "водоход": ["водоходец", "мореход", "мореходец", "речник"],
    "водоходец": ["водоход"],
    "водоходный": ["мореходный"],
    "водоходство": ["судоходство", "судовождение"],
    "водохранный": ["влагозащитный", "водозащитный"],
    "водохрущ": ["водяник"],
    "водочерпальный": ["водочерпательный"],
    "водочка": ["беленькая"],
    "водоямина": ["водоямица", "водоприямок"],
    "водоёмкий": ["водозатратный"],
    "водружав": ["водружавши"],
    "водружавши": ["водружав"],
    "водружение": ["установка"],
    "водрузив": ["водрузивши"],
    "водрузивши": ["водрузив"],
    "водрузить": ["установить", "взгромоздить"],
    "воду в ступе толочь": ["переливать из пустого в порожнее"],
    "воду варить": ["трепать нервы"],
    "водья": ["вадья", "водея"],
    "водяная": ["водянка"],
    "водянев": ["водяневши"],
    "водяневши": ["водянев"],
    "водяника": ["багновка", "водяница", "вороника", "дорогая трава", "медвежья ягода", "психа", "псих-ягода", "пьянка", "сикса", "синявишна трава", "ссыха", "чёрная трава", "обыкновенный ерник", "черный ерник", "ягодный ерник"],
    "водянистый": ["разбавленный", "жидкий", "бессодержательный", "невыразительный", "вялый", "пресный", "расплывчатый", "размытый", "бесцветный", "слабоокрашенный"],
    "водянить": ["разводить", "разжижать", "разбавлять", "наводнять"],
    "водяной": ["водник", "водяник", "водовик", "водяной дедушка", "водяной шут", "морской царь"],
    "водяной знак": ["филигрань"],
    "водяра": ["водка", "вода", "водища"],
    "воевав": ["воевавши"],
    "воевавши": ["воевав"],
    "воевать": ["сражаться", "биться", "бороться", "искоренять"],
    "воеводина": ["автономный край воеводина"],
    "воеводствовав": ["воеводствовавши"],
    "воеводствовавши": ["воеводствовав"],
    "военачалник": ["командир", "пълководец"],
    "военачальник": ["военноначальник", "полководец", "командующий", "командир"],
    "военизация": ["милитаризация", "начальная военная подготовка"],
    "военизировав": ["военизировавши"],
    "военизировавши": ["военизировав"],
    "военизированный": ["парамилитарный"],
    "военизировать": ["милитаризировать"],
    "военка": ["оборонка", "военная кафедра"],
    "военком": ["военный", "комиссар"],
    "военкомат": ["военный комиссариат", "вк"],
    "военкоматовский": ["военкоматский"],
    "военкоматский": ["военкоматовский"],
    "военкорский": ["военкоровский"],
    "военлёт": ["краслёт", "красвоенлёт"],
    "военная база": ["военный лагерь"],
    "военная полиция": ["вп"],
    "военно-": ["милитаристски-"],
    "военно-воздушные силы": ["ввс"],
    "военно-спортивный": ["спортивно-военный"],
    "военное искусство": ["мастерство", "наука"],
    "военное положение": ["вп"],
    "военное право": ["военная юриспруденция", "военное законодательство"],
    "военноначальник": ["военачальник"],
    "военнопленный": ["пленный"],
    "военнослужащая": ["военная", "воительница"],
    "военнослужащий": ["солдат", "военный", "вояка", "воин", "воитель", "ратник", "боец", "солдафон", "армеец"],
    "военные действия": ["боевые действия", "вооружённая борьба"],
    "военный": ["боевой", "армейский", "солдатский", "воинский", "войсковой", "военнослужащий", "военнообязанный", "солдат"],
    "военный билет": ["военник"],
    "военный городок": ["военгородок"],
    "военный комиссариат": ["военкомат", "вк"],
    "военный корреспондент": ["военкор"],
    "военщина": ["милитарист", "милитаризм", "армия", "солдафон", "солдатчина", "солдафонство"],
    "вожак": ["водитель", "водырь", "поводырь", "водчик", "водильщик", "вожатый", "вожатай", "проводник", "провожатый", "путеводитель", "кормчий", "лоцман", "кондуктор", "чичероне", "гид"],
    "вожатый": ["вожак", "водитель", "водырь", "поводырь", "водчик", "водильщик", "вожатай", "пионервожатый", "вагоновожатый", "лидер"],
    "вожделев": ["вожделевши"],
    "вожделевав": ["вожделевавши"],
    "вожделевавши": ["вожделевав"],
    "вожделевая": ["вожделея"],
    "вожделевши": ["вожделев"],
    "вожделение": ["вожделенье"],
    "вожделенный": ["желанный"],
    "вожделенье": ["вожделение"],
    "вожделеть": ["жаждать", "хотеть", "желать"],
    "вождизм": ["диктатура"],
    "вождь": ["полководец"],
    "вожжа": ["сопля"],
    "воз": ["всемирная организация здравоохранения"],
    "воз и маленькая тележка": ["достаточно", "предостаточно", "вдоволь", "девать некуда", "сколько хочешь", "сколько душе угодно", "более чем достаточно"],
    "воз-": ["вос-", "возо-"],
    "возблагодарив": ["возблагодаривши"],
    "возблагодаривши": ["возблагодарив"],
    "возблестев": ["возблестевши"],
    "возблестевши": ["возблестев"],
    "возблестеть": ["возблистать"],
    "возблистав": ["возблиставши"],
    "возблиставши": ["возблистав"],
    "возблистать": ["возблестеть"],
    "возбранив": ["возбранивши"],
    "возбранивши": ["возбранив"],
    "возбраняв": ["возбранявши"],
    "возбранявши": ["возбраняв"],
    "возбраняться": ["запрещаться", "воспрещаться"],
    "возбудив": ["возбудивши"],
    "возбудивши": ["возбудив"],
    "возбудитель": ["источник", "инициатор", "побудитель", "зачинатель", "начинатель", "виновник", "причина", "патоген", "генератор", "стартер"],
    "возбуждав": ["возбуждавши"],
    "возбуждавши": ["возбуждав"],
    "возбуждать": ["будоражить", "вызывать", "пробуждать", "порождать", "волновать", "приводить в возбуждение"],
    "возбужденье": ["возбуждение"],
    "возбуждённый": ["приподнятый", "оживленный", "пафосный"],
    "возбухав": ["возбухавши"],
    "возбухавши": ["возбухав"],
    "возведенье": ["возведение"],
    "возвеличение": ["возвеличенье"],
    "возвеличенье": ["возвеличение"],
    "возвеличив": ["возвеличивши"],
    "возвеличивав": ["возвеличивавши"],
    "возвеличивавши": ["возвеличивав"],
    "возвеличивать": ["превозносить", "прославлять"],
    "возвеличивши": ["возвеличив"],
    "возвернув": ["возвернувши"],
    "возвернувши": ["возвернув"],
    "возвернуть": ["возвратить", "вернуть"],
    "возвернуться": ["возвратиться"],
    "возвеселив": ["возвеселивши"],
    "возвеселивши": ["возвеселив"],
    "возвеселяв": ["возвеселявши"],
    "возвеселявши": ["возвеселяв"],
    "возвести напраслину": ["оклеветать", "оболгать"],
    "возвестив": ["возвестивши"],
    "возвестивши": ["возвестив"],
    "возвещав": ["возвещавши"],
    "возвещавши": ["возвещав"],
    "возвещенье": ["возвещение"],
    "возводив": ["возводивши"],
    "возводивши": ["возводив"],
    "возводить напраслину": ["клеветать", "наговаривать", "оговаривать", "клепать", "возводить поклёп"],
    "возврат": ["возвращение", "отдача"],
    "возвратив": ["возвративши"],
    "возвративши": ["возвратив"],
    "возвратить": ["вернуть", "отдать"],
    "возвратиться": ["вернуться"],
    "возвратность": ["возвращаемость", "возобновляемость", "рефлексивность"],
    "возвратный глагол": ["местоименный глагол"],
    "возвращав": ["возвращавши"],
    "возвращавши": ["возвращав"],
    "возвращение": ["возврат"],
    "возвысив": ["возвысивши"],
    "возвысивши": ["возвысив"],
    "возвышав": ["возвышавши"],
    "возвышавши": ["возвышав"],
    "возвышаться": ["выситься", "превосходить", "подниматься", "расти"],
    "возвышение": ["повышение", "поднятие", "возвышенность"],
    "возвышенность": ["возвышение", "холм", "приподнятость", "благородство"],
    "возвышенье": ["возвышение"],
    "возглавив": ["возглавивши"],
    "возглавивши": ["возглавив"],
    "возглавляв": ["возглавлявши"],
    "возглавлявши": ["возглавляв"],
    "возглавлять": ["руководить", "управлять", "главенствовать"],
    "возглавье": ["возглавие"],
    "возглас": ["восклицание"],
    "возгласив": ["возгласивши"],
    "возгласивши": ["возгласив"],
    "возглашав": ["возглашавши"],
    "возглашавши": ["возглашав"],
    "возгнав": ["возгнавши"],
    "возгнавши": ["возгнав"],
    "возговорив": ["возговоривши"],
    "возговоривши": ["возговорив"],
    "возгонка": ["сублимация"],
    "возгоняв": ["возгонявши"],
    "возгонявши": ["возгоняв"],
    "возгонять": ["сублимировать", "повышать", "возносить"],
    "возгоняться": ["сублимироваться"],
    "возгорав": ["возгоравши"],
    "возгоравши": ["возгорав"],
    "возгораемый": ["воспламеняемый"],
    "возгорание": ["воспламенение"],
    "возгорать": ["возгораться"],
    "возгордив": ["возгордивши"],
    "возгордивши": ["возгордив"],
    "возгордиться": ["загордиться", "занестись"],
    "возгорев": ["возгоревши"],
    "возгоревши": ["возгорев"],
    "возгореть": ["возгореться"],
    "возгремев": ["возгремевши"],
    "возгремевши": ["возгремев"],
    "воздав": ["воздавши"],
    "воздавав": ["воздававши"],
    "воздававши": ["воздавав"],
    "воздавать": ["оказывать", "платить", "отплачивать", "отвечать", "мстить"],
    "воздавши": ["воздав"],
    "воздать": ["оказать", "отплатить", "ответить"],
    "воздаяние": ["воздаянье", "кара", "возмездие", "вознаграждение"],
    "воздаянье": ["воздаяние"],
    "воздаятель": ["вознаграждающий"],
    "воздвигав": ["воздвигавши"],
    "воздвигавши": ["воздвигав"],
    "воздвигать": ["вздымать", "возводить"],
    "воздвигнув": ["воздвигнувши"],
    "воздвигнувши": ["воздвигнув"],
    "воздвигнуть": ["возвести", "соорудить"],
    "воздвижение": ["воздвиженье"],
    "воздвиженье": ["воздвижение"],
    "воздев": ["воздевши"],
    "воздевав": ["воздевавши"],
    "воздевавши": ["воздевав"],
    "воздевать": ["поднимать"],
    "воздевши": ["воздев"],
    "воздействие": ["влияние"],
    "воздействовав": ["воздействовавши"],
    "воздействовавши": ["воздействовав"],
    "воздействовать": ["влиять", "затрагивать", "повлиять", "затронуть"],
    "возделав": ["возделавши"],
    "возделавши": ["возделав"],
    "возделывав": ["возделывавши"],
    "возделывавши": ["возделывав"],
    "возделыванье": ["возделывание"],
    "возделывать": ["обрабатывать", "выращивать", "разводить"],
    "воздержав": ["воздержавши"],
    "воздержавши": ["воздержав"],
    "воздержанный": ["воздержный", "сдержанный", "умеренный"],
    "воздержанье": ["воздержание"],
    "воздерживав": ["воздерживавши"],
    "воздерживавши": ["воздерживав"],
    "воздохнув": ["воздохнувши"],
    "воздохнувши": ["воздохнув"],
    "воздух": ["атмосфера"],
    "воздуховод": ["воздухопровод"],
    "воздухомер": ["аэрометр"],
    "воздухонагреватель": ["воздухоподогреватель"],
    "воздухонезависимый": ["анаэробный"],
    "воздухообразный": ["газообразный"],
    "воздухоотражатель": ["дефлектор"],
    "воздухоочиститель": ["пылеуловитель"],
    "воздухоплавание": ["аэронавтика", "воздухоплаванье"],
    "воздухоплаванье": ["воздухоплавание"],
    "воздухоплаватель": ["аэронавт"],
    "воздухоплавательный": ["авиационный"],
    "воздухоподогреватель": ["воздухонагреватель"],
    "воздухопровод": ["воздуховод"],
    "воздушка": ["пневматическое оружие", "пневматика"],
    "воздушная почта": ["авиапочта", "голубиная почта"],
    "воздушно-десантные войска": ["вдв"],
    "воздушное пространство": ["пятый океан", "поднебесье", "воздух", "высота", "высь", "вышина"],
    "воздушный винт": ["пропеллер"],
    "воздушный змей": ["кайт"],
    "воздушный океан": ["эфирный океан"],
    "воздушный шар": ["воздушный шарик", "аэростат", "монгольфьер"],
    "воздымав": ["воздымавши"],
    "воздымавши": ["воздымав"],
    "воздымать": ["вздымать"],
    "воздыхав": ["воздыхавши"],
    "воздыхавши": ["воздыхав"],
    "воздыханье": ["воздыхание"],
    "воздыхатель": ["поклонник", "ухажёр"],
    "воздыхательница": ["поклонница", "ухажёрка"],
    "возжаждав": ["возжаждавши"],
    "возжаждавши": ["возжаждав"],
    "возжаться": ["вожжаться"],
    "возжелав": ["возжелавши"],
    "возжелавши": ["возжелав"],
    "возжечь": ["зажечь", "воспалить"],
    "возжжение": ["возжигание", "зажигание"],
    "возжигав": ["возжигавши"],
    "возжигавши": ["возжигав"],
    "возжигание": ["зажжение"],
    "возжигатель": ["возжигательница"],
    "воззвав": ["воззвавши"],
    "воззвавши": ["воззвав"],
    "воззвание": ["обращение", "призыв"],
    "воззванье": ["воззвание"],
    "воззнаменовав": ["воззнаменовавши"],
    "воззнаменовавши": ["воззнаменовав"],
    "воззрев": ["воззревши"],
    "воззревав": ["воззревавши"],
    "воззревавши": ["воззревав"],
    "воззревши": ["воззрев"],
    "воззрение": ["точка зрения", "мнение", "взгляд", "взор", "рассмотрение", "суждение"],
    "воззренье": ["воззрение"],
    "воззреть": ["посмотреть"],
    "воззреться": ["воззриться"],
    "возив": ["возивши"],
    "возивши": ["возив"],
    "возить": ["перевозить", "транспортировать", "доставлять", "возюкать", "елозить"],
    "возиться": ["ворочаться", "шуршать", "копаться", "корпеть", "колупаться"],
    "возка": ["перевозка", "доставка"],
    "возлагав": ["возлагавши"],
    "возлагавши": ["возлагав"],
    "возле": ["рядом", "близко", "недалеко", "около", "близ", "подле", "при"],
    "возлегав": ["возлегавши"],
    "возлегавши": ["возлегав"],
    "возлежав": ["возлежавши"],
    "возлежавши": ["возлежав"],
    "возлетав": ["возлетавши"],
    "возлетавши": ["возлетав"],
    "возлетание": ["взлёт", "возлёт"],
    "возлетев": ["возлетевши"],
    "возлетевши": ["возлетев"],
    "возлететь": ["взмыть"],
    "возлив": ["возливши"],
    "возливав": ["возливавши"],
    "возливавши": ["возливав"],
    "возливать": ["наливать", "поливать", "возлиять"],
    "возливши": ["возлив"],
    "возликовав": ["возликовавши"],
    "возликовавши": ["возликовав"],
    "возлияв": ["возлиявши"],
    "возлиявши": ["возлияв"],
    "возлияние": ["возлиянье"],
    "возлиянье": ["возлияние"],
    "возложенье": ["возложение"],
    "возложив": ["возложивши"],
    "возложивши": ["возложив"],
    "возлюбив": ["возлюбивши"],
    "возлюбивши": ["возлюбив"],
    "возлюбленный": ["любимый"],
    "возмездие": ["отплата", "расплата"],
    "возместив": ["возместивши"],
    "возместивши": ["возместив"],
    "возместимость": ["компенсируемость"],
    "возместимый": ["возвратимый", "компенсируемый"],
    "возместитель": ["возместительница"],
    "возместить": ["компенсировать"],
    "возмечтав": ["возмечтавши"],
    "возмечтавши": ["возмечтав"],
    "возмечтать": ["замечтать", "загрезить", "возгордиться", "возомнить", "заважничать"],
    "возмещав": ["возмещавши"],
    "возмещавши": ["возмещав"],
    "возмещать": ["компенсировать", "восполнять"],
    "возмещение": ["компенсация"],
    "возмещенье": ["возмещение"],
    "возмнив": ["возмнивши"],
    "возмнивши": ["возмнив"],
    "возможно": ["можно", "вероятно", "видимо", "пожалуй"],
    "возможность": ["вероятность"],
    "возможный": ["вероятный", "допустимый", "мыслимый"],
    "возмочь": ["смочь"],
    "возмужав": ["возмужавши"],
    "возмужавши": ["возмужав"],
    "возмужание": ["возмужалость"],
    "возмужанье": ["возмужание"],
    "возмужать": ["созреть", "повзрослеть", "закалиться", "сложиться"],
    "возмутив": ["возмутивши"],
    "возмутивши": ["возмутив"],
    "возмутитель": ["возмутительница", "бунтовщик", "мятежник", "смутьян"],
    "возмутиться": ["взбунтоваться", "восстать", "поднять бунт", "поднять восстание", "поднять мятеж", "вознегодовать"],
    "возмущав": ["возмущавши"],
    "возмущавши": ["возмущав"],
    "возмущать": ["сердить", "злить", "бесить", "выводить из себя"],
    "возмущаться": ["негодовать", "бунтовать", "восставать", "поднимать бунт", "поднимать восстание", "поднимать мятеж"],
    "возмущение": ["восстание", "мятеж", "негодование", "недовольство", "помеха"],
    "вознаградив": ["вознаградивши"],
    "вознаградивши": ["вознаградив"],
    "вознаграждав": ["вознаграждавши"],
    "вознаграждавши": ["вознаграждав"],
    "вознагражденье": ["вознаграждение"],
    "вознамериться": ["собраться", "задумать", "запланировать"],
    "вознегодовав": ["вознегодовавши"],
    "вознегодовавши": ["вознегодовав"],
    "возненавидев": ["возненавидевши"],
    "возненавидевши": ["возненавидев"],
    "вознесение господне": ["вознесение"],
    "вознесенье": ["вознесение"],
    "вознести": ["вскинуть", "возвеличить", "взмолиться"],
    "возникав": ["возникавши"],
    "возникавши": ["возникав"],
    "возникать": ["появляться", "выступать"],
    "возникающий": ["появляющийся"],
    "возникновение": ["появление", "зарождение", "образование", "появленье", "зарожденье"],
    "возникновенье": ["возникновение"],
    "возникнув": ["возникнувши"],
    "возникнувши": ["возникнув"],
    "возникнуть": ["появиться", "начаться", "стать видимым", "показаться", "предстать", "возражать", "проявлять инициативу", "протестовать"],
    "возница": ["извозчик", "кучер", "возничий"],
    "возничий": ["извозчик", "кучер", "возница"],
    "возносив": ["возносивши"],
    "возносивши": ["возносив"],
    "возносить до небес": ["расхваливать", "восхвалять", "курить фимиам"],
    "возня": ["копошение"],
    "возобладав": ["возобладавши"],
    "возобладавши": ["возобладав"],
    "возобновив": ["возобновивши"],
    "возобновивши": ["возобновив"],
    "возобновить": ["восстановить", "продлить"],
    "возобновление": ["восстановление", "возрождение"],
    "возобновляв": ["возобновлявши"],
    "возобновлявши": ["возобновляв"],
    "возобновляемость": ["восстанавливаемость"],
    "возобновлять": ["возвращаться", "восстанавливать", "обновлять"],
    "возок": ["сани", "повозка"],
    "возомнив": ["возомнивши"],
    "возомнивши": ["возомнив"],
    "возомнивший": ["вообразивший"],
    "возопив": ["возопивши"],
    "возопивши": ["возопив"],
    "возопить": ["возопиять", "завопить", "закричать", "воззвать", "вскричать"],
    "возопияв": ["возопиявши"],
    "возопиявши": ["возопияв"],
    "возопиять": ["воззвать", "возопить", "воскликнуть", "вскричать", "завопить", "закричать"],
    "возражав": ["возражавши"],
    "возражавши": ["возражав"],
    "возражать": ["противоречить"],
    "возражение": ["несогласие", "прекословие", "отповедь", "протест"],
    "возраженье": ["возражение"],
    "возразив": ["возразивши"],
    "возразивши": ["возразив"],
    "возраст согласия": ["возраст сексуального согласия"],
    "возрастав": ["возраставши"],
    "возраставши": ["возрастав"],
    "возрастание": ["увеличение", "рост"],
    "возрастанье": ["возрастание"],
    "возрасти": ["вырасти", "усилиться"],
    "возрастив": ["возрастивши"],
    "возрастивши": ["возрастив"],
    "возрастной": ["пожилой", "старческий", "старый"],
    "возращав": ["возращавши"],
    "возращавши": ["возращав"],
    "возревновав": ["возревновавши"],
    "возревновавши": ["возревновав"],
    "возродив": ["возродивши"],
    "возродивши": ["возродив"],
    "возрождав": ["возрождавши"],
    "возрождавши": ["возрождав"],
    "возрождать": ["воскрешать", "восстанавливать"],
    "возрождение": ["восстановление", "расцвет", "подъём"],
    "возрожденческий": ["ренессансный"],
    "возрожденье": ["возрождение"],
    "возроптав": ["возроптавши"],
    "возроптавши": ["возроптав"],
    "возрыдав": ["возрыдавши"],
    "возрыдавши": ["возрыдав"],
    "возрыдавший": ["разрыдавшийся"],
    "возрыдать": ["взрыдать"],
    "возчик": ["извозчик", "возница"],
    "возыграв": ["возыгравши"],
    "возыгравши": ["возыграв"],
    "возымев": ["возымевши"],
    "возымевши": ["возымев"],
    "возюкав": ["возюкавши"],
    "возюкавши": ["возюкав"],
    "воин": ["боец", "воитель", "военнослужащий", "солдат", "ратник"],
    "воинский": ["военный", "армейский", "войсковой"],
    "воинственно": ["агрессивно", "по-боевому", "боевито"],
    "воинственность": ["агрессивность", "боевитость"],
    "воинство": ["войско", "рать"],
    "воинствовав": ["воинствовавши"],
    "воинствовавши": ["воинствовав"],
    "воинствующий": ["непримиримый", "агрессивный", "активный"],
    "воинъ": ["боец"],
    "воистину": ["действительно", "подлинно", "поистине", "истинно", "вправду", "аминь"],
    "воитель": ["воин", "драчун", "забияка", "поборник"],
    "воительница": ["амазонка"],
    "вой": ["завывание", "стон"],
    "войда": ["войд"],
    "война": ["баталия", "битва", "побоище", "сражение", "рать", "брань", "сеча", "вражда", "борьба", "столкновение", "противостояние"],
    "война в донбассе": ["антитеррористическая операция", "ато"],
    "война всех против всех": ["пауки в банке"],
    "война иксов": ["ядерная война иксов"],
    "войска": ["силы", "армия"],
    "войска сс": ["ваффен-сс"],
    "войско": ["армия"],
    "войско польское": ["вп"],
    "войсовер": ["закадровое озвучивание", "закадровый перевод"],
    "войт": ["градоначальник", "староста", "старшина"],
    "войти": ["вступить", "входить", "зайти", "пройти", "ступить", "вбежать", "взойти", "вкатиться", "влезть", "вломиться", "внырнуть", "вплыть", "вторгнуться", "забежать", "забраться"],
    "войти в дом": ["взойти в дом", "выйти в дом", "уйти в дом"],
    "войти в раж": ["взволноваться", "разгорячиться", "взбудоражиться", "возбудиться", "распалиться", "взвинтиться", "завестись", "прийти в раж", "прийти в возбуждение", "завестись с пол-оборота"],
    "войцех": ["войтек"],
    "вокабуляр": ["запас слов", "лексика", "лексический запас", "словарный запас", "словарь", "активный словарь", "вокабулярий", "словник"],
    "вокабулярий": ["запас слов", "лексика", "лексикон", "лексический запас", "словарный запас", "словарь", "активный словарь", "вокабуляр"],
    "вокализировав": ["вокализировавши"],
    "вокализировавши": ["вокализировав"],
    "вокализовав": ["вокализовавши"],
    "вокализовавши": ["вокализовав"],
    "вокальный": ["певческий"],
    "вокатив": ["звательный падеж"],
    "вокативный": ["звательный"],
    "вокзал": ["станция", "воксал", "курзал"],
    "вокизм": ["воук-идеология"],
    "воксал": ["курзал"],
    "воксельная морфометрия": ["воксель-базированная морфометрия"],
    "волан": ["воланчик", "оборка", "рюш"],
    "волапюк": ["воляпук", "воляпюк", "бессмыслица", "тарабарщина"],
    "волатильность": ["изменчивость"],
    "волатильный": ["изменчивый", "неустойчивый", "лабильный"],
    "волга": ["баржа", "волжана"],
    "волгарь": ["волжанин", "бурлак"],
    "волглость": ["сырость", "влажность"],
    "волглый": ["вохкий"],
    "волгнув": ["волгнувши"],
    "волгнувши": ["волгнув"],
    "волгоград": ["волжская твердыня", "сталинград", "царицын"],
    "волгоградец": ["царицанин", "царицынец", "сталинградец"],
    "волгоградка": ["царицынка", "сталинградка"],
    "волдырик": ["волдырёк", "волдырчик"],
    "волдырчик": ["волдырёк", "волдырик"],
    "волдырь": ["пузырь"],
    "волдырёк": ["волдырик", "волдырчик"],
    "волевой": ["сильный", "авторитарный"],
    "волеизволение": ["волеизволенье"],
    "волей-неволей": ["поневоле", "вынужденно"],
    "воленс-ноленс": ["поневоле", "волей-неволей", "хочешь не хочешь", "вынужденно"],
    "волеро": ["кипелыч", "лерсаныч"],
    "волжана": ["волга"],
    "волжская булгария": ["волжско-камская булгария", "серебряная булгария", "болгарское ханство", "булгарское ханство"],
    "волид": ["волидайн"],
    "волидайн": ["волидон", "абавайн", "падару модар"],
    "волитив": ["волюнтатив"],
    "волить": ["желать", "хотеть", "изволить"],
    "волк": ["серый волк", "обыкновенный волк", "лыкас", "бирюк", "вор", "нелюдим"],
    "волк в овечьей шкуре": ["двуликий янус"],
    "волк-одиночка": ["интроверт"],
    "волкамерия": ["клеродендрум"],
    "волкан": ["вулкан"],
    "волкобой": ["аконит", "борец", "волкобойник", "волчатка"],
    "волковысянин": ["волковычанин"],
    "волковычанин": ["волковысянин"],
    "волколак": ["волкодлак", "волкулак", "вукула", "вервольф"],
    "волколов": ["ловец"],
    "волком смотреть": ["смотреть волком", "смотреть зверем", "зверем смотреть"],
    "волкопёс": ["волкособака", "волкособ", "полуволк"],
    "волкособ": ["волкособака"],
    "волкособака": ["волкособ"],
    "волна": ["всплеск", "колебание"],
    "волна из-под угла бьёт": ["золотая волна из-под угла бьёт", "волна под угол бьёт", "золотая волна под угол бьёт"],
    "волненье": ["волнение"],
    "волнист": ["волновик", "ньювейвер"],
    "волнисто": ["волнообразно"],
    "волнистость": ["волнообразность"],
    "волнительно": ["взволнованно", "волнующе"],
    "волнительный": ["волнующий", "тревожный"],
    "волновав": ["волновавши"],
    "волновавши": ["волновав"],
    "волнование": ["волнованье"],
    "волнованье": ["волнование"],
    "волновать": ["колебать", "зыбить", "заботить", "тревожить"],
    "волноваться": ["колебаться", "зыбаться", "зыбиться", "беспокоиться", "переживать", "тревожиться", "бузить"],
    "волновая функция": ["пси-функция"],
    "волновик": ["ньювейвер", "трейдер"],
    "волногаситель": ["волнолом", "волнорез", "брекватер"],
    "волнолом": ["волнорез", "брекватер"],
    "волнообразный": ["волнистый"],
    "волнорез": ["волнолом"],
    "волнуха": ["волнушка"],
    "волнушка": ["волнуха"],
    "волнующий": ["беспокоящий"],
    "волнянка": ["волвеник", "волвеница", "волвенка", "волвеня", "волвянец", "волвяница", "волвянка", "волжанка", "волнуха", "волнушка", "волняница"],
    "волобуйствовав": ["волобуйствовавши"],
    "волобуйствовавши": ["волобуйствовав"],
    "воловец": ["воловчанин"],
    "воловка": ["воловчанка"],
    "воловчанин": ["воловец"],
    "вологжанин": ["вологодец", "вологодчанин", "воложанин"],
    "вологодец": ["вологжанин", "вологодчанин"],
    "вологодская область": ["вологодчина"],
    "вологодчанин": ["вологжанин", "вологодец"],
    "володар": ["господар"],
    "володаровец": ["володарец"],
    "володев": ["володевши"],
    "володевши": ["володев"],
    "володимерец": ["володимирец", "владимирец"],
    "володимирец": ["володимерец", "владимирец"],
    "володя": ["вова", "волоша"],
    "воложанин": ["вологжанин", "вологодец", "вологодчанин"],
    "волокита": ["проволочка", "бюрократизм"],
    "волокитив": ["волокитивши"],
    "волокитивши": ["волокитив"],
    "волокитство": ["селадонство"],
    "волокно": ["фибра", "нить"],
    "волоколамец": ["волочанин"],
    "волоконно-оптический": ["оптико-волоконный", "оптоволоконный"],
    "волонтёр": ["доброволец"],
    "волонтёрив": ["волонтёривши"],
    "волонтёривши": ["волонтёрив"],
    "волонтёрка": ["доброволица"],
    "волонтёрский": ["волонтёрный"],
    "волонтёрство": ["добровольничество"],
    "волонтёрствовав": ["волонтёрствовавши"],
    "волонтёрствовавши": ["волонтёрствовав"],
    "волосастость": ["волосатость"],
    "волосастый": ["волосатый"],
    "волосатая мартышка": ["учитель"],
    "волосатев": ["волосатевши"],
    "волосатевши": ["волосатев"],
    "волосатик": ["рутиловый кварц"],
    "волосной": ["волосный", "капиллярный"],
    "волосность": ["капиллярность"],
    "волосовина": ["волосная трещина"],
    "волосок": ["волосинка"],
    "волосообразный": ["волосовидный"],
    "волосохвост": ["рыба-сабля"],
    "волостель": ["голова", "кормленщик", "руководитель"],
    "волость": ["удел", "княжество"],
    "волосъ": ["власъ"],
    "волосы": ["шевелюра", "волосья", "локоны", "кудри", "волос"],
    "волосьё": ["волосня", "волосья"],
    "волоцюга": ["безхатченко", "блудяга", "галайда"],
    "волочанин": ["волоколмец", "вышневолочанин"],
    "волоченье": ["волочение"],
    "волочив": ["волочивши"],
    "волочивши": ["волочив"],
    "волочильных дел мастер": ["карманный вор", "карманник"],
    "волочить": ["волочь", "тянуть", "тащить", "влачить"],
    "волочиться": ["ползти", "херачить"],
    "волочь": ["волочить", "тянуть", "тащить", "рубить", "сечь"],
    "волоёб": ["мумоёб", "лентяй", "бездельник", "уклонист", "лодырь", "халтурщик", "бракодел", "халявщик", "рукожоп"],
    "волоёбив": ["волоёбивши"],
    "волоёбивши": ["волоёбив"],
    "волоёбство": ["ничегонеделание", "мудоёбство", "мумоёбство", "мумоебание", "мумоебанье", "мозгоёбство", "мозгоебание", "мозгоебанье", "долбоёбство", "долбоебизм"],
    "волоёбствовав": ["волоёбствовавши"],
    "волоёбствовавши": ["волоёбствовав"],
    "волоёбствовать": ["волоёбить"],
    "волтерьянец": ["вольтерьянец", "вольтерианец", "свободомыслящий", "либерал", "вольнодумец", "фармазон", "атеист", "безбожник"],
    "волтузив": ["волтузивши"],
    "волтузивши": ["волтузив"],
    "волхв": ["жрец", "колдун", "кудесник", "чудодей", "чародей", "маг", "мудрец", "звездочёт", "астролог", "знахарь", "ворожея", "чернокнижник", "волшебник", "ведун"],
    "волхвовав": ["волхвовавши"],
    "волхвовавши": ["волхвовав"],
    "волхвование": ["ворожба", "чародейство"],
    "волхвованье": ["волхвование"],
    "волхвовать": ["колдовать", "чародействовать"],
    "волхование": ["волхвование", "ворожба"],
    "волхованье": ["волхование"],
    "волховать": ["волхвовать", "ворожить", "колдовать"],
    "волховец": ["волховчанин", "волховстроевец"],
    "волховстроевец": ["волховец", "волховчанин"],
    "волховчанин": ["волховец", "волховстроец"],
    "волчанка": ["люпус"],
    "волчеягодник": ["волчник", "волчье лыко", "волчья ягода"],
    "волчий": ["злобный", "звериный", "хищнический", "опасный"],
    "волчий билет": ["волчий паспорт", "волчий аттестат"],
    "волчиха": ["волчица"],
    "волчица": ["волчиха"],
    "волчишка": ["волк"],
    "волчник": ["волчеягодник"],
    "волчок": ["волк"],
    "волчье лыко": ["волчеягодник", "дафна"],
    "волчья капуста": ["чемерица"],
    "волчья ягода": ["жимолость обыкновенная"],
    "волшба": ["волшебство", "колдовство", "ведовство", "чародейство", "ворожба"],
    "волшебник": ["колдун", "маг", "чародей"],
    "волшебница": ["чародейка", "колдунья"],
    "волшебный": ["магический", "сказочный", "чудодейственный", "фантастический", "чарующий"],
    "волшебство": ["колдовство", "магия", "чародейство"],
    "волынец": ["волынчанин", "волынянин"],
    "волынив": ["волынивши"],
    "волынивши": ["волынив"],
    "волынская область": ["волынщина"],
    "волынчанин": ["волынец", "волынянин"],
    "волынчанка": ["волынянка"],
    "волынщик": ["саботажник"],
    "волынь": ["волын", "велынь"],
    "волынянин": ["волынец", "волынчанин"],
    "волынянка": ["волынчанка"],
    "вольготно": ["привольно"],
    "вольготный": ["свободный", "вольный", "привольный"],
    "вольер": ["вольера"],
    "вольера": ["вольер", "клетка"],
    "вольничав": ["вольничавши"],
    "вольничавши": ["вольничав"],
    "вольнодум": ["вольнодумец"],
    "вольнодумие": ["вольнодумство", "свободомыслие"],
    "вольнодумничав": ["вольнодумничавши"],
    "вольнодумничавши": ["вольнодумничав"],
    "вольнодумный": ["свободомыслящий"],
    "вольнодумство": ["вольнодумие", "свободомыслие", "фармазонство"],
    "вольнодумствовав": ["вольнодумствовавши"],
    "вольнодумствовавши": ["вольнодумствовав"],
    "вольнолюбивый": ["свободолюбивый"],
    "вольнолюбие": ["свободолюбие"],
    "вольномыслие": ["вольнодумство", "свободомыслие"],
    "вольномыслящий": ["вольнодумный", "свободомыслящий", "вольнодумец"],
    "вольнонадеждинец": ["надеждинец"],
    "вольнонаемник": ["вольнонаёмный"],
    "вольноопределяющийся": ["вольнопёр", "юнкер", "доброволец", "охотник", "волонтёр"],
    "вольноотпущенная": ["вольноотпущенница"],
    "вольноотпущенница": ["вольноотпущенная"],
    "вольность": ["свобода"],
    "вольный": ["свободный", "беспрепятственный", "вольготный", "дикий", "могущий", "субъективный", "нескромный", "развязный", "фамильярный", "фривольный", "привольный", "независимый"],
    "вольный город": ["вольный имперский город"],
    "вольный каменщик": ["каменщик", "масон", "франкмасон", "фармазон"],
    "вольнянец": ["червоноармеец"],
    "вольнянск": ["софиевка", "красноармейское", "червоноармейское"],
    "вольняшка": ["вольняга"],
    "вольт-амперный": ["вольтамперный"],
    "вольтаж": ["напряжение"],
    "вольтамперметр": ["ампервольтметр"],
    "вольтамперный": ["вольт-амперный"],
    "вольтерьянец": ["вольтерианец", "свободомыслящий", "либерал", "вольнодумец", "фармазон", "атеист", "безбожник", "вольтерьянка"],
    "вольтерьянство": ["вольтерианство"],
    "вольтиец": ["буркиниец"],
    "вольтижировав": ["вольтижировавши"],
    "вольтижировавши": ["вольтижировав"],
    "вольтижировать": ["джигитовать"],
    "вольтижёр": ["вольтижёрка"],
    "вольтметр": ["вольтиметр"],
    "вольфрам": ["тунгстен"],
    "вольфрамировав": ["вольфрамировавши"],
    "вольфрамировавши": ["вольфрамировав"],
    "волюморецептор": ["волюмрецептор"],
    "волюнтатив": ["волитив"],
    "волютин": ["метахроматин"],
    "воля": ["целеустремлённость", "намерение", "самоконтроль", "желание", "пожелание", "требование", "власть", "свобода"],
    "воля ваша": ["извините", "простите", "хорошо", "ладно", "ага", "окей"],
    "воляпюк": ["волапюк"],
    "вомероназальный": ["сошниково-носовой"],
    "вомчав": ["вомчавши"],
    "вомчавши": ["вомчав"],
    "вон": ["вовне", "изнутри", "кнаружи", "наружу"],
    "вонзав": ["вонзавши"],
    "вонзавши": ["вонзав"],
    "вонзаться": ["втыкаться", "вклиниваться", "вперяться"],
    "вонзив": ["вонзивши"],
    "вонзивши": ["вонзив"],
    "вонзить": ["воткнуть", "устремить", "сострить", "опрокинуть", "хлопнуть"],
    "вонзиться": ["воткнуться", "вклиниться", "впериться", "уставиться"],
    "вонзённый": ["воткнутый", "вбитый", "вколотый"],
    "вонизм": ["вонь", "вонизма", "вонизмия"],
    "вонизма": ["вонь", "вонизм", "вонизмия"],
    "вонизмия": ["вонь", "вонища", "вонизма", "вонизм"],
    "вонь": ["зловоние", "смрад", "вонища"],
    "вонючий": ["зловонный", "смердящий"],
    "вонючка": ["скунс"],
    "воняв": ["вонявши"],
    "вонява": ["вонючка"],
    "вонявши": ["воняв"],
    "вонять": ["смердить", "вякать", "выступать"],
    "воображав": ["воображавши"],
    "воображавши": ["воображав"],
    "воображаемо": ["мнимо"],
    "воображаемый": ["мнимый"],
    "воображала": ["задавака", "зазнайка", "чванливец"],
    "воображать": ["придумывать", "фантазировать", "имажинировать", "предполагать", "думать", "представлять"],
    "воображение": ["фантазия", "представление", "имажинация", "имагинация", "домысел", "мнение", "предположение", "воспоминание", "понятие"],
    "воображенье": ["воображение"],
    "воображуля": ["воображала"],
    "вообразив": ["вообразивши"],
    "вообразивши": ["вообразив"],
    "вообразимый": ["представимый", "мыслимый"],
    "вообразить": ["представить"],
    "вообще": ["обычно", "в общем", "в целом", "всегда", "постоянно", "во всём", "по сути", "в общих чертах", "приблизительно", "абсолютно", "вовсе", "полностью", "совершенно", "совсем"],
    "вообще говоря": ["вообще-то"],
    "воодушевив": ["воодушевивши"],
    "воодушевивши": ["воодушевив"],
    "воодушевить": ["вдохновить"],
    "воодушевление": ["агитация", "энтузиазм", "восторг", "экзальтация", "вдохновение"],
    "воодушевляв": ["воодушевлявши"],
    "воодушевлявши": ["воодушевляв"],
    "воодушевлять": ["вдохновлять"],
    "вооружав": ["вооружавши"],
    "вооружавши": ["вооружав"],
    "вооружение": ["экипировка", "оружие"],
    "вооруженье": ["вооружение"],
    "вооружив": ["вооруживши"],
    "вооруживши": ["вооружив"],
    "вооружённые силы": ["армия"],
    "вооружённый конфликт": ["военный конфликт"],
    "воочию": ["своими глазами", "наглядно", "ясно"],
    "вопив": ["вопивши"],
    "вопивши": ["вопив"],
    "вопить": ["вопиять", "орать", "выть", "реветь"],
    "вопиюще": ["шокирующе"],
    "вопиющий": ["недопустимый", "возмутительный"],
    "вопияв": ["вопиявши"],
    "вопиявши": ["вопияв"],
    "вопленица": ["плакальщица", "плакуша", "плачея"],
    "воплотив": ["воплотивши"],
    "воплотивши": ["воплотив"],
    "воплотиться": ["осуществиться"],
    "воплощав": ["воплощавши"],
    "воплощавши": ["воплощав"],
    "воплощение": ["осуществление", "претворение", "реализация", "инкарнация", "олицетворение", "квинтэссенция"],
    "вопнув": ["вопнувши"],
    "вопнувши": ["вопнув"],
    "вопреки": ["несмотря на", "против", "наперекор"],
    "вопрос": ["дело", "проблема", "вопросительный знак"],
    "вопросив": ["вопросивши"],
    "вопросивши": ["вопросив"],
    "вопросительный знак": ["знак вопроса", "вопрос", "знак вопрошения", "неясность", "непонимание"],
    "вопросить": ["спросить", "осведомиться"],
    "вопросник": ["анкета"],
    "вопросно-ответный": ["вопросо-ответный"],
    "вопрошав": ["вопрошавши"],
    "вопрошавши": ["вопрошав"],
    "вопрошание": ["вопрошение"],
    "вопрошанье": ["вопрошание"],
    "вопрошать": ["спрашивать", "задавать вопрос"],
    "вопрошающе": ["вопросительно"],
    "вопрошение": ["вопрошание"],
    "вопъл": ["стенание", "ридание", "хленч", "охкане"],
    "ворба": ["хорба"],
    "ворвав": ["ворвавши"],
    "ворвавши": ["ворвав"],
    "ворвань": ["жир"],
    "ворворка": ["висюлька", "балаболка"],
    "ворзаться": ["возиться", "баловаться"],
    "ворковав": ["ворковавши"],
    "ворковавши": ["ворковав"],
    "ворковать": ["нежничать", "любезничать"],
    "воркотав": ["воркотавши"],
    "воркотавши": ["воркотав"],
    "воркотанье": ["воркотание"],
    "воркотня": ["ворчание", "брюзжание", "бормотание", "воркование"],
    "воркотун": ["ворчун", "брюзга", "воркотунья"],
    "воркотунья": ["брюзга", "воркотун"],
    "воркутинец": ["воркутянин"],
    "воркутянин": ["воркутинец"],
    "воркутянка": ["воркутинка"],
    "воробей": ["воробышек", "воробьишка", "врабий"],
    "воробейник": ["каменное семя"],
    "воробка": ["воробьиха"],
    "воробушек": ["воробейчик", "воробьишка", "воробышек"],
    "воробышек": ["воробейчик", "воробьишка", "воробушек"],
    "воробьевит": ["морганит", "аметист-бальзатин"],
    "воробьи чирикают": ["секрет полишинеля"],
    "воробьиная ночь": ["рябиновая ночь"],
    "воробья в поле загонять": ["душу заложить"],
    "воровав": ["воровавши"],
    "воровавши": ["воровав"],
    "воровайка": ["воровка", "грабительница", "похитительница", "крадунья"],
    "вороватый": ["воровливый"],
    "воровать": ["красть", "похищать", "прихватизировать", "тыбзить", "тыбрить", "тырить"],
    "воровка": ["грабительница", "похитительница", "крадунья", "воровайка"],
    "воровливый": ["вороватый"],
    "воровской притон": ["малина"],
    "воровство": ["кража", "хищение"],
    "ворог": ["враг", "недруг", "неприятель"],
    "ворогъ": ["врагъ"],
    "ворожба": ["гадание", "колдовство"],
    "ворожбит": ["знахар"],
    "ворожей": ["заклинатель", "колдун"],
    "ворожейка": ["ворожея", "колдунья", "гадалка"],
    "ворожение": ["ворожба"],
    "ворожея": ["колдунья", "гадалка", "знахарка"],
    "ворожив": ["вороживши"],
    "вороживши": ["ворожив"],
    "ворожить": ["гадать", "колдовать"],
    "ворожка": ["ворожея", "ворожба", "гадание", "знахарство"],
    "ворократ": ["клептократ"],
    "ворократия": ["ворократ"],
    "ворон": ["вран"],
    "ворона": ["хава"],
    "вороначанин": ["вороничанин", "вороночанин", "воронечанин"],
    "воронеж": ["столица черноземья", "город куража", "воронежский"],
    "воронежанин": ["воронежец"],
    "воронежанка": ["воронежка"],
    "воронежец": ["воронежанин", "долгопузик", "саламатник", "соломатник", "скобёл"],
    "воронежка": ["воронежанка", "воронеженка"],
    "воронец": ["матица", "гряда", "актея", "купена", "купень", "кровавник", "сындрик", "волчья трава", "волчьи глазки", "вороновы глазки", "сорочьи ягоды"],
    "воронечанин": ["вороничанин", "вороночанин", "вороначанин"],
    "воронив": ["воронивши"],
    "воронивши": ["воронив"],
    "вороника": ["водяника", "вороница"],
    "воронить": ["зевать", "хлопать ушами", "тупить"],
    "вороничанин": ["вороночанин", "вороначанин", "воронечанин"],
    "воронка": ["раструб", "кратер", "водоворот"],
    "воронковидный": ["воронкообразный", "воронкоподобный"],
    "воронковый": ["воронкообразный"],
    "воронкообразный": ["воронковый", "конусообразный"],
    "вороновый": ["воронов"],
    "вороной": ["чёрный", "вороный"],
    "воронок": ["городская ласточка"],
    "вороночанин": ["вороничанин", "вороначанин", "воронечанин"],
    "вороночинин": ["вороничанин", "вороначанин", "воронечанин"],
    "воронцовоалександровец": ["зеленокумец"],
    "воронь": ["чернота"],
    "воронёночек": ["воронёнок"],
    "воронёный": ["оксидированный", "чернёный"],
    "ворот": ["воротник"],
    "ворота": ["врата"],
    "воротив": ["воротивши"],
    "воротивши": ["воротив"],
    "воротить": ["вернуть", "возвратить"],
    "воротить рыло": ["рыло воротить", "воротить рылом", "отворачивать рыло"],
    "воротить рылом": ["воротить рыло", "рыло воротить"],
    "воротиться": ["вернуться", "возвратиться", "возвернуться"],
    "воротник": ["привратник"],
    "воротчик": ["вратарь", "голкипер"],
    "ворохнув": ["ворохнувши"],
    "ворохнувши": ["ворохнув"],
    "ворочав": ["ворочавши"],
    "ворочавши": ["ворочав"],
    "ворочанье": ["ворочание"],
    "ворочать": ["двигать", "поворачивать", "крутить", "перекатывать"],
    "ворошив": ["ворошивши"],
    "ворошивши": ["ворошив"],
    "ворошилка": ["ворошитель"],
    "ворошиловград": ["луганск"],
    "ворошиловградец": ["луганчанин", "луганец"],
    "ворошиловец": ["ворошиловский стрелок"],
    "ворошиловский стрелок": ["ворошиловец"],
    "ворошитель": ["ворошилка"],
    "ворсив": ["ворсивши"],
    "ворсивши": ["ворсив"],
    "ворсильный": ["ворсовальный"],
    "ворсильня": ["ворсовальня"],
    "ворсильщик": ["ворсовщик", "ворсочник"],
    "ворсинка": ["пиль", "фимбрия"],
    "ворсистость": ["мохнатость", "пушистость", "махровость"],
    "ворсить": ["ворсовать"],
    "ворситься": ["ворсоваться"],
    "ворсовав": ["ворсовавши"],
    "ворсовавши": ["ворсовав"],
    "ворсовальный": ["ворсильный"],
    "ворсовальня": ["ворсильня"],
    "ворсоваться": ["ворситься"],
    "ворсяной": ["ворсинчатый", "ворсистый"],
    "ворчав": ["ворчавши"],
    "ворчавши": ["ворчав"],
    "ворчание": ["брюзжание", "бурчание", "бухтение", "воркотня", "жужжание", "рычание"],
    "ворчанье": ["ворчание"],
    "ворчливо": ["сварливо", "брюзгливо"],
    "ворчливость": ["брюзгливость"],
    "ворчун": ["брюзга"],
    "ворюга": ["вор"],
    "вос-": ["воз-", "возо-", "вз-"],
    "восвояси": ["обратно", "домой"],
    "восемнадцатилетие": ["восемнадцатилетье"],
    "восемнадцатый": ["осьмнадцатый"],
    "восемнадцать": ["осьмнадцать", "восьмнадцать"],
    "восемь": ["восьмёрка", "осемь", "осмь"],
    "восемью": ["восьмикратно"],
    "воск": ["вощина"],
    "воскипав": ["воскипавши"],
    "воскипавши": ["воскипав"],
    "воскипев": ["воскипевши"],
    "воскипевши": ["воскипев"],
    "воскладав": ["воскладавши"],
    "воскладавши": ["воскладав"],
    "воскладать": ["возлагать", "налагать"],
    "воскликнув": ["воскликнувши"],
    "воскликнувши": ["воскликнув"],
    "воскликнуть": ["выкрикнуть", "вскричать"],
    "восклицав": ["восклицавши"],
    "восклицавши": ["восклицав"],
    "восклицание": ["воскликновение", "возглас"],
    "восклицанье": ["восклицание"],
    "восклицательный знак": ["знак восклицания", "восклицание"],
    "восклицать": ["вскрикивать", "выкрикивать"],
    "восклицать осанну": ["петь осанну", "славословить"],
    "восковник": ["воскоцветник", "вощанка", "восковница"],
    "восковница": ["восковник"],
    "воскормив": ["воскормивши"],
    "воскормивши": ["воскормив"],
    "воскормленец": ["воскормленник"],
    "воскормленник": ["воскормленец"],
    "воскормленница": ["воспитанница"],
    "воскраие": ["край", "кромка"],
    "воскресав": ["воскресавши"],
    "воскресавши": ["воскресав"],
    "воскресать": ["оживать"],
    "воскресение": ["воскресание", "воскрешение", "оживание", "возрождение", "пробуждение"],
    "воскресенье": ["воскресение"],
    "воскресив": ["воскресивши"],
    "воскресивши": ["воскресив"],
    "воскресить": ["оживить"],
    "воскреснув": ["воскреснувши"],
    "воскреснувши": ["воскреснув"],
    "воскреснуть": ["ожить", "вернуться"],
    "воскрешав": ["воскрешавши"],
    "воскрешавши": ["воскрешав"],
    "воскрешать": ["оживлять"],
    "воскрешенье": ["воскрешение"],
    "воскрикнув": ["воскрикнувши"],
    "воскрикнувши": ["воскрикнув"],
    "воскрилия": ["цицит"],
    "воскрылив": ["воскрыливши"],
    "воскрыливши": ["воскрылив"],
    "воскрыляв": ["воскрылявши"],
    "воскрылявши": ["воскрыляв"],
    "воскуренье": ["воскурение"],
    "воскурив": ["воскуривши"],
    "воскуривав": ["воскуривавши"],
    "воскуривавши": ["воскуривав"],
    "воскуривать": ["воскурять"],
    "воскуривши": ["воскурив"],
    "воскуряв": ["воскурявши"],
    "воскурявши": ["воскуряв"],
    "вослед": ["вслед"],
    "воспаление": ["возбуждение"],
    "воспаление лёгких": ["пневмония"],
    "воспаление хитрости": ["воспаление левой пятки", "воспаление левой пятки правого уха"],
    "воспаленье": ["воспаление"],
    "воспалив": ["воспаливши"],
    "воспаливши": ["воспалив"],
    "воспалить": ["разжечь", "возбудить"],
    "воспаляв": ["воспалявши"],
    "воспалявши": ["воспаляв"],
    "воспалять": ["воспламенять", "разжигать", "возбуждать"],
    "воспаренье": ["воспарение"],
    "воспарив": ["воспаривши"],
    "воспаривши": ["воспарив"],
    "воспарить": ["взлететь"],
    "воспаряв": ["воспарявши"],
    "воспарявши": ["воспаряв"],
    "воспарять": ["взлетать"],
    "воспев": ["воспевши"],
    "воспевав": ["воспевавши"],
    "воспевавши": ["воспевав"],
    "воспеванье": ["воспевание"],
    "воспеватель": ["восхвалитель", "прославитель"],
    "воспевать": ["прославлять"],
    "воспевши": ["воспев"],
    "воспетый": ["восхваленный", "увековеченный", "прославленный"],
    "воспеть": ["восславить"],
    "воспитав": ["воспитавши"],
    "воспитавши": ["воспитав"],
    "воспиталка": ["воспитательница"],
    "воспитание": ["обучение", "тренировка", "образование", "дрессировка", "воспитанность"],
    "воспитанность": ["благовоспитанность"],
    "воспитанный": ["благовоспитанный", "благонравный", "вежливый", "образованный"],
    "воспитанье": ["воспитание"],
    "воспитать": ["взрастить", "взлелеять", "вскормить", "вспоить", "вынянчить", "выхолить", "вырастить"],
    "воспитуемый": ["пестуемый"],
    "воспитывав": ["воспитывавши"],
    "воспитывавши": ["воспитывав"],
    "воспитывать": ["растить", "формировать", "прививать", "внушать", "развивать"],
    "восплакав": ["восплакавши"],
    "восплакавши": ["восплакав"],
    "воспламенение": ["возгорание"],
    "воспламененье": ["воспламенение"],
    "воспламенив": ["воспламенивши"],
    "воспламенивши": ["воспламенив"],
    "воспламенитель": ["зажигалка"],
    "воспламенить": ["зажечь", "поджечь", "воодушевить"],
    "воспламеняв": ["воспламенявши"],
    "воспламенявши": ["воспламеняв"],
    "воспламенять": ["зажигать", "поджигать", "воодушевлять"],
    "восплескав": ["восплескавши"],
    "восплескавши": ["восплескав"],
    "восплясать": ["заплясать"],
    "воспоив": ["воспоивши"],
    "воспоивши": ["воспоив"],
    "восполненье": ["восполнение"],
    "восполнив": ["восполнивши"],
    "восполнивши": ["восполнив"],
    "восполнимый": ["восстановимый"],
    "восполняв": ["восполнявши"],
    "восполнявши": ["восполняв"],
    "восполняемый": ["возобновляемый"],
    "восполнять": ["возмещать"],
    "воспоминав": ["воспоминавши"],
    "воспоминавши": ["воспоминав"],
    "воспоминания": ["мемуары"],
    "воспомнив": ["воспомнивши"],
    "воспомнивши": ["воспомнив"],
    "воспомянув": ["воспомянувши"],
    "воспомянувши": ["воспомянув"],
    "воспомянуть": ["вспомнить"],
    "воспоследовав": ["воспоследовавши"],
    "воспоследовавши": ["воспоследовав"],
    "воспрепятствовав": ["воспрепятствовавши"],
    "воспрепятствовавши": ["воспрепятствовав"],
    "воспрепятствовать": ["помешать"],
    "воспретив": ["воспретивши"],
    "воспретивши": ["воспретив"],
    "воспретить": ["запретить"],
    "воспрещав": ["воспрещавши"],
    "воспрещавши": ["воспрещав"],
    "воспрещать": ["запрещать"],
    "воспрещённый": ["запрещённый", "недозволенный"],
    "восприемник": ["восприемница", "крёстный отец", "крёстный"],
    "восприемница": ["крёстная мать", "крёстная"],
    "восприимав": ["восприимавши"],
    "восприимавши": ["восприимав"],
    "восприимать": ["воспринимать"],
    "воспринимание": ["восприятие"],
    "воспринимать": ["ощущать", "принимать", "истолковывать", "трактовать", "усваивать"],
    "воспринимать как должное": ["считать само собой разумеющимся"],
    "восприниматься": ["ощущаться", "приниматься", "истолковываться", "трактоваться", "усваиваться"],
    "восприняв": ["воспринявши"],
    "воспринявши": ["восприняв"],
    "воспринять": ["ощутить", "испытать", "принять", "усвоить", "понять", "расценить", "истолковать"],
    "восприяв": ["восприявши"],
    "восприявши": ["восприяв"],
    "восприятие": ["воспринятие", "воспринимание"],
    "восприять": ["воспринять", "узнать", "усвоить", "постигнуть", "прийти", "осилить", "возобладать"],
    "воспроизведенье": ["воспроизведение"],
    "воспроизводив": ["воспроизводивши"],
    "воспроизводивши": ["воспроизводив"],
    "воспроизводимость": ["повторяемость"],
    "воспряв": ["воспрявши"],
    "воспрявши": ["воспряв"],
    "воспрядать": ["пробуждаться"],
    "воспрядывав": ["воспрядывавши"],
    "воспрядывавши": ["воспрядывав"],
    "воспрянув": ["воспрянувши"],
    "воспрянувши": ["воспрянув"],
    "воспрянуть": ["воспрять", "вспрянуть"],
    "воспрять": ["воспрянуть"],
    "воспылав": ["воспылавши"],
    "воспылавши": ["воспылав"],
    "воспылать": ["воспламениться", "вспламениться", "запылать", "зажечься", "загореться"],
    "воспящать": ["препятствовать", "мешать"],
    "восседав": ["восседавши"],
    "восседавши": ["восседав"],
    "восседание": ["восседение"],
    "восседение": ["восседание"],
    "воссияв": ["воссиявши"],
    "воссиявши": ["воссияв"],
    "восславив": ["восславивши"],
    "восславивши": ["восславив"],
    "восславляв": ["восславлявши"],
    "восславлявши": ["восславляв"],
    "воссоединенье": ["воссоединение"],
    "воссоединив": ["воссоединивши"],
    "воссоединивши": ["воссоединив"],
    "воссоединяв": ["воссоединявши"],
    "воссоединявши": ["воссоединяв"],
    "воссоздав": ["воссоздавши"],
    "воссоздавав": ["воссоздававши"],
    "воссоздававши": ["воссоздавав"],
    "воссоздавши": ["воссоздав"],
    "воссоздание": ["возрождение", "восстановление"],
    "воссозданье": ["воссоздание"],
    "воссозидав": ["воссозидавши"],
    "воссозидавши": ["воссозидав"],
    "воссозидать": ["воссоздавать"],
    "восстав": ["восставши"],
    "восставав": ["восстававши"],
    "восстававши": ["восставав"],
    "восставать": ["вставать", "подниматься"],
    "восставив": ["восставивши"],
    "восставивши": ["восставив"],
    "восставляв": ["восставлявши"],
    "восставлявши": ["восставляв"],
    "восставши": ["восстав"],
    "восстанавливав": ["восстанавливавши"],
    "восстанавливавши": ["восстанавливав"],
    "восстанавливаемость": ["самовосстанавливаемость"],
    "восстанавливать": ["воссоздавать", "возрождать", "возобновлять", "подстрекать"],
    "восстание": ["бунт", "мятеж"],
    "восстановив": ["восстановивши"],
    "восстановивши": ["восстановив"],
    "восстановиться": ["возродиться", "возобновиться"],
    "восстановление": ["возрождение", "реконструкция", "реставрация", "восставление"],
    "восстановленное молоко": ["порошковое молоко"],
    "восстановленье": ["восстановление"],
    "восстановляв": ["восстановлявши"],
    "восстановлявши": ["восстановляв"],
    "восстановлять": ["восстанавливать"],
    "восстановляться": ["восстанавливаться"],
    "восстанье": ["восстание"],
    "восстать": ["встать", "подняться", "воспрянуть", "взбунтоваться", "поднять мятеж"],
    "воссылав": ["воссылавши"],
    "воссылавши": ["воссылав"],
    "востекав": ["востекавши"],
    "востекавши": ["востекав"],
    "восток": ["восход"],
    "востоковед": ["ориенталист"],
    "востоковедение": ["ориенталистика"],
    "востоковедный": ["востоковедческий"],
    "востоковедческий": ["востоковедный"],
    "восторгав": ["восторгавши"],
    "восторгавши": ["восторгав"],
    "восторгание": ["восхищение"],
    "восторгаться": ["восхищаться"],
    "восторженно": ["восхищённо"],
    "восторженный": ["восхищённый"],
    "восторжествовав": ["восторжествовавши"],
    "восторжествовавши": ["восторжествовав"],
    "восторжествовать": ["победить", "одержать верх"],
    "восточная германия": ["германская демократическая республика", "гдр"],
    "восточно-сибирское море": ["колымское море", "индигирское море"],
    "восточнофризский": ["восточнофризский язык", "затерландский фризский"],
    "восточнофризский язык": ["восточнофризский", "затерландский фризский язык"],
    "восточный административный округ": ["вао"],
    "восточный мурман": ["русская сторона", "русский берег"],
    "востребовав": ["востребовавши"],
    "востребовавши": ["востребовав"],
    "востребованность": ["спрос"],
    "востребованье": ["востребование"],
    "востребоваться": ["потребоваться"],
    "востренький": ["остренький"],
    "вострепетав": ["вострепетавши"],
    "вострепетавши": ["вострепетав"],
    "вострепетать": ["задрожать", "затрепетать", "встрепетать"],
    "вострив": ["востривши"],
    "востривши": ["вострив"],
    "вострить": ["точить"],
    "востроглазый": ["быстроглазый", "остроглазый", "глазастый"],
    "востроногий": ["подвижный", "прыткий", "шустрый", "проворный"],
    "востроносый": ["остроносый"],
    "вострубив": ["вострубивши"],
    "вострубивши": ["вострубив"],
    "воструха": ["вострушка"],
    "вострушка": ["воструха"],
    "вострый": ["острый", "заострённый", "проницательный"],
    "восхваленье": ["восхваление"],
    "восхвалив": ["восхваливши"],
    "восхваливши": ["восхвалив"],
    "восхваляв": ["восхвалявши"],
    "восхвалявши": ["восхваляв"],
    "восхвалять": ["прославлять", "воспевать", "превозносить"],
    "восхваляться": ["превозноситься", "расхваливаться"],
    "восхитив": ["восхитивши"],
    "восхитивши": ["восхитив"],
    "восхитительно": ["прекрасно", "изумительно", "превосходно", "блестяще", "необычайно"],
    "восхитительный": ["великолепный", "изумительный", "очаровательный", "превосходный", "прекрасный", "чудесный"],
    "восхищав": ["восхищавши"],
    "восхищавши": ["восхищав"],
    "восхищать": ["изумлять"],
    "восхищаться": ["восторгаться", "подниматься"],
    "восхищение": ["восторгание", "ликование", "восторг"],
    "восхищённо": ["восторженно"],
    "восход": ["восхождение", "рассвет", "восток"],
    "восходив": ["восходивши"],
    "восходивши": ["восходив"],
    "восходитель": ["горовосходитель"],
    "восходить": ["взбираться", "подниматься", "влезать", "всходить"],
    "восхождение": ["подъём"],
    "восхожденье": ["восхождение"],
    "восхотев": ["восхотевши"],
    "восхотевши": ["восхотев"],
    "восчувствовав": ["восчувствовавши"],
    "восчувствовавши": ["восчувствовав"],
    "восчувствовать": ["почувствовать", "ощутить"],
    "восшествие": ["восхождение"],
    "восшумев": ["восшумевши"],
    "восшумевши": ["восшумев"],
    "вось": ["вот", "во"],
    "восьмерив": ["восьмеривши"],
    "восьмеривши": ["восьмерив"],
    "восьмерной": ["восьмичастный", "восьмикратный"],
    "восьмеро": ["восемь", "осьмеро"],
    "восьми-": ["осьми-", "окта-"],
    "восьмибитный": ["восьмибитовый", "однобайтовый"],
    "восьмибитовый": ["восьмибитный", "однобайтовый"],
    "восьмигранный": ["октаэдральный"],
    "восьмизначный": ["восьмизнаковый"],
    "восьмиклассник": ["восьмиклашка", "восьмиклассница"],
    "восьмикомпонентный": ["восьмичастный"],
    "восьмилеток": ["восьмилетка"],
    "восьмина": ["восьмушка", "осьмина", "осьмушка", "получетверть", "получеть"],
    "восьмиобразный": ["крестообразный"],
    "восьмиокись": ["восьмиоксид", "октооксид"],
    "восьмиразрядность": ["восьмизначность"],
    "восьмиразрядный": ["восьмибитный"],
    "восьмистишие": ["октава"],
    "восьмистишье": ["восьмистишие"],
    "восьмичастный": ["восьмерной", "восьмикомпонентный"],
    "восьмиэтажка": ["восьмиэтажный", "здание"],
    "восьмиэтажный": ["восьмиуровневый"],
    "восьмнадцать": ["осьмнадцать"],
    "восьмой": ["осьмой"],
    "восьмушка": ["получеть", "получетверть", "осьмушка", "осьмина"],
    "вот": ["гласуване", "гласоподаване", "избор"],
    "вот где собака зарыта": ["из-за чего весь сыр-бор загорелся", "вот где собака порылась"],
    "вот где собака порылась": ["из-за чего весь сыр-бор загорелся", "вот где собака зарыта"],
    "вот ещё": ["как бы не так"],
    "вот и весь хуй": ["и все дела", "вот и все дела", "такие пироги", "вот такие пироги", "вот такие пироги с котятками", "и весь хрен", "и весь хер", "вот и весь хрен", "вот и весь хер", "вот и весь хрен до копейки", "вот и весь хер до копейки", "вот и весь хрен до копеечки", "вот и весь хер до копеечки", "и весь хуй", "вот и весь хуй до копейки"],
    "вот какие пироги": ["вот такие пироги"],
    "вот такие пироги": ["вот какие пироги"],
    "вот-вот": ["вскоре", "сейчас", "щас", "того и гляди"],
    "вотан": ["один"],
    "вотанизм": ["одинизм"],
    "вотермарк": ["вотермарка"],
    "вотермарка": ["вотермарк"],
    "вотировав": ["вотировавши"],
    "вотировавши": ["вотировав"],
    "вотировать": ["голосовать"],
    "воткав": ["воткавши"],
    "воткавши": ["воткав"],
    "воткнув": ["воткнувши"],
    "воткнувши": ["воткнув"],
    "воткнуть": ["вонзить", "всадить", "вколоть"],
    "воткнуться": ["вонзиться"],
    "вотский": ["вотяцкий", "удмуртский"],
    "вотчим": ["отчим"],
    "вотчина": ["отчина", "аллод", "бокленд", "удел", "волость"],
    "вотще": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "втуне", "всуе", "бесплодно", "зазря"],
    "вотэбаутизм": ["какнасчётизм"],
    "вотяк": ["вотин", "удмурт"],
    "вотянка": ["вотячка", "удмуртка"],
    "вотяцкий": ["вотский", "удмуртский"],
    "вотячка": ["вотянка", "удмуртка"],
    "воук-идеология": ["вокизм"],
    "воха": ["вова", "вован"],
    "вохкий": ["волглый"],
    "вохменин": ["вохмяк", "вохмянин", "вохомец"],
    "вохмуша": ["вохмяк", "вохмячка", "вохомец", "вохомка"],
    "вохмяк": ["вохомец", "вохмянин"],
    "вохмянин": ["вохмяк", "вохменин", "вохомец"],
    "вохмянка": ["вохмячка"],
    "вохмячка": ["вохмянка"],
    "вохомец": ["вохмяк", "вохменин", "вохмянин"],
    "вохомка": ["вохмянка", "вохмячка"],
    "вохровец": ["вохра"],
    "вохряной": ["жёлтый"],
    "воцаренье": ["воцарение"],
    "воцарив": ["воцаривши"],
    "воцаривши": ["воцарив"],
    "воцариться": ["вступать на трон", "водвориться", "установиться", "настать", "наступить", "прийти"],
    "воцаряв": ["воцарявши"],
    "воцарявши": ["воцаряв"],
    "воцарять": ["короновать", "устанавливать"],
    "воцерковив": ["воцерковивши"],
    "воцерковивши": ["воцерковив"],
    "воцерковление": ["катехизация"],
    "воцерковляв": ["воцерковлявши"],
    "воцерковлявши": ["воцерковляв"],
    "вочеловечив": ["вочеловечивши"],
    "вочеловечивав": ["вочеловечивавши"],
    "вочеловечивавши": ["вочеловечивав"],
    "вочеловечивши": ["вочеловечив"],
    "вошкужвож": ["вожкуж-вож"],
    "вошь": ["пухоед", "вша", "крыса"],
    "вощанка": ["вощина"],
    "вощаной": ["восковой", "вощёный"],
    "вощечка": ["цера"],
    "вощив": ["вощивши"],
    "вощивши": ["вощив"],
    "воющий": ["заунывный"],
    "воюющий": ["сражающийся"],
    "вояж": ["поездка", "путешествие"],
    "вояжировав": ["вояжировавши"],
    "вояжировавши": ["вояжировав"],
    "вояжировать": ["путешествовать"],
    "вояка": ["воин"],
    "вояченько": ["вояк"],
    "впадав": ["впадавши"],
    "впадавши": ["впадав"],
    "впадание": ["впадение"],
    "впадать": ["вваливаться"],
    "впадение": ["впадание"],
    "впаденье": ["впадение"],
    "впадина": ["углубление", "яма", "ямка", "понижение"],
    "впадлу": ["западло", "зашквар", "зашкварно", "стыдно", "унизительно", "позорно", "зазорно", "негоже", "претит", "лень", "неохота", "жалко"],
    "впаивав": ["впаивавши"],
    "впаивавши": ["впаивав"],
    "впалзывав": ["впалзывавши"],
    "впалзывавши": ["впалзывав"],
    "впалый": ["вдавшийся", "ввалившийся", "вогнутый"],
    "впарив": ["впаривши"],
    "впаривав": ["впаривавши"],
    "впаривавши": ["впаривав"],
    "впаривать": ["всучивать", "вкручивать", "всучать"],
    "впаривши": ["впарив"],
    "впархивав": ["впархивавши"],
    "впархивавши": ["впархивав"],
    "впасть": ["ввалиться"],
    "впасть в немилость": ["разонравиться"],
    "впахивав": ["впахивавши"],
    "впахивавши": ["впахивав"],
    "впаяв": ["впаявши"],
    "впаявши": ["впаяв"],
    "впевав": ["впевавши"],
    "впевавши": ["впевав"],
    "впекав": ["впекавши"],
    "впекавши": ["впекав"],
    "впендюрив": ["впендюривши"],
    "впендюривши": ["впендюрив"],
    "впервой": ["впервые"],
    "впервые": ["впервой", "впервинку"],
    "вперебивку": ["вперебив", "вперебой", "наперебой"],
    "вперебой": ["вперебив", "вперебивку", "наперебой"],
    "вперев": ["впёрши"],
    "вперевалку": ["вразвалку"],
    "вперевалочку": ["вперевалку", "вразвалку", "вразвалочку", "утицей", "уточкой", "враскачку", "с развальцем"],
    "вперевшись": ["впёршись"],
    "вперевёрт": ["вперевёртку", "наоборот"],
    "вперевёртку": ["вперевёрт"],
    "вперегонки": ["вперегон", "вперегонку", "наперегонки"],
    "вперегонку": ["вперегонки", "наперегонки"],
    "впереди": ["спереди", "потом"],
    "вперемешку": ["смешанно", "беспорядочно", "хаотически"],
    "вперив": ["вперивши"],
    "вперивать": ["вперять", "устремлять", "направлять", "уставлять", "таращить", "пялить", "впихивать", "всовывать", "втискивать"],
    "вперивши": ["вперив"],
    "впериться": ["уставиться"],
    "вперяв": ["вперявши"],
    "вперявши": ["вперяв"],
    "вперёд": ["наперёд", "авансом", "заранее"],
    "вперёдсмотрящий": ["новатор", "первопроходец", "первооткрыватель", "пионер", "застрельщик"],
    "впечатав": ["впечатавши"],
    "впечатавши": ["впечатав"],
    "впечатлев": ["впечатлевши"],
    "впечатлевав": ["впечатлевавши"],
    "впечатлевавши": ["впечатлевав"],
    "впечатлевши": ["впечатлев"],
    "впечатление": ["эффект"],
    "впечатленье": ["впечатление"],
    "впечатлеться": ["впечатлиться"],
    "впечатлив": ["впечатливши"],
    "впечатливши": ["впечатлив"],
    "впечатлительный": ["восприимчивый"],
    "впечатляв": ["впечатлявши"],
    "впечатлявши": ["впечатляв"],
    "впечатляющий": ["внушительный", "неслабый"],
    "впечатывав": ["впечатывавши"],
    "впечатывавши": ["впечатывав"],
    "впив": ["впивши"],
    "впивав": ["впивавши"],
    "впивавши": ["впивав"],
    "впивать": ["пить"],
    "впиваться": ["вонзаться", "вцепляться"],
    "впивши": ["впив"],
    "впинав": ["впинавши"],
    "впинавши": ["впинав"],
    "впиндюрив": ["впиндюривши"],
    "впиндюривав": ["впиндюривавши"],
    "впиндюривавши": ["впиндюривав"],
    "впиндюривши": ["впиндюрив"],
    "впирав": ["впиравши"],
    "впиравши": ["впирав"],
    "вписав": ["вписавши"],
    "вписавши": ["вписав"],
    "вписон": ["вписка"],
    "вписывав": ["вписывавши"],
    "вписывавши": ["вписывав"],
    "вписывание": ["вписка"],
    "вписывать": ["дописывать", "заносить"],
    "вписываться": ["дописываться", "записываться", "приписываться", "вмещаться", "входить", "умещаться", "встраиваться", "включаться", "интегрироваться", "сочетаться", "гармонировать"],
    "впитав": ["впитавши"],
    "впитавши": ["впитав"],
    "впитывав": ["впитывавши"],
    "впитывавши": ["впитывав"],
    "впитывать": ["вбирать", "поглощать"],
    "впитываться": ["вбираться"],
    "впихав": ["впихавши"],
    "впихавши": ["впихав"],
    "впихаться": ["впихнуться"],
    "впихивав": ["впихивавши"],
    "впихивавши": ["впихивав"],
    "впихивать": ["запихивать"],
    "впихнув": ["впихнувши"],
    "впихнувши": ["впихнув"],
    "впихнуть": ["втиснуть", "всунуть", "втолкнуть", "впарить", "втюхать", "пристроить"],
    "впк": ["военно-промышленный комплекс"],
    "вплавив": ["вплавивши"],
    "вплавивши": ["вплавив"],
    "вплавляв": ["вплавлявши"],
    "вплавлявши": ["вплавляв"],
    "вплеснув": ["вплеснувши"],
    "вплеснувши": ["вплеснув"],
    "вплетав": ["вплетавши"],
    "вплетавши": ["вплетав"],
    "вплетание": ["вплетение"],
    "вплетение": ["вплетание"],
    "вплигнути": ["уплигнути", "вскочити", "ускочити"],
    "вплотную": ["тесно", "плотненько", "всерьёз", "плотно"],
    "вплоть": ["вплотную", "включая"],
    "вплоть до": ["до", "до самого", "включая"],
    "вплыв": ["вплывши"],
    "вплывав": ["вплывавши"],
    "вплывавши": ["вплывав"],
    "вплывши": ["вплыв"],
    "вплюснув": ["вплюснувши"],
    "вплюснувши": ["вплюснув"],
    "вплёскивав": ["вплёскивавши"],
    "вплёскивавши": ["вплёскивав"],
    "вповалку": ["рядом", "вповал"],
    "впоймав": ["впоймавши"],
    "впоймавши": ["впоймав"],
    "впоймать": ["поймать", "словить"],
    "вползав": ["вползавши"],
    "вползавши": ["вползав"],
    "вползание": ["вскарабкивание", "втягивание"],
    "вполне": ["полностью", "абсолютно", "совершенно"],
    "вполоборота": ["боком", "вполразворота"],
    "вполсна": ["чутко"],
    "вполцены": ["за полцены", "вполстоимости"],
    "впопад": ["кстати", "вовремя", "уместно", "к месту"],
    "впополам": ["напополам", "пополам", "надвое"],
    "впопыхах": ["второпях", "поспешно"],
    "впору": ["как раз", "в самый раз"],
    "впорхнув": ["впорхнувши"],
    "впорхнувши": ["впорхнув"],
    "впоследнее": ["впоследние"],
    "впоследние": ["впоследнее"],
    "впоследствии": ["затем", "позднее", "после", "потом", "позже"],
    "впотьмах": ["в темноте"],
    "вправду": ["взаправду"],
    "вправе": ["иметь право"],
    "вправив": ["вправивши"],
    "вправивши": ["вправив"],
    "вправляв": ["вправлявши"],
    "вправлявши": ["вправляв"],
    "вправлять": ["заправлять"],
    "вправо": ["направо"],
    "впредь": ["впоследствии", "затем", "потом", "отныне", "отселе", "отсель", "вперёд"],
    "впредь до": ["до"],
    "впрессовав": ["впрессовавши"],
    "впрессовавши": ["впрессовав"],
    "впрессовывав": ["впрессовывавши"],
    "впрессовывавши": ["впрессовывав"],
    "вприпрыжку": ["прыжками", "подпрыгивая", "припрыгивая"],
    "вприскочку": ["вприпрыжку"],
    "вприснути": ["уприснути", "впорснути", "упорснути"],
    "впритруску": ["трусцой"],
    "впритул": ["упритул"],
    "впритык": ["вплотную"],
    "вприщур": ["вприщурку"],
    "впроброс": ["между прочим", "мимоходом", "попутно", "походя"],
    "впровадження": ["впроваджування"],
    "впроголодь": ["не жрамши"],
    "впрок": ["про запас"],
    "впросинь": ["иссиня"],
    "впросонках": ["впросонье"],
    "впросонье": ["впросоньи", "впросонках"],
    "впросоньи": ["впросонье", "впросонках"],
    "впросырь": ["сыроватый", "восырой", "восырь"],
    "впрочем": ["всё же", "всё-таки", "тем не менее", "с другой стороны", "в прочем"],
    "впрыгивав": ["впрыгивавши"],
    "впрыгивавши": ["впрыгивав"],
    "впрыгивать": ["запрыгивать"],
    "впрыгнув": ["впрыгнувши"],
    "впрыгнувши": ["впрыгнув"],
    "впрыск": ["впрыскивание"],
    "впрыскивав": ["впрыскивавши"],
    "впрыскивавши": ["впрыскивав"],
    "впрыскиванье": ["впрыскивание"],
    "впрыснув": ["впрыснувши"],
    "впрыснувши": ["впрыснув"],
    "впрягав": ["впрягавши"],
    "впрягавши": ["впрягав"],
    "впрягание": ["впряжение"],
    "впрягаться": ["вступаться", "заступаться"],
    "впрядав": ["впрядавши"],
    "впрядавши": ["впрядав"],
    "впрядывав": ["впрядывавши"],
    "впрядывавши": ["впрядывав"],
    "впряжённый": ["запряжённый"],
    "впрямь": ["в самом деле", "действительно", "прям"],
    "впуклый": ["вогнутый", "полый"],
    "впуск": ["впускание"],
    "впускав": ["впускавши"],
    "впускавши": ["впускав"],
    "впускание": ["впуск"],
    "впустив": ["впустивши"],
    "впустивши": ["впустив"],
    "впутав": ["впутавши"],
    "впутавши": ["впутав"],
    "впутать": ["втянуть"],
    "впутывав": ["впутывавши"],
    "впутывавши": ["впутывав"],
    "впялив": ["впяливши"],
    "впяливав": ["впяливавши"],
    "впяливавши": ["впяливав"],
    "впяливши": ["впялив"],
    "впятив": ["впятивши"],
    "впятивши": ["впятив"],
    "впячивав": ["впячивавши"],
    "впячивавши": ["впячивав"],
    "впёрши": ["вперев"],
    "впёршись": ["вперевшись"],
    "врабатывав": ["врабатывавши"],
    "врабатывавши": ["врабатывав"],
    "врабатываемость": ["адаптируемость"],
    "вработав": ["вработавши"],
    "вработавши": ["вработав"],
    "врав": ["вравши"],
    "вравши": ["врав"],
    "враг": ["ворог", "противник", "неприятель", "недруг"],
    "врагиня": ["недоброжелательница"],
    "враждебно": ["недоброжелательно", "неприязненно"],
    "враждебность": ["неприязненность", "неприязнь", "недоброжелательство", "нерасположение", "недружелюбие"],
    "враждебный": ["недоброжелательный", "вражеский"],
    "враждовав": ["враждовавши"],
    "враждовавши": ["враждовав"],
    "враждовать": ["ссориться"],
    "вражеский": ["неприятельский", "вражий"],
    "вражество": ["вражда"],
    "вражий": ["вражеский", "неприятельский", "дьявольский", "бесовский"],
    "враз": ["одновременно", "вместе", "разом", "сразу"],
    "вразбивку": ["отдельно", "вразрядку"],
    "вразброд": ["разбродно"],
    "вразбродку": ["вразброд"],
    "вразброс": ["порознь", "разбросанно", "хаотично", "беспорядочно", "непоследовательно"],
    "враздрай": ["несогласованно", "вразнобой"],
    "вразлёт": ["вразмёт", "враспах"],
    "вразмёт": ["вразлёт"],
    "вразнобой": ["беспорядочно", "несогласованно", "недружно", "вразброд"],
    "вразнос": ["навынос", "на износ", "как попало", "наперекосяк", "сильно", "вовсю"],
    "вразрез": ["вопреки", "наперекор"],
    "вразрядку": ["разрядкой", "раздельно"],
    "вразумив": ["вразумивши"],
    "вразумивши": ["вразумив"],
    "вразумительно": ["ясно", "понятно", "внятно", "убедительно"],
    "вразумительность": ["ясность", "точность", "чёткость"],
    "вразумительный": ["понятный", "внятный", "ясный", "убедительный"],
    "вразумить": ["научить", "просветить"],
    "вразумленье": ["вразумление"],
    "вразумляв": ["вразумлявши"],
    "вразумлявши": ["вразумляв"],
    "вразумлять": ["поучать"],
    "враль": ["обманщик", "врун", "лжец", "лгун", "пустослов"],
    "враньё": ["ложь", "выдумка", "вздор", "небылица", "неправда", "нелепость"],
    "враскоряку": ["враскорячку", "раскорячившись", "раскорякой", "раскорякою", "на раскоряку", "враскорячки"],
    "враскорячку": ["враскоряку", "раскорячившись", "раскорякой", "раскорякою", "на раскоряку", "враскорячки"],
    "врасплох": ["неожиданно", "внезапно"],
    "врассыпку": ["врассыпную"],
    "врассыпную": ["врассыпку"],
    "врастав": ["враставши"],
    "враставши": ["врастав"],
    "врата": ["ворота", "вход"],
    "вратарский": ["голкиперский"],
    "вратарствовав": ["вратарствовавши"],
    "вратарствовавши": ["вратарствовав"],
    "вратарствовать": ["стоять на воротах"],
    "вратарь": ["привратник", "голкипер", "воротчик"],
    "врать": ["ошибаться", "фальшивить", "детонировать"],
    "врахування": ["урахування"],
    "врач": ["доктор", "медик", "лекарь", "эскулап", "знахарь"],
    "врач-педиатр": ["педиатр", "детский врач"],
    "врачебный": ["медицинский"],
    "врачевав": ["врачевавши"],
    "врачевавши": ["врачевав"],
    "врачевание": ["лекарство", "лечение"],
    "врачеванье": ["врачевание"],
    "врачеватель": ["целитель"],
    "врачевать": ["лечить", "целить", "исцелять", "облегчать"],
    "врачиха": ["врач", "докторша"],
    "врачица": ["врачиха", "докторша", "женщина-врач"],
    "вращав": ["вращавши"],
    "вращавши": ["вращав"],
    "вращание": ["вращение"],
    "вращательный": ["поворотный", "крутильный", "круговой"],
    "вращать": ["вертеть", "крутить"],
    "вращаться": ["вертеться", "крутиться", "поворачиваться", "оборачиваться", "возвращаться", "бывать"],
    "вращая": ["вертя"],
    "вращение": ["кручение", "поворот"],
    "вред": ["ущерб", "шкода", "зло"],
    "вредив": ["вредивши"],
    "вредивши": ["вредив"],
    "вредина": ["вреднюга", "вреднюха"],
    "вредительница": ["губительница"],
    "вредительствовав": ["вредительствовавши"],
    "вредительствовавши": ["вредительствовав"],
    "вредник": ["списочник"],
    "вредничав": ["вредничавши"],
    "вредничавши": ["вредничав"],
    "вредничание": ["вредничанье"],
    "вредничанье": ["вредничание"],
    "вредный": ["вредоносный", "грязный", "недоброжелательный", "злой", "зловредный"],
    "вредонос": ["зловред", "компьютерный", "вредитель", "вредоносная программа", "малварь"],
    "вредоносная программа": ["зловредная программа", "вредонос", "зловред", "малварь"],
    "врезав": ["врезавши"],
    "врезавши": ["врезав"],
    "врезаться": ["воткнуться", "вонзиться", "вдаться", "вклиниться", "ворваться", "запечатлеться", "наскочить", "налететь", "втюриться", "влюбиться"],
    "врезка": ["врезание", "врезывание", "вставка", "врез"],
    "врезывав": ["врезывавши"],
    "врезывавши": ["врезывав"],
    "вректи": ["уректи"],
    "временами": ["иногда", "порой", "время от времени", "подчас"],
    "временив": ["временивши"],
    "временивши": ["временив"],
    "времениподобный": ["временноподобный", "времяподобный", "времяобразный"],
    "временить": ["мешкать", "медлить", "выжидать"],
    "временник": ["летопись", "хроника", "хронограф", "летописец"],
    "временноподобный": ["времениподобный", "времяподобный", "времяобразный"],
    "временный": ["краткосрочный", "мимолётный", "непостоянный", "преходящий", "скоропреходящий", "скоротечный"],
    "временщик": ["выползень", "фаворит", "любимец", "припадочный", "калиф на час", "халиф на час"],
    "временье": ["время"],
    "время года": ["сезон", "пора года"],
    "время от времени": ["временами", "по временам", "порой", "иногда", "бывает"],
    "времяисчисление": ["летосчисление", "летоисчисление", "времясчисление", "времясчисленье", "летосчисленье", "летоисчисленье"],
    "времяпрепровождение": ["времяпровождение", "занятие"],
    "времяпрепровожденье": ["времяпровождение"],
    "времяпровождение": ["времяпрепровождение"],
    "времяпровожденье": ["времяпровождение"],
    "вретен": ["уврат"],
    "вретище": ["рубище", "власяница", "веретье", "рядно", "ряднина", "рвань", "рванина", "рваньё", "отрепье", "отрепья", "лохмотье", "лохмотья", "лохмотьище", "обносок", "гуня"],
    "врид": ["врио"],
    "врикшасана": ["поза дерева"],
    "вринув": ["вринувши"],
    "вринувши": ["вринув"],
    "врио": ["временно исполняющий обязанности", "временно исполняющая обязанности", "местоблюститель"],
    "врисовав": ["врисовавши"],
    "врисовавши": ["врисовав"],
    "врисовывав": ["врисовывавши"],
    "врисовывавши": ["врисовывав"],
    "врн": ["воронеж", "столица черноземья", "врождённая расщелина нёба"],
    "врода": ["вигляд", "краса"],
    "вроде": ["наподобие"],
    "вродливий": ["гарний", "красивий"],
    "врождённая грамотность": ["языковое чутье"],
    "врождённый": ["природный"],
    "врозь": ["врознь", "поврозь", "порознь", "в отдельности", "в раздельности", "по раздельности", "раздельно", "вразнобой"],
    "вронскиан": ["определитель вронского"],
    "вростав": ["вроставши"],
    "вроставши": ["вростав"],
    "вротобранка": ["минетчица", "хуесоска"],
    "вроцлавец": ["вроцлавянин", "бреславец"],
    "вроцлавянин": ["вроцлавец", "бреславец"],
    "врубав": ["врубавши"],
    "врубавши": ["врубав"],
    "врубаться": ["понимать", "постигать"],
    "врубив": ["врубивши"],
    "врубивши": ["врубив"],
    "врубить съебаторы": ["съебаторы врубить", "съебаться", "свалить", "сдристнуть"],
    "врун": ["враль", "лгун", "лжец", "брехун", "брехло"],
    "врунья": ["брехунья", "лгунья", "вруха", "врушка", "вруша", "обманщица", "вралья"],
    "вручав": ["вручавши"],
    "вручавши": ["вручав"],
    "вручать": ["отдавать", "передавать", "давать", "вверять"],
    "врученье": ["вручение"],
    "вручив": ["вручивши"],
    "вручивши": ["вручив"],
    "вручить": ["дать", "вверить", "доверить"],
    "вручную": ["руками"],
    "вруша": ["лжец", "лгун", "врун", "враль", "врунишка", "брехун", "обманщик"],
    "вруша редкозубая": ["вруша", "врушка", "врунишка", "врун", "врунья"],
    "врушка": ["вруша", "врунишка", "лжец", "лгун", "врун", "враль", "брехун", "обманщик", "лгунья", "врунья", "вралиха", "брехунья", "обманщица"],
    "връв": ["шнур"],
    "връстник": ["акран"],
    "връх": ["възвишение", "зенит", "разцвет", "острие"],
    "връщане": ["завръщане", "повръщане"],
    "врыв": ["врывши"],
    "врывав": ["врывавши"],
    "врывавши": ["врывав"],
    "врывание": ["вкапывание", "зарывание"],
    "врывать": ["вкапывать"],
    "врываться": ["вкапываться", "углубляться", "зарываться"],
    "врывши": ["врыв"],
    "врыть": ["вкопать"],
    "врэжмаш": ["душман", "неприетин", "потривник"],
    "врютить": ["втолкнуть", "втиснуть", "впихнуть", "запихнуть", "засунуть", "впутать", "втянуть"],
    "врява": ["шум", "глъч", "олелия", "глъчка", "гюрултия", "дандания"],
    "вряд": ["едва"],
    "вряд ли": ["едва ли", "навряд ли", "сомнительно", "маловероятно", "вряд"],
    "вс": ["армия"],
    "всадив": ["всадивши"],
    "всадивши": ["всадив"],
    "всадник": ["наездник", "эквит"],
    "всадница": ["наездница"],
    "всаживав": ["всаживавши"],
    "всаживавши": ["всаживав"],
    "всаживание": ["всаживанье"],
    "всаживать": ["вонзать"],
    "всамделишный": ["взаправдашний", "настоящий", "подлинный"],
    "всасывав": ["всасывавши"],
    "всасывавши": ["всасывав"],
    "всачивав": ["всачивавши"],
    "всачивавши": ["всачивав"],
    "всверлив": ["всверливши"],
    "всверливав": ["всверливавши"],
    "всверливавши": ["всверливав"],
    "всверливши": ["всверлив"],
    "все глаза высмотреть": ["все глаза проглядеть"],
    "все-на-все": ["всё же", "всё-таки"],
    "всеблагий": ["всеблагой"],
    "всевав": ["всевавши"],
    "всевавши": ["всевав"],
    "всеведение": ["всезнание", "всеведенье", "всезнанье"],
    "всеведенье": ["всеведение"],
    "всеведущий": ["всезнающий"],
    "всевидец": ["бог", "прозорливец"],
    "всевластие": ["полновластие"],
    "всевластный": ["всемогущий", "всесильный"],
    "всевластье": ["всевластие"],
    "всевозрастной": ["разновозрастной"],
    "всевышний": ["бог"],
    "всегдашний": ["постоянный"],
    "всего": ["итого", "в общей сложности", "лишь", "только", "всего хорошего", "всего доброго", "до свидания"],
    "всего доброго": ["удачи", "до свидания"],
    "всего лишь": ["не больше чем", "не более чем", "только", "только лишь", "всего-навсего"],
    "всего хорошего": ["всего доброго"],
    "всего-навсего": ["всего", "всего-то", "лишь", "только", "просто"],
    "всего-то": ["всего", "всего лишь", "всего-навсего", "всего только", "лишь", "только"],
    "вседенно": ["вседневно", "ежедневно", "каждодневно", "ежеденно", "ежедённо", "буднично", "обыденно", "повседневно"],
    "всеевропейский": ["общеевропейский", "панъевропейский"],
    "всезнайка": ["ходячая энциклопедия"],
    "всезнайство": ["всезнание"],
    "всезнання": ["всезнайство"],
    "всезнанье": ["всезнание"],
    "всезнающий": ["всеведущий"],
    "всей душой": ["всем сердцем", "всем существом"],
    "вселена": ["свят", "мир", "всемир", "природа", "космос"],
    "вселение": ["заселение"],
    "вселенная": ["космос", "мир", "мироздание", "свет", "земля"],
    "вселенский": ["мировой", "всемирный", "космический", "широкомасштабный", "экуменический", "общецерковный"],
    "вселенскость": ["всемирность"],
    "вселив": ["вселивши"],
    "вселивши": ["вселив"],
    "вселить": ["поселить", "внушить"],
    "вселиться": ["поселиться"],
    "вселуг": ["овселуг", "вселук", "вселуки"],
    "вселюбимость": ["всеблагость"],
    "вселяв": ["вселявши"],
    "вселявши": ["вселяв"],
    "вселять": ["заронять"],
    "всем сердцем": ["всей душой", "всем существом"],
    "всем сестрам по серьгам": ["всякому старцу по ставцу"],
    "всем существом": ["всем сердцем", "всей душой"],
    "всеми фибрами души": ["всеми жабрами души"],
    "всемилостивейший": ["всемилостивый"],
    "всемилостиво": ["милостиво"],
    "всеминутный": ["ежеминутный"],
    "всемир": ["вселена", "свят", "мир", "природа", "космос"],
    "всемирная организация здравоохранения": ["воз"],
    "всемирная паутина": ["веб"],
    "всемирная сеть": ["интернет", "всемирная паутина"],
    "всемирно": ["повсеместно", "глобально"],
    "всемирный": ["мировой", "глобальный", "универсальный"],
    "всемогущество": ["всесилие"],
    "всемогущий": ["всесильный", "всемощный"],
    "всенаправленный": ["ненаправленный"],
    "всенародно": ["общенародно", "прилюдно"],
    "всенародный": ["общенациональный", "общенародный", "публичный"],
    "всенепременно": ["обязательно", "непременно", "конечно", "несомненно"],
    "всенепременный": ["непременный", "обязательный"],
    "всенижайший": ["покорнейший", "смиренный", "глубочайший"],
    "всенощная": ["всенощное бдение", "полиелей", "всеночная", "всенощница"],
    "всенощный": ["всеночный"],
    "всеобщий": ["поголовный", "повальный", "тотальный", "сплошной", "общий", "всенародный", "всемирный"],
    "всеобщность": ["всесторонность", "тотальность", "глобальность"],
    "всеобъемлющий": ["всесторонний"],
    "всеоружье": ["всеоружие"],
    "всеохватный": ["всеобъемлющий"],
    "всеохватывающий": ["всеобъемлющий", "всесторонний", "всеобщий", "полный", "общий", "универсальный"],
    "всеощущающий": ["всечувствующий"],
    "всепожирающий": ["всепоглощающий"],
    "всепроникающий": ["всепронизывающий"],
    "всепрощение": ["всепрощенье", "всепрощенчество"],
    "всепрощенье": ["всепрощение"],
    "всероссийская проверочная работа": ["впр"],
    "всесветный": ["всемирный", "всеобщий", "мировой", "вселенский", "планетарный", "всеобъемлющий", "всеохватный", "безграничный"],
    "всесилие": ["всесильность", "всемогущество", "всесилье"],
    "всесилье": ["всесилие"],
    "всесильный": ["всемогущий"],
    "всеславянский": ["общеславянский", "панславянский"],
    "всесовершенный": ["идеальный"],
    "всесожженье": ["всесожжение"],
    "всесоюзная здравница": ["столица курортов"],
    "всесторонне": ["разносторонне", "многосторонне", "полноценно"],
    "всесторонний": ["полный", "разносторонний", "многопрофильный"],
    "всесторонность": ["многоохватность", "универсализм", "глобальность", "всеобщность", "многогранность", "полнота"],
    "всеуслышанье": ["всеуслышание"],
    "всех шерстей": ["всех мастей", "всевозможный", "на любой вкус"],
    "всецело": ["полностью", "целиком", "исключительно"],
    "всецелый": ["совершенный", "безраздельный", "нераздельный", "бескомпромиссный"],
    "всечасно": ["ежечасно", "постоянно"],
    "всечасный": ["ежечасный"],
    "всечеловеческий": ["общечеловеческий"],
    "всеяв": ["всеявши"],
    "всеявши": ["всеяв"],
    "всеядность": ["эврифагия", "пантофагия", "миксофагия"],
    "всеядный": ["эврифаг", "омнивор", "эвритроф", "неразборчивый", "нетребовательный"],
    "вскакав": ["вскакавши"],
    "вскакавши": ["вскакав"],
    "вскакивав": ["вскакивавши"],
    "вскакивавши": ["вскакивав"],
    "вскальзывав": ["вскальзывавши"],
    "вскальзывавши": ["вскальзывав"],
    "вскапывав": ["вскапывавши"],
    "вскапывавши": ["вскапывав"],
    "вскарабкивание": ["влезание"],
    "вскарабкиваться": ["карабкаться"],
    "вскармливав": ["вскармливавши"],
    "вскармливавши": ["вскармливав"],
    "вскатив": ["вскативши"],
    "вскативши": ["вскатив"],
    "вскатывав": ["вскатывавши"],
    "вскатывавши": ["вскатывав"],
    "вскачь": ["скачками", "галопом"],
    "вскидчивый": ["вспыльчивый"],
    "вскидывав": ["вскидывавши"],
    "вскидывавши": ["вскидывав"],
    "вскинув": ["вскинувши"],
    "вскинувши": ["вскинув"],
    "вскипав": ["вскипавши"],
    "вскипавши": ["вскипав"],
    "вскипев": ["вскипевши"],
    "вскипевши": ["вскипев"],
    "вскипятив": ["вскипятивши"],
    "вскипятивши": ["вскипятив"],
    "вскисав": ["вскисавши"],
    "вскисавши": ["вскисав"],
    "вскисать": ["закиснуть", "прокиснуть"],
    "вскиснув": ["вскиснувши"],
    "вскиснувши": ["вскиснув"],
    "всклень": ["полностью", "доверху", "всклянь", "вскрай", "вздрочь", "вскрень"],
    "всклепав": ["всклепавши"],
    "всклепавши": ["всклепав"],
    "вскликнув": ["вскликнувши"],
    "вскликнувши": ["вскликнув"],
    "всклокотав": ["всклокотавши"],
    "всклокотавши": ["всклокотав"],
    "всклокотив": ["всклокотивши"],
    "всклокотивши": ["всклокотив"],
    "всклокоченный": ["всклоченный", "взлохмаченный", "растрёпанный", "нечёсаный"],
    "всклокочив": ["всклокочивши"],
    "всклокочивав": ["всклокочивавши"],
    "всклокочивавши": ["всклокочивав"],
    "всклокочивши": ["всклокочив"],
    "всклокочить": ["взлохматить", "взъерошить", "всклокотить", "всклочить"],
    "всклочив": ["всклочивши"],
    "всклочивав": ["всклочивавши"],
    "всклочивавши": ["всклочивав"],
    "всклочивши": ["всклочив"],
    "всклочить": ["всклокочить"],
    "всклубив": ["всклубивши"],
    "всклубивши": ["всклубив"],
    "всклянь": ["всклень", "полностью", "до краёв"],
    "всклёпывав": ["всклёпывавши"],
    "всклёпывавши": ["всклёпывав"],
    "всколебав": ["всколебавши"],
    "всколебавши": ["всколебав"],
    "всколотив": ["всколотивши"],
    "всколотивши": ["всколотив"],
    "всколошматив": ["всколошмативши"],
    "всколошмативши": ["всколошматив"],
    "всколошмачивав": ["всколошмачивавши"],
    "всколошмачивавши": ["всколошмачивав"],
    "всколупнув": ["всколупнувши"],
    "всколупнувши": ["всколупнув"],
    "всколупывав": ["всколупывавши"],
    "всколупывавши": ["всколупывав"],
    "всколыхав": ["всколыхавши"],
    "всколыхавши": ["всколыхав"],
    "всколыхивав": ["всколыхивавши"],
    "всколыхивавши": ["всколыхивав"],
    "всколыхиваться": ["всколыхаться", "всколыхнуться"],
    "всколыхнув": ["всколыхнувши"],
    "всколыхнувши": ["всколыхнув"],
    "вскользнув": ["вскользнувши"],
    "вскользнувши": ["вскользнув"],
    "вскользь": ["мимоходом", "между прочим"],
    "вскопав": ["вскопавши"],
    "вскопавши": ["вскопав"],
    "вскопка": ["вскапывание"],
    "вскопнув": ["вскопнувши"],
    "вскопнувши": ["вскопнув"],
    "вскоре": ["скоро", "вскорости", "невдолге"],
    "вскормив": ["вскормивши"],
    "вскормивши": ["вскормив"],
    "вскормить": ["выкормить"],
    "вскоробив": ["вскоробивши"],
    "вскоробивши": ["вскоробив"],
    "вскородив": ["вскородивши"],
    "вскородивши": ["вскородив"],
    "вскорости": ["вскоре"],
    "вскосматив": ["вскосмативши"],
    "вскосмативши": ["вскосматив"],
    "вскосматиться": ["всклокочиться", "взлохматиться"],
    "вскосмачивав": ["вскосмачивавши"],
    "вскосмачивавши": ["вскосмачивав"],
    "вскочив": ["вскочивши"],
    "вскочивши": ["вскочив"],
    "вскрик": ["крик", "вскрикивание"],
    "вскрикивав": ["вскрикивавши"],
    "вскрикивавши": ["вскрикивав"],
    "вскрикивание": ["выкрикивание", "вскрикиванье"],
    "вскрикиванье": ["вскрикивание"],
    "вскрикнув": ["вскрикнувши"],
    "вскрикнувши": ["вскрикнув"],
    "вскричав": ["вскричавши"],
    "вскричавши": ["вскричав"],
    "вскричать": ["вскрикнуть"],
    "вскричаться": ["раскричаться"],
    "вскружив": ["вскруживши"],
    "вскруживав": ["вскруживавши"],
    "вскруживавши": ["вскруживав"],
    "вскруживши": ["вскружив"],
    "вскрутив": ["вскрутивши"],
    "вскрутивши": ["вскрутив"],
    "вскручивав": ["вскручивавши"],
    "вскручивавши": ["вскручивав"],
    "вскрыв": ["вскрывши"],
    "вскрывав": ["вскрывавши"],
    "вскрывавши": ["вскрывав"],
    "вскрывание": ["открывание", "распечатывание", "обнаружение", "выявление", "ледоход", "анатомирование", "вскрытие"],
    "вскрывши": ["вскрыв"],
    "вскрытие": ["открытие", "обнаружение", "выявление", "взламывание", "нахождение", "анатомирование", "аутопсия", "некропсия", "секция", "паталого-анатомическое вскрытие"],
    "вскрыть": ["открыть", "раскрыть", "выявить", "анатомировать"],
    "вскрытье": ["вскрытие"],
    "вскрякивав": ["вскрякивавши"],
    "вскрякивавши": ["вскрякивав"],
    "вскрякнув": ["вскрякнувши"],
    "вскрякнувши": ["вскрякнув"],
    "всласть": ["вдоволь"],
    "вслед": ["вослед", "вдогонку"],
    "вслед за": ["после", "следом за"],
    "вследствие": ["из-за", "из", "от", "по", "за", "благодаря", "по причине", "в результате", "ввиду", "в силу"],
    "вслепую": ["наугад"],
    "вслушиванье": ["вслушивание"],
    "вслушиваться": ["напрягать", "слух", "настораживаться", "превращаться в слух", "прислушиваться", "держать ушки на макушке", "навострять ухо", "навострить уши", "настораживать", "ухо", "уши", "приклонять слух", "приклонять ухо"],
    "всматриваться": ["вглядываться"],
    "всмотреться": ["вглядеться"],
    "всмятку": ["вдребезги"],
    "всобачив": ["всобачивши"],
    "всобачивши": ["всобачив"],
    "всовав": ["всовавши"],
    "всовавши": ["всовав"],
    "всовывав": ["всовывавши"],
    "всовывавши": ["всовывав"],
    "всовывать": ["впихивать", "засовывать"],
    "всосав": ["всосавши"],
    "всосавши": ["всосав"],
    "всочинив": ["всочинивши"],
    "всочинивши": ["всочинив"],
    "всочиняв": ["всочинявши"],
    "всочинявши": ["всочиняв"],
    "вспадав": ["вспадавши"],
    "вспадавши": ["вспадав"],
    "вспаивав": ["вспаивавши"],
    "вспаивавши": ["вспаивав"],
    "вспалзывав": ["вспалзывавши"],
    "вспалзывавши": ["вспалзывав"],
    "вспарив": ["вспаривши"],
    "вспаривав": ["вспаривавши"],
    "вспаривавши": ["вспаривав"],
    "вспаривши": ["вспарив"],
    "вспархивав": ["вспархивавши"],
    "вспархивавши": ["вспархивав"],
    "вспарывав": ["вспарывавши"],
    "вспарывавши": ["вспарывав"],
    "вспахав": ["вспахавши"],
    "вспахавши": ["вспахав"],
    "вспахивав": ["вспахивавши"],
    "вспахивавши": ["вспахивав"],
    "вспашка": ["пахота"],
    "вспев": ["вспевши"],
    "вспевав": ["вспевавши"],
    "вспевавши": ["вспевав"],
    "вспевши": ["вспев"],
    "вспенив": ["вспенивши"],
    "вспенивав": ["вспенивавши"],
    "вспенивавши": ["вспенивав"],
    "вспенивание": ["пенообразование", "пена"],
    "вспенивать": ["взмыливать"],
    "вспенивши": ["вспенив"],
    "всплакав": ["всплакавши"],
    "всплакавши": ["всплакав"],
    "всплакать": ["восплакать"],
    "всплакаться": ["всплакать", "восплакать", "расплакаться"],
    "всплакивав": ["всплакивавши"],
    "всплакивавши": ["всплакивав"],
    "всплакнув": ["всплакнувши"],
    "всплакнувши": ["всплакнув"],
    "вспламенив": ["вспламенивши"],
    "вспламенивши": ["вспламенив"],
    "вспламеняв": ["вспламенявши"],
    "вспламенявши": ["вспламеняв"],
    "всплеск": ["всполох", "вейвлет"],
    "всплескивав": ["всплескивавши"],
    "всплескивавши": ["всплескивав"],
    "всплеснув": ["всплеснувши"],
    "всплеснувши": ["всплеснув"],
    "всплошную": ["сплошь", "всплошь"],
    "всплыв": ["всплывши"],
    "всплывав": ["всплывавши"],
    "всплывавши": ["всплывав"],
    "всплывашка": ["всплывайка"],
    "всплывши": ["всплыв"],
    "всплёскивав": ["всплёскивавши"],
    "всплёскивавши": ["всплёскивав"],
    "вспоив": ["вспоивши"],
    "вспоивши": ["вспоив"],
    "всполаскивав": ["всполаскивавши"],
    "всполаскивавши": ["всполаскивав"],
    "всползав": ["всползавши"],
    "всползавши": ["всползав"],
    "всполоснув": ["всполоснувши"],
    "всполоснувши": ["всполоснув"],
    "всполох": ["сполох", "вспышка", "северное сияние", "переполох", "тревога", "суматоха", "испуг", "суетня", "набат"],
    "всполохнув": ["всполохнувши"],
    "всполохнувши": ["всполохнув"],
    "всполошив": ["всполошивши"],
    "всполошивши": ["всполошив"],
    "всполыхнув": ["всполыхнувши"],
    "всполыхнувши": ["всполыхнув"],
    "вспоминав": ["вспоминавши"],
    "вспоминавши": ["вспоминав"],
    "вспоминанье": ["вспоминание"],
    "вспоминаться": ["припоминаться", "поминаться", "приходить на память"],
    "вспомнив": ["вспомнивши"],
    "вспомнивши": ["вспомнив"],
    "вспомнить": ["припомнить", "помянуть", "вспомянуть", "упомянуть"],
    "вспомогав": ["вспомогавши"],
    "вспомогавши": ["вспомогав"],
    "вспомогательная историческая дисциплина": ["специальная историческая дисциплина"],
    "вспомогательная силовая установка": ["всу"],
    "вспомогательный": ["подсобный", "дополнительный"],
    "вспоможение": ["благопоспешение", "благопоспешествование", "благоприятствование", "воспособление", "вспомоществование", "пособие", "содействие"],
    "вспоможенье": ["вспоможение"],
    "вспомошествовав": ["вспомошествовавши"],
    "вспомошествовавши": ["вспомошествовав"],
    "вспомоществовав": ["вспомоществовавши"],
    "вспомоществовавши": ["вспомоществовав"],
    "вспомоществование": ["помощь", "вспоможение"],
    "вспомоществованье": ["вспомоществование"],
    "вспомоществовать": ["благотворительствовать"],
    "вспомянув": ["вспомянувши"],
    "вспомянувши": ["вспомянув"],
    "вспоров": ["вспоровши"],
    "вспоровши": ["вспоров"],
    "вспорхнув": ["вспорхнувши"],
    "вспорхнувши": ["вспорхнув"],
    "вспотев": ["вспотевши"],
    "вспотевши": ["вспотев"],
    "вспотеть": ["взмокнуть", "запотеть"],
    "вспрыгивав": ["вспрыгивавши"],
    "вспрыгивавши": ["вспрыгивав"],
    "вспрыгнув": ["вспрыгнувши"],
    "вспрыгнувши": ["вспрыгнув"],
    "вспрыскивав": ["вспрыскивавши"],
    "вспрыскивавши": ["вспрыскивав"],
    "вспрыскиванье": ["вспрыскивание"],
    "вспрыснув": ["вспрыснувши"],
    "вспрыснувши": ["вспрыснув"],
    "вспрядывав": ["вспрядывавши"],
    "вспрядывавши": ["вспрядывав"],
    "вспрянув": ["вспрянувши"],
    "вспрянувши": ["вспрянув"],
    "вспугивав": ["вспугивавши"],
    "вспугивавши": ["вспугивав"],
    "вспугнув": ["вспугнувши"],
    "вспугнувши": ["вспугнув"],
    "вспузырив": ["вспузыривши"],
    "вспузыривав": ["вспузыривавши"],
    "вспузыривавши": ["вспузыривав"],
    "вспузыривши": ["вспузырив"],
    "вспутав": ["вспутавши"],
    "вспутавши": ["вспутав"],
    "вспутывав": ["вспутывавши"],
    "вспутывавши": ["вспутывав"],
    "вспухав": ["вспухавши"],
    "вспухавши": ["вспухав"],
    "вспухать": ["опухать", "распухать"],
    "вспухнув": ["вспухнувши"],
    "вспухнувши": ["вспухнув"],
    "вспучив": ["вспучивши"],
    "вспучивав": ["вспучивавши"],
    "вспучивавши": ["вспучивав"],
    "вспучивши": ["вспучив"],
    "вспушив": ["вспушивши"],
    "вспушивши": ["вспушив"],
    "вспылав": ["вспылавши"],
    "вспылавши": ["вспылав"],
    "вспылив": ["вспыливши"],
    "вспыливав": ["вспыливавши"],
    "вспыливавши": ["вспыливав"],
    "вспыливши": ["вспылив"],
    "вспыльчивость": ["гневливость", "раздражительность"],
    "вспыльчивый": ["вскидчивый", "гневливый", "горячий", "запальчивый", "неуравновешенный", "пылкий", "раздражительный", "сангвинический"],
    "вспыхивав": ["вспыхивавши"],
    "вспыхивавши": ["вспыхивав"],
    "вспыхнув": ["вспыхнувши"],
    "вспыхнувши": ["вспыхнув"],
    "вспыхнуть": ["воспламениться", "полыхнуть", "заполыхать", "загореться", "зажечься", "разъяриться"],
    "вспять": ["назад", "обратно"],
    "всратый": ["паршивый", "дурацкий", "безобразный", "уродливый", "неприятный", "убогий", "ужасный", "ужравшийся", "обколовшийся", "обдолбанный", "обдолбавшийся", "плоский", "кринжовый", "оскорбительный"],
    "всрать": ["профукать", "промотать"],
    "всраться": ["сдаться"],
    "встав": ["вставши"],
    "вставав": ["встававши"],
    "встававши": ["вставав"],
    "вставанье": ["вставание"],
    "вставать": ["подниматься", "умещаться", "помещаться", "размещаться", "подыматься", "ступать", "наступать"],
    "вставать с колен": ["подниматься с колен"],
    "вставив": ["вставивши"],
    "вставивши": ["вставив"],
    "вставить": ["поместить", "перебить"],
    "вставка": ["вставление"],
    "вставляв": ["вставлявши"],
    "вставлявши": ["вставляв"],
    "вставлять палки в колёса": ["мешать"],
    "вставши": ["встав"],
    "встала задача": ["столкнуться с проблемой"],
    "встарь": ["древле", "некогда"],
    "встаскивав": ["встаскивавши"],
    "встаскивавши": ["встаскивав"],
    "встать": ["подняться", "уместиться", "поместиться", "разместиться", "взойти", "возникнуть", "появиться", "предстать", "вспомниться", "расположиться", "стать", "остановиться", "застыть", "замёрзнуть"],
    "встащив": ["встащивши"],
    "встащивши": ["встащив"],
    "встерегти": ["устерегти"],
    "встигти": ["устигти"],
    "встопорщив": ["встопорщивши"],
    "встопорщивав": ["встопорщивавши"],
    "встопорщивавши": ["встопорщивав"],
    "встопорщиваться": ["топорщиться"],
    "встопорщивши": ["встопорщив"],
    "встопырив": ["встопыривши"],
    "встопыривши": ["встопырив"],
    "встормошив": ["встормошивши"],
    "встормошивши": ["встормошив"],
    "встоячку": ["стойком", "встоечку", "встояка"],
    "встраивав": ["встраивавши"],
    "встраивавши": ["встраивав"],
    "встрев": ["встревши"],
    "встревав": ["встревавши"],
    "встревавши": ["встревав"],
    "встревать": ["вмешиваться"],
    "встревоженность": ["озабоченность"],
    "встревожив": ["встревоживши"],
    "встревоживав": ["встревоживавши"],
    "встревоживавши": ["встревоживав"],
    "встревоживать": ["растревоживать", "тревожить", "обеспокоивать"],
    "встревоживши": ["встревожив"],
    "встревожиться": ["взволноваться", "обеспокоиться"],
    "встревши": ["встрев"],
    "встрепав": ["встрепавши"],
    "встрепавши": ["встрепав"],
    "встрепенуться": ["вздрогнуть", "оживиться"],
    "встрепетав": ["встрепетавши"],
    "встрепетавши": ["встрепетав"],
    "встрепетать": ["вострепетать", "затрепетать"],
    "встретив": ["встретивши"],
    "встретивши": ["встретив"],
    "встретить": ["сретить"],
    "встретиться": ["повстречаться", "попасться"],
    "встреть": ["встретить"],
    "встречав": ["встречавши"],
    "встречавши": ["встречав"],
    "встречаемость": ["частота встречаемости", "процент встречаемости"],
    "встречание": ["встречанье", "сретение"],
    "встречанье": ["встречание", "сретенье"],
    "встречать": ["сречать"],
    "встречать в штыки": ["принимать в штыки"],
    "встречаться": ["попадаться", "наблюдаться"],
    "встречка": ["встречная полоса"],
    "встроив": ["встроивши"],
    "встроивши": ["встроив"],
    "вструхнув": ["вструхнувши"],
    "вструхнувши": ["вструхнув"],
    "встряв": ["встрявши"],
    "встрявши": ["встряв"],
    "встрянув": ["встрянувши"],
    "встрянувши": ["встрянув"],
    "встряска": ["встряхивание", "тряска"],
    "встрять": ["вмешаться"],
    "встряхивав": ["встряхивавши"],
    "встряхивавши": ["встряхивав"],
    "встряхиванье": ["встряхивание"],
    "встряхнув": ["встряхнувши"],
    "встряхнувши": ["встряхнув"],
    "встрёпанный": ["взъерошенный"],
    "встрёпывав": ["встрёпывавши"],
    "встрёпывавши": ["встрёпывав"],
    "вступав": ["вступавши"],
    "вступавши": ["вступав"],
    "вступать": ["входить"],
    "вступив": ["вступивши"],
    "вступивши": ["вступив"],
    "вступительный": ["вводный", "начальный"],
    "вступить в брак": ["сочетаться браком", "заключить брак"],
    "вступление": ["вступленье", "введение", "введенье", "преамбула", "интродукция"],
    "вступленье": ["вступление", "введение", "введенье", "преамбула", "интродукция"],
    "встягивав": ["встягивавши"],
    "встягивавши": ["встягивав"],
    "встянув": ["встянувши"],
    "встянувши": ["встянув"],
    "всуе": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "бесплодно", "зазря"],
    "всунув": ["всунувши"],
    "всунувши": ["всунув"],
    "всунути": ["усунути"],
    "всучав": ["всучавши"],
    "всучавши": ["всучав"],
    "всучив": ["всучивши"],
    "всучивав": ["всучивавши"],
    "всучивавши": ["всучивав"],
    "всучивание": ["всучиванье", "всовывание", "всовыванье"],
    "всучивши": ["всучив"],
    "всучить": ["вплести", "навязать", "впарить"],
    "всхв": ["всесоюзная сельскохозяйственная выставка"],
    "всхлипнув": ["всхлипнувши"],
    "всхлипнувши": ["всхлипнув"],
    "всхлипнуть": ["заплакать", "захныкать", "захлюпать"],
    "всхлипывав": ["всхлипывавши"],
    "всхлипывавши": ["всхлипывав"],
    "всхлипывание": ["всхлипыванье"],
    "всхлипыванье": ["всхлипывание"],
    "всхлопнув": ["всхлопнувши"],
    "всхлопнувши": ["всхлопнув"],
    "всхлопывав": ["всхлопывавши"],
    "всхлопывавши": ["всхлопывав"],
    "всходив": ["всходивши"],
    "всходивши": ["всходив"],
    "всходить": ["подниматься"],
    "всхожий": ["всходчивый"],
    "всхолив": ["всхоливши"],
    "всхоливши": ["всхолив"],
    "всхолмив": ["всхолмивши"],
    "всхолмивши": ["всхолмив"],
    "всхолмлённость": ["всхолмление", "всхолмье"],
    "всхолмлённый": ["холмистый"],
    "всхолмье": ["всхолмление", "всхолмлённость"],
    "всхохатывав": ["всхохатывавши"],
    "всхохатывавши": ["всхохатывав"],
    "всхохлатив": ["всхохлативши"],
    "всхохлативши": ["всхохлатив"],
    "всхохлачивав": ["всхохлачивавши"],
    "всхохлачивавши": ["всхохлачивав"],
    "всхохотнув": ["всхохотнувши"],
    "всхохотнувши": ["всхохотнув"],
    "всхрапев": ["всхрапевши"],
    "всхрапевши": ["всхрапев"],
    "всхрапнув": ["всхрапнувши"],
    "всхрапнувши": ["всхрапнув"],
    "всхрапывав": ["всхрапывавши"],
    "всхрапывавши": ["всхрапывав"],
    "всхрапыванье": ["всхрапывание"],
    "всъдеход": ["джип"],
    "всыпав": ["всыпавши"],
    "всыпавши": ["всыпав"],
    "всыпать": ["досыпать", "подсыпать"],
    "всю дорогу": ["всё время", "всегда", "постоянно"],
    "всюду": ["везде", "повсеместно", "повсюду"],
    "всяк кулик своё болото хвалит": ["в каждой избушке свои погремушки", "в тулу со своим самоваром не ездят"],
    "всякая всячина": ["всё на свете"],
    "всякий": ["каждый", "любой", "разный", "разнообразный", "всевозможный", "какой бы то ни было", "малейший"],
    "всяко": ["всячески"],
    "всячески": ["по-разному", "по-всякому"],
    "всяческий": ["всякий"],
    "всё в порядке": ["всё пучком"],
    "всё время": ["как заведённая машина"],
    "всё едино": ["всё равно"],
    "всё ещё": ["ещё", "до сих пор", "пока что", "так и", "по сей день", "поныне", "доныне", "по сию пору", "доселе", "доднесь", "досель", "поднесь", "покамест", "посейчас", "всё"],
    "всё ж таки": ["всё-таки", "всё же", "всё равно", "всё", "ведь", "как-никак", "опять-таки", "опять же", "тем не менее", "как бы то ни было", "так или иначе", "при всём том", "вместе с тем", "во всяком случае", "впрочем"],
    "всё же": ["всё-таки", "однако", "тем не менее"],
    "всё пучком и пизда торчком": ["хорошо", "нормально", "нормалёк", "нормалец", "нормуль", "окей", "окейно", "всё окей", "хоккей", "всё хоккей", "тип-топ", "тики-так", "чики-пуки", "ништяк", "пучком"],
    "всё равно": ["несмотря ни на что", "всё же", "при всём при этом", "тем не менее", "в любом случае", "так или иначе", "как ни крути"],
    "всё так": ["правильно", "совершенно верно"],
    "всё-таки": ["тем не менее", "всё же", "таки ж", "всё ж таки", "однако", "несмотря на", "однако же", "в конце концов"],
    "втайне": ["тайно", "скрытно", "тайком"],
    "вталдычить": ["втолковать"],
    "вталкивав": ["вталкивавши"],
    "вталкивавши": ["вталкивав"],
    "вталкивать": ["проталкивать", "впихивать"],
    "втапливав": ["втапливавши"],
    "втапливавши": ["втапливав"],
    "втаптывав": ["втаптывавши"],
    "втаптывавши": ["втаптывав"],
    "втаскав": ["втаскавши"],
    "втаскавши": ["втаскав"],
    "втаскивав": ["втаскивавши"],
    "втаскивавши": ["втаскивав"],
    "втаскивать": ["затаскивать"],
    "втасовав": ["втасовавши"],
    "втасовавши": ["втасовав"],
    "втасовывав": ["втасовывавши"],
    "втасовывавши": ["втасовывав"],
    "втачав": ["втачавши"],
    "втачавши": ["втачав"],
    "втачивав": ["втачивавши"],
    "втачивавши": ["втачивав"],
    "втащив": ["втащивши"],
    "втащивши": ["втащив"],
    "втащить": ["переместить"],
    "втекав": ["втекавши"],
    "втекавши": ["втекав"],
    "втекать": ["вливаться"],
    "втемяшив": ["втемяшивши"],
    "втемяшивав": ["втемяшивавши"],
    "втемяшивавши": ["втемяшивав"],
    "втемяшивши": ["втемяшив"],
    "втемяшить": ["вдолбить"],
    "втерев": ["втёрши"],
    "втеснив": ["втеснивши"],
    "втеснивши": ["втеснив"],
    "втеснить": ["втиснуть"],
    "втесняв": ["втеснявши"],
    "втеснявши": ["втесняв"],
    "втеча": ["утеча"],
    "втечь": ["влиться"],
    "втирав": ["втиравши"],
    "втиравши": ["втирав"],
    "втискав": ["втискавши"],
    "втискавши": ["втискав"],
    "втискаться": ["втиснуться"],
    "втискивав": ["втискивавши"],
    "втискивавши": ["втискивав"],
    "втискивание": ["втискиванье"],
    "втискиванье": ["втискивание"],
    "втиснув": ["втиснувши"],
    "втиснувши": ["втиснув"],
    "втихаря": ["втихомолку", "втихомолочку", "тихомолком", "тихомолочкой", "по-тихому", "тихой сапой", "по-тихушному", "по-тихушечному", "втихую", "тишком", "тишком-ладком", "потайно", "потихоньку", "потихонечку", "тайно"],
    "втихомолку": ["втихаря", "втайне", "тихомолком"],
    "втихушку": ["втихаря", "втихую", "втихомолку"],
    "втихую": ["втихомолку", "втихаря"],
    "втолкав": ["втолкавши"],
    "втолкавши": ["втолкав"],
    "втолкнув": ["втолкнувши"],
    "втолкнувши": ["втолкнув"],
    "втолковав": ["втолковавши"],
    "втолковавши": ["втолковав"],
    "втолковать": ["внести", "ясность", "пролить", "бросить", "свет", "объяснить", "разъяснить", "пояснить", "вталдычить", "растолковать", "изъяснить", "вбить", "голову", "вдолбить", "втемяшить"],
    "втолковывав": ["втолковывавши"],
    "втолковывавши": ["втолковывав"],
    "втолочь": ["вбить", "вдавить", "вмять", "втолковать"],
    "втопив": ["втопивши"],
    "втопивши": ["втопив"],
    "втоптав": ["втоптавши"],
    "втоптавши": ["втоптав"],
    "вторачивав": ["вторачивавши"],
    "вторачивавши": ["вторачивав"],
    "вторая культура": ["андеграунд"],
    "вторая половина": ["дражайшая половина"],
    "вторая речка": ["вторяк"],
    "вторая чеченская война": ["вторая чеченская"],
    "вторжение": ["вторженье", "вторгание", "вторганье"],
    "вторженье": ["вторжение"],
    "вторив": ["вторивши"],
    "вторивши": ["вторив"],
    "вторичная занятость": ["подработка"],
    "вторично": ["повторно"],
    "вторичное сырьё": ["сырьё вторичной переработки", "вторсырьё"],
    "вторичнополостной": ["целомический"],
    "вторичный": ["повторный"],
    "вторичный источник электропитания": ["источник электропитания"],
    "вторка": ["вторсырьё"],
    "второбрачие": ["двубрачие"],
    "второе лицо": ["правая рука", "премьер-министр", "вице-президент"],
    "второе сердце мужчины": ["предстательная железа", "простата"],
    "второе я": ["альтер эго"],
    "второзаконие": ["дварим"],
    "второй": ["другой", "дополнительный", "ещё один", "скрытый", "девяносто второй"],
    "второй дом": ["школа", "дом знаний", "большой дом у дороги", "долбаный дом", "дом вампиров", "дом ужасов", "училищный дом"],
    "второй завтрак": ["ланч"],
    "второй пилот": ["правак"],
    "второй рейх": ["германская империя"],
    "второй русский авангард": ["второй авангард"],
    "второй свежести": ["не первой свежести"],
    "второклассник": ["второклашка"],
    "второклассница": ["второклашка"],
    "второклашка": ["второклассник", "второклассница"],
    "второразрядный": ["второсортный", "второстепенный", "второплановый", "посредственный"],
    "второсортный": ["второразрядный", "второстепенный", "посредственный"],
    "второстепенность": ["незначимость"],
    "второстепенный": ["побочный", "несущественный", "посредственный", "третьестепенный", "второклассный", "второсортный"],
    "второчив": ["второчивши"],
    "второчивши": ["второчив"],
    "второчить": ["заторочить"],
    "вторсырьё": ["вторичное сырьё", "сырьё вторичной переработки"],
    "вторые девяносто": ["пятая точка"],
    "вторяк": ["вторая речка"],
    "втравив": ["втравивши"],
    "втравивши": ["втравив"],
    "втравливав": ["втравливавши"],
    "втравливавши": ["втравливав"],
    "втравляв": ["втравлявши"],
    "втравлявши": ["втравляв"],
    "втрамбовав": ["втрамбовавши"],
    "втрамбовавши": ["втрамбовав"],
    "втрамбовывав": ["втрамбовывавши"],
    "втрамбовывавши": ["втрамбовывав"],
    "втрескаться": ["влюбиться"],
    "втридешева": ["по дешёвке"],
    "втридорога": ["задорого"],
    "втрое": ["втройне"],
    "втройне": ["втрое"],
    "втуз": ["политехнический университет", "политех", "технический вуз"],
    "втулка": ["затычка", "пробка"],
    "втуне": ["без толку", "бесплодно", "бесполезно", "безрезультатно", "безуспешно", "вотще", "впустую", "всуе", "вхолостую", "даром", "зря", "зазря", "напрасно", "понапрасну", "попусту"],
    "втык": ["взбучка", "нагоняй", "разнос", "пиздюлина"],
    "втыкав": ["втыкавши"],
    "втыкавши": ["втыкав"],
    "втыкать": ["вонзать", "залипать", "въезжать", "врубаться", "просекать", "сечь", "рубить", "догонять", "вкуривать", "глазеть", "таращиться", "пялиться"],
    "втыкаться": ["вонзаться"],
    "втюриться": ["втюхаться", "врютиться", "врюхаться", "вляпаться"],
    "втюхав": ["втюхавши"],
    "втюхавши": ["втюхав"],
    "втюхать": ["впарить", "сплавить"],
    "втюхивав": ["втюхивавши"],
    "втюхивавши": ["втюхивав"],
    "втюхивать": ["впаривать", "сплавлять"],
    "втягивав": ["втягивавши"],
    "втягивавши": ["втягивав"],
    "втягивать": ["брать"],
    "втямив": ["втямивши"],
    "втямивши": ["втямив"],
    "втянув": ["втянувши"],
    "втянувши": ["втянув"],
    "втянуться": ["привыкнуть", "приучиться", "приохотиться", "пристраститься", "повадиться"],
    "втяпав": ["втяпавши"],
    "втяпавши": ["втяпав"],
    "втяпывав": ["втяпывавши"],
    "втяпывавши": ["втяпывав"],
    "втёрши": ["втерев"],
    "вуайер": ["вуайерист"],
    "вуайеризм": ["миксоскопия", "визионизм", "скопофилия"],
    "вуалировав": ["вуалировавши"],
    "вуалировавши": ["вуалировав"],
    "вуалирование": ["сокрытие"],
    "вуаль": ["фата", "чадра", "паранджа", "пелена", "завеса"],
    "вуаля": ["оп", "опа", "пожалуйста", "готово"],
    "вувузела": ["лепатата"],
    "вувылкарнан": ["вукарнан"],
    "вугольчык": ["жарынка"],
    "вуди-алленовский": ["алленовский"],
    "вудро": ["вуди"],
    "вуду": ["вудуизм"],
    "вудуизм": ["вуду"],
    "вуз": ["высшее учебное заведение"],
    "вузовец": ["студент"],
    "вузькуватий": ["завузький"],
    "вуй": ["уй"],
    "вуйко": ["дядько"],
    "вуковица": ["сербская кириллица"],
    "вукузё": ["вумурт"],
    "вулкан": ["гефест"],
    "вулканизат": ["вулканизатор"],
    "вулканизировав": ["вулканизировавши"],
    "вулканизировавши": ["вулканизировав"],
    "вулканизовав": ["вулканизовавши"],
    "вулканизовавши": ["вулканизовав"],
    "вулканитовый": ["асбестоизвестковотрепельный"],
    "вульва": ["вольва", "влагалище"],
    "вульгаризировав": ["вульгаризировавши"],
    "вульгаризировавши": ["вульгаризировав"],
    "вульгарно": ["пошло", "развязно"],
    "вульгарный": ["бестактный", "развязный", "пошлый", "грубый", "вычурный"],
    "вумурт": ["вукузё"],
    "вурд": ["чув"],
    "вурдалак": ["вампир", "упырь"],
    "вусмерть": ["смертельно", "до полусмерти", "в мясо", "в салат", "в зюзю"],
    "вухатий": ["вухастий"],
    "вухерериоз": ["банкрофтоз"],
    "вхаживав": ["вхаживавши"],
    "вхаживавши": ["вхаживав"],
    "вхерачив": ["вхерачивши"],
    "вхерачивши": ["вхерачив"],
    "вхерачить": ["добавить"],
    "вход": ["вхождение"],
    "входив": ["входивши"],
    "входивши": ["входив"],
    "входить": ["втыкаться", "вонзаться"],
    "входить в дом": ["выходить в дом", "уходить в дом"],
    "входящий": ["проникающий", "поступающий"],
    "вхождение": ["вход", "случай"],
    "вхожденье": ["вхождение"],
    "вхолостую": ["напрасно", "понапрасну", "зря", "зазря", "тщетно", "безуспешно", "бесплодно", "безрезультатно", "бесполезно", "без толку", "впустую", "попусту", "даром", "вотще", "втуне"],
    "вхутемас": ["вхутеин"],
    "вцедив": ["вцедивши"],
    "вцедивши": ["вцедив"],
    "вцеживав": ["вцеживавши"],
    "вцеживавши": ["вцеживав"],
    "вцементировав": ["вцементировавши"],
    "вцементировавши": ["вцементировав"],
    "вцепененост": ["вдървеност", "скованост", "парализа"],
    "вцепив": ["вцепивши"],
    "вцепивши": ["вцепив"],
    "вцепиться": ["схватить", "сцепиться", "схватиться", "ухватиться", "прицепиться", "заинтересоваться"],
    "вцепляв": ["вцеплявши"],
    "вцеплявши": ["вцепляв"],
    "вчений": ["учений", "науковець"],
    "вчера": ["вчерашний день"],
    "вчерась": ["вчера"],
    "вчерашний": ["давешний", "бывший", "прошлый"],
    "вчерне": ["начерно"],
    "вчертив": ["вчертивши"],
    "вчертивши": ["вчертив"],
    "вчерчивав": ["вчерчивавши"],
    "вчерчивавши": ["вчерчивав"],
    "вчинив": ["вчинивши"],
    "вчинивши": ["вчинив"],
    "вчиняв": ["вчинявши"],
    "вчинявши": ["вчиняв"],
    "вчинённый": ["предъявленный"],
    "вчитав": ["вчитавши"],
    "вчитавши": ["вчитав"],
    "вчк": ["чк", "чека"],
    "вчуже": ["со стороны"],
    "вчёк": ["фчёк", "коряс", "корява", "ладямс", "съняра", "мъзяра", "эряви"],
    "вша": ["вошь"],
    "вшибав": ["вшибавши"],
    "вшибавши": ["вшибав"],
    "вшибив": ["вшибивши"],
    "вшибивши": ["вшибив"],
    "вшив": ["вшивши"],
    "вшивав": ["вшивавши"],
    "вшивавши": ["вшивав"],
    "вшиваться": ["подшиваться"],
    "вшивев": ["вшивевши"],
    "вшивевши": ["вшивев"],
    "вшивость": ["завшивленность", "педикулёз"],
    "вшивши": ["вшив"],
    "вшивый": ["дрянной", "паршивый"],
    "вшити": ["ушити"],
    "вштырив": ["вштыривши"],
    "вштыривав": ["вштыривавши"],
    "вштыривавши": ["вштыривав"],
    "вштыривать": ["штырить"],
    "вштыривши": ["вштырив"],
    "вшэ": ["высшая школа экономики", "вышка"],
    "въ": ["внутрь", "на", "черезъ", "сквозь", "для", "ради", "изъ-за", "за", "во имя", "съ целью", "въ целяхъ", "внутри", "посреди"],
    "въебав": ["въебавши"],
    "въебавши": ["въебав"],
    "въебать": ["жахнуть", "ударить", "проебать"],
    "въебаться": ["впилиться"],
    "въебашив": ["въебашивши"],
    "въебашивши": ["въебашив"],
    "въебенив": ["въебенивши"],
    "въебенивши": ["въебенив"],
    "въебенить": ["въебать", "въебашить", "вхуячить"],
    "въедчиво": ["въедливо", "дотошно"],
    "въезжав": ["въезжавши"],
    "въезжавши": ["въезжав"],
    "въезжать": ["заезжать", "водворяться", "селиться", "поселяться", "вселяться", "ударять", "врубаться", "доходить"],
    "въехав": ["въехавши"],
    "въехавши": ["въехав"],
    "въехать в рай на чужом хую": ["въехать в рай на чужом горбу", "на чужом горбу в рай въехать", "на чужом горбу в рай выехать", "в рай въехать на чужом хую", "на хую в рай вкатиться"],
    "възбрана": ["забрана", "запрещение", "заповед"],
    "възбуда": ["възбуждение", "възбуденост", "раздразнение", "нервност", "безпокойство"],
    "възглед": ["схващане", "разбиране", "мнение", "убеждение", "поглед"],
    "въздух": ["атмосфера"],
    "въздържател": ["трезвеник"],
    "възпитаник": ["ученик", "питомец", "последовател", "адепт"],
    "възхита": ["възхищение", "възторг", "захлас"],
    "върволица": ["върволяк", "ред", "редица"],
    "вързоп": ["връзка", "сноп", "пакет", "денк", "бохча"],
    "върколак": ["вълколак"],
    "върлина": ["прът", "дърво"],
    "въртоп": ["водовъртеж", "вир"],
    "вътрешност": ["сърцевина", "среда", "център"],
    "въюркнув": ["въюркнувши"],
    "въюркнувши": ["въюркнув"],
    "въяве": ["наяву", "въявь", "на самом деле"],
    "въявь": ["въяве", "наяву", "взаправду"],
    "въёб": ["кайф", "кейф", "кеф"],
    "въёбка": ["въёбывание", "вливание", "вбухивание"],
    "въёбывав": ["въёбывавши"],
    "въёбывавши": ["въёбывав"],
    "вы": ["уважаемый"],
    "выбаллотировав": ["выбаллотировавши"],
    "выбаллотировавши": ["выбаллотировав"],
    "выбаллотировать": ["вышарить"],
    "выбалтывав": ["выбалтывавши"],
    "выбалтывавши": ["выбалтывав"],
    "выбалтывать": ["разбалтывать", "проговариваться"],
    "выбарышничав": ["выбарышничавши"],
    "выбарышничавши": ["выбарышничав"],
    "выбег": ["выгон"],
    "выбегав": ["выбегавши"],
    "выбегавши": ["выбегав"],
    "выбегивав": ["выбегивавши"],
    "выбегивавши": ["выбегивав"],
    "выбежав": ["выбежавши"],
    "выбежавши": ["выбежав"],
    "выбелив": ["выбеливши"],
    "выбеливав": ["выбеливавши"],
    "выбеливавши": ["выбеливав"],
    "выбеливать": ["выбелять"],
    "выбеливши": ["выбелив"],
    "выбеляв": ["выбелявши"],
    "выбелявши": ["выбеляв"],
    "выбесив": ["выбесивши"],
    "выбесивши": ["выбесив"],
    "выбесить": ["рассердить", "разозлить"],
    "выбешивав": ["выбешивавши"],
    "выбешивавши": ["выбешивав"],
    "выбешивать": ["бесить"],
    "выбив": ["выбивши"],
    "выбивав": ["выбивавши"],
    "выбивавши": ["выбивав"],
    "выбивалка": ["хлопушка"],
    "выбивать": ["выколачивать", "выстукивать", "высекать"],
    "выбивши": ["выбив"],
    "выбирав": ["выбиравши"],
    "выбиравши": ["выбирав"],
    "выбирать": ["избирать", "отбирать", "отсеивать", "голосовать", "извлекать", "изымать", "брать", "находить", "выделять"],
    "выбирать канат": ["травить канат", "вытаскивать", "вытягивать"],
    "выбить": ["вышибить", "выколотить", "вытеснить", "побить", "протоптать"],
    "выблевав": ["выблевавши"],
    "выблевавши": ["выблевав"],
    "выблевать": ["рвота", "блевание", "блевота"],
    "выблевнув": ["выблевнувши"],
    "выблевнувши": ["выблевнув"],
    "выблядок": ["ублюдок", "выродок", "вымесок", "байстрюк", "бастрюк", "байстрючонок", "болдырь", "бастард", "недоделок", "недоделыш", "выхухоль", "ушлёпок", "выблядыш", "блядёныш", "блядин род"],
    "выблёвывав": ["выблёвывавши"],
    "выблёвывавши": ["выблёвывав"],
    "выбоина": ["колдобина", "ухаб", "рытвина", "яма"],
    "выбойка": ["выбивание"],
    "выболев": ["выболевши"],
    "выболевши": ["выболев"],
    "выболтав": ["выболтавши"],
    "выболтавши": ["выболтав"],
    "выболтнув": ["выболтнувши"],
    "выболтнувши": ["выболтнув"],
    "выбомбив": ["выбомбивши"],
    "выбомбивши": ["выбомбив"],
    "выбор": ["отбор", "избрание", "ассортимент", "решение", "голосование"],
    "выборгский": ["виипурский"],
    "выборжанин": ["выборжец"],
    "выборжец": ["выборжанин"],
    "выборзок": ["полуборзой", "болван"],
    "выборка": ["выбор"],
    "выборматывав": ["выборматывавши"],
    "выборматывавши": ["выборматывав"],
    "выбормотав": ["выбормотавши"],
    "выбормотавши": ["выбормотав"],
    "выборность": ["избираемость"],
    "выбороздив": ["выбороздивши"],
    "выбороздивши": ["выбороздив"],
    "выборонив": ["выборонивши"],
    "выборонивши": ["выборонив"],
    "выборонить": ["изборонить", "взборонить", "взбороновать"],
    "выборочно": ["избирательно", "селективно"],
    "выборы": ["избрание"],
    "выбрав": ["выбравши"],
    "выбравши": ["выбрав"],
    "выбраживав": ["выбраживавши"],
    "выбраживавши": ["выбраживав"],
    "выбраковав": ["выбраковавши"],
    "выбраковавши": ["выбраковав"],
    "выбраковка": ["отбраковка"],
    "выбраковывав": ["выбраковывавши"],
    "выбраковывавши": ["выбраковывав"],
    "выбраковывать": ["браковать", "отсеивать", "отбраковывать"],
    "выбранив": ["выбранивши"],
    "выбранивши": ["выбранив"],
    "выбранить": ["выругать", "обругать"],
    "выбранный": ["отобранный"],
    "выбрасывав": ["выбрасывавши"],
    "выбрасывавши": ["выбрасывав"],
    "выбрасыванье": ["выбрасывание"],
    "выбрасывать": ["выкидывать", "вышвыривать"],
    "выбрать": ["избрать", "отобрать", "подобрать", "отсеять", "проголосовать", "извлечь", "изъять", "забрать", "найти", "выкроить", "улучить"],
    "выбредав": ["выбредавши"],
    "выбредавши": ["выбредав"],
    "выбрив": ["выбривши"],
    "выбривав": ["выбривавши"],
    "выбривавши": ["выбривав"],
    "выбривши": ["выбрив"],
    "выбродив": ["выбродивши"],
    "выбродивши": ["выбродив"],
    "выбронзировав": ["выбронзировавши"],
    "выбронзировавши": ["выбронзировав"],
    "выброс": ["выбрасывание"],
    "выбросав": ["выбросавши"],
    "выбросавши": ["выбросав"],
    "выбросать": ["повыбрасывать"],
    "выбросив": ["выбросивши"],
    "выбросивши": ["выбросив"],
    "выбрызгав": ["выбрызгавши"],
    "выбрызгавши": ["выбрызгав"],
    "выбрызгать": ["выбрызнуть"],
    "выбрызгивав": ["выбрызгивавши"],
    "выбрызгивавши": ["выбрызгивав"],
    "выбрызнув": ["выбрызнувши"],
    "выбрызнувши": ["выбрызнув"],
    "выбрюзжав": ["выбрюзжавши"],
    "выбрюзжавши": ["выбрюзжав"],
    "выбрюшив": ["выбрюшивши"],
    "выбрюшивши": ["выбрюшив"],
    "выбрякав": ["выбрякавши"],
    "выбрякавши": ["выбрякав"],
    "выбрякнув": ["выбрякнувши"],
    "выбрякнувши": ["выбрякнув"],
    "выбуздав": ["выбуздавши"],
    "выбуздавши": ["выбуздав"],
    "выбуксировав": ["выбуксировавши"],
    "выбуксировавши": ["выбуксировав"],
    "выбуксировывав": ["выбуксировывавши"],
    "выбуксировывавши": ["выбуксировывав"],
    "выбунтовав": ["выбунтовавши"],
    "выбунтовавши": ["выбунтовав"],
    "выбуравив": ["выбуравивши"],
    "выбуравивши": ["выбуравив"],
    "выбуравливав": ["выбуравливавши"],
    "выбуравливавши": ["выбуравливав"],
    "выбурив": ["выбуривши"],
    "выбуривав": ["выбуривавши"],
    "выбуривавши": ["выбуривав"],
    "выбуривши": ["выбурив"],
    "выбутив": ["выбутивши"],
    "выбутивши": ["выбутив"],
    "выбухав": ["выбухавши"],
    "выбухавши": ["выбухав"],
    "выбухивав": ["выбухивавши"],
    "выбухивавши": ["выбухивав"],
    "выбухнув": ["выбухнувши"],
    "выбухнувши": ["выбухнув"],
    "выбухны": ["выбуховы"],
    "выбучив": ["выбучивши"],
    "выбучивав": ["выбучивавши"],
    "выбучивавши": ["выбучивав"],
    "выбучивши": ["выбучив"],
    "выбыв": ["выбывши"],
    "выбывав": ["выбывавши"],
    "выбывавши": ["выбывав"],
    "выбывать": ["убывать"],
    "выбывши": ["выбыв"],
    "выв": ["вывши"],
    "вываживав": ["вываживавши"],
    "вываживавши": ["вываживав"],
    "вывалив": ["вываливши"],
    "вываливав": ["вываливавши"],
    "вываливавши": ["вываливав"],
    "вываливать глаза": ["вывалить глаза"],
    "вываливши": ["вывалив"],
    "вывалить белуды": ["таращить глаза", "пялить зенки", "выкатить белуды", "вылупить белуды", "выворотить белуды", "выголить белуды", "выкатить белутки", "вылупить белутки", "вывалить белутки", "выворотить белутки", "выголить белутки"],
    "вывалить глаза": ["уставиться", "вываливать глаза", "вывалить бурклы", "выпялить бурклы", "вывалить буркалы", "выпялить буркалы"],
    "вывалить язык": ["вывалить язык на плечо"],
    "вывалить язык на плечо": ["вывалить язык"],
    "вываляв": ["вывалявши"],
    "вывалявши": ["вываляв"],
    "вываляться": ["выпачкаться"],
    "выварат": ["адварот"],
    "выварив": ["вываривши"],
    "вываривав": ["вываривавши"],
    "вываривавши": ["вываривав"],
    "вываривши": ["выварив"],
    "выварка": ["вываривание"],
    "выващивав": ["выващивавши"],
    "выващивавши": ["выващивав"],
    "вывевав": ["вывевавши"],
    "вывевавши": ["вывевав"],
    "вывевание": ["вывеивание"],
    "вывевать": ["вывеивать"],
    "выведав": ["выведавши"],
    "выведавши": ["выведав"],
    "выведрив": ["выведривши"],
    "выведривав": ["выведривавши"],
    "выведривавши": ["выведривав"],
    "выведривши": ["выведрив"],
    "выведывав": ["выведывавши"],
    "выведывавши": ["выведывав"],
    "выведыванье": ["выведывание"],
    "вывезши": ["вывезя"],
    "вывезшись": ["вывезясь"],
    "вывезя": ["вывезши"],
    "вывезясь": ["вывезшись"],
    "вывеивав": ["вывеивавши"],
    "вывеивавши": ["вывеивав"],
    "вывеивание": ["вывевание"],
    "выверив": ["выверивши"],
    "выверивши": ["выверив"],
    "вывернув": ["вывернувши"],
    "вывернувши": ["вывернув"],
    "вывернуть матку": ["вытряхнуть из кителя", "растереть по переборке", "матку вывернуть", "матку наизнанку вывернуть", "глаз на жопу натянуть", "из кителя вытряхнуть", "по переборке растереть"],
    "вывернуться": ["выкрутиться", "открутиться", "вывихнуться", "выскользнуть"],
    "выверстав": ["выверставши"],
    "выверставши": ["выверстав"],
    "выверт": ["коленце", "причуда", "чудачество"],
    "вывертев": ["вывертевши"],
    "вывертевши": ["вывертев"],
    "вывертка": ["изворот"],
    "выверчивав": ["выверчивавши"],
    "выверчивавши": ["выверчивав"],
    "вывершив": ["вывершивши"],
    "вывершивав": ["вывершивавши"],
    "вывершивавши": ["вывершивав"],
    "вывершивши": ["вывершив"],
    "выверяв": ["выверявши"],
    "выверявши": ["выверяв"],
    "вывесив": ["вывесивши"],
    "вывесивши": ["вывесив"],
    "вывести": ["рассчитать", "уничтожить", "искоренить"],
    "вывести на свежую воду": ["сорвать маску", "вывести на чистую воду"],
    "вывести на чистую воду": ["сорвать маску", "узнать истинное лицо"],
    "выветрев": ["выветревши"],
    "выветревши": ["выветрев"],
    "выветрив": ["выветривши"],
    "выветривав": ["выветривавши"],
    "выветривавши": ["выветривав"],
    "выветривши": ["выветрив"],
    "выветрить": ["проветрить"],
    "вывешив": ["вывешивши"],
    "вывешивав": ["вывешивавши"],
    "вывешивавши": ["вывешивав"],
    "вывешивши": ["вывешив"],
    "вывеяв": ["вывеявши"],
    "вывеявши": ["вывеяв"],
    "вывив": ["вывивши"],
    "вывивав": ["вывивавши"],
    "вывивавши": ["вывивав"],
    "вывивши": ["вывив"],
    "вывинтив": ["вывинтивши"],
    "вывинтивши": ["вывинтив"],
    "вывинтить": ["вывернуть"],
    "вывинтиться": ["вывернуться", "выкрутиться"],
    "вывинчивав": ["вывинчивавши"],
    "вывинчивавши": ["вывинчивав"],
    "вывинчивать": ["вывёртывать", "отвинчивать"],
    "вывинчиваться": ["вывёртываться"],
    "вывихивав": ["вывихивавши"],
    "вывихивавши": ["вывихивав"],
    "вывихнув": ["вывихнувши"],
    "вывихнувши": ["вывихнув"],
    "вывод": ["выведение", "заключение", "результат", "итог", "следствие", "плод", "последствие", "продукт", "развязка", "конец", "исход", "эффект", "ножка", "нога", "контакт"],
    "выводив": ["выводивши"],
    "выводивши": ["выводив"],
    "выводить": ["уводить", "приводить", "исключать", "изводить", "истреблять", "искоренять", "устранять", "заключать", "получать", "создавать", "выращивать", "производить", "выписывать", "вырисовывать", "воспроизводить"],
    "выводить из себя": ["бесить"],
    "выводка": ["уничтожение", "устранение", "выгул"],
    "выводок": ["стайка"],
    "вывозив": ["вывозивши"],
    "вывозивши": ["вывозив"],
    "вывозить": ["увозить", "экспортировать"],
    "вывозиться": ["вымазаться", "выпачкаться", "извозиться", "испачкаться", "перепачкаться"],
    "выволакивав": ["выволакивавши"],
    "выволакивавши": ["выволакивав"],
    "выволочив": ["выволочивши"],
    "выволочивши": ["выволочив"],
    "выволочка": ["нагоняй", "нахлобучка", "трёпка"],
    "выволочь": ["выволочить"],
    "выворачивав": ["выворачивавши"],
    "выворачивавши": ["выворачивав"],
    "выворачивать": ["вытаскивать", "вывёртывать", "вывинчивать", "выкручивать", "тошнить", "рвать"],
    "выворотив": ["выворотивши"],
    "выворотивши": ["выворотив"],
    "вывострив": ["вывостривши"],
    "вывостривши": ["вывострив"],
    "вывощив": ["вывощивши"],
    "вывощивши": ["вывощив"],
    "вывши": ["выв"],
    "вывязав": ["вывязавши"],
    "вывязавши": ["вывязав"],
    "вывязив": ["вывязивши"],
    "вывязивши": ["вывязив"],
    "вывязывав": ["вывязывавши"],
    "вывязывавши": ["вывязывав"],
    "вывялив": ["вывяливши"],
    "вывяливав": ["вывяливавши"],
    "вывяливавши": ["вывяливав"],
    "вывяливши": ["вывялив"],
    "вывёрстывав": ["вывёрстывавши"],
    "вывёрстывавши": ["вывёрстывав"],
    "вывёрстывать": ["выравнивать", "стругать"],
    "вывёртывав": ["вывёртывавши"],
    "вывёртывавши": ["вывёртывав"],
    "вывёртывание": ["вывёртыванье"],
    "вывёртывать": ["вывинчивать", "выворачивать", "выкручивать"],
    "вывёртывающийся": ["выворачивающийся", "выкручивающийся"],
    "выгадав": ["выгадавши"],
    "выгадавши": ["выгадав"],
    "выгадывав": ["выгадывавши"],
    "выгадывавши": ["выгадывав"],
    "выгатив": ["выгативши"],
    "выгативши": ["выгатив"],
    "выгачивав": ["выгачивавши"],
    "выгачивавши": ["выгачивав"],
    "выгиб": ["изгиб"],
    "выгибав": ["выгибавши"],
    "выгибавши": ["выгибав"],
    "выгибаться": ["прогнуться", "изогнуться"],
    "выгладив": ["выгладивши"],
    "выгладивши": ["выгладив"],
    "выгладить": ["отгладить", "выутюжить", "отутюжить"],
    "выгладывав": ["выгладывавши"],
    "выгладывавши": ["выгладывав"],
    "выглаживав": ["выглаживавши"],
    "выглаживавши": ["выглаживав"],
    "выглодав": ["выглодавши"],
    "выглодавши": ["выглодав"],
    "выглотав": ["выглотавши"],
    "выглотавши": ["выглотав"],
    "выглушив": ["выглушивши"],
    "выглушивши": ["выглушив"],
    "выглядав": ["выглядавши"],
    "выглядавши": ["выглядав"],
    "выглядев": ["выглядевши"],
    "выглядевши": ["выглядев"],
    "выглядеть": ["смотреться", "казаться"],
    "выглядывав": ["выглядывавши"],
    "выглядывавши": ["выглядывав"],
    "выглядывать": ["высматривать", "осматривать"],
    "выглянув": ["выглянувши"],
    "выглянувши": ["выглянув"],
    "выглянуть": ["высунуться", "показаться", "появиться"],
    "выгнав": ["выгнавши"],
    "выгнавши": ["выгнав"],
    "выгнать": ["прогнать", "изгнать", "уволить", "исключить", "депортировать"],
    "выгнетав": ["выгнетавши"],
    "выгнетавши": ["выгнетав"],
    "выгнив": ["выгнивши"],
    "выгнивав": ["выгнивавши"],
    "выгнивавши": ["выгнивав"],
    "выгнивши": ["выгнив"],
    "выгнув": ["выгнувши"],
    "выгнувши": ["выгнув"],
    "выгнуться": ["прогнуться", "изогнуться"],
    "выговаривав": ["выговаривавши"],
    "выговаривавши": ["выговаривав"],
    "выговариваться": ["произноситься"],
    "выговор": ["произношение", "прононс", "порицание"],
    "выговорив": ["выговоривши"],
    "выговоривши": ["выговорив"],
    "выговорить": ["сказать"],
    "выгода": ["прибыль", "доход", "профит", "польза", "прок", "дивиденд", "преимущество"],
    "выгодно": ["прибыльно"],
    "выгодный": ["небезвыгодный"],
    "выгодополучатель": ["выгодоприобретатель"],
    "выгодоприобретатель": ["бенефициар", "бенефициарий"],
    "выгон": ["выгонка"],
    "выгонка": ["выкуривание"],
    "выгоняв": ["выгонявши"],
    "выгонявши": ["выгоняв"],
    "выгонять": ["прогонять", "изгонять", "исключать", "выводить", "выкуривать"],
    "выгорав": ["выгоравши"],
    "выгоравши": ["выгорав"],
    "выгораживав": ["выгораживавши"],
    "выгораживавши": ["выгораживав"],
    "выгорание": ["линяние", "сгорание", "дефлаграция", "выцветание", "истощение", "переутомление", "перенапряжение"],
    "выгорать": ["сгорать", "догорать", "выцветать", "истощиться", "переутомиться"],
    "выгорев": ["выгоревши"],
    "выгоревши": ["выгорев"],
    "выгоревший": ["выгорелый"],
    "выгорелый": ["выгоревший"],
    "выгореть": ["сгореть", "догореть", "выцвести"],
    "выгородив": ["выгородивши"],
    "выгородивши": ["выгородив"],
    "выгостив": ["выгостивши"],
    "выгостивши": ["выгостив"],
    "выгравировав": ["выгравировавши"],
    "выгравировавши": ["выгравировав"],
    "выгранив": ["выгранивши"],
    "выгранивав": ["выгранивавши"],
    "выгранивавши": ["выгранивав"],
    "выгранивши": ["выгранив"],
    "выгребав": ["выгребавши"],
    "выгребавши": ["выгребав"],
    "выгребание": ["выгребанье"],
    "выгребка": ["выгребание"],
    "выгрести": ["вытащить"],
    "выгружав": ["выгружавши"],
    "выгружавши": ["выгружав"],
    "выгрузив": ["выгрузивши"],
    "выгрузивши": ["выгрузив"],
    "выгрузить": ["разгрузить"],
    "выгрузка": ["разгрузка"],
    "выгрызав": ["выгрызавши"],
    "выгрызавши": ["выгрызав"],
    "выгрязнив": ["выгрязнивши"],
    "выгрязнивши": ["выгрязнив"],
    "выгуливав": ["выгуливавши"],
    "выгуливавши": ["выгуливав"],
    "выгуляв": ["выгулявши"],
    "выгулявши": ["выгуляв"],
    "выдав": ["выдавши"],
    "выдавав": ["выдававши"],
    "выдававши": ["выдавав"],
    "выдавать базу": ["объяснять", "разъяснять", "растолковывать"],
    "выдавив": ["выдавивши"],
    "выдавивши": ["выдавив"],
    "выдавливав": ["выдавливавши"],
    "выдавливавши": ["выдавливав"],
    "выдавши": ["выдав"],
    "выдаивав": ["выдаивавши"],
    "выдаивавши": ["выдаивав"],
    "выдалбливав": ["выдалбливавши"],
    "выдалбливавши": ["выдалбливав"],
    "выдалбливание": ["выдалбливанье"],
    "выданье": ["выдание"],
    "выдать": ["дать", "раскрыть", "спалить"],
    "выдать базу": ["объяснить", "разъяснить", "растолковать"],
    "выдать на клык": ["дать на клык", "дать за щеку", "на клык дать", "за щеку дать"],
    "выдающийся": ["выступающий", "выпирающий", "неординарный", "замечательный", "великий", "главный", "лучший"],
    "выдвигав": ["выдвигавши"],
    "выдвигавши": ["выдвигав"],
    "выдвигать": ["извлекать", "вытаскивать", "предлагать", "приводить", "номинировать", "представлять", "рекомендовать"],
    "выдвинув": ["выдвинувши"],
    "выдвинувши": ["выдвинув"],
    "выдвинуть": ["выставить", "высунуть", "выпятить", "продвинуть", "извлечь", "вытащить", "предложить", "привести", "номинировать", "представить", "рекомендовать"],
    "выдворение": ["выселение", "высылка", "ссылка", "депортация", "изгнание", "выдворенье", "выселенье", "изгнанье"],
    "выдворив": ["выдворивши"],
    "выдворивши": ["выдворив"],
    "выдворяв": ["выдворявши"],
    "выдворявши": ["выдворяв"],
    "выдворять": ["депортировать"],
    "выделав": ["выделавши"],
    "выделавши": ["выделав"],
    "выделив": ["выделивши"],
    "выделивши": ["выделив"],
    "выделка": ["изготовление", "производство", "обработка", "отделка", "качество"],
    "выделывав": ["выделывавши"],
    "выделывавши": ["выделывав"],
    "выделываться": ["вырабатываться", "производиться", "изготовляться", "выёживаться", "выпендриваться", "кочевряжиться", "дурачиться"],
    "выделяв": ["выделявши"],
    "выделявши": ["выделяв"],
    "выделять": ["предназначать", "направлять", "выпускать", "испускать", "отмечать", "подчёркивать"],
    "выделяться": ["обособляться", "отличаться"],
    "выдергав": ["выдергавши"],
    "выдергавши": ["выдергав"],
    "выдержав": ["выдержавши"],
    "выдержавши": ["выдержав"],
    "выдержать": ["выстоять", "устоять", "вытерпеть", "стерпеть", "выдюжить", "пройти", "соблюсти"],
    "выдерживав": ["выдерживавши"],
    "выдерживавши": ["выдерживав"],
    "выдерживать": ["выносить", "переносить", "терпеть", "сносить", "сдавать", "соблюдать", "держать"],
    "выдержка": ["экспозиция"],
    "выдернув": ["выдернувши"],
    "выдернувши": ["выдернув"],
    "выдернуть": ["вырвать", "выдрать"],
    "выджял": ["выджяла"],
    "выдирав": ["выдиравши"],
    "выдиравши": ["выдирав"],
    "выдирать": ["вырывать", "выдёргивать"],
    "выдирка": ["выдирание", "купюра"],
    "выдоив": ["выдоивши"],
    "выдоивши": ["выдоив"],
    "выдолбив": ["выдолбивши"],
    "выдолбивши": ["выдолбив"],
    "выдох": ["выдыхание"],
    "выдохнув": ["выдохнувши"],
    "выдохнувши": ["выдохнув"],
    "выдра": ["порешня", "кикимора", "уда"],
    "выдрав": ["выдравши"],
    "выдравши": ["выдрав"],
    "выдраив": ["выдраивши"],
    "выдраивав": ["выдраивавши"],
    "выдраивавши": ["выдраивав"],
    "выдраивши": ["выдраив"],
    "выдранный": ["вырванный"],
    "выдрать": ["вырвать", "выдернуть"],
    "выдрессировав": ["выдрессировавши"],
    "выдрессировавши": ["выдрессировав"],
    "выдрючивав": ["выдрючивавши"],
    "выдрючивавши": ["выдрючивав"],
    "выдубив": ["выдубивши"],
    "выдубивши": ["выдубив"],
    "выдував": ["выдувавши"],
    "выдувавши": ["выдував"],
    "выдувальщик": ["стеклодув"],
    "выдувание": ["выдуванье"],
    "выдувши": ["выдув"],
    "выдудеть": ["продудеть"],
    "выдудив": ["выдудивши"],
    "выдудивши": ["выдудив"],
    "выдудить": ["выдудолить", "выдулить", "вызюзить", "выдуть", "вытянуть", "выкуликать", "выглохтать"],
    "выдумав": ["выдумавши"],
    "выдумавши": ["выдумав"],
    "выдуманный": ["придуманный", "вымышленный", "мифический"],
    "выдуматься": ["придуматься"],
    "выдумка": ["изобретательность", "затея", "забава", "изобретение", "придумка", "вымысел", "измышление"],
    "выдумщик": ["придумщик", "фантазёр", "врун", "врунишка", "лгун", "обманщик"],
    "выдумывав": ["выдумывавши"],
    "выдумывавши": ["выдумывав"],
    "выдушив": ["выдушивши"],
    "выдушивши": ["выдушив"],
    "выдыхав": ["выдыхавши"],
    "выдыхавши": ["выдыхав"],
    "выдыхание": ["выдыханье", "выдох"],
    "выдыханье": ["выдыхание"],
    "выдыхательный": ["экспираторный"],
    "выдюжив": ["выдюживши"],
    "выдюживав": ["выдюживавши"],
    "выдюживавши": ["выдюживав"],
    "выдюживши": ["выдюжив"],
    "выдюжить": ["выдержать", "сдюжить"],
    "выдёргивав": ["выдёргивавши"],
    "выдёргивавши": ["выдёргивав"],
    "выдёргивать": ["вырывать"],
    "выебав": ["выебавши"],
    "выебавши": ["выебав"],
    "выебать": ["высношать", "отсношать", "выдрать", "отодрать", "вытрахать", "оттрахать", "трахнуть", "употребить", "оприходовать", "помять", "выдрючить", "отдрючить", "продрючить", "финтифлюхнуть", "загнать дурака под шкурку"],
    "выебина": ["выбоина", "рытвина", "ухаб", "колдобина", "колдоёбина"],
    "выебнув": ["выебнувши"],
    "выебнувши": ["выебнув"],
    "выебнуться": ["выпендриться"],
    "выебонщик": ["позёр", "воображала", "воображуля", "выпендрёжник", "понторез", "выёбщик"],
    "выебсти": ["выебать", "выебть", "выеть", "отъебать", "отъебсти", "отъеть"],
    "выебти": ["пропесочить"],
    "выев": ["выевши"],
    "выевши": ["выев"],
    "выедав": ["выедавши"],
    "выедавши": ["выедав"],
    "выеденного яйца не стоить": ["ломаного гроша не стоить"],
    "выездив": ["выездивши"],
    "выездивши": ["выездив"],
    "выезжав": ["выезжавши"],
    "выезжавши": ["выезжав"],
    "выезживав": ["выезживавши"],
    "выезживавши": ["выезживав"],
    "выемка": ["впадина", "углубление"],
    "выемный": ["выемной"],
    "выехав": ["выехавши"],
    "выехавши": ["выехав"],
    "выжав": ["выжавши"],
    "выжавши": ["выжав"],
    "выжарив": ["выжаривши"],
    "выжаривав": ["выжаривавши"],
    "выжаривавши": ["выжаривав"],
    "выжаривши": ["выжарив"],
    "выждав": ["выждавши"],
    "выждавши": ["выждав"],
    "выжелтев": ["выжелтевши"],
    "выжелтевши": ["выжелтев"],
    "выжелтив": ["выжелтивши"],
    "выжелтивши": ["выжелтив"],
    "выжеребиться": ["ожеребиться"],
    "выжив": ["выживши"],
    "выживав": ["выживавши"],
    "выживавши": ["выживав"],
    "выживалка": ["выживач"],
    "выживальщик": ["сурвивалист", "квартирный рейдер", "профессиональный сосед"],
    "выживанье": ["выживание"],
    "выживач": ["выживалка"],
    "выживши": ["выжив"],
    "выживший": ["уцелевший"],
    "выжига": ["плут", "пройдоха"],
    "выжигав": ["выжигавши"],
    "выжигавши": ["выжигав"],
    "выжигание": ["пирография"],
    "выжиганье": ["выжигание"],
    "выжигатель": ["пирограф"],
    "выжидав": ["выжидавши"],
    "выжидавши": ["выжидав"],
    "выжиданье": ["выжидание"],
    "выжидательно": ["выжидающе"],
    "выжидать": ["ждать", "ожидать"],
    "выжидающе": ["выжидательно"],
    "выжимав": ["выжимавши"],
    "выжимавши": ["выжимав"],
    "выжимать": ["отжимать", "выдавливать"],
    "выжимать коку с соком": ["выжимать пот"],
    "выжинав": ["выжинавши"],
    "выжинавши": ["выжинав"],
    "выжирав": ["выжиравши"],
    "выжиравши": ["выжирав"],
    "выжлец": ["выжлёнок"],
    "выжрав": ["выжравши"],
    "выжравши": ["выжрав"],
    "вызвав": ["вызвавши"],
    "вызвавши": ["вызвав"],
    "вызванивав": ["вызванивавши"],
    "вызванивавши": ["вызванивав"],
    "вызвать": ["возбудить", "породить"],
    "вызвать образ": ["представить", "вспомнить", "вообразить"],
    "вызвездив": ["вызвездивши"],
    "вызвездивши": ["вызвездив"],
    "вызволенье": ["вызволение"],
    "вызволив": ["вызволивши"],
    "вызволивши": ["вызволив"],
    "вызволить": ["выручить"],
    "вызволяв": ["вызволявши"],
    "вызволявши": ["вызволяв"],
    "вызвонив": ["вызвонивши"],
    "вызвонивши": ["вызвонив"],
    "вызвякивав": ["вызвякивавши"],
    "вызвякивавши": ["вызвякивав"],
    "выздоравливав": ["выздоравливавши"],
    "выздоравливавши": ["выздоравливав"],
    "выздоравливать": ["поправляться"],
    "выздоровев": ["выздоровевши"],
    "выздоровевши": ["выздоровев"],
    "выздороветь": ["поправиться"],
    "выздоровление": ["выздоровленье", "поправка", "излечение"],
    "выздоровленье": ["выздоровление"],
    "вызеленив": ["вызеленивши"],
    "вызеленивши": ["вызеленив"],
    "вызимовав": ["вызимовавши"],
    "вызимовавши": ["вызимовав"],
    "вызнав": ["вызнавши"],
    "вызнавав": ["вызнававши"],
    "вызнававши": ["вызнавав"],
    "вызнавши": ["вызнав"],
    "вызнобив": ["вызнобивши"],
    "вызнобивши": ["вызнобив"],
    "вызолачивав": ["вызолачивавши"],
    "вызолачивавши": ["вызолачивав"],
    "вызолив": ["вызоливши"],
    "вызоливши": ["вызолив"],
    "вызолотив": ["вызолотивши"],
    "вызолотивши": ["вызолотив"],
    "вызрев": ["вызревши"],
    "вызревав": ["вызревавши"],
    "вызревавши": ["вызревав"],
    "вызревать": ["выспевать", "дозревать", "назревать", "достигать спелости", "достигать зрелости", "спеть", "поспевать", "определяться"],
    "вызревши": ["вызрев"],
    "вызубрив": ["вызубривши"],
    "вызубривав": ["вызубривавши"],
    "вызубривавши": ["вызубривав"],
    "вызубривши": ["вызубрив"],
    "вызудив": ["вызудивши"],
    "вызудивши": ["вызудив"],
    "вызуживав": ["вызуживавши"],
    "вызуживавши": ["вызуживав"],
    "вызывав": ["вызывавши"],
    "вызывавши": ["вызывав"],
    "вызывание": ["вызов"],
    "вызывать": ["звать", "приглашать", "побуждать", "провоцировать", "бросать вызов", "порождать", "приводить к появлению", "каузировать"],
    "вызябав": ["вызябавши"],
    "вызябавши": ["вызябав"],
    "вызябнув": ["вызябнувши"],
    "вызябнувши": ["вызябнув"],
    "выиграв": ["выигравши"],
    "выигравши": ["выиграв"],
    "выиграть": ["победить", "выгадать"],
    "выигрывав": ["выигрывавши"],
    "выигрывавши": ["выигрывав"],
    "выигрывать": ["побеждать", "приобретать"],
    "выигрыш": ["победа"],
    "выикнув": ["выикнувши"],
    "выикнувши": ["выикнув"],
    "выискав": ["выискавши"],
    "выискавши": ["выискав"],
    "выискать": ["разыскать", "найти"],
    "выискаться": ["найтись"],
    "выискивав": ["выискивавши"],
    "выискивавши": ["выискивав"],
    "выискиванье": ["выискивание"],
    "выйдя": ["вышед"],
    "выйти боком": ["вылезти боком", "выйти соком"],
    "выйти в тираж": ["устареть"],
    "выйти из себя": ["разгневаться", "рассердиться", "вознегодовать", "взорваться", "вспылить", "потерять лицо", "раскрыться"],
    "выйти из строя": ["сломаться", "испортиться"],
    "выйти соком": ["выйти боком"],
    "выйти сухим из воды": ["вывернуться"],
    "выкаблучивав": ["выкаблучивавши"],
    "выкаблучивавши": ["выкаблучивав"],
    "выкав": ["выкавши"],
    "выкавши": ["выкав"],
    "выказав": ["выказавши"],
    "выказавши": ["выказав"],
    "выказать": ["продемонстрировать"],
    "выказывав": ["выказывавши"],
    "выказывавши": ["выказывав"],
    "выказывать": ["показывать"],
    "выкакав": ["выкакавши"],
    "выкакавши": ["выкакав"],
    "выкакать": ["высрать", "испражнить", "родить"],
    "выкакивать": ["высирать"],
    "выкалив": ["выкаливши"],
    "выкаливав": ["выкаливавши"],
    "выкаливавши": ["выкаливав"],
    "выкаливши": ["выкалив"],
    "выкалывав": ["выкалывавши"],
    "выкалывавши": ["выкалывав"],
    "выкаляв": ["выкалявши"],
    "выкалявши": ["выкаляв"],
    "выкамаривав": ["выкамаривавши"],
    "выкамаривавши": ["выкамаривав"],
    "выкамаривание": ["выпендривание", "выпендрёж", "выделывание"],
    "выкамаривать": ["выделывать", "выкаблучивать", "отмачивать"],
    "выкание": ["выканье"],
    "выканье": ["выкание"],
    "выканючив": ["выканючивши"],
    "выканючивав": ["выканючивавши"],
    "выканючивавши": ["выканючивав"],
    "выканючивать": ["выпрашивать", "выклянчивать", "клянчить"],
    "выканючивши": ["выканючив"],
    "выкапав": ["выкапавши"],
    "выкапавши": ["выкапав"],
    "выкапчивав": ["выкапчивавши"],
    "выкапчивавши": ["выкапчивав"],
    "выкапывав": ["выкапывавши"],
    "выкапывавши": ["выкапывав"],
    "выкапывать": ["вырывать", "откапывать"],
    "выкарабкаться": ["вылезти", "выдраться", "выползти", "справиться", "преодолеть"],
    "выкармливав": ["выкармливавши"],
    "выкармливавши": ["выкармливав"],
    "выкарыстаць": ["скарыстаць", "ужыць"],
    "выкатав": ["выкатавши"],
    "выкатавши": ["выкатав"],
    "выкатив": ["выкативши"],
    "выкативши": ["выкатив"],
    "выкатить": ["выпустить", "выдать"],
    "выкатывав": ["выкатывавши"],
    "выкатывавши": ["выкатывав"],
    "выкачав": ["выкачавши"],
    "выкачавши": ["выкачав"],
    "выкачивав": ["выкачивавши"],
    "выкачивавши": ["выкачивав"],
    "выкачивать": ["извлекать"],
    "выкашивав": ["выкашивавши"],
    "выкашивавши": ["выкашивав"],
    "выкашивать": ["скашивать", "косить"],
    "выкашливав": ["выкашливавши"],
    "выкашливавши": ["выкашливав"],
    "выкашляв": ["выкашлявши"],
    "выкашлявши": ["выкашляв"],
    "выкашлянув": ["выкашлянувши"],
    "выкашлянувши": ["выкашлянув"],
    "выквасив": ["выквасивши"],
    "выквасивши": ["выквасив"],
    "выквашивав": ["выквашивавши"],
    "выквашивавши": ["выквашивав"],
    "выкидав": ["выкидавши"],
    "выкидавши": ["выкидав"],
    "выкидывав": ["выкидывавши"],
    "выкидывавши": ["выкидывав"],
    "выкидывать": ["выбрасывать", "вышвыривать"],
    "выкидывать артикулы": ["смешить", "развлекать", "делать", "фокус", "смешной", "штуки", "номер"],
    "выкинув": ["выкинувши"],
    "выкинувши": ["выкинув"],
    "выкипав": ["выкипавши"],
    "выкипавши": ["выкипав"],
    "выкипание": ["убегание"],
    "выкипев": ["выкипевши"],
    "выкипевши": ["выкипев"],
    "выкипятив": ["выкипятивши"],
    "выкипятивши": ["выкипятив"],
    "выкисав": ["выкисавши"],
    "выкисавши": ["выкисав"],
    "выкиснув": ["выкиснувши"],
    "выкиснувши": ["выкиснув"],
    "выкладка": ["снаряжение", "расчёт", "довод", "аргумент", "вывод"],
    "выкладывав": ["выкладывавши"],
    "выкладывавши": ["выкладывав"],
    "выкладывать": ["вынимать", "сообщать", "выстилать", "покрывать", "нашивать", "выстраивать", "платить"],
    "выкласть": ["выложить", "выхолостить", "кастрировать"],
    "выклевав": ["выклевавши"],
    "выклевавши": ["выклевав"],
    "выклеив": ["выклеивши"],
    "выклеивав": ["выклеивавши"],
    "выклеивавши": ["выклеивав"],
    "выклеивши": ["выклеив"],
    "выклеймив": ["выклеймивши"],
    "выклеймивши": ["выклеймив"],
    "выклепав": ["выклепавши"],
    "выклепавши": ["выклепав"],
    "выкликав": ["выкликавши"],
    "выкликавши": ["выкликав"],
    "выкликивав": ["выкликивавши"],
    "выкликивавши": ["выкликивав"],
    "выкликнув": ["выкликнувши"],
    "выкликнувши": ["выкликнув"],
    "выклинив": ["выклинивши"],
    "выклинивав": ["выклинивавши"],
    "выклинивавши": ["выклинивав"],
    "выклинивши": ["выклинив"],
    "выклюнув": ["выклюнувши"],
    "выклюнувши": ["выклюнув"],
    "выключав": ["выключавши"],
    "выключавши": ["выключав"],
    "выключать": ["отключать"],
    "выключение": ["отключение", "исключение"],
    "выключенность": ["отключенность", "отстраненность", "уход", "обособление"],
    "выключенный": ["исключённый", "отключенный"],
    "выключив": ["выключивши"],
    "выключивши": ["выключив"],
    "выключить": ["остановить", "вырубить", "отключить", "отсоединить", "изъять", "исключить"],
    "выключиться": ["отключиться", "вырубиться", "отсоединиться", "забыться", "лишиться чувств", "впасть в беспамятство", "отрубиться", "потерять сознание"],
    "выключка": ["выравнивание"],
    "выклянчив": ["выклянчивши"],
    "выклянчивав": ["выклянчивавши"],
    "выклянчивавши": ["выклянчивав"],
    "выклянчивши": ["выклянчив"],
    "выклёвывав": ["выклёвывавши"],
    "выклёвывавши": ["выклёвывав"],
    "выклёпывав": ["выклёпывавши"],
    "выклёпывавши": ["выклёпывав"],
    "выкобениваться": ["упрямиться", "выпендриваться", "выделываться"],
    "выковав": ["выковавши"],
    "выковавши": ["выковав"],
    "выковывав": ["выковывавши"],
    "выковывавши": ["выковывав"],
    "выковывать": ["ковать"],
    "выковыляв": ["выковылявши"],
    "выковылявши": ["выковыляв"],
    "выковырив": ["выковыривши"],
    "выковыривав": ["выковыривавши"],
    "выковыривавши": ["выковыривав"],
    "выковыривши": ["выковырив"],
    "выковырнув": ["выковырнувши"],
    "выковырнувши": ["выковырнув"],
    "выковыряв": ["выковырявши"],
    "выковырявши": ["выковыряв"],
    "выколачивав": ["выколачивавши"],
    "выколачивавши": ["выколачивав"],
    "выколашивание": ["выколашиванье"],
    "выколашиваться": ["околоситься", "отколоситься"],
    "выколов": ["выколовши"],
    "выколовши": ["выколов"],
    "выколоситься": ["околоситься", "околашиваться", "выколашиваться"],
    "выколотив": ["выколотивши"],
    "выколотивши": ["выколотив"],
    "выколупав": ["выколупавши"],
    "выколупавши": ["выколупав"],
    "выколупив": ["выколупивши"],
    "выколупивши": ["выколупив"],
    "выколупливав": ["выколупливавши"],
    "выколупливавши": ["выколупливав"],
    "выколупнув": ["выколупнувши"],
    "выколупнувши": ["выколупнув"],
    "выколупнуть": ["выковырять"],
    "выколупывав": ["выколупывавши"],
    "выколупывавши": ["выколупывав"],
    "выколупывать": ["выковыривать"],
    "выкомаривав": ["выкомаривавши"],
    "выкомаривавши": ["выкомаривав"],
    "выкомариваться": ["выкамаривать", "выкомуривать"],
    "выкомуривав": ["выкомуривавши"],
    "выкомуривавши": ["выкомуривав"],
    "выконопатив": ["выконопативши"],
    "выконопативши": ["выконопатив"],
    "выконопачивав": ["выконопачивавши"],
    "выконопачивавши": ["выконопачивав"],
    "выкопав": ["выкопавши"],
    "выкопавши": ["выкопав"],
    "выкопировав": ["выкопировавши"],
    "выкопировавши": ["выкопировав"],
    "выкопировывав": ["выкопировывавши"],
    "выкопировывавши": ["выкопировывав"],
    "выкопка": ["выкапывание"],
    "выкоптив": ["выкоптивши"],
    "выкоптивши": ["выкоптив"],
    "выкормив": ["выкормивши"],
    "выкормивши": ["выкормив"],
    "выкорпев": ["выкорпевши"],
    "выкорпевши": ["выкорпев"],
    "выкорчевав": ["выкорчевавши"],
    "выкорчевавши": ["выкорчевав"],
    "выкорчить": ["выкорчевать"],
    "выкорчёвывав": ["выкорчёвывавши"],
    "выкорчёвывавши": ["выкорчёвывав"],
    "выкосив": ["выкосивши"],
    "выкосивши": ["выкосив"],
    "выкосить": ["скосить"],
    "выкрадывав": ["выкрадывавши"],
    "выкрадывавши": ["выкрадывав"],
    "выкраивав": ["выкраивавши"],
    "выкраивавши": ["выкраивав"],
    "выкрасив": ["выкрасивши"],
    "выкрасивши": ["выкрасив"],
    "выкрасить": ["окрасить"],
    "выкрахмалив": ["выкрахмаливши"],
    "выкрахмаливав": ["выкрахмаливавши"],
    "выкрахмаливавши": ["выкрахмаливав"],
    "выкрахмаливши": ["выкрахмалив"],
    "выкрашенный": ["покрашенный"],
    "выкрашивав": ["выкрашивавши"],
    "выкрашивавши": ["выкрашивав"],
    "выкрашивать": ["окрашивать", "красить"],
    "выкрестив": ["выкрестивши"],
    "выкрестивши": ["выкрестив"],
    "выкрещивав": ["выкрещивавши"],
    "выкрещивавши": ["выкрещивав"],
    "выкривив": ["выкрививши"],
    "выкрививши": ["выкривив"],
    "выкривляв": ["выкривлявши"],
    "выкривлявши": ["выкривляв"],
    "выкрик": ["выкрикивание", "крик", "восклицание", "выклик"],
    "выкрикивав": ["выкрикивавши"],
    "выкрикивавши": ["выкрикивав"],
    "выкрикиванье": ["выкрикивание"],
    "выкрикнув": ["выкрикнувши"],
    "выкрикнувши": ["выкрикнув"],
    "выкристаллизировав": ["выкристаллизировавши"],
    "выкристаллизировавши": ["выкристаллизировав"],
    "выкристаллизовав": ["выкристаллизовавши"],
    "выкристаллизовавши": ["выкристаллизовав"],
    "выкристаллизовывав": ["выкристаллизовывавши"],
    "выкристаллизовывавши": ["выкристаллизовывав"],
    "выкричав": ["выкричавши"],
    "выкричавши": ["выкричав"],
    "выкричать": ["выкрикнуть"],
    "выкроив": ["выкроивши"],
    "выкроивши": ["выкроив"],
    "выкройка": ["выкраивание"],
    "выкромсав": ["выкромсавши"],
    "выкромсавши": ["выкромсав"],
    "выкрошив": ["выкрошивши"],
    "выкрошивши": ["выкрошив"],
    "выкруглив": ["выкругливши"],
    "выкругливши": ["выкруглив"],
    "выкругляв": ["выкруглявши"],
    "выкруглявши": ["выкругляв"],
    "выкружив": ["выкруживши"],
    "выкруживав": ["выкруживавши"],
    "выкруживавши": ["выкруживав"],
    "выкруживши": ["выкружив"],
    "выкружка": ["каветто"],
    "выкрутасничав": ["выкрутасничавши"],
    "выкрутасничавши": ["выкрутасничав"],
    "выкрутив": ["выкрутивши"],
    "выкрутивши": ["выкрутив"],
    "выкручивав": ["выкручивавши"],
    "выкручивавши": ["выкручивав"],
    "выкручивать": ["выжимать", "скручивать", "свивать", "вывёртывать", "вывинчивать", "заламывать", "выламывать"],
    "выкрыв": ["выкрывши"],
    "выкрывав": ["выкрывавши"],
    "выкрывавши": ["выкрывав"],
    "выкрывши": ["выкрыв"],
    "выкувыркивав": ["выкувыркивавши"],
    "выкувыркивавши": ["выкувыркивав"],
    "выкувырнув": ["выкувырнувши"],
    "выкувырнувши": ["выкувырнув"],
    "выкуковав": ["выкуковавши"],
    "выкуковавши": ["выкуковав"],
    "выкунев": ["выкуневши"],
    "выкуневши": ["выкунев"],
    "выкупав": ["выкупавши"],
    "выкупавши": ["выкупав"],
    "выкупать": ["искупать"],
    "выкупаться": ["искупаться"],
    "выкупив": ["выкупивши"],
    "выкупивши": ["выкупив"],
    "выкурив": ["выкуривши"],
    "выкуривав": ["выкуривавши"],
    "выкуривавши": ["выкуривав"],
    "выкуривши": ["выкурив"],
    "выкурка": ["выкуривание"],
    "выкус": ["выкусывание"],
    "выкусав": ["выкусавши"],
    "выкусавши": ["выкусав"],
    "выкусив": ["выкусивши"],
    "выкусивши": ["выкусив"],
    "выкусывав": ["выкусывавши"],
    "выкусывавши": ["выкусывав"],
    "выкушав": ["выкушавши"],
    "выкушавши": ["выкушав"],
    "выкушать": ["попить", "выпить", "напиться", "испить"],
    "вылавировав": ["вылавировавши"],
    "вылавировавши": ["вылавировав"],
    "вылавливав": ["вылавливавши"],
    "вылавливавши": ["вылавливав"],
    "вылаз": ["лаз"],
    "вылазив": ["вылазивши"],
    "вылазивши": ["вылазив"],
    "вылазить": ["вылезать"],
    "вылакав": ["вылакавши"],
    "вылакавши": ["вылакав"],
    "выламывав": ["выламывавши"],
    "выламывавши": ["выламывав"],
    "вылащивав": ["вылащивавши"],
    "вылащивавши": ["вылащивав"],
    "вылегав": ["вылегавши"],
    "вылегавши": ["вылегав"],
    "вылегчив": ["вылегчивши"],
    "вылегчивши": ["вылегчив"],
    "вылежав": ["вылежавши"],
    "вылежавши": ["вылежав"],
    "вылезав": ["вылезавши"],
    "вылезавши": ["вылезав"],
    "вылезать": ["вылазить"],
    "вылезти": ["вылезть", "выйти", "сойти", "выбраться"],
    "вылезть": ["вылезти"],
    "вылезя": ["вылезши"],
    "вылепив": ["вылепивши"],
    "вылепивши": ["вылепив"],
    "вылепливав": ["вылепливавши"],
    "вылепливавши": ["вылепливав"],
    "вылепливать": ["вылеплять"],
    "вылепляв": ["вылеплявши"],
    "вылеплявши": ["вылепляв"],
    "вылеплять": ["вылепливать", "лепить", "ваять", "выводить", "вырисовывать", "выписывать", "создавать"],
    "вылет": ["отлёт", "вылетание", "взлёт", "увольнение", "выступ", "запас", "ушко"],
    "вылетав": ["вылетавши"],
    "вылетавши": ["вылетав"],
    "вылетев": ["вылетевши"],
    "вылетевши": ["вылетев"],
    "вылететь": ["вылететь с треском"],
    "вылететь в трубу": ["прогореть", "потерпеть неудачу"],
    "вылечив": ["вылечивши"],
    "вылечивав": ["вылечивавши"],
    "вылечивавши": ["вылечивав"],
    "вылечивать": ["излечивать", "исцелять"],
    "вылечиваться": ["исцеляться"],
    "вылечивши": ["вылечив"],
    "вылечить": ["излечить", "исцелить"],
    "вылечиться": ["исцелиться"],
    "вылечка": ["вылечение"],
    "выливав": ["выливавши"],
    "выливавши": ["выливав"],
    "выливать": ["отливать", "изливать"],
    "выливши": ["вылив"],
    "вылизав": ["вылизавши"],
    "вылизавши": ["вылизав"],
    "вылизывав": ["вылизывавши"],
    "вылизывавши": ["вылизывав"],
    "вылиняв": ["вылинявши"],
    "вылинявши": ["вылиняв"],
    "выло": ["выльник"],
    "выловив": ["выловивши"],
    "выловивши": ["выловив"],
    "выложив": ["выложивши"],
    "выложивши": ["выложив"],
    "вылокав": ["вылокавши"],
    "вылокавши": ["вылокав"],
    "выломав": ["выломавши"],
    "выломавши": ["выломав"],
    "выломив": ["выломивши"],
    "выломивши": ["выломив"],
    "вылощив": ["вылощивши"],
    "вылощивши": ["вылощив"],
    "вылудив": ["вылудивши"],
    "вылудивши": ["вылудив"],
    "вылуживав": ["вылуживавши"],
    "вылуживавши": ["вылуживав"],
    "вылупив": ["вылупивши"],
    "вылупивши": ["вылупив"],
    "вылупить": ["выпучить", "вытаращить"],
    "вылупить глаза": ["вылупиться"],
    "вылупиться": ["появиться", "уставиться", "родиться", "повзрослеть"],
    "вылупливав": ["вылупливавши"],
    "вылупливавши": ["вылупливав"],
    "вылупляв": ["вылуплявши"],
    "вылуплявши": ["вылупляв"],
    "вылупляться": ["вылупливаться", "появляться", "возникать", "вперяться", "взгляд"],
    "вылущив": ["вылущивши"],
    "вылущивав": ["вылущивавши"],
    "вылущивавши": ["вылущивав"],
    "вылущивание": ["вылущение", "вылущиванье", "вылущенье"],
    "вылущивать": ["вышелушивать"],
    "вылущивши": ["вылущив"],
    "выляпывав": ["выляпывавши"],
    "выляпывавши": ["выляпывав"],
    "вылёживав": ["вылёживавши"],
    "вылёживавши": ["вылёживав"],
    "вылётывав": ["вылётывавши"],
    "вылётывавши": ["вылётывав"],
    "вымазав": ["вымазавши"],
    "вымазавши": ["вымазав"],
    "вымазживав": ["вымазживавши"],
    "вымазживавши": ["вымазживав"],
    "вымазывав": ["вымазывавши"],
    "вымазывавши": ["вымазывав"],
    "вымакав": ["вымакавши"],
    "вымакавши": ["вымакав"],
    "вымалевав": ["вымалевавши"],
    "вымалевавши": ["вымалевав"],
    "вымаливав": ["вымаливавши"],
    "вымаливавши": ["вымаливав"],
    "вымалчивав": ["вымалчивавши"],
    "вымалчивавши": ["вымалчивав"],
    "вымалывав": ["вымалывавши"],
    "вымалывавши": ["вымалывав"],
    "вымалёвывав": ["вымалёвывавши"],
    "вымалёвывавши": ["вымалёвывав"],
    "выманив": ["выманивши"],
    "выманивав": ["выманивавши"],
    "выманивавши": ["выманивав"],
    "выманивши": ["выманив"],
    "вымарав": ["вымаравши"],
    "вымаравши": ["вымарав"],
    "вымаривав": ["вымаривавши"],
    "вымаривавши": ["вымаривав"],
    "вымарщивав": ["вымарщивавши"],
    "вымарщивавши": ["вымарщивав"],
    "вымарывав": ["вымарывавши"],
    "вымарывавши": ["вымарывав"],
    "вымаслив": ["вымасливши"],
    "вымасливав": ["вымасливавши"],
    "вымасливавши": ["вымасливав"],
    "вымасливши": ["вымаслив"],
    "выматерив": ["выматеривши"],
    "выматеривши": ["выматерив"],
    "выматывав": ["выматывавши"],
    "выматывавши": ["выматывав"],
    "выматюгаться": ["выматюкаться"],
    "выматюкаться": ["выматюгаться"],
    "вымахав": ["вымахавши"],
    "вымахавши": ["вымахав"],
    "вымахивав": ["вымахивавши"],
    "вымахивавши": ["вымахивав"],
    "вымахнув": ["вымахнувши"],
    "вымахнувши": ["вымахнув"],
    "вымачивав": ["вымачивавши"],
    "вымачивавши": ["вымачивав"],
    "вымащивав": ["вымащивавши"],
    "вымащивавши": ["вымащивав"],
    "вымбовка": ["аншпуг"],
    "вымежевав": ["вымежевавши"],
    "вымежевавши": ["вымежевав"],
    "вымежовывав": ["вымежовывавши"],
    "вымежовывавши": ["вымежовывав"],
    "вымежёвывав": ["вымежёвывавши"],
    "вымежёвывавши": ["вымежёвывав"],
    "вымелив": ["вымеливши"],
    "вымеливши": ["вымелив"],
    "выменив": ["выменивши"],
    "выменивав": ["выменивавши"],
    "выменивавши": ["выменивав"],
    "выменивать": ["обменивать", "менять", "променивать"],
    "выменивши": ["выменив"],
    "выменяв": ["выменявши"],
    "выменявши": ["выменяв"],
    "вымерев": ["вымерши"],
    "вымерзав": ["вымерзавши"],
    "вымерзавши": ["вымерзав"],
    "вымерзание": ["вымораживание"],
    "вымерзнув": ["вымерзнувши"],
    "вымерзнувши": ["вымерзнув"],
    "вымерив": ["вымеривши"],
    "вымеривав": ["вымеривавши"],
    "вымеривавши": ["вымеривав"],
    "вымеривание": ["замер", "обмер", "обмеривание", "обмерка", "смеривание", "замеривание", "измерение", "размеривание"],
    "вымеривши": ["вымерив"],
    "вымертвив": ["вымертвивши"],
    "вымертвивши": ["вымертвив"],
    "вымертвляв": ["вымертвлявши"],
    "вымертвлявши": ["вымертвляв"],
    "вымерши": ["вымерев"],
    "вымеряв": ["вымерявши"],
    "вымерявши": ["вымеряв"],
    "вымесив": ["вымесивши"],
    "вымесивши": ["вымесив"],
    "выместив": ["выместивши"],
    "выместивши": ["выместив"],
    "выметав": ["выметавши"],
    "выметавши": ["выметав"],
    "выметив": ["выметивши"],
    "выметивши": ["выметив"],
    "выметнув": ["выметнувши"],
    "выметнувши": ["выметнув"],
    "выметывав": ["выметывавши"],
    "выметывавши": ["выметывав"],
    "вымечав": ["вымечавши"],
    "вымечавши": ["вымечав"],
    "вымечтав": ["вымечтавши"],
    "вымечтавши": ["вымечтав"],
    "вымешав": ["вымешавши"],
    "вымешавши": ["вымешав"],
    "вымешивав": ["вымешивавши"],
    "вымешивавши": ["вымешивав"],
    "вымещав": ["вымещавши"],
    "вымещавши": ["вымещав"],
    "выминав": ["выминавши"],
    "выминавши": ["выминав"],
    "вымирав": ["вымиравши"],
    "вымиравши": ["вымирав"],
    "вымитин": ["вымич", "вымитянин", "вымянин"],
    "вымитянин": ["вымич", "вымянин", "вымитин"],
    "вымич": ["вымитянин", "вымянин", "вымитин"],
    "вымогав": ["вымогавши"],
    "вымогавши": ["вымогав"],
    "вымогатель": ["обирала", "лихоимец"],
    "вымогательский": ["лихоимский"],
    "вымогательство": ["вымогание", "вымогалово"],
    "вымозжив": ["вымозживши"],
    "вымозживши": ["вымозжив"],
    "вымоина": ["водомоина"],
    "вымокав": ["вымокавши"],
    "вымокавши": ["вымокав"],
    "вымокнув": ["вымокнувши"],
    "вымокнувши": ["вымокнув"],
    "вымолачивав": ["вымолачивавши"],
    "вымолачивавши": ["вымолачивав"],
    "вымолвив": ["вымолвивши"],
    "вымолвивши": ["вымолвив"],
    "вымолвляв": ["вымолвлявши"],
    "вымолвлявши": ["вымолвляв"],
    "вымолвлять": ["молвить"],
    "вымолив": ["вымоливши"],
    "вымоливши": ["вымолив"],
    "вымолить": ["выпросить"],
    "вымолов": ["вымоловши"],
    "вымоловши": ["вымолов"],
    "вымолотив": ["вымолотивши"],
    "вымолотивши": ["вымолотив"],
    "вымолчав": ["вымолчавши"],
    "вымолчавши": ["вымолчав"],
    "вымораживав": ["вымораживавши"],
    "вымораживавши": ["вымораживав"],
    "вымораживать": ["выстужать", "выстуживать", "раздражать", "выводить из себя"],
    "выморив": ["выморивши"],
    "выморивши": ["выморив"],
    "выморозив": ["выморозивши"],
    "выморозивши": ["выморозив"],
    "выморозок": ["отморозок"],
    "выморочный": ["бесхозный", "бесхозяйный", "безжизненный", "пустой", "мертвенный", "болезненный"],
    "выморщив": ["выморщивши"],
    "выморщивши": ["выморщив"],
    "вымостив": ["вымостивши"],
    "вымостивши": ["вымостив"],
    "вымотав": ["вымотавши"],
    "вымотавши": ["вымотав"],
    "вымочив": ["вымочивши"],
    "вымочивши": ["вымочив"],
    "вымудрив": ["вымудривши"],
    "вымудривши": ["вымудрив"],
    "вымуравив": ["вымуравивши"],
    "вымуравивши": ["вымуравив"],
    "вымуравливав": ["вымуравливавши"],
    "вымуравливавши": ["вымуравливав"],
    "вымуслив": ["вымусливши"],
    "вымусливав": ["вымусливавши"],
    "вымусливавши": ["вымусливав"],
    "вымусливши": ["вымуслив"],
    "вымучив": ["вымучивши"],
    "вымучивав": ["вымучивавши"],
    "вымучивавши": ["вымучивав"],
    "вымучивши": ["вымучив"],
    "вымуштровав": ["вымуштровавши"],
    "вымуштровавши": ["вымуштровав"],
    "вымчав": ["вымчавши"],
    "вымчавши": ["вымчав"],
    "вымыв": ["вымывши"],
    "вымывав": ["вымывавши"],
    "вымывавши": ["вымывав"],
    "вымывши": ["вымыв"],
    "вымылив": ["вымыливши"],
    "вымыливав": ["вымыливавши"],
    "вымыливавши": ["вымыливав"],
    "вымыливши": ["вымылив"],
    "вымысел": ["фантазия", "сочинение", "небыль", "небылица", "выдумка"],
    "вымыслив": ["вымысливши"],
    "вымысливши": ["вымыслив"],
    "вымыслить": ["выдумать"],
    "вымыть": ["отмыть", "помыть", "выстирать", "промыть"],
    "вымышленный": ["выдуманный"],
    "вымышляв": ["вымышлявши"],
    "вымышлявши": ["вымышляв"],
    "вымяв": ["вымявши"],
    "вымявши": ["вымяв"],
    "вымянин": ["вымич", "вымитянин", "вымитин"],
    "вымётывав": ["вымётывавши"],
    "вымётывавши": ["вымётывав"],
    "вынашивав": ["вынашивавши"],
    "вынашивавши": ["вынашивав"],
    "вынесение": ["вынос"],
    "вынизав": ["вынизавши"],
    "вынизавши": ["вынизав"],
    "вынизывав": ["вынизывавши"],
    "вынизывавши": ["вынизывав"],
    "выникав": ["выникавши"],
    "выникавши": ["выникав"],
    "выникнув": ["выникнувши"],
    "выникнувши": ["выникнув"],
    "вынимав": ["вынимавши"],
    "вынимавши": ["вынимав"],
    "вынимать": ["извлекать"],
    "вынимая": ["вынимавши"],
    "вынос": ["вынесение"],
    "выносив": ["выносивши"],
    "выносивши": ["выносив"],
    "выносить мозг": ["выносить мозги", "есть мозг", "ковырять мозг", "колупать мозги", "мозг выносить", "мозг ковырять", "мозги колупать", "мозги выносить", "ебать мозг", "ебать мозга", "ебать мозги", "мозг ебать", "мозга ебать", "мозги ебать", "пилить"],
    "выноска": ["вынос", "примечание", "сноска", "вынашивание", "износ"],
    "выносливость": ["закал", "закалённость", "закалка"],
    "выносной": ["внешний"],
    "вынув": ["вынувши"],
    "вынувши": ["вынув"],
    "вынудив": ["вынудивши"],
    "вынудивши": ["вынудив"],
    "вынудить": ["заставить", "принудить"],
    "вынуждав": ["вынуждавши"],
    "вынуждавши": ["вынуждав"],
    "вынуждать": ["заставлять", "принуждать", "понуждать", "вытягивать"],
    "вынужденное голосование": ["тактическое голосование", "умное голосование"],
    "вынужденный": ["невольный"],
    "вынутие": ["извлечение"],
    "вынуть": ["вытащить", "достать", "извлечь", "изъять", "выудить", "вынять"],
    "выныривав": ["выныривавши"],
    "выныривавши": ["выныривав"],
    "вынырнув": ["вынырнувши"],
    "вынырнувши": ["вынырнув"],
    "вынырнувший": ["всплывший"],
    "вынюхав": ["вынюхавши"],
    "вынюхавши": ["вынюхав"],
    "вынюхивав": ["вынюхивавши"],
    "вынюхивавши": ["вынюхивая", "вынюхивав"],
    "выняв": ["вынявши"],
    "вынявши": ["выняв"],
    "вынянчив": ["вынянчивши"],
    "вынянчивав": ["вынянчивавши"],
    "вынянчивавши": ["вынянчивав"],
    "вынянчивши": ["вынянчив"],
    "выняньчив": ["выняньчивши"],
    "выняньчивав": ["выняньчивавши"],
    "выняньчивавши": ["выняньчивав"],
    "выняньчивши": ["выняньчив"],
    "выострив": ["выостривши"],
    "выостривши": ["выострив"],
    "выостряв": ["выострявши"],
    "выострявши": ["выостряв"],
    "выпад": ["выпадение", "колющий удар", "наскок"],
    "выпадав": ["выпадавши"],
    "выпадавши": ["выпадав"],
    "выпадание": ["выпадение", "вываливание"],
    "выпадать": ["вываливаться", "случаться", "выдаваться"],
    "выпадение": ["выпаденье"],
    "выпаденье": ["выпадение"],
    "выпазив": ["выпазивши"],
    "выпазивши": ["выпазив"],
    "выпаивав": ["выпаивавши"],
    "выпаивавши": ["выпаивав"],
    "выпал": ["отпал"],
    "выпалзывав": ["выпалзывавши"],
    "выпалзывавши": ["выпалзывав"],
    "выпалив": ["выпаливши"],
    "выпаливав": ["выпаливавши"],
    "выпаливавши": ["выпаливав"],
    "выпаливать": ["выжигать", "сжигать"],
    "выпаливши": ["выпалив"],
    "выпалывав": ["выпалывавши"],
    "выпалывавши": ["выпалывав"],
    "выпалывать": ["полоть"],
    "выпарив": ["выпаривши"],
    "выпаривав": ["выпаривавши"],
    "выпаривавши": ["выпаривав"],
    "выпаривание": ["выпарка"],
    "выпаривши": ["выпарив"],
    "выпарка": ["выпаривание"],
    "выпархивав": ["выпархивавши"],
    "выпархивавши": ["выпархивав"],
    "выпарывав": ["выпарывавши"],
    "выпарывавши": ["выпарывав"],
    "выпаряв": ["выпарявши"],
    "выпарявши": ["выпаряв"],
    "выпас": ["выгон", "выпаска", "пажить", "пастьба", "попас", "паства", "пастбище"],
    "выпасав": ["выпасавши"],
    "выпасавши": ["выпасав"],
    "выпаска": ["выпас"],
    "выпасть": ["вывалиться", "упасть", "вылететь", "случиться", "попасться"],
    "выпасть из рук": ["отбиться от рук"],
    "выпасть на долю": ["прийтись", "достаться"],
    "выпахав": ["выпахавши"],
    "выпахавши": ["выпахав"],
    "выпахивав": ["выпахивавши"],
    "выпахивавши": ["выпахивав"],
    "выпахнув": ["выпахнувши"],
    "выпахнувши": ["выпахнув"],
    "выпачкав": ["выпачкавши"],
    "выпачкавши": ["выпачкав"],
    "выпачкать": ["марать", "грязнить", "изгваздать", "извозюкать"],
    "выпачкивав": ["выпачкивавши"],
    "выпачкивавши": ["выпачкивав"],
    "выпаяв": ["выпаявши"],
    "выпаявши": ["выпаяв"],
    "выпев": ["выпевши"],
    "выпевав": ["выпевавши"],
    "выпевавши": ["выпевав"],
    "выпевши": ["выпев"],
    "выпек": ["выпекание", "выпечка", "выход"],
    "выпекав": ["выпекавши"],
    "выпекавши": ["выпекав"],
    "выпекание": ["запекание"],
    "выпендривание": ["выпендрёж"],
    "выпендриваться": ["выпендрёжничать", "выёживаться"],
    "выпендрёж": ["выпендривание"],
    "выпендрёжник": ["позёр", "понторез", "выебонщик", "выёбщик"],
    "выпендрёжничав": ["выпендрёжничавши"],
    "выпендрёжничавши": ["выпендрёжничав"],
    "выпендрёжничать": ["выпендриваться"],
    "выпердев": ["выпердевши"],
    "выпердевши": ["выпердев"],
    "выпердыш": ["выблядок"],
    "выперев": ["выперши"],
    "выпередив": ["выпередивши"],
    "выпередивши": ["выпередив"],
    "выпереживав": ["выпереживавши"],
    "выпереживавши": ["выпереживав"],
    "выперхнув": ["выперхнувши"],
    "выперхнувши": ["выперхнув"],
    "выперши": ["выперев"],
    "выпестовав": ["выпестовавши"],
    "выпестовавши": ["выпестовав"],
    "выпестрив": ["выпестривши"],
    "выпестривши": ["выпестрив"],
    "выпестряв": ["выпестрявши"],
    "выпестрявши": ["выпестряв"],
    "выпечатав": ["выпечатавши"],
    "выпечатавши": ["выпечатав"],
    "выпечатывав": ["выпечатывавши"],
    "выпечатывавши": ["выпечатывав"],
    "выпечка": ["выпекание", "хлеб"],
    "выпив": ["выпивши"],
    "выпивав": ["выпивавши"],
    "выпивавши": ["выпивав"],
    "выпиванье": ["выпивание"],
    "выпивка": ["бухло"],
    "выпивон": ["выпивка", "попойка"],
    "выпивший": ["пьяный"],
    "выпил": ["вырез"],
    "выпилив": ["выпиливши"],
    "выпиливав": ["выпиливавши"],
    "выпиливавши": ["выпиливав"],
    "выпиливши": ["выпилив"],
    "выпилиться": ["покончить с собой", "самовыпилиться"],
    "выпинывав": ["выпинывавши"],
    "выпинывавши": ["выпинывав"],
    "выпинывать": ["выталкивать"],
    "выпирав": ["выпиравши"],
    "выпиравши": ["выпирав"],
    "выписав": ["выписавши"],
    "выписавши": ["выписав"],
    "выписать": ["списать", "скопировать", "вывести", "написать", "составить", "оформить", "подписаться", "вызвать", "исключить"],
    "выписка": ["выписывание", "оформление", "выдержка", "цитата"],
    "выписывав": ["выписывавши"],
    "выписывавши": ["выписывав"],
    "выписывать": ["списывать", "копировать", "выводить", "писать", "составлять", "оформлять", "подписываться", "вызывать", "исключать"],
    "выпить": ["осушить", "выдуть", "хлебнуть", "бухнуть", "вмазать", "выбухать", "дерябнуть", "клюкнуть", "принять на грудь", "погудеть", "поддать", "промочить горло", "накатить", "распить", "хлопнуть"],
    "выпихав": ["выпихавши"],
    "выпихавши": ["выпихав"],
    "выпихивав": ["выпихивавши"],
    "выпихивавши": ["выпихивав"],
    "выпихнув": ["выпихнувши"],
    "выпихнувши": ["выпихнув"],
    "выпихнуть": ["вытолкнуть"],
    "выплавив": ["выплавивши"],
    "выплавивши": ["выплавив"],
    "выплавление": ["выплавка"],
    "выплавливав": ["выплавливавши"],
    "выплавливавши": ["выплавливав"],
    "выплавляв": ["выплавлявши"],
    "выплавлявши": ["выплавляв"],
    "выплакав": ["выплакавши"],
    "выплакавши": ["выплакав"],
    "выплакивав": ["выплакивавши"],
    "выплакивавши": ["выплакивав"],
    "выпластав": ["выпластавши"],
    "выпластавши": ["выпластав"],
    "выпластывав": ["выпластывавши"],
    "выпластывавши": ["выпластывав"],
    "выплат": ["аплата", "выплата", "плата", "сплата"],
    "выплата": ["зарплата"],
    "выплатив": ["выплативши"],
    "выплативши": ["выплатив"],
    "выплатить": ["заплатить"],
    "выплачивав": ["выплачивавши"],
    "выплачивавши": ["выплачивав"],
    "выплачивание": ["выплата"],
    "выплачивать": ["платить"],
    "выплевав": ["выплевавши"],
    "выплевавши": ["выплевав"],
    "выплескав": ["выплескавши"],
    "выплескавши": ["выплескав"],
    "выплеснув": ["выплеснувши"],
    "выплеснувши": ["выплеснув"],
    "выплетав": ["выплетавши"],
    "выплетавши": ["выплетав"],
    "выплодив": ["выплодивши"],
    "выплодивши": ["выплодив"],
    "выплывав": ["выплывавши"],
    "выплывавши": ["выплывав"],
    "выплывать": ["всплывать"],
    "выплывши": ["выплыв"],
    "выплюнув": ["выплюнувши"],
    "выплюнувши": ["выплюнув"],
    "выплясав": ["выплясавши"],
    "выплясавши": ["выплясав"],
    "выплясывав": ["выплясывавши"],
    "выплясывавши": ["выплясывав"],
    "выплёвывав": ["выплёвывавши"],
    "выплёвывавши": ["выплёвывав"],
    "выплёскивав": ["выплёскивавши"],
    "выплёскивавши": ["выплёскивав"],
    "выпоив": ["выпоивши"],
    "выпоивши": ["выпоив"],
    "выполаживав": ["выполаживавши"],
    "выполаживавши": ["выполаживав"],
    "выполаскивав": ["выполаскивавши"],
    "выполаскивавши": ["выполаскивав"],
    "выползав": ["выползавши"],
    "выползавши": ["выползав"],
    "выползина": ["выползень", "выползок"],
    "выползок": ["выползень", "выползина"],
    "выполировав": ["выполировавши"],
    "выполировавши": ["выполировав"],
    "выполировывав": ["выполировывавши"],
    "выполировывавши": ["выполировывав"],
    "выполнение": ["исполнение", "осуществление", "реализация", "воплощение"],
    "выполненный": ["исполненный", "изготовленный", "произведённый"],
    "выполненье": ["выполнение"],
    "выполнив": ["выполнивши"],
    "выполнивши": ["выполнив"],
    "выполнимый": ["исполнимый"],
    "выполнить": ["осуществить", "исполнить", "создать", "изготовить"],
    "выполняв": ["выполнявши"],
    "выполнявши": ["выполняв"],
    "выполняемый": ["исполняемый"],
    "выполнять": ["исполнять", "осуществлять", "реализовывать", "создавать", "изготовлять", "созидать"],
    "выполов": ["выполовши"],
    "выполовши": ["выполов"],
    "выполоскав": ["выполоскавши"],
    "выполоскавши": ["выполоскав"],
    "выполоснув": ["выполоснувши"],
    "выполоснувши": ["выполоснув"],
    "выпользовав": ["выпользовавши"],
    "выпользовавши": ["выпользовав"],
    "выпонтировав": ["выпонтировавши"],
    "выпонтировавши": ["выпонтировав"],
    "выпоражнивав": ["выпоражнивавши"],
    "выпоражнивавши": ["выпоражнивав"],
    "выпоражнивать": ["опустошать", "осводождать", "очищать"],
    "выпоров": ["выпоровши"],
    "выпоровши": ["выпоров"],
    "выпорожнив": ["выпорожнивши"],
    "выпорожнивши": ["выпорожнив"],
    "выпорхнув": ["выпорхнувши"],
    "выпорхнувши": ["выпорхнув"],
    "выпотев": ["выпотевши"],
    "выпотевав": ["выпотевавши"],
    "выпотевавши": ["выпотевав"],
    "выпотевши": ["выпотев"],
    "выпотрашивав": ["выпотрашивавши"],
    "выпотрашивавши": ["выпотрашивав"],
    "выпотрошив": ["выпотрошивши"],
    "выпотрошивши": ["выпотрошив"],
    "выправив": ["выправивши"],
    "выправивши": ["выправив"],
    "выправка": ["выправление", "корректировка", "осанка"],
    "выправляв": ["выправлявши"],
    "выправлявши": ["выправляв"],
    "выправлять": ["выпрямлять", "распрямлять", "править", "исправлять", "поправлять", "корректировать", "точить", "заострять"],
    "выпрастывав": ["выпрастывавши"],
    "выпрастывавши": ["выпрастывав"],
    "выпрашивав": ["выпрашивавши"],
    "выпрашивавши": ["выпрашивав"],
    "выпрашиванье": ["выпрашивание"],
    "выпрашивать": ["выцыганивать"],
    "выпрев": ["выпревши"],
    "выпревав": ["выпревавши"],
    "выпревавши": ["выпревав"],
    "выпревши": ["выпрев"],
    "выпрессовав": ["выпрессовавши"],
    "выпрессовавши": ["выпрессовав"],
    "выпрессовывав": ["выпрессовывавши"],
    "выпрессовывавши": ["выпрессовывав"],
    "выпроваживав": ["выпроваживавши"],
    "выпроваживавши": ["выпроваживав"],
    "выпроваживать": ["выгонять", "изгонять"],
    "выпроводив": ["выпроводивши"],
    "выпроводивши": ["выпроводив"],
    "выпроводить": ["выгнать", "турнуть"],
    "выпровождав": ["выпровождавши"],
    "выпровождавши": ["выпровождав"],
    "выпровождать": ["выпроваживать", "выдворять"],
    "выпровождение": ["выпроваживание", "выдворение"],
    "выпродав": ["выпродавши"],
    "выпродавши": ["выпродав"],
    "выпрокидывав": ["выпрокидывавши"],
    "выпрокидывавши": ["выпрокидывав"],
    "выпрокинув": ["выпрокинувши"],
    "выпрокинувши": ["выпрокинув"],
    "выпросив": ["выпросивши"],
    "выпросивши": ["выпросив"],
    "выпростав": ["выпроставши"],
    "выпроставши": ["выпростав"],
    "выпростать": ["высвободить", "высунуть", "вызволить", "опорожнить"],
    "выпрудив": ["выпрудивши"],
    "выпрудивши": ["выпрудив"],
    "выпрыгивав": ["выпрыгивавши"],
    "выпрыгивавши": ["выпрыгивав"],
    "выпрыгивать": ["выскакивать"],
    "выпрыгивать из штанов": ["выпрыгивать из собственных штанов", "из штанов выпрыгивать", "из собственных штанов выпрыгивать", "заискивать", "выслуживаться"],
    "выпрыгнув": ["выпрыгнувши"],
    "выпрыгнувши": ["выпрыгнув"],
    "выпрыгнуть": ["выскочить"],
    "выпрыскав": ["выпрыскавши"],
    "выпрыскавши": ["выпрыскав"],
    "выпрыскивав": ["выпрыскивавши"],
    "выпрыскивавши": ["выпрыскивав"],
    "выпрыснув": ["выпрыснувши"],
    "выпрыснувши": ["выпрыснув"],
    "выпрягав": ["выпрягавши"],
    "выпрягавши": ["выпрягав"],
    "выпрягать": ["распрягать"],
    "выпрядав": ["выпрядавши"],
    "выпрядавши": ["выпрядав"],
    "выпрядание": ["выпрядка"],
    "выпрядать": ["выпрядывать"],
    "выпрядка": ["выпрядание"],
    "выпрядывав": ["выпрядывавши"],
    "выпрядывавши": ["выпрядывав"],
    "выпрядывать": ["выпрядать"],
    "выпрямив": ["выпрямивши"],
    "выпрямивши": ["выпрямив"],
    "выпрямить": ["выравнять", "расправить"],
    "выпрямиться": ["распрямиться", "разогнуться"],
    "выпрямливав": ["выпрямливавши"],
    "выпрямливавши": ["выпрямливав"],
    "выпрямляв": ["выпрямлявши"],
    "выпрямлявши": ["выпрямляв"],
    "выпрямлять": ["распрямлять"],
    "выпрямляться": ["распрямляться", "разгибаться"],
    "выпугав": ["выпугавши"],
    "выпугавши": ["выпугав"],
    "выпугать": ["выпугнуть"],
    "выпугивав": ["выпугивавши"],
    "выпугивавши": ["выпугивав"],
    "выпугнув": ["выпугнувши"],
    "выпугнувши": ["выпугнув"],
    "выпугнуть": ["вспугнуть"],
    "выпуки": ["упаги"],
    "выпуклина": ["выпуклость", "выпука"],
    "выпуклый": ["округлый", "выдающийся", "выступающий", "отчётливый", "подчёркнутый", "рельефный", "выразительный"],
    "выпуск": ["изготовление", "производство", "продукция", "номер", "передача", "серия", "эмиссия", "изъятие", "сокращение", "пропуск"],
    "выпускав": ["выпускавши"],
    "выпускавши": ["выпускав"],
    "выпускать": ["отпускать", "освобождать", "стрелять", "высовывать", "выдвигать"],
    "выпускной": ["выходной"],
    "выпустив": ["выпустивши"],
    "выпустивши": ["выпустив"],
    "выпустить": ["отпустить", "высунуть", "выдвинуть", "выстрелить", "освободить"],
    "выпутав": ["выпутавши"],
    "выпутавши": ["выпутав"],
    "выпутывав": ["выпутывавши"],
    "выпутывавши": ["выпутывав"],
    "выпучив": ["выпучивши"],
    "выпучивав": ["выпучивавши"],
    "выпучивавши": ["выпучивав"],
    "выпучивши": ["выпучив"],
    "выпушив": ["выпушивши"],
    "выпушивши": ["выпушив"],
    "выпушка": ["оторочка", "обшивка", "кант"],
    "выпущав": ["выпущавши"],
    "выпущавши": ["выпущав"],
    "выпытав": ["выпытавши"],
    "выпытавши": ["выпытав"],
    "выпытывав": ["выпытывавши"],
    "выпытывавши": ["выпытывав"],
    "выпыхивав": ["выпыхивавши"],
    "выпыхивавши": ["выпыхивав"],
    "выпыхнув": ["выпыхнувши"],
    "выпыхнувши": ["выпыхнув"],
    "выпь": ["водяной бык", "бугай"],
    "выпялив": ["выпяливши"],
    "выпяливав": ["выпяливавши"],
    "выпяливавши": ["выпяливав"],
    "выпяливши": ["выпялив"],
    "выпятив": ["выпятивши"],
    "выпятивши": ["выпятив"],
    "выпячивав": ["выпячивавши"],
    "выпячивавши": ["выпячивав"],
    "вырабатывав": ["вырабатывавши"],
    "вырабатывавши": ["вырабатывав"],
    "вырабатывание": ["продуцирование"],
    "вырабатывать": ["производить", "создавать", "формировать", "исчерпывать"],
    "выработав": ["выработавши"],
    "выработавши": ["выработав"],
    "выработать": ["произвести", "изготовить", "разработать", "сформировать", "заработать", "исчерпать"],
    "выработка": ["изготовление"],
    "выработывав": ["выработывавши"],
    "выработывавши": ["выработывав"],
    "выравнивав": ["выравнивавши"],
    "выравнивавши": ["выравнивав"],
    "выравнивание": ["сглаживание", "сглаживанье", "выравниванье", "унификация", "выключка"],
    "выравнивать": ["ровнять"],
    "выравняв": ["выравнявши"],
    "выравнявши": ["выравняв"],
    "выражав": ["выражавши"],
    "выражавши": ["выражав"],
    "выражать": ["проявлять", "передавать", "отражать", "демонстрировать"],
    "выражаться": ["обнаруживаться", "проявляться", "воплощаться", "высказываться", "изъясняться", "ругаться", "браниться", "обозначаться", "исчисляться"],
    "выражение": ["изъявление", "высказывание"],
    "выраженность": ["определённость", "проявление"],
    "выраженье": ["выражение"],
    "выразив": ["выразивши"],
    "выразивши": ["выразив"],
    "выразительный": ["наглядный", "доходчивый", "эмоциональный", "образный"],
    "выразить": ["проявить", "передать", "отразить", "продемонстрировать", "показать"],
    "выразиться": ["ругнуться"],
    "выразумев": ["выразумевши"],
    "выразумевши": ["выразумев"],
    "вырастав": ["выраставши"],
    "выраставши": ["вырастав"],
    "вырастать": ["взрослеть"],
    "вырасти": ["увеличиться", "повыситься", "возрасти", "подрасти", "усовершенствоваться", "перерасти", "развиться"],
    "вырастив": ["вырастивши"],
    "вырастивши": ["вырастив"],
    "вырастить": ["воспитать", "взрастить"],
    "выращивав": ["выращивавши"],
    "выращивавши": ["выращивав"],
    "выращиванье": ["выращивание"],
    "выращивать": ["воспитывать", "взращивать", "растить", "разводить"],
    "вырвав": ["вырвавши"],
    "вырвавши": ["вырвав"],
    "вырвать": ["выдрать", "выдернуть", "выхватить", "урвать"],
    "вырваться": ["вывернуться"],
    "вырви глаз": ["вырви-глаз", "вырви-глазы", "вывернет глаз", "глаз рвёт"],
    "вырвиглазный": ["уродливый", "страшный", "некрасивый", "несмотрибельный"],
    "выреветься": ["выплакаться"],
    "вырезав": ["вырезавши"],
    "вырезавши": ["вырезав"],
    "вырезка": ["вырезание", "вырезывание"],
    "вырезывав": ["вырезывавши"],
    "вырезывавши": ["вырезывав"],
    "вырезывание": ["вырезыванье", "выкраивание", "выкраиванье", "выгравирование", "выгравированье"],
    "вырезывать": ["вырезать"],
    "вырешав": ["вырешавши"],
    "вырешавши": ["вырешав"],
    "вырешив": ["вырешивши"],
    "вырешивав": ["вырешивавши"],
    "вырешивавши": ["вырешивав"],
    "вырешивши": ["вырешив"],
    "вырив": ["выривши"],
    "выривши": ["вырив"],
    "вырий": ["вырей", "ирей", "ирий"],
    "вырисовав": ["вырисовавши"],
    "вырисовавши": ["вырисовав"],
    "вырисовывав": ["вырисовывавши"],
    "вырисовывавши": ["вырисовывав"],
    "выровнив": ["выровнивши"],
    "выровнивши": ["выровнив"],
    "выровнить": ["выровнять"],
    "выровняв": ["выровнявши"],
    "выровнявши": ["выровняв"],
    "выродив": ["выродивши"],
    "выродивши": ["выродив"],
    "выродок": ["дегенерат", "урод", "нелюдь", "белая ворона"],
    "вырождав": ["вырождавши"],
    "вырождавши": ["вырождав"],
    "вырождаться": ["деградировать", "деэволюционировать", "дегенерировать", "дегенерироваться"],
    "вырожденец": ["дегенерат", "выродок", "декадент"],
    "вырождение": ["дегенерация"],
    "вырожденный": ["выродившийся"],
    "выронив": ["выронивши"],
    "выронивши": ["выронив"],
    "вырост": ["вырастание", "отросток", "нарост"],
    "вырубав": ["вырубавши"],
    "вырубавши": ["вырубав"],
    "вырубив": ["вырубивши"],
    "вырубивши": ["вырубив"],
    "выругав": ["выругавши"],
    "выругавши": ["выругав"],
    "выругаться": ["выбраниться", "ругнуться"],
    "вырулив": ["выруливши"],
    "выруливав": ["выруливавши"],
    "выруливавши": ["выруливав"],
    "выруливши": ["вырулив"],
    "вырумянив": ["вырумянивши"],
    "вырумянивши": ["вырумянив"],
    "вырумянить": ["нарумянить"],
    "выручав": ["выручавши"],
    "выручавши": ["выручав"],
    "выручальник": ["выручатель"],
    "выручатель": ["вызволитель", "выручалочка", "избавитель", "выручальник"],
    "выручив": ["выручивши"],
    "выручивши": ["выручив"],
    "вырыв": ["вырывши"],
    "вырывав": ["вырывавши"],
    "вырывавши": ["вырывав"],
    "вырыванье": ["вырывание"],
    "вырывать": ["выхватывать", "отделять"],
    "вырывши": ["вырыв"],
    "вырыгав": ["вырыгавши"],
    "вырыгавши": ["вырыгав"],
    "вырыть": ["выкопать"],
    "вырядив": ["вырядивши"],
    "вырядивши": ["вырядив"],
    "вырядить": ["нарядить"],
    "вырядиться": ["нарядиться", "разодеться"],
    "выряжав": ["выряжавши"],
    "выряжавши": ["выряжав"],
    "выряживав": ["выряживавши"],
    "выряживавши": ["выряживав"],
    "высадив": ["высадивши"],
    "высадивши": ["высадив"],
    "высадить": ["посадить", "вытолкать", "снять", "выломать", "выбить", "выкурить"],
    "высаживав": ["высаживавши"],
    "высаживавши": ["высаживав"],
    "высаживать": ["пересаживать", "выбивать", "выламывать", "выставлять"],
    "высака": ["высока"],
    "высака над": ["высока над"],
    "высалив": ["высаливши"],
    "высаливав": ["высаливавши"],
    "высаливавши": ["высаливав"],
    "высаливши": ["высалив"],
    "высасывав": ["высасывавши"],
    "высасывавши": ["высасывав"],
    "высачив": ["высачивши"],
    "высачивав": ["высачивавши"],
    "высачивавши": ["высачивав"],
    "высачивши": ["высачив"],
    "высватав": ["высватавши"],
    "высватавши": ["высватав"],
    "высватывав": ["высватывавши"],
    "высватывавши": ["высватывав"],
    "высвежевав": ["высвежевавши"],
    "высвежевавши": ["высвежевав"],
    "высверк": ["вспышка"],
    "высверкивав": ["высверкивавши"],
    "высверкивавши": ["высверкивав"],
    "высверкнув": ["высверкнувши"],
    "высверкнувши": ["высверкнув"],
    "высверлив": ["высверливши"],
    "высверливав": ["высверливавши"],
    "высверливавши": ["высверливав"],
    "высверливши": ["высверлив"],
    "высветив": ["высветивши"],
    "высветивши": ["высветив"],
    "высветлив": ["высветливши"],
    "высветливав": ["высветливавши"],
    "высветливавши": ["высветливав"],
    "высветливши": ["высветлив"],
    "высветляв": ["высветлявши"],
    "высветлявши": ["высветляв"],
    "высветлять": ["высветливать"],
    "высвечивав": ["высвечивавши"],
    "высвечивавши": ["высвечивав"],
    "высвечивание": ["подсветка"],
    "высвистав": ["высвиставши"],
    "высвиставши": ["высвистав"],
    "высвистать": ["высвистеть"],
    "высвистев": ["высвистевши"],
    "высвистевши": ["высвистев"],
    "высвистывав": ["высвистывавши"],
    "высвистывавши": ["высвистывав"],
    "высвободив": ["высвободивши"],
    "высвободивши": ["высвободив"],
    "высвобождав": ["высвобождавши"],
    "высвобождавши": ["высвобождав"],
    "высвобождаться": ["освобождаться"],
    "высев": ["высевание", "высевка"],
    "высевав": ["высевавши"],
    "высевавши": ["высевав"],
    "высевать": ["сеять", "высеивать", "просеивать"],
    "высеивав": ["высеивавши"],
    "высеивавши": ["высеивав"],
    "высеивать": ["высевать", "засеивать"],
    "высекав": ["высекавши"],
    "высекавши": ["высекав"],
    "высекать": ["вырубать", "вырезать"],
    "выселив": ["выселивши"],
    "выселивши": ["выселив"],
    "выселки": ["выселок"],
    "выселяв": ["выселявши"],
    "выселявши": ["выселяв"],
    "выселять": ["выдворять"],
    "высеребрив": ["высеребривши"],
    "высеребривши": ["высеребрив"],
    "высесть": ["спешиться", "высадиться"],
    "высечь": ["выпороть", "отстегать", "посечь", "выдрать", "исполосовать", "исхлестать", "отодрать", "отхлестать", "излупить", "отлупить", "отлупцевать"],
    "высеяв": ["высеявши"],
    "высеявши": ["высеяв"],
    "высив": ["высивши"],
    "высивши": ["высив"],
    "высидев": ["высидевши"],
    "высидевши": ["высидев"],
    "высидной": ["высидочный"],
    "высидочный": ["высидной"],
    "высиживав": ["высиживавши"],
    "высиживавши": ["высиживав"],
    "высинив": ["высинивши"],
    "высинивав": ["высинивавши"],
    "высинивавши": ["высинивав"],
    "высинивать": ["высинять"],
    "высинивши": ["высинив"],
    "высиняв": ["высинявши"],
    "высинявши": ["высиняв"],
    "высинять": ["высинивать"],
    "высирав": ["высиравши"],
    "высиравши": ["высирав"],
    "выситься": ["возвышаться"],
    "выскабливав": ["выскабливавши"],
    "выскабливавши": ["выскабливав"],
    "выскабливание": ["кюретаж"],
    "высказав": ["высказавши"],
    "высказавши": ["высказав"],
    "высказать": ["сказать", "изречь", "произнести"],
    "высказывав": ["высказывавши"],
    "высказывавши": ["высказывав"],
    "высказывание": ["произнесение", "говорение", "изречение", "выражение", "мысль", "речение", "суждение"],
    "высказыванье": ["высказывание"],
    "выскакав": ["выскакавши"],
    "выскакавши": ["выскакав"],
    "выскакивав": ["выскакивавши"],
    "выскакивавши": ["выскакивав"],
    "выскакнув": ["выскакнувши"],
    "выскакнувши": ["выскакнув"],
    "выскаливать": ["оскаливать", "скалить"],
    "выскальзывав": ["выскальзывавши"],
    "выскальзывавши": ["выскальзывав"],
    "выскобелив": ["выскобеливши"],
    "выскобеливши": ["выскобелив"],
    "выскоблив": ["выскобливши"],
    "выскобливши": ["выскоблив"],
    "выскоблить": ["отскоблить", "соскоблить"],
    "выскользав": ["выскользавши"],
    "выскользавши": ["выскользав"],
    "выскользнув": ["выскользнувши"],
    "выскользнувши": ["выскользнув"],
    "выскочив": ["выскочивши"],
    "выскочивши": ["выскочив"],
    "выскребав": ["выскребавши"],
    "выскребавши": ["выскребав"],
    "выскрёбывав": ["выскрёбывавши"],
    "выскрёбывавши": ["выскрёбывав"],
    "выслав": ["выславши"],
    "выславши": ["выслав"],
    "выслать": ["направить", "послать", "переслать", "прислать", "сослать"],
    "выследив": ["выследивши"],
    "выследивши": ["выследив"],
    "выслеживав": ["выслеживавши"],
    "выслеживавши": ["выслеживав"],
    "выслеживанье": ["выслеживание"],
    "выслеживать": ["охотиться"],
    "выслужив": ["выслуживши"],
    "выслуживав": ["выслуживавши"],
    "выслуживавши": ["выслуживав"],
    "выслуживание": ["выслуживанье"],
    "выслуживши": ["выслужив"],
    "выслушав": ["выслушавши"],
    "выслушавши": ["выслушав"],
    "выслушивав": ["выслушивавши"],
    "выслушивавши": ["выслушивав"],
    "выслушиванье": ["выслушивание"],
    "высмаливав": ["высмаливавши"],
    "высмаливавши": ["высмаливав"],
    "высмаркивав": ["высмаркивавши"],
    "высмаркивавши": ["высмаркивав"],
    "высматривав": ["высматривавши"],
    "высматривавши": ["высматривав"],
    "высматривать": ["выглядывать"],
    "высмеивав": ["высмеивавши"],
    "высмеивавши": ["высмеивав"],
    "высмеивать": ["осмеивать"],
    "высмеиваться": ["осмеиваться"],
    "высмеяв": ["высмеявши"],
    "высмеявши": ["высмеяв"],
    "высмеять": ["осмеять", "поднять на смех"],
    "высмолив": ["высмоливши"],
    "высмоливши": ["высмолив"],
    "высморкав": ["высморкавши"],
    "высморкавши": ["высморкав"],
    "высморкнув": ["высморкнувши"],
    "высморкнувши": ["высморкнув"],
    "высмотрев": ["высмотревши"],
    "высмотревши": ["высмотрев"],
    "высовывав": ["высовывавши"],
    "высовывавши": ["высовывав"],
    "высока": ["высака"],
    "высока над": ["высака над"],
    "высокая договаривающаяся сторона": ["государство"],
    "высокая мода": ["от кутюр"],
    "высокий": ["большой", "важный", "уважаемый"],
    "высокоблагородие": ["высокоблагородье", "вашескородие"],
    "высокоблагородье": ["высокоблагородие"],
    "высокобюджетный": ["высокозатратный", "крупнобюджетный"],
    "высокогорный": ["мули", "гора", "горка"],
    "высокодисперсный": ["мелкодисперсный", "тонкодисперсный"],
    "высокодоходный": ["прибыльный"],
    "высокозатратный": ["дорогой"],
    "высокоинтенсивный": ["интенсивный"],
    "высококвалифицированный": ["умелый"],
    "высоколегированный": ["сильнолегированный"],
    "высоколобый": ["лобастый"],
    "высокоманёвренный": ["манёвренный"],
    "высокомерие": ["гордыня", "надменность", "спесь"],
    "высокомерничав": ["высокомерничавши"],
    "высокомерничавши": ["высокомерничав"],
    "высокомерно": ["надменно", "презрительно", "спесиво", "чванливо"],
    "высокомерность": ["высокомерие"],
    "высокомерный": ["заносчивый", "надменный", "горделивый", "кичливый", "презрительный", "тщеславный", "спесивый", "многомерный"],
    "высокомерье": ["высокомерие"],
    "высокомолекулярное соединение": ["полимер"],
    "высокомолекулярный": ["макромолекулярный"],
    "высокоморальный": ["высоконравственный"],
    "высоконравственный": ["высокоморальный"],
    "высокообразованный": ["академичный"],
    "высокоодарённый": ["талантливый"],
    "высокооценённый": ["чтимый"],
    "высокопарно": ["торжественно", "напыщенно"],
    "высокопарный": ["помпезный", "торжественный"],
    "высокоплан": ["верхнеплан"],
    "высокополимерный": ["полимерный"],
    "высокопородистый": ["высокопородный"],
    "высокопреосвященнейший": ["высокопреосвященный"],
    "высокоприбыльный": ["высокодоходный"],
    "высокопроизводительно": ["ударно"],
    "высокорадиоактивный": ["сильнорадиоактивный"],
    "высокоразвитый": ["высокоразвитой"],
    "высокорискованный": ["высокорисковый"],
    "высокорисковый": ["высокорискованный"],
    "высокородный": ["знатный", "родовитый", "благородный"],
    "высокородье": ["высокородие"],
    "высокорослость": ["гигантизм"],
    "высокость": ["высота"],
    "высокотехнологический": ["высокотехнологичный"],
    "высокотехнологичный": ["высокотехнологический", "наукоёмкий", "хайтековский"],
    "высокоточный": ["прецизионный"],
    "высокоуважаемый": ["глубокоуважаемый"],
    "высокоумие": ["гордыня", "высокоумсто", "высокомудрие", "высокомыслие", "высокомерие"],
    "высокоумье": ["высокоумие"],
    "высокоэнергетический": ["высокоэнергичный", "высокоэнергетичный"],
    "высокоэнергичный": ["высокоэнергетический"],
    "высокоэтажный": ["многоэтажный"],
    "высокоэффективно": ["продуктивно"],
    "высол": ["выцвет", "эфлоресценция"],
    "высолаживав": ["высолаживавши"],
    "высолаживавши": ["высолаживав"],
    "высолив": ["высоливши"],
    "высоливши": ["высолив"],
    "высолить": ["просолить"],
    "высолодив": ["высолодивши"],
    "высолодивши": ["высолодив"],
    "высосав": ["высосавши"],
    "высосавши": ["высосав"],
    "высота": ["вышина", "высь", "небо", "высотка", "рекорд", "достижение", "вершина", "частота", "угол возвышения"],
    "высотка": ["высота"],
    "высотомер": ["альтиметр"],
    "высохнув": ["высохнувши"],
    "высохнувши": ["высохнув"],
    "высочайший": ["высший", "императорский", "царский", "монарший"],
    "высочив": ["высочивши"],
    "высочивши": ["высочив"],
    "выспав": ["выспавши"],
    "выспавши": ["выспав"],
    "выспаривав": ["выспаривавши"],
    "выспаривавши": ["выспаривав"],
    "выспев": ["выспевши"],
    "выспевав": ["выспевавши"],
    "выспевавши": ["выспевав"],
    "выспевши": ["выспев"],
    "выспорив": ["выспоривши"],
    "выспоривши": ["выспорив"],
    "выспрашивав": ["выспрашивавши"],
    "выспрашивавши": ["выспрашивав"],
    "выспренне": ["возвышенно", "торжественно"],
    "выспренний": ["выспренный", "высокопарный", "напыщенный", "горний"],
    "выспренно": ["выспренне"],
    "выспренность": ["высокопарность"],
    "выспренный": ["выспренний", "вычурный"],
    "выспросив": ["выспросивши"],
    "выспросивши": ["выспросив"],
    "высрав": ["высравши"],
    "высравши": ["высрав"],
    "высрать": ["выкакать", "сказать", "ляпнуть", "брякнуть", "взболтнуть", "выдать", "сделать", "оплошать", "родить", "разродиться"],
    "выставив": ["выставивши"],
    "выставивши": ["выставив"],
    "выставка": ["выставление", "выкладывание", "экспозиция"],
    "выставком": ["выставочный", "комитет"],
    "выставляв": ["выставлявши"],
    "выставлявши": ["выставляв"],
    "выставлять": ["выдвигать", "вынимать", "выгонять", "выпроваживать", "экспонировать", "демонстрировать", "показывать", "расставлять", "продвигать", "предлагать", "представлять", "вписывать", "ставить", "фиксировать", "угощать"],
    "выстаивав": ["выстаивавши"],
    "выстаивавши": ["выстаивав"],
    "выстарев": ["выстаревши"],
    "выстаревши": ["выстарев"],
    "выстегав": ["выстегавши"],
    "выстегавши": ["выстегав"],
    "выстегнув": ["выстегнувши"],
    "выстегнувши": ["выстегнув"],
    "выстелив": ["выстеливши"],
    "выстеливши": ["выстелив"],
    "выстилав": ["выстилавши"],
    "выстилавши": ["выстилав"],
    "выстилать": ["покрывать", "стлать", "застилать", "исстилать", "укладывать", "устилать", "плыть", "идти"],
    "выстирав": ["выстиравши"],
    "выстиравши": ["выстирав"],
    "выстирывав": ["выстирывавши"],
    "выстирывавши": ["выстирывав"],
    "выстлав": ["выстлавши"],
    "выстлавши": ["выстлав"],
    "выстояв": ["выстоявши"],
    "выстоявши": ["выстояв"],
    "выстоять": ["отстоять", "достояться", "выдержать", "выдюжить", "устоять"],
    "выстрагивав": ["выстрагивавши"],
    "выстрагивавши": ["выстрагивав"],
    "выстрадав": ["выстрадавши"],
    "выстрадавши": ["выстрадав"],
    "выстраивав": ["выстраивавши"],
    "выстраивавши": ["выстраивав"],
    "выстраивать": ["расставлять", "строить", "сооружать", "возводить", "устраивать", "вытворять"],
    "выстраиваться": ["строиться", "отстраиваться", "сооружаться"],
    "выстрачивав": ["выстрачивавши"],
    "выстрачивавши": ["выстрачивав"],
    "выстрелив": ["выстреливши"],
    "выстреливав": ["выстреливавши"],
    "выстреливавши": ["выстреливав"],
    "выстреливать": ["стрелять", "производить выстрел"],
    "выстреливши": ["выстрелив"],
    "выстрелить": ["стрельнуть", "пальнуть", "выпалить", "отрезать"],
    "выстреляв": ["выстрелявши"],
    "выстрелявши": ["выстреляв"],
    "выстригав": ["выстригавши"],
    "выстригавши": ["выстригав"],
    "выстригаемый": ["удаляемый", "корректируемый"],
    "выстрогав": ["выстрогавши"],
    "выстрогавши": ["выстрогав"],
    "выстроив": ["выстроивши"],
    "выстроивши": ["выстроив"],
    "выстрочив": ["выстрочивши"],
    "выстрочивши": ["выстрочив"],
    "выстругав": ["выстругавши"],
    "выстругавши": ["выстругав"],
    "выстругивав": ["выстругивавши"],
    "выстругивавши": ["выстругивав"],
    "выстудив": ["выстудивши"],
    "выстудивши": ["выстудив"],
    "выстужав": ["выстужавши"],
    "выстужавши": ["выстужав"],
    "выстуживав": ["выстуживавши"],
    "выстуживавши": ["выстуживав"],
    "выстукав": ["выстукавши"],
    "выстукавши": ["выстукав"],
    "выстукивав": ["выстукивавши"],
    "выстукивавши": ["выстукивав"],
    "выступав": ["выступавши"],
    "выступавши": ["выступав"],
    "выступавший": ["докладчик", "оратор", "спикер"],
    "выступание": ["выпирание"],
    "выступать": ["выдаваться", "выделяться", "отправляться", "выходить", "проступать", "появляться", "вышагивать", "вякать"],
    "выступив": ["выступивши"],
    "выступивши": ["выступив"],
    "выступление": ["выдвижение", "выход", "марш", "речь", "доклад", "перформанс"],
    "выступленье": ["выступление"],
    "выстучав": ["выстучавши"],
    "выстучавши": ["выстучав"],
    "выстучать": ["выстукать"],
    "выстыв": ["выстывши"],
    "выстывав": ["выстывавши"],
    "выстывавши": ["выстывав"],
    "выстывши": ["выстыв"],
    "выстыть": ["выстудиться", "остыть", "простынуть", "простыть", "остынуть", "настыть", "настудиться", "охладиться"],
    "выстёбывав": ["выстёбывавши"],
    "выстёбывавши": ["выстёбывав"],
    "выстёгивав": ["выстёгивавши"],
    "выстёгивавши": ["выстёгивав"],
    "высудив": ["высудивши"],
    "высудивши": ["высудив"],
    "высуживав": ["высуживавши"],
    "высуживавши": ["высуживав"],
    "высунув": ["высунувши"],
    "высунувши": ["высунув"],
    "высурмив": ["высурмивши"],
    "высурмивши": ["высурмив"],
    "высурьмив": ["высурьмивши"],
    "высурьмивши": ["высурьмив"],
    "высучив": ["высучивши"],
    "высучивав": ["высучивавши"],
    "высучивавши": ["высучивав"],
    "высучивши": ["высучив"],
    "высушенный": ["засушенный"],
    "высушив": ["высушивши"],
    "высушивав": ["высушивавши"],
    "высушивавши": ["высушивав"],
    "высушиваться": ["высыхать", "сохнуть"],
    "высушивши": ["высушив"],
    "высушиться": ["высохнуть", "иссохнуть"],
    "высчитав": ["высчитавши"],
    "высчитавши": ["высчитав"],
    "высчитывав": ["высчитывавши"],
    "высчитывавши": ["высчитывав"],
    "высшая математика": ["вышка", "премудрость", "бином ньютона"],
    "высшая мера наказания": ["высшая мера", "вышка", "вышак"],
    "высшая школа": ["высшее учебное заведение"],
    "высшего полёта": ["высокого полёта", "шишка"],
    "высшее образование": ["третичное образование"],
    "высшее собрание": ["маджлиси оли"],
    "высшее учебное заведение": ["вуз", "высшая школа"],
    "высший": ["верховный", "главный", "высочайший"],
    "высылав": ["высылавши"],
    "высылавши": ["высылав"],
    "высыпав": ["высыпавши"],
    "высыпавши": ["высыпав"],
    "высыпь": ["сыпь"],
    "высыхав": ["высыхавши"],
    "высыхавши": ["высыхав"],
    "высыхать": ["засыхать", "сохнуть", "вянуть", "увядать", "чахнуть"],
    "высь": ["вышина"],
    "вытаивав": ["вытаивавши"],
    "вытаивавши": ["вытаивав"],
    "выталкивав": ["выталкивавши"],
    "выталкивавши": ["выталкивав"],
    "выталкивать": ["выбивать", "выгонять"],
    "вытанцевав": ["вытанцевавши"],
    "вытанцевавши": ["вытанцевав"],
    "вытанцовывав": ["вытанцовывавши"],
    "вытанцовывавши": ["вытанцовывав"],
    "вытапливав": ["вытапливавши"],
    "вытапливавши": ["вытапливав"],
    "вытаптывав": ["вытаптывавши"],
    "вытаптывавши": ["вытаптывав"],
    "вытараскивав": ["вытараскивавши"],
    "вытараскивавши": ["вытараскивав"],
    "вытаращив": ["вытаращивши"],
    "вытаращивав": ["вытаращивавши"],
    "вытаращивавши": ["вытаращивав"],
    "вытаращивать": ["выпучивать"],
    "вытаращивши": ["вытаращив"],
    "вытаскав": ["вытаскавши"],
    "вытаскавши": ["вытаскав"],
    "вытаскивав": ["вытаскивавши"],
    "вытаскивавши": ["вытаскивав"],
    "вытаскиванье": ["вытаскивание"],
    "вытаскивать": ["вытягивать", "красть", "тырить"],
    "вытатуировав": ["вытатуировавши"],
    "вытатуировавши": ["вытатуировав"],
    "вытачав": ["вытачавши"],
    "вытачавши": ["вытачав"],
    "вытачивав": ["вытачивавши"],
    "вытачивавши": ["вытачивав"],
    "вытащив": ["вытащивши"],
    "вытащивши": ["вытащив"],
    "вытащить": ["вытянуть", "стащить", "стянуть", "украсть"],
    "вытаяв": ["вытаявши"],
    "вытаявши": ["вытаяв"],
    "вытвердив": ["вытвердивши"],
    "вытвердивши": ["вытвердив"],
    "вытвердить": ["заучить", "вызубрить", "зазубрить", "затвердить"],
    "вытверживав": ["вытверживавши"],
    "вытверживавши": ["вытверживав"],
    "вытверживать": ["заучивать", "зазубривать", "выучивать"],
    "вытворив": ["вытворивши"],
    "вытворивши": ["вытворив"],
    "вытворяв": ["вытворявши"],
    "вытворявши": ["вытворяв"],
    "вытегор": ["вытегорец"],
    "вытекав": ["вытекавши"],
    "вытекавши": ["вытекав"],
    "вытекать": ["истекать", "брать начало", "проистекать", "следовать"],
    "вытеребив": ["вытеребивши"],
    "вытеребивши": ["вытеребив"],
    "вытерев": ["вытерши"],
    "вытереть": ["протереть", "утереть", "стереть"],
    "вытерпев": ["вытерпевши"],
    "вытерпевши": ["вытерпев"],
    "вытерпливав": ["вытерпливавши"],
    "вытерпливавши": ["вытерпливав"],
    "вытерши": ["вытерев"],
    "вытесав": ["вытесавши"],
    "вытесавши": ["вытесав"],
    "вытеснив": ["вытеснивши"],
    "вытеснивши": ["вытеснив"],
    "вытесняв": ["вытеснявши"],
    "вытеснявши": ["вытесняв"],
    "вытечь": ["выливать", "вытекать"],
    "вытирав": ["вытиравши"],
    "вытиравши": ["вытирав"],
    "вытирать": ["протирать", "очищать", "стирать"],
    "вытискав": ["вытискавши"],
    "вытискавши": ["вытискав"],
    "вытискивав": ["вытискивавши"],
    "вытискивавши": ["вытискивав"],
    "вытиснив": ["вытиснивши"],
    "вытиснивши": ["вытиснив"],
    "вытиснить": ["выдавить"],
    "вытиснув": ["вытиснувши"],
    "вытиснувши": ["вытиснув"],
    "вытиснуть": ["вытиснить"],
    "вытисняв": ["вытиснявши"],
    "вытиснявши": ["вытисняв"],
    "выткав": ["выткавши"],
    "выткавши": ["выткав"],
    "выткнув": ["выткнувши"],
    "выткнувши": ["выткнув"],
    "вытлев": ["вытлевши"],
    "вытлевши": ["вытлев"],
    "вытолкав": ["вытолкавши"],
    "вытолкавши": ["вытолкав"],
    "вытолкнув": ["вытолкнувши"],
    "вытолкнувши": ["вытолкнув"],
    "вытопив": ["вытопивши"],
    "вытопивши": ["вытопив"],
    "вытопить": ["истопить", "протопить"],
    "вытоптав": ["вытоптавши"],
    "вытоптавши": ["вытоптав"],
    "выторачивав": ["выторачивавши"],
    "выторачивавши": ["выторачивав"],
    "выторговав": ["выторговавши"],
    "выторговавши": ["выторговав"],
    "выторговывав": ["выторговывавши"],
    "выторговывавши": ["выторговывав"],
    "вытормошив": ["вытормошивши"],
    "вытормошивши": ["вытормошив"],
    "выторочив": ["выторочивши"],
    "выторочивши": ["выторочив"],
    "выточив": ["выточивши"],
    "выточивши": ["выточив"],
    "выточка": ["вытачивание"],
    "вытошнив": ["вытошнивши"],
    "вытошнивши": ["вытошнив"],
    "вытравив": ["вытравивши"],
    "вытравивши": ["вытравив"],
    "вытравливав": ["вытравливавши"],
    "вытравливавши": ["вытравливав"],
    "вытравливать": ["вытравлять"],
    "вытравляв": ["вытравлявши"],
    "вытравлявши": ["вытравляв"],
    "вытравлять": ["вытравливать"],
    "вытраивав": ["вытраивавши"],
    "вытраивавши": ["вытраивав"],
    "вытралив": ["вытраливши"],
    "вытраливав": ["вытраливавши"],
    "вытраливавши": ["вытраливав"],
    "вытраливши": ["вытралив"],
    "вытрамбовав": ["вытрамбовавши"],
    "вытрамбовавши": ["вытрамбовав"],
    "вытрамбовывав": ["вытрамбовывавши"],
    "вытрамбовывавши": ["вытрамбовывав"],
    "вытребовав": ["вытребовавши"],
    "вытребовавши": ["вытребовав"],
    "вытрезвив": ["вытрезвивши"],
    "вытрезвивши": ["вытрезвив"],
    "вытрезвиловка": ["вытрезвяк"],
    "вытрезвитель": ["медвытрезвитель", "вытрезвиловка", "трезвяк"],
    "вытрезвить": ["отрезвить"],
    "вытрезвляв": ["вытрезвлявши"],
    "вытрезвлявши": ["вытрезвляв"],
    "вытрезвлять": ["отрезвлять"],
    "вытренировав": ["вытренировавши"],
    "вытренировавши": ["вытренировав"],
    "вытрепав": ["вытрепавши"],
    "вытрепавши": ["вытрепав"],
    "вытрескав": ["вытрескавши"],
    "вытрескавши": ["вытрескав"],
    "вытроив": ["вытроивши"],
    "вытроивши": ["вытроив"],
    "вытрусив": ["вытрусивши"],
    "вытрусивши": ["вытрусив"],
    "вытрусить": ["вытряхнуть", "вытрясти"],
    "вытрушивав": ["вытрушивавши"],
    "вытрушивавши": ["вытрушивав"],
    "вытрясав": ["вытрясавши"],
    "вытрясавши": ["вытрясав"],
    "вытряхав": ["вытряхавши"],
    "вытряхавши": ["вытряхав"],
    "вытряхивав": ["вытряхивавши"],
    "вытряхивавши": ["вытряхивав"],
    "вытряхнув": ["вытряхнувши"],
    "вытряхнувши": ["вытряхнув"],
    "вытряхнуть из кителя": ["растереть по переборке", "матку вывернуть", "матку наизнанку вывернуть", "глаз на жопу натянуть", "из кителя вытряхнуть", "по переборке растереть"],
    "вытрёпывав": ["вытрёпывавши"],
    "вытрёпывавши": ["вытрёпывав"],
    "вытулив": ["вытуливши"],
    "вытуливши": ["вытулив"],
    "вытулить": ["выставлять", "высовывать", "выпучивать", "выпяливать", "выпячивать"],
    "вытурив": ["вытуривши"],
    "вытуривав": ["вытуривавши"],
    "вытуривавши": ["вытуривав"],
    "вытуривши": ["вытурив"],
    "вытурить": ["прогнать", "выгнать"],
    "вытуряв": ["вытурявши"],
    "вытурявши": ["вытуряв"],
    "вытушевав": ["вытушевавши"],
    "вытушевавши": ["вытушевав"],
    "вытушёвывав": ["вытушёвывавши"],
    "вытушёвывавши": ["вытушёвывав"],
    "вытыкав": ["вытыкавши"],
    "вытыкавши": ["вытыкав"],
    "выть": ["завывать"],
    "вытягав": ["вытягавши"],
    "вытягавши": ["вытягав"],
    "вытягивав": ["вытягивавши"],
    "вытягивавши": ["вытягивав"],
    "вытягиванье": ["вытягивание"],
    "вытягивать": ["простирать", "протягивать", "выстраивать", "вытаскивать"],
    "вытяжка": ["экстракт"],
    "вытянув": ["вытянувши"],
    "вытянувши": ["вытянув"],
    "вытянуться": ["вырасти"],
    "вытёсывав": ["вытёсывавши"],
    "вытёсывавши": ["вытёсывав"],
    "выудив": ["выудивши"],
    "выудивши": ["выудив"],
    "выуживав": ["выуживавши"],
    "выуживавши": ["выуживав"],
    "выутюжив": ["выутюживши"],
    "выутюживши": ["выутюжив"],
    "выутюжить": ["выгладить"],
    "выучив": ["выучивши"],
    "выучивав": ["выучивавши"],
    "выучивавши": ["выучивав"],
    "выучивать": ["учить", "научать", "запоминать", "заучивать"],
    "выучиваться": ["учиться", "обучаться"],
    "выучивши": ["выучив"],
    "выучить": ["обучить", "научить", "заучить"],
    "выучиться": ["научиться", "обучиться"],
    "выучка": ["ученичество", "учение", "обучение", "навык"],
    "вых": ["выходной"],
    "выхаживав": ["выхаживавши"],
    "выхаживавши": ["выхаживав"],
    "выхаживать": ["вылечивать", "излечивать", "исцелять", "вытягивать", "воспитывать", "взращивать", "вынянчивать", "выращивать", "пестовать"],
    "выхаркав": ["выхаркавши"],
    "выхаркавши": ["выхаркав"],
    "выхаркивав": ["выхаркивавши"],
    "выхаркивавши": ["выхаркивав"],
    "выхаркнув": ["выхаркнувши"],
    "выхаркнувши": ["выхаркнув"],
    "выхвалив": ["выхваливши"],
    "выхваливав": ["выхваливавши"],
    "выхваливавши": ["выхваливав"],
    "выхваливши": ["выхвалив"],
    "выхваляв": ["выхвалявши"],
    "выхвалявши": ["выхваляв"],
    "выхватив": ["выхвативши"],
    "выхвативши": ["выхватив"],
    "выхватывав": ["выхватывавши"],
    "выхватывавши": ["выхватывав"],
    "выхитрив": ["выхитривши"],
    "выхитривав": ["выхитривавши"],
    "выхитривавши": ["выхитривав"],
    "выхитривши": ["выхитрив"],
    "выхлебав": ["выхлебавши"],
    "выхлебавши": ["выхлебав"],
    "выхлебнув": ["выхлебнувши"],
    "выхлебнувши": ["выхлебнув"],
    "выхлеснув": ["выхлеснувши"],
    "выхлеснувши": ["выхлеснув"],
    "выхлестав": ["выхлеставши"],
    "выхлеставши": ["выхлестав"],
    "выхлестнув": ["выхлестнувши"],
    "выхлестнувши": ["выхлестнув"],
    "выхлоп": ["перегар", "результативность"],
    "выхлопав": ["выхлопавши"],
    "выхлопавши": ["выхлопав"],
    "выхлопатывав": ["выхлопатывавши"],
    "выхлопатывавши": ["выхлопатывав"],
    "выхлопнув": ["выхлопнувши"],
    "выхлопнувши": ["выхлопнув"],
    "выхлопотав": ["выхлопотавши"],
    "выхлопотавши": ["выхлопотав"],
    "выхлопотать": ["раздобыть", "заполучить", "достигнуть"],
    "выхлопывав": ["выхлопывавши"],
    "выхлопывавши": ["выхлопывав"],
    "выхлёбывав": ["выхлёбывавши"],
    "выхлёбывавши": ["выхлёбывав"],
    "выхлёстывав": ["выхлёстывавши"],
    "выхлёстывавши": ["выхлёстывав"],
    "выховывав": ["выховывавши"],
    "выховывавши": ["выховывав"],
    "выход": ["исход", "уход", "решение", "производство", "появление"],
    "выходец": ["уроженец"],
    "выходив": ["выходивши"],
    "выходивши": ["выходив"],
    "выходить": ["вылечить", "вытянуть", "воспитать", "вынянчить", "выпестовать", "взрастить", "вскормить", "вырастить"],
    "выходить в свет": ["издаваться", "публиковаться", "печататься"],
    "выходить из себя": ["гневаться", "сердиться", "негодовать"],
    "выходка": ["проказа", "шалость", "эскапада"],
    "выходной": ["оконечный", "выводной", "праздничный", "нарядный", "парадный", "торжественный"],
    "выхолаживав": ["выхолаживавши"],
    "выхолаживавши": ["выхолаживав"],
    "выхолащивав": ["выхолащивавши"],
    "выхолащивавши": ["выхолащивав"],
    "выхолащивание": ["обессмысливание"],
    "выхолащивать": ["оскоплять", "кастрировать"],
    "выхолив": ["выхоливши"],
    "выхоливав": ["выхоливавши"],
    "выхоливавши": ["выхоливав"],
    "выхоливши": ["выхолив"],
    "выхолодив": ["выхолодивши"],
    "выхолодивши": ["выхолодив"],
    "выхолостив": ["выхолостивши"],
    "выхолостивши": ["выхолостив"],
    "выхолостить": ["оскопить", "кастрировать"],
    "выхолощенный": ["кастрированный", "оскоплённый", "холощенный", "холощёный", "бесснастный", "опустошённый", "невыразительный", "неприметный", "непримечательный", "обеднённый", "обыкновенный", "обычный", "ординарный", "простой", "рядовой"],
    "выхухолевый": ["выхухолий", "выхухольный"],
    "выхухолий": ["выхухолевый", "выхухольный"],
    "выхухоль": ["хохуля"],
    "выцапав": ["выцапавши"],
    "выцапавши": ["выцапав"],
    "выцарапав": ["выцарапавши"],
    "выцарапавши": ["выцарапав"],
    "выцарапывав": ["выцарапывавши"],
    "выцарапывавши": ["выцарапывав"],
    "выцветав": ["выцветавши"],
    "выцветавши": ["выцветав"],
    "выцветать": ["линять"],
    "выцветив": ["выцветивши"],
    "выцветивши": ["выцветив"],
    "выцветший": ["блёклый", "поблёклый", "линялый", "полинялый"],
    "выцвечивав": ["выцвечивавши"],
    "выцвечивавши": ["выцвечивав"],
    "выцедив": ["выцедивши"],
    "выцедивши": ["выцедив"],
    "выцеживав": ["выцеживавши"],
    "выцеживавши": ["выцеживав"],
    "выцелив": ["выцеливши"],
    "выцеливав": ["выцеливавши"],
    "выцеливавши": ["выцеливав"],
    "выцеливши": ["выцелив"],
    "выцепив": ["выцепивши"],
    "выцепивши": ["выцепив"],
    "выцепляв": ["выцеплявши"],
    "выцеплявши": ["выцепляв"],
    "выцыганив": ["выцыганивши"],
    "выцыганивав": ["выцыганивавши"],
    "выцыганивавши": ["выцыганивав"],
    "выцыганивши": ["выцыганив"],
    "вычалив": ["вычаливши"],
    "вычаливав": ["вычаливавши"],
    "вычаливавши": ["вычаливав"],
    "вычаливши": ["вычалив"],
    "вычегодец": ["сольвычегодец", "сольвычегодчанин", "усолец"],
    "вычеканив": ["вычеканивши"],
    "вычеканивав": ["вычеканивавши"],
    "вычеканивавши": ["вычеканивав"],
    "вычеканивши": ["вычеканив"],
    "вычеркав": ["вычеркавши"],
    "вычеркавши": ["вычеркав"],
    "вычеркнув": ["вычеркнувши"],
    "вычеркнувши": ["вычеркнув"],
    "вычеркнуть": ["зачеркнуть", "исключить", "устранить"],
    "вычернив": ["вычернивши"],
    "вычернивав": ["вычернивавши"],
    "вычернивавши": ["вычернивав"],
    "вычернивши": ["вычернив"],
    "вычерпав": ["вычерпавши"],
    "вычерпавши": ["вычерпав"],
    "вычерпнув": ["вычерпнувши"],
    "вычерпнувши": ["вычерпнув"],
    "вычерпывав": ["вычерпывавши"],
    "вычерпывавши": ["вычерпывав"],
    "вычерпывать": ["вычёрпывать"],
    "вычертив": ["вычертивши"],
    "вычертивши": ["вычертив"],
    "вычерчивав": ["вычерчивавши"],
    "вычерчивавши": ["вычерчивав"],
    "вычесав": ["вычесавши"],
    "вычесавши": ["вычесав"],
    "вычесть": ["отнять", "уменьшить"],
    "вычимеживав": ["вычимеживавши"],
    "вычимеживавши": ["вычимеживав"],
    "вычинив": ["вычинивши"],
    "вычинивав": ["вычинивавши"],
    "вычинивавши": ["вычинивав"],
    "вычинивши": ["вычинив"],
    "вычинить": ["починить"],
    "вычиниться": ["починиться"],
    "вычисление": ["вычисленье", "калькуляция", "результат", "итог", "итого"],
    "вычислив": ["вычисливши"],
    "вычисливши": ["вычислив"],
    "вычислимость": ["вычисляемость", "исчислимость"],
    "вычислитель": ["компьютерщик", "калькулятор"],
    "вычислительная сеть": ["сеть эвм", "компьютерная сеть"],
    "вычисляв": ["вычислявши"],
    "вычислявши": ["вычисляв"],
    "вычисляемость": ["вычислимость"],
    "вычислять": ["высчитывать", "оценивать", "взвешивать"],
    "вычистив": ["вычистивши"],
    "вычистивши": ["вычистив"],
    "вычистить": ["очистить", "прочистить", "начистить"],
    "вычитав": ["вычитавши"],
    "вычитавши": ["вычитав"],
    "вычитание": ["отнимание"],
    "вычитанье": ["вычитание"],
    "вычитать": ["прочитать", "выверить", "сверить"],
    "вычитка": ["корректирование", "корректировка"],
    "вычитывав": ["вычитывавши"],
    "вычитывавши": ["вычитывав"],
    "вычихав": ["вычихавши"],
    "вычихавши": ["вычихав"],
    "вычихивав": ["вычихивавши"],
    "вычихивавши": ["вычихивав"],
    "вычихнув": ["вычихнувши"],
    "вычихнувши": ["вычихнув"],
    "вычищав": ["вычищавши"],
    "вычищавши": ["вычищав"],
    "вычищать": ["чистить"],
    "вычленив": ["вычленивши"],
    "вычленивши": ["вычленив"],
    "вычленяв": ["вычленявши"],
    "вычленявши": ["вычленяв"],
    "вычура": ["завитушка", "витиеватость"],
    "вычурно": ["витиевато", "замысловато", "напыщенно", "претенциозно"],
    "вычурность": ["затейливость", "витиеватость", "сложность"],
    "вычурный": ["витиеватый", "замысловатый", "напыщенный", "претенциозный"],
    "вычёркивав": ["вычёркивавши"],
    "вычёркивавши": ["вычёркивав"],
    "вычёркивать": ["зачёркивать", "исключать", "устранять"],
    "вычёсывав": ["вычёсывавши"],
    "вычёсывавши": ["вычёсывав"],
    "вычёсывание": ["выческа"],
    "вышагав": ["вышагавши"],
    "вышагавши": ["вышагав"],
    "вышагивав": ["вышагивавши"],
    "вышагивавши": ["вышагивав"],
    "вышагнув": ["вышагнувши"],
    "вышагнувши": ["вышагнув"],
    "вышарив": ["вышаривши"],
    "вышаривав": ["вышаривавши"],
    "вышаривавши": ["вышаривав"],
    "вышаривши": ["вышарив"],
    "вышарить": ["выбаллотировать"],
    "вышаркав": ["вышаркавши"],
    "вышаркавши": ["вышаркав"],
    "вышаркивав": ["вышаркивавши"],
    "вышаркивавши": ["вышаркивав"],
    "вышатав": ["вышатавши"],
    "вышатавши": ["вышатав"],
    "вышатывав": ["вышатывавши"],
    "вышатывавши": ["вышатывав"],
    "вышвыривав": ["вышвыривавши"],
    "вышвыривавши": ["вышвыривав"],
    "вышвырнув": ["вышвырнувши"],
    "вышвырнувши": ["вышвырнув"],
    "вышвыряв": ["вышвырявши"],
    "вышвырявши": ["вышвыряв"],
    "выше": ["ранее"],
    "выше всяких похвал": ["лучший", "замечательный", "идеальный"],
    "выше крыши": ["по горло", "сверх меры"],
    "вышед": ["выйдя", "вышедши"],
    "вышелушив": ["вышелушивши"],
    "вышелушивав": ["вышелушивавши"],
    "вышелушивавши": ["вышелушивав"],
    "вышелушивши": ["вышелушив"],
    "вышеназванный": ["вышеупомянутый"],
    "вышеописанный": ["вышеназванный", "вышеуказанный", "вышеупомянутый"],
    "вышеперечисленный": ["вышеобозначенный"],
    "вышепомянутый": ["вышеназванный", "вышеозначенный", "вышеотмеченный", "вышеупомянутый"],
    "вышеприведённый": ["вышесказанный", "вышеупомянутый"],
    "вышептав": ["вышептавши"],
    "вышептавши": ["вышептав"],
    "вышесказанный": ["вышеупомянутый", "вышеприведённый"],
    "вышеуказанный": ["вышеназванный", "вышеозначенный", "вышеотмеченный", "вышеперечисленный", "вышеприведённый", "вышепомянутый", "вышесказанный", "вышеупомянутый", "названный", "означенный", "оный", "сказанный", "упомянутый", "помянутый"],
    "вышеупомянутый": ["вышесказанный", "вышеприведённый"],
    "вышибав": ["вышибавши"],
    "вышибавши": ["вышибав"],
    "вышибив": ["вышибивши"],
    "вышибивши": ["вышибив"],
    "вышив": ["вышивши"],
    "вышивав": ["вышивавши"],
    "вышивавши": ["вышивав"],
    "вышивание": ["вышивка"],
    "вышивка": ["вышивание"],
    "вышивши": ["вышив"],
    "вышина": ["высота", "высь"],
    "вышка": ["высшая мера наказания", "вуз", "высшая математика", "мезонин", "мансарда", "горенка", "терем", "теремок", "рубка", "чердачок"],
    "вышколенность": ["выдрессированность", "вымуштрованность", "натасканность", "дисциплинированность", "обученность", "подкованность"],
    "вышколенный": ["вымуштрованный"],
    "вышколив": ["вышколивши"],
    "вышколивши": ["вышколив"],
    "вышколить": ["обучить", "воспитать", "выдрессировать"],
    "вышлифовав": ["вышлифовавши"],
    "вышлифовавши": ["вышлифовав"],
    "вышлифовывав": ["вышлифовывавши"],
    "вышлифовывавши": ["вышлифовывав"],
    "вышмыгивав": ["вышмыгивавши"],
    "вышмыгивавши": ["вышмыгивав"],
    "вышмыгнув": ["вышмыгнувши"],
    "вышмыгнувши": ["вышмыгнув"],
    "вышневолочанин": ["волочанин"],
    "вышний": ["горний", "небесный"],
    "вышныривав": ["вышныривавши"],
    "вышныривавши": ["вышныривав"],
    "вышнырнув": ["вышнырнувши"],
    "вышнырнувши": ["вышнырнув"],
    "вышныряв": ["вышнырявши"],
    "вышнырявши": ["вышныряв"],
    "вышпарив": ["вышпаривши"],
    "вышпаривав": ["вышпаривавши"],
    "вышпаривавши": ["вышпаривав"],
    "вышпаривши": ["вышпарив"],
    "выштамповав": ["выштамповавши"],
    "выштамповавши": ["выштамповав"],
    "выштамповка": ["выштамповывание", "штамповка"],
    "выштамповывав": ["выштамповывавши"],
    "выштамповывавши": ["выштамповывав"],
    "выштамповывание": ["выштамповка"],
    "выштукатурив": ["выштукатуривши"],
    "выштукатуривав": ["выштукатуривавши"],
    "выштукатуривавши": ["выштукатуривав"],
    "выштукатуривши": ["выштукатурив"],
    "вышутив": ["вышутивши"],
    "вышутивши": ["вышутив"],
    "вышучивав": ["вышучивавши"],
    "вышучивавши": ["вышучивав"],
    "вышучивать": ["высмеивать"],
    "вышёптывав": ["вышёптывавши"],
    "вышёптывавши": ["вышёптывав"],
    "выщелачивав": ["выщелачивавши"],
    "выщелачивавши": ["выщелачивав"],
    "выщелкав": ["выщелкавши"],
    "выщелкавши": ["выщелкав"],
    "выщелкнув": ["выщелкнувши"],
    "выщелкнувши": ["выщелкнув"],
    "выщелочив": ["выщелочивши"],
    "выщелочивши": ["выщелочив"],
    "выщепив": ["выщепивши"],
    "выщепивши": ["выщепив"],
    "выщепляв": ["выщеплявши"],
    "выщеплявши": ["выщепляв"],
    "выщербив": ["выщербивши"],
    "выщербивши": ["выщербив"],
    "выщербина": ["щербина", "повреждение", "отверстие", "скол", "выбоина", "яма"],
    "выщербляв": ["выщерблявши"],
    "выщерблявши": ["выщербляв"],
    "выщерблять": ["щербить"],
    "выщипав": ["выщипавши"],
    "выщипавши": ["выщипав"],
    "выщипнув": ["выщипнувши"],
    "выщипнувши": ["выщипнув"],
    "выщипывав": ["выщипывавши"],
    "выщипывавши": ["выщипывав"],
    "выщупав": ["выщупавши"],
    "выщупавши": ["выщупав"],
    "выщупывав": ["выщупывавши"],
    "выщупывавши": ["выщупывав"],
    "выщёлкивав": ["выщёлкивавши"],
    "выщёлкивавши": ["выщёлкивав"],
    "выюркнув": ["выюркнувши"],
    "выюркнувши": ["выюркнув"],
    "выя": ["шея"],
    "выявив": ["выявивши"],
    "выявивши": ["выявив"],
    "выявитель": ["детектор"],
    "выявиться": ["обнаружиться", "открыться"],
    "выявление": ["обнаружение"],
    "выявляв": ["выявлявши"],
    "выявлявши": ["выявляв"],
    "выявлять": ["обнаруживать", "проявлять", "разоблачать"],
    "выявляться": ["обнаруживаться", "проявляться"],
    "выяснев": ["выясневши"],
    "выясневши": ["выяснев"],
    "выяснение": ["прояснение"],
    "выяснив": ["выяснивши"],
    "выяснивав": ["выяснивавши"],
    "выяснивавши": ["выяснивав"],
    "выяснивши": ["выяснив"],
    "выяснить": ["установить", "узнать"],
    "выясниться": ["обнаружиться", "определиться", "проясниться", "развиднеться"],
    "выясняв": ["выяснявши"],
    "выяснявши": ["выясняв"],
    "выёбывав": ["выёбывавши"],
    "выёбывавши": ["выёбывав"],
    "выёбываться": ["выпендриваться", "выделываться", "выкобениваться", "выёживаться"],
    "выёживаться": ["выделываться", "выпендриваться", "выкаблучиваться"],
    "вьетнам": ["социалистическая республика вьетнам", "срв"],
    "вьетнамо-китайский": ["китайско-вьетнамский"],
    "вьетнамско-российский": ["российско-вьетнамский"],
    "вьюга": ["буран", "метель"],
    "вьюжив": ["вьюживши"],
    "вьюживши": ["вьюжив"],
    "вьюжистый": ["вьюжливый"],
    "вьюжить": ["пуржить", "мести", "метелить"],
    "вьюжливый": ["вьюжистый"],
    "вьюн": ["вьюнок"],
    "вьюнив": ["вьюнивши"],
    "вьюнивши": ["вьюнив"],
    "вьюрок": ["юрок"],
    "вьючив": ["вьючивши"],
    "вьючивши": ["вьючив"],
    "вьючка": ["навьючивание"],
    "вьюшка": ["заслонка"],
    "вэбанув": ["вэбанувши"],
    "вэбанувши": ["вэбанув"],
    "вэза": ["вежа"],
    "вэйвлет": ["вейвлет"],
    "вэйвлетный": ["вейвлетный"],
    "вэйпинг": ["вейпинг"],
    "вэнселлинг": ["ванселлинг"],
    "вэшка": ["вэшник", "вэшница"],
    "вяз": ["ильм"],
    "вязав": ["вязавши"],
    "вязавши": ["вязав"],
    "вязание": ["вязка"],
    "вязанка": ["связка"],
    "вязанье": ["вязание", "вязка", "изделие", "вещь", "трикотаж"],
    "вязать": ["завязывать", "плести", "сплетать"],
    "вязель": ["заячий клевер"],
    "вяземец": ["вязьмич", "вязьмитин", "вязьмитинин"],
    "вязига": ["визига"],
    "вязка": ["вязание", "отступное", "случка"],
    "вязкий": ["тягучий", "засасывающий", "топкий"],
    "вязкоупругий": ["вязкоэластичный"],
    "вязкоэластичный": ["вязкоупругий"],
    "вязниковец": ["везниковец"],
    "вязнув": ["вязнувши"],
    "вязнувши": ["вязнув"],
    "вязнуть": ["погружаться", "увязать"],
    "вязывав": ["вязывавши"],
    "вязывавши": ["вязывав"],
    "вязьмитин": ["вяземец", "вязьмич", "вязьмичанин", "вязьмитинин"],
    "вязьмитинин": ["вяземец", "вязьмитин", "вязьмич"],
    "вязьмич": ["вяземец", "вязьмитин", "вязьмитинин"],
    "вязьмичанин": ["вяземец", "вязьмич", "вязьмитин", "вязьмитинин"],
    "вякав": ["вякавши"],
    "вякавши": ["вякав"],
    "вякать": ["тявкать", "потявкивать", "мяукать", "мяучить", "блеять", "возражать", "роптать", "жаловаться", "трындеть", "раскрывать рот", "разевать рот"],
    "вякнув": ["вякнувши"],
    "вякнувши": ["вякнув"],
    "вякнуть": ["брякнуть"],
    "вяленый": ["провяленный"],
    "вялив": ["вяливши"],
    "вяливши": ["вялив"],
    "вялотекущий": ["малопрогредиентный", "затянувшийся"],
    "вялый": ["увядший", "безжизненный", "апатичный", "потухший"],
    "вянув": ["вянувши"],
    "вянувши": ["вянув"],
    "вянуть": ["увядать", "сохнуть"],
    "вяньгав": ["вяньгавши"],
    "вяньгавши": ["вяньгав"],
    "вятич": ["вятчанин", "вятичанин", "кировчанин", "кировец", "хлыновец"],
    "вятичанин": ["вятич", "вятчанин", "кировец", "кировчанин", "хлыновец"],
    "вятичанка": ["вятчанка", "кировчанка"],
    "вятские поляны": ["вп"],
    "вятский": ["кировский"],
    "вятчанин": ["вятич", "вятичанин", "кировчанин", "кировец", "хлыновец"],
    "вятърничавост": ["непостоянство", "лекомислие"],
    "вяхирь": ["витютень"],
    "вячеслав": ["вячеславка", "слава"],
    "вячеславович": ["вячеславыч"],
    "вящий": ["пущий"],
    "вящший": ["выспренний"],
    "вёдро": ["краснопогодье"],
    "вёрджинал": ["вёрджинел"],
    "вёрджинел": ["вирджинал", "вёрджинал"],
    "вёрджинелист": ["вирджиналист"],
    "вёрткий": ["вертлявый", "изворотливый", "ловкий", "подвижный", "проворный"],
    "вёх": ["вех", "вяха", "цикута", "болиголов"],
    "га": ["го"],
    "гаага": ["мус"],
    "габала": ["куткашен"],
    "габалинский район": ["куткашенский район"],
    "габардин": ["ратин"],
    "габарит": ["абрис", "размеры", "измерения"],
    "габба": ["габбер"],
    "габбер": ["габба"],
    "габбро-долерит": ["габбро-диабаз"],
    "габбро-норит": ["габбронорит"],
    "габбродолерит": ["габбро-долерит"],
    "габза": ["рабчжун"],
    "габитоскопия": ["габитология"],
    "габитус": ["хабитус", "внешность", "облик"],
    "габичка": ["габа"],
    "габонка": ["габонская гадюка", "кассава"],
    "габриель": ["габриэль"],
    "габриэлла": ["габи", "габриэллочка", "элла"],
    "габриэль": ["габриель"],
    "гав": ["тяф", "вау", "ав"],
    "гавазин": ["телохранител", "пазител", "страж", "пазач", "охранител"],
    "гавайи": ["гавайские острова", "гаваи"],
    "гавар": ["камо"],
    "гавкав": ["гавкавши"],
    "гавкавши": ["гавкав"],
    "гавкание": ["лай", "лаяние", "лаянье", "гавканье", "брехание"],
    "гавканье": ["лай", "лаяние", "гавкание", "лаянье", "брехание"],
    "гавкать": ["лаять"],
    "гавкнув": ["гавкнувши"],
    "гавкнувши": ["гавкнув"],
    "гавкнуть пиздой": ["накрыться пиздой", "гавкнуться пиздой", "пиздой накрыться", "пиздой гавкнуть", "пиздой гавкнуться"],
    "гавриил": ["гаврила", "гаврил", "гаврило", "гейбриел", "габриель", "габриэль", "габриеле", "габриэле", "габор"],
    "гавриила": ["габриела", "габриелла", "габриэла", "габриэлла"],
    "гаврик": ["гаврюша"],
    "гаврила": ["гавриил"],
    "гага": ["утка"],
    "гагакав": ["гагакавши"],
    "гагакавши": ["гагакав"],
    "гагакнув": ["гагакнувши"],
    "гагакнувши": ["гагакнув"],
    "гагановец": ["стахановец"],
    "гагат": ["чёрная яшма", "гишер"],
    "гагаузия": ["ато гагаузия", "гагауз ери", "республика гагаузия"],
    "гагьо": ["гогьари", "мугеру", "гампар"],
    "гад": ["рептилия", "пресмыкающееся", "амфибия", "сволочь", "подлец", "ашнак", "висельник", "гаденыш", "гадина", "гадюка", "гнида", "гумза", "дрянцо", "дрянь", "зараза"],
    "гада": ["гад"],
    "гадав": ["гадавши"],
    "гадавши": ["гадав"],
    "гадалка": ["прорицательница"],
    "гадальщик": ["гадатель"],
    "гадальщица": ["гадалка"],
    "гадание": ["гаданье"],
    "гаданье": ["гадание"],
    "гадатель": ["гадальщик"],
    "гадательница": ["гадалка", "гадальщица"],
    "гадательность": ["предположительность", "сомнительность", "недостоверность", "проблематичность", "гипотетичность"],
    "гадательный": ["предположительный", "гипотетичный", "гипотетический"],
    "гадать": ["прорицать", "пророчествовать"],
    "гадать на кофейной гуще": ["гадать на бобах"],
    "гадей": ["катархей"],
    "гадес": ["аид", "плутон", "дит", "орк", "дионис", "кадис", "гадир", "гадер", "гадира", "гадейра"],
    "гаджет": ["прибамбас"],
    "гаджиево": ["скалистый", "ягельная губа"],
    "гаджё": ["ракло", "мурш"],
    "гадив": ["гадивши"],
    "гадивши": ["гадив"],
    "гадина": ["гад", "рептилия"],
    "гадить": ["испражняться", "срать", "какать", "марать", "пачкать", "мусорить", "пакостить", "вредить"],
    "гадка": ["думка"],
    "гадкий": ["мерзкий", "омерзительный", "дрянной", "грязный", "гнусный", "отвратный", "ужасный", "отвратительный"],
    "гадко": ["противно", "тошно", "отвратительно"],
    "гадкость": ["вредность", "злонравие"],
    "гадолинит": ["итербит"],
    "гадост": ["гадност", "низост", "подлост", "мръсотия"],
    "гадостный": ["гадкий", "мерзкий", "мерзостный", "пакостный"],
    "гадость": ["гадня"],
    "гадство": ["гадость", "дрянь", "мерзость", "гнусность", "скотство", "свинство"],
    "гадствовав": ["гадствовавши"],
    "гадствовавши": ["гадствовав"],
    "гадюка": ["гадина", "сволочь", "падла", "подлюка"],
    "гадюка подколодная": ["змея подколодная"],
    "гадюка рыжая": ["гадюка"],
    "гадюковый": ["виперовый"],
    "гадючка": ["гадина", "тварь"],
    "гадюшник": ["змеюшник", "гадючник", "серпентарий"],
    "гадёныш": ["шебестовщик"],
    "гаевица": ["хорватская латиница"],
    "гаер": ["шут", "паяц", "фигляр", "буффон"],
    "гаерничав": ["гаерничавши"],
    "гаерничавши": ["гаерничав"],
    "гаерничать": ["гаерствовать"],
    "гаерски": ["по-гаерски"],
    "гаерство": ["шутовство", "кривляние", "паясничание", "кривлянье", "паясничанье"],
    "гаерствовав": ["гаерствовавши"],
    "гаерствовавши": ["гаерствовав"],
    "гаец": ["гаишник"],
    "гаечка": ["гайка"],
    "гажа": ["ганч"],
    "гаживав": ["гаживавши"],
    "гаживавши": ["гаживав"],
    "газ": ["горьковский автомобильный завод"],
    "газа": ["сектор газа"],
    "газават": ["джихад"],
    "газаль": ["газель", "газелла", "газела"],
    "газанув": ["газанувши"],
    "газанувши": ["газанув"],
    "газация": ["газирование"],
    "газваген": ["газенваген", "душегубка"],
    "газгольдер": ["газохранилище", "газосборник"],
    "газела": ["газель", "газелла", "газаль"],
    "газелист": ["газельщик", "маршруточник", "маршрутчик"],
    "газелла": ["газель", "газела", "газаль"],
    "газенваген": ["газваген", "душегубка"],
    "газетчик": ["журналист"],
    "газетчица": ["журналистка"],
    "газетёнка": ["газетка"],
    "газив": ["газивши"],
    "газивши": ["газив"],
    "газик": ["козлик"],
    "газировав": ["газировавши"],
    "газировавши": ["газировав"],
    "газированная вода": ["газвода", "газировка", "шипучка", "шипучая вода"],
    "газировка": ["газирование", "газированная вода"],
    "газифицировав": ["газифицировавши"],
    "газифицировавши": ["газифицировав"],
    "газобетон": ["пенобетон"],
    "газовав": ["газовавши"],
    "газовавши": ["газовав"],
    "газовидный": ["газообразный", "газоподобный"],
    "газово-пылевой": ["газопылевой"],
    "газовый баллончик": ["перцовка", "перцовый баллончик"],
    "газозварник": ["газозварювач"],
    "газозварниця": ["газозварювачка"],
    "газойлевый": ["газойльный"],
    "газойльный": ["газойлевый"],
    "газолечение": ["газотерапия"],
    "газонепроницаемость": ["герметичность"],
    "газонефтенакопление": ["нефтегазонакопление"],
    "газонокосильщик": ["косильщик", "косарь"],
    "газообразный": ["газоподобный", "воздухообразный", "газовидный"],
    "газоочистительный": ["газоочистный"],
    "газопенобетон": ["пеногазобетон"],
    "газоподобный": ["газообразный", "газовидный"],
    "газопромыватель": ["скруббер"],
    "газопылевой": ["газово-пылевой", "пылегазовый"],
    "газоразрядный": ["газосветный"],
    "газораспределительный механизм": ["грм"],
    "газорезка": ["газокислородная резка"],
    "газосварка": ["газовая сварка", "газоплавильная сварка"],
    "газосварщик": ["сварщик"],
    "газосчётчик": ["газомер"],
    "газотурбина": ["газовая турбина"],
    "газотурбовоз": ["турботепловоз"],
    "газохол": ["бензоспирт"],
    "газы": ["метеоризм", "вздутие живота"],
    "газява": ["газявка"],
    "газявка": ["газява"],
    "гаи": ["гибдд", "госавтоинспекция", "государственная автомобильная инспекция"],
    "гаити": ["эспаньола", "республика гаити"],
    "гаишник": ["гаец", "гаер", "гиббон"],
    "гай": ["лесок"],
    "гайворон": ["грак"],
    "гайда": ["айда"],
    "гайдамачив": ["гайдамачивши"],
    "гайдамачивши": ["гайдамачив"],
    "гайдарик": ["гайдарёнок", "гайдарист", "гайдаровец"],
    "гайдарист": ["гайдарёнок", "гайдарик", "гайдаровец"],
    "гайдаровец": ["гайдарёнок", "гайдарик", "гайдарист"],
    "гайдаровщина": ["гайдарономика"],
    "гайдарономика": ["гайдаровщина"],
    "гайдарёнок": ["гайдарик", "гайдарист", "гайдаровец"],
    "гайдук": ["гайдамак"],
    "гайдуцкий": ["гайдучий"],
    "гайдучий": ["гайдуцкий"],
    "гайдучиха": ["гайдучка"],
    "гайдучишка": ["гайдучок", "гайдучёнок", "гайдучёночек"],
    "гайдучка": ["гайдучиха"],
    "гайдучок": ["гайдучёнок", "гайдучишка", "гайдучёночек"],
    "гайдучёночек": ["гайдучок", "гайдучишка", "гайдучёнок"],
    "гайкав": ["гайкавши"],
    "гайкавши": ["гайкав"],
    "гайкнув": ["гайкнувши"],
    "гайкнувши": ["гайкнув"],
    "гайморит": ["максиллит"],
    "гайно": ["гнездо", "дупло", "логово", "логовище", "берлога", "нора", "хаос", "бардак", "ералаш", "беспорядок"],
    "гайтан": ["шнурок", "тесьма", "тесёмка", "лента"],
    "гак": ["добавка"],
    "гакав": ["гакавши"],
    "гакавши": ["гакав"],
    "гакнув": ["гакнувши"],
    "гакнувши": ["гакнув"],
    "гаковница": ["пищаль"],
    "гал": ["гали"],
    "гала": ["гбало", "гибало"],
    "гала-представление": ["гала-шоу"],
    "галабея": ["галабия"],
    "галабия": ["галабея"],
    "галактикос": ["королевский клуб"],
    "галактометр": ["лактометр"],
    "галантерейный": ["галантный", "учтивый"],
    "галантир": ["галантин"],
    "галантно": ["вежливо", "учтиво", "любезно"],
    "галантность": ["любезность", "учтивость"],
    "галантный": ["любезный", "обходительный"],
    "галапагосские острова": ["галапагос"],
    "галатея": ["гала"],
    "галаха": ["алаха"],
    "галахай": ["крапива"],
    "галгал": ["халха"],
    "галда": ["галдёж", "галдение", "галденье"],
    "галдарейка": ["галерея"],
    "галдарея": ["галерея"],
    "галдев": ["галдевши"],
    "галдевши": ["галдев"],
    "галдение": ["галдёж"],
    "галденье": ["галдение"],
    "галдеть": ["гомонить"],
    "галдикати": ["галакати"],
    "галдёж": ["галдение"],
    "галега": ["козлятник"],
    "галеник": ["любимец"],
    "галерейщик": ["галерист"],
    "галерейщица": ["галеристка"],
    "галерист": ["галерейщик"],
    "галеристка": ["галерейщица"],
    "галета": ["крекер"],
    "гали": ["пятнашки", "догонялки", "салочки", "салки", "сифа"],
    "галив": ["галивши"],
    "галивши": ["галив"],
    "галима": ["алима"],
    "галимация": ["брътвеж", "безсмислица"],
    "галимый": ["голый", "чистый", "голимый", "сплошной", "плохой", "омерзительный", "дрянной", "некачественный", "лажовый", "отвратительный", "гадкий", "мерзкий", "паршивый", "никудышный", "фиговый"],
    "галина": ["галя", "галчонок"],
    "галипот": ["баррас"],
    "галис": ["марасантия", "чицзян", "брабант"],
    "галит": ["каменная соль", "поваренная соль"],
    "галиться": ["изгаляться"],
    "галифе": ["брюки-галифе", "брюки галифе", "брюки с напуском", "брюки с галифеем", "гальхве", "бананы"],
    "галиция": ["галичина"],
    "галичина": ["галиция"],
    "галка": ["галина", "галя", "галиночка", "галечка", "галчонок", "галюсик"],
    "галл": ["мирмиллон", "мурмиллон"],
    "галла": ["гичи", "гулла", "оромо", "галлу"],
    "галликанизм": ["галликанство"],
    "галликанство": ["галликанизм"],
    "галлия": ["франция"],
    "галломан": ["франкофил"],
    "галломания": ["франкофилия"],
    "галломанка": ["франкофилка"],
    "галломанский": ["франкофильский"],
    "галлофильский": ["галломанский", "франкофильский"],
    "галлофоб": ["франкофоб"],
    "галлофобский": ["франкофобский"],
    "галлюцинаторный": ["психопатологический", "аффективный", "психомоторный", "шизофренический", "психогенный"],
    "галлюцинаторный фонографизм": ["слуховая галлюцинация"],
    "галлюцинация": ["галюн", "фантом", "видение"],
    "галлюцинировав": ["галлюцинировавши"],
    "галлюцинировавши": ["галлюцинировав"],
    "гало": ["галос", "галактическое гало"],
    "галоген": ["галоид"],
    "галогеналкан": ["алкилгалогенид", "галогеноалкан"],
    "галогенид": ["галоид"],
    "галогенизация": ["галогенизирование", "галогенирование"],
    "галогенирование": ["галоидирование"],
    "галогеноид": ["псевдогалоген"],
    "галогеносодержащий": ["галогенсодержащий"],
    "галогеноспирт": ["галогенгидрин"],
    "галогенсодержащий": ["галогеносодержащий"],
    "галоид": ["галоген"],
    "галоидирование": ["галогенирование"],
    "галоидный": ["галогеновый", "галогенный"],
    "галокамера": ["галокомплекс"],
    "галокомплекс": ["галокамера"],
    "галоп": ["намёт"],
    "галопировав": ["галопировавши"],
    "галопировавши": ["галопировав"],
    "галопом по европам": ["бегло", "поверхностно", "неглубоко", "наскоро", "по диагонали", "через строчку"],
    "галос": ["гало"],
    "галочий": ["галчачий", "галчиный"],
    "галочка": ["галка", "птичка"],
    "галоша": ["калоша"],
    "галошница": ["обувница"],
    "галстук": ["галстух", "селёдка", "шейный платок"],
    "галтель": ["молдинг", "плинтус", "галтельник"],
    "галтование": ["галтовка"],
    "галтовка": ["галтование"],
    "галун": ["позумент"],
    "галфон": ["глупак", "тъпак", "простак"],
    "гальванизация": ["электрофорез"],
    "гальванизировав": ["гальванизировавши"],
    "гальванизировавши": ["гальванизировав"],
    "гальванизовав": ["гальванизовавши"],
    "гальванизовавши": ["гальванизовав"],
    "гальваника": ["гальванотехника"],
    "гальванокаустика": ["гальванотермия", "термокаустика", "электрокаустика"],
    "гальванопара": ["гальваническая пара"],
    "гальванопокрытие": ["гальваностегия"],
    "гальванотаксис": ["электротаксис"],
    "гальванотермия": ["гальванокаустика", "термокаустика", "электрокаустика"],
    "галька": ["галечник"],
    "гальот": ["галиот"],
    "галюн": ["галюник", "глюк"],
    "галюник": ["галюн", "глюк"],
    "галя": ["гали", "пятнашки", "догонялки", "салочки", "салки", "сифа"],
    "галявина": ["галява"],
    "гам": ["гомон"],
    "гама": ["гейма"],
    "гамав": ["гамавши"],
    "гамавши": ["гамав"],
    "гамада": ["хамада"],
    "гамадрил": ["плащеносный павиан"],
    "гамазей": ["гамазея"],
    "гаман": ["хамьян", "бумажник", "кошелёк", "кисет", "трутница", "трутоноша"],
    "гаманок": ["гаманец", "кошелёк"],
    "гамать": ["геймить"],
    "гамаша": ["штиблета"],
    "гамбургер": ["бургер", "бутерброд"],
    "гамбургерный": ["бургерный"],
    "гамен": ["уличник", "негодяй", "нехранимайко", "безделник", "хулиган"],
    "гамив": ["гамивши"],
    "гамивши": ["гамив"],
    "гамильтон": ["хамилтон", "хамильтон", "хэмилтон"],
    "гамильтониан": ["функция гамильтона", "оператор гамильтона"],
    "гамильтонов": ["гамильтоновский"],
    "гамкав": ["гамкавши"],
    "гамкавши": ["гамкав"],
    "гамкнув": ["гамкнувши"],
    "гамкнувши": ["гамкнув"],
    "гамма": ["спектр", "ассортимент"],
    "гамма-аминомасляная кислота": ["гамк"],
    "гамма-аппарат": ["гамма-облучатель", "гамма-установка", "телегамма-аппарат"],
    "гамма-вариант": ["гамма-штамм"],
    "гамма-излучение": ["гамма-луч"],
    "гамма-лазер": ["газер"],
    "гамма-фотон": ["гамма-квант"],
    "гамма-штамм": ["гамма-вариант"],
    "гаммаграмма": ["сцинтиграмма"],
    "гамовер": ["геймовер"],
    "гамонт": ["гаметоцит"],
    "гампар": ["гагьо", "мугеру", "гогьари"],
    "гамузом": ["гуртом", "огулом"],
    "гана": ["республика гана"],
    "ганглий": ["нервный узел"],
    "ганглионарный": ["ганглиозный"],
    "гангрена": ["антонов огонь", "язва", "порок"],
    "гангстер": ["бандит", "головорез"],
    "гангстерский": ["бандитский"],
    "гандбол": ["ручной мяч"],
    "ганджубас": ["марихуана"],
    "гандизм": ["гандианство"],
    "гандист": ["гандианец"],
    "гандон": ["гондон", "кондом", "презерватив", "презик", "презер", "резинка"],
    "гандшпуг": ["аншпуг", "андшпуг"],
    "ганедень": ["ган"],
    "ганивав": ["ганивавши"],
    "ганивавши": ["ганивав"],
    "ганоин": ["ганойн"],
    "ганс": ["ханс"],
    "гантировать": ["гантироваться"],
    "ганцевичи": ["ганы", "ганцы", "ганцули"],
    "ганч": ["глиногипс", "гажа"],
    "ганьбити": ["позорити", "принижувати"],
    "гаолян": ["маньчжурское сорго", "маньчжурское просо", "китайское просо", "сорго"],
    "гаочэ": ["динлин", "телэ"],
    "гапакс": ["гапакс легоменон", "окказионализм"],
    "гапакс легоменон": ["гапакс"],
    "гаплик": ["крючок"],
    "гаптофобия": ["афефобия", "гафефобия", "гафофобия", "гапнофобия", "гаптефобия", "тиксофобия"],
    "гаптувати": ["вишивати"],
    "гапы": ["кириш"],
    "гарав": ["надаб"],
    "гараж-ракушка": ["ракушка"],
    "гаражестроительный": ["гаражно-строительный"],
    "гарант": ["гарантия", "гарант николаевич"],
    "гарант конституции": ["гарант"],
    "гарантировав": ["гарантировавши"],
    "гарантировавши": ["гарантировав"],
    "гарантировать": ["ручаться", "поручиться", "оградить", "ограждать", "защитить", "защищать"],
    "гарвей": ["харви"],
    "гарга": ["чавка", "врана"],
    "гаргулья": ["горгулья"],
    "гарда": ["гард", "решётка", "огниво"],
    "гардеман": ["самогон", "самогонка", "сивуха"],
    "гардероб": ["туалет"],
    "гардеробная": ["гардероб"],
    "гардина": ["занавеска", "штора", "карниз"],
    "гарем": ["сераль", "харем"],
    "гариб": ["гъариб"],
    "гариг": ["гараг"],
    "гарик": ["горизонт"],
    "гаркав": ["гаркавши"],
    "гаркавши": ["гаркав"],
    "гаркать": ["рявкать", "орать"],
    "гаркнув": ["гаркнувши"],
    "гаркнувши": ["гаркнув"],
    "гаркнуть": ["рявкнуть"],
    "гарм": ["тафсон"],
    "гармала": ["могильник", "адраспан"],
    "гарматан": ["сирокко"],
    "гармин": ["банистерин"],
    "гармоба": ["хаммом"],
    "гармонизировав": ["гармонизировавши"],
    "гармонизировавши": ["гармонизировав"],
    "гармонизировать": ["гармонизовать", "привести в гармонию"],
    "гармонизовав": ["гармонизовавши"],
    "гармонизовавши": ["гармонизовав"],
    "гармонизовать": ["гармонизировать"],
    "гармоника": ["гармонь", "гармошка", "обертон", "гармония", "музыка"],
    "гармонировав": ["гармонировавши"],
    "гармонировавши": ["гармонировав"],
    "гармонист": ["тальянщик", "гармониш", "гармонщик", "игрок", "игрочок", "игруля"],
    "гармонистка": ["баянистка", "аккордеонистка"],
    "гармонический": ["гармоничный"],
    "гармоничность": ["гармония", "стройность"],
    "гармония": ["согласованность", "соразмерность", "стройность", "благозвучие"],
    "гармонщик": ["гармонист", "тальянщик", "гармониш"],
    "гармонь": ["гармоника", "гармошка"],
    "гармошка": ["гармонь", "гармоника", "сочленённый автобус"],
    "гарнесенький": ["гарненький"],
    "гарниерит": ["никелевая зелень"],
    "гарний": ["вродливий", "красивий", "прекрасний", "божественний", "чудовий"],
    "гарнировав": ["гарнировавши"],
    "гарнировавши": ["гарнировав"],
    "гарнировать": ["украшать", "украсить", "отделывать", "отделать", "снаряжать", "снарядить"],
    "гарнисаж": ["настыль"],
    "гарнитур": ["набор", "прибор", "гарнитура", "комплект"],
    "гарнитура": ["шрифт", "фонт", "гарнитур", "набор", "комплект", "прибор"],
    "гарнц": ["гарнец"],
    "гарпастон": ["гарпастум"],
    "гарпастум": ["гарпастон"],
    "гарпунив": ["гарпунивши"],
    "гарпунивши": ["гарпунив"],
    "гарпунщик": ["гарпунёр"],
    "гарпунёр": ["гарпунщик"],
    "гарринча": ["гарринша", "радость народа", "кривоногий ангел", "чарли чаплин футбола", "гауличо", "великий хромой"],
    "гарсиа": ["гарсия"],
    "гарсия": ["гарсиа"],
    "гарсон": ["официант", "посыльный"],
    "гартунг": ["хартунг"],
    "гарцевав": ["гарцевавши"],
    "гарцевавши": ["гарцевав"],
    "гарцевать": ["вольтижировать", "ментуситься", "фланировать", "красоваться"],
    "гарь": ["шлак", "сажа", "копоть", "нагар"],
    "гасив": ["гасивши"],
    "гасивши": ["гасив"],
    "гасило": ["кистень"],
    "гаситься": ["гаснуть", "прятаться", "скрываться", "мотать"],
    "гасконада": ["хвастовство", "бахвальство", "фанфаронство"],
    "гасник": ["гашник", "буковица", "буквица"],
    "гаснув": ["гаснувши"],
    "гаснувши": ["гаснув"],
    "гаснуть": ["угасать", "терять силу", "ослабевать", "сходить на нет"],
    "гастарбайтер": ["заробитчанин", "гостевой рабочий", "трудовой мигрант"],
    "гастеромицет": ["гастромицет", "нутревик"],
    "гастробар": ["гастропаб"],
    "гастрокритик": ["ресторанный", "критик"],
    "гастролатр": ["чревоугодник", "гурман"],
    "гастролатрия": ["чревоугодие", "чревоугодничество", "гастромания", "гурманство"],
    "гастролировав": ["гастролировавши"],
    "гастролировавши": ["гастролировав"],
    "гастролёрка": ["гастролёрша"],
    "гастролёрша": ["гастролёрка"],
    "гастроном": ["гурман", "аристолог"],
    "гастрономия": ["продукты", "отдел", "кулинария"],
    "гастропод": ["брюхоногий"],
    "гастропор": ["бластопор"],
    "гастросканирование": ["вентрикулосканирование", "гастросканография"],
    "гастроскопия": ["эзофагогастродуоденоскопия"],
    "гастротомия": ["гастростомия"],
    "гастротрих": ["брюхоресничные черви"],
    "гастроёмкость": ["мармит"],
    "гатив": ["гативши"],
    "гативши": ["гатив"],
    "гатор": ["хатор"],
    "гаттерия": ["туатара"],
    "гауграф": ["граф"],
    "гауляйтер": ["рейхскомиссар"],
    "гауптвахта": ["кордегардия", "абвахта", "гобвахта", "губа", "кича", "гауптическая вахта", "караулка", "караульня"],
    "гауптштурмфюрер": ["штурмгауптфюрер"],
    "гаустория": ["пята"],
    "гаучо": ["ковбой", "гаушо"],
    "гах": ["кахи"],
    "гахн": ["государственная академия художеств"],
    "гачок": ["крючок", "ключка"],
    "гашетка": ["спусковой крючок"],
    "гашиш": ["дурь", "анаша", "хэш"],
    "гашишизм": ["анашизм", "гашишемания", "каннабизм"],
    "гашник": ["поясок"],
    "гашпиль": ["баркас"],
    "гашт": ["сайр"],
    "гаштан": ["рафтан"],
    "гащивав": ["гащивавши"],
    "гащивавши": ["гащивав"],
    "гбр": ["группа быстрого реагирования"],
    "гбц": ["головка блока цилиндров"],
    "гв": ["грунтовые воды", "грудное вскармливание", "естественное вскармливание"],
    "гваздав": ["гваздавши"],
    "гваздавши": ["гваздав"],
    "гваздать": ["грязнить", "загрязнять", "марать", "пачкать", "пятнать"],
    "гваздаться": ["пачкаться"],
    "гвалт": ["гам", "галдёж", "гомон"],
    "гварани": ["гуарани"],
    "гвардеец": ["гвардионец", "дылда", "верзила", "жердь", "каланча", "верста", "оглобля", "жердяй", "лызла"],
    "гвардионец": ["гвардеец"],
    "гвардия": ["группировка", "эскадрилья"],
    "гваюла": ["гуайюла", "гвайюла", "гуаюле"],
    "гваяк": ["бакаут"],
    "гвд": ["продлёнка", "группа субботнего дня"],
    "гверилья": ["герилья"],
    "гверильяс": ["герильяс", "герильерос", "герильеро", "герильос"],
    "гвиана": ["французская гвиана"],
    "гвинейка": ["бисау-гвинейка"],
    "гвинея-бисау": ["республика гвинея-бисау"],
    "гвозданув": ["гвозданувши"],
    "гвозданувши": ["гвозданув"],
    "гвоздив": ["гвоздивши"],
    "гвоздивши": ["гвоздив"],
    "гвоздить": ["бить", "дубасить", "колотить", "колошматить", "костылять", "лупить", "лупцевать", "молотить", "мутузить", "тузить", "утюжить"],
    "гвоздь": ["гвоздь еланского"],
    "гвоздь программы": ["хедлайнер"],
    "гг": ["кт", "килотонна"],
    "гд": ["государственная дума", "госдума", "гд рф", "гемодиализ"],
    "где": ["в каком месте", "куда", "откуда", "в чём", "где-нибудь", "где-либо"],
    "где бы ни было": ["где бы то ни было"],
    "где бы то ни было": ["где бы ни было"],
    "где наше не пропадало": ["будь что будет", "пан или пропал", "была не была", "что уж там"],
    "где попало": ["где-либо", "где угодно", "где ни попадя"],
    "где-либо": ["где-то", "где-нибудь", "кое-где"],
    "где-нибудь": ["где-либо", "где-то"],
    "где-то": ["кое-где", "примерно", "около", "где"],
    "гдовец": ["гдович", "гдовичанин"],
    "гдр": ["германская демократическая республика", "восточная германия", "грузинская демократическая республика", "глобальная депозитарная расписка"],
    "геа": ["мать земля", "хайа", "энки", "айа", "эа"],
    "геб": ["кронос"],
    "гебраистика": ["иудаика"],
    "гевдэ": ["гёвдя", "говда", "гевдя"],
    "гевея": ["хевея"],
    "геврек": ["кравай"],
    "гевьон": ["гёфьён", "гефион"],
    "гегард": ["гехард", "айриванк"],
    "гегевюл": ["къаталан"],
    "гегелизм": ["гегельянство"],
    "гегельянец": ["гегелист"],
    "гегельянство": ["гегелизм"],
    "гегельянствовав": ["гегельянствовавши"],
    "гегельянствовавши": ["гегельянствовав"],
    "гегемония": ["верховенство", "главенство", "господство", "доминирование", "первенство"],
    "геделизировав": ["геделизировавши"],
    "геделизировавши": ["геделизировав"],
    "геджас": ["хиджаз"],
    "гедже": ["кечя"],
    "гедиз": ["герм"],
    "гедонист": ["эпикуреец"],
    "гедония": ["довольство", "наслаждение"],
    "гееборец": ["гомофоб"],
    "геенна": ["гинном", "енном"],
    "гезенк": ["вертикал"],
    "гезер": ["газру"],
    "гей-активистка": ["лгбт-активистка"],
    "гей-манифестация": ["гей-шествие"],
    "гей-порнография": ["гей-порно"],
    "гей-шествие": ["гей-манифестация"],
    "гейзер": ["фонтан"],
    "гейкав": ["гейкавши"],
    "гейкавши": ["гейкав"],
    "гейкнув": ["гейкнувши"],
    "гейкнувши": ["гейкнув"],
    "гейкнуть": ["нукнуть"],
    "гейма": ["гама"],
    "геймер": ["игроман", "игрун", "киберспортсмен"],
    "геймификация": ["игрофикация", "геймизация"],
    "геймовер": ["гамовер"],
    "гейропа": ["евросодом"],
    "гейскость": ["гейство"],
    "гейство": ["гейскость"],
    "гейтоногамия": ["соседнее опыление"],
    "гейша": ["гэйко"],
    "гекатомба": ["бойня"],
    "гекзаметр": ["гексаметр"],
    "гекзаметрический": ["гексаметрический"],
    "гексаген": ["гексоген"],
    "гексагон": ["шестиугольник"],
    "гексагональная плотнейшая упаковка": ["пгу", "плотнейшая двухслойная упаковка"],
    "гексагональная сингония": ["гексагирная сингония"],
    "гексаграмма": ["магендоид"],
    "гексадекан": ["цетан"],
    "гексалин": ["циклогексанол"],
    "гексаль": ["гексаграмма"],
    "гексаметилентрипероксиддиамин": ["гмтд"],
    "гексаметр": ["гекзаметр"],
    "гексатетраэдр": ["двадцатичетырёхгранник"],
    "гексафторбутадиен": ["гфбд"],
    "гексаэдр": ["шестигранник"],
    "гексен": ["гексилен"],
    "гексеракт": ["додекапетон"],
    "гексил": ["гексанитродифениламин"],
    "гектаар": ["гектар"],
    "гектар": ["га", "ар"],
    "гектографировав": ["гектографировавши"],
    "гектографировавши": ["гектографировав"],
    "гелгаудишкис": ["гельгудишки"],
    "гелендваген": ["гелик"],
    "геленджикец": ["геленджичанин"],
    "геленджичанин": ["геленджикец"],
    "гелеобразный": ["гелеподобный"],
    "гелеобразование": ["желатинирование", "застудневание"],
    "гелертер": ["книжный червь"],
    "гелертерский": ["талмудистский", "схоластический", "начётнический"],
    "гелиакический": ["гелиакальный"],
    "гелиантин": ["метилоранж"],
    "гелиево-неоновый": ["гелий-неоновый"],
    "гелий-неоновый": ["гелиево-неоновый"],
    "геликоидальный": ["винтовой", "винтообразный", "спиральный"],
    "геликоптер": ["вертолёт"],
    "гелим": ["пайда", "хайыр"],
    "гелио-планетный": ["солнечно-планетный"],
    "гелиогравюра": ["фотогравюра"],
    "гелиограф": ["солнечный телескоп"],
    "гелиоз": ["солнечный удар"],
    "гелиокс": ["гелиэйр"],
    "гелион": ["альфа-частица"],
    "гелиопатия": ["гелиопатология"],
    "гелиополис": ["гелиополь", "илиополь"],
    "гелиополь": ["гелиополис", "илиополь"],
    "гелиостанция": ["гелиоэлектрическая станция"],
    "гелиотерапия": ["солнцелечение"],
    "гелиотипия": ["артотипия", "альбертипия", "коллотипия"],
    "гелиотроп": ["лишаева трава", "зелёный халцедон"],
    "гелиофизика": ["физика", "солнце"],
    "гелиофильный": ["солнцелюбивый"],
    "гелиоцентрический": ["гелиоцентричный"],
    "гелиоцентричный": ["гелиоцентрический"],
    "гелиплан": ["винтокрыл", "гиродин"],
    "гелипорт": ["вертодром", "хелипорт"],
    "гелиэя": ["гелиея", "дикастерий"],
    "геллиевая жидкость": ["жидкость гелли"],
    "гелуьр": ["гъэзенж"],
    "гель": ["желе"],
    "гельветический": ["швейцарский"],
    "гельвеция": ["швейцария"],
    "гельминт": ["глист"],
    "гельмут": ["хельмут"],
    "гем": ["балканы"],
    "гематогенный": ["кроветворный"],
    "гематолиз": ["гемолиз", "эритроцитолиз"],
    "гематома": ["кровоподтёк", "синяк"],
    "гематомка": ["синячок"],
    "гематофаг": ["кровосос"],
    "гематофагический": ["кровососущий", "кровоядный"],
    "гематофобия": ["гемофобия", "гемафобия"],
    "гематрия": ["гиматрия"],
    "гемблер": ["игроман", "лудоман"],
    "гемблинг": ["гэмблинг", "азартная игра", "игорный бизнес", "лудомания", "игромания"],
    "гемералопия": ["никталопия", "куриная слепота"],
    "гемиартроз": ["симфиз"],
    "гемикрания": ["мигрень"],
    "гемимегалэнцефалия": ["гмэ", "унилатеральная мегалэнцефалия"],
    "гемимонадный": ["пальмеллоидный", "капсальный", "трансгрессивный"],
    "гемин": ["солянокислый гематин"],
    "геминальный": ["вицинальный"],
    "гемината": ["двойной", "согласный", "долгий"],
    "геминация": ["удвоение"],
    "гемини": ["бивалент"],
    "геминировав": ["геминировавши"],
    "геминировавши": ["геминировав"],
    "гемиспороз": ["ооспороз", "спорэндомикоз"],
    "гемициклический": ["полукруговой"],
    "гемиэдрический": ["бисфеноидический"],
    "гемлик": ["киос"],
    "гемма": ["глипт"],
    "гемоглобинный": ["гемоглобиновый"],
    "гемоглобиновый": ["гемоглобинный"],
    "гемоглобинометр": ["гемометр"],
    "гемоделюция": ["гидремия"],
    "гемодиализ": ["гд"],
    "гемодилюция": ["гидремия"],
    "гемолиз": ["гематолиз", "эритроцитолиз"],
    "гемолизин": ["сапонин"],
    "гемомеланин": ["малярийный пигмент"],
    "гемометр": ["гемоглобинометр"],
    "гемопоэз": ["кроветворение", "кровеобразование"],
    "гемопоэтин": ["эритропоэтин"],
    "гемор": ["беспокойство", "геморрой", "занудство", "затруднение", "проблема"],
    "геморрагия": ["кровоизлияние", "кровотечение"],
    "геморроидальный": ["геморройный", "почечуйный"],
    "геморройный": ["геморроидальный", "почечуйный", "томительный", "трудный", "тяжёлый", "мучительный", "неудобный", "хлопотный", "геморный"],
    "гемостазиология": ["коагулология"],
    "гемотрансфузия": ["переливание крови"],
    "гемофобия": ["гематофобия"],
    "гемоцель": ["схизоцель"],
    "гемоцит": ["гематоцит"],
    "генам": ["чъехынэм"],
    "генварь": ["январь"],
    "генделик": ["рюмочная", "наливайка"],
    "гендер": ["биологический пол", "пол"],
    "гендер-пати": ["гендерная вечеринка"],
    "гендергэп": ["гендерный пробел", "гендерный разрыв", "подчёркивание"],
    "гендерквир": ["небинарность"],
    "гендерная дисфория": ["расстройство гендерной идентичности", "транссексуальность", "транссексуализм", "гендерное несоответствие"],
    "гендерная идентичность": ["психологический пол"],
    "гендерная лингвистика": ["лингвистическая гендерология"],
    "гендерно-нейтральный": ["унисекс"],
    "гендерный": ["полоролевой", "половой", "сексуальный"],
    "гендиадис": ["редупликация"],
    "гендиректор": ["генеральный директор", "исполнительный директор", "гендир"],
    "гендляр": ["баришник", "спекулянт"],
    "генеалогия": ["родословная"],
    "генезис": ["возникновение", "синтез", "происхождение", "зарождение"],
    "генерал": ["адмирал", "гроссмейстер"],
    "генерал-бас": ["бассо континуо", "непрерывный бас", "общий бас", "цифрованный бас"],
    "генерал-оберст": ["генерал-полковник"],
    "генерал-полковник": ["генерал-оберст"],
    "генералив": ["генераливши"],
    "генераливши": ["генералив"],
    "генерализация": ["генерализирование"],
    "генерализировав": ["генерализировавши"],
    "генерализировавши": ["генерализировав"],
    "генерализирование": ["обобщение", "генерализация"],
    "генерализовав": ["генерализовавши"],
    "генерализовавши": ["генерализовав"],
    "генерализованный": ["генерализированный", "обобщенный", "общий", "распространенный", "распространяющийся"],
    "генерализовать": ["обобщать"],
    "генералист": ["эрудит", "универсал"],
    "генеральный директор": ["гендир"],
    "генеральный примар": ["генпримар"],
    "генеральный секретарь": ["генсек", "генсекретарь"],
    "генеральствовав": ["генеральствовавши"],
    "генеральствовавши": ["генеральствовав"],
    "генеративная лингвистика": ["трансформационная порождающая грамматика", "трансформационно-генеративная грамматика", "хомскианская лингвистика", "генеративизм"],
    "генеративно-состязательная сеть": ["гсс"],
    "генеративный": ["репродуктивный", "порождающий"],
    "генератор": ["источник", "производитель", "родитель", "начало", "кладезь"],
    "генерировав": ["генерировавши"],
    "генерировавши": ["генерировав"],
    "генерировать": ["порождать", "производить", "создавать"],
    "генерирующая компания": ["генкомпания"],
    "генетив": ["родительный падеж", "генитив"],
    "генетика": ["продажная девка империализма"],
    "генетический": ["генный"],
    "генетлиакон": ["ода", "гороскоп"],
    "генетта": ["генета"],
    "гениальничав": ["гениальничавши"],
    "гениальничавши": ["гениальничав"],
    "гениально": ["шедеврально"],
    "гениальный": ["выдающийся", "великий", "редкостный", "исключительный"],
    "гении мыслят одинаково": ["у гениев мысли сходятся"],
    "гений": ["гениальность", "талант", "бог", "богиня"],
    "гениталии": ["половой орган", "копулятивный орган", "хозяйство", "интимное место", "причинное место", "срамное место", "срам", "причиндал", "стыд"],
    "генитив": ["родительный падеж", "генетив"],
    "генка": ["гена"],
    "генконсул": ["генеральный консул"],
    "геннадиевич": ["геннадьевич"],
    "геннадиевский": ["геннадьевский"],
    "геннадьевич": ["геннадиевич"],
    "геннадьевский": ["геннадиевский"],
    "генно-инженерно-модифицированный": ["генетически", "модифицированный", "генно-модифицированный", "трансгенный"],
    "генно-модифицированный": ["генетически", "модифицированный", "генно-инженерно-модифицированный", "трансгенный"],
    "генный": ["генетический"],
    "геносома": ["липоплекс"],
    "генотипировав": ["генотипировавши"],
    "генотипировавши": ["генотипировав"],
    "генотипический": ["генотипный"],
    "генотипный": ["генотипический"],
    "генотипоскопия": ["днк-анализ", "днк-тест"],
    "геноцид": ["массовое убийство"],
    "генподряд": ["генеральный", "подряд"],
    "генподрядчик": ["генеральный подрядчик"],
    "генпрок": ["генпрокурор"],
    "генри": ["генрих", "анри"],
    "генриетта": ["гарриета", "анриетт"],
    "генрих": ["хайнрих", "генри", "анри"],
    "генсек-бровеносец": ["бровеносец", "бровястый"],
    "генсекретарь": ["генсек"],
    "генуинный": ["природный", "врождённый", "наследственный", "идиопатический", "нативный", "первоначальный"],
    "генциана": ["горечавка"],
    "генштаб": ["гш"],
    "геня": ["гена", "женя"],
    "геоботаника": ["фитоценология"],
    "географиня": ["географичка"],
    "географическая карта": ["ландкарта"],
    "географический": ["землеописательный"],
    "географичка": ["географиня"],
    "география": ["землеописание", "распространение"],
    "геоизотерма": ["изогеотерма"],
    "геокриология": ["мерзлотоведение"],
    "геокультурный": ["культурно-географический", "макрокультурный", "социокультурный"],
    "геолингвистика": ["лингвогеография"],
    "геологиня": ["геологичка"],
    "геологическая группа": ["эратема"],
    "геологическая система": ["система"],
    "геологическая эпоха": ["эпоха"],
    "геологическая эра": ["эра"],
    "геологический век": ["век"],
    "геологический компас": ["горный компас"],
    "геологический период": ["период"],
    "геологический эон": ["эон"],
    "геологичка": ["геологиня"],
    "геология": ["геогнозия"],
    "геометризовав": ["геометризовавши"],
    "геометризовавши": ["геометризовав"],
    "геометризоваться": ["геометризироваться"],
    "геометрия": ["габариты", "форма"],
    "геопалинология": ["палеопалинология"],
    "георг": ["джордж"],
    "георгиевич": ["егорович"],
    "георгиевский крест": ["георгий", "солдатский георгий", "егорий", "солдатский егорий"],
    "георгий": ["егор", "юрий", "геша", "гоша", "гога", "жора", "юра"],
    "георгин": ["далия", "георгина"],
    "геосутура": ["сутура"],
    "геотег": ["геометка"],
    "геотропизм": ["гравитропизм"],
    "геофон": ["сейсмограф", "сейсмоприёмник"],
    "геохронологическая шкала": ["стратиграфическая шкала"],
    "геохронологический": ["стратиграфический"],
    "геоцентризм": ["геоцентрическая система мира"],
    "гепард": ["охотничий леопард", "чита"],
    "гепардов": ["гепардовый"],
    "гепардовый": ["гепардов"],
    "гепатися": ["гепати", "падати"],
    "гепатонефромегальный": ["нефромегалический"],
    "гептагон": ["семиугольник"],
    "гептада": ["семёрка"],
    "гептаэдр": ["семигранник"],
    "гептеракт": ["тетрадекаэксон", "тетрадекаэкзон"],
    "геракл": ["алкид", "геркулес"],
    "геральдик": ["геральдист", "гербовед"],
    "геральдика": ["гербоведение"],
    "геральдист": ["геральдик", "арморист", "гербовед"],
    "геранбой": ["касум-исмаилов"],
    "гераневый": ["гераниевый"],
    "геранизация": ["цветение герани", "цветёт герань"],
    "герань": ["журавельник", "пеларгония"],
    "гераскофобия": ["геронтофобия"],
    "герб": ["эмблема"],
    "гербалайфист": ["гербалайфщик"],
    "гербалайфщик": ["гербалайфист"],
    "гербаризировав": ["гербаризировавши"],
    "гербаризировавши": ["гербаризировав"],
    "гербовая печать": ["удостоверяющая печать"],
    "гербовед": ["геральдик", "геральдист"],
    "гербоведение": ["геральдика"],
    "гереп": ["геряб"],
    "гериатр": ["геронтолог"],
    "герилья": ["гверилья"],
    "герильяс": ["гверильяс", "герильерос", "герильеро", "герильос", "партизан"],
    "геринг": ["херинг", "гёринг"],
    "геркулес": ["геракл"],
    "геркулес на распутье": ["геракл на распутье", "геракл на перепутье", "выбор геркулеса", "выбор геракла"],
    "геркулесов": ["геркулесовский"],
    "геркулесовая каша": ["овсяная каша", "овсянка", "геркулес"],
    "геркулесовский": ["геркулесов"],
    "геркулесовый": ["овсяный"],
    "герм": ["гедиз", "саробад"],
    "германец": ["немец"],
    "германизация": ["онемечивание"],
    "германизировав": ["германизировавши"],
    "германизировавши": ["германизировав"],
    "германизм": ["немечизна"],
    "германий": ["экасилиций"],
    "германия": ["фрг", "федеративная республика германия"],
    "германофилия": ["германофильство"],
    "германофобия": ["германофобство"],
    "германофобский": ["антинемецкий"],
    "германофобство": ["германофобия"],
    "германская демократическая республика": ["восточная германия", "гдр"],
    "германская империя": ["второй рейх"],
    "германский": ["немецкий"],
    "гермафродит": ["андрогин", "гинантроп", "двуснастный", "двусбруйный", "двуполый", "обаполый", "межеумок", "девуня", "девуля", "бабатя", "бабуля", "раздевулье", "бабьяк", "бабеня", "бородуля"],
    "гермафродитизм": ["обоеполость", "андрогиния"],
    "гермес": ["меркурий", "психопомп", "трисмегист", "тот"],
    "герметизировав": ["герметизировавши"],
    "герметизировавши": ["герметизировав"],
    "герметизирование": ["герметизация"],
    "герметический": ["герметичный", "тайный", "скрытый"],
    "герметично": ["герметически"],
    "герметичность": ["непроницаемость"],
    "герметичный": ["непроницаемый", "герметический"],
    "герминативный": ["зародышевый", "прорастающий"],
    "герминация": ["прорастание"],
    "гермомешок": ["драйбег"],
    "гермонт": ["гермонтис"],
    "гермонтис": ["иуни", "ермонт", "армант", "гермонт"],
    "гермополис": ["ермонт", "армант"],
    "гермополь": ["гермополис", "ермополь", "гермонтис"],
    "героизация": ["героизирование"],
    "героизировав": ["героизировавши"],
    "героизировавши": ["героизировав"],
    "героизирование": ["героизация"],
    "героизировать": ["героизовать", "возвеличивать"],
    "героизм": ["доблесть", "геройство"],
    "героизовав": ["героизовавши"],
    "героизовавши": ["героизовав"],
    "героизовать": ["героизировать"],
    "героин": ["диаморфин", "диацетилморфин", "герыч", "гердос", "герандос", "герасим", "греча", "гречка"],
    "героинизм": ["героиномания"],
    "героинист": ["героинщик"],
    "героиномания": ["героинизм"],
    "героинщик": ["героинист"],
    "героически": ["геройски"],
    "героический": ["геройский", "героичный", "мужественный"],
    "героично": ["героически", "геройски"],
    "героичный": ["героический"],
    "герой": ["деятел"],
    "герой в жопе с дырой": ["герой кверху дырой"],
    "герой кверху дырой": ["герой в жопе с дырой"],
    "герой россии": ["герой российской федерации"],
    "герой российской федерации": ["герой россии"],
    "герой-панфиловец": ["панфиловец"],
    "геройски": ["героически"],
    "геройский": ["героический"],
    "геройство": ["героизм"],
    "геройствовав": ["геройствовавши"],
    "геройствовавши": ["геройствовав"],
    "геронтофобия": ["гераскофобия"],
    "геростратов": ["геростратовский"],
    "геростратовский": ["геростратов"],
    "герпесовирусный": ["герпесвирусный"],
    "герптилия": ["гад"],
    "герреразаврид": ["эррерозаврид"],
    "герсдорфит": ["амоибит", "никелево-мышьяковый блеск", "добшуанит", "никелево-мышьяковый колчедан", "соммаругаит", "стириан", "плессит"],
    "гертмэ": ["гертмя"],
    "герхард": ["джеррард", "жерар"],
    "герц": ["гц"],
    "герцметр": ["частотомер"],
    "герцог": ["дюк"],
    "герцог мира": ["мирный герцог", "пиздюк"],
    "герцогиня": ["княгиня", "принцесса"],
    "герыч": ["хмурый"],
    "геряб": ["гереп"],
    "геспер": ["венера"],
    "гесперидий": ["померанец"],
    "гессонит": ["гроссуляр"],
    "гестапо": ["тайная государственная полиция"],
    "гестация": ["беременность", "осанка"],
    "гестия": ["гистия"],
    "гесур": ["гешур"],
    "гет": ["прусс"],
    "гетера": ["куртизанка", "гейша", "ганика", "проститутка"],
    "гетерист": ["этерист"],
    "гетеро-": ["разно-"],
    "гетероауксин": ["индолилуксусная кислота"],
    "гетерогамия": ["анизогамия"],
    "гетерогенез": ["гетерогенезис"],
    "гетерогенезис": ["гетерогенез"],
    "гетерогенная система": ["неоднородная система"],
    "гетерогенность": ["неоднородность", "разнородность"],
    "гетерогенный": ["разнородный", "неоднородный"],
    "гетеродетный пептид": ["депсипептид"],
    "гетеродинировав": ["гетеродинировавши"],
    "гетеродинировавши": ["гетеродинировав"],
    "гетеродонтизм": ["гетеродонтность", "гетеродонтия"],
    "гетерозис": ["гибридный", "сила"],
    "гетерокарпия": ["разноплодие"],
    "гетероклизия": ["разносклоняемость"],
    "гетероконтакт": ["гетеропереход"],
    "гетерологичный": ["гетерологический", "нерефлексивный", "несамоприменимый"],
    "гетероромантичность": ["биромантичность"],
    "гетеросек": ["гетеросексуал", "натурал"],
    "гетеросексуал": ["гетеросексуалист", "натурал", "гетераст", "гетеросек", "гетерас", "гетрила"],
    "гетеросексуалист": ["гетеросексуал", "натурал"],
    "гетеросексуалистка": ["гетеросексуалка", "натуралка"],
    "гетеросексуалка": ["гетеросексуалистка"],
    "гетеросома": ["аллосома", "аллохромосома", "гетерохромосома", "гоносома", "гонохромосома", "идиохромосома"],
    "гетероспоровый": ["разноспоровый"],
    "гетеростилия": ["разностолбчатость"],
    "гетерострак": ["разнощитковый"],
    "гетеротопия": ["дистопия", "эктопия"],
    "гетеротрихальный": ["разнонитчатый"],
    "гетеротропия": ["косоглазие"],
    "гетеротроф": ["консумент"],
    "гетеротрофия": ["органотрофия"],
    "гетерофиллия": ["разнолистность", "разнолиственность"],
    "гетерофория": ["эксциклофория"],
    "гетерохромия": ["гетерофтальм"],
    "гетероцикл": ["гетероциклическое соединение"],
    "гетит": ["гьотит"],
    "гетманат": ["гетманщина"],
    "гетманский": ["гетьманский"],
    "гетманщина": ["малороссия"],
    "гетрила": ["гетеросексуал", "натурал"],
    "геттанг": ["геттангий"],
    "геттангий": ["геттанг"],
    "гетто": ["трущобы", "фавела"],
    "геть": ["прочь", "вон", "долой"],
    "гетьманский": ["гетманский"],
    "гефельсберг": ["гевельсберг"],
    "гефилте-фиш": ["фаршированная рыба", "рыба-фиш"],
    "гефиона": ["гефион"],
    "гечекъуш": ["варкъанат"],
    "гешефт": ["спекуляция"],
    "гешефтмахер": ["бизнесмен", "торгаш", "ловкач", "проныра", "воротила", "аферист"],
    "гешефтмахерство": ["торгашество"],
    "геэз": ["древнеэфиопский язык"],
    "гея": ["хтония", "теллус"],
    "гиа": ["огэ", "дпа"],
    "гиалоплазма": ["цитозоль", "матрикс цитоплазмы"],
    "гиалуронидаза": ["муциназа"],
    "гиалуроновая кислота": ["гиалуронат", "гиалуронан", "гиалурон", "гиалуронка"],
    "гиат": ["гиатус", "хиатус", "зияние"],
    "гиатус": ["хиатус", "зияние"],
    "гиацинт": ["гиакинф"],
    "гиббон": ["гаишник"],
    "гибдд": ["гаи"],
    "гибель": ["погибель", "насильственная смерть", "крушение", "крах", "провал"],
    "гибернация миокарда": ["спящий миокард"],
    "гибкий": ["тонкий", "эластичный", "податливый", "изящный", "стройный", "ловкий", "мягкий", "плавный", "приспосабливающийся", "изворотливый", "уступчивый", "покладистый", "богатый", "сложный"],
    "гибко": ["податливо", "эластично"],
    "гибкость": ["пластичность", "изворотливость"],
    "гибнув": ["гибнувши"],
    "гибнувши": ["гибнув"],
    "гибнуть": ["погибать", "пропадать"],
    "гибнущий": ["погибающий", "умирающий"],
    "гибралтар": ["гибралтарский пролив"],
    "гибрид": ["помесь", "полукровка", "гибридный автомобиль", "смесь", "карпокарась", "речной карась"],
    "гибридизировав": ["гибридизировавши"],
    "гибридизировавши": ["гибридизировав"],
    "гибридизировать": ["скрещивать", "скрестить"],
    "гибрис-синдром": ["синдром высокомерия"],
    "гибэдэдэшник": ["гаишник"],
    "гиг": ["гигес", "гуггу"],
    "гигабайт": ["гиг", "гектар", "гибибайт"],
    "гигабайтный": ["гигабайтовый"],
    "гигабайтовый": ["гигабайтный"],
    "гигагерц": ["гигацикл", "киломегацикл", "киломегагерц"],
    "гигант": ["корифей", "титан", "громада", "исполин"],
    "гигантный": ["гигантский"],
    "гигантский": ["огромный", "огроменный", "громадный"],
    "гигапарсек": ["гпк"],
    "гигаэлектрон-вольт": ["гигаэлектронвольт", "гэв", "бэв", "биллиэлектронвольт"],
    "гигаэлектронвольт": ["гэв", "гигаэлектрон-вольт", "биллиэлектронвольт", "бэв"],
    "гигрометр": ["гигроскоп", "влагомер"],
    "гигроскопический": ["гигроскопичный"],
    "гигроскопичность": ["влагоёмкость"],
    "гигроскопичный": ["гигроскопический"],
    "гигрофильность": ["влаголюбивость"],
    "гигрофильный": ["влаголюбивый"],
    "гид": ["проводник", "путеводитель"],
    "гидантоин": ["гликолилмочевина"],
    "гидеон": ["гедеон"],
    "гидитися": ["гидувати"],
    "гидкий": ["огидний"],
    "гидра": ["лернейская гидра", "спрут"],
    "гидравлическая передача": ["гидропередача"],
    "гидравлическая тележка": ["рокла", "рохля"],
    "гидравлическая турбина": ["гидротурбина"],
    "гидравлический кран": ["гидрокран"],
    "гидравлический молот": ["гидромолот"],
    "гидравлический мотор": ["гидромотор"],
    "гидравлический привод": ["гидропривод"],
    "гидравлический усилитель": ["гидроусилитель", "следящий гидропривод"],
    "гидразин": ["диамид"],
    "гидрартроз": ["водянка сустава"],
    "гидрастис": ["желтокорень"],
    "гидратировав": ["гидратировавши"],
    "гидратировавши": ["гидратировав"],
    "гидрач": ["гидроусилитель руля", "гидравлический усилитель руля"],
    "гидремия": ["гемоделюция"],
    "гидрировав": ["гидрировавши"],
    "гидрировавши": ["гидрировав"],
    "гидрирование": ["гидрогенизация"],
    "гидрия": ["кальпида"],
    "гидроабразивный": ["водоструйный"],
    "гидроавианосец": ["гидроавиатранспорт", "авиатендер", "авиаматка", "гидрокрейсер"],
    "гидроавиатранспорт": ["гидроавианосец"],
    "гидроавиация": ["морская авиация"],
    "гидроаэробика": ["аквааэробика"],
    "гидроаэромеханика": ["гидродинамика"],
    "гидроген": ["водород"],
    "гидрогенизировав": ["гидрогенизировавши"],
    "гидрогенизировавши": ["гидрогенизировав"],
    "гидрография": ["мореописание", "талассография"],
    "гидрогётит": ["лепидокрокит", "рубиновая слюдка", "пирросидерит"],
    "гидродинамика": ["динамика жидкости", "механика жидкости и газа"],
    "гидродинамический": ["жидкостный"],
    "гидроизопьеза": ["пьезоизогипса"],
    "гидрокарбонат": ["бикарбонат"],
    "гидрокарбонат натрия": ["бикарбонат натрия", "питьевая сода", "пищевая сода", "двууглекислый натрий"],
    "гидрокарбонатный": ["бикарбонатный"],
    "гидрокефал": ["гидроцефал"],
    "гидрокефалия": ["гидроцефалия", "водянка головного мозга"],
    "гидроколонотерапия": ["колоногидротерапия"],
    "гидрокортизон": ["кортизол"],
    "гидроксид": ["гидроокись"],
    "гидроксид кальция": ["гашёная известь", "едкая известь", "пушонка"],
    "гидроксикарбамид": ["гидроксимочевина"],
    "гидроксильная группа": ["гидроксогруппа"],
    "гидроксимочевина": ["гидроксиурея", "гидроксикарбамид"],
    "гидрокситолуол": ["крезол", "метилфенол"],
    "гидроксиурея": ["гидроксимочевина", "гидроксиуреа"],
    "гидроксихлорохин": ["оксихлорохин", "плакенил", "плаквенил"],
    "гидроксоний": ["оксоний", "гидроний"],
    "гидролиз": ["гидролизация"],
    "гидролизация": ["гидролиз"],
    "гидролизировав": ["гидролизировавши"],
    "гидролизировавши": ["гидролизировав"],
    "гидролизовав": ["гидролизовавши"],
    "гидролизовавши": ["гидролизовав"],
    "гидролокатор": ["сонар"],
    "гидролокатор бокового обзора": ["гбо"],
    "гидромайор": ["капитан третьего ранга", "каптри"],
    "гидромашина": ["гидравлическая машина"],
    "гидрометеослужба": ["гидрометслужба"],
    "гидрометслужба": ["гидрометеослужба"],
    "гидромолот": ["гидравлический молот"],
    "гидромонитор": ["гидропушка"],
    "гидромотор": ["гидравлический мотор"],
    "гидронавт": ["акванавт"],
    "гидроним": ["гидротопоним"],
    "гидронимика": ["гидротопонимика"],
    "гидроокись": ["гидроксид"],
    "гидрооксид": ["гидроксид"],
    "гидропатия": ["гидротерапия"],
    "гидроплан": ["гидросамолёт"],
    "гидропонический": ["гидропонный"],
    "гидропонный": ["гидропонический"],
    "гидропривод": ["гидравлический привод", "гидростатический привод"],
    "гидропушка": ["гидромонитор"],
    "гидроразъём": ["гидравлический разъём"],
    "гидроресурсы": ["гидроэнергоресурсы"],
    "гидросамолёт": ["гидроплан"],
    "гидроселенид": ["гидроселенид-анион"],
    "гидротерапевтический": ["водолечебный"],
    "гидротерапия": ["водолечение"],
    "гидротермальный": ["гидротермический"],
    "гидротермический": ["гидротермальный"],
    "гидротопоним": ["гидроним"],
    "гидротопонимика": ["гидронимика"],
    "гидротранспорт": ["гидротранспортировка"],
    "гидротранспортировка": ["гидротранспорт"],
    "гидротрансформатор": ["турботрансформатор"],
    "гидроусилитель": ["гидравлический усилитель", "гидравлический следящий привод", "следящий гидропривод"],
    "гидроусилитель руля": ["гур", "гидрач"],
    "гидрофилизировав": ["гидрофилизировавши"],
    "гидрофилизировавши": ["гидрофилизировав"],
    "гидрофилизировать": ["гидрофилизовать"],
    "гидрофилизовав": ["гидрофилизовавши"],
    "гидрофилизовавши": ["гидрофилизовав"],
    "гидрофилизовать": ["гидрофилизировать"],
    "гидрофильный": ["смачиваемый"],
    "гидрофобизировав": ["гидрофобизировавши"],
    "гидрофобизировавши": ["гидрофобизировав"],
    "гидрофобизировать": ["гидрофобизовать"],
    "гидрофобизовав": ["гидрофобизовавши"],
    "гидрофобизовавши": ["гидрофобизовав"],
    "гидрофобизовать": ["гидрофобизировать"],
    "гидрофобия": ["водобоязнь"],
    "гидрофобный": ["водоотталкивающий", "олеофильный"],
    "гидрохлорид": ["хлоргидрат"],
    "гидроцефалия": ["гидрокефалия"],
    "гидроцикл": ["аквабайк", "водный мотоцикл", "скутер"],
    "гидроцилиндр": ["гидравлический цилиндр"],
    "гидроэлектростанция": ["гидроэлектрическая станция", "гэс"],
    "гидроэнергетический": ["водно-энергетический"],
    "гидроэнергоресурсы": ["гидроресурсы"],
    "гиена": ["хищник"],
    "гиений": ["гиеновый"],
    "гиеновый": ["гиений"],
    "гиератический": ["иератический"],
    "гиероглиф": ["иероглиф"],
    "гиерофобия": ["агиофобия"],
    "гизаурус": ["идеографический словарь", "тезаурус"],
    "гик": ["гикание", "гиканье"],
    "гикав": ["гикавши"],
    "гикавши": ["гикав"],
    "гикание": ["гик", "гиканье"],
    "гиканье": ["гикание", "гик"],
    "гикнув": ["гикнувши"],
    "гикнувши": ["гикнув"],
    "гикнуться": ["гакнуться"],
    "гикори": ["кария"],
    "гил": ["салсол"],
    "гилас": ["дон"],
    "гилгул": ["гильгуль"],
    "гилдия": ["колегия"],
    "гилем": ["фарш"],
    "гиль": ["вздор", "чепуха", "галиматья"],
    "гильотинировав": ["гильотинировавши"],
    "гильотинировавши": ["гильотинировав"],
    "гилэй": ["гиляй"],
    "гиматий": ["гиматион"],
    "гименокаллис": ["лилия-паук"],
    "гимет": ["имитос"],
    "гимн": ["ода", "прославление", "восхваление", "славословие"],
    "гимнаст": ["акробат"],
    "гимнография": ["гимнописание", "гимнотворчество"],
    "гимнодия": ["гимнология"],
    "гимнология": ["гимнодия"],
    "гимнософист": ["адживик"],
    "гимор": ["траханина", "жопа", "гемор"],
    "гингиво-": ["гингив-"],
    "гинекей": ["гинекейон", "гинесей"],
    "гинекейон": ["гинекей"],
    "гинекофобия": ["гинофобия", "женофобия"],
    "гинесей": ["гинекей"],
    "гинобазис": ["цветоложе", "гинобаз", "гинофор"],
    "гиноид": ["фембот"],
    "гиноидный": ["глютеофеморальный"],
    "гинув": ["гинувши"],
    "гинувши": ["гинув"],
    "гинухский": ["гинухский язык"],
    "гиньоль": ["петрушка", "дурак", "балаган", "театр ужасов"],
    "гиомандибуляре": ["подвесок"],
    "гип": ["главный инженер проекта"],
    "гип-гип": ["гип-гип-ура"],
    "гип-гип-ура": ["гип-гип"],
    "гипата": ["ипати"],
    "гипер-": ["сверх-", "супер-"],
    "гиперандрогенизм": ["гиперандрогения"],
    "гипербарическая барокамера": ["компрессионная барокамера"],
    "гипербарическая оксигенация": ["гбо"],
    "гипербатон": ["гипербат"],
    "гиперболизация": ["преувеличение", "преувеличенье", "преувеличивание", "утрирование"],
    "гиперболизировав": ["гиперболизировавши"],
    "гиперболизировавши": ["гиперболизировав"],
    "гиперболизировать": ["преувеличивать"],
    "гиперболизм": ["гиперболичность", "гипербола"],
    "гиперболически": ["чрезмерно", "преувеличенно", "слишком", "излишне", "чрезвычайно", "избыточно", "чересчур"],
    "гиперболично": ["гиперболически", "преувеличенно", "чрезмерно"],
    "гипербореец": ["гиперборей"],
    "гиперборей": ["гипербореец", "северянин"],
    "гиперборейский": ["северный", "нордический"],
    "гипергидратация": ["гипергидрия"],
    "гиперголический": ["гипергольный"],
    "гипергольный": ["гиперголический"],
    "гипергонадизм": ["гипергенитализм"],
    "гипердактилия": ["многопалость", "полидактилия"],
    "гиперестезия": ["гиперэстезия"],
    "гиперинвазия": ["инвазия"],
    "гиперквадрика": ["многообразие"],
    "гиперкинез": ["дискинезия"],
    "гиперкинезия": ["гипермотильность"],
    "гиперкоагуляция": ["тромбофилия"],
    "гиперкорректность": ["гиперкоррекция"],
    "гиперметропия": ["дальнозоркость"],
    "гипермотильность": ["гиперкинезия"],
    "гиперник": ["гайперник", "перменорм"],
    "гипероним": ["надмножество"],
    "гиперопека": ["гиперпротекция"],
    "гиперпаратиреоидный": ["паратиреотоксический", "гиперкальциемический"],
    "гиперпирамида": ["пентатоп"],
    "гиперплазия": ["пролиферация", "гипертрофия", "гипергенез"],
    "гиперпротекция": ["гиперопека"],
    "гиперсаливация": ["птиализм", "слюнотечение", "сиалорея"],
    "гиперсема": ["архисема"],
    "гиперскоростной": ["сверхскоростной"],
    "гиперсомния": ["сонливость"],
    "гиперсреда": ["гипермедиа"],
    "гиперссылка": ["линк"],
    "гиперстеник": ["эндоморф"],
    "гиперстенический": ["пикнический"],
    "гиперструна": ["суперструна"],
    "гипертело": ["гиперобъём"],
    "гипертензин": ["ангиотензин", "ангиотонин"],
    "гипертиреоз": ["тиреотоксикоз"],
    "гипертония": ["гипертензия", "артериальная гипертензия"],
    "гипертрофировав": ["гипертрофировавши"],
    "гипертрофировавши": ["гипертрофировав"],
    "гипертрофированный": ["увеличенный", "преувеличенный"],
    "гипертрофировать": ["гиперболизировать", "преувеличивать"],
    "гиперфрагмент": ["гиперядро"],
    "гиперхромия": ["гиперхромазия"],
    "гиперцикл": ["гиперокружность", "эквидистанта"],
    "гиперцитокинемия": ["цитокиновый шторм"],
    "гиперчувствительность": ["гиперэстезия"],
    "гиперэллипсоид": ["эллипсоид"],
    "гиперэстезия": ["гиперестезия", "сверхчувствительность", "гиперчувствительность"],
    "гиперядро": ["гиперфрагмент"],
    "гипестезия": ["гипоэстезия"],
    "гипнагогия": ["гипногогия"],
    "гипногогический": ["гипнагогический"],
    "гипногогия": ["гипнагогия"],
    "гипноз": ["месмеризм", "гипнотизм"],
    "гипнонаркоз": ["наркогипноз"],
    "гипнотизация": ["гипнотизирование"],
    "гипнотизировав": ["гипнотизировавши"],
    "гипнотизировавши": ["гипнотизировав"],
    "гипнотизирование": ["гипнотизированье"],
    "гипнотизёр": ["магнетизёр"],
    "гипнофобия": ["клинофобия", "сомнифобия", "сомнотанатофобия"],
    "гиповав": ["гиповавши"],
    "гиповавши": ["гиповав"],
    "гиповолемия": ["олигемия"],
    "гипогенезия": ["гипоплазия"],
    "гипогидратация": ["обезвоживание"],
    "гиподинамия": ["гипокинезия"],
    "гипокинез": ["гипокинезия"],
    "гипокинезия": ["гиподинамия"],
    "гипокористика": ["уменьшительное имя", "гипокористическое имя"],
    "гипокористический": ["уменьшительно-ласкательный", "уменьшительный"],
    "гипокотиль": ["подсемядольное колено"],
    "гипоксия": ["кислородное голодание"],
    "гипомания": ["оптимистичность"],
    "гипоним": ["подмножество"],
    "гипонимия": ["выше"],
    "гипоопека": ["недосмотр"],
    "гипоплазия": ["гипогенезия"],
    "гипопластический": ["гипогенетический", "апластический"],
    "гипореактивность": ["гипочувствительность"],
    "гипосекреция": ["секреторная недостаточность"],
    "гипоспермия": ["олигоспермия"],
    "гипостазировав": ["гипостазировавши"],
    "гипостазировавши": ["гипостазировав"],
    "гипостазирование": ["ипостазирование"],
    "гипостазировать": ["реифицировать"],
    "гипостазис": ["транспозиция"],
    "гипостеник": ["эктоморф", "астеник"],
    "гипосульфит": ["тиосульфат"],
    "гипотеза": ["предположение", "ипотеза"],
    "гипотензивный": ["антигипертензивный"],
    "гипотензия": ["гипотония"],
    "гипотермия": ["переохлаждение"],
    "гипотетически": ["предположительно", "предполагаемо", "теоретически"],
    "гипотетический": ["предположительный", "предполагаемый", "теоретический"],
    "гипотония": ["артериальная гипотензия", "мышечная гипотония", "мышечный гипотонус"],
    "гипотонус": ["гипотония"],
    "гипофибриногенемия": ["фибриногенопения", "фибринопения", "афибриногенемия"],
    "гипофиз": ["нижний мозговой придаток", "питуитарная железа"],
    "гипофизарный": ["гипофизный"],
    "гипофизный": ["гипофизарный"],
    "гипохромия": ["гипохромазия"],
    "гипоцентавр": ["китоврас"],
    "гипоэстезия": ["гипестезия"],
    "гиппокампус": ["гиппокамп", "гидриппус"],
    "гиппокрена": ["иппокрена"],
    "гиппопотам": ["бегемот", "бегемот обыкновенный"],
    "гиппурит": ["рудист"],
    "гипрок": ["гипсокартон", "лист гипсокартонный", "сухая гипсовая штукатурка"],
    "гипроковый": ["гипсокартонный", "гипсокартоновый"],
    "гипсовав": ["гипсовавши"],
    "гипсовавши": ["гипсовав"],
    "гипсокартон": ["лист гипсокартонный", "сухая гипсовая штукатурка", "гипрок"],
    "гипсокартонный": ["гипсокартоновый", "гипроковый"],
    "гипсокартоновый": ["гипсокартонный", "гипроковый"],
    "гипсотермометр": ["баротермометр", "гипсометр", "термобарометр"],
    "гипсохромный сдвиг": ["гипсохромный эффект"],
    "гипсохромный эффект": ["гипсохромный сдвиг"],
    "гипюр": ["гипюровая ткань"],
    "гиргис": ["сиргис", "сюргис", "дон", "северский донец"],
    "гиробус": ["маховичный автобус"],
    "гировертикаль": ["гирогоризонт"],
    "гирогонит": ["оогоний"],
    "гирогоризонт": ["гировертикаль"],
    "гироплан": ["автожир", "жироплан", "гирокоптер", "ротаплан"],
    "гирорулевой": ["авторулевой"],
    "гироскутер": ["гироборд", "гироцикл", "ховерборд"],
    "гиростатика": ["жиростатика"],
    "гироцикл": ["гироскутер"],
    "гироэдр": ["пентагональный икоситетраэдр"],
    "гирудотерапия": ["бделлотерапия"],
    "гистаминовый": ["гистаминный"],
    "гистерология": ["гистерон-протерон", "гистеропротерон", "протистерон"],
    "гистеросальпингография": ["метросальпингография"],
    "гистерэктомия": ["гистероэктомия"],
    "гистиеотида": ["гистиея"],
    "гистия": ["гестия"],
    "гистогенный": ["тканевой"],
    "гистологический": ["микроскопический", "целлюлярный"],
    "гистомоноз": ["тифлогепатит", "энтерогепатит"],
    "гит": ["заезд", "бег", "забег", "пробег"],
    "гитлер": ["огнетушитель"],
    "гитлеровец": ["фашист", "фриц"],
    "гиттия": ["гиттья"],
    "гиттья": ["гиттия"],
    "гифка": ["гифак", "гифчик"],
    "гихон": ["геон", "гихун", "хинном"],
    "гиши": ["адам", "инсан"],
    "гишпанской": ["гишпанский"],
    "гкс": ["глюкокортикостероид"],
    "глабелла": ["надпереносье", "глабель"],
    "глабель": ["глабелла"],
    "глава": ["голова", "вершина", "купол"],
    "глава семьи": ["глава семейства"],
    "главарь": ["руководитель", "вожак", "зачинщик", "босс"],
    "главатар": ["предводител", "вожд", "водач", "войвода", "байрактар", "тартор"],
    "главврач": ["главный врач"],
    "главгерой": ["главный герой", "гг"],
    "главенство": ["верховенство", "первенство", "предводительство", "старшинство", "владычество"],
    "главенствовав": ["главенствовавши"],
    "главенствовавши": ["главенствовав"],
    "главенствовать": ["возглавлять", "доминировать", "господствовать", "руководить", "преобладать"],
    "главк": ["главное управление"],
    "главнейший": ["наиглавнейший"],
    "главнокомандующий": ["главком", "коннетабль", "сераскир", "сердар", "давнокомандующий"],
    "главный": ["основной", "головной", "ведущий", "важнейший", "верховный", "первостепенный", "центральный", "директор", "начальник", "предводитель", "руководитель"],
    "главный бухгалтер": ["главбух"],
    "главный врач": ["главврач"],
    "главный старшина": ["главстаршина"],
    "главоболие": ["глагобол"],
    "главорез": ["палач", "джелатин", "убиец"],
    "главоч": ["глупак", "тъпак", "малоумник", "гламчо"],
    "главреж": ["главный режиссёр"],
    "глагол-связка": ["связка"],
    "глаголав": ["глаголавши"],
    "глаголавши": ["глаголав"],
    "глаголавший": ["высказывавший", "говоривший"],
    "глаголать": ["изрекать", "говорить", "произносить"],
    "глаголив": ["глаголивши"],
    "глаголивши": ["глаголив"],
    "глаголить": ["говорить", "высказывать"],
    "глаголица": ["буквица", "глаголита"],
    "глагольный вид": ["вид глагола", "аспект"],
    "глад": ["голод"],
    "гладив": ["гладивши"],
    "гладивши": ["гладив"],
    "гладильная доска": ["гладилка"],
    "гладиолус": ["шпажник"],
    "гладить": ["утюжить", "поглаживать"],
    "гладить по головке": ["потворствовать", "дрочить по головке"],
    "гладкий": ["плавный", "ровный", "плоский"],
    "гладкокрашеный": ["однотонный"],
    "гладколицый": ["гладколикий"],
    "гладкость": ["зеркальность", "шелковистость", "беспроблемность", "накатанность", "размеренность", "плавность"],
    "гладкошёрстный": ["гладкошёрстый"],
    "гладкошёрстый": ["гладкошёрстный"],
    "гладь": ["зеркало", "мир", "покой", "спокойствие", "благополучие", "благоденствие", "мир да лад", "тишь да гладь", "тишь да гладь да божья благодать", "тишь да крыш"],
    "глажение": ["глаженье", "глажка"],
    "глаженье": ["глажение", "глажка"],
    "глаз": ["бельмо", "буркалы", "глазенапы", "глазенапа", "глазище", "глазёнки", "глазок", "глазоньки", "глазочек", "гляделка", "зенки", "мигалки", "шар", "зеница", "око"],
    "глаз бури": ["глаз циклона", "глаз урагана", "глаз тайфуна", "бычий глаз"],
    "глаз да глаз": ["держать ухо востро"],
    "глаз намётан": ["глаз набит"],
    "глаз урагана": ["глаз циклона", "глаз бури", "глаз тайфуна", "бычий глаз"],
    "глаз циклона": ["глаз урагана", "глаз бури", "глаз тайфуна", "бычий глаз"],
    "глаз-алмаз": ["острый глаз", "зоркий глаз"],
    "глаза": ["очи", "зрение", "глаз", "взгляд", "взор", "зенки", "зеница"],
    "глаза высмотреть": ["глаза проглядеть"],
    "глаза по пять копеек": ["глаза по пять рублей", "глаза по пять крон", "глаза по семь копеек", "шары по семь копеек"],
    "глазастая яичница": ["глазунья", "глазуха"],
    "глазастый": ["большеглазый", "зоркий", "яркий", "броский"],
    "глазев": ["глазевши"],
    "глазевши": ["глазев"],
    "глазенапа": ["глаза", "очи"],
    "глазеть": ["пялиться", "таращиться"],
    "глазив": ["глазивши"],
    "глазивши": ["глазив"],
    "глазировав": ["глазировавши"],
    "глазировавши": ["глазировав"],
    "глазная орбита": ["глазница"],
    "глазник": ["окулист", "офтальмолог"],
    "глазница": ["глазная орбита"],
    "глазное яблоко": ["глаз"],
    "глазной": ["окулист", "офтальмолог"],
    "глазовец": ["глазовчанин"],
    "глазовчанин": ["глазовец"],
    "глазок": ["глазик"],
    "глазунья": ["яичница", "яичница-глазунья", "глазуха", "глазастая яичница"],
    "глазуровав": ["глазуровавши"],
    "глазуровавши": ["глазуровав"],
    "глазчатый": ["пятнистый"],
    "глайдер": ["планёр", "кресло"],
    "гламавщина": ["глупост", "малоумие", "нелепост", "безсмислица", "тъпоумие"],
    "гламур": ["глянец"],
    "гламурив": ["гламуривши"],
    "гламуривши": ["гламурив"],
    "гламурный": ["вычурный", "модный", "роскошный", "яркий", "пёстрый", "блестящий", "великолепный", "показной", "безупречный", "чарующий", "очаровательный"],
    "гландулоцит": ["железистая клетка"],
    "гландулярный": ["железистый"],
    "глас": ["голос", "мнение"],
    "гласив": ["гласивши"],
    "гласивши": ["гласив"],
    "гласить": ["возвещать"],
    "гласный": ["гласный звук"],
    "глауберит": ["соль чудесная"],
    "глауберова соль": ["мирабилит", "сибирская соль", "гуджир", "сернокислый натрий"],
    "глаша": ["глафира"],
    "глашатай": ["провозвестник", "голос", "глас", "рупор"],
    "глебович": ["глебыч"],
    "глевия": ["глефа"],
    "гледка": ["изглед", "пейзаж", "панорама"],
    "глезльо": ["глезен"],
    "глек": ["глечик"],
    "глен": ["жабуняк"],
    "глендонит": ["беломорская рогулька"],
    "глетчер": ["ледник"],
    "глефа": ["глевия", "нагината"],
    "глеч": ["глазура", "блясък", "гланц"],
    "глечик": ["горшок", "кринка", "крынка", "кувшин", "кувшинчик"],
    "глиальный": ["нейроглиальный"],
    "глиба": ["брила"],
    "глибочина": ["глибина"],
    "гликирование": ["неферментативное гликозилирование"],
    "гликогенез": ["гликогения", "гликогеногенез"],
    "гликогения": ["гликогенез", "гликогеногенез"],
    "гликогеногенез": ["гликогенез"],
    "гликозаминогликан": ["мукополисахарид"],
    "гликозидаза": ["гликозил-гидролаза"],
    "гликозил-гидролаза": ["гликозидаза"],
    "гликозурия": ["гликурия", "глюкозурия"],
    "гликолевая кислота": ["гидроксиуксусная кислота", "гидроксиэтановая кислота"],
    "гликолиз": ["фосфотриозный путь", "путь эмбдена-мейергофа-парнаса"],
    "гликолипид": ["гликосфинголипид"],
    "гликоль": ["диол"],
    "гликонеогенез": ["гликонеогения"],
    "гликопротеид": ["гликопротеин"],
    "гликопротеин": ["гликопротеид"],
    "гликурия": ["гликозурия"],
    "глинизировав": ["глинизировавши"],
    "глинизировавши": ["глинизировав"],
    "глиний": ["алюминий"],
    "глинистий": ["глинястий"],
    "глинозём": ["оксид алюминия"],
    "глиссада": ["планирование"],
    "глиссандо": ["скольжение", "рулада"],
    "глиссировав": ["глиссировавши"],
    "глиссировавши": ["глиссировав"],
    "глист": ["глиста", "гельминт"],
    "глиста": ["глист", "гельминт", "нутряк", "дождевой червь", "навозный червь"],
    "глиф": ["желобок"],
    "глицерин": ["глицерол", "пропантриол"],
    "глицерол": ["глицерин"],
    "глицин": ["аминоэтановая кислота", "аминоуксусная кислота", "гликокол", "глицин-фото", "пара-оксифениламиноуксусная кислота"],
    "глициния": ["вистерия"],
    "глицирризин": ["гликозид глицирризиновая кислота"],
    "глия": ["нейроглия"],
    "глобализация": ["интернационализация", "глобальность"],
    "глобализировав": ["глобализировавши"],
    "глобализировавши": ["глобализировав"],
    "глобализировать": ["глобализовать"],
    "глобализовав": ["глобализовавши"],
    "глобализовавши": ["глобализовав"],
    "глобальность": ["всеобъемлемость", "широкомасштабность", "всемирность", "повсеместность"],
    "глобальный": ["универсальный", "мировой", "общедоступный"],
    "гловелетта": ["митенка", "полуперчатка"],
    "глог": ["декоративная свидина", "слепокур", "слепокурник", "курослеп", "курослепник"],
    "глодав": ["глодавши"],
    "глодавши": ["глодав"],
    "глодать": ["грызть", "мучить", "терзать"],
    "глокеншпиль": ["колокольчики"],
    "гломерул-": ["гломеруло-"],
    "гломерулярный пучок": ["гломерула"],
    "глор": ["глорик", "глорихантер"],
    "глорификация": ["восхваление", "возвеличивание", "славление", "прославление"],
    "глорихантер": ["глор", "глорик"],
    "глосса": ["черноморская камбала"],
    "глоссарий": ["глоссатор"],
    "глоссировав": ["глоссировавши"],
    "глоссировавши": ["глоссировав"],
    "глоссировать": ["толковать", "растолковывать", "комментировать"],
    "глоссоним": ["глоттоним", "лингвоним"],
    "глоссофобия": ["логофобия"],
    "глот": ["глотание", "глотень", "глотенек", "глоточек", "глотанье", "глоток"],
    "глотав": ["глотавши"],
    "глотавши": ["глотав"],
    "глотанье": ["глотание"],
    "глотать": ["заглатывать", "проглатывать", "делать глотательное движение", "поглощать", "пожирать"],
    "глотка": ["горло"],
    "глотнув": ["глотнувши"],
    "глотнувши": ["глотнув"],
    "глоточек": ["глоток"],
    "глоточный": ["фарингеальный"],
    "глоттализация": ["ларингализация"],
    "глоттализованный": ["гортанный", "ларингальный"],
    "глоттогенез": ["глоттогония"],
    "глоттогония": ["глоттогенез"],
    "глоттология": ["глоссология"],
    "глоттохронология": ["лексикостатистика"],
    "глохнув": ["глохнувши"],
    "глохнувши": ["глохнув"],
    "глубина резкости": ["глубина резко изображаемого пространства", "грип"],
    "глубинка": ["глухомань"],
    "глубинное государство": ["государство в государстве", "параллельное государство"],
    "глубинный народ": ["простонародье", "простолюдин"],
    "глубокая свёрточная нейронная сеть": ["гснс"],
    "глубокомысленный": ["серьёзный", "сосредоточенный"],
    "глубокость": ["глубина"],
    "глубокоуважаемый": ["уважаемый", "многоуважаемый"],
    "глубоченный": ["преглубокий", "приглубый", "бездонный"],
    "глубь": ["глубина"],
    "глузг": ["лузга"],
    "глузд": ["ум", "рассудок"],
    "глум": ["глумление", "насмешка"],
    "глумец": ["глумотворец"],
    "глумив": ["глумивши"],
    "глумивши": ["глумив"],
    "глумить": ["глумиться", "насмехаться", "потешаться", "издеваться"],
    "глумление": ["глум", "насмешка", "издевательство", "измывательство"],
    "глумленье": ["глумление"],
    "глумливый": ["насмешливый", "издевательский"],
    "глумной": ["глумный", "бестолковый", "смешливый", "насмешливый", "забавный"],
    "глумёж": ["глум", "глумление", "глумленье", "ехидство", "издевательство", "насмешка", "стёб", "стебалово", "перебранка"],
    "глупев": ["глупевши"],
    "глупевши": ["глупев"],
    "глупеть": ["тупеть"],
    "глупец": ["дурак", "болван", "дубина"],
    "глупив": ["глупивши"],
    "глупивши": ["глупив"],
    "глупить": ["дурить", "барахлить", "тупить", "куролесить", "глуповать"],
    "глупо": ["безумно", "опрометчиво", "нелепо"],
    "глуповатость": ["придурковатость", "глупость"],
    "глуповать": ["глупить"],
    "глупость": ["тупость", "идиотизм", "слабоумие", "имбецильность", "дебилизм", "бредовость", "бред", "чушь", "чепуха", "бессмыслица", "ерунда", "алогичность"],
    "глупота": ["глупость"],
    "глупый": ["тупой", "неумный", "неразумный", "безумный", "слабоумный", "дурашный", "дурак"],
    "глупыш": ["глупый", "глупец"],
    "глупышка": ["глупыш", "дурачок"],
    "глупёхонький": ["глупёшенький"],
    "глупёшенький": ["глупёхонький"],
    "глутамат": ["глутамат натрия"],
    "глутаровая кислота": ["пентандиовая кислота"],
    "глутаровый": ["фенол"],
    "глутатион": ["глютатион"],
    "глухарка": ["копалуха"],
    "глухарь": ["мошник", "моховик"],
    "глухая пора": ["безвременье", "глухое время", "застой", "затишье"],
    "глухо": ["негромко", "приглушённо", "тихо", "равнодушно", "безразлично", "смутно", "тупо", "наглухо", "плотно", "непроницаемо", "густо"],
    "глухой": ["неслышащий", "глухарь", "глухая тетеря", "нечуткий", "невосприимчивый", "неотзывчивый", "безразличный", "индифферентный", "непробиваемый", "приглушённый", "тихий", "невнятный", "смутный", "тупой", "безлюдный"],
    "глухой телефон": ["сломанный телефон", "испорченный телефон"],
    "глухомань": ["глушь", "дыра", "захолустье", "медвежий угол", "пердь", "тьмутаракань"],
    "глухота": ["глухость", "бесчувственность", "невнимание", "равнодушие"],
    "глушив": ["глушивши"],
    "глушивши": ["глушив"],
    "глушитель": ["глушак"],
    "глушить": ["оглушать", "заглушать", "подавлять", "выключать", "обесточивать", "останавливать"],
    "глушман": ["глухар"],
    "глушь": ["чаща", "чащоба", "дыра", "захолустье", "задворки", "медвежий угол", "пердь", "тьмутаракань", "чёртовы кулички", "провинция", "периферия"],
    "глъч": ["глъчка", "шум", "врява", "олелия", "гюрултия", "шепот"],
    "глъчка": ["глъч", "шум", "врява", "олелия", "гюрултия"],
    "глыбистый": ["тяжёлый", "грузный"],
    "глыбко": ["глубоко", "глубко"],
    "глыбовидный": ["глыбообразный"],
    "глыбообразный": ["глыбовидный"],
    "глэм": ["глэм-рок"],
    "глэм-рок": ["глэм"],
    "глюк": ["галлюцинация", "галюн", "морок", "баг"],
    "глюкав": ["глюкавши"],
    "глюкавши": ["глюкав"],
    "глюкоза": ["декстроза", "виноградный сахар"],
    "глюкозаминилмурамилдипептид": ["ликопид"],
    "глюкозно-галактозный": ["глюкозо-галактозный"],
    "глюкокортикоид": ["глюкокортикостероид", "гликокортикоид", "гкс"],
    "глюкоманнан": ["конжакоманнан", "коньякоманнан", "коннякоманнан"],
    "глютаминовый": ["глутаминовый"],
    "глютатион": ["глутатион"],
    "глютеальный": ["ягодичный"],
    "глютен": ["клейковина"],
    "глюцит": ["сорбит"],
    "глючив": ["глючивши"],
    "глючивши": ["глючив"],
    "глючить": ["галлюцинировать"],
    "глядев": ["глядевши"],
    "глядевши": ["глядев"],
    "глядеть": ["смотреть", "глазеть", "пялиться", "зырить"],
    "глядеть в оба": ["быть на чеку"],
    "глядеть сквозь пальцы": ["смотреть сквозь пальцы"],
    "глядывав": ["глядывавши"],
    "глядывавши": ["глядывав"],
    "глядь": ["оказываться"],
    "глядючи": ["глядя"],
    "глядящий": ["смотрящий"],
    "глянец": ["блеск"],
    "глянув": ["глянувши"],
    "глянувши": ["глянув"],
    "глянуть": ["посмотреть", "поглядеть", "бросить взгляд", "обратить взгляд", "выглянуть", "появиться", "показаться", "проглянуть"],
    "глянцевав": ["глянцевавши"],
    "глянцевавши": ["глянцевав"],
    "глянцевание": ["лощение"],
    "глянцеватель": ["фотоглянцеватель", "электроглянцеватель", "электрофотоглянцеватель"],
    "глянцевев": ["глянцевевши"],
    "глянцевевши": ["глянцевев"],
    "глянцевитый": ["глянцеватый"],
    "глянцевый": ["блестящий", "лоснящийся", "светский", "развлекательный", "гламурный"],
    "глянцовав": ["глянцовавши"],
    "глянцовавши": ["глянцовав"],
    "гляциал": ["ледниковая эпоха"],
    "гляциальный": ["ледовый"],
    "гляциация": ["оледенение"],
    "гляциоэра": ["криоэра"],
    "глёг": ["глинтвейн"],
    "гм": ["хм", "кхм"],
    "гмм": ["хм", "кхм"],
    "гмо": ["генетически модифицированный организм"],
    "гмыкав": ["гмыкавши"],
    "гмыкавши": ["гмыкав"],
    "гмыкать": ["гымкать", "гумкать"],
    "гмыкнув": ["гмыкнувши"],
    "гмыкнувши": ["гмыкнув"],
    "гнав": ["гнавши"],
    "гнавши": ["гнав"],
    "гнать": ["торопить", "понукать", "выдумывать", "врать", "лгать", "нести", "обманывать", "фантазировать", "городить", "молоть", "охотиться", "преследовать", "притеснять", "упрекать", "обвинять"],
    "гнать в три шеи": ["гнать поганой метлой", "гнать ссаными тряпками"],
    "гнать волну": ["кипишевать"],
    "гнать поганой метлой": ["гнать в три шеи", "гнать ссаными тряпками"],
    "гнать пургу": ["нести пургу", "обманывать", "врать", "молоть", "городить", "втирать", "гнать тюльку", "гнать туфту", "нагонять", "наговаривать", "привирать", "плести небылицы", "нести чушь", "гнать порожняк"],
    "гнать ссаными тряпками": ["гнать поганой метлой", "гнать в три шеи"],
    "гнаться": ["преследовать"],
    "гнев": ["ярость", "бешенство", "негодование"],
    "гневав": ["гневавши"],
    "гневавши": ["гневав"],
    "гневать": ["гневить", "злить", "сердить"],
    "гневаться": ["сердиться"],
    "гневив": ["гневивши"],
    "гневивши": ["гневив"],
    "гневить": ["гневать", "сердить", "злить", "бесить", "разъярять"],
    "гневливый": ["вспыльчивый", "раздражительный", "гневный"],
    "гневный": ["разгневанный", "рассерженный"],
    "гнедко": ["гнедок"],
    "гнедой": ["бурка"],
    "гнедок": ["гнедко"],
    "гнездилище": ["обиталище"],
    "гнездо": ["логово", "берлога", "дом", "жилище", "пристанище", "рассадник", "разъём", "розетка", "слот", "ячейка"],
    "гнездовав": ["гнездовавши"],
    "гнездовавши": ["гнездовав"],
    "гнездованье": ["гнездование"],
    "гнездовка": ["гнездование", "гнездованье"],
    "гнездовье": ["гнездовка", "логово"],
    "гнейс": ["слоистый гранит"],
    "гнести": ["терзать", "угнетать", "удручать", "пригибать"],
    "гнетущий": ["угнетающий", "тягостный"],
    "гнив": ["гнивши"],
    "гнивши": ["гнив"],
    "гнида": ["паскуда", "мерзавец"],
    "гниение": ["диафтора", "сепсис", "декаданс"],
    "гниенье": ["гниение"],
    "гнииохт": ["гснииохт", "госнииохт"],
    "гнилая горячка": ["тиф"],
    "гнилой": ["испорченный", "сгнивший", "протухший", "тухлый"],
    "гнилокровие": ["сепсис", "гнилокровье"],
    "гниль": ["тухлятина"],
    "гнильё": ["гниль"],
    "гнисти": ["гнити"],
    "гнобив": ["гнобивши"],
    "гнобивши": ["гнобив"],
    "гнобить": ["изводить", "угнетать", "третировать", "оскорблять", "унижать", "придираться", "подавлять"],
    "гноевой": ["гнойный"],
    "гноекровие": ["пиемия"],
    "гноив": ["гноивши"],
    "гноивши": ["гноив"],
    "гноище": ["помойка"],
    "гной": ["ихор", "сукровица", "выпот"],
    "гнойник": ["абсцесс", "нарыв"],
    "гнойный": ["абсцессный"],
    "гном": ["дворф", "кобольд", "пигмей", "гоблин", "карлик"],
    "гномон": ["солнечные часы"],
    "гносеологический": ["познавательный"],
    "гносеология": ["эпистемология"],
    "гностик": ["варвелиот", "борборит", "ворвориан"],
    "гнотобиология": ["гнотобиотика"],
    "гнотобионт": ["гнотобиот"],
    "гнотобиот": ["гнотобионт"],
    "гну": ["антилопа гну", "баранки гну"],
    "гнув": ["гнувши"],
    "гнувши": ["гнув"],
    "гнус": ["мошка", "мошкара", "гад", "гнида"],
    "гнусавив": ["гнусавивши"],
    "гнусавивши": ["гнусавив"],
    "гнусавый": ["гундосый"],
    "гнусив": ["гнусивши"],
    "гнусивши": ["гнусив"],
    "гнусно": ["гадко", "мерзко", "погано", "омерзительно", "отвратительно"],
    "гнусность": ["мерзость"],
    "гнусь": ["мерзость", "гнусность", "мерзавец"],
    "гнуть": ["сгибать", "искривлять", "изгибать", "загибать", "склонять", "наклонять", "настаивать"],
    "гнуть мат": ["гнуть маты"],
    "гнуть маты": ["гнуть мат"],
    "гнуться": ["искривляться", "изгибаться", "наклоняться"],
    "гнучий": ["гнучкий"],
    "гнучкий": ["гнучий"],
    "гнушаться": ["брезгать", "брезговать", "чуждаться"],
    "гнущийся": ["сгибаемый", "сгибающийся", "гибкий"],
    "гнюс": ["электрический скат", "торпедо"],
    "гнёт": ["груз", "пресс", "притеснение", "угнетение", "подчинение"],
    "го": ["гражданская оборона", "городской округ"],
    "гобелен": ["шпалера"],
    "гобеленовый": ["гобелиновый"],
    "гобза": ["изобилие", "богатство"],
    "гобзина": ["изобилие", "богатство"],
    "гобзование": ["изобилие", "богатство"],
    "гобзовать": ["изобиловать"],
    "гобина": ["изобилие", "богатство"],
    "гоблин": ["бык"],
    "гобой": ["гобоист"],
    "гобрий": ["губару"],
    "говаривав": ["говаривавши"],
    "говаривавши": ["говаривав"],
    "говев": ["говевши"],
    "говевши": ["говев"],
    "говедар": ["пастир"],
    "говейный": ["почитаемый", "боготворимый"],
    "говельщик": ["постник"],
    "говение": ["говенье"],
    "говения": ["ховения", "гардения", "понцирус"],
    "говеть": ["гавливать", "поститься", "постничать", "благоговеть", "уважать", "чтить", "почитать"],
    "говна пирога": ["накося выкуси", "говна на лопате", "залупу за воротник", "пососи мой шланг", "шиш с маслом"],
    "говнарь": ["говнорокер"],
    "говнина": ["кал", "дрянь", "срань"],
    "говнистость": ["злонравие", "вредность", "гадкость"],
    "говнистый": ["противный", "отвратительный", "скверный", "вредный", "гадкий", "злонравный"],
    "говнительство": ["вредительство", "правительство"],
    "говнище": ["грязища"],
    "говно": ["героин"],
    "говно вопрос": ["нет проблем", "нет вопросов", "не вопрос", "не проблема", "конечно", "обязательно"],
    "говно с дымом": ["с новым годом"],
    "говновоз": ["говновозка", "ассенизационная машина", "ассенизационный автомобиль", "ассенизатор"],
    "говноед": ["говноедина", "говноедище", "черпак говна"],
    "говнокачка": ["говнососка"],
    "говномес": ["педик", "жополюб"],
    "говнометатель": ["пропагандон"],
    "говнопост": ["щитпост"],
    "говнососка": ["говнокачка"],
    "говнохлёб": ["говноед"],
    "говночист": ["ассенизатор", "санитар", "уборщица"],
    "говны месить": ["месить говны"],
    "говнюк": ["засранец", "сволочь", "паскуда"],
    "говняв": ["говнявши"],
    "говнявши": ["говняв"],
    "говняный": ["дурной", "ужасный", "некачественный", "говённый"],
    "говор": ["диалект", "прононс", "говоря"],
    "говорив": ["говоривши"],
    "говоривши": ["говорив"],
    "говоритель": ["оратор"],
    "говорить": ["разговаривать", "сообщать", "подсказывать", "предсказывать", "беседовать", "переговариваться", "поговаривать", "молва ходит", "сплетничать", "судачить", "трепаться", "славить", "высказывать", "высказываться", "обсуждать"],
    "говорить обиняками": ["ходить вокруг да около"],
    "говорить правду": ["признаваться"],
    "говориться": ["произноситься"],
    "говорливость": ["разговорчивость", "болтливость", "словоохотность"],
    "говорливый": ["разговорчивый", "словоохотливый"],
    "говорок": ["говор", "наречие", "диалект", "многоголосие", "разноголосица", "говорун", "краснобай"],
    "говорун": ["балабол", "балаболка", "болтун"],
    "говоря": ["говор", "разговор", "беседа", "сплетни", "молва"],
    "говорят вам": ["говорят тебе"],
    "говорят тебе": ["говорят вам"],
    "говорённый": ["сказанный"],
    "говённый": ["дрянной", "хреновый", "отвратительный", "гадкий", "паршивый", "испорченный"],
    "гогон": ["гогор"],
    "гогот": ["ржание", "хохот"],
    "гоготав": ["гоготавши"],
    "гоготавши": ["гоготав"],
    "гоготание": ["гогот", "гоготанье"],
    "гоготнув": ["гоготнувши"],
    "гоготнувши": ["гоготнув"],
    "гогьари": ["гагьо", "мугеру", "гампар"],
    "годегетика": ["одегетика"],
    "годеник": ["избраник"],
    "годив": ["годивши"],
    "годивши": ["годив"],
    "година": ["год"],
    "годиться": ["подходить", "уместно"],
    "годичное кольцо": ["годовое кольцо"],
    "годичный": ["годовой", "одногодичный", "ежегодный"],
    "годмише": ["дилдо", "фаллоимитатор", "самотык", "дилдак"],
    "годный": ["подходящий", "пригодный", "гожий", "хороший", "достойный", "устраивающий", "добротный", "приличный"],
    "годовав": ["годовавши"],
    "годовавши": ["годовав"],
    "годовалый": ["одногодовалый"],
    "годовалыш": ["годовик"],
    "годовое кольцо": ["годичное кольцо"],
    "годовой": ["годичный", "ежегодный", "годовалый"],
    "годовщинка": ["годовщина"],
    "годок": ["год", "годик", "ровесник", "сверстник"],
    "годом да родом": ["годом-мимоходом", "годом-родом"],
    "годом-родом": ["изредка", "по случаю"],
    "гоже": ["гожо", "гожно", "годяще", "годяво", "годно", "годня", "гожатко", "годяй"],
    "гожий": ["годный", "пригодный"],
    "гоз": ["донгар"],
    "гой": ["нееврей"],
    "гойда": ["ура"],
    "гокча": ["севан"],
    "гол": ["ворота", "город", "очко", "попадание", "голь"],
    "гол как сокол": ["беден как церковная мышь"],
    "голбец": ["подполье", "подвал"],
    "голготав": ["голготавши"],
    "голготавши": ["голготав"],
    "голгофа": ["крест"],
    "голеадор": ["бомбардир", "забойщик"],
    "големец": ["важен", "началник", "заповедник", "властник"],
    "голенастый": ["длинноногий", "ногастый"],
    "голень": ["берцо", "голяшка", "бёрце"],
    "голец": ["обыкновенный голец", "усатый голец", "оголец", "авдюшка"],
    "голив": ["голивши"],
    "голивши": ["голив"],
    "голимый": ["гольный", "неразбавленный", "чистый", "сплошной", "полный", "галимый", "гадкий", "мерзкий", "омерзительный", "отвратительный", "паршивый", "плохой", "никудышный", "дрянной", "беспросветный"],
    "голица": ["верхонка"],
    "голкипер": ["вратарь", "воротчик"],
    "голкиперский": ["вратарский"],
    "голландер": ["ролл"],
    "голландец": ["нидерландец"],
    "голландия": ["нидерланды"],
    "голова вертячая": ["сорванец", "удалец", "сорвиголов", "сорви-голова", "оторвиголова", "оторви-голова", "сломиголов", "сломи-голова", "буйная головушка", "шальной", "шалёный", "шалый", "шальная голова", "шальная головушка", "бешенец"],
    "голова кружится": ["потерять почву под ногами", "зарваться", "зазнаться"],
    "голова пока цела": ["как сажа бела", "дела у прокурора"],
    "голова садовая": ["дурачина", "лопух"],
    "голован": ["умник", "умница"],
    "голованив": ["голованивши"],
    "голованивши": ["голованив"],
    "головастая морская черепаха": ["логгерхед", "головастая черепаха", "каретта"],
    "головастик": ["голова"],
    "головастый": ["большеголовый", "башковитый", "мозговитый"],
    "головка от руля": ["головка от часов", "головка от хуя"],
    "головка от хуя": ["головка от руля", "головка от часов"],
    "головка полового члена": ["головка", "залупа", "шляпа"],
    "головку положить": ["положить голову"],
    "головная боль": ["цефалгия", "геморрой", "гемор"],
    "головничав": ["головничавши"],
    "головничавши": ["головничав"],
    "головной": ["передний", "ведущий", "руководящий", "главный"],
    "головной мозг": ["мозг"],
    "головня": ["головешка", "спорынья", "изгарина"],
    "головняк": ["головная боль", "проблема"],
    "головогрудь": ["просома", "цефалоторакс", "кефалоторакс"],
    "головокруженье": ["головокружение"],
    "головокружительный": ["умопомрачительный", "захватывающий", "необыкновенный", "восхитительный", "дивный", "изумляющий", "потрясающий", "чрезвычайный", "ошеломительный", "ошеломляющий"],
    "головоломка": ["загадка"],
    "головомойка": ["выволочка", "нагоняй", "нахлобучка", "разнос", "трёпка"],
    "головорез": ["башибузук", "сорвиголова"],
    "головотяп": ["тяп-ляпщик", "ротозей", "упущенец"],
    "головотяпство": ["бесхозяйственность", "безответственность", "бестолковость", "бестолковщина", "халатность", "нерадивость"],
    "головотяпствовав": ["головотяпствовавши"],
    "головотяпствовавши": ["головотяпствовав"],
    "головствовав": ["головствовавши"],
    "головствовавши": ["головствовав"],
    "головщина": ["головничество"],
    "гологамия": ["хологамия"],
    "голографировав": ["голографировавши"],
    "голографировавши": ["голографировав"],
    "голод": ["аппетит", "голодание", "недоедание", "нехватка"],
    "голодав": ["голодавши"],
    "голодавши": ["голодав"],
    "голоданье": ["голодание"],
    "голодать": ["положить зубы на полку"],
    "голодная пизда": ["пизда пилоткой"],
    "голодный": ["несытый", "недоедающий"],
    "голодовав": ["голодовавши"],
    "голодовавши": ["голодовав"],
    "голодовка": ["голод"],
    "голодомор": ["голод"],
    "голодранец": ["оборванец", "босяк", "голоштанник", "бедняк", "нищеброд"],
    "голодранский": ["босяческий", "босяцкий"],
    "голодранство": ["босячество"],
    "голодуха": ["голод"],
    "голожопый": ["голозадый", "голопопый"],
    "голокриновый": ["голокринный"],
    "гололедица": ["гололёдка", "гололедь", "гололёд"],
    "гололёд": ["гололедица"],
    "голомозий": ["лисий", "голений", "бритий", "бритоголовий", "гирявий"],
    "голоморфизм": ["голоморфность"],
    "голомя": ["открытое море"],
    "голосеменной": ["голосемянный"],
    "голосемянный": ["голосеменной"],
    "голосив": ["голосивши"],
    "голосивши": ["голосив"],
    "голосина": ["голосище"],
    "голосить": ["вопить", "горланить"],
    "голосишко": ["голосок"],
    "голосище": ["голосина"],
    "голословность": ["бездоказательность"],
    "голословный": ["бездоказательный"],
    "голоснув": ["голоснувши"],
    "голоснувши": ["голоснув"],
    "голоснуть": ["проголосовать"],
    "голосовав": ["голосовавши"],
    "голосовавши": ["голосовав"],
    "голосование": ["вотирование", "баллотировка"],
    "голосованье": ["голосование"],
    "голосовать": ["избирать"],
    "голосовое": ["голосовое сообщение", "голосовуха"],
    "голосовое сообщение": ["голосовая почта", "голосовуха"],
    "голосовуха": ["голосовое сообщение"],
    "голосок": ["голосочек", "голосишко"],
    "голосьё": ["голосишко", "голосок", "голосочек", "голосище", "голосяра", "голосина"],
    "голота": ["босота"],
    "голотурия": ["морская кубышка", "морской огурец"],
    "голофермент": ["холофермент", "голоэнзим"],
    "голофразис": ["холофразис", "голофрасис", "голофраза"],
    "голохуевка": ["дефицит", "недостаток"],
    "голошенье": ["голошение"],
    "голоштанник": ["беспорточник", "бесштанник", "голодранец", "нищий", "оборванец", "санкюлот"],
    "голоэдрический": ["пинакоидальный", "полногранный"],
    "голоэнзим": ["голофермент", "холофермент"],
    "голуба": ["голубок", "голубка"],
    "голубая": ["ауксине"],
    "голубая кровь": ["белая кость"],
    "голубев": ["голубевши"],
    "голубевши": ["голубев"],
    "голубее": ["голубей"],
    "голубей": ["голубее"],
    "голубив": ["голубивши"],
    "голубивши": ["голубив"],
    "голубий": ["блакитний"],
    "голубика": ["голубика обыкновенная", "гонобобель", "еланка", "водопьянка", "голубец", "голубица", "гонобоб", "гонобой", "гоноболь", "дураха", "дурника", "дурниха", "дурница", "пьяная ягода", "пьяника"],
    "голубить": ["ласкать", "нежить", "лелеять", "баловать"],
    "голубовато-белый": ["изголуба-белый"],
    "голубоглазый": ["голубоокий"],
    "голубое золото": ["вода"],
    "голубое топливо": ["природный газ"],
    "голубой": ["небесный", "небесно-голубой", "небесноголубой", "светло-синий", "светлосиний", "бледно-синий", "цвета ясного неба", "васильковый", "блакитный", "лазоревый", "лазурный", "лазурно-голубой", "лазуревый", "аквамариновый", "цвета аквамарина"],
    "голубой берет": ["десантник", "миротворец", "голубые каски"],
    "голубок": ["голубь", "дроля"],
    "голубоокий": ["голубоглазый"],
    "голубочка": ["голубка"],
    "голубушка": ["голубка", "самка голубя"],
    "голубчик": ["голуба"],
    "голубые фишки": ["блю-чипс"],
    "голубь": ["горлица", "голубчик", "голубок", "голубочек", "голубь сизокрылый"],
    "голубятня": ["голубник", "голубница"],
    "голштин": ["голштино-фризский", "порода"],
    "голштиния": ["гольштейн"],
    "голштинский": ["гольштейнский"],
    "голый": ["нагой", "открытый", "чистый", "гольный", "голимый", "бедный", "убогий"],
    "голытьба": ["беднота", "рвань", "голодранец", "голь", "босота", "бедняк", "неимущие"],
    "голыш": ["голяк", "телеш", "голышка", "пупс", "оголыш", "бесштанник"],
    "голышка": ["голыш"],
    "голышом": ["нагишом", "ню"],
    "гольд": ["нанаец"],
    "гольный": ["голимый"],
    "гольтепа": ["беднота", "голытьба"],
    "гольф": ["водолазка", "бадлон", "битловка"],
    "гольф-площадка": ["гольф-поле"],
    "гольф-поле": ["гольф-площадка"],
    "гольфстрим": ["гольфштрем"],
    "гольштейнский": ["голштинский"],
    "гольё": ["шкура"],
    "голяк": ["голыш"],
    "голяком": ["голышом"],
    "гомарист": ["контраремонстрант"],
    "гомей": ["спартиат"],
    "гомейса": ["бета малого пса"],
    "гомелец": ["гомельчанин"],
    "гомельчанин": ["гомелец"],
    "гомеоморфизм": ["биекция"],
    "гомеостаз": ["авторегуляция"],
    "гомер": ["тормыш"],
    "гомерически": ["гомерично"],
    "гомерический": ["гомеровский"],
    "гомеровский": ["гомерический"],
    "гоминид": ["гоминида"],
    "гоминида": ["гоминид"],
    "гоминиум": ["оммаж"],
    "гомицид": ["человекоубийство"],
    "гоммоз": ["гуммоз", "камедетечение"],
    "гомо сапиенс": ["человек разумный", "хомо сапиенс", "сапиенс", "невежа", "тупица"],
    "гомо советикус": ["хомо советикус", "совок"],
    "гомо-": ["омо-", "одно-"],
    "гомогенизация": ["гомогенизирование"],
    "гомогенизировав": ["гомогенизировавши"],
    "гомогенизировавши": ["гомогенизировав"],
    "гомогенизировать": ["однообразить"],
    "гомогенизовав": ["гомогенизовавши"],
    "гомогенизовавши": ["гомогенизовав"],
    "гомогенизовать": ["гомогенизировать"],
    "гомогенная система": ["однородная система"],
    "гомогенность": ["однородность"],
    "гомогенный": ["однородный"],
    "гомодетный": ["гетеродетный"],
    "гомозив": ["гомозивши"],
    "гомозивши": ["гомозив"],
    "гомозиготизировав": ["гомозиготизировавши"],
    "гомозиготизировавши": ["гомозиготизировав"],
    "гомозить": ["гомозиться", "возиться", "копошиться", "возюкаться"],
    "гомойотермный": ["теплокровный"],
    "гомолатеральный": ["изолатеральный", "ипсилатеральный"],
    "гомон": ["гвалт", "гам"],
    "гомонив": ["гомонивши"],
    "гомонивши": ["гомонив"],
    "гомонить": ["громыхать", "грохотать", "шуметь", "вопить", "галдеть", "голосить", "стонать"],
    "гоморомантичность": ["биромантичность"],
    "гомосексуалдуулук": ["биржыныстуулук"],
    "гомосексуализм": ["гомосексуальность", "уранизм", "лгбт", "элгебетизм"],
    "гомосексуалистка": ["гомосексуалка", "лесбиянка"],
    "гомосексуалка": ["гомосексуалистка", "лесбиянка"],
    "гомосексуальность": ["гомосексуализм"],
    "гомосечество": ["гомосексуализм", "гомосексуальность"],
    "гомосфера": ["турбопауза", "гетеросфера"],
    "гомосятина": ["гомосексуализм"],
    "гомофоб": ["гомоненавистник"],
    "гомохалинный": ["гомогалинный"],
    "гомоэпитаксия": ["автоэпитаксия"],
    "гомукхасана": ["поза коровы"],
    "гомункул": ["гомункулус"],
    "гомункулус": ["гомункул"],
    "гон": ["ток", "гонево", "враньё", "брехня", "ложь"],
    "гонадолиберин": ["гонадорелин", "люлиберин"],
    "гондвана": ["гондваналандия"],
    "гондваналандия": ["гондвана"],
    "гондола": ["кабина", "вагон"],
    "гондонистость": ["вредность", "занудливость", "говнистость", "злоебучесть"],
    "гондонистый": ["говнистый", "злоебучий"],
    "гондонище": ["гондон", "мудила", "мудло"],
    "гондурас": ["республика гондурас"],
    "гонение": ["гоненье"],
    "гонец": ["нарочный", "курьер", "посланец"],
    "гонець": ["посланець"],
    "гонив": ["гонивши"],
    "гонивши": ["гонив"],
    "гониолинза": ["гониоскоп"],
    "гонионема": ["медуза-крестовик", "медуза-крестовичок"],
    "гониоскоп": ["гониолинза"],
    "гонитель": ["преследователь", "притеснитель"],
    "гонительница": ["преследовательница", "притеснительница"],
    "гонка": ["спешка", "суета", "автосимулятор", "гоночка", "состояние гонки", "нагоняй"],
    "гонка на лафетах": ["пятилетка пышных похорон"],
    "гонконг": ["сянган"],
    "гонобобель": ["голубика", "водопьянка", "голубец", "голубица", "гонобоб", "гонобой", "гоноболь", "дураха", "дурника", "дурниха", "дурница", "пьяная ягода", "пьяника", "пьяничка", "пьяница"],
    "гоноболь": ["голубика", "гонобобель", "дурника", "пьяника"],
    "гонококк": ["диплококк"],
    "гонококконосительство": ["латентная гонорея"],
    "гонор": ["достоинство", "гордость", "честь", "самолюбие", "высокомерие", "заносчивость", "спесь"],
    "гонорар": ["гонорарий", "гонорариум"],
    "гонорар успеха": ["условное вознаграждение адвоката"],
    "гонорея": ["триппер", "гоноррея", "резачка"],
    "гоношив": ["гоношивши"],
    "гоношивши": ["гоношив"],
    "гоношить": ["суетиться", "копить", "припасать"],
    "гоношиться": ["возиться", "хлопотать", "суетиться", "хорохориться", "храбриться", "ершиться", "задираться", "упрямиться"],
    "гонт": ["дранка", "шиндель", "дрон"],
    "гончар": ["горшечник", "горшеня", "глинник", "глинчар", "скудельник"],
    "гончарничав": ["гончарничавши"],
    "гончарничавши": ["гончарничав"],
    "гончарство": ["керамика"],
    "гоняв": ["гонявши"],
    "гонявши": ["гоняв"],
    "гонять": ["встречаться", "мутить"],
    "гоп": ["бац"],
    "гоп-стоп": ["грабёж"],
    "гопа": ["гопник", "гопота", "шпана"],
    "гопав": ["гопавши"],
    "гопавши": ["гопав"],
    "гопкинс": ["хопкинс"],
    "гопкомпания": ["ватага", "кодла", "шайка"],
    "гопля": ["опля"],
    "гопник": ["гоп", "гопарь", "гопстопник", "титушка", "шпанёнок", "шпана", "урла", "гопота", "гэшник", "бомж", "босяк", "бродяга", "нищеброд", "нищий", "побирушка"],
    "гопницкий": ["гопнический"],
    "гопнический": ["гопницкий"],
    "гопнув": ["гопнувши"],
    "гопнувши": ["гопнув"],
    "гопота": ["гопотень", "шпана", "хулиганьё"],
    "гопурам": ["гопура"],
    "гора": ["жора", "ора"],
    "горав": ["горавши"],
    "горавши": ["горав"],
    "гораживав": ["гораживавши"],
    "гораживавши": ["гораживав"],
    "горазд": ["способен", "ловок", "мастак", "смел", "брав"],
    "гораздо": ["намного", "значительно", "существенно"],
    "гораздый": ["искусный", "способный", "ловкий", "знающий", "опытный"],
    "горани": ["гурани", "хеврамани", "хеврами"],
    "горб": ["кифоз", "хребет", "бугор", "зазула", "зазуловина"],
    "горбатев": ["горбатевши"],
    "горбатевши": ["горбатев"],
    "горбатив": ["горбативши"],
    "горбативши": ["горбатив"],
    "горбатиться": ["вкалывать", "пахать", "горбиться"],
    "горбатый кит": ["горбач"],
    "горбачевизм": ["горбачёвщина"],
    "горбачив": ["горбачивши"],
    "горбачивши": ["горбачив"],
    "горбачить": ["горбатеть"],
    "горбачёвщина": ["горбачевизм"],
    "горбив": ["горбивши"],
    "горбивши": ["горбив"],
    "горбимания": ["горбомания"],
    "горбинник": ["горбыльник"],
    "горбить": ["сутулить", "горбатиться"],
    "горбовидный": ["горбообразный"],
    "горбок": ["холмик"],
    "горбомания": ["горбимания"],
    "горбообразный": ["горбовидный"],
    "горбостройка": ["катастройка"],
    "горбулка": ["городская булка"],
    "горбуша": ["розовый лосось"],
    "горбушка": ["дворец культуры", "имя", "горбунов"],
    "горбыль": ["обапол", "абаполок", "болонок", "оболонок", "заболонка", "горбинник", "горбыльник", "горбина", "горбушина", "краюха", "горбылина", "горбылёк"],
    "горбыльник": ["горбинник"],
    "горводоканал": ["горводопровод"],
    "горгондзола": ["горгонзола", "горгонцола"],
    "горгонзола": ["горгондзола"],
    "горгулья": ["гаргулья", "гаргуйль"],
    "горделиво": ["надменно", "гордо"],
    "гордитися": ["пишатися"],
    "гордиться": ["испытывать гордость", "кичиться", "величаться", "бахвалиться", "чваниться", "заноситься"],
    "гордо": ["горделиво"],
    "гордон": ["горди"],
    "гордыбачив": ["гордыбачивши"],
    "гордыбачивши": ["гордыбачив"],
    "гордый": ["горделивый"],
    "гордыня": ["заносчивость", "высокомерие", "надменность"],
    "горе": ["скорбь", "печаль", "несчастье"],
    "горе луковое": ["горемыка", "бедняга", "бедолага", "растяпа", "недотёпа", "невезунчик", "несчастливец", "неудачник", "сто рублей убытку"],
    "горев": ["горевши"],
    "горевав": ["горевавши"],
    "горевавши": ["горевав"],
    "гореванье": ["горевание"],
    "горевать": ["скорбеть", "тосковать", "тужить", "печалиться", "грустить", "кручиниться"],
    "горевина": ["гарь", "пал", "прогар", "паленина"],
    "горевши": ["горев"],
    "горемыка": ["несчастливец", "несчастливица", "бедняга", "бедолага", "горемыкалка", "бесталанник", "бесталанница", "бедовик", "бедовник", "бедоноша", "беданюха", "бездольник", "бездольница", "горюн", "горегляд"],
    "горемычный": ["бедный", "злополучный", "злосчастный", "несчастный"],
    "горение": ["горенье", "энтузиазм", "рвение"],
    "горенка": ["горница"],
    "горенье": ["горение"],
    "горестный": ["печальный", "скорбный", "удручённый", "унылый", "подавленный"],
    "горесть": ["горе", "несчастье", "беда", "печаль", "прискорбие", "скорбь", "горечь"],
    "гореть": ["пламенеть", "пылать", "топиться", "светить", "давать свет", "пропадать", "исчезать", "подгорать", "пригорать", "срывать", "лететь", "нездоровиться", "блестеть", "блистать", "светиться"],
    "горец почечуйный": ["почечуйная трава", "почечуйник"],
    "горечавка": ["генциана"],
    "горечь": ["горькость"],
    "горещина": ["жега", "зной"],
    "горжет": ["горжетка", "боа"],
    "горжетка": ["горжет", "боа"],
    "гори синим пламенем": ["пропади пропадом"],
    "горизонт": ["окоём", "кругозор", "гарик"],
    "горилка": ["самогонка"],
    "горилла": ["громила", "бугай"],
    "гориллка": ["обезьянка"],
    "гориллообразный": ["гориллоподобный"],
    "гориллоподобный": ["гориллообразный"],
    "горимый": ["пожароопасный"],
    "горисполком": ["городской исполнительный комитет"],
    "горит пизда": ["чешется манда", "чешется пиздища", "чешется пиздище", "раззуделася пизда", "пизда чешется", "пизда горит"],
    "горицвет": ["черногорка", "стародубка"],
    "горичка": ["гора", "дъбрава"],
    "горишние плавни": ["комсомольск"],
    "горка": ["высокогорный"],
    "горкнув": ["горкнувши"],
    "горкнувши": ["горкнув"],
    "горкнуть": ["прогоркать"],
    "горлан": ["крикун", "горлопан", "горлодёр"],
    "горланив": ["горланивши"],
    "горланивши": ["горланив"],
    "горланити": ["горлати"],
    "горланить": ["горлопанить", "драть горло", "горло драть"],
    "горлати": ["горланити"],
    "горлец": ["змеевик"],
    "горлинка": ["горлица"],
    "горлица": ["горлинка"],
    "горло": ["жабры", "жерло", "горловина"],
    "горлобесие": ["словоблудие", "пустозвонство", "пустословие", "краснобайство"],
    "горловка": ["болльгенен"],
    "горловой": ["гортанный", "грубый"],
    "горлодёр": ["крикун", "горлан", "горлопан", "горлодёра"],
    "горлопан": ["горлан", "горлодёр"],
    "горлопанив": ["горлопанивши"],
    "горлопанивши": ["горлопанив"],
    "горлопанить": ["горланить", "вопить"],
    "гормон": ["инкрет"],
    "гормон счастья": ["дофамин", "допамин", "серотонин", "эндорфин", "энкефалин"],
    "гормон удовольствия": ["окситоцин", "питоцин"],
    "гормональная терапия": ["гормонотерапия"],
    "гормоногенез": ["гормонопоэз", "гормонообразование"],
    "гормонообразование": ["гормоногенез", "гормонопоэз"],
    "гормонопоэз": ["гормоногенез", "гормонообразование"],
    "гормонотерапия": ["гормональная тепапия"],
    "гормонпродуцирующий": ["гормонопродуцирующий"],
    "горная порода": ["порода"],
    "горне": ["небесно", "возвышенно", "божественно"],
    "горний": ["высокий", "небесный", "возвышенный", "божественный"],
    "горнило": ["горн"],
    "горница": ["светлица"],
    "горно-алтайск": ["улала", "ойрот-тура"],
    "горно-бадахшанская автономная область": ["горный бадахшан", "гбао", "автономная республика бадахшан"],
    "горнозаводск": ["порнозаводск", "говнозаводск"],
    "горномарийский": ["горномарийский язык"],
    "горнопроходчик": ["проходчик"],
    "горнорабочий": ["горняк"],
    "горноскладчатый": ["горно-складчатый"],
    "горный": ["минеральный", "природный", "ископаемый", "геологический", "горнодобывающий"],
    "горный компас": ["геологический компас"],
    "горный хребет": ["горы"],
    "горняк": ["соцгородок"],
    "горняцкий": ["шахтерский", "рудокопский"],
    "горнячка": ["горняшка"],
    "горняшка": ["горнячка", "горничная"],
    "горовой": ["горный"],
    "горовосходитель": ["восходитель"],
    "город": ["град", "центр", "центр города"],
    "город большого яблока": ["нью-йорк", "большое яблоко", "столица мира", "город на гудзоне"],
    "город воинской славы": ["гвс"],
    "город льва": ["азиатский нью-йорк"],
    "город мастеров": ["город оружейников", "красная кузница", "самоварная столица"],
    "город оружейников": ["город мастеров", "красная кузница", "самоварная столица"],
    "город-государство": ["государство-город", "государство-полис"],
    "город-метрополия": ["кванъёкси"],
    "город-миллионер": ["город-миллионник"],
    "город-миллионник": ["город-миллионер"],
    "город-побратим": ["породнённый город"],
    "городив": ["городивши"],
    "городивши": ["городив"],
    "городить": ["огораживать", "болтать", "нести"],
    "городишко": ["городок", "дыра"],
    "городник": ["градоделец", "городчик"],
    "городничий": ["градоначальник", "градоправитель"],
    "городня": ["городница"],
    "городовой": ["городской"],
    "городок": ["город"],
    "городской округ": ["го"],
    "городчик": ["градоделец", "городник"],
    "горожанин": ["мещанин"],
    "горообразование": ["орогенез"],
    "горох": ["горошина", "драже", "гранула"],
    "гороховик": ["гороховник", "карагана древовидная"],
    "гороховое пальто": ["гороховая шинель", "агент", "сыщик", "тайный агент", "филёр", "сексот", "информатор", "осведомитель"],
    "гороховый": ["нутовый"],
    "горохострел": ["гороховая пушка"],
    "горошек": ["горох", "вика"],
    "горошив": ["горошивши"],
    "горошивши": ["горошив"],
    "горошница": ["гороховица", "гороховая каша"],
    "горстантиклинорий": ["горст-антиклинорий"],
    "горстка": ["горсть", "ладошка", "горсточка", "пригоршня"],
    "горсть": ["жменя", "пригоршня", "пятерня", "малость"],
    "гортань": ["глотка", "горло"],
    "гортоп": ["городской", "топливный", "отдел"],
    "горчак": ["тилопил"],
    "горчивина": ["горчило"],
    "горчивши": ["горчив"],
    "горчинка": ["горечь"],
    "горчить": ["отравлять"],
    "горчичник": ["синапизм"],
    "горчично-жёлтый": ["коричнево-жёлтый", "жёлто-коричневый"],
    "горчичный газ": ["иприт"],
    "горшечник": ["горшеня"],
    "горшечница": ["горшечник"],
    "горшок": ["ночной горшок", "ночная ваза", "шапочка", "блок-шот"],
    "горыныч": ["горынович"],
    "горькая": ["водка", "белое", "продажная дурь", "водовка", "белоголовка", "красноголовка", "горилка", "сорокаградусная", "огненная вода", "хлебное вино", "пенник", "полугар", "жидкая валюта", "покупная болезнь", "водяра"],
    "горький": ["горчащий", "печальный", "горестный", "обидный", "огорчённый"],
    "горькозём": ["магнезия", "тальковая земля"],
    "горькоминдальный": ["горько-миндальный"],
    "горькость": ["горечь"],
    "горькушка": ["горькуха"],
    "горэлектротранспорт": ["городской электротранспорт"],
    "горючее": ["горючка", "водка", "водяра", "водовка"],
    "горючий": ["воспламенимый", "воспламеняющийся", "раскалённый", "горячий"],
    "горючка": ["горючее", "топливо"],
    "горячая голова": ["горячка", "кипяток", "порох"],
    "горячая клавиша": ["сочетание клавиш"],
    "горяченький": ["горячий"],
    "горяченькое": ["тёпленькое"],
    "горячечно": ["лихорадочно", "возбуждённо"],
    "горячечный": ["бредовый", "лихорадочный"],
    "горячив": ["горячивши"],
    "горячивши": ["горячив"],
    "горячиться": ["волноваться", "кипятиться", "психовать", "раздражаться", "раззадориваться", "входить в азарт", "выходить из себя", "забываться", "вскинуться", "разгорячиться", "сердиться", "петушиться", "ершиться", "ерепениться", "хорохориться"],
    "горячка": ["лихорадка", "азарт", "одержимость", "страсть", "горячность", "спешка"],
    "горячность": ["пыл", "страстность", "задор", "горячесть"],
    "горячо": ["жарко", "пылко", "страстно", "воодушевлённо"],
    "гос": ["госэкзамен"],
    "гос-": ["государственный"],
    "госавтоинспектор": ["гаишник"],
    "госавтоинспекция": ["гаи", "гибдд"],
    "госарбитраж": ["государственный арбитраж"],
    "госбезопасность": ["государственная безопасность"],
    "госбюджетник": ["бюджетник"],
    "госвами": ["свами"],
    "госвизит": ["государственный визит"],
    "госвложение": ["госинвестиция"],
    "госдеп": ["госдепартамент"],
    "госдепартамент": ["госдеп"],
    "госдумец": ["госдумовец", "думец"],
    "госдумовец": ["госдумец", "думец"],
    "госдумовский": ["госдумский"],
    "госдумский": ["госдумовский"],
    "госдура": ["госдума", "бешеный принтер", "сумасшедший принтер"],
    "госзаём": ["заём"],
    "госизмена": ["государственная измена"],
    "госизменник": ["госизменщик"],
    "госизменщик": ["госизменник"],
    "госинвестиция": ["госвложение"],
    "госканал": ["гостелеканал"],
    "гособоронзаказ": ["оборонзаказ"],
    "госорган": ["государственный орган"],
    "госпак": ["госпиталь"],
    "госпитализировав": ["госпитализировавши"],
    "госпитализировавши": ["госпитализировав"],
    "госпиталит": ["странноприимец", "странноприимник", "гостеприимный", "госпитальер", "бедный"],
    "госпиталь": ["гошпиталь", "лазарет", "госпак"],
    "госпитальер": ["иоаннит", "мальтийский рыцарь"],
    "господа": ["г-да"],
    "господар": ["собственик", "владетел", "началник", "властелин"],
    "господарчий": ["господарський"],
    "господень дом": ["божий дом", "богадельня", "дом престарелых", "дом для престарелых"],
    "господи": ["боже"],
    "господинчик": ["господчик"],
    "господство": ["власть", "владычество", "верховенство", "главенство", "гегемония", "правление", "преобладание", "засилье", "доминирование"],
    "господствовав": ["господствовавши"],
    "господствовавши": ["господствовав"],
    "господствовать": ["владычествовать", "главенствовать", "властвовать", "преобладать", "доминировать"],
    "господствующий": ["доминирующий", "основной", "главный", "преобладающий", "командный"],
    "господчик": ["господинчик"],
    "господь": ["бог", "всевышний", "творец", "создатель"],
    "госпожа": ["хозяйка", "дама"],
    "госпомощь": ["господдержка", "госдотация"],
    "госпошлина": ["государственная пошлина"],
    "госприёмка": ["государственный", "приёмка"],
    "госсвидетельство": ["государственное свидетельство"],
    "госсекрет": ["гостайна"],
    "госсекретарь": ["государственный секретарь"],
    "госслужащий": ["государственный служащий"],
    "гостайна": ["госсекрет"],
    "гоств": ["гостелевидение"],
    "гостевав": ["гостевавши"],
    "гостевавши": ["гостевав"],
    "гостеванье": ["гостевание"],
    "гостевая книга": ["гостевуха"],
    "гостелевидение": ["гоств"],
    "гостелеканал": ["госканал"],
    "гостелерадиокомпания": ["гтрк"],
    "гостеприимный": ["хлебосольный", "радушный"],
    "гостеприимство": ["гостеприимность", "радушие"],
    "гости из краснодара": ["критические дни", "эти дни", "красный день календаря", "гости на красной машине", "по себе", "слёзы матки"],
    "гостив": ["гостивши"],
    "гостивши": ["гостив"],
    "гостиная": ["салон", "гостиная комната"],
    "гостиница": ["отель"],
    "гостинница": ["гостиница", "виталище"],
    "гостиный": ["гостевой"],
    "гостировав": ["гостировавши"],
    "гостировавши": ["гостировав"],
    "гостить": ["гостевать"],
    "гостия": ["просфора"],
    "гострайтер": ["литературный негр"],
    "гость": ["визитёр", "посетитель"],
    "гостюя": ["гостя"],
    "государив": ["государивши"],
    "государивши": ["государив"],
    "государственная дума": ["дума", "гд", "госдума", "госдура"],
    "государственная измена": ["измена родине"],
    "государственная итоговая аттестация": ["гиа", "основной государственный экзамен", "огэ"],
    "государственничество": ["этатизм"],
    "государственность": ["государство"],
    "государственный визит": ["госвизит"],
    "государственный долг": ["госдолг"],
    "государственный заказ": ["госзаказ"],
    "государственный крестьянин": ["казённый крестьянин"],
    "государственный переворот": ["госпереворот"],
    "государственный совет": ["госсовет", "гс"],
    "государственный тренер": ["гостренер"],
    "государство": ["режим", "держава", "страна"],
    "государство в государстве": ["глубинное государство"],
    "государство израиль": ["израиль"],
    "государство палестина": ["палестина"],
    "государство-агрессор": ["страна-агрессор"],
    "государство-город": ["город-государство"],
    "государство-изгой": ["страна-изгой"],
    "государство-участник": ["государство-член"],
    "государствовав": ["государствовавши"],
    "государствовавши": ["государствовав"],
    "государыня": ["высочайшая особа", "императрица", "коронованная особа", "монархиня", "суверен", "царица", "её величество", "венценосица", "порфироносица", "помазанница", "божий", "госпожа"],
    "государь": ["монарх", "суверен"],
    "госуслуга": ["государственная услуга", "госы"],
    "госфонд": ["государственный фонд"],
    "госфункционер": ["госчиновник"],
    "госчиновник": ["госфункционер"],
    "госэкзамен": ["государственный экзамен"],
    "гот": ["гутон"],
    "готавливав": ["готавливавши"],
    "готавливавши": ["готавливав"],
    "готвар": ["готвач"],
    "готварница": ["кухня"],
    "готвач": ["готвар"],
    "готичный": ["готический"],
    "готия": ["феодоро"],
    "готовив": ["готовивши"],
    "готовивши": ["готовив"],
    "готовиться": ["подготавливаться", "назревать", "надвигаться"],
    "готовка": ["стряпня"],
    "готовность": ["подготовленность", "услужливость"],
    "готовый": ["подготовленный", "пригодный", "годный", "способный", "готовный", "приготовленный", "убитый", "погибший", "пьяный"],
    "готовьсь": ["товьсь"],
    "готовясь": ["готовяся"],
    "готовяся": ["готовясь"],
    "гоустфейс": ["призрачная маска"],
    "гофра": ["гофротруба"],
    "гофрея": ["брыжи"],
    "гофрив": ["гофривши"],
    "гофривши": ["гофрив"],
    "гофрировав": ["гофрировавши"],
    "гофрировавши": ["гофрировав"],
    "гофрировальный": ["гофрировочный"],
    "гофрирование": ["гофрировка"],
    "гофрированный": ["волнистый", "складчатый", "плиссированный", "ребристый", "рифлёный", "профилированный"],
    "гофрировка": ["гофрирование"],
    "гофрировочный": ["гофрировальный"],
    "гофрировщик": ["гофрировщица"],
    "гофрировщица": ["гофрировщик"],
    "гофроагрегат": ["гофромашина"],
    "гофропласт": ["гофропластик"],
    "гофротара": ["гофрированный", "тара"],
    "гочс": ["го и чс"],
    "гощенье": ["гощение"],
    "грааль": ["чаша", "кубок"],
    "граб": ["грабина"],
    "граб восточный": ["грабинник"],
    "грабанув": ["грабанувши"],
    "грабанувши": ["грабанув"],
    "грабануть": ["ограбить"],
    "грабарив": ["грабаривши"],
    "грабаривши": ["грабарив"],
    "грабастав": ["грабаставши"],
    "грабаставши": ["грабастав"],
    "грабастать": ["загребать", "хапать", "захапывать"],
    "грабелина": ["грабловище", "граблевище", "грабельник"],
    "грабельки": ["грабли", "грабельник", "аистник", "журавельник"],
    "грабельник": ["граблевище", "журавельник", "аистник", "грабельки"],
    "грабельщик": ["гребельщик"],
    "грабельщица": ["гребельщица"],
    "грабив": ["грабивши"],
    "грабивши": ["грабив"],
    "грабиловка": ["грабёж"],
    "грабинник": ["граб восточный"],
    "грабитель": ["разбойник", "хапуга"],
    "грабительница": ["разбойница"],
    "грабительство": ["разбой", "грабёж", "ограбление", "разграбление", "обкрадывание", "обворовывание", "обдирательство"],
    "грабительствовав": ["грабительствовавши"],
    "грабительствовавши": ["грабительствовав"],
    "грабить": ["ограблять", "разорять", "опустошать"],
    "граблевидный": ["граблеобразный"],
    "граблевище": ["грабловище", "грабелина", "грабельник"],
    "грабли": ["пакши", "манипулятор", "хваталка"],
    "граблив": ["грабливши"],
    "грабливши": ["граблив"],
    "грабловище": ["граблевище", "грабелина", "грабельник"],
    "грабёж": ["разбой"],
    "гравийный": ["гравиевый"],
    "гравиола": ["гуанабана"],
    "гравирецептор": ["гравицептор"],
    "гравировав": ["гравировавши"],
    "гравировавши": ["гравировав"],
    "гравировальщик": ["гравёр", "гравировщик"],
    "гравирование": ["гравировка"],
    "гравировка": ["гравирование"],
    "гравировщик": ["гравёр"],
    "гравис": ["аксанграв"],
    "гравитационная вода": ["свободная вода"],
    "гравитация": ["всемирное тяготение", "тяготение"],
    "гравитировав": ["гравитировавши"],
    "гравитировавши": ["гравитировав"],
    "гравитировать": ["тяготеть", "притягивать", "притягиваться"],
    "гравитропизм": ["геотропизм"],
    "гравицептор": ["гравирецептор"],
    "гравюра": ["клише", "эстамп"],
    "гравюрочка": ["эстампик"],
    "гравёр": ["гравировальщик", "гравировщик"],
    "град": ["поток", "наплыв", "лавина"],
    "градация": ["интерпретация"],
    "градец": ["паланка", "касаба"],
    "градиент": ["перепад"],
    "градирня": ["охладительная башня"],
    "градировав": ["градировавши"],
    "градировавши": ["градировав"],
    "градобитие": ["градобой", "градобитье"],
    "градобитье": ["градобитие", "градобой"],
    "градоделец": ["городник", "городчик"],
    "градоначальник": ["мэр"],
    "градоначальница": ["мэрша"],
    "градоправитель": ["градоначальник"],
    "градостроение": ["градостроительство", "градоустройство", "урбанизация"],
    "градостроительство": ["градостроение"],
    "градский": ["градской"],
    "градской": ["градский"],
    "градуальный": ["постепенный"],
    "градуировав": ["градуировавши"],
    "градуировавши": ["градуировав"],
    "градуирование": ["градуировка"],
    "градусник": ["термометр"],
    "гражданин": ["подданный", "резидент"],
    "гражданин мира": ["космополит"],
    "гражданская дипломатия": ["народная дипломатия"],
    "гражданский": ["штатский", "цивильный", "светский", "гражданская война", "гражданка", "штатское", "цивильное", "партикулярное"],
    "гражданский брак": ["светский", "брак", "сожительство", "незарегистрированный", "фактический", "брачный", "отношение"],
    "гражданский инженер": ["инженер в гражданском строительстве"],
    "гражданское право": ["гп"],
    "гражданственник": ["гражданин"],
    "гражданственно": ["граждански"],
    "гражданственность": ["государственность"],
    "гражданство": ["подданство"],
    "грай": ["карканье", "гвалт"],
    "грайндкор": ["грайнд"],
    "грамм": ["грамм-сила"],
    "грамм-молекула": ["моль", "граммолекула"],
    "граммар-наци": ["граммар", "граммарик", "граммар-фашист", "орфографическая полиция", "филологическая дева", "орфочекист"],
    "грамматизоваться": ["грамматикализоваться"],
    "грамматик": ["грамматист"],
    "грамматика": ["азбука"],
    "грамматикализовав": ["грамматикализовавши"],
    "грамматикализовавши": ["грамматикализовав"],
    "грамматикализоваться": ["грамматизоваться"],
    "грамматист": ["грамматик"],
    "грамматическое значение": ["граммема"],
    "граммема": ["грамматическое значение"],
    "грамота": ["грамотность", "азы"],
    "грамотно": ["правильно"],
    "грамотность": ["образованность", "просвещённость"],
    "грамотный": ["компетентный", "правильный"],
    "грампластинка": ["пластинка"],
    "граната": ["ручная граната", "артиллерийская граната", "мина", "шрус"],
    "гранатный": ["гранатовый"],
    "гранатовый": ["гранатный"],
    "гранатомёт": ["базука", "шайтан-труба"],
    "гранатомётчик": ["гренадер"],
    "гранатоэдр": ["ромбододекаэдр"],
    "гранд-дама": ["гран-дама"],
    "гранд-концерт": ["гала-концерт"],
    "грандесса": ["аристократка", "дворянка"],
    "грандиозный": ["огромный", "мощный", "величественный", "масштабный"],
    "гранение": ["граненье", "гранка"],
    "гранив": ["гранивши"],
    "гранивши": ["гранив"],
    "гранит": ["скала"],
    "гранитоль": ["дерматин"],
    "гранить": ["огранять"],
    "граниться": ["ограняться", "ограниваться"],
    "граница": ["рубеж", "раздел", "предел", "грань", "межа", "стык"],
    "граничив": ["граничивши"],
    "граничивши": ["граничив"],
    "граничный": ["пограничный"],
    "грановитый": ["угловатый"],
    "гранулировав": ["гранулировавши"],
    "гранулировавши": ["гранулировав"],
    "гранулированность": ["гранулярность", "зернистость"],
    "гранулома": ["гранулёма"],
    "гранулопоэз": ["гранулоцитопоэз"],
    "гранулофтиз": ["агранулоцитоз", "алейкия", "анейтрофилёз"],
    "гранулоцит": ["ацидофилоцит", "лейкоцит ацидофильный", "лейкоцит эозинофильный", "эозинофил"],
    "гранулоцитопоэз": ["гранулопоэз"],
    "гранулярность": ["грануляция"],
    "гранулярный": ["гранулёзный", "гранулированный", "зернистый"],
    "гранулёма": ["гранулома"],
    "грань": ["поверхность", "кромка", "фаска", "разделитель", "граница"],
    "грассировав": ["грассировавши"],
    "грассировавши": ["грассировав"],
    "грассирование": ["грассировка", "картавость", "ротацизм"],
    "грассировать": ["картавить"],
    "гратис": ["бесплатно", "безвозмездно", "даром"],
    "граттаж": ["воскография"],
    "гратуляция": ["поздравление"],
    "граувакка": ["серая вакка"],
    "граус": ["вересковая куропатка", "шотландская куропатка"],
    "граф": ["гауграф"],
    "графив": ["графивши"],
    "графивши": ["графив"],
    "график": ["диаграмма", "план", "расписание", "программа"],
    "графинечка": ["графинюшка"],
    "графинчик": ["графин"],
    "графинюшка": ["графинечка"],
    "графит": ["грифель"],
    "графитизировав": ["графитизировавши"],
    "графитизировавши": ["графитизировав"],
    "графитировав": ["графитировавши"],
    "графитировавши": ["графитировав"],
    "графитный": ["графитовый"],
    "графитовый": ["графитный"],
    "графически": ["схематически"],
    "графический": ["рисовальный"],
    "графолог": ["почерковед"],
    "графологический": ["почерковедческий"],
    "графология": ["почерковедение"],
    "графомания": ["графоманство", "графорея", "гиперграфия", "халтура"],
    "графопостроитель": ["плоттер"],
    "графорея": ["графомания"],
    "графство": ["шир", "округ"],
    "граффер": ["граффитист", "граффитчик", "райтер", "художник", "граффити"],
    "граффити": ["граффито"],
    "граффитист": ["граффер", "граффитчик", "райтер", "художник", "граффити"],
    "граффито": ["сграффито"],
    "граффитчик": ["граффер", "граффитист", "райтер", "художник", "граффити"],
    "грацильность": ["миниатюрность строения"],
    "грациозничав": ["грациозничавши"],
    "грациозничавши": ["грациозничав"],
    "грациозно": ["изящно"],
    "грациозность": ["грация", "изящество"],
    "грациозный": ["изящный", "элегантный", "изысканный", "утончённый", "привлекательный", "лёгкий"],
    "грация": ["харита"],
    "граяв": ["граявши"],
    "граявши": ["граяв"],
    "граять": ["каркать", "хохотать", "зубоскалить", "шалить", "дурить"],
    "гребав": ["гребавши"],
    "гребавши": ["гребав"],
    "гребанув": ["гребанувши"],
    "гребанувши": ["гребанув"],
    "гребенчатость": ["кристатность"],
    "гребенчатый": ["гребневидный", "гребнеобразный"],
    "гребенчатый губан": ["красный губан"],
    "гребень": ["гребёнка", "расчёска", "чесало", "реборда", "гребешок", "хохолок", "выступ", "бугор", "верхушка", "конёк"],
    "гребешок": ["гребень", "гребёнка"],
    "гребля": ["плотина"],
    "гребля-индор": ["индор-гребля"],
    "гребневидный": ["гребнеобразный"],
    "гребневик": ["гребенник"],
    "гребнеобразный": ["гребневидный"],
    "гребнув": ["гребнувши"],
    "гребнувши": ["гребнув"],
    "гребовав": ["гребовавши"],
    "гребовавши": ["гребовав"],
    "гребовать": ["грёбовать"],
    "гребёнка": ["гребень", "расчёска"],
    "гревши": ["грев"],
    "грегори": ["грег"],
    "грезив": ["грезивши"],
    "грезивши": ["грезив"],
    "грезить": ["мечтать"],
    "грей": ["грэй"],
    "грейвз": ["грейвс"],
    "грейвс": ["грейвз"],
    "грейдировав": ["грейдировавши"],
    "грейдировавши": ["грейдировав"],
    "грейка": ["термофор"],
    "грейтунг": ["остгот"],
    "грек": ["эллин"],
    "грекокатолический": ["греко-католический"],
    "гремев": ["гремевши"],
    "гремевши": ["гремев"],
    "греметь": ["грохотать"],
    "гремучая змея": ["гремучник"],
    "гремучая ртуть": ["фульминат", "ртуть"],
    "гремучий": ["гремящий", "взрывоопасный"],
    "гремучник": ["гремучая змея"],
    "гремушка": ["погремушка", "побрякушка"],
    "гренадер": ["гранатомётчик", "рослый", "великорослый", "высокий"],
    "гренка": ["гренок", "крутон"],
    "гренландский кит": ["полярный кит"],
    "гренок": ["гренка", "крутон", "тост"],
    "грести": ["делать гребки"],
    "грета": ["маргарита"],
    "греть": ["нагревать", "подогревать", "разогревать", "согревать", "обогревать"],
    "греться": ["согреваться", "нагреваться"],
    "грех": ["прегрешение", "прегрешенье", "ошибка", "проступок", "недостаток"],
    "греховность": ["грешность", "порочность"],
    "греховный": ["грешный"],
    "греховодница": ["развратница", "непотребница", "беспутница", "распутница"],
    "греховодничав": ["греховодничавши"],
    "греховодничавши": ["греховодничав"],
    "греци": ["грекъ"],
    "грецизировав": ["грецизировавши"],
    "грецизировавши": ["грецизировав"],
    "греция": ["эллада", "греческая республика"],
    "грецкий": ["греческий"],
    "грецкий орех": ["орех грецкий", "волошский орех", "царский орех", "греческий орех"],
    "грець": ["грач"],
    "греча": ["гречка", "гречиха"],
    "гречанка": ["эллинка"],
    "греческая республика": ["греция", "эллада"],
    "греческий": ["эллинский", "греческий язык"],
    "греческий язык": ["греческий"],
    "гречиха": ["гречка"],
    "гречишник": ["горец"],
    "гречка": ["гречиха", "греча", "непал", "чёрный рис", "германия", "языческое зерно", "франция", "бельгия", "испания", "португалия", "арабское зерно", "италия", "греция", "турецкое зерно", "гречневая каша"],
    "гречневик": ["гречишник", "гречаник", "гречушник"],
    "грешен": ["беден"],
    "грешив": ["грешивши"],
    "грешивши": ["грешив"],
    "грешка": ["опущение", "погрешка", "махана", "неточност", "неправилност"],
    "грешница": ["греховница"],
    "грешно": ["грех", "греховно"],
    "грешноватый": ["грешный"],
    "грешность": ["греховность"],
    "грешный": ["греховный"],
    "гриб": ["губа", "губьё", "грыб"],
    "гриб-баран": ["грифола курчавая", "мейтаке", "маитаке", "танцующий гриб"],
    "гриб-трутовик": ["трутник", "трутовица"],
    "гриба": ["губа"],
    "грибница": ["грибовница", "грибовица"],
    "грибной дождь": ["слепой дождь"],
    "грибоварка": ["грибоварня"],
    "грибоварный": ["грибоварочный"],
    "грибоварня": ["грибоварка"],
    "грибоварочный": ["грибоварный"],
    "грибовница": ["грибница"],
    "грибовничав": ["грибовничавши"],
    "грибовничавши": ["грибовничав"],
    "грибовничать": ["ходить по грибы"],
    "грибообразный": ["грибовидный"],
    "гривенник": ["десять копеек", "десятикопеечная монета", "десюнчик"],
    "гривна": ["гривня", "хохлобакс"],
    "гривуазно": ["игриво"],
    "гривуазность": ["неприличность", "игривость", "непристойность", "нескромность", "неблагопристойность"],
    "гривуазный": ["фривольный"],
    "григишкес": ["григорьево", "григишки"],
    "григорий": ["грегорий", "грегор", "гриша"],
    "григорьевич": ["григорьич", "григорич"],
    "гриден": ["ратник"],
    "гридеперлевый": ["жемчужно-серый", "гриперлевый", "гридеперль", "гри-де-перль"],
    "грилон": ["капрон"],
    "грим": ["макияж"],
    "гримаса": ["ужимка", "рожа", "мина"],
    "гримасничав": ["гримасничавши"],
    "гримасничавши": ["гримасничав"],
    "гримасничание": ["гримасничанье", "кривляние"],
    "гримасничанье": ["гримасничание"],
    "гримасничать": ["корчить рожи"],
    "гримировав": ["гримировавши"],
    "гримировавши": ["гримировав"],
    "гримировальный": ["гримёрный", "гримировочный"],
    "гримировочная": ["гримёрная", "грим-уборная"],
    "гримировочный": ["гримёрный", "гримировальный"],
    "гримуар": ["гримория"],
    "гримёрка": ["гримёрная"],
    "гримёрная": ["гримёрка"],
    "грин": ["доллар", "гринбек", "бакс", "зелёный", "зелень"],
    "гринвошинг": ["зелёный камуфляж"],
    "гринда": ["чёрный дельфин"],
    "гринкарта": ["грин-карта", "гринкард"],
    "грип": ["глубина резкости"],
    "грипп": ["инфлюэнца", "инфлуэнца"],
    "грипповав": ["грипповавши"],
    "грипповавши": ["грипповав"],
    "грит": ["гыт", "де", "дескать", "мол", "молвить"],
    "гриф-индейка": ["катарта-индейка"],
    "грифель": ["графит"],
    "грифельная доска": ["аспидная доска"],
    "грифованный": ["загрифованный"],
    "гро-гро": ["грогрон"],
    "гроб": ["домовина", "саркофаг", "деревянный макинтош", "каюк", "хана", "смерть", "громадина"],
    "гробанув": ["гробанувши"],
    "гробанувши": ["гробанув"],
    "гробив": ["гробивши"],
    "гробивши": ["гробив"],
    "гробик": ["гроб", "гробок"],
    "гробница": ["усыпальница", "саркофаг", "мавзолей", "радуга"],
    "гробовых дел мастер": ["трудовик"],
    "гробок": ["гробик"],
    "гробокопатель": ["могильщик"],
    "грогрон": ["гро-гро"],
    "грогроновый": ["шёлковый"],
    "гродафрик": ["шёлк"],
    "гродафриковый": ["шёлковый"],
    "гроза": ["страх", "опасность", "угроза", "взбучка", "наказание"],
    "грозд": ["гроздь"],
    "гроздь": ["кисть"],
    "грозив": ["грозивши"],
    "грозивши": ["грозив"],
    "грозить": ["угрожать"],
    "грозно": ["строго"],
    "грозный": ["джохар"],
    "грозозащита": ["молниезащита"],
    "грозоспуск": ["заземляющий проводник", "заземляющий спуск", "спуск заземления", "спуск молниеприёмника", "заземляющее устройство", "заземление", "заземлитель", "молниезащита"],
    "грокнув": ["грокнувши"],
    "грокнувши": ["грокнув"],
    "грокнуть": ["врубиться", "въехать", "догнать"],
    "гром": ["молния", "громовой разряд", "грозовой разряд", "грохот", "грохотание", "грохотанье", "громыхание", "громыханье", "карточная игра", "сумка", "трамвай"],
    "гром грянул": ["грянул гром"],
    "громада": ["громадина"],
    "громадина": ["колосс", "великан"],
    "громадный": ["гигантский", "колоссальный", "огромный", "необъятный", "огромадный"],
    "громадьё": ["величие", "множество"],
    "громадянство": ["горожанство"],
    "громив": ["громивши"],
    "громивши": ["громив"],
    "громила": ["грабитель", "бандит", "гангстер", "головорез"],
    "громить": ["разрушать", "разорять", "уничтожать", "сокрушать", "разбивать"],
    "громкая связь": ["громкоговорящая связь"],
    "громкий": ["шумный", "звучный", "громогласный"],
    "громко": ["звучно", "с помпой", "помпезно"],
    "громкоговоритель": ["динамик", "рупор", "репродуктор"],
    "громкоговорящая связь": ["громкая связь"],
    "громобойный": ["громовой", "оглушительный"],
    "громовик": ["громовержець"],
    "громовой": ["громовый", "оглушительный", "бурный", "сокрушительный", "уничтожающий"],
    "громовый отвод": ["грозоотвод", "громоотвод", "молниеотвод"],
    "громогласно": ["открыто"],
    "громогласный": ["велегласный", "громкий", "громовой", "громозвучный", "громоподобный", "гулкий", "звучный", "зычноголосый", "макрофонический", "оглушительный", "трубный"],
    "громозвучный": ["громоподобный", "торжественный", "высокопарный"],
    "громоздив": ["громоздивши"],
    "громоздивши": ["громоздив"],
    "громоздиться": ["взгромождаться", "нависать"],
    "громоотвод": ["грозоотвод", "громовый отвод", "молниеотвод"],
    "громоподобный": ["громозвучный"],
    "громче": ["громчее", "громчей"],
    "громыхав": ["громыхавши"],
    "громыхавши": ["громыхав"],
    "громыхать": ["грохотать", "грохать", "греметь"],
    "громыхнув": ["громыхнувши"],
    "громыхнувши": ["громыхнув"],
    "громыхнуть": ["грохотнуть", "прогрохотать"],
    "гроно": ["китиця"],
    "гроссмейстер": ["великий магистр"],
    "гроссуляр": ["гроссулярит", "гессонит", "гомед"],
    "грот": ["пещера", "вертеп"],
    "гротеск": ["шарж"],
    "гротескний": ["гротесковий", "карикатурний"],
    "гротескный": ["гротесковый"],
    "гротесковый": ["гротескный", "карикатурный"],
    "грохав": ["грохавши"],
    "грохавши": ["грохав"],
    "грохнув": ["грохнувши"],
    "грохнувши": ["грохнув"],
    "грохнуть": ["убить", "прибить"],
    "грохнуться": ["рухнуть", "шлёпнуться", "удариться"],
    "грохотав": ["грохотавши"],
    "грохотавши": ["грохотав"],
    "грохотать": ["громыхать", "смеяться"],
    "грохотив": ["грохотивши"],
    "грохотивши": ["грохотив"],
    "грохотнув": ["грохотнувши"],
    "грохотнувши": ["грохотнув"],
    "грохотный": ["шумный", "гулкий", "громкий"],
    "грош цена в базарный день": ["грош цена", "три рубля ведро в базарный день", "гроша ломаного не стоит", "выеденного яйца не стоить", "ни к чёрту", "никуда не упираться", "ни черта не стоить", "хоть брось"],
    "грошевик": ["грош"],
    "грубев": ["грубевши"],
    "грубевши": ["грубев"],
    "грубив": ["грубивши"],
    "грубивши": ["грубив"],
    "грубить": ["хамить", "грубиянить", "дерзить", "фолить"],
    "грубиян": ["хам"],
    "грубиянив": ["грубиянивши"],
    "грубиянивши": ["грубиянив"],
    "грубо": ["хамски", "примитивно"],
    "грубодисперсный": ["крупнодисперсный", "низкодисперсный"],
    "грубость": ["топорность", "лапидарность", "прямолинейность", "хамство", "неотёсанность", "невежливость", "невоспитанность"],
    "грубошёрстный": ["грубошёрстый"],
    "грубый": ["некультурный", "невежливый", "жестокий", "неотёсанный", "невоспитанный", "шершавый", "корявый", "простой", "глухой", "хриплый", "скрипучий", "приблизительный", "неточный", "примерный", "вопиющий"],
    "груда": ["куча"],
    "грудастый": ["пышногрудый"],
    "грудень": ["студень"],
    "грудив": ["грудивши"],
    "грудивши": ["грудив"],
    "грудина": ["грудная кость"],
    "грудить": ["скучивать"],
    "грудная жаба": ["стенокардия"],
    "грудник": ["грудничок"],
    "грудничок": ["зыбочник", "пеленашка", "ходунок"],
    "грудное вскармливание": ["гв"],
    "грудняшка": ["грудник", "грудничок"],
    "грудопоясничный": ["тораколюмбальный"],
    "гружёный": ["загруженный"],
    "груз": ["тяжесть", "бремя", "грузик", "противовес", "карго"],
    "груздь": ["груздик", "груздок", "млечник"],
    "грузив": ["грузивши"],
    "грузивши": ["грузив"],
    "грузиница": ["кракозябры"],
    "грузинка": ["картвелка"],
    "грузино-российский": ["российско-грузинский"],
    "грузиноведение": ["картвелология"],
    "грузинская сср": ["грузия"],
    "грузинский": ["грузинский язык"],
    "грузинский язык": ["грузинский"],
    "грузити": ["вантажити"],
    "грузить": ["загружать"],
    "грузиться": ["загружаться", "копироваться"],
    "грузия": ["республика грузия"],
    "грузнев": ["грузневши"],
    "грузневши": ["грузнев"],
    "грузно": ["тяжело"],
    "грузнув": ["грузнувши"],
    "грузнувши": ["грузнув"],
    "грузный": ["тучный", "полный", "тяжеловесный"],
    "грузовой автомобиль": ["грузовик"],
    "грузовой тягач": ["тягач"],
    "грузозахват": ["захват", "грузовой захват"],
    "грузопассажирский": ["товарно-пассажирский"],
    "грузоподъёмность": ["грузовместимость"],
    "грузополучатель": ["консигнатор"],
    "грузчик": ["грузин", "такелажник", "докер", "носильщик", "биндюжник"],
    "грум": ["конюх"],
    "грунт": ["земля", "почва"],
    "грунтовав": ["грунтовавши"],
    "грунтовавши": ["грунтовав"],
    "грунтовальный": ["грунтовочный"],
    "грунтование": ["грунтовка"],
    "грунтовая дорога": ["грунтовка"],
    "грунтовочный": ["грунтовальный"],
    "грунтоед": ["илоед"],
    "грунторез": ["бара"],
    "грунтубель": ["грунтгебель"],
    "групер": ["мероу", "черна"],
    "групорг": ["группорг"],
    "группа": ["коллектив", "круг", "совокупность"],
    "группа быстрого реагирования": ["гбр"],
    "группа продлённого дня": ["продлёнка", "продлюга", "гпд"],
    "группенсекс": ["групповуха"],
    "группи": ["фанатка"],
    "группировав": ["группировавши"],
    "группировавши": ["группировав"],
    "группироваться": ["кучковаться"],
    "группкомсорг": ["комсорг группы"],
    "групповод": ["гид"],
    "групповой": ["коллективный", "узкий", "цеховой"],
    "групповой секс": ["групповуха", "группенсекс", "свальный грех", "оргия"],
    "групповуха": ["групповушка", "группенсекс"],
    "групповушка": ["групповуха"],
    "группорг": ["групорг"],
    "грустив": ["грустивши"],
    "грустивши": ["грустив"],
    "грустить": ["тосковать", "унывать", "печалиться", "кручиниться", "горюниться", "тужить"],
    "грустнев": ["грустневши"],
    "грустневши": ["грустнев"],
    "грустно": ["печально", "с грустью", "меланхолично", "уныло"],
    "грустный": ["огорчённый", "расстроенный", "тоскливый", "унылый", "безрадостный", "опечаленный", "жалобный", "печальный"],
    "грусть": ["печаль", "уныние", "тоска", "меланхолия"],
    "грушеобразный": ["грушевидный"],
    "грушина": ["груша", "грушица"],
    "грыжа": ["кила", "фуфло"],
    "грыжевой": ["грыжевый"],
    "грыжевый": ["грыжевой", "грыжный"],
    "грыжник": ["грыжница", "гладун", "остудник", "грыжная трава", "кильная трава"],
    "грызнув": ["грызнувши"],
    "грызнувши": ["грызнув"],
    "грымза": ["карга", "мымра"],
    "грэй": ["грей"],
    "грэс": ["кэс"],
    "грюкав": ["грюкавши"],
    "грюкавши": ["грюкав"],
    "грюкать": ["грохотать", "громыхать"],
    "гряда": ["горная цепь", "кряж", "грядка"],
    "грядиль": ["грядило", "градиль", "гредиль", "гридиль", "грядина", "грядель", "гредель", "гридель", "грядел"],
    "грядушка": ["спинка", "грядочка", "облук", "облучок", "грядка", "деревина", "передок"],
    "грядущее": ["будущее"],
    "грядущий": ["наступающий", "приближающийся", "будущий", "предстоящий"],
    "грязелечебный": ["пелотерапевтический"],
    "грязелечение": ["пелоидотерапия", "пелотерапия"],
    "грязнев": ["грязневши"],
    "грязневши": ["грязнев"],
    "грязнив": ["грязнивши"],
    "грязнивши": ["грязнив"],
    "грязнить": ["загрязнять", "пачкать"],
    "грязниться": ["загрязняться", "пачкаться"],
    "грязно": ["нечисто", "скверно", "цинично", "непристойно", "бесчестно", "неопрятно"],
    "грязно-белый": ["серовато-белый"],
    "грязно-жёлтый": ["грязновато-жёлтый", "серовато-жёлтый"],
    "грязновато-жёлтый": ["грязно-жёлтый", "грязновато-желтоватый", "серовато-жёлтоватый"],
    "грязность": ["грязнота"],
    "грязнота": ["грязность"],
    "грязнотища": ["грязь"],
    "грязнув": ["грязнувши"],
    "грязнувши": ["грязнув"],
    "грязнуля": ["замарашка", "грязнуха"],
    "грязнуха": ["грязнуля", "замарашка"],
    "грязный": ["запачканный", "недостойный", "непристойный", "мутный", "мусорный"],
    "грязца": ["пачкотня"],
    "грязь": ["пачкотня", "месиво"],
    "грянув": ["грянувши"],
    "грянувши": ["грянув"],
    "грянуть": ["нагрянуть", "разразиться", "загрохотать"],
    "грянуться": ["грохнуться"],
    "грясти": ["шествовать"],
    "грях": ["вина", "грешка", "провинение", "простъпка", "престъпление", "прегрешение"],
    "грёбаный": ["чёртов", "проклятый", "долбаный", "ёбаный", "ебаный", "заебаный"],
    "грёбаный экибастуз": ["твою дивизию"],
    "грёза": ["дрёма", "сновидение", "видение", "мечта"],
    "гс": ["государственное собрание", "государственный совет"],
    "гсм": ["топливо"],
    "гснс": ["глубокая свёрточная нейронная сеть"],
    "гтг": ["третьяковка"],
    "гтрк": ["гостелерадиокомпания"],
    "гуава": ["псидиум"],
    "гуайява": ["гуаява"],
    "гуано": ["помёт", "удобрение", "дрянь", "отстой", "дерьмо"],
    "гуанофор": ["иридофор"],
    "гуанси-чжуанский автономный район": ["гчар"],
    "гуанчжоу": ["кантон"],
    "гуаньхуа": ["севернокитайский язык", "бэйфанхуа", "мандарин"],
    "гуаран": ["гуаровая камедь"],
    "гуарани": ["гварани"],
    "гуаровая камедь": ["гуара"],
    "гуаса": ["атлантический гигантский групер"],
    "гуашь": ["гвашь"],
    "гуаява": ["гуайява"],
    "губа": ["гриба", "губки", "уста", "залив", "бухта", "трутовик"],
    "губа не дура": ["красиво жить не запретишь"],
    "губач": ["медведь-губач", "медведь-ленивец"],
    "губгъо": ["шъофы"],
    "губер": ["губернатор"],
    "губерляйтер": ["губернатор"],
    "губернатор": ["аким", "воевода", "лейтенант-губернатор", "марзпет", "номарх", "остандар", "перифериарх", "хоким", "хяким", "губер"],
    "губернаторопад": ["губеропад"],
    "губернаторствовав": ["губернаторствовавши"],
    "губернаторствовавши": ["губернаторствовав"],
    "губернаторша": ["начальница", "руководительница"],
    "губерния": ["область"],
    "губив": ["губивши"],
    "губивши": ["губив"],
    "губительный": ["гибельный", "пагубный"],
    "губить": ["убивать", "портить"],
    "губка": ["губа"],
    "губная помада": ["губнушка"],
    "губно-губной": ["билабиальный"],
    "губно-зубной": ["лабиодентальный"],
    "губной": ["ротовой", "лабиальный"],
    "губной желобок": ["фильтрум"],
    "губнушка": ["губная помада"],
    "губоцветные": ["ясноткоцветные", "яснотковые"],
    "губошлёп": ["разиня", "растяпа"],
    "губчатость": ["пористость", "ячеистость"],
    "губчатый": ["пористый"],
    "губчека": ["губчк", "гчк"],
    "гувернантка": ["бонна"],
    "гугление": ["гуглёж"],
    "гуглив": ["гугливши"],
    "гугливши": ["гуглив"],
    "гуглинг": ["гуглёж", "гугление"],
    "гуглофон": ["андроидофон"],
    "гуглёж": ["гугление", "гугленье"],
    "гугнив": ["гугнивши"],
    "гугнивши": ["гугнив"],
    "гугукав": ["гугукавши"],
    "гугукавши": ["гугукав"],
    "гугукнув": ["гугукнувши"],
    "гугукнувши": ["гугукнув"],
    "гуд": ["гудение"],
    "гудбай": ["пока", "до свидания"],
    "гудев": ["гудевши"],
    "гудевши": ["гудев"],
    "гудеть": ["гундеть"],
    "гуджарати": ["гуджаратский язык"],
    "гудочник": ["гудошник"],
    "гудронив": ["гудронивши"],
    "гудронивши": ["гудронив"],
    "гудронировав": ["гудронировавши"],
    "гудронировавши": ["гудронировав"],
    "гудронировать": ["гудронить"],
    "гудронить": ["гудронировать"],
    "гудроновый": ["гудронный"],
    "гудьба": ["гудение"],
    "гудёжный": ["запойный", "загульный", "праздный"],
    "гужбанив": ["гужбанивши"],
    "гужбанивши": ["гужбанив"],
    "гужбанить": ["пировать", "пьянствовать", "гужеваться", "куражиться", "тащиться", "балдеть", "куролесить", "резвиться", "злоупотреблять", "веселиться", "гулять", "бражничать", "разгульничать", "отрываться", "оттягиваться"],
    "гужевав": ["гужевавши"],
    "гужевавши": ["гужевав"],
    "гужевать": ["пьянствовать", "пировать", "кутить"],
    "гужевой транспорт": ["гуж"],
    "гузка": ["гузно"],
    "гузно": ["афедрон", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея", "гузло"],
    "гуйя": ["разноклювая гуйя"],
    "гукав": ["гукавши"],
    "гукавши": ["гукав"],
    "гуканье": ["гукание"],
    "гукати": ["кричати", "звати"],
    "гукнув": ["гукнувши"],
    "гукнувши": ["гукнув"],
    "гуковец": ["гуковчанин"],
    "гуковчанин": ["гуковец"],
    "гул": ["шум"],
    "гулаговский": ["гулагский"],
    "гулагский": ["гулаговский"],
    "гулец": ["гуляка", "гулёха", "гулёна", "пагуляха", "нагула"],
    "гулив": ["гуливши"],
    "гуливав": ["гуливавши"],
    "гуливавши": ["гуливав"],
    "гуливши": ["гулив"],
    "гулиньки": ["гули", "гуль"],
    "гулить": ["гулькать"],
    "гулкость": ["звучность"],
    "гуль": ["урод"],
    "гульба": ["гулянье", "пирушка"],
    "гульбище": ["гуляние", "гульба", "гулянка"],
    "гулькав": ["гулькавши"],
    "гулькавши": ["гулькав"],
    "гулькать": ["гулить"],
    "гульной": ["гулящий", "гульный", "гулевой"],
    "гульнув": ["гульнувши"],
    "гульнувши": ["гульнув"],
    "гульный": ["гульной", "гулящий", "гулевой"],
    "гульня": ["гульба"],
    "гультай": ["гулец"],
    "гультяй": ["гулена", "гуляка"],
    "гульфик": ["ширинка", "брагетт"],
    "гуляв": ["гулявши"],
    "гулявши": ["гуляв"],
    "гуляка": ["бражник", "жуир", "забулдыга", "кутила", "бездельник"],
    "гуляние": ["прогулка", "променад", "гулянье"],
    "гулянка": ["гульба", "пьянка", "пирушка", "попойка", "кутёж"],
    "гулять": ["веселиться", "развлекаться", "кутить", "сойтись"],
    "гуляш-коммунизм": ["гуляш-социализм"],
    "гуляш-социализм": ["гуляш-коммунизм"],
    "гулящий": ["праздный", "разгульный"],
    "гулёна": ["гуляка"],
    "гума": ["шрома"],
    "гуманизация": ["очеловечивание"],
    "гуманизировав": ["гуманизировавши"],
    "гуманизировавши": ["гуманизировав"],
    "гуманизм": ["человечность", "гуманность"],
    "гуманитарка": ["гумпомощь"],
    "гуманитарная наука": ["общественная наука"],
    "гуманитарная помощь": ["гуманитарка", "гумконвой", "гумпомощь"],
    "гуманитарность": ["человечность"],
    "гуманитарный коридор": ["гумкоридор"],
    "гуманно": ["человечно"],
    "гуманность": ["гуманизм", "человечность", "доброта"],
    "гуманный": ["человечный", "человеколюбивый"],
    "гуманоидный": ["человекоподобный"],
    "гуменец": ["гуменце", "тонзура", "оброснение"],
    "гуменник": ["гуменный", "гуменной", "овинник"],
    "гуменце": ["гуменец", "тонзура"],
    "гумилиат": ["вальденс", "бегинок", "бегард"],
    "гумкав": ["гумкавши"],
    "гумкавши": ["гумкав"],
    "гумкать": ["гмыкать", "гымкать"],
    "гумми": ["камедь"],
    "гуммиарабик": ["аравийская камедь", "камедь аравийская"],
    "гуммилак": ["шеллак"],
    "гуммиластик": ["резина", "каучук", "гуммиэластик", "резинка", "ластик"],
    "гуммировав": ["гуммировавши"],
    "гуммировавши": ["гуммировав"],
    "гуммировальный": ["гуммировочный"],
    "гуммирование": ["гуммировка"],
    "гуммировка": ["гуммирование"],
    "гуммировочный": ["гуммировальный"],
    "гуммоз": ["камедетечение"],
    "гумно": ["гуменник", "огуменник", "овин", "рига", "амбар"],
    "гумозив": ["гумозивши"],
    "гумозивши": ["гумозив"],
    "гумпомощь": ["гуманитарка"],
    "гумус": ["перегной"],
    "гумусный": ["гумусовый"],
    "гумусовый": ["гумусный"],
    "гумусообразование": ["гумификация"],
    "гуна": ["рубище"],
    "гунбад": ["гунбаз"],
    "гунбаз": ["гунбад"],
    "гундев": ["гундевши"],
    "гундевши": ["гундев"],
    "гундосив": ["гундосивши"],
    "гундосивши": ["гундосив"],
    "гундосить": ["гнусавить", "гугнить", "гнусить", "гудеть", "бубнить", "гундеть"],
    "гундосый": ["гнусавый"],
    "гундёж": ["нытьё", "жалоба"],
    "гунн": ["хунн"],
    "гуннский": ["хуннский"],
    "гунфу": ["кунфу", "кунг-фу", "кун-фу"],
    "гунявый": ["лысый", "плешивый", "болезненный", "паршивый", "плохой", "низкопробный", "недостойный"],
    "гурба": ["пишак"],
    "гургемей": ["куркума"],
    "гурез": ["фирор"],
    "гурий": ["тур", "каирн"],
    "гурия": ["пери"],
    "гуркав": ["гуркавши"],
    "гуркавши": ["гуркав"],
    "гуркх": ["гурк"],
    "гурман": ["гастроном", "привереда", "лакомка"],
    "гурмо": ["гур моу", "гур"],
    "гуртив": ["гуртивши"],
    "гуртивши": ["гуртив"],
    "гуртовщик": ["гуртоправ", "погонщик"],
    "гуртом": ["оптом", "чохом", "сообща", "совместно", "гурьбой"],
    "гуртоправ": ["гуртовщик"],
    "гурьба": ["ватага", "толпа", "группа", "сборище", "кучка"],
    "гурьбой": ["толпой", "ватагою", "сообща", "дружно"],
    "гурьевец": ["гурьевчанин", "гурьянин"],
    "гурьевич": ["гурьич"],
    "гурьевчанин": ["гурьевец", "гурьянин"],
    "гурьянин": ["гурьевец", "гурьевчанин"],
    "гурьянович": ["гурьяныч"],
    "гусарив": ["гусаривши"],
    "гусаривши": ["гусарив"],
    "гусарить": ["гусарствовать"],
    "гусария": ["гусятня"],
    "гусарка": ["венгерка"],
    "гусарская болезнь": ["венерическая болезнь", "венерическое заболевание"],
    "гусарство": ["молодечество", "гусарщина"],
    "гусарствовав": ["гусарствовавши"],
    "гусарствовавши": ["гусарствовав"],
    "гусарствовать": ["гусарить"],
    "гусев": ["гусиный"],
    "гусем": ["по-гусиному", "вереницей", "друг за другом", "один за другим", "цепью", "цепочкой", "чередой", "цугом", "гуськом", "друг за дружкой", "затылок в затылок", "один за одним", "чредой"],
    "гусий": ["гусиный", "гусачий"],
    "гусиная кожа": ["пилоэрекция", "мурашки"],
    "гусиный": ["гусячий"],
    "гуслист": ["гусляр"],
    "гуслистка": ["гуслярка"],
    "гуслярный": ["гусельный"],
    "густев": ["густевши"],
    "густевши": ["густев"],
    "густив": ["густивши"],
    "густивши": ["густив"],
    "густо-жёлтый": ["тёмно-жёлтый"],
    "густо-красный": ["багровый", "кармазинный", "красный", "малиновый", "рубиновый", "чермный"],
    "густобровый": ["бровастый"],
    "густовласый": ["густоволосый"],
    "густоволосый": ["густовласый", "пышноволосый"],
    "густой": ["частый", "плотный", "насыщенный", "вязкий", "низкий", "полнозвучный", "бархатистый", "тёмный"],
    "густолиственный": ["густолистый"],
    "густолистый": ["густолиственный"],
    "густонаселённый": ["многолюдный"],
    "густёшенький": ["густёхонький"],
    "густёшенько": ["густёхонько"],
    "гусь": ["гусятина"],
    "гуськом": ["гусем", "друг за другом", "цугом"],
    "гусянка": ["гусяна"],
    "гусятник": ["гусиная лапка"],
    "гусятня": ["гусария"],
    "гусячий": ["гусиный"],
    "гусёнок": ["гусёныш"],
    "гусёныш": ["гусёнок"],
    "гуталин": ["вакса"],
    "гуталинный": ["гуталиновый"],
    "гуталиновый": ["гуталинный"],
    "гутарив": ["гутаривши"],
    "гутаривши": ["гутарив"],
    "гутарить": ["разговаривать", "беседовать", "болтать", "калякать"],
    "гутировав": ["гутировавши"],
    "гутировавши": ["гутировав"],
    "гутировать": ["смаковать"],
    "гуторив": ["гуторивши"],
    "гуторивши": ["гуторив"],
    "гуторить": ["разговаривать", "болтать", "говорить"],
    "гуттаперчевый": ["резиновый", "гибкий", "эластичный"],
    "гуттуральный": ["горловой", "гортанный", "задненёбный", "заднеязычный", "фаукальный", "велярный", "ларингальный"],
    "гуфнуться": ["накрыться", "убиться"],
    "гуфташуда": ["баёншуда"],
    "гуцинь": ["цисяньцинь"],
    "гучний": ["голосний", "бучний"],
    "гуща": ["осадок", "отстой", "сгусток"],
    "гущавина": ["гуща"],
    "гущеед": ["долбёжник"],
    "гущина": ["гуща"],
    "гчар": ["гуанси-чжуанский автономный район"],
    "гъадир": ["хадир"],
    "гъадирля": ["хадирля"],
    "гъале": ["гъалегиня"],
    "гъалегиня": ["гъале"],
    "гъвкавост": ["гъвкавина", "еластичност"],
    "гъог": ["хъуг"],
    "гърч": ["спазъм", "конвулсия"],
    "гъэ": ["илъэс"],
    "гыгыкав": ["гыгыкавши"],
    "гыгыкавши": ["гыгыкав"],
    "гыгыкать": ["хохотать", "ржать", "угарать"],
    "гыйлем": ["белем"],
    "гыкав": ["гыкавши"],
    "гыкавши": ["гыкав"],
    "гыкнув": ["гыкнувши"],
    "гыкнувши": ["гыкнув"],
    "гымкав": ["гымкавши"],
    "гымкавши": ["гымкав"],
    "гымкать": ["гмыкать", "гумкать"],
    "гыммо": ["гымнан"],
    "гына": ["кына"],
    "гыныплъ": ["джыгундыр"],
    "гьайлек": ["бешик"],
    "гьакъыл": ["эс"],
    "гьанэ": ["джанэ"],
    "гьини": ["гьин", "гьи"],
    "гьол": ["локва"],
    "гэбист": ["кагебешник"],
    "гэбистка": ["гэбэшница"],
    "гэбистский": ["гэбэшный", "кагэбэшный", "гэбнявый"],
    "гэбня": ["гэбуха", "гебня"],
    "гэбульник": ["гэбэшник", "кагэбэшник", "гэбня", "гэбуха"],
    "гэбуха": ["гэбня"],
    "гэбэшник": ["гэбешник", "гэбист", "гебист", "кагэбэшник", "гэбульник"],
    "гэбэшница": ["гэбистка"],
    "гэдо": ["гэ"],
    "гэл": ["гаэл", "гойдел", "хайлендер"],
    "гэмблинг": ["гемблинг", "азартная игра", "игорный бизнес", "лудомания", "игромания"],
    "гэп": ["ценовой разрыв"],
    "гэс": ["гидроэлектростанция"],
    "гэшка": ["гэшник", "гэшница"],
    "гювеч": ["гуляш", "чанахи", "азу", "рагу"],
    "гюго": ["юго"],
    "гюльви": ["гюльфи"],
    "гюнцское оледенение": ["белорусское оледенение", "варяжское оледенение", "наровское оледенение"],
    "гюрза": ["левантская гадюка"],
    "гюрултия": ["глъч", "шум"],
    "гянджа": ["елисаветполь", "кировабад"],
    "гянджинский": ["гянджийский"],
    "гяур": ["кафир", "неверный"],
    "гёйгёль": ["еленендорф", "ханлар"],
    "гёйтепе": ["пришиб"],
    "гёк": ["яшыл"],
    "гёль": ["гел"],
    "гёр": ["гур", "гер"],
    "гёрлз": ["гёрлс"],
    "гёрлфренд": ["гёрлфрендша", "партнёрша", "сожительница", "девушка", "подруга", "возлюбленная", "невеста", "избранница", "любовница"],
    "гётит": ["бурая стеклянная голова"],
    "да": ["угу", "ага", "поддерживаю"],
    "да здравствует": ["виват"],
    "да и только": ["еще да", "вот те на"],
    "да ладно": ["иди ты", "шутишь", "брешешь", "гонишь", "ага", "ну да", "конечно", "да"],
    "да ну": ["неужели"],
    "да-да": ["да", "да-да-да"],
    "да-да-да": ["да", "да-да"],
    "даария": ["гиперборея", "арктида"],
    "дабистон": ["дабиристон"],
    "дабл-трап": ["дубль-трап"],
    "даблдекер": ["двухпалубник"],
    "дабранач": ["добрай ночы"],
    "дабурия": ["даббурия"],
    "дабут": ["табут"],
    "дабы": ["чтобы"],
    "дав": ["давши"],
    "давав": ["дававши"],
    "дававши": ["давав"],
    "давай": ["пока", "до встречи", "договорились", "молодец"],
    "давалец": ["заказчик"],
    "давалка": ["распутница", "шлюха", "блядь"],
    "давальщик": ["давалец"],
    "даванда": ["одами тездав"],
    "даванув": ["даванувши"],
    "даванувши": ["даванув"],
    "давануть": ["надавить", "нажать"],
    "даванье": ["давание"],
    "давать добро": ["позволять", "санкционировать"],
    "давать на лапу": ["давать взятку", "совать в зубы", "совать на лапу", "совать в лапу"],
    "давать слово": ["обещать", "давать обещание"],
    "давать ход": ["помогать"],
    "даве": ["недавно", "только что", "давеча", "давя", "накануне", "намедни", "надысь", "на днях"],
    "давеча": ["недавно", "накануне", "намедни", "надысь", "на днях"],
    "давешний": ["недавний", "встретившийся", "упомянутый"],
    "давив": ["давивши"],
    "давивши": ["давив"],
    "давидан": ["давида рафтан", "тохтан"],
    "давидыч": ["давидович"],
    "давильник": ["пресс"],
    "давильня": ["давило"],
    "давить": ["жать", "нажимать", "напирать", "надавливать", "топтать", "растаптывать", "душить", "прессинговать"],
    "давить лыбу": ["ухмыляться", "лыбиться", "лыбу давить", "лыбу тянуть"],
    "давиться": ["удавляться", "удавливаться", "подавливаться", "задыхаться"],
    "давка": ["давиловка", "ходынка", "вторая ходынка"],
    "давкий": ["давлючий"],
    "давлатманд": ["бой", "доро", "сарватманд", "сероб"],
    "давление": ["нажим", "натиск", "напор", "принуждение", "насилие"],
    "давлення": ["тиснення"],
    "давленье": ["давление"],
    "давливав": ["давливавши"],
    "давливавши": ["давливав"],
    "давний": ["давнишний", "древний", "далёкий", "старый"],
    "давнишний": ["давний"],
    "давния": ["дауния"],
    "давно": ["в старину", "встарь", "даве", "давным-давно", "древле", "некогда", "прежде", "раньше", "с давних времён", "с давних пор", "издавна", "издревле", "искони", "исконно", "испокон века"],
    "давнопрошедшее время": ["плюсквамперфект", "предпрошедшее время"],
    "давнопрошедший": ["давний"],
    "давность": ["отдалённость", "древность"],
    "давнув": ["давнувши"],
    "давнувши": ["давнув"],
    "давнуть": ["давануть"],
    "давным-давно": ["в незапамятные времена"],
    "давньоруська мова": ["давньоруська"],
    "давньоруський": ["староруський"],
    "давнёхонько": ["давненько", "давнёшенько"],
    "даврашакл": ["мудаввар"],
    "давывав": ["давывавши"],
    "давывавши": ["давывав"],
    "давёж": ["давление"],
    "даг": ["дагестанец"],
    "дага": ["дагана"],
    "дагеротип": ["дагерротип"],
    "дагеротипия": ["дагерротипия"],
    "дагерротипия": ["светопись", "дагерротип"],
    "дагестан": ["республика дагестан"],
    "дагестанец": ["даг"],
    "дагестано-чеченский": ["дагестанско-чеченский"],
    "дагестанско-чеченский": ["дагестано-чеченский"],
    "даго": ["хийумаа"],
    "дагоба": ["ступа"],
    "дагомеец": ["бенинец", "тоголезец"],
    "дагомея": ["французская дагомея", "республика дагомея"],
    "дагусса": ["коракан"],
    "дагъусттан": ["дагъусттаннал республика"],
    "дагъы": ["дахы"],
    "дада": ["дадаизм"],
    "дадаизм": ["дада"],
    "дадаистический": ["дадаистский"],
    "дадаистский": ["дадаистический"],
    "даденост": ["реалност", "действителност"],
    "дажба": ["дял", "порцион", "порция"],
    "даждь": ["позволь", "разреши", "предоставь", "преподнеси", "вручи", "доставь"],
    "даждьбог": ["дажьбог"],
    "даже": ["аж", "ажно"],
    "дажьбог": ["дажбог", "хорс", "хорос", "ладо", "даждьбог", "хорсъ", "хоросъ"],
    "даивав": ["даивавши"],
    "даивавши": ["даивав"],
    "дай бог": ["дай боже"],
    "дай пять": ["дай пятюню"],
    "дайвер": ["ныряльщик"],
    "дайджестировав": ["дайджестировавши"],
    "дайджестировавши": ["дайджестировав"],
    "дайкон": ["японская редька"],
    "дайм": ["десятицентовик"],
    "дак-тест": ["утиный тест"],
    "дакав": ["дакавши"],
    "дакавши": ["дакав"],
    "дакальщик": ["подхалим"],
    "дакнув": ["дакнувши"],
    "дакнувши": ["дакнув"],
    "дакриолит": ["слёзный камень", "офтальмолит"],
    "дакрон": ["лавсан", "терилен"],
    "дактилировав": ["дактилировавши"],
    "дактилировавши": ["дактилировав"],
    "дактило-хореический": ["дактилохореической"],
    "дактилографический": ["машинописный"],
    "дактилоскопировав": ["дактилоскопировавши"],
    "дактилоскопировавши": ["дактилоскопировав"],
    "дактилоскопировать": ["катать"],
    "дактилоскопия": ["икнофалангометрия"],
    "дактиль": ["палец", "дактильная азбука", "пальцевый алфавит"],
    "дакутэн": ["нигори"],
    "дакфейс": ["утиное лицо", "утиные губы"],
    "дакъикъа": ["дакъкъа"],
    "дал": ["даал", "дхал"],
    "даламбериан": ["даламбертиан", "волновой оператор"],
    "даламбертиан": ["даламбериан", "волновой оператор"],
    "даларна": ["далекарлия", "старая даларна"],
    "далв": ["сатил"],
    "далее": ["затем", "потом", "в дальнейшем"],
    "далеко": ["далёко", "вдалеке", "вдали", "далече", "неблизко", "поодаль"],
    "далел": ["санад", "асос"],
    "далеч": ["далече", "далеко"],
    "далече": ["далеко"],
    "далида": ["далила"],
    "далила": ["далида"],
    "далина": ["даль"],
    "даллас": ["дальнегорск"],
    "далматин": ["далматинец"],
    "далматинец": ["далматин", "далмат"],
    "далматинский": ["далматский"],
    "дальдер": ["даальдер", "дальдре"],
    "дальневидение": ["телевидение", "дальновидение"],
    "дальневосточная республика": ["двр", "красный буфер", "довольно весёлая республика"],
    "дальневосточный край": ["двк"],
    "дальневосточный федеральный округ": ["дфо", "двфо"],
    "дальнегорск": ["тетюхе", "даллас"],
    "дальнейший": ["последующий", "будущий"],
    "дальний": ["далёкий", "удалённый", "отдалённый", "неближний", "неблизкий", "долгий", "протяжённый"],
    "дальнобойщица": ["плечевая"],
    "дальновидно": ["предусмотрительно"],
    "дальновидность": ["проницательность", "предусмотрительность"],
    "дальновидный": ["предусмотрительный"],
    "дальнозоркий": ["зоркий", "остроглазый", "дальновидный", "предусмотрительный"],
    "дальнозоркость": ["дальновидность", "зоркость", "прозорливость", "предусмотрительность", "гиперметропия"],
    "дальность": ["удаление", "дистанция", "расстояние", "отдалённость", "удалённость", "даль"],
    "дальный": ["далёкий", "дальний"],
    "дальняк": ["параша"],
    "дальтон-план": ["далтон-план"],
    "дальтонизм": ["цветовая слепота"],
    "дальтоник": ["дальтонист"],
    "дальше": ["вперёд", "далее", "затем", "потом"],
    "далёкий": ["отдалённый", "удалённый", "дальний", "неблизкий", "неближний", "длинный", "продолжительный", "долгий", "длительный", "давний", "чуждый", "незнакомый"],
    "далёко": ["вдалеке", "вдали", "далеко", "далече", "неблизко", "поодаль"],
    "далёкость": ["дальность"],
    "дама": ["госпожа", "леди", "гражданка", "барышня", "дамочка", "мадама", "фрау", "партнёрша", "ферзь", "королева"],
    "дама сердца": ["возлюбленная"],
    "дамаджана": ["стомна", "шише"],
    "дамажив": ["дамаживши"],
    "дамаживши": ["дамажив"],
    "даманский": ["чжэньбаодао"],
    "дамаскский": ["дамасский"],
    "дамасская сталь": ["булат"],
    "дамасский": ["дамаскский"],
    "дамба": ["плотина"],
    "дамп": ["разгрузка"],
    "дамы и господа": ["леди и джентльмены"],
    "данго": ["оданго"],
    "дандрдо": ["сахари", "гудло"],
    "данил": ["даня", "даник"],
    "данила": ["данил", "даниил"],
    "дания": ["королевство дания"],
    "данность": ["действительность", "реальность"],
    "данные": ["информация", "сведения"],
    "данный": ["этот", "сей", "настоящий", "определённый", "известный"],
    "данс-пол": ["танцпол"],
    "дансилхлорид": ["дансил"],
    "дантист": ["стоматолог"],
    "дань": ["подать", "должное"],
    "дань-тянь": ["дантянь", "даньтянь"],
    "даня": ["даниил", "данька", "данил"],
    "дао": ["логос", "брахман", "до"],
    "даос": ["даосист"],
    "даосизм": ["таосизм"],
    "даосист": ["даос"],
    "дар": ["подарок", "подношение", "презент", "гостинец", "пожертвование", "талант", "дарование", "одарённость", "талантливость", "даровитость", "способность", "задатки"],
    "дар речи": ["дар слова"],
    "дараваць": ["прабачаць", "прабачыць"],
    "дарбази": ["карадам"],
    "дарбар": ["дурбар"],
    "дарвоза": ["боб"],
    "дарение": ["дарование"],
    "даренье": ["дарение", "подношенье", "подношение", "дар"],
    "дари": ["фарси-кабули", "афганско-персидский язык"],
    "дарив": ["даривши"],
    "даривав": ["даривавши"],
    "даривавши": ["даривав"],
    "даривши": ["дарив"],
    "дарий": ["дараявауш"],
    "дарить": ["одарять"],
    "дария": ["дарья"],
    "даркнет": ["скрытая сеть", "теневая сеть", "тёмный интернет", "тёмная сеть", "тёмный веб"],
    "дарма": ["задарма", "даром"],
    "дармовой": ["даровой", "бесплатный", "халявный"],
    "дармоедка": ["тунеядка"],
    "дармоедничав": ["дармоедничавши"],
    "дармоедничавши": ["дармоедничав"],
    "дармоедский": ["тунеядский"],
    "дармоедство": ["тунеядство", "паразитизм", "прихлебательство"],
    "даро": ["дарой"],
    "даровав": ["даровавши"],
    "даровавши": ["даровав"],
    "дарование": ["пожалование", "талант", "дар", "одарённость", "талантливость", "даровитость", "способность", "задатки", "гений"],
    "дарованный": ["подаренный"],
    "дарователь": ["даритель"],
    "даровать": ["одарить", "наградить", "пожаловать"],
    "даровитость": ["талант", "дар", "дарование", "одарённость", "талантливость", "способность", "задатки"],
    "даровитый": ["одарённый", "щедрый"],
    "даровой": ["подаренный", "дарёный", "дармовой", "безвозмездный", "бескорыстный", "бесплатный", "свободный", "халявный"],
    "даровщина": ["дармовщина", "даровщинка", "халява"],
    "даровщинка": ["дармовщинка", "халява"],
    "дароз": ["дур", "чунг", "баланд", "калон"],
    "дароздаст": ["дастдароз"],
    "даром": ["бесплатно", "безвозмездно", "задаром", "задарма", "на шару", "на халяву", "за так", "за просто так", "за здорово живёшь", "за красивые глаза", "за спасибо", "напрасно", "зря", "тщетно", "безуспешно"],
    "даром что": ["хотя", "хотя и", "хоть", "хоть и", "пусть", "пускай"],
    "даромадан": ["дохил шудан"],
    "дарственный": ["даренный", "подарочный"],
    "дарствовав": ["дарствовавши"],
    "дарствовавши": ["дарствовав"],
    "дартс": ["дротик"],
    "дарунок": ["подарунок"],
    "даршан": ["даршана"],
    "дарыс": ["сабак"],
    "дарыу": ["дауа"],
    "дарья": ["даша", "дара", "дашенька", "дашечка", "дашуня", "дашуля", "дашик", "дашка", "даха"],
    "дарёному коню в зубы не смотрят": ["от добра добра не ищут", "дарёному коню под хвост не смотрят"],
    "дарёный": ["подаренный", "безвозмездный", "бескорыстный", "бесплатный", "свободный", "даровой", "дармовой", "халявный"],
    "дасия": ["густое придыхание"],
    "дастбанд": ["дастпона"],
    "дастдароз": ["дароздаст"],
    "дастор": ["аммома"],
    "дастпона": ["дастбанд"],
    "дата-сайентист": ["аналитик данных"],
    "дата-центр": ["датацентр"],
    "датабаза": ["база данных", "бд"],
    "датаграмма": ["дейтаграмма", "дэйтаграмма"],
    "датацентр": ["дата-центр"],
    "датель": ["даятель"],
    "дательный": ["дативный", "датив", "дательный падеж"],
    "дательный падеж": ["датив"],
    "датив": ["дательный падеж"],
    "датировав": ["датировавши"],
    "датировавши": ["датировав"],
    "датирование": ["датировка"],
    "датировка": ["датирование", "дата", "возраст"],
    "датский язык": ["датский"],
    "датський": ["данський"],
    "датчик": ["сенсор", "детектор", "сканер"],
    "датый": ["поддатый", "нетрезвый", "бухой"],
    "дать": ["предоставить"],
    "дать в бубен": ["дать по морде"],
    "дать в хрюсло": ["дать в бубен"],
    "дать добро": ["позволить", "санкционировать"],
    "дать дёру": ["сбежать"],
    "дать крюк": ["дать крюка", "дать крюку"],
    "дать крюка": ["дать крюк", "дать крюку"],
    "дать крюку": ["дать крюк", "дать крюка"],
    "дать маху": ["промахнуться", "промазать", "совершить ошибку"],
    "дать на клык": ["выдать на клык", "дать за щеку", "дать в рот", "дать на клыка", "на клык дать", "на клык выдать", "за щеку дать"],
    "дать пизды": ["отделать", "уделать", "отмудохать", "измудохать", "отпиздить", "испиздить", "отхуярить", "исхуярить", "вломить пизды", "пиздюлей навесить", "пиздюлей отвесить", "пизды дать"],
    "дать плоды": ["окупиться"],
    "дать по пизде мешалкой": ["надавать по пизде мешалкой"],
    "дать под дых": ["ударить под дых", "прессануть"],
    "дать прикурить": ["задать жару", "задать перцу", "дать просраться"],
    "дать пять": ["дать пятюню"],
    "дать слово": ["обещать"],
    "дать тягу": ["дать дёру", "дать тёку", "дать тягуна", "дать бегуна", "дать лататы", "дать сквозняка", "дать тягача", "дать тягаля", "дать тягиля"],
    "дать удовлетворение": ["дать сатисфакцию"],
    "даугава": ["западная двина"],
    "даун": ["дурак", "идиот"],
    "даун-пэймент": ["даун-пеймент", "даунпеймент"],
    "даунизм": ["синдром дауна", "болезнь дауна"],
    "дауния": ["давния"],
    "даунпеймент": ["даун-пэймент"],
    "даунсайзинг": ["шринкфляция"],
    "даунсвинг": ["даунстрик"],
    "даунстрик": ["даунсвинг"],
    "даурит": ["рубеллит"],
    "даурия": ["даурская земля"],
    "дауэсизировав": ["дауэсизировавши"],
    "дауэсизировавши": ["дауэсизировав"],
    "дафна": ["волчье лыко", "волчеягодник"],
    "дафния": ["водяная блоха"],
    "дахы": ["дагъы"],
    "дача": ["фазенда", "надел", "землевладение"],
    "дачник": ["садовод", "огородник", "фазендейер", "домовладелец", "горожанин", "городской"],
    "даша": ["дарья"],
    "дашогуз": ["дашховуз", "ташауз"],
    "дашогузский велаят": ["дашховузский велаят", "ташаузская область"],
    "даяние": ["дар"],
    "даянье": ["даяние", "дар"],
    "дбайливий": ["дбалий", "ретельний"],
    "дбайний": ["дбайливий"],
    "дбалий": ["дбайливий", "ретельний"],
    "дбати": ["турбуватися", "клопотатися", "виготовляти", "заготовляти", "заготовлювати", "працювати", "заробляти", "придбавати", "надбувати"],
    "дбать": ["заботиться", "стараться", "копить"],
    "дбаха": ["дбач"],
    "дбач": ["дбайливець"],
    "два": ["пара", "двойка"],
    "два аякса": ["закадычный друг"],
    "два сапога пара": ["под стать", "одного поля ягода", "одним миром мазаны", "сладкая парочка"],
    "двадесет": ["двайсет"],
    "двадцатигранник": ["икосаэдр"],
    "двадцатигранный": ["икосаэдральный", "икосаэдрический"],
    "двадцатидневный": ["трёхнедельный"],
    "двадцатилетье": ["двадцатилетие"],
    "двадцатипятирублёвка": ["четвертак", "четвертной", "четвертная"],
    "двадцатиугольник": ["икосагон"],
    "двадцатичетырёхгранник": ["дидодекаэдр", "гексатетраэдр", "икоситетраэдр"],
    "двадцатичетырёхчасовой": ["суточный", "полночный", "круглосуточный"],
    "двадцаточка": ["двадцатка"],
    "двадцать": ["двадцатник", "двадцатка"],
    "двадцать одно": ["очко", "двадцать одно очко"],
    "двадцать семь": ["тридевять"],
    "двадцать четыре удовольствия": ["тридцать три удовольствия", "все тридцать три удовольствия"],
    "двайсет": ["двадесет"],
    "дванадесет": ["дванайсет"],
    "дванадесять": ["двенадцать"],
    "двапять": ["десять"],
    "дварим": ["второзаконие"],
    "двенадцатигранник": ["додекаэдр"],
    "двенадцатидюймовка": ["гигант"],
    "двенадцатиугольник": ["додекагон"],
    "двенадцатиугольный": ["додекагональный"],
    "двенадцать": ["дванадесять", "дюжина"],
    "дверка": ["дверца"],
    "дверца": ["створка"],
    "дверь": ["ворота", "врата", "портал", "вход", "выход", "проход", "створка", "путь"],
    "двеста": ["двесте"],
    "двига": ["движка", "движок"],
    "двигав": ["двигавши"],
    "двигавши": ["двигав"],
    "двигание": ["двиганье", "движение"],
    "двиганье": ["двигание"],
    "двигатель": ["мотор", "движок", "двигло", "пружина"],
    "двигатель внутреннего сгорания": ["двс"],
    "двигательный": ["моторный", "движущий"],
    "двигать": ["шевелить", "перемещать", "побуждать", "стимулировать", "мотивировать"],
    "двигаться": ["перемещаться", "передвигаться", "направляться", "трогаться", "отправляться", "расти"],
    "двигнув": ["двигнувши"],
    "двигнувши": ["двигнув"],
    "двигнутый": ["сдвинутый"],
    "двигнуть": ["двинуть", "шевельнуть"],
    "двигнуться": ["пошевелиться", "сдвинуться", "шевельнуться"],
    "двигун": ["мотор"],
    "двигунець": ["двигунчик"],
    "двиджа": ["дваждырождённый"],
    "движение": ["перемещение"],
    "движив": ["движивши"],
    "движивши": ["движив"],
    "движимость": ["движимое имущество", "подвижность"],
    "движитель": ["привод", "передача", "двигатель"],
    "движить": ["двигать"],
    "движок": ["бегунок", "мотор", "двигатель", "ядро"],
    "движуха": ["деятельность", "движение", "активность", "подвижность", "движ"],
    "двинский": ["двинской"],
    "двинской": ["двинский"],
    "двинув": ["двинувши"],
    "двинувши": ["двинув"],
    "двинуться": ["задвигаться", "зашевелиться", "отправиться", "тронуться", "пошевелиться", "пошевельнуться", "шевельнуться", "рехнуться"],
    "двое": ["два", "пара"],
    "двоеверец": ["двоеверка"],
    "двоеверие": ["двоеверье", "двуверие"],
    "двоевластие": ["диархия", "двоевластье"],
    "двоевластье": ["двоевластие"],
    "двоеглавый": ["двуглавый"],
    "двоегласный": ["двугласный"],
    "двоедушие": ["лицемерие", "двуличие", "двоедушье"],
    "двоедушник": ["лицемер"],
    "двоедушничав": ["двоедушничавши"],
    "двоедушничавши": ["двоедушничав"],
    "двоедушничать": ["лицемерить"],
    "двоедушный": ["двуличный", "лицемерный", "неискренний"],
    "двоежопие": ["двуличие", "двуличье"],
    "двоежёнство": ["бигиния", "бигамия"],
    "двоекратно": ["дважды", "повторно"],
    "двоекратный": ["двукратный", "двухкратный"],
    "двоелистник": ["мать-и-мачеха"],
    "двоеморх": ["рытый", "бархат"],
    "двоемужество": ["двоемужие", "биандрия"],
    "двоемужие": ["двоемужество", "биандрия"],
    "двоемужница": ["двумужница"],
    "двоеперстие": ["двуперстие"],
    "двоестишие": ["двустишие"],
    "двоетёс": ["двутёс"],
    "двоетёсный": ["двутёсный", "двухтёсный"],
    "двоецарствие": ["двуцарствие"],
    "двоечник": ["отстающий", "мастер-ломастер", "неумеха"],
    "двоечница": ["хвостистка"],
    "двоешка": ["близнец", "близняшка", "двойняшка"],
    "двоив": ["двоивши"],
    "двоивши": ["двоив"],
    "двоица": ["пара"],
    "двоичность": ["бинарность"],
    "двоичный": ["бинарный"],
    "двойбан": ["два", "двойка", "двояк", "пара"],
    "двойка": ["тандем", "пара", "два", "двояк", "неуд"],
    "двойник": ["копия", "дубль"],
    "двойничник": ["двойняшка", "близнец"],
    "двойнишник": ["двойняшка"],
    "двойной": ["удвоенный", "двукратный", "двоичный", "двухэтапный", "двузвенный", "двуличный"],
    "двойной стандарт": ["двойная мораль", "двоемыслие"],
    "двойня": ["двойняшки", "близнецы", "двойнишки", "двоешни"],
    "двойняшка": ["двояшка", "двойнишник"],
    "двойственно": ["двояко"],
    "двойственное число": ["дуалис"],
    "двойственность": ["двойство", "двоякость", "противоречивость", "дуализм", "двуличие"],
    "двойственный": ["противоречивый", "неоднозначный", "двуличный", "двоякий"],
    "двойство": ["двойственность", "двоякость"],
    "дворецкий": ["гофмейстер", "мажордом", "старший лакей"],
    "дворник": ["уборщик"],
    "дворницкий": ["дворничий", "дворнический"],
    "дворничав": ["дворничавши"],
    "дворничавши": ["дворничав"],
    "дворнический": ["дворницкий"],
    "дворняга": ["барбос", "дворняжка", "двортерьер"],
    "дворняжка": ["дворняга", "шавка"],
    "дворовое место": ["двор"],
    "дворовой": ["дворовый"],
    "дворский": ["придворный"],
    "дворф": ["гном"],
    "дворянство": ["благородное сословие", "голубая кровь", "белая кость"],
    "двофазний": ["двофазовий"],
    "двофазовий": ["двофазний"],
    "двоюродная бабушка": ["двоюродная бабка"],
    "двоюродная внучка": ["внучатая племянница"],
    "двоюродная сестра": ["кузина"],
    "двоюродная тётка": ["двоюродная тётя"],
    "двоюродная тётя": ["двоюродная тётка"],
    "двоюродный брат": ["кузен"],
    "двоюродный внук": ["внучатый племянник"],
    "двоюродный дед": ["двоюродный дедушка"],
    "двоюродный дедушка": ["двоюродный дед"],
    "двояк": ["два", "двойка", "неудовлетворительно", "медловка", "бык"],
    "двоякий": ["двойной", "двойственный"],
    "двояковогнутый": ["амфицельный"],
    "двояковыпуклый": ["обоевыпуклый"],
    "двоякодышащие": ["двудышащие"],
    "двоякодышащий": ["двудышащий"],
    "двоякопильчатый": ["двупильчатый"],
    "двоякопреломляющий": ["двупреломляющий"],
    "двояшка": ["двойняшка", "двойчатка"],
    "двс": ["двигатель внутреннего сгорания"],
    "двубережный": ["двусторонний"],
    "двублоковый": ["двухблоковый"],
    "двубой": ["дуел", "разпра"],
    "двубрачие": ["второбрачие"],
    "двувершинный": ["двухвершинный"],
    "двувесельный": ["двухвесельный"],
    "двувидовой": ["двухвидовой", "двувидный"],
    "двуволновой": ["двухволновой"],
    "двуглазый": ["двухглазый"],
    "двугласный": ["дифтонгический", "двухголосный"],
    "двугодичный": ["двухгодичный"],
    "двуголовый": ["двухголовый"],
    "двуголосный": ["двухголосный", "двуголосый", "двухголосый"],
    "двуголосый": ["двуголосный", "двухголосный"],
    "двугорбый верблюд": ["бактриан"],
    "двугранник": ["диэдр"],
    "двугривенник": ["двугривенный"],
    "двугривенный": ["двугривенник", "двухгривенный"],
    "двудверный": ["двухдверный"],
    "двудетный": ["двухдетный"],
    "двудольные": ["двусемядольные", "двусеменодольные", "магнолиопсиды"],
    "двудольный": ["двусемядольный", "двусеменодольный"],
    "двудонный": ["двухдонный"],
    "двудушевой": ["двухдушевой"],
    "двудушник": ["двухдушник"],
    "двудушный": ["двудушевой", "двухдушевой", "двоедушный", "двуличный"],
    "двужаберные": ["колеоиды"],
    "двужаберный": ["колеоидея"],
    "двужилый": ["двужильный"],
    "двужильный": ["крепкий", "сильный", "выносливый"],
    "двузамещённый": ["двухзамещённый"],
    "двузначный": ["двухзначный", "двоякий"],
    "двузуб": ["двузубка"],
    "двузубка": ["двузуб"],
    "двузубый": ["двухзубый", "двузубчатый"],
    "двуклассный": ["двухклассный"],
    "двуколка": ["двухколёска"],
    "двуколёсный": ["двухколёсный"],
    "двуконечный": ["двухконечный"],
    "двуконный": ["пароконный"],
    "двукопытный": ["жвачный", "парнокопытный"],
    "двукратно": ["дважды", "вдвое"],
    "двукратный": ["двухкратный"],
    "двукрылый": ["двухкрылый"],
    "двуластик": ["интерлок"],
    "двулетний": ["двухлетний", "двулетный", "двугодный", "двугодовалый", "двугодовой"],
    "двуликий": ["двуличный"],
    "двулистный": ["двухлистный"],
    "двулицый": ["двуликий"],
    "двуличие": ["двоедушие", "двуличность", "двоедушье", "двуличье"],
    "двуличник": ["лицемер", "двуличница", "мать-и-мачеха"],
    "двуличничав": ["двуличничавши"],
    "двуличничавши": ["двуличничав"],
    "двуличность": ["лицемерность", "неискренность", "двуличие"],
    "двуличный": ["двуликий", "двулицый", "двоедушный", "лицемерный"],
    "двуличье": ["двуличие"],
    "двумерность": ["двухмерность"],
    "двумерный": ["двухмерный", "поверхностный"],
    "двуместный": ["двухместный"],
    "двумужие": ["двоемужие"],
    "двумужница": ["двоемужница"],
    "двунога": ["сошка", "подсошка"],
    "двуокись": ["двуоксид", "диоксид"],
    "двуокись углерода": ["диоксид углерода", "угольный ангидрид", "углекислый газ", "углекислота"],
    "двуокись хрома": ["диоксид хрома"],
    "двуоксид": ["диоксид", "двуокись"],
    "двуосный": ["двухосный"],
    "двуострый": ["обоюдоострый"],
    "двупалый": ["двоепалый", "двухпалый", "двуперстный", "двохпалый"],
    "двупереходный": ["трёхвалентный"],
    "двуперстие": ["двоеперстие"],
    "двуперстный": ["двуперстый", "двупалый"],
    "двуперстье": ["двуперстие"],
    "двуполюсный": ["биполярный"],
    "двуполярный": ["двухполярный", "биполярный", "диполярный"],
    "двупреломление": ["двойное лучепреломление"],
    "двупудовый": ["двухпудовый"],
    "двуречье": ["месопотамия", "междуречье"],
    "двурогий": ["серповидный"],
    "двурульный": ["двухрульный"],
    "двурушник": ["иуда", "оборотень", "двурушница", "перебежчик", "перевёртыш"],
    "двурушничав": ["двурушничавши"],
    "двурушничавши": ["двурушничав"],
    "двурушничество": ["двоедушие", "двуличие", "двуличность"],
    "двурядный": ["двухрядный"],
    "двусветный": ["двухсветный"],
    "двусвечник": ["дикирий"],
    "двусеменодольные": ["двудольные", "двусемядольные"],
    "двусемядольные": ["двудольные", "двусеменодольные"],
    "двусемядольный": ["двудольный", "двусеменодольный"],
    "двусемянный": ["двухсемянный", "дисперматический"],
    "двускатный": ["двухскатный"],
    "двусложный": ["двухсложный"],
    "двуслойный": ["двухслойный"],
    "двусменный": ["двухсменный"],
    "двусмысленность": ["неоднозначность", "двузначность"],
    "двуспальный": ["двухспальный"],
    "двустволка": ["двухстволка", "двудулка"],
    "двуствольный": ["двухствольный"],
    "двустворчатый": ["двустворный", "двухстворчатый"],
    "двустишие": ["дистих"],
    "двустишье": ["двустишие"],
    "двусторонка": ["двухсторонка"],
    "двусторонневыпуклый": ["двоякосторонневыпуклый", "двояковыпуклый"],
    "двусторонний": ["двухсторонний"],
    "двутавр": ["двутавровая балка"],
    "двутактный": ["двухтактный"],
    "двутёс": ["двоетёс"],
    "двуугольник": ["двухугольник", "дигон"],
    "двуутробка": ["опоссум", "сумчатая крыса", "сумчатое"],
    "двуфунтовый": ["двухфунтовый"],
    "двухатомный": ["двуатомный"],
    "двухбайтовый": ["шестнадцатибитный"],
    "двухбашенный": ["двубашенный"],
    "двухблоковый": ["двублоковый"],
    "двухвалютный": ["бивалютный"],
    "двухвершинный": ["двувершинный"],
    "двухвинтовой": ["двухроторный"],
    "двухвостка": ["уховёртка", "кожистокрылое", "вилохвостка", "двойчатка"],
    "двухвёдерный": ["двухведёрный"],
    "двухвёрстка": ["двухкилометровка"],
    "двухглазый": ["двуглазый"],
    "двухгодичник": ["пиджак"],
    "двухгодичный": ["двугодичный"],
    "двухгодовой": ["двухгодичный", "двухгодовалый"],
    "двухголовый": ["двуглавый", "двуголовый"],
    "двухголосие": ["двоегласие"],
    "двухголосье": ["двухголосие"],
    "двухгривенный": ["двугривенный"],
    "двухдверный": ["двудверный"],
    "двухдетный": ["двудетный"],
    "двухдольный": ["двудольный"],
    "двухдонный": ["двудонный"],
    "двухдушевой": ["двудушевой"],
    "двухзамещённый": ["двузамещённый"],
    "двухзначный": ["двузначный"],
    "двухзубый": ["двузубый", "двузубчатый"],
    "двухколейный": ["двухпутный"],
    "двухколёсный": ["двуколёсный"],
    "двухконечный": ["двуконечный"],
    "двухкопеечник": ["семишник"],
    "двухкратный": ["двукратный"],
    "двухкрылый": ["двукрылый"],
    "двухлетний": ["двулетний", "двухгодовалый"],
    "двухлопастной": ["двухлопастный"],
    "двухлопастный": ["двухлопастной"],
    "двухмерность": ["двумерность"],
    "двухмерный": ["двумерный", "поверхностный"],
    "двухместный": ["двуместный"],
    "двухметроворостый": ["двухметровый"],
    "двухметровый": ["двуметровый"],
    "двухмодальный": ["бимодальный"],
    "двухосный": ["двуосный"],
    "двухпартийность": ["двухпартийная система"],
    "двухполоска": ["двухрядка"],
    "двухпольный": ["двупольный"],
    "двухполюсный": ["биполярный"],
    "двухполярный": ["двуполярный"],
    "двухпудовка": ["тридцатидвухкилограммовка"],
    "двухпульный": ["дуплексный"],
    "двухрублёвик": ["андреевский золотой"],
    "двухрульный": ["двурульный"],
    "двухрядный": ["двурядный"],
    "двухсветный": ["двусветный"],
    "двухсимочный": ["двусимочный", "двухсимковый", "двусимковый"],
    "двухслойный": ["двуслойный"],
    "двухсменный": ["двусменный"],
    "двухсогласный": ["двусогласный"],
    "двухсотить": ["мочить", "валить"],
    "двухсотка": ["двухсотрублёвка"],
    "двухсотлетний": ["двухвековой"],
    "двухсотрублёвка": ["двухсотка"],
    "двухствольный": ["двуствольный"],
    "двухстворчатый": ["двустворчатый"],
    "двухстопный": ["двустопный"],
    "двухсторонка": ["двусторонка"],
    "двухсторонний": ["двусторонний"],
    "двухфазный": ["двухфазовый"],
    "двухфазовый": ["двухфазный"],
    "двухфакторка": ["двухфакторная аутентификация"],
    "двухфакторная аутентификация": ["двухфакторка"],
    "двухфакторный": ["двуфакторный", "бифакторный"],
    "двухфокусный": ["двуфокусный"],
    "двухфунтовый": ["двуфунтовый"],
    "двухцветный": ["бихроматический", "дихроический", "дихроичный"],
    "двухчасовой": ["стодвадцатиминутный"],
    "двухшпиндельный": ["двушпиндельный"],
    "двухшёрстный": ["двушёрстный"],
    "двухъяйцовый": ["двухяйцовый"],
    "двухъярусность": ["двухярусность"],
    "двухъярусный": ["двухуровневый", "двуярусный", "двухэтажный"],
    "двухэтажный": ["двуэтажный", "двухпалубный", "громоздкий", "замысловатый", "витиеватый", "изощрённый"],
    "двухяйцовый": ["двухъяйцовый"],
    "двуцарствие": ["двоецарствие"],
    "двуцветный": ["двухцветный"],
    "двучерепной": ["двустворчатый"],
    "двучлен": ["бином"],
    "двушёрстный": ["двухшёрстный"],
    "двуядерный": ["двухъядерный"],
    "двуязычие": ["билингвизм"],
    "двуязычный словарь": ["переводной словарь"],
    "двьрь": ["двьри", "врата"],
    "ддт": ["дихлордифенилтрихлорэтан", "дуст", "дихлордифенилтрихлорметилметан", "цдт"],
    "де": ["дескать", "дискать", "мол", "молвил", "стало быть", "грит", "гыт"],
    "де-": ["дез-", "раз-"],
    "де-факто": ["фактически", "на деле", "практически"],
    "деавторизовав": ["деавторизовавши"],
    "деавторизовавши": ["деавторизовав"],
    "деактивация": ["дезактивация", "деактивирование", "дезактивирование", "пассивирование", "пассивация"],
    "деактивировав": ["деактивировавши"],
    "деактивировавши": ["деактивировав"],
    "деактивировать": ["дезактивировать"],
    "деактуализовав": ["деактуализовавши"],
    "деактуализовавши": ["деактуализовав"],
    "деактуализовать": ["деактуализировать"],
    "деанглификация": ["деанглизация"],
    "деанон": ["деанонимизация"],
    "деанонимизация": ["деанон"],
    "деанонимизировав": ["деанонимизировавши"],
    "деанонимизировавши": ["деанонимизировав"],
    "деаэрировав": ["деаэрировавши"],
    "деаэрировавши": ["деаэрировав"],
    "дебаггер": ["отладчик"],
    "дебажить": ["отлаживать"],
    "дебальцевский котёл": ["дебальцевская дуга"],
    "дебаркадер": ["пристань", "перрон"],
    "дебатировав": ["дебатировавши"],
    "дебатировавши": ["дебатировав"],
    "дебатировать": ["обсуждать"],
    "дебатёр": ["спорщик"],
    "дебелость": ["дородность", "полнота", "пухлость", "тучность", "грузность"],
    "дебет": ["приход", "убыток", "дебит"],
    "дебетировав": ["дебетировавши"],
    "дебетировавши": ["дебетировав"],
    "дебетовав": ["дебетовавши"],
    "дебетовавши": ["дебетовав"],
    "дебетовать": ["дебетировать", "приходовать", "оприходовать"],
    "дебил": ["слабоумный"],
    "дебилизировав": ["дебилизировавши"],
    "дебилизировавши": ["дебилизировав"],
    "дебилизм": ["дебильность", "идиотизм"],
    "дебилизовав": ["дебилизовавши"],
    "дебилизовавши": ["дебилизовав"],
    "дебилоид": ["баран", "недоумок", "дурак", "идиотина", "дебил", "олигофрен"],
    "дебильность": ["имбецильность"],
    "дебильный": ["дурацкий", "глупый", "нелепый"],
    "дебилёныш": ["баран", "недоумок", "дурак", "идиотина", "дебил", "олигофрен"],
    "дебитовав": ["дебитовавши"],
    "дебитовавши": ["дебитовав"],
    "дебитор": ["должник"],
    "деблокировав": ["деблокировавши"],
    "деблокировавши": ["деблокировав"],
    "деблокирование": ["деблокировка", "освобождение"],
    "деблокировать": ["разблокировать"],
    "дебордировав": ["дебордировавши"],
    "дебордировавши": ["дебордировав"],
    "дебошир": ["скандалист", "забияка", "дебошник", "буян", "хулиган"],
    "дебоширив": ["дебоширивши"],
    "дебоширивши": ["дебоширив"],
    "дебоширить": ["дебоширствовать", "дебошничать", "буянить", "скандалить", "распутничать"],
    "дебоширничав": ["дебоширничавши"],
    "дебоширничавши": ["дебоширничав"],
    "дебоширский": ["хулиганский"],
    "дебоширство": ["бузотёрство", "буянство", "хулиганство"],
    "дебоширствовав": ["дебоширствовавши"],
    "дебоширствовавши": ["дебоширствовав"],
    "дебошничав": ["дебошничавши"],
    "дебошничавши": ["дебошничав"],
    "дебри": ["глушь", "заросли", "чаща", "чащоба", "захолустье", "медвежий угол"],
    "дебушировав": ["дебушировавши"],
    "дебушировавши": ["дебушировав"],
    "дебюрократизировав": ["дебюрократизировавши"],
    "дебюрократизировавши": ["дебюрократизировав"],
    "дебют": ["почин", "премьера", "старт", "начало"],
    "дебют-альбом": ["дебютный", "альбом"],
    "дебютант": ["новичок"],
    "дебютировав": ["дебютировавши"],
    "дебютировавши": ["дебютировав"],
    "дева": ["девушка", "девица", "девственница"],
    "девав": ["девавши"],
    "девавши": ["девав"],
    "девайс": ["дивайс"],
    "девальвация": ["обесценивание", "обесценение"],
    "девальвировав": ["девальвировавши"],
    "девальвировавши": ["девальвировав"],
    "девальвирование": ["девальвация", "обесценивание"],
    "девальвировать": ["обесценивать", "обесценить"],
    "деваха": ["девка", "девушка"],
    "девелопер": ["программист", "программер", "кодер", "разработчик"],
    "девелопмент": ["девелопинг", "разработка"],
    "деветнадесет": ["деветнайсет"],
    "девиантность": ["девиация"],
    "девиантный": ["ненормальный"],
    "девиация": ["филогенез", "извращение"],
    "девиз": ["лозунг"],
    "девикифицировав": ["девикифицировавши"],
    "девикифицировавши": ["девикифицировав"],
    "девитализировав": ["девитализировавши"],
    "девитализировавши": ["девитализировав"],
    "девица": ["дева", "девушка", "барышня", "девчонка", "деваха", "девка", "чувиха"],
    "девичествовать": ["сидеть в девках", "девовать"],
    "девка": ["девушка", "девица"],
    "девкин": ["девахин", "девий", "девичий", "девушкин"],
    "девовать": ["девичествовать", "девствовать"],
    "девойка": ["момиче", "мома"],
    "деволюция": ["инволюция"],
    "девон": ["девоншир"],
    "девонский период": ["девон", "девонская система"],
    "девоншир": ["девон"],
    "девот": ["ханжа", "святоша"],
    "девотствовать": ["ханжествовать", "ханжить"],
    "девочий монастырь": ["девичий монастырь", "девий монастырь"],
    "девочка по вызову": ["девушка по вызову"],
    "девочка-девочка": ["девочка-припевочка"],
    "девственная плева": ["гимен"],
    "девственница": ["девушка", "дева", "девица", "весталка", "целка"],
    "девственный": ["целомудренный", "невинный", "непорочный"],
    "девственный брак": ["виргогамия", "непорочное супружество"],
    "девство": ["безбрачие", "девичество", "девственность", "непорочность"],
    "девствовав": ["девствовавши"],
    "девствовавши": ["девствовав"],
    "девушка": ["дева", "девица", "горничная", "девка", "барышня", "сударыня", "гёрлфренд"],
    "девушка лёгкого поведения": ["женщина лёгкого поведения", "древнейшая профессия"],
    "девушка по вызову": ["девочка по вызову"],
    "девушкин": ["девахин", "девий", "девичий", "девкин"],
    "девчата": ["девочки", "девушки"],
    "девчачий": ["девический", "девичий", "девчоночий", "девчоночный"],
    "девчонка": ["девочка"],
    "девчоночий": ["девчачий"],
    "девчоночка": ["девчушка", "девчурка"],
    "девши": ["дев"],
    "девяностик": ["девяностник", "девятидесятник"],
    "девяностник": ["девяностик", "девятидесятник"],
    "девясил": ["инула"],
    "девятерной": ["девятичастный", "девятикратный"],
    "девятеро": ["девять"],
    "девятигранник": ["эннеаэдр"],
    "девятидесятник": ["девяностик", "девяностник"],
    "девятихвостка": ["кошка", "плеть", "плётка"],
    "девятый": ["номер", "девять", "девятая часть", "девятый час"],
    "девять": ["девятка"],
    "дегазировав": ["дегазировавши"],
    "дегазировавши": ["дегазировав"],
    "дегалоидировав": ["дегалоидировавши"],
    "дегалоидировавши": ["дегалоидировав"],
    "дегатировав": ["дегатировавши"],
    "дегатировавши": ["дегатировав"],
    "дегельминтизация": ["дегельминтация"],
    "дегенерал": ["говнокомандующий"],
    "дегенерат": ["вырожденец", "выродок", "ублюдок"],
    "дегенеративный": ["дегенерационный", "выродившийся", "вырождающийся"],
    "дегенерация": ["вырождение", "деградация"],
    "дегенерировав": ["дегенерировавши"],
    "дегенерировавши": ["дегенерировав"],
    "дегероизация": ["развенчание", "развенчивание"],
    "дегероизировав": ["дегероизировавши"],
    "дегероизировавши": ["дегероизировав"],
    "дегидратация": ["обезвоживание"],
    "дегидратировав": ["дегидратировавши"],
    "дегидратировавши": ["дегидратировав"],
    "дегидрировав": ["дегидрировавши"],
    "дегидрировавши": ["дегидрировав"],
    "дегидрировать": ["дегидрогенизировать", "осушать"],
    "дегидрогенизация": ["дегидрирование"],
    "дегоржаж": ["дегоржирование"],
    "дегоржирование": ["дегоржаж"],
    "деградант": ["дегенерат", "деградат"],
    "деградация": ["упадок", "регресс"],
    "деграде": ["градиент"],
    "деградировав": ["деградировавши"],
    "деградировавши": ["деградировав"],
    "деградированный": ["деградировавший"],
    "дегрессивный": ["нисходящий", "снижающийся", "уменьшающийся"],
    "дегрод": ["дурак", "тупица", "дегенерат", "идиот", "придурок", "дебил"],
    "дегтевой": ["дёгтевый"],
    "дегтярник": ["дегтярь"],
    "дегуманизировав": ["дегуманизировавши"],
    "дегуманизировавши": ["дегуманизировав"],
    "дегуманизироваться": ["обесчеловечиться"],
    "дегуммировав": ["дегуммировавши"],
    "дегуммировавши": ["дегуммировав"],
    "дегустация": ["опробование", "дегустирование"],
    "дегустировав": ["дегустировавши"],
    "дегустировавши": ["дегустировав"],
    "дегустировать": ["опробовать"],
    "дед": ["прародитель", "дедушка", "старик", "дедка", "невежда"],
    "дед мороз": ["дед-мороз"],
    "дед пихто": ["конь в пальто"],
    "дед-мороз": ["дедушка-мороз"],
    "дедвейт": ["грузоподъёмность"],
    "деддом": ["дом престарелых"],
    "дедифференциация": ["нивелирование", "дедифференцировка"],
    "дедка": ["речник"],
    "дедов": ["дедушкин", "дедкин", "дедовский", "дедулин"],
    "дедовский": ["дедов", "старинный", "унаследованный", "старомодный", "замшелый", "устаревший"],
    "дедовщина": ["неуставные отношения", "неуставные взаимоотношения", "дедовство", "стариковщина", "местовщина", "годковщина"],
    "дедсад": ["дом престарелых"],
    "дедубликация": ["дедупликация"],
    "дедукция": ["вывод"],
    "дедуля": ["дедуня", "дедуся"],
    "дедуня": ["дедуля", "дедуся"],
    "дедупликация": ["дедубликация"],
    "дедуся": ["дедуля", "дедуня"],
    "дедуцировав": ["дедуцировавши"],
    "дедуцировавши": ["дедуцировав"],
    "дедушка": ["дед", "праотец", "старик", "дембель", "старослужащий"],
    "дедушка мороз": ["дед мороз", "морозко"],
    "дедушкин": ["дедкин", "дедов", "дедовский", "дедулин"],
    "деепричастие": ["конверб", "герундий"],
    "дееспособность": ["деликтоспособность"],
    "дееспособный": ["работоспособный", "вменяемый", "правомочный"],
    "дежурив": ["дежуривши"],
    "дежуривши": ["дежурив"],
    "дежурить": ["караулить"],
    "дежурка": ["дежурная часть"],
    "дежурная часть": ["дежурка"],
    "дежурный": ["дневальный"],
    "дез-": ["де-"],
    "деза": ["дезинформация", "дезуха", "дезинформирование"],
    "дезабилье": ["неглиже", "неодетый"],
    "дезавуировав": ["дезавуировавши"],
    "дезавуировавши": ["дезавуировав"],
    "дезавуировать": ["опровергать"],
    "дезагрегация": ["дезагрегирование"],
    "дезагрегировав": ["дезагрегировавши"],
    "дезагрегировавши": ["дезагрегировав"],
    "дезагрегирование": ["разукрупнение", "разделение"],
    "дезадаптировав": ["дезадаптировавши"],
    "дезадаптировавши": ["дезадаптировав"],
    "дезактивизация": ["дезактивация"],
    "дезактивировав": ["дезактивировавши"],
    "дезактивировавши": ["дезактивировав"],
    "дезактивировать": ["деактивировать"],
    "дезаминировав": ["дезаминировавши"],
    "дезаминировавши": ["дезаминировав"],
    "дезартикуляция": ["вылущивание"],
    "дезертир": ["уклонист", "дезик"],
    "дезертировав": ["дезертировавши"],
    "дезертировавши": ["дезертировав"],
    "дезертирствовав": ["дезертирствовавши"],
    "дезертирствовавши": ["дезертирствовав"],
    "дезертирувати": ["дезертувати"],
    "дезертификация": ["опустынивание"],
    "дезертувати": ["дезертирувати"],
    "дезидерия": ["желание"],
    "дезинсектировав": ["дезинсектировавши"],
    "дезинсектировавши": ["дезинсектировав"],
    "дезинтегратор": ["измельчитель", "дробилка"],
    "дезинтегрировав": ["дезинтегрировавши"],
    "дезинтегрировавши": ["дезинтегрировав"],
    "дезинфекция": ["обеззараживание"],
    "дезинфицировав": ["дезинфицировавши"],
    "дезинфицировавши": ["дезинфицировав"],
    "дезинфицировать": ["обеззараживать", "обеззаразить"],
    "дезинформация": ["деза", "дезуха", "дезинформирование"],
    "дезинформировав": ["дезинформировавши"],
    "дезинформировавши": ["дезинформировав"],
    "дезинформирование": ["дезинформация"],
    "дезинформировать": ["дезить"],
    "дезодорант": ["деодорант"],
    "дезодорировав": ["дезодорировавши"],
    "дезодорировавши": ["дезодорировав"],
    "дезодорирование": ["дезодорация", "дезодоризация"],
    "дезоксирибонуклеиновая кислота": ["днк"],
    "дезоморфин": ["крокодил", "борщ", "электроширка", "электричка"],
    "дезорганизация": ["разлад"],
    "дезорганизовав": ["дезорганизовавши"],
    "дезорганизовавши": ["дезорганизовав"],
    "дезорганизовывав": ["дезорганизовывавши"],
    "дезорганизовывавши": ["дезорганизовывав"],
    "дезориентировав": ["дезориентировавши"],
    "дезориентировавши": ["дезориентировав"],
    "дезориентировать": ["вводить в заблуждение", "сбивать с толку"],
    "дезсредство": ["дезинфицирующее средство"],
    "дезурбанизация": ["деурбанизация", "рурализация"],
    "дезуха": ["деза"],
    "деидеологизировав": ["деидеологизировавши"],
    "деидеологизировавши": ["деидеологизировав"],
    "деинвестировав": ["деинвестировавши"],
    "деинвестировавши": ["деинвестировав"],
    "деиндивидуализировав": ["деиндивидуализировавши"],
    "деиндивидуализировавши": ["деиндивидуализировав"],
    "деиндивидуализировать": ["нивелировать", "обезличивать"],
    "деинсталлировав": ["деинсталлировавши"],
    "деинсталлировавши": ["деинсталлировав"],
    "деинсталлировать": ["удалить"],
    "деинсталлятор": ["анинсталлер"],
    "деинсталляция": ["удаление"],
    "деионизировав": ["деионизировавши"],
    "деионизировавши": ["деионизировав"],
    "деионизированная вода": ["чистая вода"],
    "дейинь": ["дэйин"],
    "дейктический": ["указательный"],
    "дейле": ["диль"],
    "дейност": ["деятелност", "активност"],
    "дейнохейрус": ["дейнохейр"],
    "дейноцефал": ["диноцефал"],
    "дейодирование": ["деиодирование"],
    "дейр": ["дейр-эз-зор"],
    "дейр-эз-зор": ["дайр-эз-заур", "дейр"],
    "действенно": ["эффективно"],
    "действенный": ["эффективный"],
    "действие": ["акт", "движение", "вмешательство", "эффект", "воздействие"],
    "действительно": ["вправду", "правда", "в самом деле", "на самом деле", "поистине", "впрямь", "верно", "точно"],
    "действительное число": ["вещественное число"],
    "действительнозначный": ["вещественнозначный"],
    "действительность": ["бытие", "обстановка", "подлинность", "реальность", "действенность", "актуальность"],
    "действительный": ["реальный", "настоящий", "истинный", "годный", "валидный", "действующий", "действенный", "эффективный", "активный", "вещественный"],
    "действительный залог": ["активный залог", "актив"],
    "действовав": ["действовавши"],
    "действовавши": ["действовав"],
    "действовать": ["функционировать"],
    "действовать на нервы": ["нервировать", "раздражать"],
    "действующее вещество": ["активное вещество"],
    "дейтаграмма": ["датаграмма"],
    "дейтерий": ["тяжёлый водород"],
    "дейтерсовский": ["дейтерсов"],
    "дейтон": ["дейтрон", "дейтерон"],
    "дейтоплазма": ["параплазма"],
    "дейтрон": ["дейтон"],
    "декагон": ["десятиугольник"],
    "декада": ["десятидневка", "десятилетие"],
    "декаданс": ["упадок", "упадничество", "декадентство", "упадочничество"],
    "декадентство": ["декаданс", "упадочничество", "упадничество"],
    "декадентствовав": ["декадентствовавши"],
    "декадентствовавши": ["декадентствовав"],
    "декадник": ["декада"],
    "декадрахма": ["демаретей"],
    "декаедр": ["десятигранник"],
    "декалин": ["декагидронафталин", "пергидронафталин"],
    "декаль": ["переводка"],
    "декалькировав": ["декалькировавши"],
    "декалькировавши": ["декалькировав"],
    "декальцинация": ["декальцинирование"],
    "декальцинировав": ["декальцинировавши"],
    "декальцинировавши": ["декальцинировав"],
    "декамуфлировав": ["декамуфлировавши"],
    "декамуфлировавши": ["декамуфлировав"],
    "декантатор": ["отстойник"],
    "декантация": ["декантирование"],
    "декантировав": ["декантировавши"],
    "декантировавши": ["декантировав"],
    "декантирование": ["декантация"],
    "декапировав": ["декапировавши"],
    "декапировавши": ["декапировав"],
    "декаплинг": ["разъединение"],
    "декартелизация": ["регулирование", "регуляция", "демонополизация"],
    "декартов": ["декартовский", "картезианский"],
    "декартовский": ["декартов", "картезианский"],
    "декатировав": ["декатировавши"],
    "декатировавши": ["декатировав"],
    "декатировщик": ["декатировщица"],
    "декатировщица": ["декатировщик"],
    "декатлон": ["десятиборье"],
    "декаэдр": ["десятигранник"],
    "деквалифицировав": ["деквалифицировавши"],
    "деквалифицировавши": ["деквалифицировав"],
    "декеракт": ["икосаксеннон"],
    "декламационный": ["речитативный"],
    "декламировав": ["декламировавши"],
    "декламировавши": ["декламировав"],
    "декларативный": ["торжественный", "демагогический"],
    "декларация": ["объявление", "заявление", "манифест"],
    "декларировав": ["декларировавши"],
    "декларировавши": ["декларировав"],
    "декларирование": ["декларация"],
    "декларировать": ["провозглашать", "заявлять", "объявлять"],
    "деклинация": ["склонность", "инклинация"],
    "декодер": ["дешифратор"],
    "декодировав": ["декодировавши"],
    "декодировавши": ["декодировав"],
    "декодирование": ["расшифровка", "раскодирование"],
    "декодировать": ["дешифровать", "расшифровывать", "расшифровать", "раскодировать"],
    "декокт": ["отвар", "декохт", "взвар", "голод", "голодуха", "декофт", "безденежье", "без гроша", "ни гроша", "ни гроша за душою", "ни копейки", "ни копейки за душою", "ни полушки", "в кармане пусто", "финансы поют романсы"],
    "деколонизировав": ["деколонизировавши"],
    "деколонизировавши": ["деколонизировав"],
    "деколонизовав": ["деколонизовавши"],
    "деколонизовавши": ["деколонизовав"],
    "деколь": ["шелкография", "шелкограмма"],
    "декольте": ["декольтированный"],
    "декольтировав": ["декольтировавши"],
    "декольтировавши": ["декольтировав"],
    "декольтированный": ["голый", "нагой", "обнажённый", "оголённый", "неприкрытый", "открытый", "непокрытый", "декольте"],
    "декоммунизировав": ["декоммунизировавши"],
    "декоммунизировавши": ["декоммунизировав"],
    "декомпактизовав": ["декомпактизовавши"],
    "декомпактизовавши": ["декомпактизовав"],
    "декомпозировав": ["декомпозировавши"],
    "декомпозировавши": ["декомпозировав"],
    "декомпозиция": ["разделение", "расчленение"],
    "деконгестант": ["антиконгестант"],
    "деконденсация": ["разуплотнение", "деспирализация"],
    "деконструировав": ["деконструировавши"],
    "деконструировавши": ["деконструировав"],
    "деконструкция": ["демонтаж", "декомпозиция"],
    "деконтаминация": ["обеззараживание"],
    "деконфликтация": ["деконфликтинг"],
    "деконфликтинг": ["деконфликтация"],
    "декор": ["декорировка", "украшение"],
    "декоративный": ["живописный", "картинный", "красочный", "нарядный", "декорационный"],
    "декорация": ["украшение", "украшательство", "оформление", "показуха", "приукрашивание", "антураж"],
    "декорировав": ["декорировавши"],
    "декорировавши": ["декорировав"],
    "декорировка": ["декорирование"],
    "декорнуация": ["обезроживание"],
    "декорум": ["благопристойность"],
    "декохт": ["отвар", "декокт", "взвар", "голод", "голодуха", "безденежье", "без гроша", "ни гроша", "ни гроша за душою", "ни копейки", "ни копейки за душою", "ни полушки", "в кармане пусто", "финансы поют романсы"],
    "декремент": ["декрементирование"],
    "декрементировав": ["декрементировавши"],
    "декрементировавши": ["декрементировав"],
    "декрементирование": ["декремент"],
    "декретировав": ["декретировавши"],
    "декретировавши": ["декретировав"],
    "декретный отпуск": ["декрет"],
    "декрешендо": ["декрещендо", "диминуэндо"],
    "декрещендо": ["декрешендо", "диминуэндо"],
    "декриминализировав": ["декриминализировавши"],
    "декриминализировавши": ["декриминализировав"],
    "декриминализировать": ["узаконить", "легализовать"],
    "декриминализовав": ["декриминализовавши"],
    "декриминализовавши": ["декриминализовав"],
    "декстринмальтоза": ["патока", "мальтодекстрин"],
    "декстринный": ["декстриновый"],
    "декстриновый": ["декстринный"],
    "декстринчик": ["декстрин"],
    "декстрограмма": ["правограмма"],
    "декстроза": ["глюкоза"],
    "делав": ["делавши"],
    "делавши": ["делав"],
    "деланный": ["искусственный"],
    "деланость": ["наигранность", "жеманность", "искусственность", "манерность"],
    "деланье": ["делание"],
    "делатель": ["производитель", "создатель"],
    "делать": ["действовать", "изготовлять", "производить", "создавать", "совершать", "осуществлять", "выполнять", "исполнять", "чинить", "ремонтировать"],
    "делать вид": ["притворяться", "прикидываться", "симулировать"],
    "делать глазки": ["строить глазки"],
    "делать из мухи слона": ["утрировать", "преувеличивать"],
    "делать мозги": ["ездить по мозгам"],
    "делать морду тяпкой": ["делать морду кирпичом", "делать голубые глаза"],
    "делать ноги": ["сматываться", "уносить ноги", "драпать", "дать драпа", "дать драпу", "линять"],
    "делаться": ["изготовляться", "производиться", "создаваться", "становиться", "превращаться"],
    "делая": ["изготовляя", "изготавливая", "производя", "создавая", "совершая", "осуществляя", "выполняя", "исполняя"],
    "делва": ["гърне", "кюп"],
    "делегат": ["депутат"],
    "делегация": ["делегирование", "представительство", "депутация"],
    "делегировав": ["делегировавши"],
    "делегировавши": ["делегировав"],
    "делегированный": ["направленный", "посланный", "уполномоченный", "переданный"],
    "делегировать": ["уполномочивать"],
    "деление": ["расчленение", "раздел", "разделение", "распределение", "разъединение", "дезинтеграция", "разбивка", "дробление", "сегментация", "риска", "разведение", "разбавление"],
    "деление с остатком": ["деление по модулю"],
    "деленье": ["деление"],
    "делетив": ["делетивши"],
    "делетивши": ["делетив"],
    "делец": ["торгаш", "деляга", "барыга"],
    "делив": ["деливши"],
    "деливши": ["делив"],
    "деликатес": ["лакомство", "изюминка"],
    "деликатесный": ["изысканный"],
    "деликатничав": ["деликатничавши"],
    "деликатничавши": ["деликатничав"],
    "деликатно": ["вежливо", "тактично", "изящно", "ненавязчиво"],
    "деликатность": ["тактичность", "вежливость", "обходительность", "мягкость", "щекотливость"],
    "деликатный": ["тактичный", "воспитанный"],
    "делимитационный": ["демаркационный"],
    "делимое": ["числитель"],
    "делимый": ["составной", "делящийся"],
    "делинквентный": ["правонарушительный", "противоправный", "противозаконный", "асоциальный", "антисоциальный", "антиобщественный", "психопатоподобный"],
    "делирий": ["делириум"],
    "делириум": ["делирий"],
    "делитель": ["знаменатель", "множитель", "дивизор"],
    "делитель-округлитель": ["делитель", "округлитель"],
    "делить": ["разделять", "разъединять", "расчленять", "разнимать"],
    "делиться": ["рассказывать", "сообщать"],
    "делничност": ["всекидневие", "ежедневие", "еднообразие", "монотонност"],
    "дело": ["работа", "бизнес", "предприятие", "досье"],
    "дело десятое": ["не суть важно", "не суть"],
    "дело житейское": ["пустяки", "мелочи жизни"],
    "дело молодое": ["шуры-муры"],
    "дело табак": ["дело", "плохо", "дрянь"],
    "деловар": ["ловкач", "пройдоха"],
    "деловая женщина": ["бизнесвумен"],
    "деловая колбаса": ["деловая сосиска"],
    "деловитый": ["деловой", "предприимчивый", "практичный"],
    "делово": ["деловито"],
    "делокализовав": ["делокализовавши"],
    "делокализовавши": ["делокализовав"],
    "делопроизводитель": ["письмоводитель", "подъячий", "делопуп", "канцелярская крыса"],
    "делопроизводство": ["документирование"],
    "делос": ["дилос"],
    "делывав": ["делывавши"],
    "делывавши": ["делывав"],
    "дель": ["полотно", "нитка"],
    "дельта": ["разность"],
    "дельта-функция": ["функция дирака", "единичная импульсная функция"],
    "дельта-штамм": ["дельта-вариант", "индийский штамм", "дельта", "индиец"],
    "дельтаплан": ["параглайдер"],
    "дельтапланеристка": ["дельтапланерист"],
    "дельтовидный": ["дельтообразный"],
    "дельтоид-додекаэдр": ["тетрагон-тритетраэдр", "дельтоэдр"],
    "дельтообразный": ["дельтовидный"],
    "дельтоэдр": ["дельтоид-додекаэдр", "тетрагон-тритетраэдр"],
    "дельфинарий": ["дельфинариум"],
    "дельфинариум": ["дельфинарий"],
    "дельфиниум": ["живокость", "шпорник"],
    "делюкс": ["люкс"],
    "деляга": ["трудяга", "делец", "бизнесмен"],
    "деляна": ["делянка"],
    "делянка": ["лесосека", "деляна", "пай"],
    "деляческий": ["корыстный", "меркантильный"],
    "делёж": ["делёжка"],
    "делёжка": ["делёж"],
    "демагог": ["демократ", "пустомеля", "фразёр"],
    "демагогически": ["демагогично"],
    "демагогический": ["демагогичный"],
    "демагогично": ["демагогически"],
    "демагогичный": ["демагогический"],
    "демагогия": ["софистика"],
    "демагогствовав": ["демагогствовавши"],
    "демагогствовавши": ["демагогствовав"],
    "демаркировав": ["демаркировавши"],
    "демаркировавши": ["демаркировав"],
    "демархия": ["лотократия"],
    "демаскировав": ["демаскировавши"],
    "демаскировавши": ["демаскировав"],
    "демаскирование": ["демаскировка"],
    "дематериализовав": ["дематериализовавши"],
    "дематериализовавши": ["дематериализовав"],
    "дембель": ["демобилизация"],
    "дембельный": ["дембельский"],
    "демек": ["айтмакъ", "сёйлемек"],
    "деменция": ["слабоумие", "старческий маразм", "сенильная деменция", "старческое слабоумие"],
    "деменция прекокс": ["шизофрения", "схизофрения", "раннее слабоумие"],
    "демеркуризировав": ["демеркуризировавши"],
    "демеркуризировавши": ["демеркуризировав"],
    "деметилировав": ["деметилировавши"],
    "деметилировавши": ["деметилировав"],
    "демид": ["диомид"],
    "демикотонный": ["демикотоновый"],
    "демилитаризировав": ["демилитаризировавши"],
    "демилитаризировавши": ["демилитаризировав"],
    "демилитаризовав": ["демилитаризовавши"],
    "демилитаризовавши": ["демилитаризовав"],
    "демимонд": ["полусвет"],
    "демимонденка": ["дама полусвета"],
    "деминерализовав": ["деминерализовавши"],
    "деминерализовавши": ["деминерализовав"],
    "деминерализовать": ["деминерализовывать"],
    "деминутив": ["диминутив"],
    "демисезонный": ["межсезонный"],
    "демистифицировав": ["демистифицировавши"],
    "демистифицировавши": ["демистифицировав"],
    "демитас": ["дмитас", "демитассе"],
    "демиург": ["творец", "создатель"],
    "демифизация": ["демифологизация"],
    "демифологизация": ["демифизация"],
    "демифологизировав": ["демифологизировавши"],
    "демифологизировавши": ["демифологизировав"],
    "демка": ["демоверсия"],
    "демо": ["демка"],
    "демобилизация": ["дембель", "увольнение в запас", "демилитаризация"],
    "демобилизовав": ["демобилизовавши"],
    "демобилизовавши": ["демобилизовав"],
    "демобилизовывав": ["демобилизовывавши"],
    "демобилизовывавши": ["демобилизовывав"],
    "демоверсия": ["демка"],
    "демодулировать": ["детектировать"],
    "демозапись": ["демотэйп"],
    "демокрад": ["дерьмократ"],
    "демократизировав": ["демократизировавши"],
    "демократизировавши": ["демократизировав"],
    "демократизировать": ["либерализовать"],
    "демократическая республика конго": ["дрк", "др конго", "заир", "республика заир", "республика конго"],
    "демократически": ["демократично"],
    "демократично": ["демократически"],
    "демократичный": ["простой", "демократический", "дешёвый", "недорогой"],
    "демократия": ["народовластие", "равноправие"],
    "демон": ["дьявол", "сатана", "чёрт", "бес", "аггел"],
    "демонесса": ["демоница", "дьяволица"],
    "демонизировав": ["демонизировавши"],
    "демонизировавши": ["демонизировав"],
    "демоница": ["демонесса"],
    "демонически": ["демонично", "демонски", "дьявольски", "чувственно", "страстно", "безумно"],
    "демонично": ["демонически"],
    "демоничный": ["демонический", "дьявольский"],
    "демонополизировав": ["демонополизировавши"],
    "демонополизировавши": ["демонополизировав"],
    "демонски": ["по-демонски", "демонически"],
    "демонский": ["бесовский", "дьявольский", "сатанинский", "чертовский", "демонический", "инфернальный", "вражий", "сатанический"],
    "демонстративно": ["показательно"],
    "демонстрационный": ["показательный", "представительский"],
    "демонстрация": ["показ", "манифестация", "марш", "подчёркивание"],
    "демонстрировавши": ["демонстрировав"],
    "демонстрировать": ["показывать", "представлять", "выставлять"],
    "демонстрироваться": ["показываться"],
    "демонтаж": ["разборка"],
    "демонтировав": ["демонтировавши"],
    "демонтировавши": ["демонтировав"],
    "демонъ": ["сатана", "чортъ"],
    "деморализация": ["разложение"],
    "деморализовав": ["деморализовавши"],
    "деморализовавши": ["деморализовав"],
    "деморализовать": ["деморалить"],
    "деморосс": ["демросс"],
    "демотивация": ["демотивирование"],
    "демотивировав": ["демотивировавши"],
    "демотивировавши": ["демотивировав"],
    "демотивирование": ["демотивация"],
    "демотивировать": ["дестимулировать"],
    "демпечать": ["демпресса"],
    "демпинговав": ["демпинговавши"],
    "демпинговавши": ["демпинговав"],
    "демпресса": ["демпечать"],
    "демпфер": ["удароглушитель", "амортизатор", "гаситель"],
    "демпфировав": ["демпфировавши"],
    "демпфировавши": ["демпфировав"],
    "демпфирование": ["подавление"],
    "демпфировать": ["смягчать", "гасить"],
    "демросс": ["деморосс"],
    "демуниципализировав": ["демуниципализировавши"],
    "демуниципализировавши": ["демуниципализировав"],
    "демшиза": ["демшизоид", "демофрения"],
    "демшизоид": ["демшиза"],
    "ден": ["денье"],
    "денарий": ["динарий"],
    "денатурализовав": ["денатурализовавши"],
    "денатурализовавши": ["денатурализовав"],
    "денатурат": ["денатурированный спирт"],
    "денатурировав": ["денатурировавши"],
    "денатурировавши": ["денатурировав"],
    "денационализация": ["приватизация"],
    "денационализировав": ["денационализировавши"],
    "денационализировавши": ["денационализировав"],
    "денационализировать": ["разгосударствлять", "разгосударствить", "приватизировать"],
    "денацифицировав": ["денацифицировавши"],
    "денацифицировавши": ["денацифицировав"],
    "денди": ["щёголь", "франт", "фат", "петиметр", "ферт", "модник", "пижон", "стиляга"],
    "дендизм": ["джентельменство", "щегольство", "франтовство", "шик", "пижонство", "фатовство"],
    "дендрарий": ["арборетум"],
    "дендритический": ["дендритный", "древовидный"],
    "дендритный": ["древовидный", "древообразный", "древоподобный"],
    "дендроидный": ["древовидный", "дендритический", "дендритный"],
    "дендрология": ["ксилология"],
    "дендрофекальный": ["из говна и палок"],
    "денег куры не клюют": ["при деньгах", "с деньгами", "денег не считает", "набит деньгами", "деньгам счёта не знает", "гребёт деньги лопатой", "денег как грязи", "денег что грязи", "деньги водятся", "капиталы водятся", "деньги шевелятся", "капиталы шевелятся", "деньги шелестят", "птичьего молока не хватает", "птичьего молока недостаёт"],
    "денежка": ["деньга", "монетка", "монета"],
    "денежная единица": ["валюта"],
    "денежник": ["копеечник", "ярутка полевая", "щитолистник"],
    "денежные средства": ["наличность"],
    "денежный": ["монетарный", "богатый", "состоятельный"],
    "денежный знак": ["дензнак"],
    "денежный перевод": ["перевод"],
    "денисовец": ["денисовский человек"],
    "денитрифицировав": ["денитрифицировавши"],
    "денитрифицировавши": ["денитрифицировав"],
    "денитрование": ["денитрация"],
    "денк": ["пакет", "вързоп", "бала", "тесте", "топ"],
    "денница": ["сатана", "люцифер"],
    "денно и нощно": ["постоянно"],
    "денной": ["дневной", "денный"],
    "денный": ["дневной"],
    "деноменклатуризация": ["десоветизация"],
    "деноминация": ["наименование", "конфессия"],
    "деноминировав": ["деноминировавши"],
    "деноминировавши": ["деноминировав"],
    "денонсация": ["денонсирование"],
    "денонсировав": ["денонсировавши"],
    "денонсировавши": ["денонсировав"],
    "денонсирование": ["денонсация"],
    "денонсировать": ["осуждать", "докладывать"],
    "денормализовав": ["денормализовавши"],
    "денормализовавши": ["денормализовав"],
    "денормализовывав": ["денормализовывавши"],
    "денормализовывавши": ["денормализовывав"],
    "денотат": ["референт", "обозначаемое"],
    "денотативное значение": ["денотат"],
    "денотативный": ["референциальный", "референтный"],
    "денсиметр": ["ареометр", "плотномер"],
    "денсиметрия": ["денситометрия"],
    "денситография": ["денсография"],
    "денсография": ["денситография"],
    "дентальный": ["зубной"],
    "дентикул": ["сухарик"],
    "дентиновый": ["дентинный"],
    "денуклеаризация": ["ядерное разоружение"],
    "денуклеаризировав": ["денуклеаризировавши"],
    "денуклеаризировавши": ["денуклеаризировав"],
    "денщик": ["вестовой", "ординарец", "адъютант"],
    "день": ["свет", "сутки", "праздник", "юбилей", "годовщина", "час", "момент"],
    "день варенья": ["день рождения", "днюха", "др", "бёздник"],
    "день весны и труда": ["первое мая", "первомай"],
    "день дурака": ["день смеха", "первое апреля"],
    "день за днём": ["изо дня в день", "день-деньской"],
    "день защитника отечества": ["день красной армии и флота"],
    "день знаний": ["первое сентября"],
    "день народження": ["народини"],
    "день победы": ["девятое мая"],
    "день прощания": ["шуфутинов день"],
    "день рождения": ["день рожденья", "день варенья", "днюха", "др", "бёздник"],
    "день россии": ["день независимости"],
    "день святого валентина": ["валентинов день", "день влюблённых", "день всех влюблённых"],
    "день смеха": ["день дурака", "первое апреля"],
    "деньга": ["денга", "полушка", "денежка", "монета", "копейка", "бабло", "капуста"],
    "деньги": ["зарплата", "капитал"],
    "деньги счёт любят": ["копейка рубль бережёт"],
    "деньговоз": ["инкассаторский", "автомобиль", "деньговозка"],
    "деньговозка": ["инкассаторский", "автомобиль", "деньговоз"],
    "денюжка": ["денюшка", "денежка"],
    "денюшка": ["денежка", "деньжата"],
    "денёчек": ["денёк"],
    "деодорант": ["дезодорант"],
    "деодорировав": ["деодорировавши"],
    "деодорировавши": ["деодорировав"],
    "деоккупировав": ["деоккупировавши"],
    "деоккупировавши": ["деоккупировав"],
    "деонимизация": ["апеллятивация"],
    "депардье": ["депардьё"],
    "департизировав": ["департизировавши"],
    "департизировавши": ["департизировав"],
    "деперсонализация": ["ценестезия"],
    "деперсонифицировав": ["деперсонифицировавши"],
    "деперсонифицировавши": ["деперсонифицировав"],
    "деперсонифицировать": ["обезличить", "обезличивать"],
    "депеша": ["телеграмма", "донесение"],
    "депилятор": ["эпилятор"],
    "депиляция": ["эпиляция"],
    "депланировав": ["депланировавши"],
    "депланировавши": ["депланировав"],
    "деплатформинг": ["деплатформирование"],
    "деплоив": ["деплоивши"],
    "деплоивши": ["деплоив"],
    "депнув": ["депнувши"],
    "депнувши": ["депнув"],
    "депо": ["пожарное депо", "склад", "магазин"],
    "депозит": ["вклад", "отложение", "залежь"],
    "депозитор": ["депонент"],
    "депозиция": ["десублимация", "осаждение"],
    "деполитизировав": ["деполитизировавши"],
    "деполитизировавши": ["деполитизировав"],
    "деполитизированность": ["аполитичность"],
    "деполяризовав": ["деполяризовавши"],
    "деполяризовавши": ["деполяризовав"],
    "деполяризовать": ["деполяризовывать"],
    "депонировав": ["депонировавши"],
    "депонировавши": ["депонировав"],
    "депопуляция": ["обезлюдение"],
    "депортация": ["высылка", "ссылка", "выселение", "выдворение", "изгнание"],
    "депортировав": ["депортировавши"],
    "депортировавши": ["депортировав"],
    "депортировать": ["выдворять"],
    "деправация": ["распущенность", "развратность", "порочность"],
    "депремировав": ["депремировавши"],
    "депремировавши": ["депремировав"],
    "депресняк": ["депрессия", "депрессуха"],
    "депрессировав": ["депрессировавши"],
    "депрессировавши": ["депрессировав"],
    "депрессия": ["депрессняк", "депресняк", "депрессуха", "депра", "баритимия", "меланхолия", "липемания", "рецессия", "спад"],
    "депрессняк": ["депресняк", "депрессуха"],
    "депрессуха": ["депрессняк", "депресняк"],
    "деприватизация": ["расприватизация"],
    "деприватизировав": ["деприватизировавши"],
    "деприватизировавши": ["деприватизировав"],
    "деприватизировать": ["расприватизировать"],
    "депривация": ["лишение"],
    "депроприация": ["апеллятивация"],
    "депульпировав": ["депульпировавши"],
    "депульпировавши": ["депульпировав"],
    "депутан": ["депутатишко"],
    "депутат": ["депутатик", "депутатишка", "депутатишко", "депутатище", "депутан", "делегат"],
    "депутатик": ["депутатишко"],
    "депутатишко": ["депутан"],
    "депутатка": ["депутатша"],
    "депутатский": ["парламентский"],
    "депутатша": ["депутатка"],
    "депутация": ["делегация"],
    "дер": ["дурум"],
    "деранув": ["деранувши"],
    "деранувши": ["деранув"],
    "дераша": ["дэраша"],
    "дерба": ["участок"],
    "дербалызнув": ["дербалызнувши"],
    "дербалызнувши": ["дербалызнув"],
    "дербалызнуть": ["намахнуть", "замахнуть", "накатить", "дёрнуть", "дерябнуть", "шлёпнуть", "хряпнуть"],
    "дербанить": ["разделывать", "расчленять", "разделять", "кромсать", "терзать", "раздёргивать", "раздирать", "потрошить", "раздраконивать", "распатронивать", "избивать", "бить", "стучать", "ломить", "делить"],
    "дербенник": ["подбережник"],
    "дербент": ["кьвевар"],
    "дербень": ["дерюга"],
    "дерби": ["класико"],
    "дербянка колосистая": ["блехнум колосистый"],
    "дервиш": ["каландар", "календер"],
    "дерганув": ["дерганувши"],
    "дерганувши": ["дерганув"],
    "дергач": ["коростель", "дергун"],
    "дергиктэ": ["тэвуктэ"],
    "дергота": ["подёргивание"],
    "дергун": ["дергач", "коростель"],
    "деребить": ["драть", "раздирать", "ковырять", "беспокоить", "волновать", "тревожить", "дерябить", "плакать", "рыдать", "выть", "визжать"],
    "деревей": ["тысячелистник", "кровеник", "кровавник", "серпорез", "порез", "грыжная", "рудомётка", "подбел", "дикая греча", "кашка", "белоголовец", "растиральник", "сузик", "гулявица", "рябинка"],
    "деревенев": ["деревеневши"],
    "деревеневши": ["деревенев"],
    "деревенив": ["деревенивши"],
    "деревенивши": ["деревенив"],
    "деревенская аптека": ["ниим", "азадирахта индийская", "маргоза"],
    "деревенский": ["сельский"],
    "деревенщина": ["дикарь", "невежда"],
    "деревище": ["домовина", "труна"],
    "деревня": ["село", "сельский населённый пункт", "крестьянство", "изба"],
    "дерево": ["лес", "древесина", "рангоут", "рангоутное дерево", "иерархия", "дуб", "дубина", "тормоз"],
    "деревообделочный": ["деревообрабатывающий"],
    "деревообрабатывающий": ["деревообделочный"],
    "деревопереработка": ["деревообработка"],
    "деревушка": ["деревенька"],
    "деревце": ["деревцо"],
    "деревцо": ["деревце"],
    "деревянев": ["деревяневши"],
    "деревяневши": ["деревянев"],
    "деревянный": ["скованный", "напряжённый"],
    "деревянный бушлат": ["деревянный макинтош", "деревянный тулуп", "гроб"],
    "деревянный макинтош": ["деревянный бушлат", "деревянный тулуп", "деревянный костюм"],
    "деревянный тулуп": ["деревянный бушлат", "деревянный тулуп о шести досках"],
    "деревянный тулуп о шести досках": ["деревянный бушлат", "деревянный тулуп"],
    "деревяшка": ["деревяха", "протез", "чурбан", "заготовка"],
    "дерегулировав": ["дерегулировавши"],
    "дерегулировавши": ["дерегулировав"],
    "дерегулирование": ["дерегуляция"],
    "дерегулировать": ["либерализовать"],
    "дерегуляция": ["дерегулирование", "либерализация"],
    "дереу": ["жылдам"],
    "держава": ["страна", "государство", "царство", "империя"],
    "державец": ["правитель", "владыка"],
    "державиця": ["владниця", "власниця", "властителька"],
    "державник": ["государственник", "великодержавник"],
    "державствовав": ["державствовавши"],
    "державствовавши": ["державствовав"],
    "державствовать": ["господствовать", "доминировать", "властвовать"],
    "державши": ["держав"],
    "держак": ["рукоятка"],
    "держалка": ["держатель", "ручка", "выносливость"],
    "держание": ["удерживание"],
    "держаный": ["подержанный"],
    "держанье": ["держание"],
    "держатель": ["обладатель"],
    "держати": ["тримати"],
    "держать в ежовых рукавицах": ["держать в чёрном теле"],
    "держать в чёрном теле": ["держать в ежовых рукавицах"],
    "держать камень за пазухой": ["носить камень за пазухой", "держать камень за душой", "иметь зуб"],
    "держать кулачки": ["скрестить пальцы"],
    "держать мазу": ["защищать", "заступаться"],
    "держать ответ": ["оправдываться", "защищаться"],
    "держать пари": ["биться об заклад"],
    "держать порох сухим": ["быть наготове", "быть во всеоружии", "держать ухо востро"],
    "держать рот на замке": ["держать язык за зубами", "молчать", "помалкивать"],
    "держать руку": ["держать сторону"],
    "держать сторону": ["держать руку"],
    "держать ухо востро": ["держать порох сухим"],
    "держать хвост пистолетом": ["держать хвост трубой", "держать хвост морковкой"],
    "держать экзамен": ["экзаменоваться"],
    "держать язык за зубами": ["держать рот на замке", "молчать как партизан"],
    "держаться": ["придерживаться", "крепиться", "водиться", "обитать", "сопротивляться", "вести себя", "поддерживаться", "сохраняться", "оставаться"],
    "держзамовлення": ["державне замовлення"],
    "держи карман шире": ["чёрта с два", "ещё чего"],
    "держивав": ["держивавши"],
    "держивавши": ["держивав"],
    "держидерево": ["палиурус христова колючка", "держидерево тернии христа", "держи-дерево"],
    "держслужбовець": ["посадовець", "високопосадовець", "службовець", "урядник"],
    "дерзав": ["дерзавши"],
    "дерзавши": ["дерзав"],
    "дерзанье": ["дерзание"],
    "дерзать": ["осмеливаться", "сметь", "рисковать"],
    "дерзив": ["дерзивши"],
    "дерзивши": ["дерзив"],
    "дерзить": ["грубить"],
    "дерзкий": ["смелый", "отважный", "отчаянный", "рискованный", "непочтительный", "грубый", "самонадеянный", "надменный"],
    "дерзко": ["нагло", "непочтительно", "невежливо", "дерзновенно"],
    "дерзничав": ["дерзничавши"],
    "дерзничавши": ["дерзничав"],
    "дерзновенье": ["дерзновение"],
    "дерзнув": ["дерзнувши"],
    "дерзнувши": ["дерзнув"],
    "дерзнуть": ["осмелиться", "отважиться", "рискнуть"],
    "дерзостно": ["дерзко"],
    "дерзостность": ["дерзость"],
    "дерзостный": ["дерзкий"],
    "дерзость": ["резкость", "грубость"],
    "дериват": ["производное", "дериватив"],
    "дериватив": ["деривативная ценная бумага", "дериват"],
    "дериватология": ["словообразование"],
    "дериватор": ["деривиметр", "дифференциатор", "словообразовательный формант"],
    "дерис": ["сабак", "урок"],
    "дерма": ["кориум", "кутис"],
    "дерматин": ["гранитоль", "нитроискожа"],
    "дерматоз": ["дерматит"],
    "дерматолог": ["кожник"],
    "дерматомикоз": ["дерматофития"],
    "дерматофития": ["дерматомикоз"],
    "дермоскопия": ["дерматоскопия"],
    "дернев": ["дерневши"],
    "дерневши": ["дернев"],
    "дернив": ["дернивши"],
    "дернивши": ["дернив"],
    "дернина": ["дерновина"],
    "дернить": ["дерновать"],
    "дерновав": ["дерновавши"],
    "дерновавши": ["дерновав"],
    "дерновать": ["обдерновывать", "обдернять"],
    "дерновина": ["дернина"],
    "дерносним": ["дерносниматель"],
    "дерогативный": ["уничижительный", "пейоративный"],
    "дерпт": ["тарту", "юрьев", "дорпат"],
    "дерусифицировав": ["дерусифицировавши"],
    "дерусифицировавши": ["дерусифицировав"],
    "дерьмище": ["дрисня", "дриснище"],
    "дерьмо": ["экскременты", "фекалии", "говно", "дрянь", "отбросы", "отстой", "жопа", "блядь", "пиздец"],
    "дерьмово": ["хреново", "погано", "плохо", "херово"],
    "дерьмовость": ["говённость"],
    "дерьмовый": ["говённый", "хреновый", "дрянной"],
    "дерьмократ": ["демокрад"],
    "дерюга": ["дерюжка", "дерюжина", "мешковина"],
    "деря": ["дейинь"],
    "дерябнув": ["дерябнувши"],
    "дерябнувши": ["дерябнув"],
    "дерябнуть": ["хлобыстнуть"],
    "дерёвня": ["чурбан", "деревенщина"],
    "десакрализовав": ["десакрализовавши"],
    "десакрализовавши": ["десакрализовав"],
    "десант": ["десантирование"],
    "десантировав": ["десантировавши"],
    "десантировавши": ["десантировав"],
    "десантировать": ["высаживать", "высадить"],
    "десантник": ["голубой берет"],
    "десегментация": ["десекционирование"],
    "десегрегировав": ["десегрегировавши"],
    "десегрегировавши": ["десегрегировав"],
    "десенсибилизировав": ["десенсибилизировавши"],
    "десенсибилизировавши": ["десенсибилизировав"],
    "десерт": ["сладкое"],
    "десигнат": ["сигнификат", "сигнификация"],
    "десинхронизировав": ["десинхронизировавши"],
    "десинхронизировавши": ["десинхронизировав"],
    "десинхронизировать": ["синхронизировать"],
    "дескать": ["де", "мол", "значит", "так сказать", "типа"],
    "дескриптивизм": ["дескриптивная лингвистика"],
    "дескриптивний": ["описовий"],
    "дескриптивный": ["описательный"],
    "десктоп": ["настольный компьютер", "рабочий стол"],
    "десмотропия": ["таутомерия"],
    "десневой": ["деснёвый", "дёсенный"],
    "десниця": ["десна"],
    "деснёвый": ["десневой"],
    "десоветизация": ["деноменклатуризация"],
    "десоветизировав": ["десоветизировавши"],
    "десоветизировавши": ["десоветизировав"],
    "десперация": ["отчаяние"],
    "деспирализация": ["деконденсация"],
    "деспот": ["тиран", "самодержец", "властелин", "самодур"],
    "деспотизм": ["тирания", "абсолютизм", "самодержавие", "самовластие", "тиранство", "самодурство"],
    "деспотический": ["тиранический", "деспотичный"],
    "деспотичный": ["деспотический", "самовластный"],
    "деспотия": ["деспотизм"],
    "деспотка": ["тиранша"],
    "дестабилизировав": ["дестабилизировавши"],
    "дестабилизировавши": ["дестабилизировав"],
    "дестабилизировать": ["разбалансировать", "расшатывать", "расшатать"],
    "дестабилизироваться": ["расшатываться"],
    "дестимулировав": ["дестимулировавши"],
    "дестимулировавши": ["дестимулировав"],
    "дестимулировать": ["демотивировать"],
    "деституция": ["отстранение", "увольнение", "отрешение", "лишение"],
    "деструктивность": ["разрушительность"],
    "деструктивный": ["неплодотворный", "разрушительный", "злокачественный"],
    "деструктурировав": ["деструктурировавши"],
    "деструктурировавши": ["деструктурировав"],
    "десублимация": ["депозиция", "осаждение"],
    "десубстантивация": ["десубстантивизация"],
    "десятеро": ["десять"],
    "десятиборье": ["декатлон"],
    "десятигранник": ["декаэдр"],
    "десятидневка": ["декада"],
    "десятидюймовка": ["гранд"],
    "десятижды": ["десятикратно"],
    "десятикратно": ["десятижды", "вдесятеро"],
    "десятилетие": ["декада", "десятилетье"],
    "десятилетье": ["десятилетие"],
    "десятинка": ["десятина"],
    "десятиразовый": ["десятикратный"],
    "десятицентовик": ["дайм"],
    "десятка": ["десять", "десяток", "червонец", "яблочко", "десятилетний", "срок"],
    "десятник": ["бригадир", "десятский"],
    "десятчик": ["гривенник"],
    "десять": ["червонец", "десятка", "десяток"],
    "десять сталинских ударов": ["десять ударов"],
    "десять тысяч": ["мириада", "тьма"],
    "детабуизация": ["детабуирование"],
    "детабуировав": ["детабуировавши"],
    "детабуировавши": ["детабуировав"],
    "детабуирование": ["детабуизация"],
    "детайл": ["подробност", "дреболия", "незначителност", "дребнавост"],
    "детализировав": ["детализировавши"],
    "детализировавши": ["детализировав"],
    "детализировать": ["детализовать"],
    "детализироваться": ["детализоваться"],
    "детализовав": ["детализовавши"],
    "детализовавши": ["детализовав"],
    "детализовать": ["детализировать"],
    "детализоваться": ["детализироваться"],
    "деталировав": ["деталировавши"],
    "деталировавши": ["деталировав"],
    "деталь": ["составляющая", "компонент", "подробность", "частность", "нюанс", "уточнение"],
    "детально": ["подробно"],
    "детальность": ["подробность"],
    "детальный": ["подробный"],
    "детант": ["разрядка"],
    "детвора": ["дети", "ребятня"],
    "детдом": ["детский дом"],
    "детезаврация": ["детезаврирование", "прекращение тезаврирования"],
    "детектив": ["сыщик"],
    "детективист": ["детективщик"],
    "детективщик": ["детективист"],
    "детектировав": ["детектировавши"],
    "детектировавши": ["детектировав"],
    "детектировать": ["определять", "определить", "выявлять", "выявить", "обнаруживать", "обнаружить"],
    "детектор лжи": ["полиграф"],
    "детекция": ["обнаружение", "выявление"],
    "детел": ["кълвач"],
    "детериоративность": ["уничижительность", "пейоративность"],
    "детериоративный": ["уничижительный", "пейоративный"],
    "детерминант": ["определитель"],
    "детерминировав": ["детерминировавши"],
    "детерминировавши": ["детерминировав"],
    "детерминированный": ["предопределённый", "обусловленный"],
    "детерминировать": ["определять", "предопределять", "обуславливать"],
    "детерминистский": ["причинностный", "причинный", "детерминированный", "детерминистический"],
    "детерминологизировав": ["детерминологизировавши"],
    "детерминологизировавши": ["детерминологизировав"],
    "дети": ["ребёнок", "детвора", "ребятня", "ребятишки"],
    "дети цветов": ["хиппи", "дети-цветы"],
    "дети-цветы": ["дети цветов"],
    "детинец": ["кремль"],
    "детишки": ["дети", "ребята", "ребятишки"],
    "детишковый": ["ребятишковый", "детский"],
    "детище": ["ребёнок", "дитя", "чадо", "детёныш", "птенец", "вещь", "создание", "творение", "порождение"],
    "детка": ["ребёнок", "дитя", "малышка"],
    "деткомбинат": ["детсад-ясли", "ясли-сад"],
    "деткор": ["юнкор"],
    "детокс": ["детоксикация", "детокс-программа"],
    "детоксикант": ["детоксикатор"],
    "детоксикация": ["детокс"],
    "детолюб": ["чадолюб"],
    "детонатор": ["взрыватель"],
    "детонация": ["детонирование", "взрыв"],
    "детоненавистничество": ["мизопедия"],
    "детонировав": ["детонировавши"],
    "детонировавши": ["детонировав"],
    "деторастление": ["патика", "растление", "педофилия"],
    "детородный": ["половой"],
    "детородный орган": ["орган размножения"],
    "детородный член": ["пенис"],
    "деторожденье": ["деторождение"],
    "детоубийство": ["инфантицид", "чадоубийство"],
    "детоубийца": ["чадоубийца"],
    "деточка": ["детка", "дитя", "ребёночек", "малышка"],
    "детренировав": ["детренировавши"],
    "детренировавши": ["детренировав"],
    "детритофаг": ["сапрофаг"],
    "детритофагия": ["сапрофагия", "грунтоедение"],
    "детсад-ясли": ["деткомбинат", "ясли-детсад"],
    "детская коляска": ["коляска"],
    "детские деньги": ["детские"],
    "детский дом": ["сиротский дом", "детдом"],
    "детский лепет": ["детский лепет на лужайке", "мелочь", "пустяк", "ерунда", "ничто", "фигня"],
    "детский сад": ["детсад"],
    "детский церебральный паралич": ["дцп"],
    "детское дошкольное учреждение": ["дшу"],
    "детское место": ["плацента", "послед"],
    "детскость": ["инфантильность"],
    "деть": ["потерять", "поместить"],
    "деурбанизация": ["дезурбанизация", "рурализация"],
    "дефать": ["защищать", "оборонять"],
    "дефекация": ["испражнение", "какание", "сранье", "срачка", "стул", "экскреция"],
    "дефект": ["изъян", "недостаток", "ошибка", "порок", "порча", "пробел"],
    "дефективный": ["неполноценный"],
    "дефектовав": ["дефектовавши"],
    "дефектовавши": ["дефектовав"],
    "дефензин": ["дефенсин"],
    "дефенсин": ["дефензин"],
    "деферризация": ["обезжелезивание"],
    "дефетизм": ["пораженчество"],
    "дефетизъм": ["пораженство"],
    "дефибринировав": ["дефибринировавши"],
    "дефибринировавши": ["дефибринировав"],
    "дефибрировав": ["дефибрировавши"],
    "дефибрировавши": ["дефибрировав"],
    "дефиле": ["ущелье"],
    "дефилей": ["дифелея"],
    "дефилировав": ["дефилировавши"],
    "дефилировавши": ["дефилировав"],
    "дефин": ["дефн"],
    "дефинитный": ["определённый", "ясный", "конкретный", "чёткий", "точный"],
    "дефиниция": ["определение"],
    "дефис": ["чёрточка"],
    "дефисный": ["полуслитный"],
    "дефицит": ["убыток"],
    "дефицитарный": ["дефицитный"],
    "дефицитка": ["дефицит"],
    "дефицитный": ["убыточный"],
    "дефлорировав": ["дефлорировавши"],
    "дефлорировавши": ["дефлорировав"],
    "дефн": ["дефин"],
    "дефокусирование": ["расфокусирование", "расфокусировка"],
    "дефолиация": ["обезлиствение"],
    "дефолт": ["кризис", "как обычно"],
    "дефорестация": ["обезлесение"],
    "деформация": ["деформирование", "искажение", "деформированность"],
    "деформировав": ["деформировавши"],
    "деформировавши": ["деформировав"],
    "деформировать": ["искажать", "корёжить"],
    "дефосфорация": ["дефосфоризация", "обесфосфоривание"],
    "дефосфоризация": ["дефосфорация", "обесфосфоривание"],
    "дефосфорилировав": ["дефосфорилировавши"],
    "дефосфорилировавши": ["дефосфорилировав"],
    "дефрагментировав": ["дефрагментировавши"],
    "дефрагментировавши": ["дефрагментировав"],
    "дефрагментирование": ["дефрагментация"],
    "дехлорировав": ["дехлорировавши"],
    "дехлорировавши": ["дехлорировав"],
    "дехристианизация": ["расхристианизация"],
    "децентрализировав": ["децентрализировавши"],
    "децентрализировавши": ["децентрализировав"],
    "децентрализовав": ["децентрализовавши"],
    "децентрализовавши": ["децентрализовав"],
    "децентрализованный": ["рассредоточенный"],
    "децидуальный": ["хориальный"],
    "дециллион": ["новемдециллион"],
    "децимальный": ["десятичный"],
    "дециметр": ["десиметр"],
    "децл": ["немного", "чуть-чуть"],
    "дешевев": ["дешевевши"],
    "дешевевши": ["дешевев"],
    "дешеветь": ["падать в цене"],
    "дешевив": ["дешевивши"],
    "дешевивши": ["дешевив"],
    "дешевле": ["подешевле"],
    "дешевле пареной репы": ["по грошу пара", "пятачок за пучок"],
    "дешифратор": ["декодер"],
    "дешифрация": ["дешифрирование"],
    "дешифрировав": ["дешифрировавши"],
    "дешифрировавши": ["дешифрировав"],
    "дешифрирование": ["дешифрование", "дешифровка", "расшифровка", "декодирование"],
    "дешифрировать": ["дешифровать", "расшифровывать"],
    "дешифровав": ["дешифровавши"],
    "дешифровавши": ["дешифровав"],
    "дешифровальщик": ["дешифровщик"],
    "дешифровать": ["дешифрировать", "расшифровать", "декодировать"],
    "дешифровка": ["дешифрование", "дешифрирование"],
    "дешифровщик": ["дешифровальщик", "расшифровщик"],
    "дешифровывав": ["дешифровывавши"],
    "дешифровывавши": ["дешифровывав"],
    "дешманский": ["бросовый", "ширпотребный"],
    "дешёвый": ["недорогой", "доступный", "примитивный", "жалкий", "недостойный"],
    "деэволюционировав": ["деэволюционировавши"],
    "деэволюционировавши": ["деэволюционировав"],
    "деэволюционировать": ["вырождаться"],
    "деэмульгатор": ["деэмульсификатор"],
    "деэтимологизация": ["опрощение"],
    "деэтимологизировав": ["деэтимологизировавши"],
    "деэтимологизировавши": ["деэтимологизировав"],
    "деяв": ["деявши"],
    "деявши": ["деяв"],
    "деяние": ["действие", "поступок"],
    "деятель": ["активист"],
    "деятельница": ["активистка", "участница"],
    "деятельно": ["активно"],
    "деятельность": ["занятие", "дело", "активность"],
    "деятельный": ["активный", "энергичный", "инициативный"],
    "деять": ["делать", "совершать", "претворять"],
    "деёфицировав": ["деёфицировавши"],
    "деёфицировавши": ["деёфицировав"],
    "джа": ["кьят", "ча"],
    "джавахетия": ["джавахети", "джавахк"],
    "джадувлух": ["джадулук"],
    "джаз": ["джаз-ансамбль", "джаз-банд", "джаз-бэнд"],
    "джаз-банд": ["джаз"],
    "джайн": ["джайнист"],
    "джайнский": ["джайнистский"],
    "джалилабад": ["астрахан-базар"],
    "джамагат": ["джамаат", "народное собрание"],
    "джамахирия": ["вснлад", "ливийская арабская джамахирия", "снлад"],
    "джамшид": ["йима"],
    "джамшутка": ["маршрутка", "джихад-арба"],
    "джан": ["дорогой", "милый"],
    "джанк-фуд": ["фастфуд"],
    "джанэ": ["гьанэ"],
    "джаркент": ["панфилов"],
    "джарудит": ["сурхубит"],
    "джау": ["май"],
    "джаьнджаьфир": ["джаьнджаьфил"],
    "джедай": ["рыцарь"],
    "джедефра": ["раджедеф"],
    "джеджи": ["фон", "гун", "дагомеец", "восточные эве"],
    "джезва": ["джезвей", "турка", "далла"],
    "джезве": ["кафениче"],
    "джеймс": ["джим", "джимми"],
    "джеймс-бондовский": ["бондовский"],
    "джеймсбондиана": ["бондиана", "кинобондиана"],
    "джек": ["вихляй"],
    "джекпот": ["куш"],
    "джекфрут": ["канун"],
    "джелоба": ["джаллабийя", "джеллаба"],
    "джем": ["конфитюр", "повидло"],
    "джемпер": ["пуловер"],
    "джемс": ["джеймс"],
    "джендем": ["ад", "пъкъл", "мъчилище", "преизподня"],
    "джентльмен": ["эсквайр"],
    "джентльмен удачи": ["пират", "разбойник", "жулик", "мошенник"],
    "джентрификация": ["реновация", "ревитализация"],
    "джеркбейт": ["джерк-бейт"],
    "джерримендеринг": ["избирательная геометрия", "избирательная география"],
    "джеспилит": ["железистый кварцит"],
    "джетлаг": ["десинхрония", "синдром смены часового пояса"],
    "джетлег": ["джетлаг"],
    "джибути": ["республика джибути"],
    "джига": ["жига"],
    "джигда": ["лох узколистный"],
    "джигитовав": ["джигитовавши"],
    "джигитовавши": ["джигитовав"],
    "джигитовать": ["вольтижировать"],
    "джигитовка": ["вольтижировка"],
    "джидда": ["пшат", "лоховина", "лох"],
    "джил": ["джиль"],
    "джила": ["хила"],
    "джиль": ["джил"],
    "джилян": ["гилян"],
    "джимхана": ["вольтижировка", "слалом"],
    "джингоизм": ["шовинизм"],
    "джинн": ["джин"],
    "джинса": ["джинсовка"],
    "джинсуха": ["джинса"],
    "джинсы": ["джины", "джинсуха", "джинсяры"],
    "джины": ["джинсы"],
    "джип": ["вседорожник", "вездеход"],
    "джиу-джитсу": ["дзю-дзюцу"],
    "джихад": ["газават"],
    "джихад-арба": ["джамшутка"],
    "джихад-мобиль": ["шахид-мобиль", "техничка", "бандеромобиль"],
    "джихадист": ["гази", "моджахед"],
    "джойнт": ["косяк", "косячина", "пятка", "гудуля"],
    "джоли-джамперы": ["джамперы", "джампы"],
    "джомолунгма": ["эверест", "сагарматха", "шэнмуфэн"],
    "джон": ["джонни"],
    "джон булль": ["джон буль", "джон-буль"],
    "джонни": ["джон"],
    "джордж": ["георг"],
    "джорджия": ["георгия"],
    "джоуль": ["ватт-секунда"],
    "джугара": ["дурра"],
    "джудит": ["джуди"],
    "джун": ["джуниор"],
    "джунгли": ["сельва"],
    "джуниор": ["джун"],
    "джурбай": ["каландра"],
    "джыл": ["жыл"],
    "джынс": ["дзынс"],
    "джэдкъаз": ["бзу"],
    "джювлы": ["ромны", "гаджи"],
    "дзайбацу": ["чеболь"],
    "дзан": ["джан"],
    "дзевяты": ["дзявяты"],
    "дзекав": ["дзекавши"],
    "дзекавши": ["дзекав"],
    "дзеленькати": ["дзеленчати"],
    "дзеля": ["для"],
    "дзен": ["дзен-буддизм", "дзэн"],
    "дзен-буддизм": ["дзен"],
    "дзерен": ["дзэрэн"],
    "дзержинск": ["чёрное", "растяпино", "койданово", "торецк", "щербиновка"],
    "дзеркало": ["люстерко"],
    "дзета": ["зита"],
    "дзинькав": ["дзинькавши"],
    "дзинькавши": ["дзинькав"],
    "дзинькнув": ["дзинькнувши"],
    "дзинькнувши": ["дзинькнув"],
    "дзинькнуть": ["звякнуть"],
    "дзуккетто": ["пилеолус"],
    "дзырд": ["ныхас", "сыбыртт"],
    "дзьмухавец": ["адуванчык"],
    "дзэн": ["дзен"],
    "дзэн-буддист": ["дзен-буддист"],
    "дзю-дзюцу": ["джиу-джитсу"],
    "дзюдоист": ["дзюдока"],
    "дзюркотати": ["дзюрчати"],
    "дзюрчати": ["журчати"],
    "диабаз": ["долерит"],
    "диабазовая структура": ["офитовая структура"],
    "диавол": ["дьявол"],
    "диагноз": ["клиника"],
    "диагност": ["диагностик"],
    "диагностика": ["определение", "выявление", "диагностирование"],
    "диагностировав": ["диагностировавши"],
    "диагностировавши": ["диагностировав"],
    "диагностирование": ["диагностика"],
    "диада": ["пара"],
    "диадема": ["тиара"],
    "диазокопия": ["синька"],
    "диазот": ["азот"],
    "диазотипия": ["диазография", "светокопирование"],
    "диазотрофия": ["азотфиксация", "азотофиксация"],
    "диакон": ["дьякон"],
    "диаконисса": ["диаконица", "дьяконица"],
    "диаконник": ["малая ризница", "ризница"],
    "диаконские двери": ["диаконские врата"],
    "диаконство": ["дьяконство"],
    "диаконствовав": ["диаконствовавши"],
    "диаконствовавши": ["диаконствовав"],
    "диакритика": ["акцент"],
    "диалект": ["наречие", "говор"],
    "диалектальный": ["диалектный"],
    "диалектический": ["диалектальный"],
    "диалектичный": ["диалектический"],
    "диализировав": ["диализировавши"],
    "диализировавши": ["диализировав"],
    "диалог": ["разговор", "беседа", "събеседване"],
    "диалогичный": ["диалогический"],
    "диамант": ["бриллиант"],
    "диаметрально": ["напротив", "полностью", "совершенно"],
    "диамид": ["гидразин"],
    "диаммофос": ["гидрофосфат аммония", "диаммонийфосфат"],
    "диаморфин": ["героин", "диацетилморфин"],
    "дианочка": ["диана"],
    "диапазон": ["спектр", "интервал"],
    "диапауза": ["гибернация", "спячка"],
    "диапроектор": ["диаскоп"],
    "диарея": ["понос"],
    "диаскоп": ["диапроектор"],
    "диаскопия": ["витропрессия"],
    "диаспора": ["рассеяние"],
    "диаспоровый": ["диаспоральный"],
    "диаспорология": ["карпоэкология"],
    "диастаза": ["амилаза"],
    "диастазурия": ["амилазурия"],
    "диастематомиелия": ["дипломиелия"],
    "диастола": ["эктазис"],
    "диастрофизм": ["орогения"],
    "диастрофический": ["тектонический"],
    "диасхистовый": ["диашистовый", "расщепленный"],
    "диатезный": ["аллергический"],
    "диатермия": ["термопенетрация", "эндотермия", "электропенетрация", "электротранстермия"],
    "диатермокоагуляция": ["электрокоагуляция"],
    "диатермоэлектрофорез": ["ионогальванодиатермия"],
    "диатол": ["диэтилкарбонат"],
    "диатомея": ["диатомовая водоросль"],
    "диатомит": ["кизельгур", "инфузорная земля", "горная мука", "целит"],
    "диатриба": ["проповедь", "обличение", "памфлет", "разоблачение", "обвинение", "филиппика"],
    "диафрагмировав": ["диафрагмировавши"],
    "диафрагмировавши": ["диафрагмировав"],
    "диахронический": ["диахронный"],
    "диацетат": ["биацетат"],
    "диацетилморфин": ["героин"],
    "диацилглицерин": ["диацилглицерол"],
    "диацитный": ["кариофиллоидный", "перекрестноклеточный"],
    "диботриоцефалёз": ["ботриоцефалёз", "дифиллоботриоз"],
    "дибрахий": ["пиррихий"],
    "див": ["дэв"],
    "дива": ["дивия", "дева", "диана"],
    "дивагация": ["бред", "бредни"],
    "дивайс": ["девайс", "устройство"],
    "дивакансия": ["бивакансия"],
    "диван": ["ложе"],
    "диванные войска": ["вотсапные войска", "вацапные войска", "клавиатурный спецназ", "диванные теоретики"],
    "диванный": ["любительский", "доморощенный", "дилетантский", "профанский"],
    "диванхана": ["присутственное место"],
    "диващина": ["грубостъ", "бруталност", "зверство", "зверщина", "жестокост", "варварство"],
    "дивда": ["дифта"],
    "дивектор": ["бивектор"],
    "дивергенция": ["расхождение", "расходимость"],
    "дивергировав": ["дивергировавши"],
    "дивергировавши": ["дивергировав"],
    "диверсионно-разведывательная группа": ["дрг"],
    "диверсионно-разведывательный": ["разведывательно-диверсионный"],
    "диверсионный": ["диверсантский", "подрывной"],
    "диверсификация": ["диверсифицирование"],
    "диверсифицировав": ["диверсифицировавши"],
    "диверсифицировавши": ["диверсифицировав"],
    "диверсифицирование": ["диверсификация"],
    "диверсифицировать": ["разнообразить"],
    "дивехи": ["мальдивский язык"],
    "дивив": ["дививши"],
    "дививши": ["дивив"],
    "дивиди": ["дивиди-диск", "дивидишка"],
    "дивиди-диск": ["дивиди"],
    "дивиди-плеер": ["дивиди-проигрыватель", "дивидишник"],
    "дивидишка": ["дивиди", "дивиди-диск"],
    "дивидюк": ["двд-проигрыватель", "ди-ви-ди-проигрыватель", "дивиди-проигрыватель", "двд", "дивидишка", "дивидишник", "дивидюшник", "дивидильник", "дивидюльник", "дивидак", "дивидюн", "дидюк", "двд-диск"],
    "дивинация": ["прорицание", "гадание"],
    "дивинил": ["бутадиен"],
    "дивинировать": ["догадываться"],
    "дивиться": ["удивляться", "дивоваться"],
    "дивниця": ["диво"],
    "дивногорье": ["дивные горы", "донское дивногорье"],
    "дивный": ["чудесный", "чудный", "прекрасный", "восхитительный"],
    "диво": ["чудо"],
    "дивоваться": ["любоваться"],
    "дивчина": ["девушка", "девица"],
    "дигамия": ["двоебрачие", "двоежёнство"],
    "дигамма": ["вав", "двойная гамма"],
    "дигестия": ["сахаристость", "пищеварение"],
    "дигесты": ["пандекты"],
    "дигидрат": ["бигидрат"],
    "дигидрид": ["бигидрид"],
    "дигидромонооксид": ["вода"],
    "дигидротестостерон": ["дгт"],
    "дигитайзер": ["графический планшет", "планшет для рисования", "диджитайзер"],
    "дигитализация": ["оцифровка", "дигитизация", "цифровизация", "диджитализация"],
    "дигитальный": ["цифровой", "виртуальный", "двоичный"],
    "диглиф": ["двоерез"],
    "диграф": ["диграмма"],
    "дигрессия": ["отступление", "экскурс"],
    "дид": ["дед", "прародитель", "дедушка"],
    "дида": ["чашм"],
    "дидактизм": ["дидактичность", "поучительность", "назидательность"],
    "дидактика": ["дидактизм"],
    "дидактический": ["педагогический", "дидактичный", "нравоучительный", "наставнический", "менторский", "учительный", "поучительный", "наставительный", "назидательный"],
    "дидактичность": ["дидактизм"],
    "дидактичный": ["назидательный", "дидактический"],
    "дидаскалейон": ["дидаскалион"],
    "диджеевский": ["диджейский"],
    "диджеив": ["диджеивши"],
    "диджеивши": ["диджеив"],
    "диджеить": ["диджействовать"],
    "диджей": ["диск-жокей"],
    "диджейский": ["диджеевский"],
    "диджействовав": ["диджействовавши"],
    "диджействовавши": ["диджействовав"],
    "диджействовать": ["диджеить"],
    "диджитализация": ["дигитализация", "цифровизация"],
    "дидодекаэдр": ["двадцатичетырёхгранник"],
    "диез": ["диэз", "диезис", "семитониум"],
    "диен": ["алкадиен"],
    "диереза": ["диерезис"],
    "диерезис": ["трема"],
    "диета": ["рацион"],
    "диететика": ["диетология"],
    "диетив": ["диетивши"],
    "диетивши": ["диетив"],
    "диетический": ["диетный"],
    "диетный": ["диетический"],
    "диетология": ["диететика"],
    "дизайнер": ["проектировщик"],
    "дизайнерствовав": ["дизайнерствовавши"],
    "дизайнерствовавши": ["дизайнерствовав"],
    "дизамбиг": ["неоднозначность"],
    "дизамбигуация": ["таггинг"],
    "дизассемблер": ["реассемблер"],
    "дизассемблировав": ["дизассемблировавши"],
    "дизассемблировавши": ["дизассемблировав"],
    "дизелестроение": ["дизелестроительство"],
    "дизель": ["дизельмотор", "соляра", "солярка", "дизтопливо"],
    "дизель-поезд": ["дизель"],
    "дизентерия": ["шигеллёз"],
    "дизлайк": ["дислайк"],
    "дизморалить": ["деморализовывать"],
    "дизъюнктный": ["дизъюнктивный"],
    "дизъюнкция": ["логическое сложение"],
    "диис": ["моортай"],
    "дий": ["дый", "зевс"],
    "дийнат": ["экха"],
    "дикарка": ["туземка"],
    "дикастерий": ["дикастерия", "гелиэя"],
    "дикастерия": ["дикастерий"],
    "дикая роза": ["шиповник"],
    "дикенький": ["серовато-жёлтый"],
    "дикий": ["неокультуренный", "первозданный", "неприручённый", "неодомашненный", "некультивированный", "первобытный", "примитивный", "необузданный", "несдержанный", "ужасный", "нелепый", "неправдоподобный", "необычный"],
    "дикий голубь": ["клинтух"],
    "дикий перец": ["элеутерококк", "сибирский женьшень", "чёртов куст"],
    "дикирий": ["двусвечник"],
    "дикобразий": ["дикобразовый"],
    "дикобразовый": ["дикобразий"],
    "диковав": ["диковавши"],
    "диковавши": ["диковав"],
    "диковинный": ["необыкновенный", "необычный", "странный", "небывалый", "невиданный", "неслыханный"],
    "дикой": ["дикий"],
    "дикообразный": ["дикий"],
    "дикость": ["дичь", "грубость", "необузданность", "свирепость", "вандализм", "чудовищность"],
    "дикошарый": ["дикообразный", "дичайший", "одичалый", "одичавший"],
    "диксончанин": ["диксонец"],
    "диктатор": ["вождь"],
    "диктаторствовав": ["диктаторствовавши"],
    "диктаторствовавши": ["диктаторствовав"],
    "диктаторша": ["тиранка", "вождица"],
    "диктатура": ["автократия", "тоталитаризм"],
    "диктовав": ["диктовавши"],
    "диктовавши": ["диктовав"],
    "диктовка": ["диктование", "диктант"],
    "диктор": ["актёр озвучивания"],
    "дилатационный": ["дилятационный"],
    "дилдак": ["дилдачина"],
    "дилдо": ["фаллоимитатор", "годмише", "самотык", "дилдак"],
    "дилен": ["эндсы"],
    "дилетант": ["любитель", "аматёр"],
    "дилетантизм": ["непрофессионализм"],
    "дилетантизъм": ["любителство", "аматьорство", "неподготвеност"],
    "дилетантство": ["дилетантизм", "любительство"],
    "дилижанец": ["дилижанс"],
    "дилижанс": ["дилижанец"],
    "дилос": ["делос"],
    "диль": ["дейле"],
    "дильдрин": ["гэод"],
    "дилювиальный": ["допотопный"],
    "дим": ["пушек"],
    "дима": ["митя", "димон"],
    "димедрол": ["дифенгидрамин"],
    "димельштадт": ["димель"],
    "дименсия": ["деменция"],
    "диметикон": ["конотран", "сиопел"],
    "диметиламиноэтанол": ["диметилэтаноламин", "деанол"],
    "диметилбензол": ["ксилол"],
    "диминутив": ["деминутив"],
    "диминутивация": ["диминутивизация"],
    "диминутивизация": ["диминутивация"],
    "диминуэндо": ["декрешендо", "декрещендо"],
    "димитриевич": ["димыч"],
    "димитрий": ["дмитрий"],
    "диммер": ["светорегулятор"],
    "диморфотека": ["золотоцвет"],
    "динамив": ["динамивши"],
    "динамивши": ["динамив"],
    "динамизировав": ["динамизировавши"],
    "динамизировавши": ["динамизировав"],
    "динамизм": ["динамика"],
    "динамик": ["громкоговоритель"],
    "динамить": ["водить за нос", "вводить в заблуждение", "обманывать", "лгать", "врать", "гулять", "прогуливать", "забивать", "флиртовать"],
    "динамически": ["динамично"],
    "динамическое рассеяние света": ["фотонная корреляционная спектроскопия"],
    "динамично": ["активно", "быстро", "оживлённо", "энергично"],
    "динамичность": ["динамизм", "энергичность", "стремительность"],
    "динамичный": ["динамический", "подвижный", "изменчивый"],
    "динамка": ["динамо-машина", "динамо"],
    "динамо": ["динамо-машина"],
    "динамо-машина": ["динамо"],
    "динамометр": ["силомер"],
    "динарий": ["денарий"],
    "династия": ["дом"],
    "дини": ["руханый"],
    "динитрофенол": ["днп"],
    "динитроцеллюлоза": ["коллоксилин"],
    "динлин": ["гаочэ", "телэ"],
    "динозавр": ["ящер", "ретроград", "консерватор"],
    "динора": ["динор"],
    "динотерий": ["дейнотерий"],
    "динофлагеллят": ["динофит", "перидинея"],
    "диноцерат": ["страннорог", "уинтатерий"],
    "диноцефал": ["дейноцефал"],
    "динь": ["дзынь", "тинь"],
    "динька": ["динятко"],
    "динькав": ["динькавши"],
    "динькавши": ["динькав"],
    "диня": ["любеница", "карпуз"],
    "диоксан": ["диэтилендиоксид", "диэтиловый эфир"],
    "диоксид": ["двуоксид", "двуокись"],
    "диоксид кремния": ["двуокись кремния"],
    "диоксид углерода": ["углекислый газ", "углекислота", "двуокись углерода", "угольный ангидрид"],
    "диоксиметилен": ["параформальдегид"],
    "диоксометилтетрагидропиримидин": ["метилурацил"],
    "диоктаэдр": ["шестнадцатигранник"],
    "диол": ["гликоль"],
    "диомид": ["демид"],
    "дионин": ["этилморфин"],
    "дионис": ["бахус", "вакх"],
    "диоптрия": ["дптр"],
    "диоцез": ["диоцезия", "край", "область", "епархия"],
    "диоцезия": ["диоцез", "епархия", "епископия", "архиепископия"],
    "дипанкара": ["атиша дипанкара шриджняна"],
    "дипептидгидролаза": ["дипептидаза"],
    "дипирамида": ["бипирамида"],
    "дипирамидальный": ["бипирамидальный"],
    "дипла": ["гънка", "плисе"],
    "диплоген": ["дейтерий"],
    "дипломант": ["дипломник"],
    "дипломатически": ["дипломатично"],
    "дипломатический": ["дипломатичный"],
    "дипломатический курьер": ["дипкурьер"],
    "дипломатический паспорт": ["диппаспорт"],
    "дипломатично": ["дипломатически"],
    "дипломатичность": ["дипломатизм", "тактичность"],
    "дипломатичный": ["дипломатический"],
    "дипломатия": ["дипломатичность"],
    "дипломатничав": ["дипломатничавши"],
    "дипломатничавши": ["дипломатничав"],
    "дипломировав": ["дипломировавши"],
    "дипломировавши": ["дипломировав"],
    "диплон": ["дейтрон"],
    "диплонема": ["диплотена"],
    "диплотена": ["диплонема"],
    "диплофония": ["дифтонгия", "дифония"],
    "диплохромосома": ["удвоенная хромосома"],
    "диполярный": ["биполярный"],
    "дипротон": ["бипротон"],
    "дипсомания": ["запой"],
    "диптера": ["двукрылый"],
    "диптих": ["складень"],
    "дир": ["директор"],
    "дира": ["дирка", "отверстие"],
    "дирав": ["диравши"],
    "диравши": ["дирав"],
    "диравый": ["дырявый", "прорванный", "продырявленный", "дырчатый"],
    "директ-маркетинг": ["прямой маркетинг"],
    "директива": ["установка", "указание", "распоряжение", "инструкция"],
    "директивно-командный": ["командно-директивный"],
    "директор": ["главный", "начальник", "руководитель"],
    "директорий": ["директория", "каталог", "папка", "фолдер"],
    "директорствовав": ["директорствовавши"],
    "директорствовавши": ["директорствовав"],
    "директорша": ["директриса"],
    "директриса": ["директорка"],
    "дирекция": ["директорат"],
    "дирижировав": ["дирижировавши"],
    "дирижировавши": ["дирижировав"],
    "дирижированье": ["дирижирование"],
    "дирижёр": ["манипулятор", "организатор", "кукловод", "руководитель"],
    "дирик": ["директор", "дир", "дира", "дирекшионер"],
    "дирка": ["дырка", "отверстие"],
    "диродан": ["родан"],
    "дирхам": ["дирхем", "дирик"],
    "дирхем": ["дирхам"],
    "дисбалансировав": ["дисбалансировавши"],
    "дисбалансировавши": ["дисбалансировав"],
    "дисбаризм": ["аэроэмболия"],
    "дисбулия": ["абулия"],
    "дисгармонировав": ["дисгармонировавши"],
    "дисгармонировавши": ["дисгармонировав"],
    "дисгармоничность": ["дисгармония", "разлад"],
    "дисгармоничный": ["дисгармонический"],
    "дисгармония": ["диссонанс", "неблагозвучность", "разлад", "несогласованность"],
    "дисгенезия": ["дисплазия", "недоразвитие"],
    "дисгидроз": ["водяница"],
    "дисиллаб": ["двусложный", "слово"],
    "диск": ["шайба", "круг", "музыкальный диск", "суставной диск", "хрящевой диск"],
    "диск-гигант": ["гигант"],
    "диск-жокей": ["диджей"],
    "диск-корреспондент": ["диск-жокей", "дискор"],
    "дискальный": ["дискообразный"],
    "дискантный": ["дискантовый"],
    "дискать": ["де", "мол", "значит"],
    "дискаунт": ["скидка", "дисконт", "дискаунтер"],
    "дискаунтер": ["дискаунт"],
    "дисквал": ["дисквалификация"],
    "дисквалифай": ["дисквалификация"],
    "дисквалификация": ["дисквалифай"],
    "дисквалифицировав": ["дисквалифицировавши"],
    "дисквалифицировавши": ["дисквалифицировав"],
    "дискета": ["флоппи-дискета", "флоппи-диск", "флопик", "гибкий магнитный диск", "гмд"],
    "дискинезия": ["гиперкинез"],
    "дисковав": ["дисковавши"],
    "дисковавши": ["дисковав"],
    "дисковидный": ["дискообразный", "дискоидный"],
    "дисковод": ["привод"],
    "дисконтировав": ["дисконтировавши"],
    "дисконтировавши": ["дисконтировав"],
    "дискор": ["диск-корреспондент"],
    "дискордантность": ["схизис", "интрапсихическая атаксия"],
    "дискордианство": ["дискордианизм"],
    "дискордия": ["эрида"],
    "дискотетчик": ["дискотечник"],
    "дискотечник": ["дискотетчик"],
    "дискредитация": ["дискредитирование", "замарывание", "инсинуация", "клевета", "компрометация", "компрометирование", "марание", "маранье", "обесславливание", "обесчещивание", "опорочивание", "охаивание", "очернение", "пачканье", "порочение"],
    "дискредитировав": ["дискредитировавши"],
    "дискредитировавши": ["дискредитировав"],
    "дискредитирование": ["дискредитация"],
    "дискредитировать": ["компрометировать", "опустить", "опускать"],
    "дискретизировав": ["дискретизировавши"],
    "дискретизировавши": ["дискретизировав"],
    "дискретно": ["раздельно", "прерывисто", "дробно"],
    "дискретность": ["прерывность"],
    "дискретный": ["точечный", "прерывистый"],
    "дискриминировав": ["дискриминировавши"],
    "дискриминировавши": ["дискриминировав"],
    "дискуссант": ["дискутант"],
    "дискуссионность": ["спорность"],
    "дискуссировав": ["дискуссировавши"],
    "дискуссировавши": ["дискуссировав"],
    "дискуссировать": ["дискутировать"],
    "дискуссия": ["обсуждение", "спор", "полемика", "диспут", "дебаты", "дискутирование"],
    "дискутабельный": ["спорный", "дискуссионный"],
    "дискутант": ["дискуссант"],
    "дискутировав": ["дискутировавши"],
    "дискутировавши": ["дискутировав"],
    "дискутирование": ["дискуссия", "обсуждение"],
    "дискутировать": ["обсуждать", "спорить", "дискуссировать"],
    "дискутироваться": ["обсуждаться"],
    "дислексик": ["дислектик"],
    "дислексия": ["легастения"],
    "дислектик": ["дислексик"],
    "дислокация": ["смещение", "перемещение"],
    "дислоцировав": ["дислоцировавши"],
    "дислоцировавши": ["дислоцировав"],
    "дисморфия": ["дисморфофобия"],
    "дисморфофобия": ["дисморфия"],
    "диспансеризовав": ["диспансеризовавши"],
    "диспансеризовавши": ["диспансеризовав"],
    "диспансеризовать": ["обследовать"],
    "диспарантность": ["диспаратность"],
    "диспаратность": ["диспарантность"],
    "диспепсический": ["диспептический"],
    "диспептический": ["диспепсический"],
    "диспергировав": ["диспергировавши"],
    "диспергировавши": ["диспергировав"],
    "диспергирование": ["диспергация"],
    "дисперсировав": ["дисперсировавши"],
    "дисперсировавши": ["дисперсировав"],
    "дисперсный": ["дисперсионный"],
    "диспетчер": ["координатор", "распорядитель", "планировщик"],
    "диспетчерствовав": ["диспетчерствовавши"],
    "диспетчерствовавши": ["диспетчерствовав"],
    "дисплазия": ["дисгенезия"],
    "дисплей": ["монитор"],
    "диспноэ": ["одышка"],
    "диспозиция": ["расположение"],
    "диспонировав": ["диспонировавши"],
    "диспонировавши": ["диспонировав"],
    "диспропорциональный": ["непропорциональный"],
    "диспропорционирование": ["дисмутация"],
    "диспропорция": ["диссиметрия", "дисгармония"],
    "диспут": ["спор", "дискуссия"],
    "диспутировав": ["диспутировавши"],
    "диспутировавши": ["диспутировав"],
    "диссектор": ["анатом", "прозектор"],
    "диссеминация": ["распространение"],
    "диссеминировав": ["диссеминировавши"],
    "диссеминировавши": ["диссеминировав"],
    "диссеминированный": ["рассеянный", "распространённый"],
    "диссида": ["диссидентство", "диссидентщина", "диссент"],
    "диссидент": ["инакомыслящий", "инакодумец", "отщепенец", "нонконформист", "оппортунист", "оппозиционер", "несогласный", "еретик", "вероотступник"],
    "диссидентствовав": ["диссидентствовавши"],
    "диссидентствовавши": ["диссидентствовав"],
    "диссидентщина": ["диссидентство", "диссент", "диссида"],
    "диссимиляция": ["расподобление", "различение", "катаболизм"],
    "диссимметрия": ["асимметрия"],
    "диссимулировав": ["диссимулировавши"],
    "диссимулировавши": ["диссимулировав"],
    "диссомния": ["асомния", "агрипния", "бессонница", "инсомния"],
    "диссонанс": ["дисгармония", "разлад", "диссонансная рифма"],
    "диссонировав": ["диссонировавши"],
    "диссонировавши": ["диссонировав"],
    "диссоциация": ["растворение", "распад", "отделение", "разделение", "сегрегация", "разъединение"],
    "диссоциировав": ["диссоциировавши"],
    "диссоциировавши": ["диссоциировав"],
    "диссоциировать": ["распадаться", "разлагаться", "разъединять", "разобщать"],
    "дистальный прикус": ["прогнатический прикус"],
    "дистант": ["дистанционка", "удалёнка"],
    "дистантный": ["дистанционный"],
    "дистанционное обучение": ["дистанционка", "дистант", "удалёнка"],
    "дистанционность": ["удалённость"],
    "дистанционный": ["удалённый"],
    "дистанцировав": ["дистанцировавши"],
    "дистанцировавши": ["дистанцировав"],
    "дистанцирование": ["отдаление", "дистанция", "отстранённость", "отдалённость"],
    "дистанция": ["расстояние"],
    "дистен": ["кианит", "баус", "псевдоандалузит", "саппарит", "тальковый шерл"],
    "дистеновый": ["кианитовый"],
    "дистиллировав": ["дистиллировавши"],
    "дистиллировавши": ["дистиллировав"],
    "дистиллированный": ["очищенный", "вычищенный", "безвкусный", "пресный"],
    "дистиллировать": ["перегонять"],
    "дистиллятор": ["перегонный куб"],
    "дистимный": ["гипотимный"],
    "дистопический": ["дистопичный", "дистопированный", "антиутопический"],
    "дистопия": ["гетеротопия", "эктопия", "антиутопия"],
    "дисторзия": ["дисторсия"],
    "дисторсия": ["дисторзия"],
    "дисторция": ["изкривяване", "деформация"],
    "дистракция": ["рассеянность"],
    "дистрибьютор": ["дистрибутор"],
    "дистрофик": ["анорексик", "хиляк", "слабак"],
    "дистрофичный": ["дистрофический"],
    "дисульфид": ["бисульфид"],
    "дисульфид углерода": ["сероуглерод"],
    "дисульфидный": ["бисульфидный"],
    "дисфемизм": ["какофемизм"],
    "дисфония": ["афония"],
    "дисфория": ["хандра", "сплин"],
    "дисциплина научная": ["научная дисциплина"],
    "дисциплинировав": ["дисциплинировавши"],
    "дисциплинировавши": ["дисциплинировав"],
    "дисциплинированность": ["самодисциплина", "организованность"],
    "дит": ["донн"],
    "дитина": ["дитя", "чадо"],
    "дитиол": ["димеркаптан"],
    "дитриглиф": ["метоп", "метопа"],
    "дитя": ["крошка", "малютка", "младенец", "ребенок", "малолетний", "малолеток", "малыш", "чадо", "исчадие", "отпрыск", "отродье", "плод", "порождение", "птенец", "вылупок"],
    "дитятка": ["дитятко", "дитя", "ребёнок"],
    "дитятко": ["дитя", "дитятка"],
    "дитятя": ["дитя", "чадо"],
    "дитёнок": ["детёнок", "ребёнок"],
    "диулин": ["дюлин"],
    "диуретик": ["мочегонное"],
    "диуретический": ["мочегонный"],
    "дифенил": ["бифенил"],
    "дифениламин": ["дфа"],
    "дифиллоботриоз": ["ботриоцефалёз", "диботриоцефалёз"],
    "дифирамб": ["гимн", "панегирик", "похвала", "славословие", "хвала"],
    "дифосфат": ["пирофосфат"],
    "дифрагировав": ["дифрагировавши"],
    "дифрагировавши": ["дифрагировав"],
    "дифтерийный": ["дифтеритный"],
    "дифтерит": ["дифтерия"],
    "дифтеритный": ["дифтерийный"],
    "дифтерия": ["дифтерит"],
    "дифтонг": ["двугласный", "двоегласный"],
    "дифф": ["дифференциал"],
    "диффамационный": ["клеветнический", "пасквильный"],
    "диффамация": ["чёрный пиар", "клевета", "очернение", "злословие"],
    "диффамировав": ["диффамировавши"],
    "диффамировавши": ["диффамировав"],
    "дифферент": ["тангаж"],
    "дифференцировав": ["дифференцировавши"],
    "дифференцировавши": ["дифференцировав"],
    "дифференцирование": ["дифференциация"],
    "дифференцированный": ["разграниченный"],
    "диффузия": ["смешивание", "взаимопроникновение", "смешение"],
    "диффузность": ["неопределённость", "расплывчатость"],
    "диффундировав": ["диффундировавши"],
    "диффундировавши": ["диффундировав"],
    "дихлордифенилтрихлорметилметан": ["ддт"],
    "дихлордифенилтрихлорэтан": ["ддт", "клофенотан"],
    "дихромат": ["бихромат"],
    "дихроматизм": ["бихроматизм"],
    "дихроматический": ["бихроматический"],
    "дицентрический": ["бицентрический"],
    "дициан": ["циан"],
    "дичав": ["дичавши"],
    "дичавши": ["дичав"],
    "дичиться": ["сторониться", "чуждаться", "чураться", "стесняться", "смущаться", "конфузиться", "тушеваться"],
    "дичок": ["сеянец", "подвой"],
    "дичь": ["дичина", "чушь", "бред", "бредятина", "галиматья", "глушь"],
    "дишель": ["дишло"],
    "дишельний": ["дишловий"],
    "дишканить": ["голосить"],
    "дишловий": ["дишельний"],
    "диэдр": ["двугранник"],
    "диэлектрик": ["изолятор", "непроводник"],
    "диэтиленгликоль": ["дигликоль"],
    "диярбакыр": ["амид"],
    "дкп": ["доконтактная профилактика"],
    "длань": ["ладонь", "рука", "кисть", "лапа"],
    "длив": ["дливши"],
    "дливши": ["длив"],
    "длина": ["размер", "протяжённость", "расстояние"],
    "длиннев": ["длинневши"],
    "длинневши": ["длиннев"],
    "длинно": ["протяжённо"],
    "длинновязый": ["долговязый", "высокий"],
    "длинногривый": ["долгогривый"],
    "длинноногий": ["долгоногий"],
    "длиннополый": ["долгополый"],
    "длиннорукий": ["долгорукий"],
    "длиннохвост": ["долгохвост", "макрурус"],
    "длиннохвостая синица": ["ополовник"],
    "длиннохвостый": ["долгохвостый"],
    "длинношеий": ["долгошеий"],
    "длинношёрстный": ["длинношёрстый", "долгошёрстный", "долгошёрстый"],
    "длинношёрстый": ["длинношёрстный", "долгошёрстный", "долгошёрстый"],
    "длиннущий": ["длиннющий"],
    "длинный": ["вытянутый", "долгий", "длительный", "продолжительный", "высокий", "долговязый", "рослый", "высокорослый", "верзила", "дылда", "каланча", "жердь", "жердяй", "верста", "детина"],
    "длинный ковид": ["лонг-ковид", "постковид", "постковидный синдром"],
    "длиннющий": ["длиннущий"],
    "длительность": ["продолжительность"],
    "длительный": ["долгий", "продолжительный"],
    "длить": ["продлевать"],
    "длиться": ["продолжаться"],
    "для": ["ради", "на", "за", "во имя", "на благо", "во благо", "в пользу", "из-за", "в целях", "с целью", "относительно", "по сравнению с"],
    "для блезиру": ["для вида", "для проформы", "для блезира"],
    "для души": ["для себя", "для удовольствия"],
    "для мебели": ["для вида", "для галочки"],
    "для острастки": ["на всякий пожарный"],
    "для фасада": ["для отвода глаз", "для проформы"],
    "для-ради": ["для", "ради"],
    "дмитриевка": ["талас"],
    "дмитрий": ["димитрий", "дима", "митя"],
    "дмитровск": ["дмитровск-орловский"],
    "дмс": ["добровольное медицинское страхование"],
    "дневав": ["дневавши"],
    "дневавши": ["дневав"],
    "дневалив": ["дневаливши"],
    "дневаливши": ["дневалив"],
    "дневалить": ["дневальствовать"],
    "дневальный": ["дежурный"],
    "дневна": ["стая", "всекидневна"],
    "дневник": ["отчёт", "журнал", "дневные записки", "подневные записки"],
    "дневной": ["денной", "денный", "суточный", "очный"],
    "днепр": ["бористен", "борисфен", "славутич", "днепропетровск", "екатеринослав", "новороссийск"],
    "днепро-бугский лиман": ["днепровско-бугский лиман"],
    "днепропетровск": ["днепр", "екатеринослав", "новороссийск"],
    "днепропетровская область": ["днепропетровщина"],
    "днепропетровский": ["днепровский"],
    "днепрорудное": ["дружба", "днепроград"],
    "днесь": ["ныне", "сегодня", "нынче", "нонеча"],
    "днина": ["день"],
    "днище": ["дно", "ноль", "слабак", "нуб"],
    "днищенский": ["отстойный"],
    "днк": ["дезоксирибонуклеиновая кислота"],
    "днк-анализ": ["днк-тест", "генотипоскопия"],
    "днк-тест": ["днк-анализ", "генотипоскопия"],
    "дно": ["основание", "днище", "низы", "отбросы"],
    "днт": ["дача"],
    "днюха": ["день рождения", "день варенья", "др", "бёздник"],
    "днюшечка": ["днюха", "день рождения"],
    "днями": ["на днях"],
    "до": ["дошкольное образование", "дополнительное образование"],
    "до балды": ["до лампочки", "параллельно", "фиолетово"],
    "до безумия": ["беспредельно", "безгранично", "чрезвычайно", "до крайности", "до безумья"],
    "до безумья": ["беспредельно", "безгранично", "чрезвычайно", "до крайности", "до безумия"],
    "до бесконечности": ["без конца"],
    "до встречи": ["до свидания", "до свиданья", "всего доброго", "всего хорошего", "всех благ", "счастливо", "до свиданьица", "пока", "пока-пока", "покасики", "чао", "гудбай", "бай", "ауфидерзейн", "покеда"],
    "до гроба": ["до гробовой доски", "до могилы"],
    "до гробовой доски": ["до гроба", "до последнего вздоха", "до смерти", "до могилы"],
    "до дуриков": ["до чёртиков"],
    "до жопы": ["до хрена", "до фига", "до фонаря", "до лампочки", "очень", "сильно", "в высшей степени"],
    "до зарезу": ["чрезвычайно", "крайне", "очень", "во что бы то ни стало", "до зареза", "позарез", "кровь из носу"],
    "до мозга костей": ["от и до", "насквозь", "целиком и полностью"],
    "до морковкина заговенья": ["до морковкиных заговен", "до моржова заговня", "на морковкино заговенье", "на калмыцкий заговен"],
    "до нашей эры": ["до рождества христова"],
    "до нитки": ["насквозь", "совсем", "подробно"],
    "до облаков": ["под облаками"],
    "до отвала": ["вдоволь"],
    "до поры до времени": ["пока суд да дело", "временно", "покамест", "пока", "покуда", "до времени", "пока что", "на время"],
    "до последней капли": ["до конца", "полностью"],
    "до последней капли крови": ["до последнего вздоха", "не щадя живота", "до смерти", "насмерть"],
    "до пота лица": ["до седьмого пота"],
    "до рождества христова": ["до нашей эры", "до новой эры"],
    "до росы": ["до света", "до рассвета", "до свету", "спозаранку", "спозаранок"],
    "до свидания": ["до свиданья", "всего доброго", "всего хорошего", "всех благ", "счастливо", "до свиданьица", "пока", "пока-пока", "покасики", "чао", "гудбай", "бай", "ауфидерзейн", "покеда", "покедова"],
    "до свиданьица": ["до свидания", "досвидос"],
    "до свиданья": ["до свидания", "всего доброго", "всего хорошего", "всех благ", "счастливо", "до свиданьица", "пока", "пока-пока", "покасики", "чао", "гудбай", "бай", "ауфидерзейн", "покеда", "покедова"],
    "до седьмого пота": ["до пота лица"],
    "до смерти": ["чрезвычайно", "насмерть", "на смерть"],
    "до смерёточки": ["до смерти"],
    "до страсти": ["крайне", "очень"],
    "до усёру": ["до ужаса", "до самого не могу"],
    "до хрена": ["до хренища", "до фига"],
    "до хуища": ["до хуя", "хуева туча", "с хуеву тучу", "до фига", "до хрена", "туева хуча", "с туеву хучу"],
    "до-бемоль": ["си"],
    "до-диез": ["ре-бемоль"],
    "доавраамический": ["языческий", "политеистический"],
    "доба": ["пора", "время", "эпоха", "эра", "година"],
    "добавив": ["добавивши"],
    "добавивши": ["добавив"],
    "добавиться": ["прибавиться"],
    "добавка": ["добавление", "прибавка"],
    "добавление": ["прибавление", "прибавка", "добавка"],
    "добавленье": ["добавление"],
    "добавляв": ["добавлявши"],
    "добавлявши": ["добавляв"],
    "добавлять": ["дополнять", "прилагать", "прибавлять", "приобщать", "присоединять", "подключать", "суммировать"],
    "добавок": ["добавка"],
    "добавочно": ["дополнительно"],
    "добавочный": ["дополнительный"],
    "добарабанив": ["добарабанивши"],
    "добарабанивши": ["добарабанив"],
    "добегав": ["добегавши"],
    "добегавши": ["добегав"],
    "добежав": ["добежавши"],
    "добежавши": ["добежав"],
    "добелив": ["добеливши"],
    "добеливав": ["добеливавши"],
    "добеливавши": ["добеливав"],
    "добеливши": ["добелив"],
    "доберман": ["доберман-пинчер"],
    "доберман-пинчер": ["доберман"],
    "добетонировав": ["добетонировавши"],
    "добетонировавши": ["добетонировав"],
    "добив": ["добивши"],
    "добивав": ["добивавши"],
    "добивавши": ["добивав"],
    "добиваться": ["достигать"],
    "добивши": ["добив"],
    "добирав": ["добиравши"],
    "добиравши": ["добирав"],
    "добитися": ["досягти"],
    "добитък": ["животно", "говедо", "добиче", "скот", "хайван"],
    "добить": ["прикончить", "доконать", "разбить", "доделать", "довершить"],
    "добиться": ["достичь", "узнать", "допытаться", "выпытать"],
    "доблестно": ["храбро", "бесстрашно", "мужественно", "смело", "отважно"],
    "доблестный": ["отважный", "храбрый", "доблественный"],
    "доблесть": ["мужество", "храбрость", "смелость", "отвага", "геройство", "героизм", "самоотверженность", "достоинство"],
    "доболев": ["доболевши"],
    "доболевши": ["доболев"],
    "доболтав": ["доболтавши"],
    "доболтавши": ["доболтав"],
    "добор": ["добирание", "донабор", "допнабор", "погоня", "преследование"],
    "доборонить": ["добороновать"],
    "добрав": ["добравши"],
    "добравши": ["добрав"],
    "дображивав": ["дображивавши"],
    "дображивавши": ["дображивав"],
    "добрасывав": ["добрасывавши"],
    "добрасывавши": ["добрасывав"],
    "добраться": ["найти разгадку", "приступить"],
    "добрая душа": ["добряк", "добрячка", "самаритянка", "самаритянин"],
    "добре": ["ладно", "хорошо"],
    "добрев": ["добревши"],
    "добревши": ["добрев"],
    "добредав": ["добредавши"],
    "добредавши": ["добредав"],
    "добрейший": ["наидобрейший"],
    "добрив": ["добривши"],
    "добривав": ["добривавши"],
    "добривавши": ["добривав"],
    "добривши": ["добрив"],
    "добричлия": ["добричанец"],
    "добро": ["благо", "хорошее", "имущество"],
    "добро пожаловать": ["с прибытием"],
    "доброволец": ["волонтёр"],
    "доброволица": ["доброволка", "волонтёрка"],
    "доброволка": ["доброволица", "волонтёрка"],
    "добровольно": ["не ожидая приглашения", "не по принуждению"],
    "добровольный": ["невынужденный"],
    "добродей": ["благодетель"],
    "добродетель": ["нравственность", "праведность", "благодеяние"],
    "добродетельный": ["нравственный"],
    "добродеяние": ["благодеяние"],
    "добродив": ["добродивши"],
    "добродивши": ["добродив"],
    "добродушие": ["доброта", "мягкосердечие", "приветливость", "незлобивость"],
    "добродушный": ["незлобивый"],
    "добродушье": ["добродушие"],
    "доброе имя": ["хорошая репутация", "честь"],
    "доброе утро": ["с добрым утром", "здравствуйте"],
    "доброжелательно": ["благожелательно", "благосклонно", "дружелюбно", "приязненно", "дружески"],
    "доброжелательность": ["благожелательность", "дружелюбие", "дружественность", "расположенность", "благорасположенность", "расположение", "благосклонность", "приветливость"],
    "доброжелательный": ["благожелательный", "благодушный", "добродушный", "добросердечный"],
    "доброжелательство": ["доброжелательность"],
    "доброжелательствовав": ["доброжелательствовавши"],
    "доброжелательствовавши": ["доброжелательствовав"],
    "доброй ночи": ["спокойной ночи"],
    "доброкачественный": ["качественный", "хороший"],
    "добролюбие": ["доброта"],
    "добром": ["добровольно", "по доброй воле"],
    "добронравие": ["благонравие"],
    "добронравный": ["благонравный"],
    "добронравье": ["добронравие"],
    "добропорядочный": ["приличный", "честный", "уважаемый"],
    "доброс": ["добрасывание"],
    "добросав": ["добросавши"],
    "добросавши": ["добросав"],
    "добросердечие": ["добросердечность", "доброта", "участие"],
    "добросердечность": ["добросердечие", "добродушие", "доброта"],
    "добросердечный": ["ласковый", "участливый", "добрый", "сердечный", "благодушный", "добродушный", "простой", "чувствительный"],
    "добросердечье": ["добросердечие"],
    "добросив": ["добросивши"],
    "добросивши": ["добросив"],
    "добросовестно": ["усердно"],
    "добросовестность": ["честность", "старательность"],
    "добросовестный": ["основательный", "старательный", "исполнительный", "ответственный"],
    "добрососедский": ["недобрососедский"],
    "добрососедствовав": ["добрососедствовавши"],
    "добрососедствовавши": ["добрососедствовав"],
    "доброта": ["ласка", "дружба", "забота"],
    "добротно": ["качественно", "надёжно", "основательно"],
    "добротный": ["доброкачественный", "качественный", "хороший"],
    "доброхот": ["благожелатель", "доброжелатель", "доброволец", "волонтёр"],
    "доброхотствовав": ["доброхотствовавши"],
    "доброхотствовавши": ["доброхотствовав"],
    "доброчестина": ["благоденствие", "благополучие", "добруване"],
    "добрый": ["благожелательный", "доброжелательный", "добродушный", "отзывчивый", "сердечный", "добросердечный", "душевный", "сочувствующий", "хороший", "приятный", "благоприятный", "незапятнанный", "чистый", "честный", "целый"],
    "добрый малый": ["добряк"],
    "добрый молодец": ["удалец", "храбрец", "герой"],
    "добуддийский": ["добуддистский"],
    "добуддистский": ["добуддийский"],
    "добулбасчы": ["добулбас"],
    "добухав": ["добухавши"],
    "добухавши": ["добухав"],
    "добухаться": ["допиться"],
    "добър": ["благ", "мек", "хрисим", "смирен", "снизходителен", "състрадателен", "милостив", "отзивчив", "човешки", "добродушен", "бащински", "добряк", "наивник", "доверчив", "доброкачествен"],
    "добыв": ["добывши"],
    "добывав": ["добывавши"],
    "добывавши": ["добывав"],
    "добыванье": ["добывание"],
    "добывать": ["производить", "вырабатывать", "раздобывать", "доставать", "зарабатывать", "промышлять", "выуживать", "завоёвывать"],
    "добывши": ["добыв"],
    "добыча": ["добывание", "доставание", "промысел", "майнинг", "приобретение"],
    "доваживав": ["доваживавши"],
    "доваживавши": ["доваживав"],
    "довалив": ["доваливши"],
    "доваливав": ["доваливавши"],
    "доваливавши": ["доваливав"],
    "доваливши": ["довалив"],
    "доваляв": ["довалявши"],
    "довалявши": ["доваляв"],
    "доварив": ["доваривши"],
    "доваривав": ["доваривавши"],
    "доваривавши": ["доваривав"],
    "доваривши": ["доварив"],
    "довбешка": ["довбеха", "довбня"],
    "довевав": ["довевавши"],
    "довевавши": ["довевав"],
    "доведав": ["доведавши"],
    "доведавши": ["доведав"],
    "доведать": ["доведаться"],
    "доведывав": ["доведывавши"],
    "доведывавши": ["доведывав"],
    "доведь": ["дамка"],
    "довезти": ["привезти"],
    "довезя": ["довёзши"],
    "довеивав": ["довеивавши"],
    "довеивавши": ["довеивав"],
    "доверение": ["вверение"],
    "доверенность": ["гарантия", "расписка", "варрант", "ручательство", "доверка", "доверие"],
    "доверив": ["доверивши"],
    "доверивши": ["доверив"],
    "доверие": ["доверье", "вера"],
    "доверительно": ["конфиденциально"],
    "доверить": ["поручить", "передать", "сообщить", "рассказать"],
    "довернув": ["довернувши"],
    "довернувши": ["довернув"],
    "довертев": ["довертевши"],
    "довертевши": ["довертев"],
    "доверчивав": ["доверчивавши"],
    "доверчивавши": ["доверчивав"],
    "доверчивость": ["открытость"],
    "довершав": ["довершавши"],
    "довершавши": ["довершав"],
    "довершенье": ["довершение"],
    "довершив": ["довершивши"],
    "довершивши": ["довершив"],
    "довершити": ["повершити"],
    "доверье": ["доверие"],
    "доверяв": ["доверявши"],
    "доверявши": ["доверяв"],
    "довесив": ["довесивши"],
    "довесивши": ["довесив"],
    "довестись": ["посчастливиться", "повезти"],
    "довешав": ["довешавши"],
    "довешавши": ["довешав"],
    "довешивав": ["довешивавши"],
    "довешивавши": ["довешивав"],
    "довеяв": ["довеявши"],
    "довеявши": ["довеяв"],
    "довзыскав": ["довзыскавши"],
    "довзыскавши": ["довзыскав"],
    "довзыскивав": ["довзыскивавши"],
    "довзыскивавши": ["довзыскивав"],
    "довив": ["довивши"],
    "довивав": ["довивавши"],
    "довивавши": ["довивав"],
    "довивши": ["довив"],
    "довинтив": ["довинтивши"],
    "довинтивши": ["довинтив"],
    "довинчивав": ["довинчивавши"],
    "довинчивавши": ["довинчивав"],
    "довлев": ["довлевши"],
    "довлевши": ["довлев"],
    "довлеет дневи злоба его": ["жить сегодняшним днём"],
    "довлеть": ["хватать", "удовлетворять", "господствовать", "тяготеть", "могуществовать"],
    "довод": ["аргумент", "доказательство"],
    "доводив": ["доводивши"],
    "доводивши": ["доводив"],
    "доводить": ["провожать", "доставлять", "прокладывать", "протягивать"],
    "доводить до белого каления": ["выводить из себя", "выводить из терпения"],
    "довоевав": ["довоевавши"],
    "довоевавши": ["довоевав"],
    "довоенный": ["предвоенный"],
    "довоз": ["доставка", "допоставка"],
    "довозив": ["довозивши"],
    "довозивши": ["довозив"],
    "доволакивав": ["доволакивавши"],
    "доволакивавши": ["доволакивав"],
    "доволочив": ["доволочивши"],
    "доволочивши": ["доволочив"],
    "доволочь": ["доволочить"],
    "довольно": ["удовлетворённо", "радостно"],
    "довольно весёлая республика": ["дальневосточная республика"],
    "довольно-таки": ["довольно"],
    "довольный": ["удовлетворённый", "достаточный"],
    "довольствовав": ["довольствовавши"],
    "довольствовавши": ["довольствовав"],
    "довольствоваться": ["обходиться", "удовлетворяться", "снабжаться", "быть на довольствии"],
    "довоображав": ["довоображавши"],
    "довоображавши": ["довоображав"],
    "довообразив": ["довообразивши"],
    "довообразивши": ["довообразив"],
    "довооружав": ["довооружавши"],
    "довооружавши": ["довооружав"],
    "довооружив": ["довооруживши"],
    "довооруживши": ["довооружив"],
    "доворачивав": ["доворачивавши"],
    "доворачивавши": ["доворачивав"],
    "довоёвывав": ["довоёвывавши"],
    "довоёвывавши": ["довоёвывав"],
    "довыдав": ["довыдавши"],
    "довыдать": ["выдать", "додать"],
    "довыкапывав": ["довыкапывавши"],
    "довыкапывавши": ["довыкапывав"],
    "довыкопав": ["довыкопавши"],
    "довыкопавши": ["довыкопав"],
    "довылепливав": ["довылепливавши"],
    "довылепливавши": ["довылепливав"],
    "довыполнив": ["довыполнивши"],
    "довыполнивши": ["довыполнив"],
    "довыполняв": ["довыполнявши"],
    "довыполнявши": ["довыполняв"],
    "довыпуск": ["допвыпуск"],
    "довысверливав": ["довысверливавши"],
    "довысверливавши": ["довысверливав"],
    "довыёживаться": ["довыделываться", "довыёбываться"],
    "довязав": ["довязавши"],
    "довязавши": ["довязав"],
    "довязывав": ["довязывавши"],
    "довязывавши": ["довязывав"],
    "довёзши": ["довезя"],
    "довёртывав": ["довёртывавши"],
    "довёртывавши": ["довёртывав"],
    "догадав": ["догадавши"],
    "догадавши": ["догадав"],
    "догадаться": ["разгадать", "угадать"],
    "догадка": ["предположение", "догадливость"],
    "догадливость": ["сообразительность", "проницательность"],
    "догадываться": ["додуматься"],
    "догладив": ["догладивши"],
    "догладивши": ["догладив"],
    "догладывав": ["догладывавши"],
    "догладывавши": ["догладывав"],
    "доглаживав": ["доглаживавши"],
    "доглаживавши": ["доглаживав"],
    "доглодав": ["доглодавши"],
    "доглодавши": ["доглодав"],
    "доглушив": ["доглушивши"],
    "доглушивши": ["доглушив"],
    "догляд": ["наблюдение", "присмотр"],
    "доглядав": ["доглядавши"],
    "доглядавши": ["доглядав"],
    "доглядальниця": ["няня"],
    "доглядачка": ["доглядниця", "дозориця"],
    "доглядев": ["доглядевши"],
    "доглядевши": ["доглядев"],
    "доглядниця": ["доглядачка", "дозориця"],
    "доглядывав": ["доглядывавши"],
    "доглядывавши": ["доглядывав"],
    "догма": ["догмат", "постулат", "доктрина", "правило", "закон", "принцип"],
    "догмат": ["догма", "аксиома"],
    "догматизировав": ["догматизировавши"],
    "догматизировавши": ["догматизировав"],
    "догматизм": ["догматичность"],
    "догматически": ["догматично"],
    "догматический": ["догматичный"],
    "догматично": ["догматический"],
    "догматичность": ["догматизм"],
    "догнав": ["догнавши"],
    "догнавши": ["догнав"],
    "догнать": ["нагнать", "настичь", "поравняться"],
    "догнив": ["догнивши"],
    "догнивав": ["догнивавши"],
    "догнивавши": ["догнивав"],
    "догнивши": ["догнив"],
    "договаривав": ["договаривавши"],
    "договаривавши": ["договаривав"],
    "договор": ["соглашение", "пакт", "контракт", "уговор", "договорённость"],
    "договор коммерческой концессии": ["франчайзинг"],
    "договорив": ["договоривши"],
    "договоривши": ["договорив"],
    "договориться": ["прийти к соглашению", "сговориться", "достигнуть соглашения", "условиться"],
    "договорно-конституционный": ["конституционно-договорный"],
    "договорной": ["договорный"],
    "договорняк": ["дог", "левак", "договорной матч", "договорная игра"],
    "договороспособность": ["сговорчивость"],
    "договорённость": ["соглашение"],
    "догоняв": ["догонявши"],
    "догонявши": ["догоняв"],
    "догонялки": ["догоняшки", "салки", "пятнашки"],
    "догонять": ["понимать", "догадываться"],
    "догоняться": ["настигаться"],
    "догоняшки": ["догонялки", "салки", "пятнашки"],
    "догорав": ["догоравши"],
    "догоравши": ["догорав"],
    "догоранье": ["догорание"],
    "догорати": ["догоряти"],
    "догорев": ["догоревши"],
    "догоревши": ["догорев"],
    "догоряти": ["догорати"],
    "дограбив": ["дограбивши"],
    "дограбивши": ["дограбив"],
    "догребав": ["догребавши"],
    "догребавши": ["догребав"],
    "догрев": ["догревши"],
    "догревав": ["догревавши"],
    "догревавши": ["догревав"],
    "догревши": ["догрев"],
    "догружав": ["догружавши"],
    "догружавши": ["догружав"],
    "догруз": ["догрузка"],
    "догрузив": ["догрузивши"],
    "догрузивши": ["догрузив"],
    "догрызав": ["догрызавши"],
    "догрызавши": ["догрызав"],
    "догситтер": ["собаконяня", "собачья няня"],
    "догуливав": ["догуливавши"],
    "догуливавши": ["догуливав"],
    "догуляв": ["догулявши"],
    "догулявши": ["догуляв"],
    "догхантер": ["догкиллер"],
    "додав": ["додавши"],
    "додавав": ["додававши"],
    "додававши": ["додавав"],
    "додавив": ["додавивши"],
    "додавивши": ["додавив"],
    "додавливав": ["додавливавши"],
    "додавливавши": ["додавливав"],
    "додавши": ["додав"],
    "додаивав": ["додаивавши"],
    "додаивавши": ["додаивав"],
    "додар": ["ука"],
    "додаток": ["додача"],
    "додгустар": ["додгар"],
    "додекагон": ["двенадцатиугольник"],
    "додекафония": ["двенадцатитоновая музыка"],
    "додекаэдр": ["двенадцатигранник"],
    "доделав": ["доделавши"],
    "доделавши": ["доделав"],
    "доделив": ["доделивши"],
    "доделивши": ["доделив"],
    "доделывав": ["доделывавши"],
    "доделывавши": ["доделывав"],
    "додержав": ["додержавши"],
    "додержавши": ["додержав"],
    "додержання": ["додержування"],
    "додерживав": ["додерживавши"],
    "додерживавши": ["додерживав"],
    "додзинси": ["самиздат", "фанфик"],
    "додик": ["слабак", "хиляк", "дистрофик", "дрищ", "доходяга", "неважный", "скромный", "обычный", "банальный", "заурядный", "непримечательный", "посредственный", "глупец", "слабоумный", "тупица"],
    "додирав": ["додиравши"],
    "додиравши": ["додирав"],
    "доднесь": ["поныне", "доныне", "доселе", "досель", "поднесь", "посейчас", "до сих пор"],
    "додо": ["дронт", "маврикийский дронт"],
    "додоив": ["додоивши"],
    "додоивши": ["додоив"],
    "додрав": ["додравши"],
    "додравши": ["додрав"],
    "додраить": ["дочистить"],
    "додредноут": ["эскадренный броненосец"],
    "додрючив": ["додрючивши"],
    "додрючивши": ["додрючив"],
    "додумав": ["додумавши"],
    "додумавши": ["додумав"],
    "додумать": ["домыслить"],
    "додумывав": ["додумывавши"],
    "додумывавши": ["додумывав"],
    "додумывать": ["домысливать"],
    "додёрнув": ["додёрнувши"],
    "додёрнувши": ["додёрнув"],
    "доебав": ["доебавши"],
    "доебавши": ["доебав"],
    "доебать": ["доругать", "добранить", "доматерить", "доматюкать", "доматюгать"],
    "доебсти": ["доебать", "доебти"],
    "доебти": ["доебать", "доебсти"],
    "доедав": ["доедавши"],
    "доедавши": ["доедав"],
    "доездив": ["доездивши"],
    "доездивши": ["доездив"],
    "доезжав": ["доезжавши"],
    "доезжавши": ["доезжав"],
    "доезживав": ["доезживавши"],
    "доезживавши": ["доезживав"],
    "доемщик": ["доимщик"],
    "доение": ["доенье", "дойка"],
    "доехавши": ["доехав"],
    "доехать": ["донять", "допечь", "извести", "довести до ручки", "доконать"],
    "дожав": ["дожавши"],
    "дожавши": ["дожав"],
    "дожарив": ["дожаривши"],
    "дожаривав": ["дожаривавши"],
    "дожаривавши": ["дожаривав"],
    "дожаривши": ["дожарив"],
    "дождав": ["дождавши"],
    "дождавши": ["дождав"],
    "дождать": ["дождаться"],
    "дождевой червь": ["земляной червь"],
    "дождемер": ["осадкомер"],
    "дождив": ["дождивши"],
    "дождивши": ["дождив"],
    "дождик": ["дождь"],
    "дождить": ["дозжаться"],
    "дождичек": ["дождик"],
    "дождище": ["ливень", "дождина"],
    "дождь": ["сноп", "мишура"],
    "дожевав": ["дожевавши"],
    "дожевавши": ["дожевав"],
    "дожжив": ["дожживши"],
    "дожживши": ["дожжив"],
    "дожив": ["доживши"],
    "доживав": ["доживавши"],
    "доживавши": ["доживав"],
    "доживши": ["дожив"],
    "дожигав": ["дожигавши"],
    "дожигавши": ["дожигав"],
    "дожидав": ["дожидавши"],
    "дожидавши": ["дожидав"],
    "дожидать": ["ожидать"],
    "дожидаться": ["ждать", "ожидать", "поджидать", "выжидать"],
    "дожимав": ["дожимавши"],
    "дожимавши": ["дожимав"],
    "дожинав": ["дожинавши"],
    "дожинавши": ["дожинав"],
    "дожинки": ["обжинки"],
    "дожирав": ["дожиравши"],
    "дожиравши": ["дожирав"],
    "дожрав": ["дожравши"],
    "дожравши": ["дожрав"],
    "дожёвывав": ["дожёвывавши"],
    "дожёвывавши": ["дожёвывав"],
    "доза": ["дозняк"],
    "дозавтракав": ["дозавтракавши"],
    "дозавтракавши": ["дозавтракав"],
    "дозагружав": ["дозагружавши"],
    "дозагружавши": ["дозагружав"],
    "дозагрузив": ["дозагрузивши"],
    "дозагрузивши": ["дозагрузив"],
    "дозаправив": ["дозаправивши"],
    "дозаправивши": ["дозаправив"],
    "дозаправляв": ["дозаправлявши"],
    "дозаправлявши": ["дозаправляв"],
    "дозарив": ["дозаривши"],
    "дозаривав": ["дозаривавши"],
    "дозаривавши": ["дозаривав"],
    "дозаривание": ["дозревание"],
    "дозариваться": ["доводиться"],
    "дозаривши": ["дозарив"],
    "дозариться": ["дозреть"],
    "дозаряв": ["дозарявши"],
    "дозарявши": ["дозаряв"],
    "дозарядив": ["дозарядивши"],
    "дозарядивши": ["дозарядив"],
    "дозаряжав": ["дозаряжавши"],
    "дозаряжавши": ["дозаряжав"],
    "дозарять": ["помогать", "доставать", "дразнить", "гнобить", "надоедать", "приставать", "дражить", "блазнить", "вередить", "выдразнить", "дозорять", "докорять", "донжить", "доньжить", "кумарить"],
    "дозатор": ["диспенсер"],
    "дозаявив": ["дозаявивши"],
    "дозаявивши": ["дозаявив"],
    "дозаявляв": ["дозаявлявши"],
    "дозаявлявши": ["дозаявляв"],
    "дозволение": ["разрешение", "позволение"],
    "дозволенний": ["дозволений"],
    "дозволенье": ["дозволение"],
    "дозволив": ["дозволивши"],
    "дозволивши": ["дозволив"],
    "дозволительно": ["позволительно", "допустимо"],
    "дозволить": ["разрешить", "позволить"],
    "дозволяв": ["дозволявши"],
    "дозволявши": ["дозволяв"],
    "дозволять": ["разрешать", "позволять"],
    "дозиметрировав": ["дозиметрировавши"],
    "дозиметрировавши": ["дозиметрировав"],
    "дозимовав": ["дозимовавши"],
    "дозимовавши": ["дозимовав"],
    "дозировав": ["дозировавши"],
    "дозировавши": ["дозировав"],
    "дозироваться": ["отмериваться"],
    "дознав": ["дознавши"],
    "дознавав": ["дознававши"],
    "дознававши": ["дознавав"],
    "дознавши": ["дознав"],
    "дознанье": ["дознание"],
    "дознаряд": ["дозиметрический наряд"],
    "дозняк": ["доза"],
    "дозор": ["догляд", "досмотр"],
    "дозорив": ["дозоривши"],
    "дозоривши": ["дозорив"],
    "дозориця": ["доглядачка", "доглядниця"],
    "дозорщик": ["дозорный"],
    "дозоряв": ["дозорявши"],
    "дозорявши": ["дозоряв"],
    "дозорять": ["доставать", "гнобить", "надоедать", "приставать", "дражить", "блазнить", "вередить", "выдразнить", "дозарять", "докорять", "донжить", "доньжить", "кумарить", "надзирать", "наблюдать"],
    "дозрев": ["дозревши"],
    "дозревав": ["дозревавши"],
    "дозревавши": ["дозревав"],
    "дозревши": ["дозрев"],
    "доив": ["доивши"],
    "доивши": ["доив"],
    "доиграв": ["доигравши"],
    "доигравши": ["доиграв"],
    "доиграться": ["добаловаться", "допрыгаться"],
    "доигрывав": ["доигрывавши"],
    "доигрывавши": ["доигрывав"],
    "доизбирав": ["доизбиравши"],
    "доизбиравши": ["доизбирав"],
    "доизбрав": ["доизбравши"],
    "доизбравши": ["доизбрав"],
    "доизвлекав": ["доизвлекавши"],
    "доизвлекавши": ["доизвлекав"],
    "доильница": ["доярка", "доильщица"],
    "доильщик": ["доильник", "дояр"],
    "доильщица": ["доярка"],
    "доимав": ["доимавши"],
    "доимавши": ["доимав"],
    "доимщик": ["доемщик"],
    "доиндексировав": ["доиндексировавши"],
    "доиндексировавши": ["доиндексировав"],
    "доинтернетовский": ["доинтернетный"],
    "доискав": ["доискавши"],
    "доискавши": ["доискав"],
    "доискивав": ["доискивавши"],
    "доискивавши": ["доискивав"],
    "доиспользовав": ["доиспользовавши"],
    "доиспользовавши": ["доиспользовав"],
    "доисторический": ["дописьменный", "первобытный", "устаревший", "глубокий"],
    "доисторическое время": ["доисторический период", "преистория"],
    "доить": ["вымогать", "выманивать", "обирать", "доиться"],
    "дойка": ["доение", "бидон"],
    "дойница": ["подойник"],
    "дойчовец": ["немец", "германец", "шваба"],
    "дока": ["знаток", "умелец", "ас", "профессионал", "мастак", "мастер"],
    "доказав": ["доказавши"],
    "доказавши": ["доказав"],
    "доказанность": ["обоснованность"],
    "доказательство": ["свидетельство", "обоснование", "доказуха"],
    "доказывав": ["доказывавши"],
    "доказывавши": ["доказывав"],
    "докалив": ["докаливши"],
    "докаливав": ["докаливавши"],
    "докаливавши": ["докаливав"],
    "докаливать": ["докалять"],
    "докаливши": ["докалив"],
    "докалывав": ["докалывавши"],
    "докалывавши": ["докалывав"],
    "докаляв": ["докалявши"],
    "докалявши": ["докаляв"],
    "доканчивав": ["доканчивавши"],
    "доканчивавши": ["доканчивав"],
    "доканчивать": ["кончать"],
    "доканывав": ["доканывавши"],
    "доканывавши": ["доканывав"],
    "докапав": ["докапавши"],
    "докапавши": ["докапав"],
    "докапитализировав": ["докапитализировавши"],
    "докапитализировавши": ["докапитализировав"],
    "докапливав": ["докапливавши"],
    "докапливавши": ["докапливав"],
    "докапчивав": ["докапчивавши"],
    "докапчивавши": ["докапчивав"],
    "докапывав": ["докапывавши"],
    "докапывавши": ["докапывав"],
    "докапываться": ["дознаваться", "доискиваться", "придираться"],
    "докармливав": ["докармливавши"],
    "докармливавши": ["докармливав"],
    "докарябав": ["докарябавши"],
    "докарябавши": ["докарябав"],
    "докарябывав": ["докарябывавши"],
    "докарябывавши": ["докарябывав"],
    "докарябывать": ["доцарапывать"],
    "докатав": ["докатавши"],
    "докатавши": ["докатав"],
    "докатив": ["докативши"],
    "докативши": ["докатив"],
    "докатывав": ["докатывавши"],
    "докатывавши": ["докатывав"],
    "докачав": ["докачавши"],
    "докачавши": ["докачав"],
    "докачивав": ["докачивавши"],
    "докачивавши": ["докачивав"],
    "докашивав": ["докашивавши"],
    "докашивавши": ["докашивав"],
    "доквасив": ["доквасивши"],
    "доквасивши": ["доквасив"],
    "доквашивав": ["доквашивавши"],
    "доквашивавши": ["доквашивав"],
    "докембрий": ["докембрийский период", "криптозой"],
    "докидав": ["докидавши"],
    "докидавши": ["докидав"],
    "докидывав": ["докидывавши"],
    "докидывавши": ["докидывав"],
    "докинув": ["докинувши"],
    "докинувши": ["докинув"],
    "докипав": ["докипавши"],
    "докипавши": ["докипав"],
    "докипев": ["докипевши"],
    "докипевши": ["докипев"],
    "докисав": ["докисавши"],
    "докисавши": ["докисав"],
    "докиснув": ["докиснувши"],
    "докиснувши": ["докиснув"],
    "доклад": ["сообщение", "выступление", "лекция", "отчёт", "статья", "публикация", "изложение", "оповещение", "предупреждение"],
    "докладав": ["докладавши"],
    "докладавши": ["докладав"],
    "докладывав": ["докладывавши"],
    "докладывавши": ["докладывав"],
    "докладывать": ["сообщать", "информировать", "извещать", "уведомлять", "осведомлять", "доносить", "заявлять", "объявлять", "оповещать", "предупреждать"],
    "доклевав": ["доклевавши"],
    "доклевавши": ["доклевав"],
    "доклеив": ["доклеивши"],
    "доклеивав": ["доклеивавши"],
    "доклеивавши": ["доклеивав"],
    "доклеивши": ["доклеив"],
    "доклинический": ["предклинический"],
    "доклёвывав": ["доклёвывавши"],
    "доклёвывавши": ["доклёвывав"],
    "доковав": ["доковавши"],
    "доковавши": ["доковав"],
    "доковидный": ["докоронавирусный", "докоронный", "предковидный", "предкоронавирусный"],
    "доковывав": ["доковывавши"],
    "доковывавши": ["доковывав"],
    "доковыляв": ["доковылявши"],
    "доковылявши": ["доковыляв"],
    "доковылять": ["дотащиться"],
    "докозагексаеновая кислота": ["дгк"],
    "доколачивав": ["доколачивавши"],
    "доколачивавши": ["доколачивав"],
    "доколе": ["сколько", "насколько", "доколь", "докель", "докуль", "пока", "покуда", "покудова", "покамест"],
    "доколов": ["доколовши"],
    "доколовши": ["доколов"],
    "доколотив": ["доколотивши"],
    "доколотивши": ["доколотив"],
    "доколь": ["сколько", "насколько", "доколе", "докель", "докуль", "пока", "покуда", "покудова", "покамест"],
    "доконав": ["доконавши"],
    "доконавши": ["доконав"],
    "доконать": ["добить", "прикончить", "погубить", "допечь", "донять", "измучить"],
    "доконопатив": ["доконопативши"],
    "доконопативши": ["доконопатив"],
    "доконопачивав": ["доконопачивавши"],
    "доконопачивавши": ["доконопачивав"],
    "докончив": ["докончивши"],
    "докончивши": ["докончив"],
    "докончить": ["кончить", "окончить", "закончить", "завершить", "довершить", "прекратить"],
    "докопав": ["докопавши"],
    "докопавши": ["докопав"],
    "докопаться": ["докопать", "доискаться"],
    "докоптив": ["докоптивши"],
    "докоптивши": ["докоптив"],
    "докормив": ["докормивши"],
    "докормивши": ["докормив"],
    "докоронавирусный": ["доковидный", "докоронный", "предковидный", "предкоронавирусный"],
    "докоронный": ["доковидный", "докоронавирусный", "предковидный", "предкоронавирусный"],
    "докорябав": ["докорябавши"],
    "докорябавши": ["докорябав"],
    "докорябывав": ["докорябывавши"],
    "докорябывавши": ["докорябывав"],
    "докорябывать": ["доцарапывать"],
    "докосив": ["докосивши"],
    "докосивши": ["докосив"],
    "докраивав": ["докраивавши"],
    "докраивавши": ["докраивав"],
    "докрасив": ["докрасивши"],
    "докрасивши": ["докрасив"],
    "докрашивав": ["докрашивавши"],
    "докрашивавши": ["докрашивав"],
    "докритический": ["субкритический"],
    "докроив": ["докроивши"],
    "докроивши": ["докроив"],
    "докрошив": ["докрошивши"],
    "докрошивши": ["докрошив"],
    "докрутив": ["докрутивши"],
    "докрутивши": ["докрутив"],
    "докручивав": ["докручивавши"],
    "докручивавши": ["докручивав"],
    "докрыв": ["докрывши"],
    "докрывав": ["докрывавши"],
    "докрывавши": ["докрывав"],
    "докрывши": ["докрыв"],
    "доксологический": ["славословный"],
    "доксология": ["славословие"],
    "доктор": ["врач", "лекарь", "эскулап", "медик", "доктор наук"],
    "доктор наук": ["доктор"],
    "докторица": ["докторша"],
    "докторский": ["врачебный"],
    "докторша": ["врачиха", "докторица"],
    "доктрина": ["теория", "учение"],
    "доктринёр": ["догматик"],
    "доктринёрски": ["догматически", "догматично"],
    "доктринёрство": ["догматизм", "догматичность"],
    "доктринёрствовав": ["доктринёрствовавши"],
    "доктринёрствовавши": ["доктринёрствовав"],
    "докуда": ["докудова", "докель"],
    "докудова": ["докуда"],
    "докудрама": ["документальная драма"],
    "докумекав": ["докумекавши"],
    "докумекавши": ["докумекав"],
    "документально": ["документированно"],
    "документация": ["документирование"],
    "документировав": ["документировавши"],
    "документировавши": ["документировав"],
    "документированно": ["документально"],
    "докупав": ["докупавши"],
    "докупавши": ["докупав"],
    "докупив": ["докупивши"],
    "докупивши": ["докупив"],
    "докупить": ["прикупить"],
    "докупка": ["докупание"],
    "докурив": ["докуривши"],
    "докуривав": ["докуривавши"],
    "докуривавши": ["докуривав"],
    "докуривши": ["докурив"],
    "докучав": ["докучавши"],
    "докучавши": ["докучав"],
    "докучаевск": ["еленовские карьеры"],
    "докучать": ["досаждать", "донимать"],
    "докучив": ["докучивши"],
    "докучивши": ["докучив"],
    "докучить": ["досадить", "донять"],
    "докучливо": ["надоедливо", "назойливо", "скучно"],
    "докучный": ["надоедливый", "назойливый", "докучливый", "навязчивый", "неотступный"],
    "докушав": ["докушавши"],
    "докушавши": ["докушав"],
    "докушать": ["доесть"],
    "докушивав": ["докушивавши"],
    "докушивавши": ["докушивав"],
    "дол": ["долина"],
    "долавливав": ["долавливавши"],
    "долавливавши": ["долавливав"],
    "доламывав": ["доламывавши"],
    "доламывавши": ["доламывав"],
    "долбав": ["долбавши"],
    "долбавши": ["долбав"],
    "долбанув": ["долбанувши"],
    "долбанувши": ["долбанув"],
    "долбанутый": ["ударенный", "пришибленный"],
    "долбаный": ["долбанутый", "ударенный", "чёртов", "хренов"],
    "долбив": ["долбивши"],
    "долбивши": ["долбив"],
    "долбить": ["курить"],
    "долбиться в дёсны": ["биться в дёсны", "хлестаться в десну", "шарахаться в десну"],
    "долбоебизм": ["тупость", "дурость", "придурковатость", "долбоёбство", "абсурдность", "бессмысленность", "бесполезность"],
    "долбозвон": ["болтун", "пустозвон", "пустослов", "пустомеля", "долдон"],
    "долбоёбина": ["долбоёбище"],
    "долбоёбство": ["долбоебизм"],
    "долбоёбствовав": ["долбоёбствовавши"],
    "долбоёбствовавши": ["долбоёбствовав"],
    "долбяжка": ["долбёжка", "зубрёжка"],
    "долбёжка": ["долбление", "заучивание", "зубрёжка"],
    "долг": ["задолженность", "обязательство", "обязанность"],
    "долган": ["долганин"],
    "долганин": ["долган"],
    "долгий": ["длительный", "продолжительный", "затяжной", "протяжённый", "долгосрочный", "длинный"],
    "долговая яма": ["долговая тюрьма"],
    "долговечно": ["долговременно"],
    "долговременно": ["долговечно"],
    "долговязый": ["долгошеий"],
    "долгогривый": ["длинногривый"],
    "долгоденствие": ["долголетие"],
    "долгоденствовав": ["долгоденствовавши"],
    "долгоденствовавши": ["долгоденствовав"],
    "долгожитель": ["долголет"],
    "долгожительство": ["долголетие"],
    "долголет": ["долгожитель"],
    "долголетие": ["долгожительство"],
    "долголетье": ["долголетие"],
    "долгоногий": ["длинноногий", "ногастый"],
    "долгоносик": ["жук-долгоносик"],
    "долгополый": ["длиннополый"],
    "долгопрудный": ["долгопа"],
    "долгопузик": ["воронежец", "воронежанин"],
    "долгосрочный": ["долговременный"],
    "долгострой": ["долгостройка"],
    "долгота": ["продолжительность", "длительность", "длиннота", "длина", "протяженность"],
    "долготерпение": ["долготерпенье"],
    "долготерпенье": ["долготерпение"],
    "долгохвостый": ["длиннохвостый"],
    "долгошеий": ["длинношеий"],
    "долгошёрстный": ["долгошёрстый", "длинношёрстный", "длинношёрстый"],
    "долгошёрстый": ["длинношёрстный", "длинношёрстый", "долгошёрстный"],
    "долдонив": ["долдонивши"],
    "долдонивши": ["долдонив"],
    "долдонить": ["талдычить", "твердить"],
    "доле": ["дольше", "долее"],
    "долевик": ["пайщик"],
    "долее": ["длиннее"],
    "долежав": ["долежавши"],
    "долежавши": ["долежав"],
    "долезав": ["долезавши"],
    "долезавши": ["долезав"],
    "долепив": ["долепивши"],
    "долепивши": ["долепив"],
    "долепливав": ["долепливавши"],
    "долепливавши": ["долепливав"],
    "долепливать": ["долеплять"],
    "долепляв": ["долеплявши"],
    "долеплявши": ["долепляв"],
    "долеплять": ["долепливать"],
    "долетав": ["долетавши"],
    "долетавши": ["долетав"],
    "долетев": ["долетевши"],
    "долетевши": ["долетев"],
    "долечив": ["долечивши"],
    "долечивав": ["долечивавши"],
    "долечивавши": ["долечивав"],
    "долечивши": ["долечив"],
    "должав": ["должавши"],
    "должавши": ["должав"],
    "должанск": ["свердловск"],
    "должать": ["одалживать"],
    "должен": ["обязан", "вынужден", "должон"],
    "долженствовав": ["долженствовавши"],
    "долженствовавши": ["долженствовав"],
    "долженствование": ["мотивированность"],
    "долженствовательное наклонение": ["дебитив", "наклонение необходимости"],
    "долженствовать": ["быть должным", "должен"],
    "долженствующий": ["подобающий"],
    "должник": ["дебитор", "заёмщик"],
    "должно": ["надо", "надлежит", "необходимо", "подобает", "полагается", "следует", "требуется"],
    "должно быть": ["вероятно", "скорее всего", "скорей всего"],
    "должностной": ["служебный", "служащий"],
    "должность": ["пост", "место", "позиция", "положение", "чин", "учреждение", "организация", "место работы", "долг", "обязанность", "необходимость", "нужда"],
    "должный": ["надлежащий", "подобающий"],
    "долив": ["доливание", "доливка"],
    "доливав": ["доливавши"],
    "доливавши": ["доливав"],
    "доливка": ["долив", "доливание"],
    "доливши": ["долив"],
    "долизав": ["долизавши"],
    "долизавши": ["долизав"],
    "долизывав": ["долизывавши"],
    "долизывавши": ["долизывав"],
    "долина": ["дол"],
    "долихокефал": ["долихоцефал"],
    "долихокефалия": ["длинноголовость", "долихоцефалия"],
    "долихоцефал": ["долихокефал"],
    "долихоцефалия": ["длинноголовость", "долихокефалия"],
    "доллар": ["бакс", "условная единица", "убитый енот"],
    "долларизировав": ["долларизировавши"],
    "долларизировавши": ["долларизировав"],
    "долларизовав": ["долларизовавши"],
    "долларизовавши": ["долларизовав"],
    "долма": ["далма", "дулма", "дурма", "толма", "сарма", "голубцы"],
    "доловив": ["доловивши"],
    "доловивши": ["доловив"],
    "доложив": ["доложивши"],
    "доложивши": ["доложив"],
    "доложить": ["отрапортовать", "сообщить", "сделать доклад"],
    "долой": ["прочь", "вон"],
    "доломав": ["доломавши"],
    "доломавши": ["доломав"],
    "доломан": ["венгерка", "долиман"],
    "доломив": ["доломивши"],
    "доломивши": ["доломив"],
    "доломитный": ["доломитовый"],
    "доломитовый": ["доломитный"],
    "долонь": ["длань", "ток", "гумно"],
    "долото": ["буровое долото"],
    "долу": ["вниз", "книзу"],
    "долька": ["зубок", "зубчик", "зубочек"],
    "дольмен": ["кромлех", "менгир"],
    "дольний": ["долинный", "земной", "нижний", "греховный"],
    "дольник": ["паузник"],
    "дольщик": ["пайщик"],
    "долюбить": ["прочувствовать"],
    "долюбливать": ["недолюбливать"],
    "доля": ["часть", "пай", "порция", "судьба", "участь", "удел", "жребий", "слог"],
    "долёживав": ["долёживавши"],
    "долёживавши": ["долёживав"],
    "долётывав": ["долётывавши"],
    "долётывавши": ["долётывав"],
    "дом": ["здание", "корпус", "жилище", "жильё", "жилплощадь", "резиденция", "фирма", "предприятие", "семья", "династия", "клан"],
    "дом культуры": ["дк"],
    "дом престарелых": ["дом для престарелых", "стардом"],
    "дом терпимости": ["публичный дом", "бордель", "бардак"],
    "дом-новостройка": ["новостройка"],
    "дома и солома едома": ["дома и стены помогают", "дома и солома съедома"],
    "домазав": ["домазавши"],
    "домазавши": ["домазав"],
    "домазывав": ["домазывавши"],
    "домазывавши": ["домазывав"],
    "домалывав": ["домалывавши"],
    "домалывавши": ["домалывав"],
    "домарксистский": ["домарксовский"],
    "доматывав": ["доматывавши"],
    "доматывавши": ["доматывав"],
    "домаха": ["домашка"],
    "домахав": ["домахавши"],
    "домахавши": ["домахав"],
    "домахивав": ["домахивавши"],
    "домахивавши": ["домахивав"],
    "домахнув": ["домахнувши"],
    "домахнувши": ["домахнув"],
    "домахнуть": ["добросить", "докинуть"],
    "домачивав": ["домачивавши"],
    "домачивавши": ["домачивав"],
    "домашар": ["домошар", "домакин"],
    "домашка": ["домашнее задание", "домашнее чтение", "домашний арест"],
    "домашнее животное": ["одомашненное животное"],
    "домашнее задание": ["домашняя работа"],
    "домашнее насилие": ["бытовое насилие"],
    "домашний": ["обжитой", "семейный", "частный", "бытовой", "кустарный", "самодельный", "домочадец", "близкий", "прирученный", "ручной", "простой", "непритязательный", "домосед"],
    "домашняя кошка": ["кошка", "киса"],
    "домашняя работа": ["домашнее задание"],
    "домашняя страница": ["персональный сайт", "хомяк"],
    "домащивав": ["домащивавши"],
    "домащивавши": ["домащивав"],
    "домбабве": ["донбабве"],
    "домежевав": ["домежевавши"],
    "домежевавши": ["домежевав"],
    "домежёвывав": ["домежёвывавши"],
    "домежёвывавши": ["домежёвывав"],
    "домейнинг": ["киберспекуляция"],
    "домекав": ["домекавши"],
    "домекавши": ["домекав"],
    "домекать": ["догадываться", "смекать"],
    "домекаться": ["догадываться", "понимать", "смекать", "замечать"],
    "домекнув": ["домекнувши"],
    "домекнувши": ["домекнув"],
    "домекнуть": ["догадаться"],
    "домекнуться": ["догадаться"],
    "домелив": ["домеливши"],
    "домеливши": ["домелив"],
    "домен": ["магнитный домен", "надцарство"],
    "доменивав": ["доменивавши"],
    "доменивавши": ["доменивав"],
    "доменная печь": ["домна"],
    "доменяв": ["доменявши"],
    "доменявши": ["доменяв"],
    "домерив": ["домеривши"],
    "домеривав": ["домеривавши"],
    "домеривавши": ["домеривав"],
    "домеривши": ["домерив"],
    "домеряв": ["домерявши"],
    "домерявши": ["домеряв"],
    "домесив": ["домесивши"],
    "домесивши": ["домесив"],
    "доместикация": ["одомашнивание"],
    "дометав": ["дометавши"],
    "дометавши": ["дометав"],
    "дометив": ["дометивши"],
    "дометивши": ["дометив"],
    "дометнув": ["дометнувши"],
    "дометнувши": ["дометнув"],
    "домечав": ["домечавши"],
    "домечавши": ["домечав"],
    "домечтав": ["домечтавши"],
    "домечтавши": ["домечтав"],
    "домешав": ["домешавши"],
    "домешавши": ["домешав"],
    "домешивав": ["домешивавши"],
    "домешивавши": ["домешивав"],
    "домик": ["домишко"],
    "домина": ["госпожа", "доминатрикс"],
    "доминав": ["доминавши"],
    "доминавши": ["доминав"],
    "доминантсептаккорд": ["доминантовый септаккорд"],
    "доминатрикс": ["госпожа", "домина"],
    "доминация": ["доминирование"],
    "доминиканская республика": ["доминикана"],
    "доминион": ["королевство содружества"],
    "доминировав": ["доминировавши"],
    "доминировавши": ["доминировав"],
    "доминирование": ["доминация", "превосходство", "преобладание", "превалирование", "господство"],
    "доминирующий": ["главный", "господствующий", "превалирующий", "преимущественный", "преобладающий", "царящий"],
    "домино": ["козёл", "доминошки"],
    "домирав": ["домиравши"],
    "домиравши": ["домирав"],
    "домицилий": ["домициль"],
    "домицилировав": ["домицилировавши"],
    "домицилировавши": ["домицилировав"],
    "домициль": ["домицилий"],
    "домишко": ["домик"],
    "домище": ["домина"],
    "домком": ["жилком"],
    "домна": ["доменная печь"],
    "домножав": ["домножавши"],
    "домножавши": ["домножав"],
    "домножив": ["домноживши"],
    "домноживши": ["домножив"],
    "домовий": ["житловий"],
    "домовик": ["домовой"],
    "домовин": ["домочадец", "член семьи", "домашние", "прислуга", "дворня"],
    "домовина": ["гроб"],
    "домовитый": ["хозяйственный"],
    "домовладелец": ["квартировладелец"],
    "домовласниця": ["домодержавиця"],
    "домовничав": ["домовничавши"],
    "домовничавши": ["домовничав"],
    "домовой": ["домашний"],
    "домовый": ["домашний"],
    "домовёнок": ["домовой", "домовик"],
    "домоганье": ["домогание"],
    "домогательство": ["домогание", "приставание"],
    "домогательствовав": ["домогательствовавши"],
    "домогательствовавши": ["домогательствовав"],
    "домогаться": ["добиваться"],
    "домод": ["язна", "амак"],
    "домодельный": ["самодельный", "кустарный"],
    "домодержавиця": ["домовласниця"],
    "домокав": ["домокавши"],
    "домокавши": ["домокав"],
    "домокнув": ["домокнувши"],
    "домокнувши": ["домокнув"],
    "домолачивав": ["домолачивавши"],
    "домолачивавши": ["домолачивав"],
    "домолвив": ["домолвивши"],
    "домолвивши": ["домолвив"],
    "домолвить": ["договорить", "досказать", "произнести"],
    "домолов": ["домоловши"],
    "домоловши": ["домолов"],
    "домолотив": ["домолотивши"],
    "домолотивши": ["домолотив"],
    "домолчав": ["домолчавши"],
    "домолчавши": ["домолчав"],
    "домоправительница": ["домработница", "экономка"],
    "доморощенный": ["своерощенный", "домашний", "непрофессиональный", "самодельный", "своедельный", "своедельский", "примитивный"],
    "домосед": ["лежебока"],
    "домоседливый": ["домоседный"],
    "домоседничав": ["домоседничавши"],
    "домоседничавши": ["домоседничав"],
    "домоседничать": ["домоседствовать"],
    "домоседствовав": ["домоседствовавши"],
    "домоседствовавши": ["домоседствовав"],
    "домоседствовать": ["домоседничать"],
    "домостив": ["домостивши"],
    "домостивши": ["домостив"],
    "домостроение": ["домостроительство"],
    "домотав": ["домотавши"],
    "домотавши": ["домотав"],
    "домотканый": ["доморощенный", "кустарный"],
    "домоуправ": ["домоуправитель", "управдом"],
    "домохозяин": ["домовладелец"],
    "домочадец": ["домовин"],
    "домочив": ["домочивши"],
    "домочивши": ["домочив"],
    "домработница": ["домашняя работница", "домоправительница", "экономка"],
    "домуз": ["домыз"],
    "домучав": ["домучавши"],
    "домучавши": ["домучав"],
    "домучив": ["домучивши"],
    "домучивав": ["домучивавши"],
    "домучивавши": ["домучивав"],
    "домучивши": ["домучив"],
    "домушничав": ["домушничавши"],
    "домушничавши": ["домушничав"],
    "домчав": ["домчавши"],
    "домчавши": ["домчав"],
    "домыв": ["домывши"],
    "домывав": ["домывавши"],
    "домывавши": ["домывав"],
    "домывши": ["домыв"],
    "домыкав": ["домыкавши"],
    "домыкавши": ["домыкав"],
    "домыкать": ["домыкивать"],
    "домыкивав": ["домыкивавши"],
    "домыкивавши": ["домыкивав"],
    "домысел": ["догадка", "предположение"],
    "домыслив": ["домысливши"],
    "домысливав": ["домысливавши"],
    "домысливавши": ["домысливав"],
    "домысливши": ["домыслив"],
    "домыть": ["додраить", "дополоскать"],
    "домышляв": ["домышлявши"],
    "домышлявши": ["домышляв"],
    "домяв": ["домявши"],
    "домявши": ["домяв"],
    "домять": ["смять"],
    "домётывав": ["домётывавши"],
    "домётывавши": ["домётывав"],
    "дон": ["танаис", "гиргис", "тан", "танаквисль", "ванаквисль"],
    "дона": ["донак"],
    "донабор": ["добор", "допнабор"],
    "донага": ["догола"],
    "дональд": ["доналд", "дон"],
    "донастройка": ["реформа"],
    "донат": ["пожертвование", "благотворительность", "милостыня"],
    "донатив": ["донативши"],
    "донативши": ["донатив"],
    "донатка": ["донатная доилка", "донатная помойка"],
    "донатная доилка": ["донатка", "донатная помойка"],
    "донатная помойка": ["донатка", "донатная доилка"],
    "донатный": ["подарочный", "наградной"],
    "донатор": ["жертвователь", "спонсор"],
    "доначислив": ["доначисливши"],
    "доначисливши": ["доначислив"],
    "доначисляв": ["доначислявши"],
    "доначислявши": ["доначисляв"],
    "донашивав": ["донашивавши"],
    "донашивавши": ["донашивав"],
    "донбабве": ["домбабве"],
    "донбасский": ["донбассовский"],
    "донбассовский": ["донбасский"],
    "донгуз": ["чочкъа"],
    "донде": ["дондеже", "доколе", "пока"],
    "дондеже": ["донде", "доколе", "пока"],
    "дондиньо": ["дондинью"],
    "дондинью": ["дондиньо"],
    "дондо": ["дондик"],
    "донекуда": ["донельзя", "до чёртиков", "дофига", "чрезмерно", "чрезвычайно", "крайне", "дохера"],
    "донельзя": ["чрезмерно", "чрезвычайно", "крайне"],
    "донер": ["шаурма"],
    "донесение": ["доклад"],
    "донесенье": ["донесение"],
    "донести": ["принести", "допереть", "довезти", "доставить", "домчать", "преподнести", "растолковать", "пояснить", "проинформировать", "наябедничать", "настучать"],
    "донецк": ["юзовка", "сталино"],
    "донецкая народная республика": ["днр", "донетчина", "донбабве"],
    "донецкая область": ["донетчина"],
    "донецко-луганский": ["луганско-донецкий"],
    "донецко-российский": ["российско-донецкий"],
    "донеччина": ["донецька область"],
    "донжон": ["цитадель"],
    "донжуан": ["бабник", "волокита", "казанова", "ловелас", "повеса", "сердцеед"],
    "донжуанствовав": ["донжуанствовавши"],
    "донжуанствовавши": ["донжуанствовав"],
    "донизав": ["донизавши"],
    "донизавши": ["донизав"],
    "донизывав": ["донизывавши"],
    "донизывавши": ["донизывав"],
    "дониконианский": ["дониконовский"],
    "дониконовский": ["дониконианский"],
    "донимав": ["донимавши"],
    "донимавши": ["донимав"],
    "донимать": ["досаждать", "докучать", "надоедать"],
    "донировав": ["донировавши"],
    "донировавши": ["донировав"],
    "дониш": ["ирфон"],
    "донишвар": ["донишманд"],
    "донишманд": ["олим", "донишвар"],
    "донка": ["закидушка"],
    "донкихот": ["мечтатель", "рыцарь", "странствующий"],
    "донкихотовский": ["донкихотский", "донкишотский"],
    "донкихотский": ["мечтательный", "прожектёрский"],
    "донкихотство": ["донкишотство", "мечтательство", "маниловщина", "прожектёрство"],
    "донкихотствовав": ["донкихотствовавши"],
    "донкихотствовавши": ["донкихотствовав"],
    "донкихотствовать": ["сражаться", "ветряными", "мельницами"],
    "донкишот": ["мечтатель", "рыцарь", "странствующий"],
    "донкишотство": ["донкихотство", "мечтательство", "маниловщина", "прожектёрство"],
    "донна": ["госпожа", "дама", "донья", "леди", "синьора", "сударыня", "мадонна"],
    "донник": ["мольная трава"],
    "донормандский": ["донорманнский"],
    "донорманнский": ["донормандский"],
    "донорно-акцепторный": ["координационный"],
    "донорствовав": ["донорствовавши"],
    "донорствовавши": ["донорствовав"],
    "доносив": ["доносивши"],
    "доносивши": ["доносив"],
    "доносительствовав": ["доносительствовавши"],
    "доносительствовавши": ["доносительствовав"],
    "доносить": ["доставлять", "сообщать", "информировать", "извещать", "уведомлять", "осведомлять", "докладывать", "заявлять", "объявлять", "оповещать", "жаловаться", "ябедничать", "фискалить", "капать", "кляузничать"],
    "доноситься": ["слышаться"],
    "доносчик": ["изветчик", "информатор", "осведомитель", "стукач", "предатель", "секретный сотрудник", "сексот", "соглядатай", "провокатор", "шпион", "ябеда"],
    "доношение": ["донесение"],
    "донце": ["донышко"],
    "дончак": ["донец"],
    "донщина": ["ростовская область", "ростовщина"],
    "донъыз": ["шошка"],
    "доныне": ["поныне", "доднесь", "доселе", "досель", "поднесь", "посейчас"],
    "доныривав": ["доныривавши"],
    "доныривавши": ["доныривав"],
    "донырнув": ["донырнувши"],
    "донырнувши": ["донырнув"],
    "доныряв": ["донырявши"],
    "донырявши": ["доныряв"],
    "донька": ["доня"],
    "донюхав": ["донюхавши"],
    "донюхавши": ["донюхав"],
    "донюхивав": ["донюхивавши"],
    "донюхивавши": ["донюхивав"],
    "доня": ["донька", "дочка"],
    "доняв": ["донявши"],
    "донявши": ["доняв"],
    "донянчив": ["донянчивши"],
    "донянчивав": ["донянчивавши"],
    "донянчивавши": ["донянчивав"],
    "донянчивши": ["донянчив"],
    "донять": ["досадить", "докучить", "надоесть"],
    "дообедав": ["дообедавши"],
    "дообедавши": ["дообедав"],
    "дообедывав": ["дообедывавши"],
    "дообедывавши": ["дообедывав"],
    "дооборудовав": ["дооборудовавши"],
    "дооборудовавши": ["дооборудовав"],
    "дообследовав": ["дообследовавши"],
    "дообследовавши": ["дообследовав"],
    "дообсудив": ["дообсудивши"],
    "дообсудивши": ["дообсудив"],
    "дообсудить": ["обсудить", "договорить"],
    "дообучив": ["дообучивши"],
    "дообучивши": ["дообучив"],
    "дооктябрьский": ["дореволюционный", "досоветский", "старорежимный"],
    "доопределив": ["доопределивши"],
    "доопределивши": ["доопределив"],
    "доопределяв": ["доопределявши"],
    "доопределявши": ["доопределяв"],
    "доопытный": ["априорный"],
    "доосмыслив": ["доосмысливши"],
    "доосмысливав": ["доосмысливавши"],
    "доосмысливавши": ["доосмысливав"],
    "доосмысливши": ["доосмыслив"],
    "дооснастив": ["дооснастивши"],
    "дооснастивши": ["дооснастив"],
    "дооснащав": ["дооснащавши"],
    "дооснащавши": ["дооснащав"],
    "дооткапываться": ["доотрываться", "доиграться", "допрыгаться"],
    "дооформляв": ["дооформлявши"],
    "дооформлявши": ["дооформляв"],
    "доочистив": ["доочистивши"],
    "доочистивши": ["доочистив"],
    "доочищав": ["доочищавши"],
    "доочищавши": ["доочищав"],
    "доп": ["дополнение", "добавка"],
    "допаивав": ["допаивавши"],
    "допаивавши": ["допаивав"],
    "допалзывав": ["допалзывавши"],
    "допалзывавши": ["допалзывав"],
    "допалив": ["допаливши"],
    "допаливав": ["допаливавши"],
    "допаливавши": ["допаливав"],
    "допаливши": ["допалив"],
    "допалывав": ["допалывавши"],
    "допалывавши": ["допалывав"],
    "допамин": ["дофамин"],
    "допаминовый": ["дофаминовый"],
    "допан": ["урамустин"],
    "допандемийный": ["допандемический", "предпандемийный", "предпандемический"],
    "допандемический": ["допандемийный", "предпандемийный", "предпандемический"],
    "допарив": ["допаривши"],
    "допаривав": ["допаривавши"],
    "допаривавши": ["допаривав"],
    "допаривши": ["допарив"],
    "допарывав": ["допарывавши"],
    "допарывавши": ["допарывав"],
    "допахав": ["допахавши"],
    "допахавши": ["допахав"],
    "допахивав": ["допахивавши"],
    "допахивавши": ["допахивав"],
    "допаяв": ["допаявши"],
    "допаявши": ["допаяв"],
    "допвыпуск": ["довыпуск"],
    "допев": ["допевши"],
    "допевав": ["допевавши"],
    "допевавши": ["допевав"],
    "допевши": ["допев"],
    "допекав": ["допекавши"],
    "допекавши": ["допекав"],
    "доперев": ["допёрши"],
    "допереть": ["дотащить", "дойти"],
    "допетрив": ["допетривши"],
    "допетривши": ["допетрив"],
    "допечатав": ["допечатавши"],
    "допечатавши": ["допечатав"],
    "допечатывав": ["допечатывавши"],
    "допечатывавши": ["допечатывав"],
    "допив": ["допивши"],
    "допивав": ["допивавши"],
    "допивавши": ["допивав"],
    "допивши": ["допив"],
    "допиздеться": ["доболтаться"],
    "допилив": ["допиливши"],
    "допиливав": ["допиливавши"],
    "допиливавши": ["допиливав"],
    "допиливши": ["допилив"],
    "допилить": ["доделать", "доработать"],
    "допинг": ["стимулятор"],
    "допинговав": ["допинговавши"],
    "допинговавши": ["допинговав"],
    "допир": ["контакт", "досег", "съприкосновение", "прикосновение"],
    "допирав": ["допиравши"],
    "допиравши": ["допирав"],
    "дописав": ["дописавши"],
    "дописавши": ["дописав"],
    "дописать": ["приписать"],
    "дописывав": ["дописывавши"],
    "дописывавши": ["дописывав"],
    "дописывавший": ["дорисовывавший"],
    "допись": ["дописка"],
    "допит": ["допитування"],
    "доплавив": ["доплавивши"],
    "доплавивши": ["доплавив"],
    "доплавливав": ["доплавливавши"],
    "доплавливавши": ["доплавливав"],
    "доплавливать": ["доплавлять"],
    "доплавливаться": ["доплавляться"],
    "доплавляв": ["доплавлявши"],
    "доплавлявши": ["доплавляв"],
    "доплавлять": ["доплавливать"],
    "доплавляться": ["доплавливаться"],
    "доплатив": ["доплативши"],
    "доплативши": ["доплатив"],
    "доплачивав": ["доплачивавши"],
    "доплачивавши": ["доплачивав"],
    "доплевав": ["доплевавши"],
    "доплевавши": ["доплевав"],
    "доплескав": ["доплескавши"],
    "доплескавши": ["доплескав"],
    "доплеснув": ["доплеснувши"],
    "доплеснувши": ["доплеснув"],
    "доплетав": ["доплетавши"],
    "доплетавши": ["доплетав"],
    "доплыв": ["доплывши"],
    "доплывав": ["доплывавши"],
    "доплывавши": ["доплывав"],
    "доплывши": ["доплыв"],
    "доплюнув": ["доплюнувши"],
    "доплюнувши": ["доплюнув"],
    "доплясав": ["доплясавши"],
    "доплясавши": ["доплясав"],
    "доплясывав": ["доплясывавши"],
    "доплясывавши": ["доплясывав"],
    "доплёвывав": ["доплёвывавши"],
    "доплёвывавши": ["доплёвывав"],
    "доплёскивав": ["доплёскивавши"],
    "доплёскивавши": ["доплёскивав"],
    "допнабор": ["добор", "донабор"],
    "доподлинно": ["достоверно"],
    "доподлинный": ["подлинный"],
    "допоздна": ["до ночи", "попозже"],
    "допоив": ["допоивши"],
    "допоивши": ["допоив"],
    "дополаскивав": ["дополаскивавши"],
    "дополаскивавши": ["дополаскивав"],
    "доползав": ["доползавши"],
    "доползавши": ["доползав"],
    "дополнение": ["добавление", "прибавление", "пополнение", "расширение"],
    "дополненье": ["дополнение"],
    "дополнив": ["дополнивши"],
    "дополнивши": ["дополнив"],
    "дополнительная эмиссия": ["допэмиссия"],
    "дополнительно": ["в добавление", "вдобавок", "в дополнение", "сверх того"],
    "дополнительное образование": ["до"],
    "дополнительный": ["добавочный"],
    "дополнить": ["пополнить"],
    "дополняв": ["дополнявши"],
    "дополнявши": ["дополняв"],
    "дополов": ["дополовши"],
    "дополовши": ["дополов"],
    "дополоскав": ["дополоскавши"],
    "дополоскавши": ["дополоскав"],
    "дополучав": ["дополучавши"],
    "дополучавши": ["дополучав"],
    "дополучив": ["дополучивши"],
    "дополучивши": ["дополучив"],
    "допоров": ["допоровши"],
    "допоровши": ["допоров"],
    "допотопность": ["древность"],
    "допотопный": ["доисторический", "архаичный"],
    "доправив": ["доправивши"],
    "доправивши": ["доправив"],
    "доправляв": ["доправлявши"],
    "доправлявши": ["доправляв"],
    "допраздновав": ["допраздновавши"],
    "допраздновавши": ["допраздновав"],
    "допрасследование": ["дорасследование"],
    "допрашивав": ["допрашивавши"],
    "допрашивавши": ["допрашивав"],
    "допрев": ["допревши"],
    "допревав": ["допревавши"],
    "допревавши": ["допревав"],
    "допревши": ["допрев"],
    "допрежь": ["прежде", "раньше"],
    "допремьерный": ["предпремьерный"],
    "допроверив": ["допроверивши"],
    "допроверивши": ["допроверив"],
    "допроверяв": ["допроверявши"],
    "допроверявши": ["допроверяв"],
    "допроводив": ["допроводивши"],
    "допроводивши": ["допроводив"],
    "допродав": ["допродавши"],
    "допродавав": ["допродававши"],
    "допродававши": ["допродавав"],
    "допродавши": ["допродав"],
    "допросив": ["допросивши"],
    "допросивши": ["допросив"],
    "допрыгав": ["допрыгавши"],
    "допрыгавши": ["допрыгав"],
    "допрыгаться": ["доиграться"],
    "допрыгивав": ["допрыгивавши"],
    "допрыгивавши": ["допрыгивав"],
    "допрыгнув": ["допрыгнувши"],
    "допрыгнувши": ["допрыгнув"],
    "допрыгнуть": ["доскочить"],
    "допрядав": ["допрядавши"],
    "допрядавши": ["допрядав"],
    "допрянув": ["допрянувши"],
    "допрянувши": ["допрянув"],
    "допускав": ["допускавши"],
    "допускавши": ["допускав"],
    "допускать": ["подпускать", "позволять", "разрешать"],
    "допустив": ["допустивши"],
    "допустивши": ["допустив"],
    "допустим": ["положим", "предположим"],
    "допустимый": ["позволительный", "приемлемый", "терпимый", "простительный"],
    "допущав": ["допущавши"],
    "допущавши": ["допущав"],
    "допущение": ["дозволение", "допуск", "позволение", "предположение", "гипотеза"],
    "допущенье": ["допущение"],
    "допытав": ["допытавши"],
    "допытавши": ["допытав"],
    "допытаться": ["выведать", "расспросить"],
    "допытывав": ["допытывавши"],
    "допытывавши": ["допытывав"],
    "допёрши": ["доперев"],
    "допёхав": ["допёхавши"],
    "допёхавши": ["допёхав"],
    "дор": ["вырубка"],
    "дорабатывав": ["дорабатывавши"],
    "дорабатывавши": ["дорабатывав"],
    "дорабатывать": ["доводить"],
    "доработав": ["доработавши"],
    "доработавши": ["доработав"],
    "дорада": ["дорадо", "спарус", "аурата", "лампука"],
    "дорадо": ["дорада"],
    "доразвив": ["доразвивши"],
    "доразвивав": ["доразвивавши"],
    "доразвивавши": ["доразвивав"],
    "доразвивши": ["доразвив"],
    "доразделав": ["доразделавши"],
    "доразделавши": ["доразделав"],
    "доразделывав": ["доразделывавши"],
    "доразделывавши": ["доразделывав"],
    "доразместив": ["доразместивши"],
    "доразместивши": ["доразместив"],
    "доразмещав": ["доразмещавши"],
    "доразмещавши": ["доразмещав"],
    "дораскапывав": ["дораскапывавши"],
    "дораскапывавши": ["дораскапывав"],
    "дораскопав": ["дораскопавши"],
    "дораскопавши": ["дораскопав"],
    "дорасследовав": ["дорасследовавши"],
    "дорасследовавши": ["дорасследовав"],
    "дорасследование": ["допрасследование"],
    "дорастав": ["дораставши"],
    "дораставши": ["дорастав"],
    "дорастив": ["дорастивши"],
    "дорастивши": ["дорастив"],
    "доращивав": ["доращивавши"],
    "доращивавши": ["доращивав"],
    "дорвав": ["дорвавши"],
    "дорвавши": ["дорвав"],
    "дордунджи": ["дёртюньчю"],
    "дорезав": ["дорезавши"],
    "дорезавши": ["дорезав"],
    "дорезывав": ["дорезывавши"],
    "дорезывавши": ["дорезывав"],
    "дорезывать": ["дорезать"],
    "дореформенный": ["устаревший", "устарелый"],
    "дореформировав": ["дореформировавши"],
    "дореформировавши": ["дореформировав"],
    "дорешив": ["дорешивши"],
    "дорешивав": ["дорешивавши"],
    "дорешивавши": ["дорешивав"],
    "дорешивши": ["дорешив"],
    "дорзальный": ["дорсальный", "спинной"],
    "дориец": ["дорянин"],
    "дорийский": ["дорический"],
    "доринцэ": ["дор", "кеф"],
    "дорисовав": ["дорисовавши"],
    "дорисовавши": ["дорисовав"],
    "дорисовать": ["додумать", "вообразить", "пририсовать"],
    "дорисовывав": ["дорисовывавши"],
    "дорисовывавши": ["дорисовывав"],
    "доро": ["давлатманд", "бой", "сарватманд", "сероб"],
    "доробло": ["доробало"],
    "дорога": ["путь", "траектория", "поездка", "путешествие", "следование", "направление", "маршрут"],
    "дорого": ["затратно", "ценно"],
    "дорогой": ["любимый", "милый", "любезный", "родной", "дорогомилый", "голубчик"],
    "дорогостоящий": ["драгоценный"],
    "дородность": ["грузность", "откормленность", "полнота", "пухлость", "пышность", "тучность", "упитанность"],
    "дородный": ["полный", "тучный"],
    "дородовый": ["дородовой"],
    "дородство": ["дородность"],
    "дорожав": ["дорожавши"],
    "дорожавши": ["дорожав"],
    "дороже": ["подороже"],
    "дорожив": ["дороживши"],
    "дороживши": ["дорожив"],
    "дорожить": ["ценить"],
    "дорожка": ["дорога", "полоса", "полоска"],
    "дорожная карта": ["программа"],
    "дороманский": ["доримский"],
    "доростол": ["силистра"],
    "дорсальная флексия": ["дорсифлексия"],
    "дорсальный": ["дорзальный", "спинной", "тыльный", "задний"],
    "дорсивентральный": ["дорзивентральный", "дорсовентральный"],
    "дорсифлексия": ["дорсальная флексия"],
    "дорсовентральный": ["дорзовентральный"],
    "дорт": ["дэрт"],
    "дортуар": ["спальня", "опочивальня", "палата", "дормиторий"],
    "дору": ["даво", "дармон"],
    "дорубав": ["дорубавши"],
    "дорубавши": ["дорубав"],
    "дорубив": ["дорубивши"],
    "дорубивши": ["дорубив"],
    "дорубливав": ["дорубливавши"],
    "дорубливавши": ["дорубливав"],
    "доругав": ["доругавши"],
    "доругавши": ["доругав"],
    "доругивав": ["доругивавши"],
    "доругивавши": ["доругивав"],
    "доручення": ["поручення"],
    "дорыв": ["дорывши"],
    "дорывав": ["дорывавши"],
    "дорывавши": ["дорывав"],
    "дорывши": ["дорыв"],
    "досада": ["обида", "неудовольствие"],
    "досадив": ["досадивши"],
    "досадивши": ["досадив"],
    "досадно": ["огорчительно", "жалко", "жаль"],
    "досадовав": ["досадовавши"],
    "досадовавши": ["досадовав"],
    "досажав": ["досажавши"],
    "досажавши": ["досажав"],
    "досаждав": ["досаждавши"],
    "досаждавши": ["досаждав"],
    "досаждать": ["докучать", "донимать", "преследовать"],
    "досаживав": ["досаживавши"],
    "досаживавши": ["досаживав"],
    "досалив": ["досаливши"],
    "досаливав": ["досаливавши"],
    "досаливавши": ["досаливав"],
    "досаливши": ["досалив"],
    "досасывав": ["досасывавши"],
    "досасывавши": ["досасывав"],
    "досбирав": ["досбиравши"],
    "досбиравши": ["досбирав"],
    "досверлив": ["досверливши"],
    "досверливав": ["досверливавши"],
    "досверливавши": ["досверливав"],
    "досверливши": ["досверлив"],
    "досветла": ["затемно"],
    "досвидулька": ["до свидания", "досвидос"],
    "досвистав": ["досвиставши"],
    "досвиставши": ["досвистав"],
    "досвистев": ["досвистевши"],
    "досвистевши": ["досвистев"],
    "досвистывав": ["досвистывавши"],
    "досвистывавши": ["досвистывав"],
    "досдав": ["досдавши"],
    "досдавав": ["досдававши"],
    "досдававши": ["досдавав"],
    "досдавши": ["досдав"],
    "досевав": ["досевавши"],
    "досевавши": ["досевав"],
    "досеивав": ["досеивавши"],
    "досеивавши": ["досеивав"],
    "доселе": ["досель", "доныне", "до сих пор", "досюда"],
    "досель": ["доныне", "доселе", "прежде", "ранее", "посейчас", "поныне", "до сих пор", "по сю пору", "досюда", "досюдова"],
    "досеяв": ["досеявши"],
    "досеявши": ["досеяв"],
    "досидев": ["досидевши"],
    "досидевши": ["досидев"],
    "досиживав": ["досиживавши"],
    "досиживавши": ["досиживав"],
    "досипев": ["досипевши"],
    "досипевши": ["досипев"],
    "доска": ["скрижаль", "борд", "плоскодонка"],
    "доска объявлений": ["афиша", "электронная доска объявлений"],
    "доска почёта": ["красная доска"],
    "доскабливав": ["доскабливавши"],
    "доскабливавши": ["доскабливав"],
    "досказав": ["досказавши"],
    "досказавши": ["досказав"],
    "досказывав": ["досказывавши"],
    "досказывавши": ["досказывав"],
    "доскакав": ["доскакавши"],
    "доскакавши": ["доскакав"],
    "доскакивав": ["доскакивавши"],
    "доскакивавши": ["доскакивав"],
    "доскакнув": ["доскакнувши"],
    "доскакнувши": ["доскакнув"],
    "доскоблив": ["доскобливши"],
    "доскобливши": ["доскоблив"],
    "досконально": ["основательно", "подробно", "тщательно"],
    "доскональный": ["основательный", "подробный", "детальный", "тщательный", "обстоятельный", "всесторонний", "дотошный"],
    "доскочив": ["доскочивши"],
    "доскочивши": ["доскочив"],
    "доскребав": ["доскребавши"],
    "доскребавши": ["доскребав"],
    "доскребая": ["доскрёбывая"],
    "доскрипев": ["доскрипевши"],
    "доскрипевши": ["доскрипев"],
    "доскрёбывав": ["доскрёбывавши"],
    "доскрёбывавши": ["доскрёбывав"],
    "доскрёбывать": ["доскребать"],
    "доскрёбывая": ["доскребая"],
    "дослав": ["дославши"],
    "дославши": ["дослав"],
    "доследив": ["доследивши"],
    "доследивши": ["доследив"],
    "доследовав": ["доследовавши"],
    "доследовавши": ["доследовав"],
    "доследовать": ["добраться"],
    "дослеживав": ["дослеживавши"],
    "дослеживавши": ["дослеживав"],
    "дословно": ["слово в слово", "буквально"],
    "дослужив": ["дослуживши"],
    "дослуживав": ["дослуживавши"],
    "дослуживавши": ["дослуживав"],
    "дослуживши": ["дослужив"],
    "дослухатися": ["дослухуватися"],
    "дослушав": ["дослушавши"],
    "дослушавши": ["дослушав"],
    "дослушивав": ["дослушивавши"],
    "дослушивавши": ["дослушивав"],
    "дослышав": ["дослышавши"],
    "дослышавши": ["дослышав"],
    "досмаливав": ["досмаливавши"],
    "досмаливавши": ["досмаливав"],
    "досматривав": ["досматривавши"],
    "досматривавши": ["досматривав"],
    "досмолив": ["досмоливши"],
    "досмоливши": ["досмолив"],
    "досмотрев": ["досмотревши"],
    "досмотревши": ["досмотрев"],
    "доснимав": ["доснимавши"],
    "доснимавши": ["доснимав"],
    "досняв": ["доснявши"],
    "доснявши": ["досняв"],
    "дособрав": ["дособравши"],
    "дособравши": ["дособрав"],
    "досогласовав": ["досогласовавши"],
    "досогласовавши": ["досогласовав"],
    "досоздав": ["досоздавши"],
    "досоздавав": ["досоздававши"],
    "досоздававши": ["досоздавав"],
    "досоздавши": ["досоздав"],
    "досолив": ["досоливши"],
    "досоливши": ["досолив"],
    "досон": ["доусон"],
    "досортировав": ["досортировавши"],
    "досортировавши": ["досортировав"],
    "досортировывав": ["досортировывавши"],
    "досортировывавши": ["досортировывав"],
    "дососав": ["дососавши"],
    "дососавши": ["дососав"],
    "досохнув": ["досохнувши"],
    "досохнувши": ["досохнув"],
    "досочинив": ["досочинивши"],
    "досочинивши": ["досочинив"],
    "досочиняв": ["досочинявши"],
    "досочинявши": ["досочиняв"],
    "доспав": ["доспавши"],
    "доспавши": ["доспав"],
    "доспев": ["доспевши"],
    "доспевав": ["доспевавши"],
    "доспевавши": ["доспевав"],
    "доспевши": ["доспев"],
    "доспеть": ["дозреть"],
    "доспех": ["снаряжение", "броня"],
    "досплетничав": ["досплетничавши"],
    "досплетничавши": ["досплетничав"],
    "доспорив": ["доспоривши"],
    "доспоривши": ["доспорив"],
    "доспрашивав": ["доспрашивавши"],
    "доспрашивавши": ["доспрашивав"],
    "доспросив": ["доспросивши"],
    "доспросивши": ["доспросив"],
    "досрочно": ["раньше времени", "преждевременно", "рано", "рановато"],
    "достав": ["доставши"],
    "доставав": ["достававши"],
    "достававши": ["доставав"],
    "доставанье": ["доставание"],
    "доставать": ["брать", "вынимать", "раздобывать", "заполучать", "приобретать", "обзаводиться", "дотягиваться", "хватать", "доводить", "изводить", "досаждать", "донимать", "надоедать"],
    "доставаться": ["получать", "выпадать"],
    "доставив": ["доставивши"],
    "доставивши": ["доставив"],
    "доставленье": ["доставление"],
    "доставляв": ["доставлявши"],
    "доставлявши": ["доставляв"],
    "доставлять": ["давать", "предоставлять", "обеспечивать", "устраивать", "причинять", "вызывать", "прикалывать", "доустанавливать"],
    "доставши": ["достав"],
    "достаивав": ["достаивавши"],
    "достаивавши": ["достаивав"],
    "досталь": ["совсем", "совершенно", "окончательно", "полностью", "основательно"],
    "достаток": ["зажиточность", "богатство", "благосостояние", "благополучие", "изобилие", "доход", "достаточность", "обилие"],
    "достаточный": ["убедительный", "веский", "зажиточный", "обеспеченный"],
    "достать": ["взять", "вынуть", "раздобыть", "заполучить", "приобрести", "дотянуться", "хватить", "задолбать", "замучить", "надоесть", "извести", "донять", "досадить"],
    "достаться": ["получить", "выпасть", "прийтись"],
    "достегав": ["достегавши"],
    "достегавши": ["достегав"],
    "достелив": ["достеливши"],
    "достеливши": ["достелив"],
    "достигав": ["достигавши"],
    "достигавши": ["достигав"],
    "достигательное наклонение": ["супин"],
    "достигательный падеж": ["целевой падеж"],
    "достигать": ["добираться", "доживать", "добиваться"],
    "достигнув": ["достигнувши"],
    "достигнувши": ["достигнув"],
    "достигнуть": ["достичь"],
    "достижение": ["успех", "заслуга"],
    "достиженье": ["достижение"],
    "достижимый": ["осуществимый"],
    "достилав": ["достилавши"],
    "достилавши": ["достилав"],
    "достирав": ["достиравши"],
    "достиравши": ["достирав"],
    "достирывав": ["достирывавши"],
    "достирывавши": ["достирывав"],
    "достичь": ["достигнуть", "до"],
    "достлав": ["достлавши"],
    "достлавши": ["достлав"],
    "достоверно": ["подлинно", "правдоподобно"],
    "достоверность": ["фактичность", "точность", "авторитетность", "надёжность"],
    "достоверный": ["правдоподобный"],
    "достодолжный": ["подобающий", "должный"],
    "достоевед": ["достоевист", "достоевсковед"],
    "достоевист": ["достоевед", "достоевсковед"],
    "достоевистика": ["достоевсковедение"],
    "достоевсковед": ["достоевед", "достоевист"],
    "достоевсковедение": ["достоевистика"],
    "достоинство": ["плюс", "преимущество", "привлекательность", "благородство"],
    "достойный": ["заслуживающий"],
    "достопочтенный": ["глубокоуважаемый", "достоуважаемый", "досточтимый", "многоуважаемый", "почтеннейший", "почтенный", "уважаемый"],
    "достопримечательность": ["примечательность", "интересность"],
    "достославный": ["достохвальный", "славный"],
    "досточка": ["досочка", "дощечка"],
    "досточтимый": ["высокочтимый", "высокопочитаемый", "глубокоуважаемый"],
    "достояв": ["достоявши"],
    "достоявши": ["достояв"],
    "достоянье": ["достояние"],
    "дострагивав": ["дострагивавши"],
    "дострагивавши": ["дострагивав"],
    "дострадав": ["дострадавши"],
    "дострадавши": ["дострадав"],
    "достраивав": ["достраивавши"],
    "достраивавши": ["достраивав"],
    "достраивание": ["достраиванье", "достроенье"],
    "достраиванье": ["достраивание", "достроенье"],
    "дострачивав": ["дострачивавши"],
    "дострачивавши": ["дострачивав"],
    "дострелив": ["достреливши"],
    "достреливав": ["достреливавши"],
    "достреливавши": ["достреливав"],
    "достреливши": ["дострелив"],
    "достреляв": ["дострелявши"],
    "дострелявши": ["достреляв"],
    "достригав": ["достригавши"],
    "достригавши": ["достригав"],
    "дострогав": ["дострогавши"],
    "дострогавши": ["дострогав"],
    "достроив": ["достроивши"],
    "достроивши": ["достроив"],
    "дострочив": ["дострочивши"],
    "дострочивши": ["дострочив"],
    "достругав": ["достругавши"],
    "достругавши": ["достругав"],
    "достругивав": ["достругивавши"],
    "достругивавши": ["достругивав"],
    "достряпав": ["достряпавши"],
    "достряпавши": ["достряпав"],
    "достряпывав": ["достряпывавши"],
    "достряпывавши": ["достряпывав"],
    "достукав": ["достукавши"],
    "достукавши": ["достукав"],
    "достукаться": ["добиться", "доиграться"],
    "достукивав": ["достукивавши"],
    "достукивавши": ["достукивав"],
    "доступав": ["доступавши"],
    "доступавши": ["доступав"],
    "доступив": ["доступивши"],
    "доступивши": ["доступив"],
    "доступный": ["открытый", "дешёвый", "понятный", "ясный", "постижимый", "внятный", "доходчивый", "простой"],
    "достёгивав": ["достёгивавши"],
    "достёгивавши": ["достёгивав"],
    "досуг": ["свободное время"],
    "досужий": ["праздный", "бездельный"],
    "досужный": ["досужий", "вольготный", "праздный"],
    "досучив": ["досучивши"],
    "досучивав": ["досучивавши"],
    "досучивавши": ["досучивав"],
    "досучивши": ["досучив"],
    "досушив": ["досушивши"],
    "досушивав": ["досушивавши"],
    "досушивавши": ["досушивав"],
    "досушивание": ["досушка"],
    "досушивши": ["досушив"],
    "досушка": ["досушивание"],
    "досчатый": ["дощатый", "досчаной", "досчаный", "дощаной"],
    "досчитав": ["досчитавши"],
    "досчитавши": ["досчитав"],
    "досчитывав": ["досчитывавши"],
    "досчитывавши": ["досчитывав"],
    "досчитываться": ["досчитывать"],
    "досылав": ["досылавши"],
    "досылавши": ["досылав"],
    "досыпав": ["досыпавши"],
    "досыпавши": ["досыпав"],
    "досыта": ["от пуза", "вдоволь"],
    "досыхав": ["досыхавши"],
    "досыхавши": ["досыхав"],
    "досье": ["дело"],
    "досюда": ["доселе", "досель", "досюдова"],
    "досягав": ["досягавши"],
    "досягавши": ["досягав"],
    "досягнув": ["досягнувши"],
    "досягнувши": ["досягнув"],
    "дот": ["долговременная огневая точка"],
    "дотаивав": ["дотаивавши"],
    "дотаивавши": ["дотаивав"],
    "доталкивав": ["доталкивавши"],
    "доталкивавши": ["доталкивав"],
    "дотанцевав": ["дотанцевавши"],
    "дотанцевавши": ["дотанцевав"],
    "дотанцовывав": ["дотанцовывавши"],
    "дотанцовывавши": ["дотанцовывав"],
    "дотапливав": ["дотапливавши"],
    "дотапливавши": ["дотапливав"],
    "дотаскав": ["дотаскавши"],
    "дотаскавши": ["дотаскав"],
    "дотаскивав": ["дотаскивавши"],
    "дотаскивавши": ["дотаскивав"],
    "дотаскувати": ["дотягувати"],
    "дотачав": ["дотачавши"],
    "дотачавши": ["дотачав"],
    "дотачивав": ["дотачивавши"],
    "дотачивавши": ["дотачивав"],
    "дотащив": ["дотащивши"],
    "дотащивши": ["дотащив"],
    "дотаяв": ["дотаявши"],
    "дотаявши": ["дотаяв"],
    "дотекав": ["дотекавши"],
    "дотекавши": ["дотекав"],
    "дотелепав": ["дотелепавши"],
    "дотелепавши": ["дотелепав"],
    "дотерев": ["дотёрши"],
    "дотерпев": ["дотерпевши"],
    "дотерпевши": ["дотерпев"],
    "дотесав": ["дотесавши"],
    "дотесавши": ["дотесав"],
    "дотив": ["дотивши"],
    "дотивши": ["дотив"],
    "дотирав": ["дотиравши"],
    "дотиравши": ["дотирав"],
    "дотировав": ["дотировавши"],
    "дотировавши": ["дотировав"],
    "дотискав": ["дотискавши"],
    "дотискавши": ["дотискав"],
    "дотискивав": ["дотискивавши"],
    "дотискивавши": ["дотискивав"],
    "дотиснув": ["дотиснувши"],
    "дотиснувши": ["дотиснув"],
    "доткав": ["доткавши"],
    "доткавши": ["доткав"],
    "дотла": ["до основания", "полностью"],
    "дотлев": ["дотлевши"],
    "дотлевав": ["дотлевавши"],
    "дотлевавши": ["дотлевав"],
    "дотлевши": ["дотлев"],
    "дотоле": ["дотоль", "прежде", "раньше", "до тех пор"],
    "дотолкав": ["дотолкавши"],
    "дотолкавши": ["дотолкав"],
    "дотопав": ["дотопавши"],
    "дотопавши": ["дотопав"],
    "дотопать": ["дойти"],
    "дотопив": ["дотопивши"],
    "дотопивши": ["дотопив"],
    "доторговав": ["доторговавши"],
    "доторговавши": ["доторговав"],
    "доторговывав": ["доторговывавши"],
    "доторговывавши": ["доторговывав"],
    "доторкання": ["доторк"],
    "доточив": ["доточивши"],
    "доточивши": ["доточив"],
    "доточка": ["доработка"],
    "дотошность": ["настойчивость", "пытливость", "придирчивость"],
    "дотошный": ["въедливый", "скрупулёзный", "педантичный"],
    "дотравив": ["дотравивши"],
    "дотравивши": ["дотравив"],
    "дотравливав": ["дотравливавши"],
    "дотравливавши": ["дотравливав"],
    "дотрагиваться": ["касаться", "прикасаться", "трогать", "притрагиваться"],
    "дотратить": ["доиспользовать"],
    "дотрепав": ["дотрепавши"],
    "дотрепавши": ["дотрепав"],
    "дотронуться": ["коснуться", "прикоснуться", "тронуть", "притронуться"],
    "дотуда": ["дотудова", "дотеле", "дотель"],
    "дотудова": ["дотуда", "дотеле", "дотель"],
    "дотумкав": ["дотумкавши"],
    "дотумкавши": ["дотумкав"],
    "дотумкивав": ["дотумкивавши"],
    "дотумкивавши": ["дотумкивав"],
    "дотушевав": ["дотушевавши"],
    "дотушевавши": ["дотушевав"],
    "дотушив": ["дотушивши"],
    "дотушивши": ["дотушив"],
    "дотушёвывав": ["дотушёвывавши"],
    "дотушёвывавши": ["дотушёвывав"],
    "дотягивав": ["дотягивавши"],
    "дотягивавши": ["дотягивав"],
    "дотянув": ["дотянувши"],
    "дотянувши": ["дотянув"],
    "дотёрши": ["дотерев"],
    "дотёсывав": ["дотёсывавши"],
    "дотёсывавши": ["дотёсывав"],
    "доужинав": ["доужинавши"],
    "доужинавши": ["доужинав"],
    "доукомплектовав": ["доукомплектовавши"],
    "доукомплектовавши": ["доукомплектовав"],
    "доукомплектование": ["доукомплектовка"],
    "доукомплектовывав": ["доукомплектовывавши"],
    "доукомплектовывавши": ["доукомплектовывав"],
    "доуплотнив": ["доуплотнивши"],
    "доуплотнивши": ["доуплотнив"],
    "доупрощав": ["доупрощавши"],
    "доупрощавши": ["доупрощав"],
    "доусон": ["досон"],
    "доучив": ["доучивши"],
    "доучивав": ["доучивавши"],
    "доучивавши": ["доучивав"],
    "доучивши": ["доучив"],
    "дофамин": ["допамин"],
    "дофаминергический": ["дофаминэргический"],
    "дофаминовый": ["допаминовый"],
    "дофантазировав": ["дофантазировавши"],
    "дофантазировавши": ["дофантазировав"],
    "дофинансировав": ["дофинансировавши"],
    "дофинансировавши": ["дофинансировав"],
    "доформировав": ["доформировавши"],
    "доформировавши": ["доформировав"],
    "доформировывав": ["доформировывавши"],
    "доформировывавши": ["доформировывав"],
    "дофорсив": ["дофорсивши"],
    "дофорсивши": ["дофорсив"],
    "дофургаловский": ["дофургальский"],
    "дофургальский": ["дофургаловский"],
    "дохав": ["дохавши"],
    "дохавши": ["дохав"],
    "дохаживав": ["дохаживавши"],
    "дохаживавши": ["дохаживав"],
    "дохаживать": ["на сносях"],
    "дохать": ["кашлять"],
    "дохватав": ["дохватавши"],
    "дохватавши": ["дохватав"],
    "дохватив": ["дохвативши"],
    "дохвативши": ["дохватив"],
    "дохватывав": ["дохватывавши"],
    "дохватывавши": ["дохватывав"],
    "дохлебав": ["дохлебавши"],
    "дохлебавши": ["дохлебав"],
    "дохлебать": ["дохлебнуть"],
    "дохлебнув": ["дохлебнувши"],
    "дохлебнувши": ["дохлебнув"],
    "дохлебнуть": ["дохлебать"],
    "дохлестав": ["дохлеставши"],
    "дохлеставши": ["дохлестав"],
    "дохлестнув": ["дохлестнувши"],
    "дохлестнувши": ["дохлестнув"],
    "дохлик": ["дохляк", "задохлик", "хиляк", "слабак", "заморыш", "дохлятина"],
    "дохлопав": ["дохлопавши"],
    "дохлопавши": ["дохлопав"],
    "дохлопывав": ["дохлопывавши"],
    "дохлопывавши": ["дохлопывав"],
    "дохлый": ["палый", "издохший", "сдохший", "умерший", "хилый", "худосочный"],
    "дохлый номер": ["пустой номер", "тщетно", "бесполезно"],
    "дохлынув": ["дохлынувши"],
    "дохлынувши": ["дохлынув"],
    "дохлятина": ["мертвечина", "падаль", "стерва"],
    "дохлёбывав": ["дохлёбывавши"],
    "дохлёбывавши": ["дохлёбывав"],
    "дохлёстывав": ["дохлёстывавши"],
    "дохлёстывавши": ["дохлёстывав"],
    "дохнув": ["дохнувши"],
    "дохнувши": ["дохнув"],
    "дохнут как мухи": ["мрут как мухи"],
    "дохнуть": ["умирать", "подыхать", "издыхать"],
    "доход": ["выгода", "приход", "выручка"],
    "доходив": ["доходивши"],
    "доходивши": ["доходив"],
    "доходность": ["выгодность", "кассовость", "прибыльность", "рентабельность"],
    "доходный": ["приходный", "выгодный", "прибыльный", "рентабельный", "коммерческий"],
    "доходчиво": ["понятно", "просто", "доступно", "вразумительно", "русским языком"],
    "дохозяйничав": ["дохозяйничавши"],
    "дохозяйничавши": ["дохозяйничав"],
    "дохолодив": ["дохолодивши"],
    "дохолодивши": ["дохолодив"],
    "дохрамывав": ["дохрамывавши"],
    "дохрамывавши": ["дохрамывав"],
    "дохромав": ["дохромавши"],
    "дохромавши": ["дохромав"],
    "дохулион": ["дохуллион", "охулион", "охулиард", "ахулиард", "дофига", "до фига", "дохуя", "до хуя"],
    "доцарапав": ["доцарапавши"],
    "доцарапавши": ["доцарапав"],
    "доцарапать": ["докорябать"],
    "доцарапывав": ["доцарапывавши"],
    "доцарапывавши": ["доцарапывав"],
    "доцарапывать": ["докорябывать"],
    "доцветав": ["доцветавши"],
    "доцветавши": ["доцветав"],
    "доцедив": ["доцедивши"],
    "доцедивши": ["доцедив"],
    "доцеживав": ["доцеживавши"],
    "доцеживавши": ["доцеживав"],
    "доцеловав": ["доцеловавши"],
    "доцеловавши": ["доцеловав"],
    "доцеловывав": ["доцеловывавши"],
    "доцеловывавши": ["доцеловывав"],
    "доцент": ["лектор"],
    "доцентура": ["доцентство"],
    "доцифровой": ["докомпьютерный"],
    "доча": ["дочь", "дочка"],
    "дочапав": ["дочапавши"],
    "дочапавши": ["дочапав"],
    "дочеканив": ["дочеканивши"],
    "дочеканивав": ["дочеканивавши"],
    "дочеканивавши": ["дочеканивав"],
    "дочеканивши": ["дочеканив"],
    "доченька": ["дочь", "дочуля", "дочурка", "дочка"],
    "дочеркав": ["дочеркавши"],
    "дочеркавши": ["дочеркав"],
    "дочеркать": ["дочеркнуть"],
    "дочеркнув": ["дочеркнувши"],
    "дочеркнувши": ["дочеркнув"],
    "дочеркнуть": ["дочеркать"],
    "дочернив": ["дочернивши"],
    "дочернивши": ["дочернив"],
    "дочерняя компания": ["дочка"],
    "дочерпав": ["дочерпавши"],
    "дочерпавши": ["дочерпав"],
    "дочерпнув": ["дочерпнувши"],
    "дочерпнувши": ["дочерпнув"],
    "дочерпнуть": ["дочерпать"],
    "дочерпывав": ["дочерпывавши"],
    "дочерпывавши": ["дочерпывав"],
    "дочертив": ["дочертивши"],
    "дочертивши": ["дочертив"],
    "дочерчивав": ["дочерчивавши"],
    "дочерчивавши": ["дочерчивав"],
    "дочесав": ["дочесавши"],
    "дочесавши": ["дочесав"],
    "дочинив": ["дочинивши"],
    "дочинивав": ["дочинивавши"],
    "дочинивавши": ["дочинивав"],
    "дочинивать": ["дочинять"],
    "дочинивши": ["дочинив"],
    "дочиняв": ["дочинявши"],
    "дочинявши": ["дочиняв"],
    "дочиста": ["начисто", "подчистую", "вчистую"],
    "дочистив": ["дочистивши"],
    "дочистивши": ["дочистив"],
    "дочитав": ["дочитавши"],
    "дочитавши": ["дочитав"],
    "дочитаться": ["дочитать", "добраться"],
    "дочитывав": ["дочитывавши"],
    "дочитывавши": ["дочитывав"],
    "дочихав": ["дочихавши"],
    "дочихавши": ["дочихав"],
    "дочищав": ["дочищавши"],
    "дочищавши": ["дочищав"],
    "дочка": ["дочь", "девочка", "дочерняя компания"],
    "дочувствовав": ["дочувствовавши"],
    "дочувствовавши": ["дочувствовав"],
    "дочуля": ["дочурка"],
    "дочурка": ["доченька", "дочка", "дочуля"],
    "дочурочка": ["дочурка", "дочуля"],
    "дочь": ["дочка", "дочурка", "дщерь"],
    "дочёркивав": ["дочёркивавши"],
    "дочёркивавши": ["дочёркивав"],
    "дочёсывав": ["дочёсывавши"],
    "дочёсывавши": ["дочёсывав"],
    "дошагав": ["дошагавши"],
    "дошагавши": ["дошагав"],
    "дошагивав": ["дошагивавши"],
    "дошагивавши": ["дошагивав"],
    "дошагнув": ["дошагнувши"],
    "дошагнувши": ["дошагнув"],
    "дошалиться": ["доиграться"],
    "дошатав": ["дошатавши"],
    "дошатавши": ["дошатав"],
    "дошатывав": ["дошатывавши"],
    "дошатывавши": ["дошатывав"],
    "дошвыривав": ["дошвыривавши"],
    "дошвыривавши": ["дошвыривав"],
    "дошвырнув": ["дошвырнувши"],
    "дошвырнувши": ["дошвырнув"],
    "дошвырнуть": ["докинуть", "добросить"],
    "дошвыряв": ["дошвырявши"],
    "дошвырявши": ["дошвыряв"],
    "дошептав": ["дошептавши"],
    "дошептавши": ["дошептав"],
    "дошибав": ["дошибавши"],
    "дошибавши": ["дошибав"],
    "дошибив": ["дошибивши"],
    "дошибивши": ["дошибив"],
    "дошив": ["дошивши"],
    "дошивав": ["дошивавши"],
    "дошивавши": ["дошивав"],
    "дошивши": ["дошив"],
    "доширак": ["дошик"],
    "дошкандыбав": ["дошкандыбавши"],
    "дошкандыбавши": ["дошкандыбав"],
    "дошколёнок": ["дошкольник"],
    "дошлифовав": ["дошлифовавши"],
    "дошлифовавши": ["дошлифовав"],
    "дошлифовывав": ["дошлифовывавши"],
    "дошлифовывавши": ["дошлифовывав"],
    "дошлый": ["ловкий", "бойкий", "смышлёный", "бывалый", "опытный", "знающий"],
    "дошнуровав": ["дошнуровавши"],
    "дошнуровавши": ["дошнуровав"],
    "дошнуровывав": ["дошнуровывавши"],
    "дошнуровывавши": ["дошнуровывав"],
    "доштукатурив": ["доштукатуривши"],
    "доштукатуривав": ["доштукатуривавши"],
    "доштукатуривавши": ["доштукатуривав"],
    "доштукатуривши": ["доштукатурив"],
    "дошумев": ["дошумевши"],
    "дошумевши": ["дошумев"],
    "дошурупив": ["дошурупивши"],
    "дошурупивши": ["дошурупив"],
    "дошутив": ["дошутивши"],
    "дошутивши": ["дошутив"],
    "дошучивав": ["дошучивавши"],
    "дошучивавши": ["дошучивав"],
    "дошёптывав": ["дошёптывавши"],
    "дошёптывавши": ["дошёптывав"],
    "дощаный": ["дощатый"],
    "дощечка": ["досточка"],
    "дощипав": ["дощипавши"],
    "дощипавши": ["дощипав"],
    "дощипаться": ["дощипываться"],
    "дощипывав": ["дощипывавши"],
    "дощипывавши": ["дощипывав"],
    "дощник": ["дошник"],
    "дощупав": ["дощупавши"],
    "дощупавши": ["дощупав"],
    "дощупывав": ["дощупывавши"],
    "дощупывавши": ["дощупывав"],
    "доэкзаменовав": ["доэкзаменовавши"],
    "доэкзаменовавши": ["доэкзаменовав"],
    "доэкзаменовывав": ["доэкзаменовывавши"],
    "доэкзаменовывавши": ["доэкзаменовывав"],
    "доэллинский": ["доэллинистический", "преэллинский"],
    "доярка": ["доильщица"],
    "доёб": ["доёбка", "доёбочка"],
    "доёбистый": ["доёбчивый"],
    "доёбка": ["придирка", "придирочка", "приёбка", "доёбочка", "приёбочка"],
    "доёбчивость": ["приставучесть", "дотошливость"],
    "доёбчивый": ["приставучий", "дотошный"],
    "доёбываться": ["приставать", "допытываться", "домогаться"],
    "дпа": ["гиа", "аам"],
    "др": ["день рождения", "днюха", "день варенья"],
    "дра": ["демократическая республика афганистан"],
    "драбант": ["трабант"],
    "драв": ["дравши"],
    "дравидийский": ["дравидский"],
    "дравидский": ["дравидийский"],
    "дравши": ["драв"],
    "драг-квин": ["дрэг-квин"],
    "драгдилер": ["наркодилер", "наркосбытчик", "наркоторговец"],
    "драгер": ["дражник", "землечерпальщик", "тральщик"],
    "драгировав": ["драгировавши"],
    "драгировавши": ["драгировав"],
    "драгирование": ["драгировка"],
    "драгметалл": ["драгоценный металл"],
    "драговит": ["другувит", "драгович"],
    "драгой": ["дорогостоящий", "ценный", "драгоценный", "любимый", "милый", "дорогомилый"],
    "драгоценный": ["ценный", "редкий", "бесценный", "важный", "нужный", "полезный", "уникальный", "дорогой", "милый"],
    "драгоценный камень": ["самоцвет", "гем"],
    "драгоценный металл": ["драгметалл", "благородный металл"],
    "драгстер": ["дрегстер", "драг"],
    "дражайший": ["драгоценнейший", "дорогой", "любезнейший"],
    "дражник": ["драгер"],
    "дразнив": ["дразнивши"],
    "дразнивши": ["дразнив"],
    "дразнить": ["злить", "сердить"],
    "драив": ["драивши"],
    "драивши": ["драив"],
    "драить": ["чистить", "натирать", "мыть", "тереть", "тянуть", "натягивать", "выговаривать", "отчитывать", "ругать", "дрюкать", "дрючить"],
    "драйв": ["кураж", "задор"],
    "драйвер": ["дрова"],
    "драка": ["потасовка", "свалка", "баталия", "ссора", "махач"],
    "драконий": ["драконов", "драконовый"],
    "драконов": ["драконий", "драконовый"],
    "драконовый": ["драконий", "драконов"],
    "драм-машина": ["ритм-компьютер"],
    "драма": ["пьеса"],
    "драматизировав": ["драматизировавши"],
    "драматизировавши": ["драматизировав"],
    "драматик": ["драматург"],
    "драматично": ["драматически"],
    "драматичный": ["театральный", "напыщенный"],
    "драматург": ["драматик", "драматист"],
    "дранголник": ["затвор", "тъмница", "пандиз"],
    "драндулет": ["тарантас", "пепелац", "развалюха", "колымага", "джабахан", "повозка", "хреновина", "фиговина"],
    "драник": ["какорка", "дерун", "тертюха", "кремзлык", "пляцок", "латкес"],
    "драница": ["дранка"],
    "дранка": ["дрань", "драньё"],
    "дрань": ["рваньё", "рванина"],
    "драпав": ["драпавши"],
    "драпавши": ["драпав"],
    "драпанув": ["драпанувши"],
    "драпанувши": ["драпанув"],
    "драпировав": ["драпировавши"],
    "драпировавши": ["драпировав"],
    "драпировка": ["драпирование"],
    "драпри": ["драпировка", "занавеска", "портьера"],
    "драскотина": ["рана", "издраскване", "порязване", "раздиране"],
    "драстический": ["драстичный"],
    "дратвенный": ["дратвяной"],
    "дратхаар": ["немецкая жесткошёрстная легавая"],
    "драть кадык": ["распустить кадык", "кадычать", "орать", "драть глотку"],
    "драть как сидорову козу": ["драть семь шкур"],
    "драться": ["биться", "бороться", "воевать", "сражаться", "добиваться"],
    "драчун": ["забияка", "задира"],
    "драчёна": ["дрочёна"],
    "дребедень": ["ерунда", "фигня", "лабуда", "хлам", "рухлядь", "мелочь", "мелочёвка"],
    "дребезг": ["дребезжание"],
    "дребезжав": ["дребезжавши"],
    "дребезжавши": ["дребезжав"],
    "дребезжание": ["дребезжанье", "дребезг"],
    "дребезжанье": ["дребезжание", "дребезг"],
    "дреболия": ["играчка", "незначителност", "нищожност", "нищожество", "детайл"],
    "древесина": ["лес", "дерево", "натуральная древесина", "натуральное дерево", "массив дерева"],
    "древесиновед": ["ксилолог"],
    "древесно-стружечная плита": ["дсп"],
    "древесный": ["деревянный"],
    "древко": ["черенок"],
    "древле": ["в древности", "в старину", "встарь", "давно", "некогда"],
    "древлеписаный": ["старописаный"],
    "древлеправославие": ["старообрядчество", "староверие"],
    "древлий": ["древний", "ветхий"],
    "древнеанглийский": ["англосаксонский", "древнеанглийский язык", "язык"],
    "древнеанглийский язык": ["англосаксонский", "язык"],
    "древнегреческий": ["эллинский"],
    "древнееврейский": ["иврит"],
    "древнеегипетский язык": ["египетский язык"],
    "древнеисландский язык": ["древнескандинавский язык"],
    "древнейшая профессия": ["проституция"],
    "древненидерландский язык": ["древненижнефранкский", "язык"],
    "древнесаксонский": ["древнесаксонский язык"],
    "древнесеверный": ["древне-северный"],
    "древнесемитский": ["ассиро-вавилонский", "халдейский", "древнесемитический", "арамейский"],
    "древнетюркский": ["древнетюркский язык", "пратюркский язык"],
    "древнефранкский язык": ["франкский язык"],
    "древнецерковнославянский": ["старославянский"],
    "древнеэфиопский язык": ["геэз"],
    "древний": ["архаичный"],
    "древняя греция": ["античная греция"],
    "древо": ["дерево"],
    "древовидный": ["древообразный", "древоподобный"],
    "древовод": ["арборист"],
    "древогрыз": ["ликтус"],
    "древолаз": ["скалолаз", "квакша"],
    "древолюбивый": ["дендрофильный"],
    "древообразный": ["древовидный"],
    "древостой": ["лесостой"],
    "дрегстер": ["драгстер"],
    "дредлок": ["дреды"],
    "дреды": ["дредлоки", "локи"],
    "дрезгавина": ["сумрак", "здрач", "здрачевина", "мрачина", "мрачевина", "полумрак"],
    "дрейф": ["снос"],
    "дрейфив": ["дрейфивши"],
    "дрейфивши": ["дрейфив"],
    "дрейфить": ["бояться", "пугаться", "страшиться", "опасаться", "трусить", "робеть", "трепетать", "дрожать", "трястись"],
    "дрейфовав": ["дрейфовавши"],
    "дрейфовавши": ["дрейфовав"],
    "дрейфун": ["дрефун"],
    "дрелив": ["дреливши"],
    "дреливши": ["дрелив"],
    "дрель": ["коловорот", "бур", "электрическая дрель", "электродрель"],
    "дремав": ["дремавши"],
    "дремавши": ["дремав"],
    "дремив": ["дремивши"],
    "дремивши": ["дремив"],
    "дремота": ["полусон"],
    "дремотность": ["сонливость", "дрёма", "дремота", "усталость"],
    "дремучий": ["густой", "труднопроходимый", "спутанный", "захолустный", "глухой", "невежественный", "необразованный"],
    "дренажировав": ["дренажировавши"],
    "дренажировавши": ["дренажировав"],
    "дренировав": ["дренировавши"],
    "дренировавши": ["дренировав"],
    "дренувати": ["дренажувати"],
    "дренькав": ["дренькавши"],
    "дренькавши": ["дренькав"],
    "дренькнув": ["дренькнувши"],
    "дренькнувши": ["дренькнув"],
    "дрепан": ["еленополь"],
    "дрессинг": ["заправка"],
    "дрессировав": ["дрессировавши"],
    "дрессировавши": ["дрессировав"],
    "дрессура": ["дрессировка", "дрессирование"],
    "дрефив": ["дрефивши"],
    "дрефивши": ["дрефив"],
    "дреха": ["облекло", "покривало", "наметало"],
    "дрешник": ["гардероб"],
    "дриблинг": ["ведение", "обводка"],
    "дриблинговав": ["дриблинговавши"],
    "дриблинговавши": ["дриблинговав"],
    "дрил": ["дрилл"],
    "дринкав": ["дринкавши"],
    "дринкавши": ["дринкав"],
    "дринкать": ["дринькать"],
    "дрипа": ["отрепка", "парцал", "вехтория"],
    "дрипльо": ["просяк", "парцалан", "бедняк", "опърпан"],
    "дрисня": ["понос", "диарея"],
    "дристав": ["дриставши"],
    "дриставши": ["дристав"],
    "дристать": ["поносить"],
    "дристун": ["дрист"],
    "дрифт": ["дрейф"],
    "дрифтив": ["дрифтивши"],
    "дрифтивши": ["дрифтив"],
    "дрифтить": ["дрифтовать"],
    "дрифтовав": ["дрифтовавши"],
    "дрифтовавши": ["дрифтовав"],
    "дрифтовать": ["дрифтить"],
    "дрищ": ["слабак", "хлюпик", "хиляк", "трус"],
    "дрк": ["демократическая республика конго", "др конго"],
    "дробив": ["дробивши"],
    "дробивши": ["дробив"],
    "дробина": ["дробинка"],
    "дробитель": ["дробилка"],
    "дробянка": ["монера"],
    "дрова": ["дровишки"],
    "дровец": ["дрова"],
    "дровишко": ["полешко"],
    "дроворуб": ["лесоруб", "дровосек", "вальщик леса"],
    "дровосек": ["лесоруб", "дроворуб"],
    "дровосушка": ["дровосушня"],
    "дровосушня": ["дровосушка"],
    "дрогаль": ["ломовик"],
    "дроги": ["повозка", "телега", "катафалк"],
    "дрогнув": ["дрогнувши"],
    "дрогнувши": ["дрогнув"],
    "дрожав": ["дрожавши"],
    "дрожавши": ["дрожав"],
    "дрожанье": ["дрожание"],
    "дрожать": ["сотрясаться", "трястись", "бояться", "пугаться", "страшиться", "опасаться", "трусить", "дрейфить", "робеть", "трепетать"],
    "дрожать как осиновый лист": ["бояться"],
    "дрожжевав": ["дрожжевавши"],
    "дрожжевавши": ["дрожжевав"],
    "дрожжеподобный": ["дрожжеобразный", "дрожжевидный"],
    "дрожжец": ["дрожжи"],
    "дрожь": ["дрожание", "трепет", "сотрясение", "тряска"],
    "дрозофила": ["плодовая мушка", "винная муха"],
    "дроля": ["пассия", "подруга"],
    "дромадер": ["одногорбый верблюд", "дромедар", "арабиан"],
    "дромедар": ["одногорбый верблюд", "дромадер", "арабиан"],
    "дромомания": ["пориомания", "вагабондаж"],
    "дрон": ["беспилотник", "бпла"],
    "дрон-камикадзе": ["барражирующий боеприпас"],
    "дронный": ["дроновый"],
    "дронобойка": ["противодроновый", "ружьё", "противодронный", "антидроновый"],
    "дроновый": ["дронный"],
    "дронт": ["додо"],
    "дропнув": ["дропнувши"],
    "дропнувши": ["дропнув"],
    "дросселировав": ["дросселировавши"],
    "дросселировавши": ["дросселировав"],
    "дроссель": ["катушка индуктивности"],
    "дрот": ["проволока"],
    "дроу": ["драу", "дров"],
    "дрофа": ["дудак"],
    "дрочер": ["онанист", "мастурбатор"],
    "дрочив": ["дрочивши"],
    "дрочивши": ["дрочив"],
    "дрочила": ["онанист", "дрочер", "дрочило", "дрочильщик", "дрочёха", "дрочилка", "дрочилкин", "задрот", "задротик", "задротыш", "зодрыч"],
    "дрочилка": ["порножурнал"],
    "дрочить по головке": ["потворствовать", "гладить по головке"],
    "дрочка": ["онанизм", "мастурбация", "ручной блуд", "рукоблудие", "рукоблудство", "рукоделие", "суходроч", "суходрочка", "геморрой"],
    "дрочливый": ["неженка"],
    "дрочун": ["онанист", "рукоблуд", "дрочила"],
    "дрочёна": ["драчёна"],
    "дрочёный": ["балованный", "выхоленный", "изнеженный"],
    "дроэда": ["дрохеда"],
    "друг": ["приятель", "товарищ", "ара", "друган", "френд", "возлюбленный", "возлюбленная", "дружок", "дружище"],
    "друг артиллеристов": ["лучший друг артиллеристов", "лучший друг детей", "лучший друг заключённых", "лучший друг угнетённых народов", "друг колхозников", "лучший друг колхозников", "лучший друг писателей", "лучший друг чекистов", "лучший друг танкистов", "лучший друг горняков", "друг шахтёров", "лучший друг шахтёров", "лучший друг физкультурников", "друг женщин", "друг художников"],
    "друг дома": ["любовник"],
    "друг друга": ["друг дружку"],
    "друг дружку": ["друг друга"],
    "друг за другом": ["гуськом", "друг за дружкой"],
    "друг ситный": ["друг ситцевый"],
    "друг ситцевый": ["друг ситный"],
    "друг человека": ["собака"],
    "другарка": ["приятелка", "дружка", "съпруга"],
    "другиня": ["подруга", "подружка", "приятельница", "товарка"],
    "другое": ["иное"],
    "другоземец": ["чужденец", "чуждестранен", "пришълец", "преселник"],
    "другой": ["иной", "прочий", "непохожий"],
    "другувит": ["драговит"],
    "дружба": ["приятельство"],
    "дружбан": ["кореш", "корешок", "корефан"],
    "дружелюбие": ["дружелюбье", "дружественность", "доброжелательность"],
    "дружелюбно": ["доброжелательно"],
    "дружелюбный": ["дружеский", "благожелательный", "доброжелательный", "дружественный", "приязненный", "приветливый"],
    "дружелюбье": ["дружелюбие"],
    "дружески": ["дружественно", "по-дружески", "приятельски", "дружелюбно"],
    "дружественный": ["благожелательный", "дружеский"],
    "дружественный огонь": ["огонь по своим"],
    "дружество": ["дружба"],
    "дружечка": ["друженька", "дружка"],
    "дружив": ["друживши"],
    "друживши": ["дружив"],
    "дружина": ["рать"],
    "дружинив": ["дружинивши"],
    "дружинивши": ["дружинив"],
    "дружинить": ["дежурить"],
    "дружить": ["приятельствовать"],
    "дружка": ["шафер", "другой"],
    "дружко": ["дружка"],
    "дружно": ["ладом", "по-товарищески", "согласованно", "слаженно"],
    "дружный": ["дружеский", "слаженный", "согласованный"],
    "дружок": ["возлюбленный", "милый"],
    "дружок-пирожок": ["дружок", "друг"],
    "дружочек": ["дружок"],
    "друкарниця": ["друкарка"],
    "друм": ["път", "улица", "пътека"],
    "друмник": ["пътник", "скитник", "странник"],
    "друскининкай": ["друскеники", "друзгеники", "друзкеники"],
    "дръжка": ["ръчка", "хватка", "ръкохватка"],
    "дръзкост": ["дързост"],
    "дрыгав": ["дрыгавши"],
    "дрыгавши": ["дрыгав"],
    "дрыгнув": ["дрыгнувши"],
    "дрыгнувши": ["дрыгнув"],
    "дрызгав": ["дрызгавши"],
    "дрызгавши": ["дрызгав"],
    "дрызготня": ["дрызганье", "пачкотня", "бурда"],
    "дрын": ["дрына"],
    "дрыхав": ["дрыхавши"],
    "дрыхавши": ["дрыхав"],
    "дрыхнув": ["дрыхнувши"],
    "дрыхнувши": ["дрыхнув"],
    "дрыхнуть": ["дрыхать", "кемарить", "спать"],
    "дрэг-квин": ["драг-квин"],
    "дрю": ["эндрю"],
    "дрюкав": ["дрюкавши"],
    "дрюкавши": ["дрюкав"],
    "дрюкать": ["дрючить"],
    "дрючив": ["дрючивши"],
    "дрючивши": ["дрючив"],
    "дрябнув": ["дрябнувши"],
    "дрябнувши": ["дрябнув"],
    "дрягав": ["дрягавши"],
    "дрягавши": ["дрягав"],
    "дрягнув": ["дрягнувши"],
    "дрягнувши": ["дрягнув"],
    "дряква": ["цикламен"],
    "дрянной": ["паршивый", "поганый", "хреновый"],
    "дрянцо": ["дрязг", "хлам", "дрянь", "мусор", "отбросы"],
    "дрянь": ["дрязг", "барахло", "дребедень", "кака", "хлам", "пустяки", "ерунда", "гадость", "фигня", "паскуда", "мразь"],
    "дряхлев": ["дряхлевши"],
    "дряхлевши": ["дряхлев"],
    "дряхлый": ["ветхий", "обветшавший"],
    "дряхнув": ["дряхнувши"],
    "дряхнувши": ["дряхнув"],
    "дрёма": ["грёза", "дремота", "сонливость", "смолёвка"],
    "дсп": ["древесно-стружечная плита"],
    "дтп": ["дорожно-транспортное происшествие"],
    "дуала": ["камерун-сити", "камерунштадт"],
    "дуализировав": ["дуализировавши"],
    "дуализировавши": ["дуализировав"],
    "дуализм": ["двойственность"],
    "дуалистический": ["двойственный"],
    "дуатлет": ["дуатлонист"],
    "дуатлон": ["скиатлон"],
    "дуатлонист": ["дуатлет", "двоеборец"],
    "дубай": ["дибай", "дубайск"],
    "дубак": ["холод", "холодина", "холодрыга", "колотун", "дубняк", "мороз", "стужа"],
    "дубарь": ["дуб", "тупица", "дурак", "мертвец", "покойник", "труп"],
    "дубасив": ["дубасивши"],
    "дубасивши": ["дубасив"],
    "дубев": ["дубевши"],
    "дубевши": ["дубев"],
    "дубель-шлюпка": ["дубель-шлюп"],
    "дубенеть": ["мёрзнуть"],
    "дубеть": ["затвердевать", "коченеть", "тупеть"],
    "дубив": ["дубивши"],
    "дубивши": ["дубив"],
    "дубина": ["палица", "болван", "дурак", "балда"],
    "дубинала прописывать": ["прописывать дубинала"],
    "дубка": ["дубление", "выдубливание", "задубливание"],
    "дублет": ["дубль", "дубликат", "дуплет"],
    "дубликат": ["копия"],
    "дубликатор": ["дупликатор", "ризограф"],
    "дублировав": ["дублировавши"],
    "дублировавши": ["дублировав"],
    "дубль-негатив": ["дубльнегатив", "интернегатив", "контратип"],
    "дубль-трап": ["дабл-трап"],
    "дубляж": ["дублирование"],
    "дублёр": ["каскадёр"],
    "дубний": ["нильсборий"],
    "дубняк": ["дубрава", "холод", "холодина", "холодрыга", "колотун", "дубак", "мороз", "стужа"],
    "дубовик": ["поддубовик"],
    "дубоголовий": ["дубуватий", "туполобий", "обмежений"],
    "дубок": ["дубочек"],
    "дуболомный": ["бестолковый", "глупый", "ограниченный"],
    "дубонос": ["дубарь"],
    "дуботолк": ["глупец", "дурак"],
    "дубрава": ["дуброва"],
    "дуброва": ["дубрава"],
    "дубровник": ["стренатка"],
    "дубьё": ["рогатина", "дрекольё", "батожьё"],
    "дуван": ["делёжка", "делёж"],
    "дуванив": ["дуванивши"],
    "дуванивши": ["дуванив"],
    "дувши": ["дув"],
    "дуга": ["кривая", "загогулина", "бугель", "дуговой разряд", "электрическая дуга", "вольтова дуга", "ребро"],
    "дуговидный": ["дугообразный"],
    "дугообразный": ["кривой", "дугой", "изогнутый", "выгнутый", "лучковый", "дуговидный", "арочный", "полукруглый", "арковый", "криволинейный", "полуовальный", "сводчатый", "куполообразный", "согнутый", "луковидный"],
    "дудак": ["дрофа"],
    "дударь": ["дудочник"],
    "дудев": ["дудевши"],
    "дудевши": ["дудев"],
    "дудение": ["дудёж"],
    "дуденье": ["дудение"],
    "дудергофка": ["лига", "лиговка"],
    "дудив": ["дудивши"],
    "дудивши": ["дудив"],
    "дудки": ["чёрта с два", "фиг"],
    "дудлинг": ["грифонаж"],
    "дудонив": ["дудонивши"],
    "дудонивши": ["дудонив"],
    "дудонить": ["дудолить"],
    "дудочник": ["флейтист"],
    "дуду": ["цзянь-цзюнь"],
    "дудук": ["циранапох", "дудука"],
    "дудёж": ["дудение"],
    "дуел": ["двубой"],
    "дуется ширинка": ["ширинка дуется", "трещит ширинка"],
    "дужий": ["сильный", "крепкий", "здоровый"],
    "дузд": ["лас", "лус"],
    "дузина": ["дванадесет", "дванадесетка"],
    "дукер": ["хохлатая антилопа"],
    "дукля": ["диоклетия", "диоклея"],
    "дукхалыпэ": ["насвалыпэн"],
    "дукштас": ["дукшты"],
    "дулеб": ["невежа", "болван", "простофиля", "дурак", "остолоп"],
    "дульцин": ["сукроль"],
    "дульцинея": ["дама сердца"],
    "дуля": ["груша", "фига", "шиш", "кукиш"],
    "дума": ["мысль", "размышление", "раздумье", "парламент"],
    "думав": ["думавши"],
    "думавши": ["думав"],
    "думак": ["думец", "думовец", "депутан", "депутатишко"],
    "думати": ["мислити", "роздумувати", "метикувати", "гадкувати"],
    "думать": ["мыслить", "осмысливать", "обдумывать", "размышлять", "полагать", "считать", "находить", "рассматривать", "смотреть", "усматривать", "видеть", "предполагать", "задумывать", "замышлять", "намереваться"],
    "думать жопой": ["ошибаться", "жопой думать"],
    "думаться": ["казаться", "сдаваться", "представляться"],
    "думая": ["осмысливая", "обдумывая", "размышляя", "полагая", "считая", "находя", "рассматривая", "смотря", "усматривая", "видя", "предполагая", "задумывая", "замышляя", "намереваясь", "собираясь"],
    "думба": ["дунба"],
    "думбаз": ["чорбаджия", "богаташ"],
    "думец": ["госдумец", "госдумовец"],
    "думка": ["дума", "раздумье", "размышление"],
    "думник": ["речник", "словник", "думотълковник"],
    "думно": ["задумчиво"],
    "думскроллинг": ["думсёрфинг"],
    "думчиво": ["задумчиво"],
    "думчивый": ["задумчивый"],
    "думывав": ["думывавши"],
    "думывавши": ["думывав"],
    "дунай": ["истр"],
    "дунайский": ["истровский"],
    "дунапентеле": ["дунауйварош"],
    "дунауйварош": ["дунапентеле", "сталинварош"],
    "дунгъуз": ["болъон"],
    "дундук": ["дурак", "болван", "бестолочь", "балбес", "тупица"],
    "дунйа": ["дуньйа"],
    "дунне": ["космос"],
    "дуновенье": ["дуновение"],
    "дунув": ["дунувши"],
    "дунувши": ["дунув"],
    "дунуть": ["венуть"],
    "дунька": ["простушка", "свинушка"],
    "дунькин поясок": ["маруськин поясок"],
    "дуня": ["дуся", "тётка"],
    "дунё": ["олам"],
    "дуодециллион": ["додециллион", "додекальон"],
    "дуомо": ["собор"],
    "дупа": ["жопа", "попа", "срака"],
    "дуплекс": ["полный дуплекс", "дуплексная связь", "дуплекс-автотипия", "двухцветная печать", "дуплекс-сталь"],
    "дуплет": ["дублет"],
    "дупль": ["дупель", "дубель"],
    "дупля не отбить": ["опешить", "тупить"],
    "дуплянка": ["бездонка"],
    "дупчица": ["дупка", "трапчинка", "вдлъбнатина"],
    "дур": ["мажор"],
    "дура": ["балбеска", "идиотка", "кретинка", "тупица", "дурёха", "дурында", "дурочка с переулочка", "хреновина"],
    "дура набитая": ["идиотка"],
    "дурак": ["глупец", "недотёпа", "простофиля", "юродивый", "шут", "скоморох", "клоун"],
    "дурак в портупее": ["милиционер"],
    "дурак родился": ["милиционер родился", "мент родился"],
    "дураков": ["дураковский"],
    "дуранда": ["жмых", "избоина"],
    "дурахш": ["завъ"],
    "дурацкий": ["глупый", "неумный", "тупой"],
    "дурачив": ["дурачивши"],
    "дурачивши": ["дурачив"],
    "дурачина": ["дурак", "дуралей"],
    "дурачить": ["водить за нос", "оставлять в дураках", "выставлять на посмешище"],
    "дурашка": ["глупыш", "дурачок"],
    "дурашный": ["дурашливый"],
    "дурбар": ["дарбар"],
    "дурдом": ["цирк", "бардак"],
    "дурдомный": ["дурдомовский"],
    "дурев": ["дуревши"],
    "дуревши": ["дурев"],
    "дурень": ["глупец", "дурак", "дуралей", "дурачина", "олух", "балбес"],
    "дурепа": ["дуринда"],
    "дуреть": ["глупеть", "тупеть"],
    "дуриан": ["индийское хлебное дерево", "джекфрут", "канун"],
    "дурив": ["дуривши"],
    "дуривши": ["дурив"],
    "дурить": ["шалить", "баловаться", "дурачиться"],
    "дурка": ["психическое растройство", "сумасшествие", "помешательство", "умопомешательство", "неадекват", "неразбериха", "бедлам", "женская сумочка"],
    "дурман": ["датура", "самодуринский", "самодуринское"],
    "дурманив": ["дурманивши"],
    "дурманивши": ["дурманив"],
    "дурная болезнь": ["сифилис", "льюис", "французская болезнь", "скверная болезнь", "стыдная болезнь", "сиф", "сифак", "сифачина"],
    "дурнев": ["дурневши"],
    "дурневши": ["дурнев"],
    "дурний": ["нерозумний"],
    "дурника": ["голубика", "гонобобель", "гоноболь", "пьяника"],
    "дурно": ["плохо", "неприятно"],
    "дурновкус": ["дурновкусие", "дурновкусица", "дурновкусец"],
    "дурновкусие": ["безвкусица", "безвкусие", "дурновкусица"],
    "дурновкусица": ["безвкусица", "дурновкусие"],
    "дурное": ["плохое"],
    "дурной": ["плохой"],
    "дурной глаз": ["сглаз"],
    "дурны": ["тупы", "неразумны"],
    "дурным матом": ["благим матом", "божьим матом", "лихим матом", "недаровым матом", "непутным матом"],
    "дурогон": ["пустомеля", "пустозвон", "пустослов", "долдон"],
    "дуроломив": ["дуроломивши"],
    "дуроломивши": ["дуроломив"],
    "дурость": ["глупость", "тупость", "идиотизм"],
    "дурра": ["дурро", "майло"],
    "дурро": ["дурра"],
    "дурында": ["дура", "дурак"],
    "дурь": ["глупость", "сумасбродство", "наркотик"],
    "дурью маяться": ["маяться дурью"],
    "дус": ["иш", "аркадаш"],
    "дусман": ["душман"],
    "дуст": ["ддт"],
    "дуся": ["милочка", "душечка"],
    "дусятос": ["дусяты"],
    "дуть": ["веять"],
    "дуть в жопу": ["дуть в попу", "дуть в задницу", "в попу дуть", "в задницу дуть", "в жопу дуть"],
    "дуться": ["вздуваться", "натужиться"],
    "дуумвират": ["двойка", "двоевластие"],
    "дух": ["призрак", "привидение"],
    "духан": ["трактир", "харчевня", "шинок"],
    "духарив": ["духаривши"],
    "духаривши": ["духарив"],
    "духарить": ["душить"],
    "духариться": ["геройствовать", "храбриться", "горячиться", "ершиться", "задираться", "куражиться", "хорохориться", "веселиться", "дурачиться", "шалить", "баловаться", "озорничать", "развлекаться", "шалопайничать", "хулиганить"],
    "духаст вячеславович": ["духаст вячеславыч"],
    "духи": ["ароматизатор"],
    "духмяний": ["ароматний", "запашний", "пахучий"],
    "духмяны": ["пахучы"],
    "духмяный": ["ароматный"],
    "духобор": ["самоназвание", "духоборец", "полуариаин", "тропик", "марафониан"],
    "духоборец": ["духобор"],
    "духоборство": ["духоборчество"],
    "духоборчество": ["македонианство", "пневматомахия"],
    "духоведение": ["спиритизм", "теософия", "антропософия"],
    "духовик": ["духовое оружие", "пневматик"],
    "духовитый": ["пахучий", "душистый", "ароматичный", "запашистый"],
    "духовка": ["духовой шкаф"],
    "духовная пища": ["духовное брашно", "душевное брашно"],
    "духовник": ["священник"],
    "духовно богатая дева": ["дбд"],
    "духовное брашно": ["душевное брашно"],
    "духовность": ["душевность", "интеллектуальность", "религиозность", "церковность"],
    "духовные скрепы": ["устои", "традиционные ценности"],
    "духовный": ["душевный", "нравственный", "религиозный", "клерикальный"],
    "духовской": ["троицкая"],
    "духон": ["дуд"],
    "духоподъёмный": ["жизнеутверждающий"],
    "духота": ["нудность", "занудство", "занудствование"],
    "духотища": ["духота"],
    "духтарак": ["духтарча"],
    "духтарча": ["духтарак"],
    "дуче": ["вождь", "правитель", "каудильо", "фюрер"],
    "душ": ["рассекатель", "душевая"],
    "душа": ["сердце", "дух", "дорогой"],
    "душа в душу": ["дружно", "согласно"],
    "душа в пятки ушла": ["кровь стынет в жилах"],
    "душа горит": ["душа загорелась"],
    "душа нараспашку": ["весь наружу", "рубаха-парень", "душа нарастопашку"],
    "душа не на месте": ["сердце не на месте"],
    "душа с богом разговаривает": ["душа с богом беседует"],
    "душанбе": ["дюшамбе", "сталинабад"],
    "душевно": ["внутренне", "психически", "искренне", "духовно", "сердечно"],
    "душевнобольная": ["сумасшедшая", "помешанная", "умалишённая"],
    "душевнобольной": ["сумасшедший", "умалишённый", "помешанный"],
    "душевное брашно": ["духовное брашно"],
    "душевный": ["духовный"],
    "душевредный": ["душепагубный"],
    "душегуб": ["душегубец", "душегубитель", "душегубник"],
    "душегубец": ["душегуб", "убийца", "разбойник"],
    "душегубка": ["злодейка", "убийца"],
    "душегубство": ["убийство", "разбой"],
    "душепагубный": ["душевредный"],
    "душеполезный": ["душеспасительный"],
    "душераздирающий": ["раздирающий", "мучительный", "ужасный", "страшный", "раздирательный", "отчаянный", "истошный"],
    "душеспасительный": ["душеполезный"],
    "души не чаять": ["обожать"],
    "душив": ["душивши"],
    "душивши": ["душив"],
    "душиловка": ["духота"],
    "душистый": ["ароматный", "благоуханный", "благовонный", "духмяный", "духовитый", "душмяный", "душной"],
    "душитель": ["удушитель", "угнетатель"],
    "душить": ["давить", "подавлять"],
    "душица": ["материнка", "ладанка", "мацердушка", "душница", "зеновка", "кара гыных", "звирак", "тавшава", "орегано"],
    "душка": ["милашка"],
    "душлы": ["бутелица"],
    "душман": ["басмач"],
    "душник": ["отдушник", "отдушина"],
    "душнить": ["занудствовать", "надоедать", "утомлять", "изнурять", "угнетать", "измучивать", "подавлять"],
    "душный": ["нудный", "занудный", "тягомотный", "изнуряющий", "изнурительный", "гнетущий"],
    "душой и телом": ["вполне", "целиком и полностью"],
    "дуэлист": ["дуэлянт", "поединщик", "бретёр", "задира", "драчун"],
    "дуэль": ["сатисфакция", "поединок", "состязание", "борьба", "единоборство"],
    "дуэльный": ["поединковый"],
    "дуэлянт": ["дуэлист", "поединщик", "бретёр", "задира", "драчун"],
    "дуэлянтский": ["бретёрский"],
    "дуэт": ["двойка", "пара"],
    "дуюм": ["дувум"],
    "дхамма": ["дхарма"],
    "дханурасана": ["поза лука"],
    "дхарма": ["дхамма"],
    "дхнув": ["дхнувши"],
    "дхнувши": ["дхнув"],
    "дши": ["детская школа искусств", "детская школа-интернат", "декадно-шаговый искатель"],
    "дщерь": ["дочь", "дочка"],
    "дъждовник": ["саламандър", "дъждовен червей"],
    "дългуч": ["едър", "висок", "пораснал", "върлина"],
    "дължина": ["продълговатост", "удължение", "удълженост", "продължение", "протежение", "разстояние"],
    "дънер": ["пън", "дърво", "кютюк"],
    "дървар": ["дървосекач"],
    "държава": ["страна"],
    "държало": ["дръжка", "сап", "ръчка"],
    "дързост": ["неустрашимост", "безстрашие", "смелост", "наглост", "нахалство", "арогантност"],
    "дъщеря": ["щерка"],
    "дыбать": ["красть"],
    "дыбив": ["дыбивши"],
    "дыбивши": ["дыбив"],
    "дыбить": ["вздыбливать"],
    "дыбом": ["вертикально", "торчком", "дыбьём"],
    "дывэс": ["свэнко"],
    "дый": ["дий", "зевс"],
    "дык": ["так", "дак", "да", "ведь", "так ведь", "итак", "а то", "вот именно", "ясное дело"],
    "дым": ["чад", "смог", "угар", "курево", "табак", "дымка", "аэрозоль", "дымовьё", "дымовье", "дымовое"],
    "дым коромыслом": ["шум-гам", "дым столбом"],
    "дым столбом": ["анархия", "базар", "безалаберщина", "беспорядок", "бестолковщина", "бестолочь", "дым коромыслом", "кагал", "неразбериха", "неурядица", "свистопляска", "шум", "задымление"],
    "дымив": ["дымивши"],
    "дымивши": ["дымив"],
    "дымина": ["дым", "дымище"],
    "дымить": ["курить", "смолить"],
    "дымище": ["дымина"],
    "дымлы": ["сей"],
    "дымник": ["дымоход"],
    "дымный": ["дымящийся", "чадящий", "задымлённый", "лёгкий", "туманный", "дымчатый"],
    "дымовая завеса": ["дымзавеса"],
    "дымовая шашка": ["дымовуха"],
    "дымогарный": ["жаротрубный", "огнетрубный"],
    "дымоход": ["дымовая труба"],
    "дымоход развальцевать": ["развальцевать дымоход"],
    "дыра": ["дырка", "дырочка", "отверстие", "глухомань", "глушь", "захолустье", "медвежий угол", "пердь", "тьмутаракань", "брешь", "прореха"],
    "дырища": ["дыра", "дырка"],
    "дырка": ["дыра", "отверстие"],
    "дырка от бублика": ["от мёртвого осла уши", "рукава от жилетки"],
    "дырокол": ["дыропробиватель"],
    "дырчатый": ["дырявый"],
    "дырявая башка": ["дырявая голова", "дырявая память"],
    "дырявая голова": ["дырявая башка", "дырявая память", "склероз"],
    "дырявая память": ["дырявая башка", "дырявая голова"],
    "дырявив": ["дырявивши"],
    "дырявивши": ["дырявив"],
    "дырявые руки": ["руки как крюки", "руки-крюки"],
    "дырявый": ["прорванный", "продырявленный", "дырчатый"],
    "дырявый гондон": ["лопнутый гондон"],
    "дыхав": ["дыхавши"],
    "дыхавши": ["дыхав"],
    "дыхание": ["дыханье", "респирация"],
    "дыханье": ["дыхание"],
    "дыхнув": ["дыхнувши"],
    "дыхнувши": ["дыхнув"],
    "дышав": ["дышавши"],
    "дышавши": ["дышав"],
    "дышать нечем": ["ни вздохнуть ни охнуть", "ни охнуть ни вздохнуть", "хоть криком кричи", "хоть караул кричи", "хоть волком вой", "хоть головой бейся", "хоть головой об стену", "хоть головой об стену бейся", "хоть ложись да помирай", "хоть в петлю лезь", "хоть в гроб ложись", "ни вздохнуть ни пёрднуть", "ни пёрднуть ни вздохнуть", "ни вздохнуть ни пёрнуть", "ни пёрнуть ни вздохнуть"],
    "дьюар": ["сосуд дьюара"],
    "дьявол": ["сатана", "лукавый", "мерзавец", "негодяй", "подлец", "поганец"],
    "дьяволизм": ["чертовщина", "бесовщина", "сатанизм"],
    "дьявольщина": ["бесовщина", "чертовщина"],
    "дьяволёнок": ["чертёнок", "бесёнок"],
    "дьяк": ["дьячок", "псаломщик", "причётник"],
    "дьякон": ["диакон"],
    "дьяконив": ["дьяконивши"],
    "дьяконивши": ["дьяконив"],
    "дьяконствовав": ["дьяконствовавши"],
    "дьяконствовавши": ["дьяконствовав"],
    "дьячив": ["дьячивши"],
    "дьячивши": ["дьячив"],
    "дьячок": ["дьяк", "псаломщик", "причётник"],
    "дэв": ["див"],
    "дэвэ": ["тевя"],
    "дэвэл": ["свэнто муй"],
    "дэйин": ["дейинь"],
    "дэмир": ["тэмир"],
    "дэн": ["зула"],
    "дэниз": ["дэнъиз"],
    "дэнсив": ["дэнсивши"],
    "дэнсивши": ["дэнсив"],
    "дэнсить": ["танцевать"],
    "дэриэбинэ": ["тыа", "сэлиэнньэ"],
    "дэт": ["дэт-метал"],
    "дэт-метал": ["дэт"],
    "дэшка": ["дэшник", "дэшница"],
    "дэшуеня": ["биекхэскиро биш"],
    "дюбель": ["чопик"],
    "дюбка железная": ["самолёт"],
    "дювальеризм": ["дювальизм"],
    "дювальерист": ["дювальист"],
    "дювальизм": ["дювальеризм"],
    "дювальист": ["дювальерист"],
    "дюже": ["очень", "изрядно", "зело", "весьма"],
    "дюжев": ["дюжевши"],
    "дюжевши": ["дюжев"],
    "дюжеть": ["добреть", "жиреть", "плотнеть", "тучнеть"],
    "дюжив": ["дюживши"],
    "дюживши": ["дюжив"],
    "дюжий": ["сильный", "крепкий"],
    "дюжина": ["бортище"],
    "дюжинный": ["заурядный", "обыкновенный", "обычный", "рядовой"],
    "дюза": ["сопло"],
    "дюк": ["герцог"],
    "дюкесса": ["дюшесса"],
    "дюраль": ["дюралюминий"],
    "дюралюминий": ["дюраль", "дюралюмин"],
    "дюшамбе": ["душанбе", "сталинабад"],
    "дюшесса": ["герцогиня", "дюкесса"],
    "дягель": ["дягиль", "дудник"],
    "дягиль лекарственный": ["дудник лекарственный", "ангелик", "волчья дудка", "луговая дудка", "дудка", "дягильник", "дудник", "дягель", "дяглица", "дудел", "пушка"],
    "дягильник": ["дягиль"],
    "дяглый": ["ражий"],
    "дяденька": ["дядечка"],
    "дяденькин": ["дядечкин", "дядин"],
    "дядеёб": ["мудак", "пидор"],
    "дядо": ["старец", "старик", "дъртак", "тъст", "бабалък"],
    "дядя": ["дядька", "дядюшка", "дяденька", "дядёк", "мужчина", "мужик", "парень", "юноша", "батя", "дяпан"],
    "дятел": ["долдон", "попугай", "стукач"],
    "дёготь": ["берёзовая смола", "древесная смола", "хвойная смола"],
    "дёр": ["разрывание", "порка", "драп", "дёра"],
    "дёра": ["разрывание", "порка", "драп", "дёр"],
    "дёргав": ["дёргавши"],
    "дёргавши": ["дёргав"],
    "дёргать": ["выдёргивать"],
    "дёргать булками": ["шевелиться", "шевелить чулками", "шевелить колготками", "шевелить помидорами", "трясти булками", "шевелить булками"],
    "дёргивав": ["дёргивавши"],
    "дёргивавши": ["дёргивав"],
    "дёрдер": ["дёртер"],
    "дёрен": ["кизил"],
    "дёренные": ["дёреновые"],
    "дёреновые": ["дёренные"],
    "дёрн": ["дернина"],
    "дёрнув": ["дёрнувши"],
    "дёрнувши": ["дёрнув"],
    "дёртюньчю": ["дордунджи"],
    "дёсенный": ["десневой", "деснёвый"],
    "дёшево": ["недорого", "легко", "просто"],
    "е-принт": ["электронный препринт"],
    "еао": ["еврейская автономная область"],
    "еба": ["ебать", "ничего себе", "вот это да", "ну и ну", "обалдеть", "опупеть", "офигеть", "охренеть", "охереть", "ой-йо", "ё-моё", "ёба", "ебать-колотить", "ебать-молотить", "ебать-разъебать"],
    "ебабельный": ["вдувабельный"],
    "ебав": ["ебавши"],
    "ебавши": ["ебав"],
    "ебак": ["любовник", "ёбарь", "ебака", "ебатарь", "ебач", "ебец", "ебун", "ёбщик", "ебарёк", "ебарёчек"],
    "ебака": ["любовник", "ёбарь", "ебак", "ебатарь", "ебач", "ебец", "ебун", "ёбщик", "ебарёк", "ебарёчек"],
    "ебал я тебя в грызло": ["барал я тебя в грызло"],
    "ебала жаба гадюку": ["жаба у рака гнездо отняла"],
    "ебалайствовав": ["ебалайствовавши"],
    "ебалайствовавши": ["ебалайствовав"],
    "ебало офнуть": ["заткнуться", "завали ебало", "ебало офф", "ебало на ноль", "ебало завали"],
    "ебало свернуть": ["свернуть ебало", "в тряпочку ебало свернуть"],
    "ебальная": ["вертеп", "притон", "притон разврата", "бордель", "бардак", "бардачок", "бордельеро", "шалман", "заведение", "весёлый дом", "розовый дом", "непотребный дом", "дом терпимости", "дом под красным фонарём", "дом ебли"],
    "ебальник просрать": ["просрать ебальник", "выхватить по ебальнику", "выхватить по еблу", "выхватить по ебалу", "по ебальнику выхватить", "по еблу выхватить", "по ебалу выхватить"],
    "ебальный": ["трахательный"],
    "ебальня": ["вертеп", "притон", "притон разврата", "бордель", "бардак", "бардачок", "бордельеро", "шалман", "заведение", "весёлый дом", "розовый дом", "непотребный дом", "дом терпимости", "дом под красным фонарём", "дом ебли"],
    "ебан": ["кретин", "дурак", "идиот", "ушлёпок", "ебаноид", "ебанутик", "ебанатик", "уёбан", "уёбок", "пиздец"],
    "ебанат": ["чудак", "ебанатик"],
    "ебанатик": ["чудак", "чудик", "ебанат", "ебанавт", "ебанутый", "ебанушка", "ёбнутый"],
    "ебание": ["ебанье"],
    "ебанизм": ["умопомешательство", "безумие", "ебанутость"],
    "ебано": ["хуёво"],
    "ебаноид": ["ебалай", "ебан", "ебанавт", "ебанат", "ебанатик", "ебанашка", "ебанутик", "ебанушка", "ебандяй", "ебантей", "ебанько", "еблан", "еблито", "ебобо", "ебундей"],
    "ебанув": ["ебанувши"],
    "ебанувши": ["ебанув"],
    "ебанутость": ["долбанутость", "чеканутость", "шизанутость"],
    "ебанутый": ["ненормальный", "чокнутый", "с приветом", "не в себе", "не все дома", "придурковатый", "с придурью", "долбанутый", "припизднутый", "припизженный", "с припиздью"],
    "ебануть": ["ебнуть", "хренакнуть", "херакнуть", "ёбнуть", "хуякнуть", "пиздануть", "жахнуть", "намахнуть", "замахнуть", "дёрнуть", "дерябнуть", "шлёпнуть", "наебнуть"],
    "ебануть в бороду": ["выпить", "намахнуть", "замахнуть", "дёрнуть", "дерябнуть", "шлёпнуть", "ёбнуть", "наебнуть"],
    "ебануться": ["ёбнуться", "хуйнуться", "пиздануться", "наебнуться"],
    "ебанушка": ["ебанашка", "ебанатик", "ебанутик", "ёбик"],
    "ебаный": ["ёбаный"],
    "ебанье": ["ебание"],
    "ебанько": ["ебанат", "ебанатка"],
    "ебаришка": ["бойфренд"],
    "ебарёк": ["хахаль", "хахарь"],
    "ебарёчек": ["хахаль", "хахарь"],
    "ебати": ["бить", "колотить", "колошматить", "наяривать", "хуярить"],
    "ебать": ["выносить взыскание", "стимулировать", "интересовать", "беспокоить", "трогать", "затрагивать"],
    "ебать мозги": ["надоедать", "морочить"],
    "ебать мой хуй ментовской жопой": ["ебать мой лысый череп"],
    "ебаться": ["возиться", "копаться", "канителиться", "трахаться", "коноёбиться", "вкалывать", "пахать", "впахивать", "мантулить", "упираться", "горбатиться", "ишачить", "въёбывать", "въябывать"],
    "ебач": ["ёбарь", "ебака", "ебак"],
    "ебашив": ["ебашивши"],
    "ебашивши": ["ебашив"],
    "ебашить": ["ебошить", "хуячить", "ебашить в кашу", "ебашашить", "вкалывать"],
    "ебейший": ["впечатляющий", "потрясающий", "охуительный", "охуетительный", "опизденительный"],
    "ебенив": ["ебенивши"],
    "ебенивши": ["ебенив"],
    "ебеня": ["захолустье", "глухомань"],
    "ебись оно всё конём": ["гори оно всё синим пламенем"],
    "ебиться сердце перестало": ["и биться сердце перестало"],
    "ебический": ["неебический"],
    "ебишка": ["ивашка", "скороёбишка"],
    "еблан": ["ничтожество", "баклан", "болван", "дурак", "тупица", "кретин", "мудак", "мудила"],
    "ебланив": ["ебланивши"],
    "ебланивши": ["ебланив"],
    "ебланить": ["дурачиться"],
    "еблец": ["торец", "ебало", "ебальник", "ебальничек", "ебальце", "ебач", "ебельник", "ебло", "еблина", "еблище", "ебучка", "ебушатня", "ёбыч"],
    "еблито": ["неумейка", "неумеха", "неумёха"],
    "ебло стянуть": ["замолкнуть", "заткнуться", "закрыть ебло", "завалить ебло", "стянуть ебло", "ебло на ноль", "ебло закрыть", "ебло завалить"],
    "ебловать": ["щёлкать еблом", "еблом щёлкать"],
    "ебля": ["канитель"],
    "ебнув": ["ебнувши"],
    "ебнувши": ["ебнув"],
    "ебнуть": ["ебануть"],
    "ебня": ["канитель"],
    "ебобо": ["ёбнутый", "ебанутый"],
    "ебоглазить": ["пялиться", "глазеть"],
    "ебота": ["коитус", "совокупление", "половой акт", "трах", "ебля", "ёбля", "поебушка", "фигня", "херня", "хуета", "поебень", "ерунда", "чушь", "дрянь", "еботень"],
    "ебота на еботе": ["дрянь", "шваль", "хуета на хуете"],
    "ебошив": ["ебошивши"],
    "ебошивши": ["ебошив"],
    "ебукав": ["ебукавши"],
    "ебукавши": ["ебукав"],
    "ебун": ["блядун"],
    "ебунев": ["ебуневши"],
    "ебуневши": ["ебунев"],
    "ебунеть": ["коченеть"],
    "ебур": ["ебака", "ебатарь", "ебец", "ебун", "ёбарь", "ёбщик", "ебач"],
    "ебучесть": ["ебливость", "ёбкость"],
    "ебёна мать": ["сучий потрох"],
    "ебёный": ["японый", "ядрёный", "сраный", "говённый", "хуёвый"],
    "ев": ["евши"],
    "евакувати": ["евакуювати"],
    "евакуювати": ["евакувати"],
    "евангелик": ["евангелист"],
    "евангелион": ["ева"],
    "евангеличка": ["протестантка"],
    "евангельски": ["как", "евангелие", "по-евангельски", "в соответствии с"],
    "евбея": ["эвбея"],
    "евгений": ["женя", "жека", "женька", "женёк", "женечка"],
    "евгения": ["женя", "женечка", "женёк", "женька"],
    "евгерья": ["евгерия"],
    "евдошка": ["умбра обыкновенная", "собачья рыба"],
    "евклид": ["эвклид"],
    "евклидов": ["эвклидов"],
    "евнухоидизм": ["дисгенитализм", "синдром"],
    "евойный": ["евонный", "евошний"],
    "евонный": ["его", "евойный", "евошний"],
    "евошний": ["евонный"],
    "евпатория": ["козлов"],
    "евпатрид": ["эвпатрид"],
    "евпл": ["еупл", "евпол"],
    "евпраксия": ["апраксея", "апракса", "апраксия", "апраксинья", "апраксения", "опраксея", "опроксинья", "опросинья", "праксея"],
    "еврамерика": ["лавруссия", "евроамерика"],
    "евреизация": ["заевреивание"],
    "еврей": ["аид", "израэлит", "иудей", "иудаист", "израильтянин", "маланец", "хасид", "жид", "обрезок"],
    "еврейка": ["еврейская автономная область"],
    "еврейская автономная область": ["еао", "еврейка"],
    "еврейское агентство": ["сохнут"],
    "еврик": ["евро"],
    "евро-атлантический регион": ["евроатлантика"],
    "евробляха": ["бляха"],
    "евробляхарь": ["бляхер", "евробляхер"],
    "евробляхер": ["бляхер", "евробляхарь"],
    "евробонд": ["еврооблигация"],
    "евробондовый": ["еврооблигационный"],
    "евробюрократ": ["еврократ", "еврочиновник"],
    "евровагонка": ["вагонка"],
    "евровинт": ["конфирмат"],
    "евродепутат": ["европарламентарий"],
    "еврократ": ["еврочиновник", "евробюрократ"],
    "еврократия": ["евробюрократия"],
    "евромайдан": ["еврореволюция", "революция достоинства"],
    "еврооблигационный": ["евробондовый"],
    "еврооблигация": ["евробонд"],
    "европарламентарий": ["евродепутат"],
    "европеизация": ["оевропеивание", "европейскость"],
    "европеизировав": ["европеизировавши"],
    "европеизировавши": ["европеизировав"],
    "европеизм": ["европейскость", "европейство"],
    "европеизовав": ["европеизовавши"],
    "европеизовавши": ["европеизовав"],
    "европеизовать": ["европеизировать"],
    "европейничав": ["европейничавши"],
    "европейничавши": ["европейничав"],
    "европейская комиссия": ["еврокомиссия", "ек"],
    "европейски": ["по-европейски", "как", "европе"],
    "европейский анчоус": ["хамса"],
    "европейский парламент": ["европарламент", "еп"],
    "европейский союз": ["ес", "евросоюз"],
    "европеоид": ["европеец", "белый человек"],
    "европеоидная раса": ["евразийская раса", "кавказская раса"],
    "европеянин": ["европеец"],
    "европеянка": ["европейка"],
    "европлата": ["еврокарта"],
    "европоцентризм": ["евроцентризм"],
    "европоцентристский": ["европоцентрический"],
    "европоцентрический": ["европоцентристский"],
    "европский": ["европейский"],
    "евросодом": ["гейропа"],
    "евросоединитель": ["соединитель", "переходник", "коннектор"],
    "евросоюз": ["европейский союз", "ес"],
    "евросоюзный": ["евросоюзовский"],
    "евросоюзовский": ["евросоюзный"],
    "евростандартизировав": ["евростандартизировавши"],
    "евростандартизировавши": ["евростандартизировав"],
    "евросуд": ["страсбургский суд"],
    "еврот": ["эвротас"],
    "евроукраинец": ["евроукр"],
    "евроцентризм": ["европоцентризм"],
    "еврочиновник": ["евробюрократ", "еврократ"],
    "евроэнтузиаст": ["еврооптимист"],
    "евсей": ["евсевий", "авсей", "овсей", "евсий", "ивсей"],
    "евстахиева труба": ["слуховая труба"],
    "евстахиит": ["тубоотит", "сальпингоотит"],
    "евтерпа": ["эвтерпа"],
    "евтихий": ["евтифий", "евтифей"],
    "евфратовский": ["евфратский"],
    "евхаристия": ["причащение", "причастие"],
    "евши": ["ев"],
    "егда": ["когда", "ежели", "если", "коли", "коль"],
    "егерь": ["охотовед", "охотник", "стрелок"],
    "египет": ["арабская республика египет", "аре", "страна пирамид"],
    "египетский": ["древнеегипетский"],
    "египетский язык": ["древнеегипетский язык"],
    "египтизация": ["египтизирование"],
    "его": ["евонный", "евошний", "евойный"],
    "егоза": ["непоседа", "юла", "вертун", "попрыгун", "вертунья", "попрыгунья", "стрекоза"],
    "егозив": ["егозивши"],
    "егозивши": ["егозив"],
    "егозить": ["вертеться", "крутиться", "елозить", "мельтешить", "проказить", "озорничать", "шалить", "суетиться", "нервничать", "беспокоиться", "волноваться", "угодничать", "подлизываться", "подхалимничать", "заискивать"],
    "егозливо": ["непоседливо", "суетливо"],
    "егозливый": ["непоседливый"],
    "егоизъм": ["себелюбие"],
    "егор": ["егорий", "георгий", "юрий", "жорж", "егорка", "егорша", "егорушка", "егорочка", "егорчик"],
    "егорович": ["егорьевич", "георгиевич", "юрьевич"],
    "егошиха": ["ягошиха"],
    "егылырга": ["аварга"],
    "еда": ["питание", "трапеза", "кормление", "приём пищи", "поглощение пищи", "блюдо", "кушанье"],
    "едав": ["едавши"],
    "едавши": ["едав"],
    "едальня": ["столовая", "закусочная", "ресторан", "кухмистерская"],
    "едва": ["едва-едва", "насилу", "еле", "еле-еле", "с трудом", "чуть", "слегка", "чуть-чуть", "только", "как только"],
    "едва ли": ["вряд ли", "маловероятно", "навряд ли", "сомнительно"],
    "едва ли не": ["чуть ли не", "пожалуй"],
    "едва ль": ["едва ли", "сомнительно", "вряд ли"],
    "едва помнить себя": ["не помнить себя"],
    "едва-едва": ["с трудом", "еле-еле", "кое-как", "насилу", "чуть-чуть", "слегка", "лишь только", "только что", "чуть только"],
    "едва-едва не": ["чуть не", "почти"],
    "едем": ["эдем"],
    "единадесет": ["единайсет"],
    "единая россия": ["ер", "едро", "партия жуликов и воров", "едим россию", "пжив"],
    "единение": ["сплочение", "объединение", "сплочённость", "единство"],
    "единец": ["единцы"],
    "единив": ["единивши"],
    "единивши": ["единив"],
    "единица": ["мера", "один", "подразделение", "отдел", "штука", "экземпляр", "предмет", "кол"],
    "единица измерения": ["единица физической величины", "единица величины"],
    "единица языка": ["языковая единица"],
    "единичная матрица": ["единица"],
    "единичник": ["колышник"],
    "единичница": ["колышница"],
    "единобожие": ["монотеизм"],
    "единоборствовав": ["единоборствовавши"],
    "единоборствовавши": ["единоборствовав"],
    "единобрачие": ["моногамия"],
    "единовластвовав": ["единовластвовавши"],
    "единовластвовавши": ["единовластвовав"],
    "единовластье": ["единовластие"],
    "единовременно": ["сразу", "враз", "зараз", "симультанно", "одновременно"],
    "единовременность": ["однократность", "одновременность"],
    "единовременный": ["разовый", "одновременный"],
    "единогласно": ["единодушно"],
    "единодержавие": ["единодержавство", "самодержавие", "монархия"],
    "единодержавно": ["самодержавно", "монархически"],
    "единодержавность": ["единодержавие", "единодержавство", "самодержавие"],
    "единодержец": ["самодержец"],
    "единодушие": ["единомыслие"],
    "единодушно": ["единогласно", "согласно", "хором"],
    "единодушный": ["единогласный", "общий"],
    "единодушье": ["единодушие"],
    "единожды": ["однажды", "разик", "разок"],
    "единозвучность": ["монотонность", "однозвучность"],
    "единоземец": ["земляк"],
    "единоличник": ["крестьянин-единоличник", "эгоист"],
    "единомыслие": ["согласие", "единство", "единодушие", "единогласие"],
    "единомыслящий": ["единомысленный"],
    "единомышленник": ["союзник", "сторонник", "соучастник"],
    "единомышленница": ["соратница"],
    "единоначалие": ["единоличие", "единовластие"],
    "единоначатие": ["анафора"],
    "единообразив": ["единообразивши"],
    "единообразивши": ["единообразив"],
    "единообразие": ["единообразность", "однородность", "одинаковость", "совпадение", "однообразие", "однообразность"],
    "единообразить": ["унифицировать", "однообразить", "уоднообразить"],
    "единообразность": ["единообразие"],
    "единоплеменник": ["соплеменник"],
    "единоразово": ["однократно", "единовременно"],
    "единоразовый": ["однократный", "единовременный"],
    "единорог": ["инорог", "нарвал", "морской единорог", "индийский носорог", "единоросс"],
    "единоросс": ["едрос", "единовброс", "единорог"],
    "единость": ["единство"],
    "единственность": ["сингулярность"],
    "единственный": ["уникальный", "единичный", "неповторимый", "исключительный"],
    "единственный в своём роде": ["уникальный", "неповторимый", "исключительный"],
    "единство": ["единость", "совпадение", "общность"],
    "единцы": ["единец"],
    "единый государственный экзамен": ["егэ"],
    "едкий": ["каустический", "злой", "обидный", "резкий"],
    "едкий натр": ["едкое кали"],
    "едкое кали": ["едкий натр"],
    "еднородност": ["сходство", "подобие"],
    "едок": ["рот"],
    "едом": ["эдом"],
    "едома": ["глушь", "пустошь"],
    "едрив": ["едривши"],
    "едривши": ["едрив"],
    "едрина": ["големина", "величина", "дебелина", "размер"],
    "едрить": ["еть", "ебать"],
    "едрос": ["единоросс"],
    "едрёна репа": ["ядрёна репа"],
    "едрёный": ["ядрёный"],
    "едучий": ["едкий"],
    "едя": ["едучи"],
    "еж": ["таралеж"],
    "ежак": ["дикобраз", "ёж"],
    "ежба": ["вражда", "разпра", "крамола", "кавга", "караница", "раздор"],
    "еже": ["которое"],
    "еже-": ["каждо-"],
    "ежевика": ["куманика", "ожина", "ажина"],
    "ежеголовник": ["ежеголовка"],
    "ежедневник": ["органайзер"],
    "ежедневно": ["каждодневно", "ежесуточно", "ежедённо"],
    "ежедневный": ["каждодневный", "постоянный", "повседневный"],
    "ежежды": ["каждый раз"],
    "ежеквартальный": ["поквартальный"],
    "ежели": ["ежель", "если", "кабы", "коли", "раз", "раз уж", "когда", "при условии", "в случае"],
    "ежели бы": ["если бы", "кабы"],
    "ежель": ["ежели"],
    "ежемесячно": ["каждомесячно", "помесячно"],
    "ежемесячный": ["каждомесячный"],
    "ежеминутно": ["постоянно"],
    "ежеминутный": ["ежесекундный", "ежечасный"],
    "ежемуха": ["тахина"],
    "еженедельно": ["понедельно"],
    "еженедельный": ["каждонедельный"],
    "еженочно": ["еженощно"],
    "еженощно": ["еженочно"],
    "еженощный": ["еженочный"],
    "ежесекундный": ["ежеминутный", "ежечасный"],
    "ежесуточно": ["ежедневно"],
    "ежесуточный": ["посуточный", "ежедневный"],
    "ежечасный": ["ежеминутный", "ежесекундный"],
    "ежиный": ["ежовый"],
    "ежовщина": ["большой террор"],
    "ежовый": ["ежиный", "колючий"],
    "ежом": ["бирюком", "букой", "бычком", "волком", "враждебно", "дико", "настороженно", "нелюдимо", "необходительно", "необщительно", "ощетинясь", "сентябрём", "сторонясь", "угрюмо", "хмуро"],
    "ез": ["частокол", "плетень"],
    "езда": ["поездка"],
    "ездив": ["ездивши"],
    "ездивши": ["ездив"],
    "ездить в тулу со своим самоваром": ["в лес дрова возить"],
    "ездить по ушам": ["втирать в уши", "вешать лапшу на уши", "пудрить мозги", "вкручивать", "впаривать"],
    "ездок": ["наездник", "водитель", "шофёр"],
    "ездра": ["эзра"],
    "ездюк": ["ездок", "ездун"],
    "езекия": ["хизкия", "хизкияу", "хизкиягу", "айзекайя"],
    "езжав": ["езжавши"],
    "езжавши": ["езжав"],
    "езживав": ["езживавши"],
    "езживавши": ["езживав"],
    "езид": ["язид", "йезид"],
    "езидизм": ["йезидизм", "езидство", "шарфадинизм"],
    "езичник": ["идолопоклонник"],
    "езнас": ["езна"],
    "езопствовав": ["езопствовавши"],
    "езопствовавши": ["езопствовав"],
    "ей-богу": ["вот те крест", "ей-ей", "ей-же-ей", "клянусь", "честное слово", "право слово"],
    "ей-ей": ["ей-богу", "забодай меня комар", "укуси корова"],
    "екатерина": ["катерина", "катя", "катюша", "катенька", "катёнок", "катька", "катюха", "кэт", "катрин"],
    "екатеринбург": ["свердловск", "ёбург", "столица урала"],
    "екатеринбургский": ["екатеринбуржский"],
    "екатеринбуржец": ["свердловчанин", "свердловец"],
    "екатеринбуржский": ["екатеринбургский"],
    "екатеринка": ["екатериновка"],
    "екатеринодар": ["краснодар"],
    "екатеринодарский": ["краснодарский"],
    "екатеринослав": ["днепр", "днепропетровск", "новороссийск"],
    "екзопланета": ["извънслънчева планета"],
    "екзотичен": ["екзотически"],
    "еким": ["иаким", "аким", "яким", "иоаким"],
    "екклезиаст": ["екклесиаст", "когэлет", "книга проповедника"],
    "ектенья": ["ектения", "эктения"],
    "елань": ["чаруса"],
    "елгава": ["митава"],
    "елда": ["член", "пенис", "хуй", "уд", "елдак", "дура", "шишак"],
    "елдак": ["елда", "елданка", "елдан", "елдачина", "елдачок", "елдач", "елдаш", "елдень", "елдометр", "елдык", "елдырина", "елдырь", "елдышек", "елдышка", "елдыш"],
    "елдачив": ["елдачивши"],
    "елдачивши": ["елдачив"],
    "еле": ["с трудом", "насилу", "едва", "чуть", "лишь только", "как только", "слабо"],
    "еле-еле": ["еле", "едва", "едва-едва"],
    "елеазар": ["елазар", "эльазар", "елизар", "лазарь"],
    "елей": ["олей", "олия", "деревянное масло", "бальзам", "бальзам на сердце", "утешение", "лесть"],
    "елена": ["лена", "ленка", "ленок", "олёна"],
    "еленовка": ["оленовка", "севан"],
    "еленополис": ["еленополь", "дабурия"],
    "еленополь": ["дрепан", "элейнуполь"],
    "елеосвящение": ["соборование"],
    "елизавета": ["елисавета", "лизавета", "лиза"],
    "елико": ["сколько", "насколько", "колико"],
    "елико возможно": ["по мере сил"],
    "еликонида": ["ликонида", "конида"],
    "елим": ["элим", "илима"],
    "елисейский дворец": ["париж"],
    "елман": ["елмань"],
    "елозив": ["елозивши"],
    "елозивши": ["елозив"],
    "елозить": ["ёрзать", "юлозить"],
    "елорда": ["астана"],
    "елушник": ["ельник", "ельняк", "ельняжник", "иван-чай", "кипрей"],
    "ель": ["рузгяр"],
    "ельник": ["ельняк", "елушник", "ельняжник", "еловый", "лапник", "еловая", "хвоя"],
    "ельняк": ["ельник", "елушник", "ельняжник"],
    "ельцинец": ["ельцинист"],
    "ельцинизм": ["ельцинщина"],
    "ельцинист": ["ельцинец"],
    "ельцинский": ["ельциновский"],
    "ельцинско-гайдаровский": ["гайдаровско-ельцинский"],
    "ельцинщина": ["ельцинизм"],
    "емать": ["ничего себе", "вот это да", "ну и ну", "обалдеть", "опупеть", "офигеть", "охренеть", "охереть", "ой-йо", "ё-моё", "ебать", "ёба", "еба", "ебать-колотить", "ебать-молотить"],
    "емелив": ["емеливши"],
    "емеливши": ["емелив"],
    "емельянович": ["емельяныч"],
    "емеля": ["мыло"],
    "еменка": ["яменка"],
    "емлив": ["емливши"],
    "емливши": ["емлив"],
    "емлить": ["емить", "имать"],
    "емшек": ["мама"],
    "ендова": ["овраг", "степное блюдце", "разжелобок", "братина"],
    "енисеец": ["кет", "остяк"],
    "еничар": ["еничарин"],
    "енол": ["алкенол"],
    "енот-полоскун": ["американский енот"],
    "енотка": ["енотиха"],
    "енэ": ["бира"],
    "енэкъокъун": ["нэкъокъон"],
    "енядэша": ["бидэшэнгиро шэл"],
    "епакта": ["эпакта", "эпакт"],
    "епанечка": ["душегрея", "епанча"],
    "епанча": ["епанечка"],
    "епархия": ["диоцез", "сфера"],
    "епгу": ["госуслуга"],
    "епидемиология": ["епидемология"],
    "епиподий": ["эпиподий", "епипод", "эпипод"],
    "епископ": ["архиерей", "архипастырь", "иерарх"],
    "епископальный": ["епископский"],
    "епископат": ["епископство"],
    "епископствовав": ["епископствовавши"],
    "епископствовавши": ["епископствовав"],
    "епитимийник": ["номоканон"],
    "епитимия": ["епитимья", "эпитимия"],
    "епичен": ["епически"],
    "ер": ["едро"],
    "ера": ["ёрник", "забияка"],
    "ерак": ["озак"],
    "ерань": ["герань"],
    "ерга": ["ёрга"],
    "ергак": ["яргак", "ергач", "доха"],
    "ерген": ["неженен", "бекяр", "лефтер"],
    "ереван": ["эребуни", "эривань"],
    "еремит": ["анахорет"],
    "ерепениться": ["артачиться", "бычиться", "ершиться", "кобениться", "ломаться", "противиться", "упрямиться", "упорствовать", "вздорить", "щетиниться", "упираться", "хорохориться", "ерошиться", "ерихониться"],
    "еретик": ["вероотступник", "богоотступник", "отступник", "пустосвят", "бунтарь", "маргинал", "возмутитель спокойствия", "инакомыслящий", "крамольник"],
    "ерзанув": ["ерзанувши"],
    "ерзанувши": ["ерзанув"],
    "ерзунчик": ["ерзунок", "ползунок"],
    "ерик": ["ложбинка", "канавка", "арык"],
    "еркек": ["ер"],
    "ермолка": ["скуфья"],
    "ермон": ["хермон"],
    "ермос": ["ирмос"],
    "ерок": ["ерик", "паерок", "воос", "ерец", "ерик верхний", "ерица", "ертица", "ерчик", "овос", "паерк", "пооксь", "речник", "кендема"],
    "ерошив": ["ерошивши"],
    "ерошивши": ["ерошив"],
    "ерошить": ["взлохмачивать", "взъерошивать", "вихорить", "лохматить", "растрёпывать", "топорщить"],
    "ерунда": ["мелочь", "пустяк", "фигня"],
    "ерундив": ["ерундивши"],
    "ерундивши": ["ерундив"],
    "ерундистика": ["ерунда", "вздор", "чепуха", "бессмыслица", "нелепость"],
    "ерундовский": ["ерундистый", "ерундовый"],
    "ерундовый": ["чепуховый"],
    "ерушалаим": ["иерусалим", "ершалаим", "аль-кудс"],
    "ершалаим": ["иерусалим"],
    "ершив": ["ершивши"],
    "ершивши": ["ершив"],
    "ершистый": ["всклокоченный", "взъерошенный", "задиристый"],
    "ершиться": ["ерошиться", "топорщиться"],
    "ершоватка": ["лиманда"],
    "ес": ["да"],
    "есаул": ["ротмистр", "капитан"],
    "есения": ["есеня"],
    "если": ["ежели", "кабы", "коли", "коль", "буде", "раз", "раз уж", "когда", "при условии", "в случае"],
    "если бы": ["ежели бы", "кабы"],
    "если бы да кабы": ["абы да кабы"],
    "ессей": ["оссин", "кумранит"],
    "ессентуки": ["нарзан", "боржоми", "боржом"],
    "ессно": ["разумеется", "конечно"],
    "ест": ["естонець"],
    "естественник": ["естествовед"],
    "естественница": ["естествоиспытательница", "натуралистка", "физика"],
    "естественно": ["нормально", "обычно", "непринуждённо", "разумеется", "конечно"],
    "естественнонаучный": ["естественно-научный"],
    "естественность": ["натуральность"],
    "естественный": ["природный", "нормальный"],
    "естество": ["суть", "природа", "натура"],
    "естествовед": ["естествоиспытатель", "естественник", "натуралист"],
    "естествознание": ["естествоведение"],
    "естествоиспытатель": ["натуралист", "природовед"],
    "естествоиспытательница": ["натуралистка"],
    "естествослов": ["натуралист", "естествоиспытатель", "естествословец", "естественник"],
    "естрагоновий": ["тархуновий"],
    "есть глазами": ["пожирать глазами"],
    "есть поедом": ["сживать со свету", "поедом есть", "со свету сживать"],
    "етив": ["етивши"],
    "етивши": ["етив"],
    "етись": ["сношаться", "ебаться", "ебстись"],
    "ефес": ["эфес"],
    "ефесский": ["эфесский"],
    "ефикасност": ["действеност", "резултатност"],
    "ефимович": ["ефимыч"],
    "ефод": ["эфод"],
    "ефрем": ["ефраим", "эфраим"],
    "ефросиния": ["ефросинья"],
    "ефросинья": ["ефросиния", "евфросиния", "евфросинья"],
    "ехав": ["ехавши"],
    "ехавши": ["ехав"],
    "ехида": ["ехидина"],
    "ехидина": ["ехида"],
    "ехиднаэдр": ["полная форма икосаэдра", "завершающая форма икосаэдра"],
    "ехидник": ["язва"],
    "ехидничав": ["ехидничавши"],
    "ехидничавши": ["ехидничав"],
    "ехидничанье": ["ехидничание"],
    "ехидничать": ["ехидствовать", "язвить", "насмехаться"],
    "ехидно": ["колко", "едко", "ядовито", "с насмешкой", "саркастически", "желчно", "иронично", "иронически", "язвительно", "насмешливо", "злорадно", "коварно"],
    "ехидный": ["язвительный", "злобный", "колкий", "хитрый", "насмешливый"],
    "ехидство": ["язвительность", "сарказм", "злорадство"],
    "ехидствовав": ["ехидствовавши"],
    "ехидствовавши": ["ехидствовав"],
    "ехидствовать": ["высмеивать", "ехидничать", "злорадствовать"],
    "ехтеж": ["кънтеж", "екот", "грохот", "ек", "ехо"],
    "ешка": ["ешник"],
    "ещё": ["более-менее", "относительно", "хоть", "хотя бы"],
    "ещё бы": ["конечно", "безусловно"],
    "ещё туда-сюда": ["сойдёт", "ещё ничего", "годится", "не так плохо", "не так страшно", "бывает и хуже", "удовлетворительно", "допустимо"],
    "её": ["ейный", "еёшный"],
    "жаба": ["пипа", "лягушка"],
    "жаба-повитуха": ["обыкновенная повитуха"],
    "жаба-рыба": ["рыба-жаба"],
    "жабный": ["жабий"],
    "жабообразные": ["батрахообразные"],
    "жабоподобный": ["жабообразный"],
    "жабра": ["жабры", "жаберки"],
    "жабрачыць": ["жабраваць"],
    "жабрей": ["пикульник", "зябра", "льнянка"],
    "жабровав": ["жабровавши"],
    "жабровавши": ["жабровав"],
    "жабровидный": ["жаброобразный", "жаброподобный"],
    "жабры": ["жаберки"],
    "жабры горят": ["трубы горят", "шланги горят"],
    "жабурниця": ["скойка"],
    "жав": ["жавши"],
    "жавальная гумка": ["жуйка"],
    "жавель": ["жавелевая вода"],
    "жаворонок": ["ранняя пташка"],
    "жавороночий": ["птичий"],
    "жавши": ["жав"],
    "жага": ["спрага", "жагота"],
    "жагота": ["жага", "спрага"],
    "жадати": ["бажати"],
    "жадина-говядина": ["жадина", "жадюга", "жмот"],
    "жаднев": ["жадневши"],
    "жадневши": ["жаднев"],
    "жадничав": ["жадничавши"],
    "жадничавши": ["жадничав"],
    "жадничать": ["скряжничать", "скупиться", "жилиться", "жмотничать", "жаждать", "стремиться"],
    "жадно": ["ненасытно", "алчно", "быстро", "сразу"],
    "жадность": ["алчность", "скупость", "жажда", "ненасытность"],
    "жадный": ["алчный", "ненасытный", "скупой", "скаредный", "страстный"],
    "жадоба": ["жадность", "алчность", "скупость", "скаредность", "скряжничество", "сквалыжничество", "скупердяйство", "ненасытность", "жадина", "скупец", "плюшкин", "жадюга", "жмот", "жмотяра", "жлоб"],
    "жажда": ["полидипсия", "гидромания", "сушняк", "трубы горят", "стремление", "страсть", "вожделение", "охота", "хотение", "хотенье"],
    "жаждав": ["жаждавши"],
    "жаждавши": ["жаждав"],
    "жаждать": ["стремиться", "хотеть"],
    "жазгыч": ["калемсап"],
    "жаздык": ["балыш"],
    "жазуучу": ["жазгыч"],
    "жайворон": ["жайворонок"],
    "жакан": ["жекан", "жиган"],
    "жакаранда": ["фиалковое дерево"],
    "жакетка": ["жакет"],
    "жаккард": ["жаккар"],
    "жаккардный": ["жаккардовый"],
    "жако": ["серый попугай"],
    "жакшы": ["ийги"],
    "жалев": ["жалевши"],
    "жалевши": ["жалев"],
    "жалейка": ["брёлка", "жаломейка", "пищик"],
    "жалеть": ["сожалеть"],
    "жалив": ["жаливши"],
    "жаливши": ["жалив"],
    "жалитися": ["жалити"],
    "жалкий": ["бедный", "жалобный", "трогательный", "страдальческий", "невзрачный", "ничтожный", "дрянной", "незначительный"],
    "жалко": ["ничтожно", "жалобно", "жаль", "обидно"],
    "жалко у пчёлки в попке": ["жалко у пчёлки", "жалко у пчёлки в жопке"],
    "жалковав": ["жалковавши"],
    "жалковавши": ["жалковав"],
    "жалоба": ["причитание"],
    "жалобив": ["жалобивши"],
    "жалобивши": ["жалобив"],
    "жалобить": ["разжалобливать"],
    "жалобная книга": ["книга отзывов и предложений", "книга жалоб", "книга жалоб и предложений"],
    "жалобница": ["иск"],
    "жалобность": ["жалостность", "жалкость", "плачевность"],
    "жаловав": ["жаловавши"],
    "жаловавши": ["жаловав"],
    "жалованье": ["заработная плата"],
    "жаловаться": ["сетовать", "роптать", "плакаться", "ныть", "хныкать", "скулить", "апеллировать", "нажаловаться", "наушничать", "ябедничать", "фискалить", "капать", "капнуть", "кляузничать", "доносить"],
    "жаловаться белому телефону": ["блевать", "рвать", "беседовать с белым другом", "дружить с белым другом", "дружиться с белым другом", "кормить белого друга", "кричать на белого друга", "обниматься с белым другом", "целоваться с белым другом", "кормить унитаз", "пугать белого друга"],
    "жаловидный": ["жалообразный", "жалоподобный"],
    "жалонёр": ["жолнёр", "желонёр"],
    "жалообразный": ["жаловидный", "жалоподобный"],
    "жалоподобный": ["жаловидный", "жалообразный"],
    "жалостливость": ["жалостность"],
    "жалостливый": ["сострадательный", "сердобольный"],
    "жалостно": ["жалостливо", "жалобно"],
    "жалостность": ["жалкость", "жалостливость", "сердобольность", "сострадательность"],
    "жалостный": ["жалобный", "жалостливый", "жалкий"],
    "жалузия": ["тревога", "подозрительность", "опасение", "ревность"],
    "жаль": ["печально"],
    "жалюзи": ["венецианские ставни"],
    "жалюзийный": ["жалюзный"],
    "жалюзный": ["жалюзийный"],
    "жалюзь": ["пластина", "планка"],
    "жамка": ["жомок", "жемок"],
    "жамкав": ["жамкавши"],
    "жамкавши": ["жамкав"],
    "жамкнув": ["жамкнувши"],
    "жамкнувши": ["жамкнув"],
    "жандарм": ["полицейский"],
    "жандармерия": ["третье отделение", "охранное отделение", "охранка", "нацгвардия", "внутренние войска", "тайная полиция", "политическая полиция", "участок", "жандармы", "фараоны"],
    "жанетизация": ["жане метод"],
    "жанр": ["разновидность"],
    "жантильничав": ["жантильничавши"],
    "жантильничавши": ["жантильничав"],
    "жантильничать": ["жеманиться", "жеманничать", "кокетничать"],
    "жантильность": ["кокетливость", "жеманность", "изнеженность"],
    "жантильный": ["жеманный", "кокетливый", "изнеженный"],
    "жануар": ["хайуан"],
    "жаныбар": ["айбан"],
    "жар": ["зной", "пекло", "жара", "температура", "пыл", "воодушевление", "энтузиазм", "румянец"],
    "жара": ["зной", "жарынь", "жарища"],
    "жарарака": ["ботропс"],
    "жаргон": ["арго", "сленг", "социолект"],
    "жаргонизм": ["арготизм"],
    "жаргонность": ["сленговость"],
    "жаргонный": ["сленговый"],
    "жарево": ["жаркое", "жара", "жарынь", "зной"],
    "жарение": ["жарка", "поджаривание"],
    "жаренный": ["жареный"],
    "жарення": ["смаження"],
    "жареный": ["жаренный", "разоблачительный", "сенсационный"],
    "жарив": ["жаривши"],
    "жаривав": ["жаривавши"],
    "жаривавши": ["жаривав"],
    "жаривши": ["жарив"],
    "жаринка": ["жарина"],
    "жарить": ["поджаривать"],
    "жарища": ["жарынь", "духотища"],
    "жарка": ["жарение"],
    "жаркий": ["горячий", "южный", "знойный", "страстный", "пылкий", "темпераментный"],
    "жарко": ["знойно", "пылко", "страстно"],
    "жаркость": ["пылкость"],
    "жарок": ["купальница азиатская", "огонёк азиатский"],
    "жаропонижающий": ["антипиретический"],
    "жаростойкий": ["жароустойчивый", "жароупорный", "жаровыносливый", "жаропрочный", "термостойкий", "термоустойчивый", "антитермический"],
    "жаростойкость": ["жаропрочность", "жароупорность"],
    "жаротрубный": ["дымогарный"],
    "жароупорный": ["жаростойкий", "жаропрочный"],
    "жароустойчивость": ["жаропрочность", "жаростойкость", "жароупорность"],
    "жароустойчивый": ["жаропрочный", "жаростойкий", "жароупорный"],
    "жарт": ["фацеция"],
    "жарынка": ["вугольчык"],
    "жарынь": ["зной", "жара"],
    "жасминный": ["жасминовый"],
    "жасминовий": ["жасминний"],
    "жасминовый": ["жасминный"],
    "жатка": ["жнейка"],
    "жать": ["давить", "сдавливать", "сжимать", "стискивать", "выдавливать", "выжимать", "притеснять", "угнетать", "поджимать", "гнать"],
    "жать руку": ["здороваться", "целую ручки", "ваш с искорками"],
    "жахав": ["жахавши"],
    "жахавши": ["жахав"],
    "жахливий": ["страшний", "жахний", "жаский"],
    "жахнув": ["жахнувши"],
    "жахнувши": ["жахнув"],
    "жахнути": ["налякати"],
    "жахнуть": ["грянуть", "ахнуть", "бабахнуть", "грохнуть", "трахнуть", "шарахнуть", "шандарахнуть", "раздаться", "прогреметь", "треснуть", "хлопнуть", "выстрелить", "сделать выстрел", "произвести выстрел", "пальнуть"],
    "жашоо": ["турмуш"],
    "жб": ["железобетонный"],
    "жб плита": ["железобетонная плита"],
    "жбанок": ["дзбанок", "джбан", "жбан"],
    "жвавий": ["прудкий"],
    "жвачка": ["тягомотина", "жевательная резинка", "жевачка"],
    "жвир": ["дресва", "крупнозернистый песок", "крупный песок", "гравий"],
    "жгут": ["сплетение", "узел", "турникет"],
    "жгутиконосец": ["флагеллата"],
    "жгутиконосный": ["лептоманадный"],
    "жгуче": ["невыносимо", "обжигающе", "очень", "сильно"],
    "жгучий": ["обжигающий", "палящий", "едкий", "острый"],
    "ждав": ["ждавши"],
    "ждавши": ["ждав"],
    "ждати": ["чекати"],
    "ждать": ["ожидать", "дожидаться", "выжидать", "поджидать", "чаять", "погодить", "медлить", "мешкать", "тянуть время"],
    "ждаться": ["ожидаться", "дожидаться"],
    "же": ["живете", "жизнь"],
    "жебракувати": ["жебрувати", "жебрачити", "старцювати"],
    "жебрання": ["жебрування"],
    "жебрати": ["жебрачити", "жебрувати"],
    "жебрацький": ["старчачий"],
    "жебрування": ["жебрання"],
    "жевав": ["жевавши"],
    "жевавши": ["жевав"],
    "жеванье": ["жевание"],
    "жевательная резинка": ["жевастик"],
    "жевать": ["пережёвывать", "жевать резину"],
    "жевать сопли": ["сопли жевать", "медлить", "тянуть время", "тянуть резину", "тянуть кота за хвост"],
    "жевачка": ["жвачка", "жёвка"],
    "жезл": ["трость", "палка"],
    "жека": ["женя"],
    "желав": ["желавши"],
    "желавши": ["желав"],
    "желаемость": ["желанность", "нужность", "вожделенность"],
    "желание": ["хотение", "хотенье", "желанье", "вожделение", "либидо", "вожделенье"],
    "желанность": ["привлекательность"],
    "желанье": ["желание"],
    "желательно": ["предпочтительно", "лучше"],
    "желательное наклонение": ["оптатив"],
    "желательный": ["нужный", "предпочтительный"],
    "желатин": ["желатина"],
    "желатинация": ["желатинизация", "желатинирование", "застудневание"],
    "желатинизация": ["желатинирование", "застудневание", "желатинация", "клейстеризация"],
    "желатинизировав": ["желатинизировавши"],
    "желатинизировавши": ["желатинизировав"],
    "желатинизировать": ["желатинировать"],
    "желатинизироваться": ["желатинироваться"],
    "желатинировав": ["желатинировавши"],
    "желатинировавши": ["желатинировав"],
    "желатинирование": ["застудневание", "желатинизация"],
    "желатинировать": ["желатинизировать"],
    "желатинироваться": ["желатинизироваться"],
    "желатинный": ["желатиновый"],
    "желатинозный": ["желатиноподобный", "желатинообразный"],
    "желатинообразный": ["желатиноподобный", "желеобразный", "желеподобный", "студенистый"],
    "желать": ["хотеть", "жаждать", "стремиться", "мечтать"],
    "желвак": ["шишка", "опухоль"],
    "желвь": ["желвец", "земляная черепаха"],
    "желе": ["студень"],
    "железина": ["железяка"],
    "железистая клетка": ["гландулоцит"],
    "железистый": ["железосодержащий"],
    "железка": ["железяка"],
    "железная дорога": ["путь", "железка", "чугунка", "железнодорожный транспорт", "дорога"],
    "железная леди": ["баба с яйцами", "бой-баба", "мужик в юбке"],
    "железная рука": ["железный кулак"],
    "железнив": ["железнивши"],
    "железнивши": ["железнив"],
    "железница": ["демодекс"],
    "железно": ["сильно", "крепко", "плотно", "твёрдо", "непоколебимо", "отлично", "отменно", "образцово"],
    "железнодорожный состав": ["состав", "поезд"],
    "железный": ["металлический", "крепкий", "прочный", "сильный", "твёрдый", "мощный", "стальной", "аппаратный"],
    "железо": ["металл", "чёрный металл", "сталь", "железяка", "железка", "цепь", "оковы", "путы", "кандалы", "узы", "аппаратное обеспечение", "хардвер", "аппаратура", "оборудование", "матчасть"],
    "железобетонная плита": ["жб плита"],
    "железобетонное изделие": ["жби"],
    "железобетонный": ["жб"],
    "железованадиевый": ["феррованадиевый"],
    "железомарганцевый": ["ферромарганцевый"],
    "железонесущий": ["железосодержащий", "железоносный"],
    "железоносный": ["железонесущий"],
    "железоплавильный": ["сталеплавильный"],
    "железосодержащий": ["железонесущий", "железоносный"],
    "железяка": ["железина", "железка"],
    "желеобразный": ["желеподобный", "желатинообразный", "студенистый"],
    "желеподобный": ["желеобразный", "желатинообразный", "студенистый"],
    "желировав": ["желировавши"],
    "желировавши": ["желировав"],
    "желирование": ["сгущение", "загущение"],
    "желировать": ["густеть", "загустеть", "сгущать", "сгущаться", "сгустить", "сгуститься", "загущать", "загущаться", "загустить", "загуститься"],
    "желна": ["чёрный дятел", "долбила"],
    "желобив": ["желобивши"],
    "желобивши": ["желобив"],
    "желобоватый": ["желобчатый"],
    "желонёр": ["жалонёр", "жолнёр"],
    "желтев": ["желтевши"],
    "желтевши": ["желтев"],
    "желтение": ["пожелтение"],
    "желтеть": ["бледнеть", "зеленеть", "желтеться"],
    "желтив": ["желтивши"],
    "желтивши": ["желтив"],
    "желтизна": ["желтинка"],
    "желтинник": ["желтушник", "желтуница", "кожевенник", "скумпия"],
    "желтиться": ["желтеть"],
    "желтковый": ["желточный"],
    "желтобрюх": ["желтобрюхий полоз", "каспийский полоз"],
    "желтовато-серый": ["серовато-жёлтый"],
    "желтоватый": ["желтоватенький"],
    "желтоглазка": ["песочник", "крупноглазка", "краеглазка"],
    "желток": ["дейтоплазма"],
    "желтокорень": ["гидрастис"],
    "желтолозник": ["ива пурпурная"],
    "желтопузик": ["глухарь"],
    "желторотый": ["желтоклювый", "неоперившийся", "неискушённый", "зелёный"],
    "желторотый птенец": ["неоперившийся птенец", "желторотый юнец", "мало каши ел"],
    "желтофиоль": ["лакфиоль"],
    "желточный": ["желтковый"],
    "желтуха": ["болезнь госпела"],
    "желть": ["желтизна"],
    "желудиный": ["желудёвый"],
    "желудёвый": ["желудиный"],
    "желузия": ["тревога", "подозрительность", "опасение", "ревность"],
    "желчевыделение": ["желчеотделение"],
    "желчевыделительный": ["желчеотделительный"],
    "желчеотделение": ["желчеобразование", "желчевыделение", "холерез"],
    "желчно": ["жёлчно"],
    "желчность": ["жёлчность", "язвительность", "ядовитость", "раздражительность", "колкость", "сердитость", "злоба", "злобность", "ехидство", "ехидность", "злоехидство", "злоехидность", "едкость", "саркастичность", "озлобленность"],
    "желчный": ["билиарный", "язвительный", "раздражительный"],
    "желчь": ["жёлчь"],
    "жеманиться": ["жеманничать", "манерничать"],
    "жеманница": ["жеманиха", "жеманка", "кокетка", "кривляка", "ломака"],
    "жеманничав": ["жеманничавши"],
    "жеманничавши": ["жеманничав"],
    "жеманничать": ["жеманиться", "манерничать", "кокетничать"],
    "жеманно": ["жантильно", "манерно"],
    "жеманность": ["жеманство", "манерность"],
    "жеманный": ["манерный"],
    "жеманство": ["жеманность", "жеманничанье", "кокетство", "кривляние", "ломание", "ломанье", "манерность", "манерничание", "манерничанье", "модничание", "модничанье", "наигранность", "церемонность"],
    "жемчуг": ["жемчужина", "бисер", "перл"],
    "жемчужина": ["жемчуг", "бисер", "перл", "драгоценность", "сокровище", "украшение"],
    "жена": ["супруга", "благоверная", "половина", "моя", "женщина"],
    "женатик": ["женатый", "семьянин"],
    "женералитет": ["женералитат"],
    "женив": ["женивши"],
    "женивши": ["женив"],
    "женировать": ["смущать", "стеснять"],
    "женить": ["венчать", "обвенчать"],
    "женитьба": ["свадьба"],
    "жениться": ["брать в жёны", "взять в жёны", "пожениться"],
    "женкар": ["женоугодник", "донжуан", "конте", "коцкар", "чапкънин"],
    "женобоязнь": ["женофобия"],
    "женоложница": ["лесбиянка"],
    "женоложство": ["лесбиянство", "сапфизм", "трибадизм"],
    "женолюбица": ["лесбиянка", "женоложница"],
    "женолюбка": ["лесбиянка", "женоложница", "женолюбица"],
    "женонеистовство": ["анальный секс", "содомия"],
    "женоненавистник": ["женофоб", "мизогин", "мизогинист"],
    "женоненавистничество": ["мизогиния"],
    "женотделовский": ["женотдельский"],
    "женотдельский": ["женотделовский"],
    "женофоб": ["женоненавистник"],
    "женофобия": ["женобоязнь"],
    "женофобство": ["женофобия"],
    "женски": ["по-женски", "женственно"],
    "женский": ["символ", "женщинский"],
    "женский пол": ["женщины", "нежный пол", "прекрасный пол", "слабый пол", "бабы"],
    "женсоветовка": ["женсоветчица"],
    "женсоветчица": ["женсоветовка"],
    "женственно": ["мягко", "изящно", "нежно"],
    "женство": ["прекрасный пол", "женственность"],
    "жентонг": ["махамадхъямака"],
    "женщина": ["мужчина", "петух"],
    "женщина лёгкого поведения": ["проститутка", "шлюха"],
    "женщина-врач": ["врач", "докторша", "врачиха"],
    "женщина-космонавт": ["космонавтка"],
    "женщинка": ["бабёнка"],
    "женщинский": ["женский"],
    "женька": ["женя", "женечка"],
    "жерар": ["герхард", "джеррард"],
    "жердевой": ["жердяной"],
    "жерделя": ["жердёла"],
    "жердинник": ["жердняк"],
    "жердняк": ["жердинник"],
    "жердь": ["слега", "соха", "верзила", "дылда", "каланча", "жердяй", "верста", "детина", "длинный", "долговязый"],
    "жердяище": ["долговяз", "дылда", "шпала", "верста", "оглобля"],
    "жердяй": ["долговяз", "дылда", "жердила", "шпала", "верста", "оглобля"],
    "жердяйка": ["долговяз", "дылда", "шпала", "верста", "оглобля"],
    "жердяйчик": ["долговяз", "дылда", "шпала", "верста", "оглобля"],
    "жердяной": ["жердевой"],
    "жеребейка": ["жеребеек"],
    "жеребец": ["конь", "бык"],
    "жеребець": ["огир"],
    "жеребив": ["жеребивши"],
    "жеребивши": ["жеребив"],
    "жеребий": ["кусочек", "отрубочек", "отрезок"],
    "жеребёнок": ["лошонок", "онжеребёнок"],
    "жерех": ["шереспер", "жерих", "черех", "белесть", "белезна"],
    "жержазма": ["география"],
    "жерло": ["дуло", "устье", "скважина", "отверстие", "углубление", "канал", "сопло", "проём", "чело", "горнило", "камера", "топка", "шесток"],
    "жертва": ["жертвоприношение", "пожертвование", "самопожертвование", "пострадавший"],
    "жертвенник": ["алтарь", "престол"],
    "жертвовав": ["жертвовавши"],
    "жертвовавши": ["жертвовав"],
    "жертвование": ["пожертвование", "жертва"],
    "жертвовать": ["даровать"],
    "жертвоприношенье": ["жертвоприношение"],
    "жерёбый": ["жерёбный", "сужерёбый"],
    "жест доброй воли": ["уступка", "компенсация", "жест доброй моли", "жест дохлой моли"],
    "жестив": ["жестивши"],
    "жестивши": ["жестив"],
    "жестикулировав": ["жестикулировавши"],
    "жестикулировавши": ["жестикулировав"],
    "жестикуляция": ["жестикулирование"],
    "жесткач": ["жесть", "тяжеляк"],
    "жестковолосной": ["жестковолосый"],
    "жестковолосый": ["жестковолосной"],
    "жестколистный": ["жестколиственный"],
    "жесткошёрстный": ["жесткошёрстый", "грубошёрстный", "грубошёрстый"],
    "жесткошёрстый": ["жесткошёрстный", "грубошёрстный", "грубошёрстый"],
    "жестовый язык": ["язык жестов"],
    "жестокий": ["суровый", "безжалостный"],
    "жестоко": ["грубо", "беспощадно", "безжалостно", "предельно"],
    "жестоковыйный": ["непокорный", "непреклонный", "жестокосердный"],
    "жестокосердие": ["жестокость", "бессердечие", "безжалостность"],
    "жестокосердный": ["жестокосердый", "жестокий", "немилосердный"],
    "жестокосердый": ["жестокосердный", "бездушный"],
    "жестокосердье": ["жестокосердие"],
    "жестокость": ["безжалостность", "беспощадность", "бессердечие", "бессердечность", "бесчеловечие", "бесчеловечность", "жестокосердие"],
    "жесточе": ["лютее", "свирепее"],
    "жестуно": ["жестовый язык"],
    "жестчение": ["закалка", "тренировка"],
    "жестяной": ["железный"],
    "жестянщик": ["жестяник"],
    "жетва": ["урожай", "добив", "реколта"],
    "жетон": ["значок", "бляха", "бляшка", "монетовидный жетон", "монетка", "номерок", "бирка", "жетон военнослужащего", "армейский жетон", "военный жетон", "солдатский жетон", "жетон смертника", "медальон смерти", "смертельный медальон", "смертник"],
    "жечь": ["палить", "сжигать", "расходовать"],
    "жжёный": ["обожжённый", "прожжённый"],
    "жибин": ["къаражибин"],
    "жив": ["живши"],
    "жива": ["сива"],
    "живав": ["живавши"],
    "живавши": ["живав"],
    "живать": ["проживать"],
    "живая очередь": ["очередь"],
    "живая сила": ["личный состав", "кинетическая энергия"],
    "живец": ["бодряк", "живоцерковник", "обновленец"],
    "живив": ["жививши"],
    "жививши": ["живив"],
    "живить": ["бодрить", "оживлять"],
    "живица": ["терпентин"],
    "живо": ["быстро", "бойко", "бегло", "проворно", "поспешно", "спешно", "скоро", "споро", "стремительно", "торопливо"],
    "живоглот": ["изверг", "изувер", "садист", "упырь", "людоед", "каннибал", "кровопийца", "кровосос", "вурдалак"],
    "живоглотский": ["живодёрский", "зверский"],
    "живодёр": ["живорез", "коновал"],
    "живодёрничав": ["живодёрничавши"],
    "живодёрничавши": ["живодёрничав"],
    "живодёрня": ["живодёрка", "бойня"],
    "живодёрский": ["садистский", "зверский", "живоглотский"],
    "живодёрствовав": ["живодёрствовавши"],
    "живодёрствовавши": ["живодёрствовав"],
    "живое существо": ["существо", "организм"],
    "живой": ["живущий", "органический", "наглядный", "реальный", "энергичный", "воодушевлённый", "деятельный", "занимательный", "увлекательный", "выразительный", "яркий", "живительный", "оживляющий", "больной"],
    "живой труп": ["живой мертвец", "зомби"],
    "живокостный": ["дельфиниум"],
    "живокость": ["дельфиниум", "шпорник"],
    "живоначальный": ["живоносный"],
    "живопис": ["малярство"],
    "живописав": ["живописавши"],
    "живописавши": ["живописав"],
    "живописать": ["расписывать", "изображать"],
    "живородка": ["лужанка"],
    "живорождение": ["живорожденье"],
    "живость": ["оживлённость", "подвижность", "выразительность", "яркость"],
    "живот": ["пузо", "брюхо", "чрево", "утроба", "желудок", "жизнь", "скот", "живность"],
    "животворен": ["укрепителен", "живителен", "жизнен", "свеж"],
    "животворив": ["животворивши"],
    "животворивши": ["животворив"],
    "животворный": ["животворящий"],
    "животворящий": ["животворный"],
    "животина": ["животинка", "домашнее животное", "скотина", "скот"],
    "животинка": ["животина", "скотинка", "скотина", "скот", "домашнее животное"],
    "животновод": ["фермер"],
    "животное": ["зверь", "тварь", "скотина"],
    "животной": ["пудо-живот"],
    "животный": ["физиологический", "низменный", "низкий"],
    "животный корм": ["корма животного происхождения"],
    "животный магнетизм": ["живой", "магнетизм", "зоомагнетизм", "месмеризм"],
    "животрепещущий": ["трепещущий", "трепетный", "дрожащий", "зыбкий", "злободневный", "насущный", "жгучий", "острый"],
    "живоцерковник": ["живец", "обновленец"],
    "живучесть": ["долговечность", "устойчивость"],
    "живучий": ["жизнеспособный", "жизнестойкий"],
    "живучка": ["дубровка", "дубница", "вологлодка", "молодило"],
    "живущий": ["обитающий"],
    "живчик": ["егоза", "непоседа"],
    "живши": ["жив"],
    "живьём": ["живой", "заживо", "вживую"],
    "живёхонький": ["живёшенький", "невредимый", "целый"],
    "жига": ["джига"],
    "жигав": ["жигавши"],
    "жигавка": ["кропива"],
    "жигавши": ["жигав"],
    "жиган": ["вор-рецидивист", "мошенник", "плут"],
    "жиганув": ["жиганувши"],
    "жиганувши": ["жиганув"],
    "жигануть": ["жогнуть"],
    "жиголо": ["проститут"],
    "жигули": ["жигулёвские горы"],
    "жигулёнок": ["жигули", "жигуль"],
    "жид": ["еврей", "иудей", "жидяра", "жидина", "жадина", "жмот"],
    "жид пархатый": ["жидовская морда", "жидяра"],
    "жидва": ["жидовня"],
    "жидев": ["жидевши"],
    "жидевши": ["жидев"],
    "жидив": ["жидивши"],
    "жидивши": ["жидив"],
    "жидить": ["разжижать"],
    "жидкий": ["текучий", "водянистый", "ненасыщенный", "разбавленный", "прозрачный", "редкий"],
    "жидковолосый": ["редковолосый"],
    "жидкокостный": ["хлипкий", "тщедушный"],
    "жидкообразный": ["жидкоподобный"],
    "жидкоподобный": ["жидкообразный"],
    "жидкостный ракетный двигатель": ["жрд"],
    "жидкость": ["влага", "текучесть", "жидкое состояние"],
    "жидкотекучий": ["жидкотекущий"],
    "жидня": ["жидва", "жидовня"],
    "жидовка": ["иудейка", "еврейка"],
    "жидовня": ["жидва"],
    "жидовская морда": ["жид пархатый"],
    "жидоед": ["антисемит", "юдофоб"],
    "жидюга": ["жид", "жидок", "скупой", "скряга"],
    "жижица": ["жижа"],
    "жизнедеятельность": ["метаболизм", "функционирование", "деятельность"],
    "жизнелюб": ["оптимист", "бодряк", "бодрячок", "животолюбец", "жизнелюбец"],
    "жизнелюбец": ["жизнелюб"],
    "жизнелюбивый": ["жизнерадостный"],
    "жизненный": ["житийный", "житейский", "насущный"],
    "жизнеобеспечение": ["жизнеобеспеченье"],
    "жизнеобеспеченье": ["жизнеобеспечение"],
    "жизнеобеспечив": ["жизнеобеспечивши"],
    "жизнеобеспечивающий": ["поддерживающий", "жизнедеятельность", "помогающий", "выжить", "удовлетворяющий", "жизненный", "потребность"],
    "жизнеобеспечивши": ["жизнеобеспечив"],
    "жизнеописание": ["биография", "жизнеописанье", "био"],
    "жизнеописанье": ["жизнеописание", "биография", "био"],
    "жизнеописательный": ["агиографический", "биографический"],
    "жизнерадостность": ["оптимистичность", "оптимизм"],
    "жизнерадостный": ["жовиальный", "неунывающий"],
    "жизнеспособность": ["живучесть", "витальность", "жизнестойкость"],
    "жизнестойкий": ["жизнеспособный", "живучий"],
    "жизнестойкость": ["жизнеспособность"],
    "жизнеугрожающий": ["жизнеопасный"],
    "жизнь": ["дни", "бытие"],
    "жизнь после смерти": ["загробная жизнь", "загробный мир", "потусторонний мир"],
    "жикав": ["жикавши"],
    "жикавши": ["жикав"],
    "жикнув": ["жикнувши"],
    "жикнувши": ["жикнув"],
    "жиковина": ["жуковина"],
    "жила": ["сосуд", "сухожилие", "провод"],
    "жилет": ["жилетка"],
    "жилетка": ["жилет", "безрукавка"],
    "жилец": ["житель", "обитатель", "квартирант"],
    "жилив": ["жиливши"],
    "жиливши": ["жилив"],
    "жилистый": ["сухощавый", "мускулистый", "сильный", "крепкий", "выносливый"],
    "жилить": ["жулить", "жульничать", "хитрить", "мошенничать", "обманывать"],
    "жилица": ["жительница", "обитательница", "съемщица", "квартирантка", "постоялка", "обитальщица", "стоялица", "стоялка", "постояльщица", "постойщица", "обитальница", "постоялица", "коечница", "жилянка", "пожиличка"],
    "жилище": ["дом", "обиталище", "жильё", "жилплощадь", "резиденция"],
    "жилищно-коммунальные услуги": ["жку", "жкх", "коммуналка"],
    "жилищное товарищество": ["жилтоварищество"],
    "жилищный фонд": ["жилфонд"],
    "жилкоммунхоз": ["жилкомхоз"],
    "жилкомхоз": ["жилкоммунхоз"],
    "жилконтора": ["жилищно-эксплуатационная контора", "жэк"],
    "жило": ["жильё"],
    "жилой": ["жилищный", "обитаемый"],
    "жилплощадь": ["жилая площадь", "дом", "жилище", "жильё", "резиденция"],
    "жилфонд": ["жилищный фонд"],
    "жильничав": ["жильничавши"],
    "жильничавши": ["жильничав"],
    "жильё": ["дом", "жилище", "жилплощадь"],
    "жиманув": ["жиманувши"],
    "жиманувши": ["жиманув"],
    "жимканье": ["жимкание", "жамкание", "жамканье"],
    "жимолость": ["шеломутник", "кобылица"],
    "жинав": ["жинавши"],
    "жинавши": ["жинав"],
    "жиппон": ["жюп", "жюпель", "жюпон"],
    "жир": ["тук", "сало", "масло", "жирок"],
    "жирант": ["индоссант"],
    "жират": ["индоссат", "индоссатор"],
    "жираф": ["жирафа", "камелопард"],
    "жирафа": ["жираф", "жирафиха"],
    "жирдяй": ["толстяк", "жиртрест", "жиртрес", "жиробас", "жиряк", "толстун", "толстопуз", "пузан", "брюхан", "бурдюк", "пончик", "туша", "жир"],
    "жирев": ["жиревши"],
    "жиревши": ["жирев"],
    "жирик": ["ввж"],
    "жириновец": ["элдэпээровец"],
    "жирировав": ["жирировавши"],
    "жирировавши": ["жирировав"],
    "жирнев": ["жирневши"],
    "жирневши": ["жирнев"],
    "жирненький": ["жирный", "толстенький", "толстый", "тучненький", "тучный", "ожиревший"],
    "жирник": ["масляная лампа", "каганец", "жирница"],
    "жирно будет": ["а жирно не будет", "сильно жирно будет", "больно жирно будет"],
    "жирнохвостый": ["широкохвостный"],
    "жирный": ["толстый", "упитанный", "разжиревший", "толстяк", "сальный"],
    "жировав": ["жировавши"],
    "жировавши": ["жировав"],
    "жирование": ["жировка"],
    "жировичок": ["жирник"],
    "жировка": ["кормёжка", "жирование", "жиры"],
    "жировоск": ["адипоцир"],
    "жироловка": ["жироуловитель"],
    "жиромер": ["бутирометр"],
    "жиромучной": ["жиротуковый"],
    "жирообменный": ["липометаболический"],
    "жирообразный": ["жироподобный"],
    "жироотталкивающий": ["гидрофильный", "олеофобный"],
    "жироплан": ["автожир", "гироплан", "гирокоптер", "ротаплан"],
    "жироподобный": ["жирообразный"],
    "жиропот": ["серка"],
    "жироскоп": ["гироскоп"],
    "жиростатика": ["гиростатика"],
    "жиростатический": ["гиростатический"],
    "жиротуковый": ["жиромучной"],
    "жироуловитель": ["жироловка"],
    "жируха": ["баловница", "толстуха"],
    "жиряк": ["даман", "гуахаро"],
    "жисть": ["жизь", "жись", "жисть-жестянка"],
    "житейский": ["жизненный", "обыденный"],
    "житель": ["обитатель"],
    "жительница": ["обитательница"],
    "жительство": ["проживание", "пребывание", "обитание", "жилище", "обиталище", "местожительство", "жильё"],
    "жительствовав": ["жительствовавши"],
    "жительствовавши": ["жительствовав"],
    "житие": ["жизнь", "жизнеописание", "биография", "биографический очерк"],
    "житло": ["помешкання"],
    "житница": ["амбар", "закрома"],
    "житомирец": ["житомирянин"],
    "житомирець": ["житомирянин"],
    "житомирская область": ["житомирщина"],
    "житуха": ["жизнь"],
    "жить": ["быть", "обитать", "вековать", "коротать век", "водиться", "проживать", "жительствовать", "квартировать", "обретаться", "стоять на квартире", "бытовать", "существовать", "зарабатывать", "кормиться", "увлекаться"],
    "жить в большой крайности": ["жить впроголодь", "перебиваться с хлеба на воду", "перебиваться с хлеба на квас", "жить паром", "жить на кочерыжке"],
    "жить впроголодь": ["жить в большой крайности", "перебиваться с хлеба на воду", "перебиваться с хлеба на квас", "жить паром", "жить на кочерыжке"],
    "жить на биче": ["сидеть на биче", "жить на бичике", "сидеть на бичике"],
    "жить на бичике": ["сидеть на бичике", "жить на биче", "сидеть на биче"],
    "жить паром": ["жить впроголодь", "перебиваться с хлеба на воду", "перебиваться с хлеба на квас", "жить в большой крайности", "жить на кочерыжке", "сидеть парасытом"],
    "жить у смерти": ["быть у смерти"],
    "житьецо": ["житьишко"],
    "житьишко": ["житьецо"],
    "житьё": ["жизнь", "проживание"],
    "жица": ["кабел", "проводник", "въже", "въженце"],
    "жлоб": ["грубиян", "деревенщина", "наглец", "невежа", "невежда", "хам", "жлобчик", "жлобяра"],
    "жлобствовав": ["жлобствовавши"],
    "жлобствовавши": ["жлобствовав"],
    "жлъчност": ["язвителност", "хапливост", "острота", "злъчност", "жегване"],
    "жмак": ["жмых", "макуха", "колоб", "дуранда", "избоина"],
    "жменя": ["горсть", "жменька", "пригоршня"],
    "жмотиться": ["жмотничать", "жилиться", "жлобствовать", "скупердяйствовать", "сквалыжничать", "скупердяйничать", "жадничать"],
    "жмотничав": ["жмотничавши"],
    "жмотничавши": ["жмотничав"],
    "жмотничать": ["жмотиться", "скупиться", "жадничать"],
    "жмотство": ["жадность", "жлобство"],
    "жмотствовав": ["жмотствовавши"],
    "жмотствовавши": ["жмотствовав"],
    "жмудский": ["жемайтский"],
    "жмудь": ["жемайты"],
    "жмур": ["мертвец", "труп"],
    "жмурив": ["жмуривши"],
    "жмуривши": ["жмурив"],
    "жмурик": ["покойник", "труп", "мертвец", "тело"],
    "жмурить": ["щурить"],
    "жмуриться": ["зажмуриваться"],
    "жмурка": ["зажмуривание", "жатка"],
    "жмут": ["пук"],
    "жмых": ["макуха", "колоб", "дуранда", "избоина", "жмак", "шрот", "окара", "пульпа", "мякоть", "дурачок"],
    "жмякав": ["жмякавши"],
    "жмякавши": ["жмякав"],
    "жмякнув": ["жмякнувши"],
    "жмякнувши": ["жмякнув"],
    "жмякнуть": ["шлёпнуть", "грохнуть", "чмокнуть", "кинуть", "бросить", "жамкнуть"],
    "жнейка": ["жатка"],
    "жниво": ["жнива", "жнивьё"],
    "жнивьё": ["жниво", "жнива", "стерня", "жатва", "уборка"],
    "жница": ["жнея"],
    "жовто-блакитный": ["жёлто-голубой", "украинский"],
    "жовтобрюх": ["жовточеревий полоз"],
    "жовтодзьобий": ["жовторотий"],
    "жовтуха": ["жовтяница"],
    "жовтяниця": ["жовтуха"],
    "жоден": ["жодний"],
    "жодний": ["жоден"],
    "жожоба": ["хохоба", "симмондсия"],
    "жозеф": ["иосиф"],
    "жокс": ["соединитель"],
    "жолкнув": ["жолкнувши"],
    "жолкнувши": ["жолкнув"],
    "жолнёр": ["жалонёр", "желонёр"],
    "жолудевий": ["жолудяний"],
    "жолудное": ["жёлудное"],
    "жолудяний": ["жолудевий"],
    "жом": ["давильня", "точило", "выжимки", "жмых", "жмыхи", "скупец", "скряга", "скаред", "сквалыга", "жмот", "жидомор", "сфинктер"],
    "жона": ["дружина"],
    "жонглировав": ["жонглировавши"],
    "жонглировавши": ["жонглировав"],
    "жонглёр": ["гистрион"],
    "жонглёрша": ["жонглёрка"],
    "жопа голову перевешивает": ["глупец"],
    "жопа дзержинского": ["дрянь", "туфта", "туфтянка", "халтура"],
    "жопа мира": ["захолустье", "медвежий угол"],
    "жопа с глазами": ["жопа с ушами", "жопа говорящая", "жопа на колёсах", "жопа на колёсиках", "жопа новый год", "пизда с ушами", "пизда с глазами", "пизда говорящая", "пизда на колёсах", "пизда на колёсиках", "пизды кусок", "пиздоглазый", "хуй пиздоглазый", "пиздоухий", "хуй пиздоухий"],
    "жопа с двумя ж": ["жопа с двумя п"],
    "жопа с ручкой": ["жопа с ушами", "жопа с глазами", "жопа говорящая", "жопа на колёсах", "жопа на колёсиках", "жопа новый год", "пизда с ушами", "пизда с глазами", "пизда говорящая", "пизда на колёсах", "пизда на колёсиках", "пизды кусок", "пиздоглазый", "хуй пиздоглазый", "пиздоухий"],
    "жопа с ушами": ["жопа с ручкой", "жопа с глазами", "жопа говорящая", "жопа на колёсах", "жопа на колёсиках", "жопа новый год", "пизда с ушами", "пизда с глазами", "пизда говорящая", "пизда на колёсах", "пизда на колёсиках", "пизды кусок", "пиздоглазый", "хуй пиздоглазый", "пиздоухий"],
    "жопа склеится": ["жопа слипнется"],
    "жопа слипнется": ["жопа склеится"],
    "жопень": ["жопа", "задница"],
    "жопив": ["жопивши"],
    "жопивши": ["жопив"],
    "жопиться": ["экономничать", "скряжничать", "жилиться"],
    "жопка": ["попка", "жупка"],
    "жопник": ["жадина"],
    "жопой думать": ["ошибаться", "думать жопой"],
    "жопой об косяк": ["каком кверху"],
    "жополиз": ["конформист", "лизоблюд", "флюрик"],
    "жопорожец": ["запорожец", "горбатый"],
    "жопорукий": ["косорукий", "криворукий", "рукожопый"],
    "жопорукость": ["рукожопость"],
    "жопочка": ["попочка"],
    "жопочник": ["жадина", "жадина-говядина", "скупердяй", "скряга", "подлиза"],
    "жопошник": ["жмот", "скупердяй", "скупец", "гомосек", "гомик", "педик", "гей", "пидорас", "пидор", "жопа", "жопища"],
    "жопу лизать": ["подлизываться", "подобострастничать", "выслуживаться"],
    "жопу морщить": ["морщить жопу"],
    "жопу рвать": ["рвать жопу"],
    "жопуа": ["афедрон", "зад", "седалище", "сидальница", "ягодица", "ягодицы", "попа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея"],
    "жопушка": ["попа"],
    "жора": ["гора"],
    "жоржет": ["креп-жоржет", "шёлк"],
    "жоржетовый": ["креп-жоржетовый"],
    "жорно": ["мельничка", "млинець", "крупник", "млинок", "мучник"],
    "жох": ["пройдоха", "плут", "бестия"],
    "жрав": ["жравши"],
    "жравши": ["жрав"],
    "жраньё": ["жратва"],
    "жрать": ["кушать", "трескать", "лопать", "хавать", "наяривать", "уплетать", "шамать", "штефкать"],
    "жрд": ["жидкостный реактивный двигатель"],
    "жребий": ["кости", "судьба", "доля", "участь", "удел"],
    "жрец": ["священнослужитель"],
    "жрица любви": ["проститутка", "женщина лёгкого поведения", "ночная бабочка", "публичная женщина", "путана", "шмара", "шлюха"],
    "жудасць": ["жах"],
    "жужжав": ["жужжавши"],
    "жужжавши": ["жужжав"],
    "жужжало": ["муха-жужжало"],
    "жужжание": ["жужжанье", "гудение", "гуденье"],
    "жужжанье": ["жужжание"],
    "жужик": ["запор"],
    "жуз": ["джус"],
    "жуир": ["гуляка", "повеса", "кутила"],
    "жуировав": ["жуировавши"],
    "жуировавши": ["жуировав"],
    "жуирство": ["гедонизм", "эпикурейство"],
    "жук": ["жесткокрылое", "ловчила", "плут", "пройдоха", "жучок"],
    "жук-долгоносик": ["долгоносик"],
    "жук-щелкун": ["щелкун"],
    "жуковина": ["жиковина"],
    "жулан": ["сорокопут-жулан"],
    "жулив": ["жуливши"],
    "жуливши": ["жулив"],
    "жулик": ["вор", "воришка"],
    "жуликовато": ["воровато"],
    "жулить": ["жульничать", "воровать", "мошенничать", "плутовать", "жилить"],
    "жульничав": ["жульничавши"],
    "жульничавши": ["жульничав"],
    "жульничание": ["жульничанье"],
    "жульничанье": ["жульничание"],
    "жульничать": ["плутовать"],
    "жульнически": ["мошеннически"],
    "жульничество": ["плутовство", "мошенничество", "надувательство"],
    "жульё": ["жулики", "мошенники", "мошня"],
    "жулябия": ["жульё"],
    "жума": ["апта"],
    "жумурият": ["республика", "элиш"],
    "жундев": ["жундевши"],
    "жундевши": ["жундев"],
    "жунта": ["хунта"],
    "жупев": ["жупевши"],
    "жупевши": ["жупев"],
    "жупел": ["сера", "пугало", "страшило"],
    "жупка": ["жопка", "попка"],
    "журавель": ["журавль"],
    "журавельник": ["аистник", "грабельник", "грабельки"],
    "журавка": ["журавлиця"],
    "журавлик": ["журавлёнок", "журавица", "жура", "журка", "журавчики", "корцанги"],
    "журавлиця": ["журавка"],
    "журавль": ["журавель", "журка", "журавль в небе"],
    "журив": ["журивши"],
    "журивши": ["журив"],
    "журить": ["упрекать", "укорять", "корить", "пенять", "отчитывать"],
    "журиться": ["печалиться", "кручиниться", "горевать"],
    "журливий": ["сумний", "зажурений", "печальний"],
    "журнал": ["дневник", "протокол", "киножурнал"],
    "журналировав": ["журналировавши"],
    "журналировавши": ["журналировав"],
    "журналист": ["журналюга", "журнализд", "журналжист", "журик", "пропагандон"],
    "журналистив": ["журналистивши"],
    "журналистивши": ["журналистив"],
    "журналистика": ["журнализм"],
    "журналистка": ["газетчица"],
    "журналюга": ["журналист"],
    "журчав": ["журчавши"],
    "журчавши": ["журчав"],
    "журчати": ["дзюрчати"],
    "журчать": ["булькать", "нашёптывать", "звучать", "ворковать"],
    "журьба": ["порицание", "укор"],
    "жутик": ["ужастик"],
    "жуткий": ["ужасный", "кошмарный", "страшный", "зловещий", "безобразный"],
    "жутко": ["страшно", "пугающе", "очень"],
    "жуть": ["ужас", "жутко"],
    "жухав": ["жухавши"],
    "жухавши": ["жухав"],
    "жухать": ["жульничать", "мошенничать", "мухлевать"],
    "жухлый": ["потускневший", "поблеклый", "поблекший", "блеклый", "блёклый", "пожухлый", "тусклый", "нечистый", "вялый", "увядший", "увялый", "вяловатый", "увянувший", "неживой", "никлый"],
    "жухнув": ["жухнувши"],
    "жухнувши": ["жухнув"],
    "жучара": ["жук", "скопидом", "скупец", "скупой", "выжига", "жадина", "жадюга", "жидомор", "жила", "жмот", "кащей", "копеечник", "крохобор", "кулак", "плюшкин"],
    "жученье": ["травля", "гнобление", "вздрючивание"],
    "жучив": ["жучивши"],
    "жучивши": ["жучив"],
    "жучила": ["плут", "мошенник", "вымогатель"],
    "жуылдарга": ["тызылдарга", "бызылдарга", "выжларга", "выжылдарга"],
    "жывёла": ["звер"],
    "жылбаян": ["жылнама"],
    "жылкы": ["ат"],
    "жэк": ["жилищно-эксплуатационная контора", "жилконтора"],
    "жэу": ["дэз"],
    "жюльен": ["суп-жюльен"],
    "жюра": ["юра"],
    "жюрив": ["жюривши"],
    "жюривши": ["жюрив"],
    "жёваный": ["помятый"],
    "жёвывав": ["жёвывавши"],
    "жёвывавши": ["жёвывав"],
    "жёлоб": ["канава", "канавка"],
    "жёлобообразный": ["жёлобовидный", "желобчатый"],
    "жёлтая вера": ["ламаизм"],
    "жёлтая вода": ["глаукома"],
    "жёлтая карточка": ["горчичник"],
    "жёлтая лихорадка": ["амариллез"],
    "жёлтая майка лидера": ["майка лидера"],
    "жёлтая река": ["хуанхэ"],
    "жёлто-белый": ["бело-жёлтый", "желтовато-белый", "бело-желтоватый", "желтовато-беловатый", "беловато-желтоватый"],
    "жёлто-бледный": ["бледно-жёлтый"],
    "жёлто-буроватый": ["буровато-жёлтый"],
    "жёлто-бурый": ["буро-жёлтый"],
    "жёлто-зеленоватый": ["оливковый", "зеленовато-жёлтый"],
    "жёлтое море": ["западно-корейское море"],
    "жёлтый металл": ["золото"],
    "жёлудное": ["жолудное"],
    "жёлчь": ["желчь", "раздражение", "злоба"],
    "жён-премьер": ["первый любовник", "сердцеед"],
    "жёнка": ["жена", "женщина"],
    "жёнушка": ["жена"],
    "жёрнов": ["мясорубка"],
    "жёсткий": ["твёрдый", "неподатливый", "прочный", "суровый", "грубый"],
    "жёсткий диск": ["диск", "винчестер", "накопитель на жёстких магнитных дисках", "нжмд", "винт"],
    "з-пад": ["для"],
    "за": ["позади", "на расстоянии", "в течение", "на протяжении", "для", "в интересах", "ради", "на", "во имя", "на благо", "во благо", "в пользу", "из-за", "с целью", "в целях"],
    "за бесценок": ["даром"],
    "за битого двух небитых дают": ["за одного учёного двух неучёных дают"],
    "за бугром": ["за границей", "за рубежом", "кордон"],
    "за всю хуйню": ["за всю херню", "за всю хурму", "почём зря"],
    "за глаза": ["заглазно", "за спиной", "заочно", "с лихвой", "с лишком"],
    "за глаза и за уши": ["за глаза"],
    "за границей": ["за рубежом", "за бугром"],
    "за закрытыми дверями": ["при закрытых дверях"],
    "за здорово живёшь": ["бесплатно", "даром", "за так", "за просто так", "задаром", "задарма", "за красивые глаза", "безвозмездно", "за спасибо"],
    "за исключением": ["кроме", "помимо"],
    "за каким хуем": ["за хуем", "нахуя", "какого хуя"],
    "за колено не поднято": ["конь не валялся", "ещё конь не валялся", "ещё и конь не валялся", "конь ещё не валялся", "ещё и кот не валялся"],
    "за копейку удавиться": ["удавиться за копейку", "удавиться за рубль", "за рубль удавиться"],
    "за красивые глаза": ["бесплатно", "даром", "за так", "за просто так", "просто так", "задаром", "задарма", "за здорово живёшь", "безвозмездно", "за спасибо", "ради прекрасных глаз", "для прекрасных глаз", "за прекрасные глаза"],
    "за милую душу": ["за милый мой"],
    "за не хуй делать": ["как не хуй делать"],
    "за один присест": ["в один присест"],
    "за просто так": ["бесплатно", "даром", "за так", "задаром", "задарма", "за здорово живёшь", "за красивые глаза", "за спасибо"],
    "за рубежом": ["за границей", "за бугром"],
    "за семью замками": ["за семью печатями"],
    "за словом в карман не полезет": ["за словом в карман не лезет", "за словом в карман не ходит"],
    "за спасибо": ["бесплатно", "даром", "за так", "за просто так", "задаром", "задарма", "за здорово живёшь", "за красивые глаза", "безвозмездно"],
    "за спиной": ["позади", "скрытно", "втайне", "исподтишка", "в тени", "в прошлом", "на шее"],
    "за сухари": ["задёшево", "за таз пельменей", "за шапку сухарей", "за красную рубаху"],
    "за счёт": ["на счёт", "благодаря"],
    "за таз пельменей": ["задёшево", "за шапку сухарей"],
    "за так": ["бесплатно", "даром", "за просто так", "задаром", "задарма", "за здорово живёшь", "за красивые глаза", "за спасибо"],
    "за тридевять земель": ["у чёрта на куличках"],
    "за фасадом": ["под фасадом"],
    "за хуем": ["за каким хуем", "нахуя", "какого хуя"],
    "за шапку сухарей": ["задёшево", "за таз пельменей", "за сухари", "за красную рубаху"],
    "за шкирку": ["за шиворот", "за шкирняк", "за шкирман", "за шкирбон", "за хибот"],
    "за-": ["надто", "занадто"],
    "заабонировав": ["заабонировавши"],
    "заабонировавши": ["заабонировав"],
    "заавансировав": ["заавансировавши"],
    "заавансировавши": ["заавансировав"],
    "заагитировав": ["заагитировавши"],
    "заагитировавши": ["заагитировав"],
    "заадресовав": ["заадресовавши"],
    "заадресовавши": ["заадресовав"],
    "заадресовывав": ["заадресовывавши"],
    "заадресовывавши": ["заадресовывав"],
    "заакав": ["заакавши"],
    "заакавши": ["заакав"],
    "зааккумулировав": ["зааккумулировавши"],
    "зааккумулировавши": ["зааккумулировав"],
    "заактивничав": ["заактивничавши"],
    "заактивничавши": ["заактивничав"],
    "заактировав": ["заактировавши"],
    "заактировавши": ["заактировав"],
    "заалев": ["заалевши"],
    "заалевши": ["заалев"],
    "заалеться": ["заалеть", "закраснеться", "зардеться"],
    "заангажировав": ["заангажировавши"],
    "заангажировавши": ["заангажировав"],
    "зааплодировав": ["зааплодировавши"],
    "зааплодировавши": ["зааплодировав"],
    "заапрувив": ["заапрувивши"],
    "заапрувивши": ["заапрувив"],
    "заарендовав": ["заарендовавши"],
    "заарендовавши": ["заарендовав"],
    "заарендовывав": ["заарендовывавши"],
    "заарендовывавши": ["заарендовывав"],
    "заарестовав": ["заарестовавши"],
    "заарестовавши": ["заарестовав"],
    "заарестовать": ["арестовать"],
    "заарестовывав": ["заарестовывавши"],
    "заарестовывавши": ["заарестовывав"],
    "заарканив": ["заарканивши"],
    "заарканивав": ["заарканивавши"],
    "заарканивавши": ["заарканивав"],
    "заарканивать": ["арканить"],
    "заарканивши": ["заарканив"],
    "заартачиться": ["заупрямиться", "заерепениться"],
    "заархивировав": ["заархивировавши"],
    "заархивировавши": ["заархивировав"],
    "заархивировать": ["упаковать"],
    "заасфальтировав": ["заасфальтировавши"],
    "заасфальтировавши": ["заасфальтировав"],
    "заатар": ["затар", "эзов"],
    "заатмосферный": ["внеатмосферный"],
    "зааттестовав": ["зааттестовавши"],
    "зааттестовавши": ["зааттестовав"],
    "заатукав": ["заатукавши"],
    "заатукавши": ["заатукав"],
    "зааукав": ["зааукавши"],
    "зааукавши": ["зааукав"],
    "заахав": ["заахавши"],
    "заахавши": ["заахав"],
    "заахать": ["разахаться", "взахаться"],
    "забабахав": ["забабахавши"],
    "забабахавши": ["забабахав"],
    "забабахивав": ["забабахивавши"],
    "забабахивавши": ["забабахивав"],
    "забава": ["игра", "потеха", "развлечение", "шутка", "увеселение", "услада", "зазноба", "заноза"],
    "забавив": ["забавивши"],
    "забавивши": ["забавив"],
    "забавить": ["развлекать", "тешить"],
    "забавиться": ["забавляться"],
    "забавляв": ["забавлявши"],
    "забавлявши": ["забавляв"],
    "забавлять": ["развлекать", "занимать", "увеселять", "тешить", "смешить", "потешать"],
    "забавляться": ["развлекаться"],
    "забавно": ["увлекательно", "смешно", "потешно"],
    "забавный": ["потешный", "смешной", "занятный", "интересный", "любопытный"],
    "забагнути": ["забагти", "забажати"],
    "забагрив": ["забагривши"],
    "забагривав": ["забагривавши"],
    "забагривавши": ["забагривав"],
    "забагривши": ["забагрив"],
    "забагровев": ["забагровевши"],
    "забагровевши": ["забагровев"],
    "забагрянев": ["забагряневши"],
    "забагряневши": ["забагрянев"],
    "забагти": ["забагнути"],
    "забазировав": ["забазировавши"],
    "забазировавши": ["забазировав"],
    "забайкальский край": ["забайкалье"],
    "забалагурив": ["забалагуривши"],
    "забалагуривши": ["забалагурив"],
    "забаламутив": ["забаламутивши"],
    "забаламутивши": ["забаламутив"],
    "забаламутить": ["замутить"],
    "забаламучивав": ["забаламучивавши"],
    "забаламучивавши": ["забаламучивав"],
    "забалансировав": ["забалансировавши"],
    "забалансировавши": ["забалансировав"],
    "забалансовый": ["внебалансовый"],
    "забалдев": ["забалдевши"],
    "забалдевав": ["забалдевавши"],
    "забалдевавши": ["забалдевав"],
    "забалдевши": ["забалдев"],
    "забаливав": ["забаливавши"],
    "забаливавши": ["забаливав"],
    "забалластировав": ["забалластировавши"],
    "забалластировавши": ["забалластировав"],
    "забаллотировав": ["забаллотировавши"],
    "забаллотировавши": ["забаллотировав"],
    "забаллотировывав": ["забаллотировывавши"],
    "забаллотировывавши": ["забаллотировывав"],
    "забаловав": ["забаловавши"],
    "забаловавши": ["забаловав"],
    "забаловывав": ["забаловывавши"],
    "забаловывавши": ["забаловывав"],
    "забалтывав": ["забалтывавши"],
    "забалтывавши": ["забалтывав"],
    "забалтывать": ["примешивать"],
    "забальзамировав": ["забальзамировавши"],
    "забальзамировавши": ["забальзамировав"],
    "забальзамированный": ["набальзамированный"],
    "забальзамировать": ["набальзамировать", "мумифицировать"],
    "забанив": ["забанивши"],
    "забанивши": ["забанив"],
    "забанить": ["заблокировать", "отлучить"],
    "забарабанив": ["забарабанивши"],
    "забарабанивши": ["забарабанив"],
    "забарахлив": ["забарахливши"],
    "забарахливши": ["забарахлив"],
    "забарахляв": ["забарахлявши"],
    "забарахлявши": ["забарахляв"],
    "забарний": ["забарливий"],
    "забаррикадировав": ["забаррикадировавши"],
    "забаррикадировавши": ["забаррикадировав"],
    "забарствовав": ["забарствовавши"],
    "забарствовавши": ["забарствовав"],
    "забасив": ["забасивши"],
    "забасивши": ["забасив"],
    "забастовав": ["забастовавши"],
    "забастовавши": ["забастовав"],
    "забастовка": ["стачка"],
    "забастовывав": ["забастовывавши"],
    "забастовывавши": ["забастовывав"],
    "забатрачив": ["забатрачивши"],
    "забатрачивши": ["забатрачив"],
    "забахав": ["забахавши"],
    "забахавши": ["забахав"],
    "забацав": ["забацавши"],
    "забацавши": ["забацав"],
    "забацать": ["слепить", "сбацать"],
    "забацывав": ["забацывавши"],
    "забацывавши": ["забацывав"],
    "забашлив": ["забашливши"],
    "забашливши": ["забашлив"],
    "забашлить": ["забашлять"],
    "забашляв": ["забашлявши"],
    "забашлявши": ["забашляв"],
    "забашлять": ["заплатить", "забашлить"],
    "забаюкав": ["забаюкавши"],
    "забаюкавши": ["забаюкав"],
    "забаюкивав": ["забаюкивавши"],
    "забаюкивавши": ["забаюкивав"],
    "забаюкивать": ["убаюкивать"],
    "забаянив": ["забаянивши"],
    "забаянивши": ["забаянив"],
    "забвение": ["пренебрежение", "невнимание", "небрежение", "забытьё"],
    "забвенно": ["самозабвенно"],
    "забвенье": ["забвение"],
    "забегав": ["забегавши"],
    "забегавши": ["забегав"],
    "забегаловка": ["столовая", "закусочная", "едальня", "кабак", "рюмочная", "притон", "бистро"],
    "забеднев": ["забедневши", "обеднев", "обедневши"],
    "забедневши": ["забеднев", "обеднев", "обедневши"],
    "забедовав": ["забедовавши"],
    "забедовавши": ["забедовав"],
    "забежав": ["забежавши"],
    "забежавши": ["забежав"],
    "забежка": ["отклонение", "прекаляване", "крайност", "залитане"],
    "забежный": ["забеглый", "присталый", "пришатавшийся"],
    "забелев": ["забелевши"],
    "забелевши": ["забелев"],
    "забелеть": ["высветлиться", "побелеть", "забелеться"],
    "забелив": ["забеливши"],
    "забеливав": ["забеливавши"],
    "забеливавши": ["забеливав"],
    "забеливатель": ["отбеливатель"],
    "забеливать": ["белить", "забелять", "подбеливать"],
    "забеливши": ["забелив"],
    "забельшив": ["забельшивши"],
    "забельшивши": ["забельшив"],
    "забельшить": ["деть", "подевать", "затерять", "потерять"],
    "забеляв": ["забелявши"],
    "забелявши": ["забеляв"],
    "забелять": ["забеливать"],
    "заберег": ["заберега"],
    "заберега": ["заберег", "закраина", "припай", "шуга"],
    "заберегав": ["заберегавши"],
    "заберегавши": ["заберегав"],
    "забеременев": ["забеременевши"],
    "забеременевши": ["забеременев"],
    "забеременевший": ["очревателый"],
    "забеременеть": ["зачать", "понести", "затяжелеть", "забрюхатеть", "обрюхатеть", "залететь", "очреватеть"],
    "забесплатно": ["бесплатно", "даром"],
    "забеспокоив": ["забеспокоивши"],
    "забеспокоивши": ["забеспокоив"],
    "забеспокоиться": ["встревожиться"],
    "забетонировав": ["забетонировавши"],
    "забетонировавши": ["забетонировав"],
    "забздев": ["забздевши"],
    "забздевши": ["забздев"],
    "забиб": ["мавиз"],
    "забивав": ["забивавши"],
    "забивавши": ["забивав"],
    "забивать": ["перебивать", "давить", "набивать", "набирать", "занимать", "резервировать", "бронировать"],
    "забивать гвозди микроскопом": ["палить из пушки по воробьям"],
    "забивать голову": ["брать в голову", "грузиться", "грузить"],
    "забивать стрелку": ["стрелку забивать"],
    "забиваться": ["забираться", "прятаться", "засоряться", "закупориваться"],
    "забивши": ["забив"],
    "забидев": ["забидевши"],
    "забидевши": ["забидев"],
    "забижав": ["забижавши"],
    "забижавши": ["забижав"],
    "забиндив": ["забиндивши"],
    "забиндивши": ["забиндив"],
    "забиндить": ["закрепить", "назначить", "присвоить", "прицепить"],
    "забинтовав": ["забинтовавши"],
    "забинтовавши": ["забинтовав"],
    "забинтованный": ["перебинтованный"],
    "забинтовывав": ["забинтовывавши"],
    "забинтовывавши": ["забинтовывав"],
    "забирав": ["забиравши"],
    "забиравши": ["забирав"],
    "забирать": ["отбирать", "захватывать", "арестовывать", "задерживать", "ушивать", "разгоняться", "ускоряться", "отклоняться", "смещаться", "загораживать", "заграждать", "закрывать", "перекрывать", "защищать"],
    "забираться": ["браться", "карабкаться", "вскарабкиваться", "залезать", "проникать", "влезать"],
    "забить": ["вбить", "заколотить", "избить", "побить", "закупорить", "заткнуть", "набить", "проигнорировать", "забить болт", "передумать", "отказаться от намерения", "застолбить", "зарезервировать", "вкатить", "вколотить"],
    "забить болт": ["пренебречь", "проигнорировать", "забить", "болт забить", "болт завинтить", "болт положить", "положить болт", "покончить", "перестать", "заниматься", "забросить", "забить член", "член забить"],
    "забить гол": ["вогнать гол", "заколотить гол"],
    "забить стрелку": ["стрелку забить"],
    "забить хуй": ["наплевать", "проигнорировать", "забить болт", "болт забить", "положить хуй", "хуй забить", "хуй положить"],
    "забиться": ["задёргаться", "застучать"],
    "забичевав": ["забичевавши"],
    "забичевавши": ["забичевав"],
    "забияка": ["драчун", "ссорщик", "задира"],
    "забиячливый": ["задиристый"],
    "заблаговестив": ["заблаговестивши"],
    "заблаговестивши": ["заблаговестив"],
    "заблаговременно": ["заранее", "вовремя", "предварительно", "завременно"],
    "заблагодушествовав": ["заблагодушествовавши"],
    "заблагодушествовавши": ["заблагодушествовав"],
    "заблагорассудив": ["заблагорассудивши"],
    "заблагорассудивши": ["заблагорассудив"],
    "заблагорассудиться": ["пожелаться", "вздуматься", "захотеться"],
    "заблагоухав": ["заблагоухавши"],
    "заблагоухавши": ["заблагоухав"],
    "заблаженствовав": ["заблаженствовавши"],
    "заблаженствовавши": ["заблаженствовав"],
    "заблажив": ["заблаживши"],
    "заблаживши": ["заблажив"],
    "заблевав": ["заблевавши"],
    "заблевавши": ["заблевав"],
    "заблестев": ["заблестевши"],
    "заблестевши": ["заблестев"],
    "заблефовав": ["заблефовавши"],
    "заблефовавши": ["заблефовав"],
    "заблеяв": ["заблеявши"],
    "заблеявши": ["заблеяв"],
    "заблистав": ["заблиставши"],
    "заблиставши": ["заблистав"],
    "заблокировав": ["заблокировавши"],
    "заблокировавши": ["заблокировав"],
    "заблокировать": ["забанить"],
    "заблокнотив": ["заблокнотивши"],
    "заблокнотивши": ["заблокнотив"],
    "заблочив": ["заблочивши"],
    "заблочивши": ["заблочив"],
    "заблудив": ["заблудивши"],
    "заблудивши": ["заблудив"],
    "заблудити": ["заблудитися", "заблукати"],
    "заблудший": ["ошибшийся"],
    "заблуждав": ["заблуждавши"],
    "заблуждавши": ["заблуждав"],
    "заблуждаться": ["ошибаться", "обманываться"],
    "заблуждающийся": ["ошибающийся"],
    "заблуждение": ["ошибка"],
    "заблукати": ["заблудити"],
    "заблядовав": ["заблядовавши"],
    "заблядовавши": ["заблядовав"],
    "заблядовать": ["заблядствовать"],
    "заблёвывав": ["заблёвывавши"],
    "заблёвывавши": ["заблёвывав"],
    "забодав": ["забодавши"],
    "забодавши": ["забодав"],
    "забодай меня комар": ["укуси меня корова", "чтоб я провалился", "ей-ей", "оба-на"],
    "забоина": ["вмятина", "царапина"],
    "забойкотировав": ["забойкотировавши"],
    "забойкотировавши": ["забойкотировав"],
    "заболачивав": ["заболачивавши"],
    "заболачивавши": ["заболачивав"],
    "заболботав": ["заболботавши"],
    "заболботавши": ["заболботав"],
    "заболботать": ["забормотать"],
    "заболев": ["заболевши"],
    "заболевав": ["заболевавши"],
    "заболевавши": ["заболевав"],
    "заболевание": ["заболеванье", "болезнь", "недомогание"],
    "заболевши": ["заболев"],
    "заболеть": ["занедужить", "занемочь", "захворать", "расхвораться", "загореться", "увлечься"],
    "заболонь": ["оболонь", "блонь", "подкорье"],
    "заболотив": ["заболотивши"],
    "заболотивши": ["заболотив"],
    "заболоченный": ["болотистый", "топкий"],
    "заболтав": ["заболтавши"],
    "заболтавши": ["заболтав"],
    "заболяване": ["болест", "страдание"],
    "забомбив": ["забомбивши"],
    "забомбивши": ["забомбив"],
    "забомбить": ["забросать", "закидать"],
    "забон": ["лисон"],
    "забор": ["изгородь"],
    "заборанивав": ["заборанивавши"],
    "заборанивавши": ["заборанивав"],
    "заборанивать": ["боронить"],
    "заборишко": ["заборчик"],
    "забормотав": ["забормотавши"],
    "забормотавши": ["забормотав"],
    "заборная книжка": ["пайковая книжка"],
    "заборный": ["оградный", "непристойный", "нецензурный", "площадной"],
    "заборов": ["заборовши"],
    "заборовши": ["заборов"],
    "заборол": ["облам", "облом"],
    "заборонив": ["заборонивши"],
    "заборонивши": ["заборонив"],
    "забороновав": ["забороновавши"],
    "забороновавши": ["забороновав"],
    "забороновать": ["заборонить"],
    "заборонувати": ["заборонити"],
    "заборостроительнее": ["заборостроительней"],
    "заботив": ["заботивши"],
    "заботивши": ["заботив"],
    "заботить": ["беспокоить", "тревожить"],
    "заботиться": ["ухаживать", "тревожиться", "беспокоиться", "волноваться"],
    "заботчик": ["кормилец", "благодетель"],
    "забрав": ["забравши"],
    "забрава": ["забравяне", "забвение"],
    "забравши": ["забрав"],
    "забражничав": ["забражничавши"],
    "забражничавши": ["забражничав"],
    "забраковав": ["забраковавши"],
    "забраковавши": ["забраковав"],
    "забраковать": ["отбраковать", "отвергнуть"],
    "забраковывав": ["забраковывавши"],
    "забраковывавши": ["забраковывав"],
    "забранив": ["забранивши"],
    "забранивши": ["забранив"],
    "забранить": ["заругать"],
    "забрасывав": ["забрасывавши"],
    "забрасывавши": ["забрасывав"],
    "забрасывать": ["закидывать", "откидывать"],
    "забрать": ["взять", "присвоить", "получить", "приобрести", "захватить", "завоевать", "покорить", "добиться", "занять", "арестовать", "задержать", "овладеть", "заполнить", "подобрать", "сузить"],
    "забраться": ["залезть"],
    "забредав": ["забредавши"],
    "забредавши": ["забредав"],
    "забредив": ["забредивши"],
    "забредивши": ["забредив"],
    "забрезговав": ["забрезговавши"],
    "забрезговавши": ["забрезговав"],
    "забрезжив": ["забрезживши"],
    "забрезживши": ["забрезжив"],
    "забрезжиться": ["забрезжить"],
    "забрендировав": ["забрендировавши"],
    "забрендировавши": ["забрендировав"],
    "забренчав": ["забренчавши"],
    "забренчавши": ["забренчав"],
    "забренькав": ["забренькавши"],
    "забренькавши": ["забренькав"],
    "забрехав": ["забрехавши"],
    "забрехавши": ["забрехав"],
    "забрив": ["забривши"],
    "забривав": ["забривавши"],
    "забривавши": ["забривав"],
    "забривши": ["забрив"],
    "забрить затылок": ["отшить"],
    "забродив": ["забродивши"],
    "забродивши": ["забродив"],
    "забродить": ["заходить", "зашевелиться"],
    "забродяжничав": ["забродяжничавши"],
    "забродяжничавши": ["забродяжничав"],
    "забронзовев": ["забронзовевши"],
    "забронзовевши": ["забронзовев"],
    "забронировав": ["забронировавши"],
    "забронировавши": ["забронировав"],
    "забронировать": ["резервировать"],
    "заброс": ["забрасывание", "заброска", "рефлюкс", "заброшенность"],
    "забросав": ["забросавши"],
    "забросавши": ["забросав"],
    "забросив": ["забросивши"],
    "забросивши": ["забросив"],
    "забросить": ["закинуть", "зашвырнуть", "отправить", "доставить", "подвезти", "внедрить", "заронить"],
    "заброситься": ["проникнуть", "попасть", "добраться"],
    "заброшенность": ["запущенность"],
    "забрус": ["печатка", "печать"],
    "забрызгав": ["забрызгавши"],
    "забрызгавши": ["забрызгав"],
    "забрызганность": ["задрызганность", "заляпанность"],
    "забрызганный": ["заляпанный", "задрызганный", "запятнанный"],
    "забрызгивав": ["забрызгивавши"],
    "забрызгивавши": ["забрызгивав"],
    "забрыкав": ["забрыкавши"],
    "забрыкавши": ["забрыкав"],
    "забрюзжав": ["забрюзжавши"],
    "забрюзжавши": ["забрюзжав"],
    "забрюхатев": ["забрюхатевши"],
    "забрюхатевши": ["забрюхатев"],
    "забрюхатив": ["забрюхативши"],
    "забрюхативши": ["забрюхатив"],
    "забрюшив": ["забрюшивши"],
    "забрюшивши": ["забрюшив"],
    "забрякав": ["забрякавши"],
    "забрякавши": ["забрякав"],
    "забрякать": ["забренчать", "забряцать", "зазвякать"],
    "забряцав": ["забряцавши"],
    "забряцавши": ["забряцав"],
    "забряцать": ["забренчать", "забрякать", "зазвякать"],
    "забубенив": ["забубенивши"],
    "забубенивав": ["забубенивавши"],
    "забубенивавши": ["забубенивав"],
    "забубенивши": ["забубенив"],
    "забубнив": ["забубнивши"],
    "забубнивши": ["забубнив"],
    "забубённый": ["безрассудный", "беспечный", "бесшабашный", "залихватский", "лихой", "разгульный", "разудалый", "удалой", "ухарский", "шальной", "шалый", "безбашенный", "бешеный", "дикий", "исступлённый"],
    "забугорный": ["заграничный", "иностранный", "зарубежный"],
    "забугорщина": ["иностранщина", "иноземщина"],
    "забугорье": ["зарубежье"],
    "забузив": ["забузивши"],
    "забузивши": ["забузив"],
    "забуйствовав": ["забуйствовавши"],
    "забуйствовавши": ["забуйствовав"],
    "забуксировав": ["забуксировавши"],
    "забуксировавши": ["забуксировав"],
    "забуксовав": ["забуксовавши"],
    "забуксовавши": ["забуксовав"],
    "забулдыга": ["пропойца", "пьяница", "ханыга"],
    "забуллить": ["загнобить"],
    "забултыхав": ["забултыхавши"],
    "забултыхавши": ["забултыхав"],
    "забулькав": ["забулькавши"],
    "забулькавши": ["забулькав"],
    "забунтовав": ["забунтовавши"],
    "забунтовавши": ["забунтовав"],
    "забурев": ["забуревши"],
    "забуревши": ["забурев"],
    "забуреть": ["побуреть"],
    "забурив": ["забуривши"],
    "забуривав": ["забуривавши"],
    "забуривавши": ["забуривав"],
    "забуривши": ["забурив"],
    "забуриться": ["затусить", "забраться"],
    "забурлив": ["забурливши"],
    "забурливши": ["забурлив"],
    "забуровив": ["забуровивши"],
    "забуровивши": ["забуровив"],
    "забуртовав": ["забуртовавши"],
    "забуртовавши": ["забуртовав"],
    "забурчав": ["забурчавши"],
    "забурчавши": ["забурчав"],
    "забутив": ["забутивши"],
    "забутивши": ["забутив"],
    "забутовав": ["забутовавши"],
    "забутовавши": ["забутовав"],
    "забухав": ["забухавши"],
    "забухавши": ["забухав"],
    "забухать": ["забабахать", "загрохотать"],
    "забухнув": ["забухнувши"],
    "забухнувши": ["забухнув"],
    "забучив": ["забучивши"],
    "забучивав": ["забучивавши"],
    "забучивавши": ["забучивав"],
    "забучивши": ["забучив"],
    "забушевав": ["забушевавши"],
    "забушевавши": ["забушевав"],
    "забуянив": ["забуянивши"],
    "забуянивши": ["забуянив"],
    "забыв": ["забывши"],
    "забывав": ["забывавши"],
    "забывавши": ["забывав"],
    "забывание": ["забыванье"],
    "забыванье": ["забывание"],
    "забываться": ["задрёмывать", "отрешаться"],
    "забывчивый": ["рассеянный"],
    "забывши": ["забыв"],
    "забытовив": ["забытовивши"],
    "забытовивши": ["забытовив"],
    "забытовляв": ["забытовлявши"],
    "забытовлявши": ["забытовляв"],
    "забытый богом": ["забытый богом и людьми", "богом забытый"],
    "забыть": ["забвение"],
    "забыться": ["задремать", "заснуть", "отключиться", "замечтаться", "отвлечься", "отрешиться"],
    "забытьё": ["беспамятство", "дремота", "отрешённость"],
    "забычковав": ["забычковавши"],
    "забычковавши": ["забычковав"],
    "забэкапив": ["забэкапивши"],
    "забэкапивши": ["забэкапив"],
    "забэкапить": ["забекапить", "засейвить"],
    "забюджетировав": ["забюджетировавши"],
    "забюджетировавши": ["забюджетировав"],
    "забюллетенив": ["забюллетенивши"],
    "забюллетенивши": ["забюллетенив"],
    "забюрократив": ["забюрокративши"],
    "забюрокративши": ["забюрократив"],
    "забюрократизировав": ["забюрократизировавши"],
    "забюрократизировавши": ["забюрократизировав"],
    "забюрократить": ["забюрократизировать"],
    "забюрокрачивав": ["забюрокрачивавши"],
    "забюрокрачивавши": ["забюрокрачивав"],
    "завабив": ["завабивши"],
    "завабивши": ["завабив"],
    "заважживав": ["заважживавши"],
    "заважживавши": ["заважживав"],
    "заважничав": ["заважничавши"],
    "заважничавши": ["заважничав"],
    "заважничаться": ["возгордиться"],
    "завалив": ["заваливши"],
    "заваливав": ["заваливавши"],
    "заваливавши": ["заваливав"],
    "заваливши": ["завалив"],
    "завалинка": ["завалина"],
    "завались": ["полно", "полным-полно", "вагон и маленькая тележка", "хоть отбавляй"],
    "завалиться": ["затеряться", "опрокинуться", "обрушиться", "обвалиться", "накрениться", "провалиться", "потерпеть неудачу", "заявиться"],
    "завальный": ["обвальный", "завалящий", "провальный"],
    "завальсировав": ["завальсировавши"],
    "завальсировавши": ["завальсировав"],
    "завальцовка": ["вальцовка"],
    "заваляв": ["завалявши"],
    "завалявши": ["заваляв"],
    "завалящий": ["негодный", "ничтожный", "бросовый", "ненужный"],
    "заварзопаться": ["изварзакаться", "замурзакаться", "измурзакаться"],
    "заварив": ["заваривши"],
    "заваривав": ["заваривавши"],
    "заваривавши": ["заваривав"],
    "заваривши": ["заварив"],
    "заварка": ["заваривание"],
    "заварник": ["заварочный чайник", "заварной чайник", "запарник"],
    "заварной": ["заварочный"],
    "заварной чайник": ["заварочный чайник", "заварник"],
    "заварочный": ["заварной", "заварочный чайник", "заварной чайник"],
    "заварочный чайник": ["заварной чайник", "заварник"],
    "заваруха": ["сумятица", "беспорядок", "свалка", "ссора", "свара", "драка", "история", "приключение"],
    "завафлив": ["завафливши"],
    "завафливши": ["завафлив"],
    "завбаней": ["заведующий баней"],
    "завбачати": ["завбачувати"],
    "завдовев": ["завдовевши"],
    "завдовевши": ["завдовев"],
    "завдоветь": ["овдоветь"],
    "завевав": ["завевавши"],
    "завевавши": ["завевав"],
    "заведение": ["открытие", "создание", "предприятие", "учреждение", "обычай", "традиция"],
    "заведенье": ["заведение"],
    "заведовав": ["заведовавши"],
    "заведовавши": ["заведовав"],
    "заведовать": ["управлять", "руководить", "возглавлять"],
    "заведомо": ["несомненно", "явно"],
    "заведующий": ["управляющий", "администратор"],
    "заведывав": ["заведывавши"],
    "заведывавши": ["заведывав"],
    "завезение": ["доставка", "завоз"],
    "завезя": ["завёзши"],
    "завеивав": ["завеивавши"],
    "завеивавши": ["завеивав"],
    "завеивать": ["завевать"],
    "завеличав": ["завеличавши"],
    "завеличавши": ["завеличав"],
    "завенчав": ["завенчавши"],
    "завенчавши": ["завенчав"],
    "завенчать": ["увенчать", "увековечить"],
    "завера": ["заговор", "конспирация", "комплот"],
    "завербовав": ["завербовавши"],
    "завербовавши": ["завербовав"],
    "завербовать": ["подрядить", "привлекать", "нанять", "привлечь"],
    "завербоваться": ["поступить", "вступить", "наняться"],
    "завербовувати": ["вербувати"],
    "завербовывав": ["завербовывавши"],
    "завербовывавши": ["завербовывав"],
    "завербовывать": ["вербовать"],
    "заверезжав": ["заверезжавши"],
    "заверезжавши": ["заверезжав"],
    "заверение": ["аффирмация", "заверенье", "уверение"],
    "заверенье": ["заверение"],
    "заверещав": ["заверещавши"],
    "заверещавши": ["заверещав"],
    "заверещать": ["запищать", "засвистеть", "завизжать", "заверезжать", "завопить", "заголосить"],
    "заверив": ["заверивши"],
    "заверивши": ["заверив"],
    "завернув": ["завернувши"],
    "завернувши": ["завернув"],
    "завернуть": ["обернуть", "упаковать", "окутать", "повернуть", "поворотить", "зайти", "заехать", "заскочить", "навестить", "завинтить", "закрутить", "дать от ворот поворот", "повертать", "сказануть", "ляпнуть"],
    "завернуться": ["обернуться", "загнуться", "завинтиться", "завернуть"],
    "заверстав": ["заверставши"],
    "заверставши": ["заверстав"],
    "завертев": ["завертевши"],
    "завертевши": ["завертев"],
    "завертеться": ["захлопотаться"],
    "заверховодив": ["заверховодивши"],
    "заверховодивши": ["заверховодив"],
    "завершав": ["завершавши"],
    "завершавши": ["завершав"],
    "завершавшись": ["оканчивавшись", "заканчивавшись"],
    "завершать": ["заканчивать", "оканчивать", "кончать"],
    "завершающий": ["заканчивающий", "конечный", "последний"],
    "завершаясь": ["оканчиваясь", "заканчиваясь"],
    "завершение": ["окончание", "заключение"],
    "завершивши": ["завершив"],
    "завершинив": ["завершинивши"],
    "завершинивши": ["завершинив"],
    "завершить": ["закончить"],
    "завершённость": ["законченность", "оконченность"],
    "завершённый": ["законченный"],
    "заверяв": ["заверявши"],
    "заверявши": ["заверяв"],
    "завес": ["завеса", "завесь"],
    "завеса": ["занавес"],
    "завесив": ["завесивши"],
    "завесивши": ["завесив"],
    "завесь": ["завес", "завеса"],
    "заветировав": ["заветировавши"],
    "заветировавши": ["заветировав"],
    "заветный": ["сокровенный", "тайный", "задушевный"],
    "заветовав": ["заветовавши"],
    "заветовавши": ["заветовав"],
    "заветрев": ["заветревши"],
    "заветревав": ["заветревавши"],
    "заветревавши": ["заветревав"],
    "заветревать": ["заветреваться", "обветриваться"],
    "заветреваться": ["заветревать", "обветриваться"],
    "заветревши": ["заветрев"],
    "заветрив": ["заветривши"],
    "заветривав": ["заветривавши"],
    "заветривавши": ["заветривав"],
    "заветривши": ["заветрив"],
    "заветы ильича": ["заветы"],
    "завечеряв": ["завечерявши"],
    "завечерявши": ["завечеряв"],
    "завешав": ["завешавши"],
    "завешавши": ["завешав"],
    "завешивав": ["завешивавши"],
    "завешивавши": ["завешивав"],
    "завещав": ["завещавши"],
    "завещавши": ["завещав"],
    "завещанье": ["завещание"],
    "завеяв": ["завеявши"],
    "завеявши": ["завеяв"],
    "завздыхав": ["завздыхавши"],
    "завздыхавши": ["завздыхав"],
    "завзятый": ["настоящий", "истинный", "заядлый", "азартный"],
    "завибрировав": ["завибрировавши"],
    "завибрировавши": ["завибрировав"],
    "завив": ["завивши"],
    "завивав": ["завивавши"],
    "завивавши": ["завивав"],
    "завиванье": ["завивание"],
    "завивать": ["вить", "закручивать", "крутиться"],
    "завивши": ["завив"],
    "завидев": ["завидевши"],
    "завидевши": ["завидев"],
    "завидовав": ["завидовавши"],
    "завидовавши": ["завидовав"],
    "завидовать": ["испытывать зависть"],
    "завидущий": ["завистливый"],
    "завизжав": ["завизжавши"],
    "завизжавши": ["завизжав"],
    "завизировав": ["завизировавши"],
    "завизировавши": ["завизировав"],
    "завиляв": ["завилявши"],
    "завилявши": ["завиляв"],
    "завинив": ["завинивши"],
    "завинивши": ["завинив"],
    "завинить": ["обвинить", "осудить"],
    "завинтив": ["завинтивши"],
    "завинтивши": ["завинтив"],
    "завинтиться": ["завернуться", "закрутиться"],
    "завинчивав": ["завинчивавши"],
    "завинчивавши": ["завинчивав"],
    "завинчиваться": ["закручиваться", "завёртываться"],
    "завинчивающийся": ["закручивающийся", "прикручивающийся", "привинчивающийся"],
    "завиняв": ["завинявши"],
    "завинявши": ["завиняв"],
    "завинять": ["обвинять", "осуждать"],
    "завирав": ["завиравши"],
    "завиравши": ["завирав"],
    "завиральный": ["вздорный", "нелепый", "надуманный", "пустой", "вольнодумный"],
    "завирать": ["врать", "привирать"],
    "завируха": ["врун", "врунья", "враль"],
    "зависав": ["зависавши"],
    "зависавши": ["зависав"],
    "зависев": ["зависевши"],
    "зависевши": ["зависев"],
    "зависеть": ["быть зависимым"],
    "зависимость": ["аддикция"],
    "зависнув": ["зависнувши"],
    "зависнувши": ["зависнув"],
    "зависнуть": ["замереть", "остановиться", "повиснуть", "подвиснуть", "грохнуться"],
    "завистливый": ["завистный", "завидующий", "ретивый", "ревностный", "жадный"],
    "завистничав": ["завистничавши"],
    "завистничавши": ["завистничав"],
    "завистничать": ["завидовать"],
    "зависть": ["завидки"],
    "зависший": ["зависнувший"],
    "завитушка": ["завиток"],
    "завихляв": ["завихлявши"],
    "завихлявши": ["завихляв"],
    "завихрение": ["турбуленция", "чудачество", "чудинка", "загибон", "заскок", "закидон", "странность"],
    "завихренье": ["завихрение"],
    "завихрив": ["завихривши"],
    "завихривав": ["завихривавши"],
    "завихривавши": ["завихривав"],
    "завихривши": ["завихрив"],
    "завихряв": ["завихрявши"],
    "завихрявши": ["завихряв"],
    "завихрённость": ["закрученность", "завихрение", "вихрь"],
    "завлаб": ["младореформатор", "чикагские мальчики", "мальчики в коротких штанишках"],
    "завлабораторией": ["завлаб"],
    "завладев": ["завладевши"],
    "завладевав": ["завладевавши"],
    "завладевавши": ["завладевав"],
    "завладевать": ["овладевать"],
    "завладевши": ["завладев"],
    "завлажнев": ["завлажневши"],
    "завлажневши": ["завлажнев"],
    "завлекав": ["завлекавши"],
    "завлекавши": ["завлекав"],
    "завлекаловка": ["замануха"],
    "завлечь": ["заманить", "вовлечь", "втянуть"],
    "завмаг": ["заведующий магазином"],
    "завод": ["фабрика", "конный завод", "конезавод"],
    "заводец": ["заводишко"],
    "заводив": ["заводивши"],
    "заводивши": ["заводив"],
    "заводик": ["заводец"],
    "заводнив": ["заводнивши"],
    "заводнивши": ["заводнив"],
    "заводняв": ["заводнявши"],
    "заводнявши": ["заводняв"],
    "заводок": ["заводь"],
    "заводчанин": ["заводец"],
    "заводь": ["омут", "затон"],
    "завоевав": ["завоевавши"],
    "завоевавши": ["завоевав"],
    "завоевание": ["захват", "покорение", "достижение"],
    "завоеванье": ["завоевание"],
    "завожжав": ["завожжавши"],
    "завожжавши": ["завожжав"],
    "завоз": ["привоз"],
    "завозив": ["завозивши"],
    "завозивши": ["завозив"],
    "завозной": ["привозной", "привезённый", "импортируемый"],
    "завозражав": ["завозражавши"],
    "завозражавши": ["завозражав"],
    "заволакивав": ["заволакивавши"],
    "заволакивавши": ["заволакивав"],
    "заволакивать": ["подёргивать", "застилать", "затуманивать"],
    "заволжск": ["владычное", "заволжье"],
    "заволновав": ["заволновавши"],
    "заволновавши": ["заволновав"],
    "заволноваться": ["заколебаться", "забеспокоиться", "затревожиться", "встревожиться"],
    "заволокитив": ["заволокитивши"],
    "заволокитивши": ["заволокитив"],
    "заволокитить": ["задержать", "затянуть"],
    "заволокичивав": ["заволокичивавши"],
    "заволокичивавши": ["заволокичивав"],
    "заволокнув": ["заволокнувши"],
    "заволокнувши": ["заволокнув"],
    "заволосатев": ["заволосатевши"],
    "заволосатевши": ["заволосатев"],
    "заволочив": ["заволочивши"],
    "заволочивши": ["заволочив"],
    "заволочить": ["заволочь"],
    "завольничав": ["завольничавши"],
    "завольничавши": ["завольничав"],
    "завоняв": ["завонявши"],
    "завонявши": ["завоняв"],
    "завоображав": ["завоображавши"],
    "завоображавши": ["завоображав"],
    "завопив": ["завопивши"],
    "завопивши": ["завопив"],
    "завораживав": ["завораживавши"],
    "завораживавши": ["завораживав"],
    "завораживать": ["заколдовывать", "очаровывать", "пленять"],
    "завораживающий": ["зачаровывающий", "околдовывающий"],
    "заворачивав": ["заворачивавши"],
    "заворачивавши": ["заворачивав"],
    "заворачивать": ["обёртывать", "упаковывать", "окутывать", "завёртывать", "поворачивать", "сворачивать", "заходить", "заезжать", "заскакивать", "навещать", "завинчивать", "закручивать", "давать от ворот поворот", "вертать"],
    "заворковав": ["заворковавши"],
    "заворковавши": ["заворковав"],
    "заворовав": ["заворовавши"],
    "заворовавши": ["заворовав"],
    "заворожив": ["завороживши"],
    "завороживши": ["заворожив"],
    "заворожить": ["заколдовать", "зачаровать", "очаровать", "пленить"],
    "заворожувати": ["зачаровувати"],
    "заворожённо": ["зачарованно"],
    "заворожённый": ["очарованный", "околдованный"],
    "заворонив": ["заворонивши"],
    "заворонивши": ["заворонив"],
    "заворотив": ["заворотивши"],
    "заворотивши": ["заворотив"],
    "заворотя оглоблю": ["немедля", "немедленно", "тотчас"],
    "заворочав": ["заворочавши"],
    "заворочавши": ["заворочав"],
    "заворошив": ["заворошивши"],
    "заворошивши": ["заворошив"],
    "заворчав": ["заворчавши"],
    "заворчавши": ["заворчав"],
    "завосклицав": ["завосклицавши"],
    "завосклицавши": ["завосклицав"],
    "завострив": ["завостривши"],
    "завостривши": ["завострив"],
    "завостряв": ["завострявши"],
    "завострявши": ["завостряв"],
    "завоёвывав": ["завоёвывавши"],
    "завоёвывавши": ["завоёвывав"],
    "завраждовав": ["завраждовавши"],
    "завраждовавши": ["завраждовав"],
    "завременно": ["заранее", "заблаговременно"],
    "завропод": ["зауропод", "зауропода"],
    "завсегда": ["всегда", "постоянно"],
    "завспоминав": ["завспоминавши"],
    "завспоминавши": ["завспоминав"],
    "завторив": ["завторивши"],
    "завторивши": ["завторив"],
    "завтрак": ["перехваток", "снеданье", "ранний кус"],
    "завтракав": ["завтракавши"],
    "завтракавши": ["завтракав"],
    "завуалировав": ["завуалировавши"],
    "завуалировавши": ["завуалировав"],
    "завуалированно": ["скрытно", "замаскированно"],
    "завуалированность": ["замаскированность", "закамуфлированность"],
    "завуалированный": ["покрытый", "закрытый", "неявный"],
    "завузький": ["вужчий"],
    "завшивев": ["завшивевши"],
    "завшивевши": ["завшивев"],
    "завъ": ["партав", "нур", "дурахш"],
    "завършек": ["свършек", "край", "финал", "развръзка", "заключение"],
    "завыв": ["завывши"],
    "завывав": ["завывавши"],
    "завывавши": ["завывав"],
    "завывать": ["выть"],
    "завывши": ["завыв"],
    "завысив": ["завысивши"],
    "завысивши": ["завысив"],
    "завышав": ["завышавши"],
    "завышавши": ["завышав"],
    "завьюжив": ["завьюживши"],
    "завьюживши": ["завьюжив"],
    "завьюжить": ["запуржить"],
    "завьючив": ["завьючивши"],
    "завьючивав": ["завьючивавши"],
    "завьючивавши": ["завьючивав"],
    "завьючивши": ["завьючив"],
    "завяв": ["завявши"],
    "завявши": ["завяв"],
    "завядав": ["завядавши"],
    "завядавши": ["завядав"],
    "завядать": ["вянуть"],
    "завязав": ["завязавши"],
    "завязавши": ["завязав"],
    "завязать": ["связать", "обвязать", "перевязать", "установить", "начать", "образовать", "закончить", "прекратить"],
    "завязив": ["завязивши"],
    "завязивши": ["завязив"],
    "завязить": ["увязить"],
    "завязиться": ["завязнуть"],
    "завязка": ["абстиненция"],
    "завязнув": ["завязнувши"],
    "завязнувши": ["завязнув"],
    "завязывав": ["завязывавши"],
    "завязывавши": ["завязывав"],
    "завязыванье": ["завязывание"],
    "завязывать": ["связывать", "обвязывать", "перевязывать", "устанавливать", "начинать", "образовывать", "заканчивать", "прекращать"],
    "завязь": ["зачаток", "зародыш"],
    "завялив": ["завяливши"],
    "завяливав": ["завяливавши"],
    "завяливавши": ["завяливав"],
    "завяливши": ["завялив"],
    "завянув": ["завянувши"],
    "завянувши": ["завянув"],
    "завянуть": ["увянуть", "засохнуть"],
    "завять": ["завянуть", "засохнуть", "поникнуть", "сдаться", "сникнуть"],
    "завёзши": ["завезя"],
    "завёрнутый": ["обёрнутый"],
    "завёрстанный": ["свёрстанный"],
    "завёрстывав": ["завёрстывавши"],
    "завёрстывавши": ["завёрстывав"],
    "завёрстывать": ["заменять"],
    "завёртывав": ["завёртывавши"],
    "завёртывавши": ["завёртывав"],
    "завёртывать": ["заворачивать"],
    "завёртываться": ["заворачиваться"],
    "загавкав": ["загавкавши"],
    "загавкавши": ["загавкав"],
    "загавкать": ["залаять", "затявкать", "забрехать"],
    "загадав": ["загадавши"],
    "загадавши": ["загадав"],
    "загадив": ["загадивши"],
    "загадивши": ["загадив"],
    "загадка": ["тайна", "мистерия", "секрет", "энигма"],
    "загадочно": ["таинственно"],
    "загадочность": ["таинственность", "секретность"],
    "загадочный": ["таинственный", "таинственное"],
    "загадывав": ["загадывавши"],
    "загадывавши": ["загадывав"],
    "загадыванье": ["загадывание"],
    "загаерничав": ["загаерничавши"],
    "загаерничавши": ["загаерничав"],
    "загаживав": ["загаживавши"],
    "загаживавши": ["загаживав"],
    "загазовав": ["загазовавши"],
    "загазовавши": ["загазовав"],
    "загазовывав": ["загазовывавши"],
    "загазовывавши": ["загазовывав"],
    "загайкав": ["загайкавши"],
    "загайкавши": ["загайкав"],
    "загалдев": ["загалдевши"],
    "загалдевши": ["загалдев"],
    "загамив": ["загамивши"],
    "загамивши": ["загамив"],
    "загамить": ["загаметь", "загалдеть", "зашуметь", "зашуметься"],
    "загамиться": ["загамить", "зашуметь", "зашуметься", "загамкать", "загавкать", "забрехать", "залаять"],
    "заганув": ["заганувши"],
    "заганувши": ["заганув"],
    "загарбний": ["загарбницький"],
    "загарпунив": ["загарпунивши"],
    "загарпунивав": ["загарпунивавши"],
    "загарпунивавши": ["загарпунивав"],
    "загарпунивши": ["загарпунив"],
    "загартовування": ["загартування"],
    "загасав": ["загасавши"],
    "загасавши": ["загасав"],
    "загасать": ["гаснуть", "потухать"],
    "загасающий": ["гаснущий"],
    "загасив": ["загасивши"],
    "загасивши": ["загасив"],
    "загасить": ["затушить", "замочить", "убить", "ликвидировать"],
    "загаснув": ["загаснувши"],
    "загаснувши": ["загаснув"],
    "загаснуть": ["погаснуть", "потухнуть"],
    "загатив": ["загативши"],
    "загативши": ["загатив"],
    "загачивав": ["загачивавши"],
    "загачивавши": ["загачивав"],
    "загашав": ["загашавши"],
    "загашавши": ["загашав"],
    "загашати": ["загашувати"],
    "загашать": ["гасить", "тушить"],
    "загашивав": ["загашивавши"],
    "загашивавши": ["загашивав"],
    "загашник": ["заначка", "тайник", "потайной", "помещение"],
    "загашувати": ["загашати"],
    "загваздав": ["загваздавши"],
    "загваздавши": ["загваздав"],
    "загваздать": ["изгваздать"],
    "загваздывав": ["загваздывавши"],
    "загваздывавши": ["загваздывав"],
    "загвоздив": ["загвоздивши"],
    "загвоздивши": ["загвоздив"],
    "загвоздка": ["затруднение", "помеха"],
    "загерметизировав": ["загерметизировавши"],
    "загерметизировавши": ["загерметизировав"],
    "загиб": ["изгиб", "искривление", "уклон", "заскок", "загибон"],
    "загибав": ["загибавши"],
    "загибавши": ["загибав"],
    "загибать": ["сгибать", "заливать", "привирать", "брехать", "прогуливать", "задвигать"],
    "загиблий": ["погиблий"],
    "загибщик": ["перегибщик"],
    "загикав": ["загикавши"],
    "загикавши": ["загикав"],
    "загинав": ["загинавши"],
    "загинавши": ["загинав"],
    "загинать": ["загибать", "клонить", "склонять", "сквернословить", "ругаться", "врать", "обманывать"],
    "загинув": ["загинувши"],
    "загинувши": ["загинув"],
    "загинуть": ["погибнуть"],
    "загипнотизировав": ["загипнотизировавши"],
    "загипнотизировавши": ["загипнотизировав"],
    "загипсовав": ["загипсовавши"],
    "загипсовавши": ["загипсовав"],
    "заглавие": ["заголовок"],
    "заглавная буква": ["прописная буква", "большая буква"],
    "заглавная страница": ["титульный лист", "форзац", "главная страница", "первая страница"],
    "заглавье": ["заглавие"],
    "заглагольный": ["постглагольный"],
    "загладив": ["загладивши"],
    "загладивши": ["загладив"],
    "заглаживав": ["заглаживавши"],
    "заглаживавши": ["заглаживав"],
    "заглазно": ["позаглазно", "по-за глаз", "позаглаз"],
    "заглазный": ["заочный", "забытый", "забытый богом", "уединённый", "затерянный", "отдалённый"],
    "заглатывав": ["заглатывавши"],
    "заглатывавши": ["заглатывав"],
    "заглодав": ["заглодавши"],
    "заглодавши": ["заглодав"],
    "заглотав": ["заглотавши"],
    "заглотавши": ["заглотав"],
    "заглотив": ["заглотивши"],
    "заглотивши": ["заглотив"],
    "заглотнув": ["заглотнувши"],
    "заглотнувши": ["заглотнув"],
    "заглохлый": ["запущенный", "заброшенный", "заглохший"],
    "заглохнув": ["заглохнувши"],
    "заглохнувши": ["заглохнув"],
    "заглубив": ["заглубивши"],
    "заглубивши": ["заглубив"],
    "заглубляв": ["заглублявши"],
    "заглублявши": ["заглубляв"],
    "заглубляться": ["углубляться"],
    "заглушав": ["заглушавши"],
    "заглушавши": ["заглушав"],
    "заглушать": ["глушить", "забивать"],
    "заглушив": ["заглушивши"],
    "заглушивши": ["заглушив"],
    "заглядев": ["заглядевши"],
    "заглядевши": ["заглядев"],
    "заглядеться": ["засмотреться", "увлечься", "очароваться"],
    "заглядывав": ["заглядывавши"],
    "заглядывавши": ["заглядывав"],
    "заглядыванье": ["заглядывание"],
    "заглядываться": ["глазеть", "засматриваться"],
    "заглянув": ["заглянувши"],
    "заглянувши": ["заглянув"],
    "заглянуть": ["посмотреть", "зайти", "заскочить"],
    "заглянцевев": ["заглянцевевши"],
    "заглянцевевши": ["заглянцевев"],
    "загнав": ["загнавши"],
    "загнавши": ["загнав"],
    "загнаивав": ["загнаивавши"],
    "загнаивавши": ["загнаивав"],
    "загнать": ["завести", "сбагрить"],
    "загнета": ["загнетка"],
    "загнетка": ["загнета", "загнётка", "загнёт", "загнеть", "загнива", "горнушка", "жароток", "порск", "бабурка", "бабка", "загнеток", "загнёток", "угли", "суглица", "жар"],
    "загнив": ["загнивши"],
    "загнивав": ["загнивавши"],
    "загнивавши": ["загнивав"],
    "загнивание": ["протухание"],
    "загнивши": ["загнив"],
    "загнобив": ["загнобивши"],
    "загнобивши": ["загнобив"],
    "загнобить": ["замучить", "извести"],
    "загноив": ["загноивши"],
    "загноивши": ["загноив"],
    "загноиться": ["деградировать"],
    "загнув": ["загнувши"],
    "загнувши": ["загнув"],
    "загнусавив": ["загнусавивши"],
    "загнусавивши": ["загнусавив"],
    "загнусив": ["загнусивши"],
    "загнусивши": ["загнусив"],
    "загнуть": ["согнуть", "изогнуть", "повернуть", "свернуть", "сказать", "произнести", "задвинуть", "прогулять"],
    "заговаривав": ["заговаривавши"],
    "заговаривавши": ["заговаривав"],
    "заговариванье": ["заговаривание"],
    "заговаривать": ["ворожить"],
    "заговаривать зубы": ["пускать пыль в глаза", "вешать лапшу на уши"],
    "заговев": ["заговевши"],
    "заговевши": ["заговев"],
    "заговены": ["заговенье", "заговины"],
    "заговенье": ["заговены", "заговины", "мясопустье"],
    "заговины": ["заговенье", "заговены"],
    "заговняв": ["заговнявши"],
    "заговнявши": ["заговняв"],
    "заговор": ["комплот", "сговор"],
    "заговорив": ["заговоривши"],
    "заговоривши": ["заговорив"],
    "заговорить зубы": ["зубы заговорить"],
    "заговорщицки": ["заговорщически", "по-заговорщицки"],
    "загоготав": ["загоготавши"],
    "загоготавши": ["загоготав"],
    "загогулина": ["завитушка", "извилина", "крокозябра"],
    "загогулинка": ["изгиб", "зигзаг", "завиток", "завитушка", "закорючка", "поворот"],
    "загодя": ["заранее", "заблаговременно", "наперёд", "предварительно"],
    "заголив": ["заголивши"],
    "заголивши": ["заголив"],
    "заголиться": ["обнажиться"],
    "заголовок": ["заглавие", "название"],
    "заголодав": ["заголодавши"],
    "заголодавши": ["заголодав"],
    "заголосив": ["заголосивши"],
    "заголосивши": ["заголосив"],
    "заголубев": ["заголубевши"],
    "заголубевши": ["заголубев"],
    "заголяв": ["заголявши"],
    "заголявши": ["заголяв"],
    "заголять": ["оголять"],
    "загомонив": ["загомонивши"],
    "загомонивши": ["загомонив"],
    "загон": ["травля", "загонка"],
    "загоношиться": ["захлопотать", "засуетиться", "завозиться"],
    "загоняв": ["загонявши"],
    "загонявши": ["загоняв"],
    "загорав": ["загоравши"],
    "загоравши": ["загорав"],
    "загораживав": ["загораживавши"],
    "загораживавши": ["загораживав"],
    "загораживать": ["огораживать", "заслонять", "закрывать", "перекрывать"],
    "загорать": ["простаивать"],
    "загордитися": ["зазнатися"],
    "загорев": ["загоревши"],
    "загоревав": ["загоревавши"],
    "загоревавши": ["загоревав"],
    "загоревши": ["загорев"],
    "загорелый": ["загоревший", "смуглый"],
    "загореться": ["воспламениться", "загореть", "запылать", "засветиться", "заблестеть", "засиять", "засверкать"],
    "загорланив": ["загорланивши"],
    "загорланивши": ["загорланив"],
    "загород": ["пригород"],
    "загородив": ["загородивши"],
    "загородивши": ["загородив"],
    "загородить": ["заслонить", "закрыть", "перекрыть"],
    "загородный": ["пригородный", "дачный"],
    "загоряти": ["загорати"],
    "загорячив": ["загорячивши"],
    "загорячивши": ["загорячив"],
    "загострювання": ["загострення"],
    "заготавливав": ["заготавливавши"],
    "заготавливавши": ["заготавливав"],
    "заготавливать": ["готовить", "приготовлять", "заготовлять", "запасать"],
    "заготовив": ["заготовивши"],
    "заготовивши": ["заготовив"],
    "заготовительный": ["заготовочный"],
    "заготовка": ["заготавливание", "заготовление", "полуфабрикат", "болванка"],
    "заготовление": ["заготовка"],
    "заготовляв": ["заготовлявши"],
    "заготовлявши": ["заготовляв"],
    "заготовлять": ["готовить", "приготовлять", "заготавливать"],
    "заготовщик": ["заготовитель"],
    "заграбастав": ["заграбаставши"],
    "заграбаставши": ["заграбастав"],
    "заграбастать": ["захапать", "прибрать к рукам", "урвать", "отхватить"],
    "заграбастывав": ["заграбастывавши"],
    "заграбастывавши": ["заграбастывав"],
    "заграбастывать": ["грабастать"],
    "заграбив": ["заграбивши"],
    "заграбивши": ["заграбив"],
    "заградив": ["заградивши"],
    "заградивши": ["заградив"],
    "заградительный отряд": ["заградотряд"],
    "заградить": ["загородить", "преградить"],
    "заградотряд": ["заградительный отряд"],
    "заграждав": ["заграждавши"],
    "заграждавши": ["заграждав"],
    "заграждать": ["загораживать", "преграждать"],
    "загражденье": ["заграждение"],
    "заграница": ["зарубежье", "чужбина"],
    "заграничный": ["зарубежный", "иноземный", "иностранный"],
    "заграничный паспорт": ["загранпаспорт", "зп", "загранник", "загран"],
    "загранпаспорт": ["заграничный паспорт", "загранник", "загран"],
    "загранплаванье": ["загранплавание"],
    "загранпредставительство": ["заграничное представительство"],
    "заграяв": ["заграявши"],
    "заграявши": ["заграяв"],
    "загребав": ["загребавши"],
    "загребавши": ["загребав"],
    "загребать": ["сгребать", "грести"],
    "загрезив": ["загрезивши"],
    "загрезивши": ["загрезив"],
    "загремев": ["загремевши"],
    "загремевши": ["загремев"],
    "загриженост": ["угриженост", "грижа", "тревога", "безпокойство", "вълнение"],
    "загримасничав": ["загримасничавши"],
    "загримасничавши": ["загримасничав"],
    "загримировав": ["загримировавши"],
    "загримировавши": ["загримировав"],
    "загримировывав": ["загримировывавши"],
    "загримировывавши": ["загримировывав"],
    "загримировывать": ["гримировать"],
    "загрипповав": ["загрипповавши"],
    "загрипповавши": ["загрипповав"],
    "загрифованный": ["грифованный", "секретный", "закрытый", "конфиденциальный"],
    "загробив": ["загробивши"],
    "загробивши": ["загробив"],
    "загробить": ["угробить"],
    "загробний": ["загробовий", "неземний"],
    "загробный": ["потусторонний", "замогильный", "стигийский"],
    "загробный мир": ["потусторонний мир", "тот свет", "загробное царство", "царство мёртвых", "мир иной", "грядущий мир"],
    "загромождав": ["загромождавши"],
    "загромождавши": ["загромождав"],
    "загромождать": ["преграждать", "затенять", "скрывать", "перегружать"],
    "загромоздив": ["загромоздивши"],
    "загромоздивши": ["загромоздив"],
    "загромыхав": ["загромыхавши"],
    "загромыхавши": ["загромыхав"],
    "загрос": ["патак", "поштекух"],
    "загрохав": ["загрохавши"],
    "загрохавши": ["загрохав"],
    "загрохотав": ["загрохотавши"],
    "загрохотавши": ["загрохотав"],
    "загрубев": ["загрубевши"],
    "загрубевши": ["загрубев"],
    "загрубляв": ["загрублявши"],
    "загрублявши": ["загрубляв"],
    "загрублять": ["черствить", "огрублять", "десенсибилизировать"],
    "загружав": ["загружавши"],
    "загружавши": ["загружав"],
    "загружаться": ["грузиться"],
    "загрузив": ["загрузивши"],
    "загрузивши": ["загрузив"],
    "загрузить": ["нагрузить", "занять", "заложить", "закачать"],
    "загрузнув": ["загрузнувши"],
    "загрузнувши": ["загрузнув"],
    "загрузочный сектор": ["бутсектор"],
    "загрунтовав": ["загрунтовавши"],
    "загрунтовавши": ["загрунтовав"],
    "загрунтовывав": ["загрунтовывавши"],
    "загрунтовывавши": ["загрунтовывав"],
    "загрустив": ["загрустивши"],
    "загрустивши": ["загрустив"],
    "загрустить": ["затосковать", "помрачнеть"],
    "загрызав": ["загрызавши"],
    "загрызавши": ["загрызав"],
    "загрязнив": ["загрязнивши"],
    "загрязнивши": ["загрязнив"],
    "загрязнить": ["замарать", "запачкать", "испачкать", "запятнать"],
    "загрязнув": ["загрязнувши"],
    "загрязнувши": ["загрязнув"],
    "загрязняв": ["загрязнявши"],
    "загрязнявши": ["загрязняв"],
    "загрязнять": ["пачкать", "марать"],
    "загрязняться": ["пачкаться"],
    "загубив": ["загубивши"],
    "загубивши": ["загубив"],
    "загубить": ["погубить", "угробить", "убить"],
    "загуглив": ["загугливши"],
    "загугливши": ["загуглив"],
    "загугнив": ["загугнивши"],
    "загугнивши": ["загугнив"],
    "загудев": ["загудевши"],
    "загудевши": ["загудев"],
    "загудеть": ["загреметь"],
    "загудронировав": ["загудронировавши"],
    "загудронировавши": ["загудронировав"],
    "загукав": ["загукавши"],
    "загукавши": ["загукав"],
    "загуливав": ["загуливавши"],
    "загуливавши": ["загуливав"],
    "загуляв": ["загулявши"],
    "загулявши": ["загуляв"],
    "загустев": ["загустевши"],
    "загустевав": ["загустевавши"],
    "загустевавши": ["загустевав"],
    "загустевши": ["загустев"],
    "загустив": ["загустивши"],
    "загустивши": ["загустив"],
    "загутарив": ["загутаривши"],
    "загутаривши": ["загутарив"],
    "загуторив": ["загуторивши"],
    "загуторивши": ["загуторив"],
    "загущав": ["загущавши"],
    "загущавши": ["загущав"],
    "зад": ["тыл", "арьергард", "задница", "попа", "попка", "ягодицы", "задворки", "околица"],
    "задабривав": ["задабривавши"],
    "задабривавши": ["задабривав"],
    "задав": ["задавши"],
    "задавав": ["задававши"],
    "задававши": ["задавав"],
    "задавака": ["воображала", "зазнайка", "задавала"],
    "задавала": ["воображала", "зазнайка", "задавака"],
    "задаваться": ["озадачиваться", "обременяться", "поручаться", "устанавливаться", "определяться"],
    "задавив": ["задавивши"],
    "задавивши": ["задавив"],
    "задавливав": ["задавливавши"],
    "задавливавши": ["задавливав"],
    "задавши": ["задав"],
    "задалбливав": ["задалбливавши"],
    "задалбливавши": ["задалбливав"],
    "задалбывав": ["задалбывавши"],
    "задалбывавши": ["задалбывав"],
    "задание": ["задача", "указание", "упражнение"],
    "заданье": ["задание"],
    "задар": ["зара"],
    "задарив": ["задаривши"],
    "задаривав": ["задаривавши"],
    "задаривавши": ["задаривав"],
    "задаривши": ["задарив"],
    "задарма": ["бесплатно", "безвозмездно", "даром", "за так", "за просто так", "задаром", "за здорово живёшь", "за красивые глаза", "за спасибо"],
    "задаром": ["бесплатно", "даром", "за так", "за просто так", "за здорово живёшь", "за красивые глаза", "задарма", "безвозмездно", "за спасибо"],
    "задастый": ["толстозадый", "широкозадый"],
    "задатировав": ["задатировавши"],
    "задатировавши": ["задатировав"],
    "задатки": ["талант", "дар", "дарование", "одарённость", "талантливость", "даровитость", "способность"],
    "задаток": ["аванс", "залог", "зачатки", "зародыши"],
    "задать": ["поручить", "дать задание", "наказать", "назначить", "определить", "указать", "устроить", "закатить"],
    "задать жару": ["дать прикурить"],
    "задать перцу": ["задать", "задать жару", "показать кузькину мать", "прессануть", "задать феферу", "задать пфейферу", "задать пфеферу"],
    "задать феферу": ["распечь", "задать", "прессануть", "задать взбучку", "задать жару", "задать пару", "показать кузькину мать", "дать перцу", "задать перцу", "всыпать перцу"],
    "задача": ["цель", "упражнение", "сложность", "проблема"],
    "задвигав": ["задвигавши"],
    "задвигавши": ["задвигав"],
    "задвигать": ["зашевелить", "двинуть"],
    "задвигаться": ["зашевелиться"],
    "задвинув": ["задвинувши"],
    "задвинувши": ["задвинув"],
    "задвинуть": ["прогулять", "загнуть"],
    "задвинуть сатану": ["засадить сатану", "антихриста втереть"],
    "задвинуться": ["вдвинуться"],
    "задвоив": ["задвоивши"],
    "задвоивши": ["задвоив"],
    "задворье": ["задворки"],
    "задеанонить": ["задеанонимизировать", "деанонимизировать"],
    "задебренный": ["заросший"],
    "задев": ["задевши"],
    "задевав": ["задевавши"],
    "задевавши": ["задевав"],
    "задевши": ["задев"],
    "задействовав": ["задействовавши"],
    "задействовавши": ["задействовав"],
    "задействование": ["привлечение"],
    "задействовать": ["заработать", "зафункционировать", "включить", "использовать"],
    "задекламировав": ["задекламировавши"],
    "задекламировавши": ["задекламировав"],
    "задекларировав": ["задекларировавши"],
    "задекларировавши": ["задекларировав"],
    "задекорировав": ["задекорировавши"],
    "задекорировавши": ["задекорировав"],
    "задел": ["заготовка", "рыба"],
    "заделав": ["заделавши"],
    "заделавши": ["заделав"],
    "заделиться": ["поделиться"],
    "заделывав": ["заделывавши"],
    "заделывавши": ["заделывав"],
    "заделывание": ["заделка"],
    "задеревенев": ["задеревеневши"],
    "задеревеневши": ["задеревенев"],
    "задержав": ["задержавши"],
    "задержавши": ["задержав"],
    "задержанье": ["задержание"],
    "задержаться": ["промедлить", "замедлиться", "приостановиться", "застрять", "припоздниться", "опоздать", "запоздать", "замешкаться"],
    "задерживав": ["задерживавши"],
    "задерживавши": ["задерживав"],
    "задерживать": ["стопорить", "приостанавливать", "замедлять"],
    "задержка": ["задержание", "промедление", "приостановка", "пауза"],
    "задернев": ["задерневши"],
    "задерневши": ["задернев"],
    "задернелый": ["задернённый"],
    "задернеть": ["задерноветь", "задерниться"],
    "задернеться": ["задерноветь", "задернеть"],
    "задерниться": ["задерноветь", "задернеть"],
    "задерновав": ["задерновавши"],
    "задерновавши": ["задерновав"],
    "задерновев": ["задерновевши"],
    "задерновевши": ["задерновев"],
    "задерноветь": ["задерниться", "задернеть"],
    "задерновывав": ["задерновывавши"],
    "задерновывавши": ["задерновывав"],
    "задернённый": ["задернелый"],
    "задетый": ["затронутый"],
    "задеть": ["коснуться", "оцарапать", "подранить", "затронуть", "охватить", "взволновать", "обидеть", "раздразнить"],
    "задиафрагмировав": ["задиафрагмировавши"],
    "задиафрагмировавши": ["задиафрагмировав"],
    "задик": ["задок"],
    "задинамив": ["задинамивши"],
    "задинамивши": ["задинамив"],
    "задира": ["забияка"],
    "задирав": ["задиравши"],
    "задиравши": ["задирав"],
    "задирать": ["провоцировать"],
    "задиристый": ["задеристый", "агрессивный", "воинственный"],
    "задиркуватий": ["задерикуватий"],
    "задихатися": ["захекатися"],
    "задичав": ["задичавши"],
    "задичавши": ["задичав"],
    "заднелатеральный": ["постеролатеральный"],
    "заднемедиальный": ["постеромедиальный"],
    "задненёбный": ["велярный", "заднеязычный"],
    "заднепроходец": ["проктолог"],
    "заднеспинка": ["метанотум"],
    "заднеязычный": ["велярный", "задненёбный"],
    "заднеязычный согласный": ["велярный согласный"],
    "задний": ["тыльный"],
    "задница": ["ягодицы", "седалище", "зад", "попа", "попка", "задок", "одно место", "думательное место", "жопа", "срака", "зараза", "гад", "сволочь", "ублюдок", "неприятность"],
    "задницу рвать": ["жопу рвать"],
    "задобрив": ["задобривши"],
    "задобривав": ["задобривавши"],
    "задобривавши": ["задобривав"],
    "задобривши": ["задобрив"],
    "задобрить": ["умилостивить"],
    "задождив": ["задождивши"],
    "задождивши": ["задождив"],
    "задожжив": ["задожживши"],
    "задожживши": ["задожжив"],
    "задок": ["задница", "задик", "задочек", "задище"],
    "задокументировав": ["задокументировавши"],
    "задокументировавши": ["задокументировав"],
    "задолбав": ["задолбавши"],
    "задолбавши": ["задолбав"],
    "задолбать": ["затюкать", "засношать", "достать"],
    "задолбаться": ["устать", "заебаться"],
    "задолбив": ["задолбивши"],
    "задолбивши": ["задолбив"],
    "задолжав": ["задолжавши"],
    "задолжавши": ["задолжав"],
    "задолжать": ["задолжаться"],
    "задолжаться": ["задолжать"],
    "задолженность": ["долг"],
    "задом наперёд": ["наоборот", "в обратном порядке"],
    "задонатив": ["задонативши"],
    "задонативши": ["задонатив"],
    "задор": ["горячность", "пыл", "энергия", "страстность", "задиристость", "запальчивость", "агрессивность"],
    "задорив": ["задоривши"],
    "задоривши": ["задорив"],
    "задорина": ["зацепка"],
    "задорно": ["задористо", "воодушевлённо", "энергично", "кокетливо", "озорно"],
    "задорого": ["втридорога"],
    "задохлик": ["хиляк", "хлюпик", "дистрофик"],
    "задрав": ["задравши"],
    "задравши": ["задрав"],
    "задразнив": ["задразнивши"],
    "задразнивав": ["задразнивавши"],
    "задразнивавши": ["задразнивав"],
    "задразнивши": ["задразнив"],
    "задраив": ["задраивши"],
    "задраивав": ["задраивавши"],
    "задраивавши": ["задраивав"],
    "задраивши": ["задраив"],
    "задрапировав": ["задрапировавши"],
    "задрапировавши": ["задрапировав"],
    "задрапировывав": ["задрапировывавши"],
    "задрапировывавши": ["задрапировывав"],
    "задрать": ["достать"],
    "задрафтовав": ["задрафтовавши"],
    "задрафтовавши": ["задрафтовав"],
    "задрачивав": ["задрачивавши"],
    "задрачивавши": ["задрачивав"],
    "задрачивать": ["доставать", "задалбывать"],
    "задребезжав": ["задребезжавши"],
    "задребезжавши": ["задребезжав"],
    "задрейфовав": ["задрейфовавши"],
    "задрейфовавши": ["задрейфовав"],
    "задремав": ["задремавши"],
    "задремавши": ["задремав"],
    "задренажив": ["задренаживши"],
    "задренаживши": ["задренажив"],
    "задрипав": ["задрипавши"],
    "задрипавши": ["задрипав"],
    "задрипанець": ["засера"],
    "задристав": ["задриставши"],
    "задриставши": ["задристав"],
    "задристать": ["запоносить", "зассать", "струсить"],
    "задрогнув": ["задрогнувши"],
    "задрогнувши": ["задрогнув"],
    "задрожав": ["задрожавши"],
    "задрожавши": ["задрожав"],
    "задрот": ["задрота", "онанист", "дрочер", "ботаник", "ботан", "гик", "придурок", "идиот", "кретин", "зануда"],
    "задротив": ["задротивши"],
    "задротивши": ["задротив"],
    "задротить": ["ботанить", "долбоёбить", "ебланить", "гамать", "резаться", "рубиться", "шпилить", "шпилиться"],
    "задружив": ["задруживши"],
    "задруживши": ["задружив"],
    "задружиться": ["подружиться"],
    "задрыга": ["дурак", "дурачок", "размазня", "сморчок", "терпила", "неудачник", "хлюпик", "слабак", "лох", "лохопед", "лошпед", "лошара", "долбоёб", "еблан", "мерзляк"],
    "задрыгав": ["задрыгавши"],
    "задрыгавши": ["задрыгав"],
    "задрызгав": ["задрызгавши"],
    "задрызгавши": ["задрызгав"],
    "задрызгивав": ["задрызгивавши"],
    "задрызгивавши": ["задрызгивав"],
    "задрыхав": ["задрыхавши"],
    "задрыхавши": ["задрыхав"],
    "задрыхнув": ["задрыхнувши"],
    "задрыхнувши": ["задрыхнув"],
    "задрюкав": ["задрюкавши"],
    "задрюкавши": ["задрюкав"],
    "задрючив": ["задрючивши"],
    "задрючивши": ["задрючив"],
    "задрябнув": ["задрябнувши"],
    "задрябнувши": ["задрябнув"],
    "задряхлев": ["задряхлевши"],
    "задряхлевши": ["задряхлев"],
    "задрёмывав": ["задрёмывавши"],
    "задрёмывавши": ["задрёмывав"],
    "задрёмывать": ["придрёмывать"],
    "задубасив": ["задубасивши"],
    "задубасивши": ["задубасив"],
    "задубев": ["задубевши"],
    "задубевши": ["задубев"],
    "задубелый": ["окостенелый", "одеревенелый", "задубенелый"],
    "задубенев": ["задубеневши"],
    "задубеневши": ["задубенев"],
    "задублировав": ["задублировавши"],
    "задублировавши": ["задублировав"],
    "задув": ["задувши"],
    "задував": ["задувавши"],
    "задувавши": ["задував"],
    "задувши": ["задув"],
    "задудев": ["задудевши"],
    "задудевши": ["задудев"],
    "задудив": ["задудивши"],
    "задудивши": ["задудив"],
    "задудосив": ["задудосивши"],
    "задудосивши": ["задудосив"],
    "задудосить": ["заддосить"],
    "задумав": ["задумавши"],
    "задумавши": ["задумав"],
    "задумать": ["замыслить"],
    "задуматься": ["впасть в задумчивость", "заколебаться", "засомневаться"],
    "задумка": ["намерение", "умысел", "замысел", "план", "проект", "прожект"],
    "задумывав": ["задумывавши"],
    "задумывавши": ["задумывав"],
    "задумывать": ["замышлять", "планировать", "затевать", "загадывать"],
    "задурачив": ["задурачивши"],
    "задурачивши": ["задурачив"],
    "задурев": ["задуревши"],
    "задуревши": ["задурев"],
    "задурив": ["задуривши"],
    "задуривав": ["задуривавши"],
    "задуривавши": ["задуривав"],
    "задуривание": ["одурачивание"],
    "задуривши": ["задурив"],
    "задурманив": ["задурманивши"],
    "задурманивав": ["задурманивавши"],
    "задурманивавши": ["задурманивав"],
    "задурманивши": ["задурманив"],
    "задуряв": ["задурявши"],
    "задурявши": ["задуряв"],
    "задушевность": ["сердечность", "душевность"],
    "задушив": ["задушивши"],
    "задушивши": ["задушив"],
    "задушить": ["удушить", "придушить", "душить"],
    "задушиться": ["повеситься", "удавиться", "удушиться", "задохнуться"],
    "задушниться": ["замучаться", "устать", "утомиться", "изнуриться", "измучаться"],
    "задымив": ["задымивши"],
    "задымивши": ["задымив"],
    "задымление": ["дымность", "задымлённость"],
    "задымляв": ["задымлявши"],
    "задымлявши": ["задымляв"],
    "задыханье": ["задыхание"],
    "задышав": ["задышавши"],
    "задышавши": ["задышав"],
    "задявка": ["закачка", "задяване", "дразнене"],
    "задёргав": ["задёргавши"],
    "задёргавши": ["задёргав"],
    "задёргивав": ["задёргивавши"],
    "задёргивавши": ["задёргивав"],
    "задёрнув": ["задёрнувши"],
    "задёрнувши": ["задёрнув"],
    "задёшево": ["за бесценок", "просто так"],
    "заебав": ["заебавши"],
    "заебавши": ["заебав"],
    "заебательский": ["отличный", "великолепный", "потрясный", "классный", "клёвый", "здоровский", "суперский", "отпадный", "пиздастый", "пиздатый", "заебатый", "заебический", "охуенный", "охуительный", "охуетительный"],
    "заебато": ["отлично", "превосходно", "великолепно", "замечательно", "здорово", "супер", "суперски", "кайфно", "кайфово", "в кайф", "пиздато", "охуенно"],
    "заебатый": ["классный", "клёвый", "здоровский", "суперский", "отпадный", "заебательский", "заебический", "пиздатый", "охуенный", "охуительный", "охуетительный"],
    "заебать": ["засношать", "задолбать", "задрать", "затрахать", "заябать", "достать", "заколебать", "заманать", "остоебенить", "остоёбнуть", "остопиздить", "настоебать", "настоёбнуть", "остохуеть", "одержать верх"],
    "заебашив": ["заебашивши"],
    "заебашивши": ["заебашив"],
    "заебашить": ["забабахать"],
    "заебенив": ["заебенивши"],
    "заебенивши": ["заебенив"],
    "заебись": ["зашибись", "пиздато", "охуенно", "охуительно", "заебательски", "заебок"],
    "заебок": ["супер", "заебца", "заебато", "заебись", "пиздато"],
    "заебти": ["засношать", "задолбать", "задрать", "затрахать", "заебать", "заебати", "заеть", "заети", "достать", "заколебать", "заманать", "остоебенить", "остоёбнуть", "остопиздить", "настоебать"],
    "заебунев": ["заебуневши"],
    "заебуневши": ["заебунев"],
    "заебунеть": ["продрогнуть"],
    "заебца": ["заебись", "заебок", "заебцом"],
    "заев": ["заевши"],
    "заевреивание": ["евреизация"],
    "заевши": ["заев"],
    "заегозив": ["заегозивши"],
    "заегозивши": ["заегозив"],
    "заеда": ["ангулит", "ангулярный стоматит", "ангулярный хейлит", "трензель"],
    "заедав": ["заедавши"],
    "заедавши": ["заедав"],
    "заедать": ["загрызать", "изводить", "закусывать"],
    "заединщик": ["единомышленник"],
    "заединщица": ["единомышленница"],
    "заедка": ["десерт", "закуска"],
    "заездив": ["заездивши"],
    "заездивши": ["заездив"],
    "заездной карман": ["карман"],
    "заезжав": ["заезжавши"],
    "заезжавши": ["заезжав"],
    "заезживав": ["заезживавши"],
    "заезживавши": ["заезживав"],
    "заелозив": ["заелозивши"],
    "заелозивши": ["заелозив"],
    "заерепениться": ["заупрямиться"],
    "заершав": ["заершавши"],
    "заершавши": ["заершав"],
    "заершив": ["заершивши"],
    "заершивши": ["заершив"],
    "заесть": ["загрызть", "задолбать", "погубить"],
    "заеть": ["засношать", "задолбать", "задрать", "затрахать", "заебать", "заебти", "заети"],
    "заехав": ["заехавши"],
    "заехавши": ["заехав"],
    "заехидничав": ["заехидничавши"],
    "заехидничавши": ["заехидничав"],
    "зажав": ["зажавши"],
    "зажавши": ["зажав"],
    "зажадничав": ["зажадничавши"],
    "зажадничавши": ["зажадничав"],
    "зажаждав": ["зажаждавши"],
    "зажаждавши": ["зажаждав"],
    "зажарив": ["зажаривши"],
    "зажаривав": ["зажаривавши"],
    "зажаривавши": ["зажаривав"],
    "зажаривать": ["жарить"],
    "зажаривши": ["зажарив"],
    "зажатый": ["скованный"],
    "зажать": ["сдавить", "стиснуть", "зажимать"],
    "зажевав": ["зажевавши"],
    "зажевавши": ["зажевав"],
    "зажевать": ["заесть", "зажать", "защемить", "замять"],
    "зажелтев": ["зажелтевши"],
    "зажелтевши": ["зажелтев"],
    "зажелтив": ["зажелтивши"],
    "зажелтивши": ["зажелтив"],
    "зажестикулировав": ["зажестикулировавши"],
    "зажестикулировавши": ["зажестикулировав"],
    "зажечь": ["запалить", "воспламенить"],
    "зажечься": ["загореться"],
    "зажжение": ["зажигание"],
    "зажив": ["заживши"],
    "заживав": ["заживавши"],
    "заживавши": ["заживав"],
    "заживать": ["затягиваться"],
    "заживив": ["зажививши"],
    "зажививши": ["заживив"],
    "заживляв": ["заживлявши"],
    "заживлявши": ["заживляв"],
    "заживо": ["живьём"],
    "заживши": ["зажив"],
    "зажигав": ["зажигавши"],
    "зажигавши": ["зажигав"],
    "зажигалка": ["зажигательная бомба"],
    "зажиганье": ["зажигание"],
    "зажигать": ["поджигать"],
    "зажилив": ["зажиливши"],
    "зажиливав": ["зажиливавши"],
    "зажиливавши": ["зажиливав"],
    "зажиливши": ["зажилив"],
    "зажилить": ["зажать", "прикарманить"],
    "зажим": ["зажимание", "зажимка"],
    "зажимав": ["зажимавши"],
    "зажимавши": ["зажимав"],
    "зажимать": ["сдавливать", "стискивать"],
    "зажинав": ["зажинавши"],
    "зажинавши": ["зажинав"],
    "зажирев": ["зажиревши"],
    "зажиревши": ["зажирев"],
    "зажиточный": ["пожиточный", "богатый", "обеспеченный", "состоятельный", "заможный", "имовитый", "крепкий", "небедный", "справный"],
    "зажмурив": ["зажмуривши"],
    "зажмуривав": ["зажмуривавши"],
    "зажмуривавши": ["зажмуривав"],
    "зажмуриваться": ["жмуриться", "щуриться"],
    "зажмуривши": ["зажмурив"],
    "зажмурить": ["прижмурить", "сожмурить", "смежить"],
    "зажолкнув": ["зажолкнувши"],
    "зажолкнувши": ["зажолкнув"],
    "зажопив": ["зажопивши"],
    "зажопивши": ["зажопив"],
    "зажопить": ["зажать"],
    "зажор": ["зажора"],
    "зажравшийся": ["пресытившийся", "заевшийся"],
    "зажраться": ["заесться"],
    "зажужжав": ["зажужжавши"],
    "зажужжавши": ["зажужжав"],
    "зажулив": ["зажуливши"],
    "зажуливав": ["зажуливавши"],
    "зажуливавши": ["зажуливав"],
    "зажуливши": ["зажулив"],
    "зажурив": ["зажуривши"],
    "зажуривши": ["зажурив"],
    "зажуриться": ["опечалиться", "огорчиться", "расстроиться"],
    "зажурчав": ["зажурчавши"],
    "зажурчавши": ["зажурчав"],
    "зажухав": ["зажухавши"],
    "зажухавши": ["зажухав"],
    "зажухнув": ["зажухнувши"],
    "зажухнувши": ["зажухнув"],
    "зажёвывав": ["зажёвывавши"],
    "зажёвывавши": ["зажёвывав"],
    "зазвав": ["зазвавши"],
    "зазвавши": ["зазвав"],
    "зазвенев": ["зазвеневши"],
    "зазвеневши": ["зазвенев"],
    "зазвонив": ["зазвонивши"],
    "зазвонивши": ["зазвонив"],
    "зазвучав": ["зазвучавши"],
    "зазвучавши": ["зазвучав"],
    "зазвякав": ["зазвякавши"],
    "зазвякавши": ["зазвякав"],
    "зазевав": ["зазевавши"],
    "зазевавши": ["зазевав"],
    "зазеленев": ["зазеленевши"],
    "зазеленевши": ["зазеленев"],
    "зазеленеть": ["позеленеть"],
    "зазеленив": ["зазеленивши"],
    "зазеленивши": ["зазеленив"],
    "заземлив": ["заземливши"],
    "заземливши": ["заземлив"],
    "заземляв": ["заземлявши"],
    "заземлявши": ["заземляв"],
    "зазенковав": ["зазенковавши"],
    "зазенковавши": ["зазенковав"],
    "зазимовав": ["зазимовавши"],
    "зазимовавши": ["зазимовав"],
    "зазимок": ["зазимье"],
    "зазирав": ["зазиравши"],
    "зазиравши": ["зазирав"],
    "зазнав": ["зазнавши"],
    "зазнаваться": ["важничать", "заноситься", "чваниться", "задирать нос", "задаваться"],
    "зазнавши": ["зазнав"],
    "зазнайка": ["задавака", "воображала", "спесивец"],
    "зазнайство": ["высокомерие", "надменность", "заносчивость"],
    "зазнамо": ["заведомо", "умышленно", "ведаючи", "знаючи", "зазнаемо"],
    "зазнаться": ["возгордиться"],
    "зазноба": ["страсть", "влечение"],
    "зазнобив": ["зазнобивши"],
    "зазнобивши": ["зазнобив"],
    "зазнобить": ["застудить", "заморозить", "залихорадить", "увлечь", "завлечь"],
    "зазолотив": ["зазолотивши"],
    "зазолотивши": ["зазолотив"],
    "зазомбировав": ["зазомбировавши"],
    "зазомбировавши": ["зазомбировав"],
    "зазор": ["просвет", "щель", "прогал", "прогалина"],
    "зазорный": ["постыдный"],
    "зазревать": ["порицать", "укорять"],
    "зазрение": ["порицание", "угрызение"],
    "зазреть": ["застыдить", "укорить"],
    "зазрив": ["зазривши"],
    "зазривши": ["зазрив"],
    "зазря": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно"],
    "зазубрив": ["зазубривши"],
    "зазубривав": ["зазубривавши"],
    "зазубривавши": ["зазубривав"],
    "зазубривши": ["зазубрив"],
    "зазубрина": ["щербина"],
    "зазуммерив": ["зазуммеривши"],
    "зазуммеривши": ["зазуммерив"],
    "зазывав": ["зазывавши"],
    "зазывавши": ["зазывав"],
    "зазыванье": ["зазывание"],
    "зазывный": ["зазывной"],
    "зазябнув": ["зазябнувши"],
    "зазябнувши": ["зазябнув"],
    "заиграв": ["заигравши"],
    "заигравши": ["заиграв"],
    "заигрывав": ["заигрывавши"],
    "заигрывавши": ["заигрывав"],
    "заигрывание": ["флирт", "кокетничание", "заискивание", "любезничание"],
    "заигрыванье": ["заигрывание"],
    "заидеологизировав": ["заидеологизировавши"],
    "заидеологизировавши": ["заидеологизировав"],
    "заизвестковав": ["заизвестковавши"],
    "заизвестковавши": ["заизвестковав"],
    "заизолировав": ["заизолировавши"],
    "заизолировавши": ["заизолировав"],
    "заикав": ["заикавши"],
    "заикавши": ["заикав"],
    "заиканье": ["заикание"],
    "заилив": ["заиливши"],
    "заиливав": ["заиливавши"],
    "заиливавши": ["заиливав"],
    "заиливши": ["заилив"],
    "заимев": ["заимевши"],
    "заимевши": ["заимев"],
    "заимодавец": ["кредитор"],
    "заимодатель": ["заимодавец", "кредитор"],
    "заимообразно": ["взаймы"],
    "заимствовав": ["заимствовавши"],
    "заимствовавши": ["заимствовав"],
    "заимствованный": ["одолжённый"],
    "заимствовать": ["перенимать", "перенять", "занимать", "занять"],
    "заимствоваться": ["перениматься"],
    "заинвентаризировав": ["заинвентаризировавши"],
    "заинвентаризировавши": ["заинвентаризировав"],
    "заинвентаризовав": ["заинвентаризовавши"],
    "заинвентаризовавши": ["заинвентаризовав"],
    "заиндевев": ["заиндевевши"],
    "заиндевевши": ["заиндевев"],
    "заиндевевший": ["заиндевелый", "заиневелый"],
    "заиндевелый": ["заиндевевший", "индевелый"],
    "заинтересовав": ["заинтересовавши"],
    "заинтересовавши": ["заинтересовав"],
    "заинтересованность": ["заинтригованность"],
    "заинтересоваться": ["поинтересоваться"],
    "заинтересовывав": ["заинтересовывавши"],
    "заинтересовывавши": ["заинтересовывав"],
    "заинтриговав": ["заинтриговавши"],
    "заинтриговавши": ["заинтриговав"],
    "заинтриговывав": ["заинтриговывавши"],
    "заинтриговывавши": ["заинтриговывав"],
    "заинька": ["зайка"],
    "заирец": ["конголезец"],
    "заискав": ["заискавши"],
    "заискавши": ["заискав"],
    "заискивав": ["заискивавши"],
    "заискивавши": ["заискивав"],
    "заискивание": ["угодничание", "лесть", "искательство", "низкопоклонство", "шапколомание"],
    "заискивать": ["подлизываться", "угодничать"],
    "заискивающе": ["угодливо", "льстиво"],
    "заискивающий": ["искательный", "подобострастный"],
    "заискрив": ["заискривши"],
    "заискривши": ["заискрив"],
    "зайдя": ["зашедши", "зашед"],
    "зайка": ["уразай"],
    "займ": ["заём"],
    "займище": ["наволок", "пойма"],
    "займодавец": ["займодатель", "кредитор"],
    "займодатель": ["кредитор", "займодавец"],
    "зайти": ["посетить", "заглянуть", "забраться", "закатиться", "заплыть"],
    "зайцекролик": ["лепорид"],
    "зайцем": ["по-заячьи"],
    "зайчатина": ["зайчатинка", "заяц"],
    "зайчатинка": ["зайчатина"],
    "зайчик": ["заяц", "солнечный зайчик", "световой зайчик", "котик", "солнышко", "ласточка", "лапочка", "белорусский рубль"],
    "зайып": ["жар"],
    "закабаление": ["порабощение"],
    "закабалив": ["закабаливши"],
    "закабаливши": ["закабалив"],
    "закабалить": ["поработить"],
    "закабаляв": ["закабалявши"],
    "закабалявши": ["закабаляв"],
    "закабалять": ["порабощать"],
    "закабалённость": ["закрепощённость"],
    "закабанеть": ["раскабанеть"],
    "закавказский": ["кавказский"],
    "закавказье": ["южный кавказ"],
    "закавыка": ["закавычка", "закорючка", "загвоздка", "заковырка", "помеха", "препятствие", "затруднение", "проблема"],
    "закавычив": ["закавычивши"],
    "закавычивав": ["закавычивавши"],
    "закавычивавши": ["закавычивав"],
    "закавычивши": ["закавычив"],
    "закавычка": ["кавыка", "ковыка", "кавычка", "ковычка", "закавыка", "заковыка", "заковычка"],
    "закадрив": ["закадривши"],
    "закадривши": ["закадрив"],
    "закадычный": ["близкий", "задушевный", "ближайший", "сердечный", "давнишний"],
    "заказ": ["заявка", "поручение", "задание", "заказуха", "заказняк", "заказнячок"],
    "заказав": ["заказавши"],
    "заказавши": ["заказав"],
    "заказуха": ["джинса", "продакт-плейсмент"],
    "заказчик": ["клиент", "покупатель"],
    "заказчица": ["клиентка", "покупательница"],
    "заказывав": ["заказывавши"],
    "заказывавши": ["заказывав"],
    "закалив": ["закаливши"],
    "закаливав": ["закаливавши"],
    "закаливавши": ["закаливав"],
    "закаливать": ["закалять"],
    "закаливши": ["закалив"],
    "закалка": ["закаливание", "закалённость"],
    "закалывав": ["закалывавши"],
    "закалывавши": ["закалывав"],
    "закаляв": ["закалявши"],
    "закалявши": ["закаляв"],
    "закалякав": ["закалякавши"],
    "закалякавши": ["закалякав"],
    "закаляться": ["закаливаться"],
    "закалённость": ["выносливость", "стойкость", "закалка"],
    "закалённый": ["выносливый", "стойкий"],
    "закаменев": ["закаменевши"],
    "закаменевав": ["закаменевавши"],
    "закаменевавши": ["закаменевав"],
    "закаменевать": ["окаменевать"],
    "закаменевши": ["закаменев"],
    "закамуфлировав": ["закамуфлировавши"],
    "закамуфлировавши": ["закамуфлировав"],
    "заканифолив": ["заканифоливши"],
    "заканифоливши": ["заканифолив"],
    "заканчивав": ["заканчивавши"],
    "заканчивавши": ["заканчивав"],
    "заканчивать": ["завершать", "кончать", "оканчивать"],
    "заканчиваться": ["кончаться", "оканчиваться", "завершаться", "приходить к концу", "подходить к концу"],
    "заканчиваясь": ["кончаясь", "завершаясь"],
    "заканючив": ["заканючивши"],
    "заканючивши": ["заканючив"],
    "закапав": ["закапавши"],
    "закапавши": ["закапав"],
    "закапризничав": ["закапризничавши"],
    "закапризничавши": ["закапризничав"],
    "закапчивав": ["закапчивавши"],
    "закапчивавши": ["закапчивав"],
    "закапывав": ["закапывавши"],
    "закапывавши": ["закапывав"],
    "закаркав": ["закаркавши"],
    "закаркавши": ["закаркав"],
    "закармливав": ["закармливавши"],
    "закармливавши": ["закармливав"],
    "закармливать": ["перекармливать"],
    "закарпатская область": ["закарпатье"],
    "закартавив": ["закартавивши"],
    "закартавивши": ["закартавив"],
    "закартировав": ["закартировавши"],
    "закартировавши": ["закартировав"],
    "закартографировав": ["закартографировавши"],
    "закартографировавши": ["закартографировав"],
    "закат": ["закатывание", "заход", "вечер", "заря", "зорька"],
    "закатав": ["закатавши"],
    "закатавши": ["закатав"],
    "закатать": ["обмотать", "подвернуть", "засучить"],
    "закатив": ["закативши"],
    "закативши": ["закатив"],
    "закатывав": ["закатывавши"],
    "закатывавши": ["закатывав"],
    "закатыванье": ["закатывание"],
    "закачав": ["закачавши"],
    "закачавши": ["закачав"],
    "закачивав": ["закачивавши"],
    "закачивавши": ["закачивав"],
    "закашивав": ["закашивавши"],
    "закашивавши": ["закашивав"],
    "закашливав": ["закашливавши"],
    "закашливавши": ["закашливав"],
    "закашляв": ["закашлявши"],
    "закашлявши": ["закашляв"],
    "закаяться": ["заречься"],
    "заквакав": ["заквакавши"],
    "заквакавши": ["заквакав"],
    "заквасив": ["заквасивши"],
    "заквасивши": ["заквасив"],
    "заквашивав": ["заквашивавши"],
    "заквашивавши": ["заквашивав"],
    "закдензнак": ["закавказский рубль"],
    "закивав": ["закивавши"],
    "закивавши": ["закивав"],
    "закидав": ["закидавши"],
    "закидавши": ["закидав"],
    "закидать": ["забросать", "зашвырять"],
    "закидать сапогами": ["закидать шапками", "шапками закидать", "закидать тапками", "тапками закидать", "сапогами закидать"],
    "закидать тапками": ["закидать шапками", "закидать сапогами", "шапками закидать", "тапками закидать", "сапогами закидать"],
    "закидать шапками": ["шапками закидать", "закидать тапками", "закидать сапогами", "тапками закидать", "сапогами закидать"],
    "закидон": ["чудачество", "придурь", "заскок"],
    "закидывав": ["закидывавши"],
    "закидывавши": ["закидывав"],
    "закинув": ["закинувши"],
    "закинувши": ["закинув"],
    "закинуть": ["забросить"],
    "закипав": ["закипавши"],
    "закипавши": ["закипав"],
    "закипание": ["закипанье", "вскипание", "возбуждение"],
    "закипанье": ["закипание"],
    "закипать": ["вскипать"],
    "закипев": ["закипевши"],
    "закипевши": ["закипев"],
    "закисав": ["закисавши"],
    "закисавши": ["закисав"],
    "закисание": ["заквашивание"],
    "закислив": ["закисливши"],
    "закисливши": ["закислив"],
    "закисляв": ["закислявши"],
    "закислявши": ["закисляв"],
    "закиснув": ["закиснувши"],
    "закиснувши": ["закиснув"],
    "закись": ["недокись"],
    "закишев": ["закишевши"],
    "закишевши": ["закишев"],
    "заклав": ["заклавши"],
    "заклавши": ["заклав"],
    "закладка": ["закладывание", "жучок", "клад"],
    "закладная": ["ипотека"],
    "закладывав": ["закладывавши"],
    "закладывавши": ["закладывав"],
    "закладывать": ["класть"],
    "закланье": ["заклание"],
    "заклевав": ["заклевавши"],
    "заклевавши": ["заклевав"],
    "заклеив": ["заклеивши"],
    "заклеивав": ["заклеивавши"],
    "заклеивавши": ["заклеивав"],
    "заклеивши": ["заклеив"],
    "заклеймив": ["заклеймивши"],
    "заклеймивши": ["заклеймив"],
    "заклекотав": ["заклекотавши"],
    "заклекотавши": ["заклекотав"],
    "заклектав": ["заклектавши"],
    "заклектавши": ["заклектав"],
    "заклектать": ["заклекотать"],
    "заклепав": ["заклепавши"],
    "заклепавши": ["заклепав"],
    "заклик": ["гасло"],
    "закликав": ["закликавши"],
    "закликавши": ["закликав"],
    "заклинав": ["заклинавши"],
    "заклинавши": ["заклинав"],
    "заклинанье": ["заклинание"],
    "заклинение": ["заклинивание"],
    "заклинив": ["заклинивши"],
    "заклинивав": ["заклинивавши"],
    "заклинивавши": ["заклинивав"],
    "заклинивши": ["заклинив"],
    "заклинка": ["заклинивание"],
    "заклишировав": ["заклишировавши"],
    "заклишировавши": ["заклишировав"],
    "заклокотав": ["заклокотавши"],
    "заклокотавши": ["заклокотав"],
    "заклохтав": ["заклохтавши"],
    "заклохтавши": ["заклохтав"],
    "заклохтать": ["закудахтать", "заквохтать", "запричитать"],
    "заклубив": ["заклубивши"],
    "заклубивши": ["заклубив"],
    "заключав": ["заключавши"],
    "заключавши": ["заключав"],
    "заключение": ["пленение", "плен", "вывод", "силлогизм", "завершение", "конец", "концовка"],
    "заключенье": ["заключение"],
    "заключив": ["заключивши"],
    "заключивши": ["заключив"],
    "заключённый": ["содержащийся", "находящийся", "обладающий", "имеющий", "законченный", "завершённый"],
    "закляв": ["заклявши"],
    "заклявши": ["закляв"],
    "заклятый": ["завзятый", "рьяный"],
    "заклёвывав": ["заклёвывавши"],
    "заклёвывавши": ["заклёвывав"],
    "заклёкнув": ["заклёкнувши"],
    "заклёкнувши": ["заклёкнув"],
    "заклёкнуть": ["заклечь", "завянуть", "засохнуть", "заскорузнуть", "зачерстветь"],
    "заклёпка": ["заклёпывание"],
    "заклёпывав": ["заклёпывавши"],
    "заклёпывавши": ["заклёпывав"],
    "заклёпывать": ["клепать"],
    "закобениться": ["заартачиться"],
    "заковав": ["заковавши"],
    "заковавши": ["заковав"],
    "закованный": ["скованный"],
    "заковать": ["сковать"],
    "заковка": ["заковывание"],
    "заковывав": ["заковывавши"],
    "заковывавши": ["заковывав"],
    "заковыка": ["кавыка", "ковыка", "кавычка", "ковычка", "закавыка", "закавычка", "заковычка"],
    "заковыляв": ["заковылявши"],
    "заковылявши": ["заковыляв"],
    "заковыривав": ["заковыривавши"],
    "заковыривавши": ["заковыривав"],
    "заковыряв": ["заковырявши"],
    "заковырявши": ["заковыряв"],
    "заковычив": ["заковычивши"],
    "заковычивши": ["заковычив"],
    "закогтив": ["закогтивши"],
    "закогтивши": ["закогтив"],
    "закодировав": ["закодировавши"],
    "закодировавши": ["закодировав"],
    "закозлив": ["закозливши"],
    "закозливши": ["закозлив"],
    "закозыряв": ["закозырявши"],
    "закозырявши": ["закозыряв"],
    "закокетничав": ["закокетничавши"],
    "закокетничавши": ["закокетничав"],
    "закокотав": ["закокотавши"],
    "закокотавши": ["закокотав"],
    "закол": ["колище", "ез", "езовище", "яз", "заездок"],
    "заколачивав": ["заколачивавши"],
    "заколачивавши": ["заколачивав"],
    "заколбасив": ["заколбасивши"],
    "заколбасивши": ["заколбасив"],
    "заколбасить": ["войти в раж"],
    "заколдовав": ["заколдовавши"],
    "заколдовавши": ["заколдовав"],
    "заколдованный": ["зачарованный"],
    "заколдованный круг": ["порочный круг"],
    "заколдовать": ["околдовать"],
    "заколдовывав": ["заколдовывавши"],
    "заколдовывавши": ["заколдовывав"],
    "заколдовывать": ["околдовывать"],
    "заколебав": ["заколебавши"],
    "заколебавши": ["заколебав"],
    "заколебать": ["закачать", "заколыхать"],
    "заколебаться": ["закачаться", "засомневаться", "усомниться", "задолбаться", "замаяться"],
    "заколев": ["заколевши"],
    "заколевши": ["заколев"],
    "заколенев": ["заколеневши"],
    "заколеневши": ["заколенев"],
    "заколенник": ["болотный сапог", "подколенная ямка"],
    "заколеровав": ["заколеровавши"],
    "заколеровавши": ["заколеровав"],
    "заколесив": ["заколесивши"],
    "заколесивши": ["заколесив"],
    "заколлировав": ["заколлировавши"],
    "заколлировавши": ["заколлировав"],
    "заколобродив": ["заколобродивши"],
    "заколобродивши": ["заколобродив"],
    "заколов": ["заколовши"],
    "заколовши": ["заколов"],
    "заколодив": ["заколодивши"],
    "заколодивши": ["заколодив"],
    "заколотив": ["заколотивши"],
    "заколотивши": ["заколотив"],
    "заколочка": ["заколка"],
    "заколошматив": ["заколошмативши"],
    "заколошмативши": ["заколошматив"],
    "заколупать": ["заковырять", "замучать", "достать", "задолбать", "затрахать"],
    "заколупаться": ["заколебаться", "заебаться"],
    "заколупка": ["затруднение", "осложнение", "помеха", "преграда", "препона", "препятствие", "проблема", "трудность", "узкое место", "загвоздка", "заморочка", "зацепка", "заковыка", "заковырка", "закавычка"],
    "заколыхав": ["заколыхавши"],
    "заколыхавши": ["заколыхав"],
    "закольцевав": ["закольцевавши"],
    "закольцевавши": ["закольцевав"],
    "закольцовывав": ["закольцовывавши"],
    "закольцовывавши": ["закольцовывав"],
    "закомкав": ["закомкавши"],
    "закомкавши": ["закомкав"],
    "закомментировав": ["закомментировавши"],
    "закомментировавши": ["закомментировав"],
    "закомплексовав": ["закомплексовавши"],
    "закомплексовавши": ["закомплексовав"],
    "закомплексованность": ["застенчивость", "заторможенность", "скованность", "стеснительность"],
    "закомпоновав": ["закомпоновавши"],
    "закомпоновавши": ["закомпоновав"],
    "закомпостировав": ["закомпостировавши"],
    "закомпостировавши": ["закомпостировав"],
    "закон": ["закон божий"],
    "закон джунглей": ["человек человеку волк"],
    "закон димы яковлева": ["закон подлецов"],
    "закон кулона": ["закон обратных квадратов"],
    "закон подлости": ["закон мёрфи", "закон падающего бутерброда"],
    "закон родченкова": ["акт родченкова"],
    "законвертовав": ["законвертовавши"],
    "законвертовавши": ["законвертовав"],
    "законвертовывав": ["законвертовывавши"],
    "законвертовывавши": ["законвертовывав"],
    "законний": ["легальний"],
    "законный": ["легитимный"],
    "законодавец": ["законодатель"],
    "законодатель": ["законодавец", "законотворец"],
    "законодательная дума": ["закдума"],
    "законодательное собрание": ["заксобрание", "закс", "зс", "индия", "видхан сабха"],
    "законодательный совет": ["зс"],
    "законодательствовав": ["законодательствовавши"],
    "законодательствовавши": ["законодательствовав"],
    "закономерный": ["законный", "правомерный", "логичный"],
    "законопатив": ["законопативши"],
    "законопативши": ["законопатив"],
    "законопатить": ["заделать", "заткнуть", "закупорить", "забить"],
    "законопачивав": ["законопачивавши"],
    "законопачивавши": ["законопачивав"],
    "законопачивать": ["конопатить"],
    "законоположение": ["закон"],
    "законопослушание": ["законопослушность"],
    "законопослушность": ["законопослушание", "лояльность"],
    "законопослушный": ["лояльный"],
    "законотворец": ["законодатель"],
    "законоучение": ["вероучение", "правоведение", "юриспруденция"],
    "законсервировав": ["законсервировавши"],
    "законсервировавши": ["законсервировав"],
    "законспектировав": ["законспектировавши"],
    "законспектировавши": ["законспектировав"],
    "законспирировав": ["законспирировавши"],
    "законспирировавши": ["законспирировав"],
    "законтачив": ["законтачивши"],
    "законтачивши": ["законтачив"],
    "законтрактовав": ["законтрактовавши"],
    "законтрактовавши": ["законтрактовав"],
    "законтрактовывав": ["законтрактовывавши"],
    "законтрактовывавши": ["законтрактовывав"],
    "законтрив": ["законтривши"],
    "законтривав": ["законтривавши"],
    "законтривавши": ["законтривав"],
    "законтривши": ["законтрив"],
    "законченность": ["завершённость"],
    "законченный": ["цельный", "истинный", "подлинный", "самый что ни на есть"],
    "закончив": ["закончивши"],
    "закончивши": ["закончив"],
    "закончить": ["кончить", "окончить", "завершить", "довершить", "прекратить"],
    "закончиться": ["кончиться", "завершиться", "окончиться"],
    "закопав": ["закопавши"],
    "закопавши": ["закопав"],
    "закопать": ["зарыть", "похоронить", "погрести", "схоронить", "захоронить"],
    "закопка": ["закапывание", "зарывание", "схрон", "тайник"],
    "закопошиться": ["завозиться", "зашевелиться"],
    "закоптев": ["закоптевши"],
    "закоптевши": ["закоптев"],
    "закоптив": ["закоптивши"],
    "закоптивши": ["закоптив"],
    "закопёрщик": ["застрельщик"],
    "закорачивав": ["закорачивавши"],
    "закорачивавши": ["закорачивав"],
    "закордонний": ["чужоземний", "заграничний", "заморський"],
    "закоренев": ["закореневши"],
    "закореневши": ["закоренев"],
    "закорефаниться": ["скорефаниться"],
    "закорешевав": ["закорешевавши"],
    "закорешевавши": ["закорешевав"],
    "закорешевать": ["закорешиться"],
    "закорешив": ["закорешивши"],
    "закорешивши": ["закорешив"],
    "закорешиться": ["скорешиться", "подружиться"],
    "закорив": ["закоривши"],
    "закоривши": ["закорив"],
    "закорки": ["закукры", "закорточки", "забедры", "кукорки", "закрошни", "закрошки"],
    "закормив": ["закормивши"],
    "закормивши": ["закормив"],
    "закормить": ["перекормить"],
    "закоробив": ["закоробивши"],
    "закоробивши": ["закоробив"],
    "закоротив": ["закоротивши"],
    "закоротивши": ["закоротив"],
    "закорпев": ["закорпевши"],
    "закорпевши": ["закорпев"],
    "закорузнув": ["закорузнувши"],
    "закорузнувши": ["закорузнув"],
    "закорчив": ["закорчивши"],
    "закорчивши": ["закорчив"],
    "закорючив": ["закорючивши"],
    "закорючивав": ["закорючивавши"],
    "закорючивавши": ["закорючивав"],
    "закорючивши": ["закорючив"],
    "закорючка": ["завитушка", "закорюка", "закорючина", "уловка", "хитрость"],
    "закорябав": ["закорябавши"],
    "закорябавши": ["закорябав"],
    "закос": ["закашивание"],
    "закосив": ["закосивши"],
    "закосивши": ["закосив"],
    "закоснев": ["закосневши"],
    "закосневав": ["закосневавши"],
    "закосневавши": ["закосневав"],
    "закосневши": ["закоснев"],
    "закостенев": ["закостеневши"],
    "закостеневав": ["закостеневавши"],
    "закостеневавши": ["закостеневав"],
    "закостеневши": ["закостенев"],
    "закостенелый": ["окостенелый", "закоснелый"],
    "закостылив": ["закостыливши"],
    "закостыливши": ["закостылив"],
    "закостыляв": ["закостылявши"],
    "закостылявши": ["закостыляв"],
    "закот": ["франтон", "залобак"],
    "закоулок": ["проулок", "закуток", "уголок"],
    "закочевав": ["закочевавши"],
    "закочевавши": ["закочевав"],
    "закочевряжиться": ["заупрямиться", "заартачиться", "закочеврячиться"],
    "закоченев": ["закоченевши"],
    "закоченевав": ["закоченевавши"],
    "закоченевавши": ["закоченевав"],
    "закоченевши": ["закоченев"],
    "закоченелый": ["задубелый"],
    "закоченеть": ["окоченеть", "замерзнуть", "застыть", "застынуть", "озябнуть", "задубеть", "окостенеть"],
    "закощунствовав": ["закощунствовавши"],
    "закощунствовавши": ["закощунствовав"],
    "закрадываться": ["прокрадываться", "красться", "возникать", "появляться"],
    "закраек": ["закрайка", "закраина", "край"],
    "закраивав": ["закраивавши"],
    "закраивавши": ["закраивав"],
    "закраина": ["край", "окраина", "кромка", "заберега", "припай"],
    "закрай": ["закраек", "закраина", "край", "кромка"],
    "закрапав": ["закрапавши"],
    "закрапавши": ["закрапав"],
    "закрапывав": ["закрапывавши"],
    "закрапывавши": ["закрапывав"],
    "закрасив": ["закрасивши"],
    "закрасивши": ["закрасив"],
    "закраснев": ["закрасневши"],
    "закрасневши": ["закраснев"],
    "закрашивав": ["закрашивавши"],
    "закрашивавши": ["закрашивав"],
    "закрепив": ["закрепивши"],
    "закрепивши": ["закрепив"],
    "закрепитель": ["держатель", "фиксатор", "фиксаж"],
    "закрепиться": ["утвердиться", "удержаться", "установиться", "укрепиться", "упрочиться"],
    "закрепляв": ["закреплявши"],
    "закреплявши": ["закрепляв"],
    "закрепостив": ["закрепостивши"],
    "закрепостивши": ["закрепостив"],
    "закрепощав": ["закрепощавши"],
    "закрепощавши": ["закрепощав"],
    "закрепощать": ["закабалять", "порабощать", "сковывать"],
    "закрепощающий": ["порабощающий"],
    "закрепощённость": ["закабалённость", "порабощённость", "скованность", "зажатость"],
    "закрепчав": ["закрепчавши"],
    "закрепчавши": ["закрепчав"],
    "закрестив": ["закрестивши"],
    "закрестивши": ["закрестив"],
    "закрещивав": ["закрещивавши"],
    "закрещивавши": ["закрещивав"],
    "закривив": ["закрививши"],
    "закрививши": ["закривив"],
    "закривляв": ["закривлявши"],
    "закривлявши": ["закривляв"],
    "закрила": ["защита", "покровителство"],
    "закрилник": ["покровител", "застъпник", "защитник", "бранител"],
    "закристаллизовав": ["закристаллизовавши"],
    "закристаллизовавши": ["закристаллизовав"],
    "закристаллизовывав": ["закристаллизовывавши"],
    "закристаллизовывавши": ["закристаллизовывав"],
    "закричав": ["закричавши"],
    "закричавши": ["закричав"],
    "закричать": ["выкрикнуть", "крикнуть", "прокричать"],
    "закровенев": ["закровеневши"],
    "закровеневши": ["закровенев"],
    "закровенив": ["закровенивши"],
    "закровенивши": ["закровенив"],
    "закроечный": ["закройный"],
    "закроив": ["закроивши"],
    "закроивши": ["закроив"],
    "закроить": ["скроить", "выкроить"],
    "закройный": ["закроечный"],
    "закропив": ["закропивши"],
    "закропивши": ["закропив"],
    "закрошив": ["закрошивши"],
    "закрошивши": ["закрошив"],
    "закруглев": ["закруглевши"],
    "закруглевши": ["закруглев"],
    "закругление": ["скругление", "округлость", "завершение", "округление", "заключение"],
    "закругленье": ["закругление"],
    "закруглив": ["закругливши"],
    "закругливши": ["закруглив"],
    "закруглить": ["скруглить"],
    "закругляв": ["закруглявши"],
    "закруглявши": ["закругляв"],
    "закруглять": ["скруглять", "оттачивать", "совершенствовать", "отшлифовывать", "сворачивать", "округлять"],
    "закружив": ["закруживши"],
    "закруживши": ["закружив"],
    "закружить": ["закружиться", "закрутиться"],
    "закружиться": ["завертеться"],
    "закрутив": ["закрутивши"],
    "закрутивши": ["закрутив"],
    "закрутить": ["завертеть", "завинтить", "ввернуть", "завернуть", "завить", "свить", "намотать", "заломить", "вывернуть"],
    "закрутить любовь": ["закрутить роман", "завести роман"],
    "закрученность": ["скрученность", "заверченность", "сложность", "усложнённость", "запутанность"],
    "закрученный": ["кручёный"],
    "закручивав": ["закручивавши"],
    "закручивавши": ["закручивав"],
    "закручивание": ["закрутка", "завёртывание", "заворачивание"],
    "закручивание гаек": ["завинчивание гаек"],
    "закручинив": ["закручинивши"],
    "закручинивши": ["закручинив"],
    "закручинить": ["опечалить"],
    "закрыв": ["закрывши"],
    "закрывав": ["закрывавши"],
    "закрывавши": ["закрывав"],
    "закрывать": ["затворять", "закупоривать", "ликвидировать", "арестовывать", "сажать", "осуждать"],
    "закрывши": ["закрыв"],
    "закрытие": ["закрыв", "закрывание", "закрытье", "закрыванье"],
    "закрытый": ["сложенный", "сомкнутый", "запертый", "недоступный", "непостижимый", "загрифованный"],
    "закрыть глаза": ["игнорировать"],
    "закрыть пиздак": ["замолчать"],
    "закрыть фонтан": ["заткнуть фонтан", "срезать фонтан"],
    "закрытье": ["закрытие"],
    "закрякав": ["закрякавши"],
    "закрякавши": ["закрякав"],
    "закряхтев": ["закряхтевши"],
    "закряхтевши": ["закряхтев"],
    "закс": ["заксобрание"],
    "заксобрание": ["парламент", "собрание"],
    "закудакав": ["закудакавши"],
    "закудакавши": ["закудакав"],
    "закудакать": ["закудыкать"],
    "закудахтав": ["закудахтавши"],
    "закудахтавши": ["закудахтав"],
    "закудрявив": ["закудрявивши"],
    "закудрявивши": ["закудрявив"],
    "закудыкав": ["закудыкавши"],
    "закудыкавши": ["закудыкав"],
    "закукарекав": ["закукарекавши"],
    "закукарекавши": ["закукарекав"],
    "закукливав": ["закукливавши"],
    "закукливавши": ["закукливав"],
    "закуковав": ["закуковавши"],
    "закуковавши": ["закуковав"],
    "закулисный": ["келейный", "конфиденциальный", "кулуарный", "негласный", "подпольный", "потаённый", "секретный", "скрываемый", "скрытый", "тайный"],
    "закультивировав": ["закультивировавши"],
    "закультивировавши": ["закультивировав"],
    "закупав": ["закупавши"],
    "закупавши": ["закупав"],
    "закупив": ["закупивши"],
    "закупивши": ["закупив"],
    "закупиться": ["затариться"],
    "закупка": ["покупка", "скупка"],
    "закупорив": ["закупоривши"],
    "закупоривав": ["закупоривавши"],
    "закупоривавши": ["закупоривав"],
    "закупоривание": ["закупорка", "укупоривание"],
    "закупориваться": ["закрываться", "затыкаться"],
    "закупоривши": ["закупорив"],
    "закупорить": ["загерметизировать"],
    "закупориться": ["укупориться", "заткнуться"],
    "закупорка": ["закупоривание", "забивка", "забивание"],
    "закуржавев": ["закуржавевши"],
    "закуржавевши": ["закуржавев"],
    "закурив": ["закуривши"],
    "закуривав": ["закуривавши"],
    "закуривавши": ["закуривав"],
    "закуривши": ["закурив"],
    "закурить": ["прокурить"],
    "закурлыкав": ["закурлыкавши"],
    "закурлыкавши": ["закурлыкав"],
    "закуролесив": ["закуролесивши"],
    "закуролесивши": ["закуролесив"],
    "закурсивив": ["закурсививши"],
    "закурсививши": ["закурсивив"],
    "закурчавев": ["закурчавевши"],
    "закурчавевши": ["закурчавев"],
    "закурчавив": ["закурчавивши"],
    "закурчавивши": ["закурчавив"],
    "закусав": ["закусавши"],
    "закусавши": ["закусав"],
    "закусив": ["закусивши"],
    "закусивши": ["закусив"],
    "закусон": ["закуска"],
    "закусочный": ["трактирный"],
    "закусывав": ["закусывавши"],
    "закусывавши": ["закусывав"],
    "закусь": ["закуска"],
    "закут": ["закута"],
    "закута": ["закут"],
    "закутав": ["закутавши"],
    "закутавши": ["закутав"],
    "закутаться": ["укутаться"],
    "закутив": ["закутивши"],
    "закутивши": ["закутив"],
    "закуток": ["каморка", "уголок"],
    "закуточек": ["уголочек"],
    "закутывав": ["закутывавши"],
    "закутывавши": ["закутывав"],
    "закутываться": ["укутываться"],
    "закэшировав": ["закэшировавши"],
    "закэшировавши": ["закэшировав"],
    "зал": ["холл", "гостиная", "зала", "зало"],
    "зала": ["зал", "зало"],
    "залавировав": ["залавировавши"],
    "залавировавши": ["залавировав"],
    "залавливав": ["залавливавши"],
    "залавливавши": ["залавливав"],
    "заладив": ["заладивши"],
    "заладивши": ["заладив"],
    "заладить": ["затвердить"],
    "залаз": ["залезание", "лаз"],
    "залазать": ["заползать"],
    "залазив": ["залазивши"],
    "залазивши": ["залазив"],
    "залазить": ["залезать", "влезать"],
    "залакав": ["залакавши"],
    "залакавши": ["залакав"],
    "залакировав": ["залакировавши"],
    "залакировавши": ["залакировав"],
    "залакировывав": ["залакировывавши"],
    "залакировывавши": ["залакировывав"],
    "залалсыздандыру": ["зарарсыздандыру"],
    "заламливав": ["заламливавши"],
    "заламливавши": ["заламливав"],
    "заламывав": ["заламывавши"],
    "заламывавши": ["заламывав"],
    "заламыванье": ["заламывание"],
    "залапав": ["залапавши"],
    "залапавши": ["залапав"],
    "залапывав": ["залапывавши"],
    "залапывавши": ["залапывав"],
    "заласив": ["заласивши"],
    "заласивши": ["заласив"],
    "заласкав": ["заласкавши"],
    "заласкавши": ["заласкав"],
    "заластив": ["заластивши"],
    "заластивши": ["заластив"],
    "залатав": ["залатавши"],
    "залатавши": ["залатав"],
    "залатать": ["заплатать", "починить", "излатать", "заштопать", "заштуковать"],
    "залатывав": ["залатывавши"],
    "залатывавши": ["залатывав"],
    "залашивав": ["залашивавши"],
    "залашивавши": ["залашивав"],
    "залащивав": ["залащивавши"],
    "залащивавши": ["залащивав"],
    "залаяв": ["залаявши"],
    "залаявши": ["залаяв"],
    "залебезив": ["залебезивши"],
    "залебезивши": ["залебезив"],
    "залегав": ["залегавши"],
    "залегавши": ["залегав"],
    "залегендировав": ["залегендировавши"],
    "залегендировавши": ["залегендировав"],
    "заледенев": ["заледеневши"],
    "заледеневав": ["заледеневавши"],
    "заледеневавши": ["заледеневав"],
    "заледеневши": ["заледенев"],
    "заледенеть": ["замёрзнуть", "обледенеть", "зальдеть", "закоченеть"],
    "заледенив": ["заледенивши"],
    "заледенивши": ["заледенив"],
    "залез": ["запад", "заник", "заход"],
    "залезав": ["залезавши"],
    "залезавши": ["залезав"],
    "залезать": ["влезать", "взбираться"],
    "залепетав": ["залепетавши"],
    "залепетавши": ["залепетав"],
    "залепив": ["залепивши"],
    "залепивши": ["залепив"],
    "залепить дуло": ["заткнуться"],
    "залепливав": ["залепливавши"],
    "залепливавши": ["залепливав"],
    "залепливать": ["залеплять"],
    "залепляв": ["залеплявши"],
    "залеплявши": ["залепляв"],
    "залесив": ["залесивши"],
    "залесивши": ["залесив"],
    "залесить": ["облесить"],
    "залетав": ["залетавши"],
    "залетавши": ["залетав"],
    "залетев": ["залетевши"],
    "залетевши": ["залетев"],
    "залечив": ["залечивши"],
    "залечивав": ["залечивавши"],
    "залечивавши": ["залечивав"],
    "залечивши": ["залечив"],
    "залзол": ["ларза"],
    "залив": ["бухта", "гавань", "заливание", "заливка", "наливание"],
    "заливав": ["заливавши"],
    "заливавши": ["заливав"],
    "заливистый": ["заливчатый"],
    "заливное": ["студень", "холодец"],
    "заливши": ["залив"],
    "зализа": ["залысина", "проплешина"],
    "зализав": ["зализавши"],
    "зализавши": ["зализав"],
    "зализывав": ["зализывавши"],
    "зализывавши": ["зализывав"],
    "заликовав": ["заликовавши"],
    "заликовавши": ["заликовав"],
    "залиловев": ["залиловевши"],
    "залиловевши": ["залиловев"],
    "залимитировав": ["залимитировавши"],
    "залимитировавши": ["залимитировав"],
    "залимпив": ["залимпивши"],
    "залимпивши": ["залимпив"],
    "залипав": ["залипавши"],
    "залипавши": ["залипав"],
    "залипать": ["заклеиться", "застывать", "подвисать", "сидеть", "просиживать", "засыпать", "задрёмывать"],
    "залипашка": ["залипалка"],
    "залипнув": ["залипнувши"],
    "залипнувши": ["залипнув"],
    "залипнуть": ["слипнуться", "склеиться", "слепиться", "застыть", "замереть", "завязнуть", "застрять", "запасть"],
    "залистав": ["залиставши"],
    "залиставши": ["залистав"],
    "залитовав": ["залитовавши"],
    "залитовавши": ["залитовав"],
    "залить жабры": ["кинуть под жабры", "плеснуть под жабры"],
    "залихватски": ["лихо", "удало", "задорно"],
    "залихватский": ["бесшабашный", "задорный", "лихой", "разбитной", "удалой"],
    "залихорадив": ["залихорадивши"],
    "залихорадивши": ["залихорадив"],
    "залицензировав": ["залицензировавши"],
    "залицензировавши": ["залицензировав"],
    "зало": ["зал", "зала"],
    "залобак": ["закот", "франтон"],
    "залобовав": ["залобовавши"],
    "залобовавши": ["залобовав"],
    "заловив": ["заловивши"],
    "заловивши": ["заловив"],
    "залогировав": ["залогировавши"],
    "залогировавши": ["залогировав"],
    "заложив": ["заложивши"],
    "заложивши": ["заложив"],
    "заложиться": ["закрыться", "броситься", "возникать", "завалиться"],
    "заложный покойник": ["мертвяк", "нечистый", "покойник"],
    "залом": ["заламывание", "надлом", "перегиб", "складка"],
    "заломав": ["заломавши"],
    "заломавши": ["заломав"],
    "заломать": ["ломать", "достать"],
    "заломив": ["заломивши"],
    "заломивши": ["заломив"],
    "залопотав": ["залопотавши"],
    "залопотавши": ["залопотав"],
    "залоснив": ["залоснивши"],
    "залоснивав": ["залоснивавши"],
    "залоснивавши": ["залоснивав"],
    "залоснивши": ["залоснив"],
    "залотошив": ["залотошивши"],
    "залотошивши": ["залотошив"],
    "залохматев": ["залохматевши"],
    "залохматевши": ["залохматев"],
    "залохматеть": ["залохматиться"],
    "залохматиться": ["залохматеть"],
    "залощив": ["залощивши"],
    "залощивши": ["залощив"],
    "залп": ["приступ"],
    "залповый ливень": ["залповый дождь"],
    "залпом": ["сразу"],
    "залубенев": ["залубеневши"],
    "залубеневши": ["залубенев"],
    "залудив": ["залудивши"],
    "залудивши": ["залудив"],
    "залужав": ["залужавши"],
    "залужавши": ["залужав"],
    "залужив": ["залуживши"],
    "залуживши": ["залужив"],
    "залужье": ["прилужье"],
    "залупа": ["залуп", "залупка"],
    "залупа с сыром": ["мудак", "мудачина", "мудло", "залупа", "хуй", "хуй с горы"],
    "залупав": ["залупавши"],
    "залупавши": ["залупав"],
    "залупать": ["запятнать"],
    "залупаться": ["задираться", "дерзить", "нагличать"],
    "залупешив": ["залупешивши"],
    "залупешивши": ["залупешив"],
    "залупив": ["залупивши"],
    "залупивши": ["залупив"],
    "залупистый": ["нарывающийся"],
    "залупить": ["забить", "убить"],
    "залупка": ["залупа", "залуп"],
    "залупливав": ["залупливавши"],
    "залупливавши": ["залупливав"],
    "залупливать": ["залупать", "залуплять"],
    "залупляв": ["залуплявши"],
    "залуплявши": ["залупляв"],
    "залуплять": ["залупывать"],
    "залупнуться": ["выебнуться"],
    "залупоглазый": ["лупоглазый", "пучеглазый", "воблоглазый", "воблоокий"],
    "залучав": ["залучавши"],
    "залучавши": ["залучав"],
    "залучать": ["зазывать", "завлекать", "заманивать"],
    "залучив": ["залучивши"],
    "залучивши": ["залучив"],
    "залучить": ["завлечь", "зазвать"],
    "залущив": ["залущивши"],
    "залущивши": ["залущив"],
    "залысев": ["залысевши"],
    "залысевши": ["залысев"],
    "зальдев": ["зальдевши"],
    "зальдевши": ["зальдев"],
    "зальстив": ["зальстивши"],
    "зальстивши": ["зальстив"],
    "залюбезничав": ["залюбезничавши"],
    "залюбезничавши": ["залюбезничав"],
    "залюбив": ["залюбивши"],
    "залюбивши": ["залюбив"],
    "залютовав": ["залютовавши"],
    "залютовавши": ["залютовав"],
    "залягав": ["залягавши"],
    "залягавши": ["залягав"],
    "залязгав": ["залязгавши"],
    "залязгавши": ["залязгав"],
    "заляпав": ["заляпавши"],
    "заляпавши": ["заляпав"],
    "заляпывав": ["заляпывавши"],
    "заляпывавши": ["заляпывав"],
    "заляскав": ["заляскавши"],
    "заляскавши": ["заляскав"],
    "залёт": ["залетание"],
    "зам": ["заместитель", "зам замыч"],
    "замав": ["замавши"],
    "замавши": ["замав"],
    "замазав": ["замазавши"],
    "замазавши": ["замазав"],
    "замазать": ["замалевать", "зашпаклевать", "заштукатурить", "покрыть", "прикрыть", "заретушировать", "закамуфлировать"],
    "замазка": ["замазывание"],
    "замазывав": ["замазывавши"],
    "замазывавши": ["замазывав"],
    "замазывание": ["замазыванье", "сокрытие", "утаивание"],
    "замазюкав": ["замазюкавши"],
    "замазюкавши": ["замазюкав"],
    "замалевав": ["замалевавши"],
    "замалевавши": ["замалевав"],
    "замаливав": ["замаливавши"],
    "замаливавши": ["замаливав"],
    "замалчивав": ["замалчивавши"],
    "замалчивавши": ["замалчивав"],
    "замалчиванье": ["замалчивание"],
    "замалчивать": ["умалчивать", "утаивать"],
    "замалёвывав": ["замалёвывавши"],
    "замалёвывавши": ["замалёвывав"],
    "замана": ["заман", "осор"],
    "заманав": ["заманавши"],
    "заманавши": ["заманав"],
    "заманать": ["довести", "доконать", "донять", "допечь", "достать", "задолбать", "заколебать", "запарить", "затрахать", "извести", "надоесть"],
    "заманаться": ["запариться", "заколебаться"],
    "заманив": ["заманивши"],
    "заманивав": ["заманивавши"],
    "заманивавши": ["заманивав"],
    "заманиванье": ["заманивание"],
    "заманивать": ["завлекать", "увлекать", "соблазнять"],
    "заманивши": ["заманив"],
    "заманить": ["завлечь"],
    "заманув": ["заманувши"],
    "заманувши": ["заманув"],
    "замануха": ["завлекаловка"],
    "заманчивый": ["соблазнительный", "привлекательный"],
    "замарав": ["замаравши"],
    "замаравши": ["замарав"],
    "замаранность": ["запятнанность"],
    "замаранный": ["изгвазданный", "испакощенный"],
    "замарашка": ["грязнуля", "неряха"],
    "замаривав": ["замаривавши"],
    "замаривавши": ["замаривав"],
    "замаривать": ["морить"],
    "замариновав": ["замариновавши"],
    "замариновавши": ["замариновав"],
    "замариновывав": ["замариновывавши"],
    "замариновывавши": ["замариновывав"],
    "замаркировав": ["замаркировавши"],
    "замаркировавши": ["замаркировав"],
    "замаршировав": ["замаршировавши"],
    "замаршировавши": ["замаршировав"],
    "замарывав": ["замарывавши"],
    "замарывавши": ["замарывав"],
    "замаскировав": ["замаскировавши"],
    "замаскировавши": ["замаскировав"],
    "замаскированный": ["скрытый", "тайный"],
    "замаскировывав": ["замаскировывавши"],
    "замаскировывавши": ["замаскировывав"],
    "замасленный": ["скользкий"],
    "замаслив": ["замасливши"],
    "замасливав": ["замасливавши"],
    "замасливавши": ["замасливав"],
    "замасливши": ["замаслив"],
    "заматерев": ["заматеревши"],
    "заматеревши": ["заматерев"],
    "заматереть": ["повзрослеть", "возмужать", "закоснеть", "закоренеть"],
    "заматовав": ["заматовавши"],
    "заматовавши": ["заматовав"],
    "заматовать": ["заматировать"],
    "заматрицировав": ["заматрицировавши"],
    "заматрицировавши": ["заматрицировав"],
    "заматывав": ["заматывавши"],
    "заматывавши": ["заматывав"],
    "замах": ["замахивание", "претензия"],
    "замахав": ["замахавши"],
    "замахавши": ["замахав"],
    "замахивав": ["замахивавши"],
    "замахивавши": ["замахивав"],
    "замахивание": ["замах", "покушение", "посягание"],
    "замахнув": ["замахнувши"],
    "замахнувши": ["замахнув"],
    "замахнуться": ["размахнуться", "махнуть"],
    "замачивав": ["замачивавши"],
    "замачивавши": ["замачивав"],
    "замашка": ["манера", "повадка", "ухватка", "привычка", "норов", "посконь", "плосконь", "дерганец", "дергань"],
    "замашковый": ["посконный"],
    "замашный": ["замашковый", "посконный", "сручный"],
    "замащивав": ["замащивавши"],
    "замащивавши": ["замащивав"],
    "замащивать": ["мостить"],
    "замаяв": ["замаявши"],
    "замаявши": ["замаяв"],
    "замаять": ["умаять"],
    "замаячив": ["замаячивши"],
    "замаячивши": ["замаячив"],
    "замаячивший": ["замелькавший"],
    "замбар": ["занбар"],
    "замбия": ["республика замбия"],
    "замбуутив": ["замбуулин", "замбатив", "замлин"],
    "замгенсека": ["замгенсекретаря"],
    "замгенсекретаря": ["замгенсека"],
    "замгоссекретаря": ["замминистра", "иностранный", "дела"],
    "замедленье": ["замедление"],
    "замедлив": ["замедливши"],
    "замедливав": ["замедливавши"],
    "замедливавши": ["замедливав"],
    "замедливши": ["замедлив"],
    "замедлитель": ["ингибитор"],
    "замедляв": ["замедлявши"],
    "замедлявши": ["замедляв"],
    "замежевав": ["замежевавши"],
    "замежевавши": ["замежевав"],
    "замежёвывав": ["замежёвывавши"],
    "замежёвывавши": ["замежёвывав"],
    "замелев": ["замелевши"],
    "замелевши": ["замелев"],
    "замелеть": ["обмелеть"],
    "замелив": ["замеливши"],
    "замеливав": ["замеливавши"],
    "замеливавши": ["замеливав"],
    "замеливши": ["замелив"],
    "замелькав": ["замелькавши"],
    "замелькавши": ["замелькав"],
    "замельтешив": ["замельтешивши"],
    "замельтешивши": ["замельтешив"],
    "заменив": ["заменивши"],
    "заменивши": ["заменив"],
    "заменимый": ["заменяемый"],
    "заменитель": ["суррогат", "эрзац", "аналог"],
    "заменяв": ["заменявши"],
    "заменявши": ["заменяв"],
    "заменять": ["сменять", "подменять", "замещать"],
    "замер": ["измерение"],
    "замерев": ["замерши"],
    "замереть": ["застыть", "остолбенеть", "оцепенеть", "окаменеть", "остановиться", "заглохнуть", "прекратиться", "затихнуть", "умолкнуть"],
    "замерзав": ["замерзавши"],
    "замерзавши": ["замерзав"],
    "замерзать": ["мёрзнуть", "промерзать", "коченеть", "зябнуть", "стыть", "стынуть", "колеть", "дрогнуть", "леденеть", "застывать", "леденить", "вымерзать", "вставать", "сковываться"],
    "замерив": ["замеривши"],
    "замеривав": ["замеривавши"],
    "замеривавши": ["замеривав"],
    "замеривши": ["замерив"],
    "замерный": ["измерительный"],
    "замертвев": ["замертвевши"],
    "замертвевши": ["замертвев"],
    "замертво": ["бездыханно", "мёртво", "мертвецки", "бесчувственно"],
    "замерцав": ["замерцавши"],
    "замерцавши": ["замерцав"],
    "замерши": ["замерев"],
    "замеряв": ["замерявши"],
    "замерявши": ["замеряв"],
    "замерять": ["измерять", "мерить"],
    "замес": ["винегрет", "гремучая смесь", "коктейль", "закваска", "схватка", "стычка", "сражение", "битва", "поединок", "драка", "избиение", "мочилово", "рубилово", "происшествие", "ситуация"],
    "замесив": ["замесивши"],
    "замесивши": ["замесив"],
    "заместив": ["заместивши"],
    "заместивши": ["заместив"],
    "заместительная гормональная терапия": ["згт"],
    "заместо": ["вместо", "взамен", "как за"],
    "заметав": ["заметавши"],
    "заметавши": ["заметав"],
    "заметаемый": ["заполняемый"],
    "заметивши": ["заметив"],
    "заметина": ["заметка"],
    "заметить": ["приметить", "отметить"],
    "заметка": ["заметина"],
    "замечав": ["замечавши"],
    "замечавши": ["замечав"],
    "замечанье": ["замечание"],
    "замечательно": ["превосходно"],
    "замечательный": ["отличный", "потрясающий", "великолепный", "прекрасный", "удивительный", "примечательный", "поразительный"],
    "замечать": ["обнаруживать", "видеть", "отмечать"],
    "замечтав": ["замечтавши"],
    "замечтавши": ["замечтав"],
    "замешав": ["замешавши"],
    "замешавши": ["замешав"],
    "замешанность": ["причастность", "вовлечённость", "связанность"],
    "замешивав": ["замешивавши"],
    "замешивавши": ["замешивав"],
    "замешкав": ["замешкавши"],
    "замешкавши": ["замешкав"],
    "замешкать": ["замешкаться"],
    "замешкаться": ["задержаться"],
    "замещав": ["замещавши"],
    "замещавши": ["замещав"],
    "замещать": ["заменять", "подменять"],
    "замещенье": ["замещение"],
    "замзам": ["земзем"],
    "замигав": ["замигавши"],
    "замигавши": ["замигав"],
    "замиксовав": ["замиксовавши"],
    "замиксовавши": ["замиксовав"],
    "заминав": ["заминавши"],
    "заминавши": ["заминав"],
    "заминать": ["замалчивать"],
    "заминировав": ["заминировавши"],
    "заминировавши": ["заминировав"],
    "заминировать": ["испражниться"],
    "заминка": ["приостановка", "прерывание", "пауза", "передышка", "перерыв", "проволочка"],
    "заминков": ["хоккаш"],
    "заминларза": ["зилзила"],
    "заминусовав": ["заминусовавши"],
    "заминусовавши": ["заминусовав"],
    "замиокулькас": ["долларовое дерево"],
    "замира": ["мира"],
    "замирав": ["замиравши"],
    "замиравши": ["замирав"],
    "замиранье": ["замирание"],
    "замиренье": ["замирение"],
    "замирив": ["замиривши"],
    "замиривши": ["замирив"],
    "замириться": ["помириться", "смириться"],
    "замироточив": ["замироточивши"],
    "замироточивши": ["замироточив"],
    "замиряв": ["замирявши"],
    "замирявши": ["замиряв"],
    "замисленост": ["замечтаност", "унесеност"],
    "замислювати": ["замишляти"],
    "замистон": ["зимистон"],
    "замишляти": ["замислювати"],
    "замкнув": ["замкнувши"],
    "замкнувши": ["замкнув"],
    "замковый": ["замочный"],
    "замковый камень": ["замок"],
    "замлев": ["замлевши"],
    "замлевши": ["замлев"],
    "замлеть": ["обомлеть", "занеметь", "одеревенеть"],
    "замминистр": ["замминистра"],
    "замминистра": ["заместитель", "министр", "замминистр"],
    "замнарком": ["замнаркома"],
    "замначальника": ["замнач"],
    "замнём для ясности": ["проехали"],
    "замовчати": ["замовкнути"],
    "замогильный": ["загробный", "потусторонний", "посмертный", "глухой", "низкий"],
    "замодничав": ["замодничавши"],
    "замодничавши": ["замодничав"],
    "заможност": ["богатство", "имотност", "състояние", "охолство", "добруване"],
    "замозжив": ["замозживши"],
    "замозживши": ["замозжив"],
    "замок": ["дворец", "крепость", "тюрьма"],
    "замокав": ["замокавши"],
    "замокавши": ["замокав"],
    "замокнув": ["замокнувши"],
    "замокнувши": ["замокнув"],
    "замокнуть": ["намокнуть"],
    "замокрев": ["замокревши"],
    "замокревши": ["замокрев"],
    "замолаживав": ["замолаживавши"],
    "замолаживавши": ["замолаживав"],
    "замолаживать": ["затуманиваться"],
    "замолачивав": ["замолачивавши"],
    "замолачивавши": ["замолачивав"],
    "замолвив": ["замолвивши"],
    "замолвивши": ["замолвив"],
    "замолвливав": ["замолвливавши"],
    "замолвливавши": ["замолвливав"],
    "замолвливать": ["замолвлять"],
    "замолвляв": ["замолвлявши"],
    "замолвлявши": ["замолвляв"],
    "замолвлять": ["замолвливать"],
    "замолив": ["замоливши"],
    "замоливши": ["замолив"],
    "замолкав": ["замолкавши"],
    "замолкавши": ["замолкав"],
    "замолкнув": ["замолкнувши"],
    "замолкнувши": ["замолкнув"],
    "замолов": ["замоловши"],
    "замоловши": ["замолов"],
    "замолотив": ["замолотивши"],
    "замолотивши": ["замолотив"],
    "замолчав": ["замолчавши"],
    "замолчавши": ["замолчав"],
    "замолчать": ["замолкнуть", "умолкнуть", "смолкнуть"],
    "замони гузаштаи муайян": ["прошедшее продолженное время"],
    "замонолитив": ["замонолитивши"],
    "замонолитивши": ["замонолитив"],
    "замоноличивав": ["замоноличивавши"],
    "замоноличивавши": ["замоноличивав"],
    "замораживав": ["замораживавши"],
    "замораживавши": ["замораживав"],
    "заморачивав": ["заморачивавши"],
    "заморачивавши": ["заморачивав"],
    "заморачиваться": ["утруждаться", "возиться", "заниматься", "озабочиваться", "задумываться", "беспокоиться", "тревожиться"],
    "заморгав": ["заморгавши"],
    "заморгавши": ["заморгав"],
    "замордовав": ["замордовавши"],
    "замордовавши": ["замордовав"],
    "замордовать": ["заморить"],
    "замордовывав": ["замордовывавши"],
    "замордовывавши": ["замордовывав"],
    "заморив": ["заморивши"],
    "заморивши": ["заморив"],
    "заморозив": ["заморозивши"],
    "заморозивши": ["заморозив"],
    "заморозка": ["замораживание"],
    "заморозок": ["утренник", "утренничек", "зазимок"],
    "заморока": ["морока"],
    "заморосив": ["заморосивши"],
    "заморосивши": ["заморосив"],
    "заморочив": ["заморочивши"],
    "заморочивши": ["заморочив"],
    "заморочить": ["ввести в заблуждение", "сбить с толку", "запутать", "задурить"],
    "заморщив": ["заморщивши"],
    "заморщивши": ["заморщив"],
    "заморяв": ["заморявши"],
    "заморявши": ["заморяв"],
    "замостив": ["замостивши"],
    "замостивши": ["замостив"],
    "замостить": ["вымостить"],
    "замотав": ["замотавши"],
    "замотавши": ["замотав"],
    "замотаться": ["закачаться"],
    "замотивировав": ["замотивировавши"],
    "замотивировавши": ["замотивировав"],
    "замохав": ["замохавши"],
    "замохавши": ["замохав"],
    "замохать": ["пропарить"],
    "замоховев": ["замоховевши"],
    "замоховевши": ["замоховев"],
    "замочек": ["замок"],
    "замочив": ["замочивши"],
    "замочивши": ["замочив"],
    "замочить в сортире": ["в сортире замочить"],
    "замочка": ["замачивание"],
    "замр": ["най"],
    "замстив": ["замстивши"],
    "замстивши": ["замстив"],
    "замудрив": ["замудривши"],
    "замудривши": ["замудрив"],
    "замудрствовав": ["замудрствовавши"],
    "замудрствовавши": ["замудрствовав"],
    "замульчировав": ["замульчировавши"],
    "замульчировавши": ["замульчировав"],
    "замундштучив": ["замундштучивши"],
    "замундштучивав": ["замундштучивавши"],
    "замундштучивавши": ["замундштучивав"],
    "замундштучивши": ["замундштучив"],
    "замуравев": ["замуравевши"],
    "замуравевши": ["замуравев"],
    "замураветь": ["замуравиться", "задернеть"],
    "замуравив": ["замуравивши"],
    "замуравивши": ["замуравив"],
    "замуравиться": ["запереться", "задернеть", "замураветь"],
    "замурзав": ["замурзавши"],
    "замурзавши": ["замурзав"],
    "замурзанный": ["испачканный", "замызганный"],
    "замурлыкав": ["замурлыкавши"],
    "замурлыкавши": ["замурлыкав"],
    "замурлыкать": ["замяукать", "закурлыкать", "заморкотать"],
    "замуровав": ["замуровавши"],
    "замуровавши": ["замуровав"],
    "замуровать": ["запечатать", "похоронить", "захоронить"],
    "замуровывав": ["замуровывавши"],
    "замуровывавши": ["замуровывав"],
    "замурчав": ["замурчавши"],
    "замурчавши": ["замурчав"],
    "замурчательный": ["замечательный", "отличный"],
    "замуслив": ["замусливши"],
    "замусливав": ["замусливавши"],
    "замусливавши": ["замусливав"],
    "замусливши": ["замуслив"],
    "замусолив": ["замусоливши"],
    "замусоливав": ["замусоливавши"],
    "замусоливавши": ["замусоливав"],
    "замусоливши": ["замусолив"],
    "замусолить": ["замуслить", "затаскать"],
    "замусолиться": ["замуслиться"],
    "замусоренный": ["загрязнённый", "захламлённый", "загаженный"],
    "замусорив": ["замусоривши"],
    "замусоривав": ["замусоривавши"],
    "замусоривавши": ["замусоривав"],
    "замусоривание": ["загаживание", "загрязнение", "испоганивание"],
    "замусоривать": ["загрязнять", "засорять"],
    "замусоривши": ["замусорив"],
    "замусориться": ["захламиться", "загрязниться", "загадиться", "засориться"],
    "замутнев": ["замутневши"],
    "замутневши": ["замутнев"],
    "замутнеться": ["замутниться"],
    "замутнив": ["замутнивши"],
    "замутнивши": ["замутнив"],
    "замутниться": ["замутнеться"],
    "замутняв": ["замутнявши"],
    "замутнявши": ["замутняв"],
    "замутнять": ["мутить", "размывать", "затуманивать", "помрачать", "запутывать"],
    "замухрышка": ["замарашка", "неряха", "михрютка"],
    "замучав": ["замучавши"],
    "замучавши": ["замучав"],
    "замучив": ["замучивши"],
    "замучивав": ["замучивавши"],
    "замучивавши": ["замучивав"],
    "замучивать": ["замаривать"],
    "замучивши": ["замучив"],
    "замуштровав": ["замуштровавши"],
    "замуштровавши": ["замуштровав"],
    "замшев": ["замшевши"],
    "замшевши": ["замшев"],
    "замшелый": ["замшалый", "позеленевший", "устаревший", "старый", "закоренелый"],
    "замшив": ["замшивши"],
    "замшивши": ["замшив"],
    "замыв": ["замывши"],
    "замывав": ["замывавши"],
    "замывавши": ["замывав"],
    "замывши": ["замыв"],
    "замызгав": ["замызгавши"],
    "замызгавши": ["замызгав"],
    "замызганный": ["изгвазданный"],
    "замызгивав": ["замызгивавши"],
    "замызгивавши": ["замызгивав"],
    "замызгивание": ["замусоливание"],
    "замызгивать": ["мызгать"],
    "замыкав": ["замыкавши"],
    "замыкавши": ["замыкав"],
    "замыкание": ["закольцовывание", "перемыкание"],
    "замыканье": ["замыкание"],
    "замыкать": ["закрывать", "запирать", "окаймлять", "завершать", "смыкать"],
    "замыкнув": ["замыкнувши"],
    "замыкнувши": ["замыкнув"],
    "замылив": ["замыливши"],
    "замыливав": ["замыливавши"],
    "замыливавши": ["замыливав"],
    "замыливать": ["намыливать"],
    "замыливши": ["замылив"],
    "замысел": ["задумка", "намерение", "план", "интенция", "умысел", "проект", "прожект", "идея", "концепция", "расчёт", "сюжет"],
    "замыслив": ["замысливши"],
    "замысливав": ["замысливавши"],
    "замысливавши": ["замысливав"],
    "замысливши": ["замыслив"],
    "замыслить": ["задумать"],
    "замысловато": ["хитро", "хитроумно", "мудрёно", "затейливо"],
    "замысловатый": ["мудрёный"],
    "замытарив": ["замытаривши"],
    "замытаривши": ["замытарив"],
    "замытарить": ["замордовать", "замучить"],
    "замычав": ["замычавши"],
    "замычавши": ["замычав"],
    "замышляв": ["замышлявши"],
    "замышлявши": ["замышляв"],
    "замышлять": ["задумывать"],
    "замяв": ["замявши"],
    "замявши": ["замяв"],
    "замямлив": ["замямливши"],
    "замямливши": ["замямлив"],
    "замяна": ["подмяна", "заменяване"],
    "замятня": ["метель", "смятенье", "бунт"],
    "замять": ["смять", "зажевать", "раздавить", "задавить"],
    "замяукав": ["замяукавши"],
    "замяукавши": ["замяукав"],
    "замяучив": ["замяучивши"],
    "замяучивши": ["замяучив"],
    "замёрзнув": ["замёрзнувши"],
    "замёрзнувши": ["замёрзнув"],
    "замёрзнуть": ["окоченеть", "закоченеть", "продрогнуть"],
    "замёрзший": ["продрогший", "озябший", "задубевший", "окоченевший", "заледеневший", "заиндевевший"],
    "замётывав": ["замётывавши"],
    "замётывавши": ["замётывав"],
    "замётывать": ["закидывать", "забрасывать"],
    "занаваживав": ["занаваживавши"],
    "занаваживавши": ["занаваживав"],
    "занавес": ["занавеска", "портьера"],
    "занавесив": ["занавесивши"],
    "занавесивши": ["занавесив"],
    "занавесить": ["закрыть", "покрыть"],
    "занавеска": ["гардина", "задергушка", "штора"],
    "занавесь": ["занавеска", "занавес"],
    "занавешивав": ["занавешивавши"],
    "занавешивавши": ["занавешивав"],
    "занавоживав": ["занавоживавши"],
    "занавоживавши": ["занавоживав"],
    "занавоживать": ["унавоживать", "навозить"],
    "занавозив": ["занавозивши"],
    "занавозивши": ["занавозив"],
    "занавозиться": ["унавозиться"],
    "занадобиться": ["потребоваться", "понадобиться"],
    "занадто": ["надто"],
    "занази": ["лекки"],
    "занайтовив": ["занайтовивши"],
    "занайтовивши": ["занайтовив"],
    "занайтовить": ["снайтовить"],
    "занаркотизировав": ["занаркотизировавши"],
    "занаркотизировавши": ["занаркотизировав"],
    "занарядив": ["занарядивши"],
    "занарядивши": ["занарядив"],
    "занаряжав": ["занаряжавши"],
    "занаряжавши": ["занаряжав"],
    "занаряживав": ["занаряживавши"],
    "занаряживавши": ["занаряживав"],
    "занаучив": ["занаучивши"],
    "занаучивши": ["занаучив"],
    "заначив": ["заначивши"],
    "заначивав": ["заначивавши"],
    "заначивавши": ["заначивав"],
    "заначивать": ["припрятывать", "утаивать", "заныкивать", "нычить"],
    "заначивши": ["заначив"],
    "заначить": ["утаить", "припрятать"],
    "заначка": ["загашник", "галинник", "зажальник", "запичужник", "курок", "качка", "фартыцор", "ховыра", "шурша", "подкожные деньги", "подкожные монеты", "подкожные"],
    "занашивав": ["занашивавши"],
    "занашивавши": ["занашивав"],
    "занаят": ["занятие", "поминък", "професия"],
    "зандан": ["тъмница", "затвор", "тюрма"],
    "занде": ["азанде"],
    "зане": ["ибо", "поелику", "понеже", "поскольку", "так как", "потому что"],
    "заневолив": ["заневоливши"],
    "заневоливши": ["заневолив"],
    "занегодовав": ["занегодовавши"],
    "занегодовавши": ["занегодовав"],
    "занедужив": ["занедуживши"],
    "занедуживши": ["занедужив"],
    "занедужувати": ["захворювати"],
    "занеже": ["зане", "понеже", "поелику", "поскольку", "так как", "потому что", "бо", "ибо"],
    "занежив": ["занеживши"],
    "занеживши": ["занежив"],
    "занеистовствовав": ["занеистовствовавши"],
    "занеистовствовавши": ["занеистовствовав"],
    "занемев": ["занемевши"],
    "занемевши": ["занемев"],
    "занемогав": ["занемогавши"],
    "занемогавши": ["занемогав"],
    "занемогать": ["заболевать"],
    "занемочь": ["занедужить", "захворать", "заболеть"],
    "заненастив": ["заненастивши"],
    "заненастивши": ["заненастив"],
    "заненастить": ["разнепогодиться"],
    "занепогодив": ["занепогодивши"],
    "занепогодивши": ["занепогодив"],
    "занервничав": ["занервничавши"],
    "занервничавши": ["занервничав"],
    "занести": ["принести", "забросить", "вписать", "записать", "включить", "отклонить", "замахнуться", "взмахнуть"],
    "занижав": ["занижавши"],
    "занижавши": ["занижав"],
    "занижать": ["понижать", "низить", "детонировать"],
    "заниження": ["занижування"],
    "занизив": ["занизивши"],
    "занизивши": ["занизив"],
    "занимав": ["занимавши"],
    "занимавши": ["занимав"],
    "занимательно": ["интересно", "увлекательно", "занятно"],
    "занимательность": ["увлекательность"],
    "занимательный": ["интересный", "увлекательный", "занятный"],
    "занимать": ["одалживаться"],
    "занмурда": ["бева"],
    "заново": ["вновь", "ещё раз", "снова", "по-новому", "сызнова"],
    "заноза": ["шип", "колючка", "зануда", "надоедала", "бухтила", "бухтило", "кайфолом", "мозгоклюй", "забава"],
    "занозив": ["занозивши"],
    "занозивши": ["занозив"],
    "занозистый": ["негладкий", "щепистый", "щепливый", "задористый", "занозливый", "занозчивый", "щеповатый", "занозоватый"],
    "заномеровав": ["заномеровавши"],
    "заномеровавши": ["заномеровав"],
    "заномеровывав": ["заномеровывавши"],
    "заномеровывавши": ["заномеровывав"],
    "занормировав": ["занормировавши"],
    "занормировавши": ["занормировав"],
    "занос": ["занесение", "привнесение", "принесение"],
    "заносив": ["заносивши"],
    "заносивши": ["заносив"],
    "заносчиво": ["высокомерно", "самоуверенно", "дерзко", "надменно", "кичливо", "спесиво"],
    "заносчивость": ["высокомерие", "зазнайство", "спесь", "чванство", "гонор", "апломб"],
    "заносчивый": ["высокомерный", "надменный", "спесивый", "чванливый"],
    "заночевав": ["заночевавши"],
    "заночевавши": ["заночевав"],
    "заночёвывав": ["заночёвывавши"],
    "заночёвывавши": ["заночёвывав"],
    "заношенный": ["старый"],
    "зануда": ["птаха"],
    "занудив": ["занудивши"],
    "занудивши": ["занудив"],
    "занудливый": ["занудный", "занудистый", "нудный", "надоедливый"],
    "занудство": ["занудность"],
    "занудствовав": ["занудствовавши"],
    "занудствовавши": ["занудствовав"],
    "занудствование": ["занудство"],
    "занудствовать": ["занудничать", "брюзжать", "гундеть", "грузить", "жужжать"],
    "зануздав": ["зануздавши"],
    "зануздавши": ["зануздав"],
    "зануздывав": ["зануздывавши"],
    "зануздывавши": ["зануздывав"],
    "занулив": ["зануливши"],
    "зануливши": ["занулив"],
    "зануляв": ["занулявши"],
    "занулявши": ["зануляв"],
    "занумеровав": ["занумеровавши"],
    "занумеровавши": ["занумеровав"],
    "занумеровывав": ["занумеровывавши"],
    "занумеровывавши": ["занумеровывав"],
    "заныв": ["занывши"],
    "занывав": ["занывавши"],
    "занывавши": ["занывав"],
    "занывши": ["заныв"],
    "заныкав": ["заныкавши"],
    "заныкавши": ["заныкав"],
    "заныканный": ["спрятанный"],
    "заныкать": ["спрятать", "утаить", "припрятать"],
    "заныкаться": ["спрятаться", "притаиться", "лечь на дно", "затихариться", "зашхериться", "зашкериться"],
    "заныкивав": ["заныкивавши"],
    "заныкивавши": ["заныкивав"],
    "заныривав": ["заныривавши"],
    "заныривавши": ["заныривав"],
    "занырнув": ["занырнувши"],
    "занырнувши": ["занырнув"],
    "заныряв": ["занырявши"],
    "занырявши": ["заныряв"],
    "занюнив": ["занюнивши"],
    "занюнивши": ["занюнив"],
    "занюхав": ["занюхавши"],
    "занюхавши": ["занюхав"],
    "занюханный": ["грязный", "неухоженный"],
    "занюхивав": ["занюхивавши"],
    "занюхивавши": ["занюхивав"],
    "заняв": ["занявши"],
    "занявши": ["заняв"],
    "занянчив": ["занянчивши"],
    "занянчивши": ["занянчив"],
    "занятие": ["взятие", "оккупация", "захват", "заполнение", "деятельность", "дело", "времяпрепровождение", "труд", "работа", "профессия", "урок", "час", "класс", "упражнение", "тренировка"],
    "занятно": ["занимательно", "интересно"],
    "занятный": ["занимательный", "интересный", "увлекательный", "забавный", "любопытный"],
    "занятой": ["занятый", "загруженный"],
    "занять": ["одолжиться", "взять в долг", "взять взаймы", "одолжить"],
    "заняться": ["приступить"],
    "зао": ["закрытое акционерное общество"],
    "заобсуждав": ["заобсуждавши"],
    "заобсуждавши": ["заобсуждав"],
    "заовалив": ["заоваливши"],
    "заоваливши": ["заовалив"],
    "заодно": ["вместе", "сообща", "кстати", "попутно", "сразу"],
    "заозёрск": ["западная лица"],
    "заойкав": ["заойкавши"],
    "заойкавши": ["заойкав"],
    "заорав": ["заоравши"],
    "заоравши": ["заорав"],
    "заорать": ["завопить", "закричать"],
    "заорганизовав": ["заорганизовавши"],
    "заорганизовавши": ["заорганизовав"],
    "заорганизовывав": ["заорганизовывавши"],
    "заорганизовывавши": ["заорганизовывав"],
    "заосенев": ["заосеневши"],
    "заосеневши": ["заосенев"],
    "заосеняв": ["заосенявши"],
    "заосенявши": ["заосеняв"],
    "заострив": ["заостривши"],
    "заостривши": ["заострив"],
    "заостряв": ["заострявши"],
    "заострявши": ["заостряв"],
    "заострённо": ["обострённо"],
    "заохав": ["заохавши"],
    "заохавши": ["заохав"],
    "заочник": ["заушник", "студент"],
    "заочница": ["заушница", "студентка"],
    "заочно": ["за глаза", "за спиной"],
    "заочное обучение": ["заочка"],
    "запад": ["вест", "закат"],
    "западав": ["западавши"],
    "западавши": ["западав"],
    "западенщина": ["западная украина"],
    "западло": ["впадлу", "зашквар", "зашкварно", "стыдно", "унизительно", "позорно", "зазорно", "негоже", "претит", "лень", "неохота", "жалко", "досадно"],
    "западная азия": ["передняя азия"],
    "западная виргиния": ["западная вирджиния"],
    "западная двина": ["даугава"],
    "западная украина": ["западенщина"],
    "западнизация": ["вестернизация"],
    "западник": ["европеист", "европист", "судно"],
    "западничество": ["европеизм", "европейство", "западнизация", "вестернизация", "западнизм"],
    "западно-казахстанская область": ["зко"],
    "западно-сибирский край": ["зск"],
    "западносахарец": ["сахарави"],
    "западные партнёры": ["коллективный запад"],
    "западный административный округ": ["зао"],
    "западный берег реки иордан": ["иудея и самария"],
    "западный буг": ["буг"],
    "западный мир": ["запад", "коллективный запад"],
    "западный мурман": ["мурманская сторона", "мурманский конец", "норвежский конец"],
    "западня": ["ловушка"],
    "запаздывав": ["запаздывавши"],
    "запаздывавши": ["запаздывав"],
    "запаздывать": ["задерживаться"],
    "запаивав": ["запаивавши"],
    "запаивавши": ["запаивав"],
    "запакетировав": ["запакетировавши"],
    "запакетировавши": ["запакетировав"],
    "запаклив": ["запакливши"],
    "запакливши": ["запаклив"],
    "запаковав": ["запаковавши"],
    "запаковавши": ["запаковав"],
    "запаковать": ["упаковать"],
    "запаковывав": ["запаковывавши"],
    "запаковывавши": ["запаковывав"],
    "запаковывать": ["паковать", "упаковывать"],
    "запакостив": ["запакостивши"],
    "запакостивши": ["запакостив"],
    "запалзывав": ["запалзывавши"],
    "запалзывавши": ["запалзывав"],
    "запалив": ["запаливши"],
    "запаливав": ["запаливавши"],
    "запаливавши": ["запаливав"],
    "запаливши": ["запалив"],
    "запалить": ["разжечь", "зажечь", "выдать"],
    "запалохаць": ["запужаць"],
    "запальцованный": ["вульгарный", "вычурный", "пошлый", "фиглярский"],
    "запальчиво": ["несдержанно", "вспыльчиво", "страстно", "пылко", "горячо"],
    "запальчивый": ["вспыльчивый", "задиристый", "гневный", "разъярённый", "негодующий", "страстный", "пылкий", "азартный", "увлечённый", "необузданный", "задористый"],
    "запалянко": ["ентусиаст", "въодушевен"],
    "запамятовав": ["запамятовавши"],
    "запамятовавши": ["запамятовав"],
    "запамятованный": ["забытый"],
    "запамятовать": ["забыть", "позабыть"],
    "запаниковав": ["запаниковавши"],
    "запаниковавши": ["запаниковав"],
    "запанировав": ["запанировавши"],
    "запанировавши": ["запанировав"],
    "запанувати": ["зацарювати"],
    "запара": ["запарка", "спешка"],
    "запараллелив": ["запараллеливши"],
    "запараллеливши": ["запараллелив"],
    "запарив": ["запаривши"],
    "запаривав": ["запаривавши"],
    "запаривавши": ["запаривав"],
    "запаривши": ["запарив"],
    "запарить": ["распарить", "заварить", "сварить", "загнать", "замучить", "надоесть", "достать", "задолбать", "заколебать", "задымиться"],
    "запарка": ["загруз", "аврал"],
    "запарковав": ["запарковавши"],
    "запарковавши": ["запарковав"],
    "запарковаться": ["припарковаться"],
    "запаролив": ["запароливши"],
    "запароливав": ["запароливавши"],
    "запароливавши": ["запароливав"],
    "запароливши": ["запаролив"],
    "запархивав": ["запархивавши"],
    "запархивавши": ["запархивав"],
    "запаршивев": ["запаршивевши"],
    "запаршивевши": ["запаршивев"],
    "запарывав": ["запарывавши"],
    "запарывавши": ["запарывав"],
    "запас": ["резерв"],
    "запасав": ["запасавши"],
    "запасавши": ["запасав"],
    "запасаться": ["обзаводиться"],
    "запасаться попкорном": ["запасаться биноклями"],
    "запасмурнев": ["запасмурневши"],
    "запасмурневши": ["запасмурнев"],
    "запасной": ["запасный"],
    "запасной аэродром": ["план б"],
    "запасный": ["запасной"],
    "запасный выход": ["аварийный выход"],
    "запасняк": ["резервист"],
    "запасть": ["впасть", "влюбиться"],
    "запатентовав": ["запатентовавши"],
    "запатентовавши": ["запатентовав"],
    "запатентовывав": ["запатентовывавши"],
    "запатентовывавши": ["запатентовывав"],
    "запатовав": ["запатовавши"],
    "запатовавши": ["запатовав"],
    "запаузив": ["запаузивши"],
    "запаузивши": ["запаузив"],
    "запах": ["дух", "амбре"],
    "запахав": ["запахавши"],
    "запахавши": ["запахав"],
    "запахивав": ["запахивавши"],
    "запахивавши": ["запахивав"],
    "запахнув": ["запахнувши"],
    "запахнувши": ["запахнув"],
    "запачкав": ["запачкавши"],
    "запачкавши": ["запачкав"],
    "запашник": ["соха", "лущильник"],
    "запашок": ["душок"],
    "запаяв": ["запаявши"],
    "запаявши": ["запаяв"],
    "запев": ["запевание", "припев", "зачин"],
    "запевав": ["запевавши"],
    "запевавши": ["запевав"],
    "запевала": ["запевало", "запевальщик", "инициатор", "зачинщик", "заводила", "затейщик", "закопёрщик", "заводиловец", "заводчик"],
    "запевало": ["запевала"],
    "запевальщик": ["запевала"],
    "запевод": ["запевала"],
    "запевши": ["запев"],
    "запейджерив": ["запейджеривши"],
    "запейджеривши": ["запейджерив"],
    "запекав": ["запекавши"],
    "запекавши": ["запекав"],
    "запекание": ["выпекание"],
    "запеленав": ["запеленавши"],
    "запеленавши": ["запеленав"],
    "запеленгировав": ["запеленгировавши"],
    "запеленгировавши": ["запеленгировав"],
    "запеленговав": ["запеленговавши"],
    "запеленговавши": ["запеленговав"],
    "запеленговывав": ["запеленговывавши"],
    "запеленговывавши": ["запеленговывав"],
    "запелёнывав": ["запелёнывавши"],
    "запелёнывавши": ["запелёнывав"],
    "запендюрив": ["запендюривши"],
    "запендюривав": ["запендюривавши"],
    "запендюривавши": ["запендюривав"],
    "запендюривши": ["запендюрив"],
    "запенив": ["запенивши"],
    "запенивав": ["запенивавши"],
    "запенивавши": ["запенивав"],
    "запенивши": ["запенив"],
    "запеняв": ["запенявши"],
    "запенявши": ["запеняв"],
    "запердев": ["запердевши"],
    "запердевши": ["запердев"],
    "запердеть": ["забздеть", "пропердеть"],
    "заперев": ["заперши"],
    "заперевшись": ["запершись"],
    "запереживав": ["запереживавши"],
    "запереживавши": ["запереживав"],
    "запереть": ["замкнуть", "перегородить", "блокировать"],
    "заперхав": ["заперхавши"],
    "заперхавши": ["заперхав"],
    "заперши": ["заперев"],
    "запершив": ["запершивши"],
    "запершивши": ["запершив"],
    "запестрев": ["запестревши"],
    "запестревши": ["запестрев"],
    "запестрив": ["запестривши"],
    "запестривши": ["запестрив"],
    "запетав": ["запетавши"],
    "запетавши": ["запетав"],
    "запетать": ["втиснуть", "затолкать", "засунуть", "положить", "заштопать", "починить", "задавить", "задушить", "замучить", "утомить", "заколоть", "зарезать", "забить"],
    "запетляв": ["запетлявши"],
    "запетлявши": ["запетляв"],
    "запеть": ["опошлить"],
    "запечатав": ["запечатавши"],
    "запечатавши": ["запечатав"],
    "запечатлев": ["запечатлевши"],
    "запечатлевав": ["запечатлевавши"],
    "запечатлевавши": ["запечатлевав"],
    "запечатлевание": ["запечатление"],
    "запечатлевши": ["запечатлев"],
    "запечатление": ["запечатлевание"],
    "запечатлеть": ["изобразить", "отобразить", "запомнить"],
    "запечатывав": ["запечатывавши"],
    "запечатывавши": ["запечатывав"],
    "запечье": ["запечек", "захолустье"],
    "запив": ["запивши"],
    "запивав": ["запивавши"],
    "запивавши": ["запивав"],
    "запивка": ["запивон"],
    "запивон": ["запивка"],
    "запивши": ["запив"],
    "запиздев": ["запиздевши"],
    "запиздевши": ["запиздев"],
    "запиздеться": ["заговориться", "заболтаться", "зацепиться языком", "зацепиться языками", "завраться", "изовраться"],
    "запиздив": ["запиздивши"],
    "запиздивши": ["запиздив"],
    "запиздрячив": ["запиздрячивши"],
    "запиздрячивши": ["запиздрячив"],
    "запиздрячить": ["захуячить"],
    "запиздюливав": ["запиздюливавши"],
    "запиздюливавши": ["запиздюливав"],
    "запиздюливать": ["запиздюривать"],
    "запиздюривав": ["запиздюривавши"],
    "запиздюривавши": ["запиздюривав"],
    "запиздючив": ["запиздючивши"],
    "запиздючивши": ["запиздючив"],
    "запикав": ["запикавши"],
    "запикавши": ["запикав"],
    "запикапив": ["запикапивши"],
    "запикапивши": ["запикапив"],
    "запикапить": ["соблазнить"],
    "запикселив": ["запикселивши"],
    "запикселивши": ["запикселив"],
    "запикселить": ["пикселизировать", "замылить", "замазать"],
    "запил": ["надпил"],
    "запилив": ["запиливши"],
    "запиливав": ["запиливавши"],
    "запиливавши": ["запиливав"],
    "запиливши": ["запилив"],
    "запиликав": ["запиликавши"],
    "запиликавши": ["запиликав"],
    "запинав": ["запинавши"],
    "запинавши": ["запинав"],
    "запирав": ["запиравши"],
    "запиравши": ["запирав"],
    "запирательство": ["отнекивание"],
    "запировав": ["запировавши"],
    "запировавши": ["запировав"],
    "записав": ["записавши"],
    "записавши": ["записав"],
    "записная книжка": ["блокнот", "запкнижка"],
    "записной": ["рьяный", "ретивый", "завзятый", "заядлый", "настоящий", "истинный", "истый", "матёрый"],
    "записывав": ["записывавши"],
    "записывавши": ["записывав"],
    "записыванье": ["записывание"],
    "запись": ["записывание", "написание", "писание", "пометка", "документ", "акт"],
    "запитав": ["запитавши"],
    "запитавши": ["запитав"],
    "запитання": ["питання"],
    "запитать": ["зарядить"],
    "запитывав": ["запитывавши"],
    "запитывавши": ["запитывав"],
    "запихав": ["запихавши"],
    "запихавши": ["запихав"],
    "запихать": ["запихнуть"],
    "запихивав": ["запихивавши"],
    "запихивавши": ["запихивав"],
    "запихивать": ["заталкивать", "впихивать"],
    "запихнув": ["запихнувши"],
    "запихнувши": ["запихнув"],
    "запихнуть": ["запихать", "затолкнуть", "впихнуть"],
    "запичкав": ["запичкавши"],
    "запичкавши": ["запичкав"],
    "запищав": ["запищавши"],
    "запищавши": ["запищав"],
    "запкнижка": ["блокнот", "записная книжка"],
    "заплав": ["бон"],
    "заплавав": ["заплававши"],
    "заплававши": ["заплавав"],
    "заплакав": ["заплакавши"],
    "заплакавши": ["заплакав"],
    "запламенев": ["запламеневши"],
    "запламеневши": ["запламенев"],
    "запланировав": ["запланировавши"],
    "запланировавши": ["запланировав"],
    "запланировать": ["наметить", "собраться", "вознамериться", "задумать"],
    "заплата": ["латка", "заплатка", "патч", "обновление"],
    "заплатав": ["заплатавши"],
    "заплатавши": ["заплатав"],
    "заплатив": ["заплативши", "заплатя"],
    "заплативши": ["заплатив"],
    "заплатя": ["заплатив"],
    "заплачивав": ["заплачивавши"],
    "заплачивавши": ["заплачивав"],
    "заплевав": ["заплевавши"],
    "заплевавши": ["заплевав"],
    "заплескав": ["заплескавши"],
    "заплескавши": ["заплескав"],
    "заплеснев": ["заплесневши"],
    "заплесневев": ["заплесневевши"],
    "заплесневевши": ["заплесневев"],
    "заплесневелый": ["заплесневевший", "замшелый", "ретроградский"],
    "заплесневеть": ["заплеснеть"],
    "заплесневши": ["заплеснев"],
    "заплеснув": ["заплеснувши"],
    "заплеснувши": ["заплеснув"],
    "заплетав": ["заплетавши"],
    "заплетавши": ["заплетав"],
    "заплетаться": ["переплетаться", "сплетаться", "спотыкаться"],
    "заплетеност": ["усложненост", "сложност", "комплицираност"],
    "заплетённый": ["сплетённый"],
    "заплечник": ["заспинник"],
    "заплешивев": ["заплешивевши"],
    "заплешивевши": ["заплешивев"],
    "запломбировав": ["запломбировавши"],
    "запломбировавши": ["запломбировав"],
    "запломбировывав": ["запломбировывавши"],
    "запломбировывавши": ["запломбировывав"],
    "заплотив": ["заплотивши"],
    "заплотивши": ["заплотив"],
    "заплошав": ["заплошавши"],
    "заплошавши": ["заплошав"],
    "заплутав": ["заплутавши"],
    "заплутавши": ["заплутав"],
    "заплутать": ["заплутаться", "заблудиться"],
    "заплутаться": ["заплутать", "заблудиться"],
    "заплутовав": ["заплутовавши"],
    "заплутовавши": ["заплутовав"],
    "заплыв": ["плаванье", "заплывание"],
    "заплывав": ["заплывавши"],
    "заплывавши": ["заплывав"],
    "заплывши": ["заплыв"],
    "заплюснув": ["заплюснувши"],
    "заплюснувши": ["заплюснув"],
    "заплюсовав": ["заплюсовавши"],
    "заплюсовавши": ["заплюсовав"],
    "заплюхав": ["заплюхавши"],
    "заплюхавши": ["заплюхав"],
    "заплющив": ["заплющивши"],
    "заплющивши": ["заплющив"],
    "заплясав": ["заплясавши"],
    "заплясавши": ["заплясав"],
    "заплясывав": ["заплясывавши"],
    "заплясывавши": ["заплясывав"],
    "заплёвывав": ["заплёвывавши"],
    "заплёвывавши": ["заплёвывав"],
    "заплёскивав": ["заплёскивавши"],
    "заплёскивавши": ["заплёскивав"],
    "запнув": ["запнувши"],
    "запнувши": ["запнув"],
    "заповедав": ["заповедавши"],
    "заповедавши": ["заповедав"],
    "заповедник": ["резерват"],
    "заповедовав": ["заповедовавши"],
    "заповедовавши": ["заповедовав"],
    "заповедывав": ["заповедывавши"],
    "заповедывавши": ["заповедывав"],
    "запоганив": ["запоганивши"],
    "запоганивав": ["запоганивавши"],
    "запоганивавши": ["запоганивав"],
    "запоганивши": ["запоганив"],
    "заподазривав": ["заподазривавши"],
    "заподазривавши": ["заподазривав"],
    "заподлицо": ["вровень", "в потай"],
    "заподличав": ["заподличавши"],
    "заподличавши": ["заподличав"],
    "заподличаться": ["исподличаться"],
    "заподозревав": ["заподозревавши"],
    "заподозревавши": ["заподозревав"],
    "заподозрив": ["заподозривши"],
    "заподозривав": ["заподозривавши"],
    "заподозривавши": ["заподозривав"],
    "заподозривши": ["заподозрив"],
    "заподрядив": ["заподрядивши"],
    "заподрядивши": ["заподрядив"],
    "заподряжав": ["заподряжавши"],
    "заподряжавши": ["заподряжав"],
    "запоздав": ["запоздавши"],
    "запоздавши": ["запоздав"],
    "запоздалый": ["запоздавший", "задержавшийся"],
    "запозданье": ["запоздание"],
    "запоздать": ["задержаться", "припоздать", "припоздниться", "опоздать"],
    "запознатост": ["осведоменост", "знание"],
    "запоив": ["запоивши"],
    "запоивши": ["запоив"],
    "запоить": ["опоить"],
    "запой": ["дипсомания", "загул"],
    "запойный": ["загульный", "гудёжный", "беспробудный", "безудержный"],
    "заполаскивав": ["заполаскивавши"],
    "заполаскивавши": ["заполаскивав"],
    "заполевав": ["заполевавши"],
    "заполевавши": ["заполевав"],
    "заползав": ["заползавши"],
    "заползавши": ["заползав"],
    "заполировав": ["заполировавши"],
    "заполировавши": ["заполировав"],
    "заполировывав": ["заполировывавши"],
    "заполировывавши": ["заполировывав"],
    "заполитизировав": ["заполитизировавши"],
    "заполитизировавши": ["заполитизировав"],
    "заполненность": ["полнота", "завершённость", "законченность"],
    "заполненье": ["заполнение"],
    "заполнив": ["заполнивши"],
    "заполнивши": ["заполнив"],
    "заполнитель": ["наполнитель"],
    "заполнить": ["наполнить"],
    "заполняв": ["заполнявши"],
    "заполнявши": ["заполняв"],
    "заполонив": ["заполонивши"],
    "заполонивши": ["заполонив"],
    "заполонить": ["пленить", "полонить"],
    "заполоняв": ["заполонявши"],
    "заполонявши": ["заполоняв"],
    "заполоскав": ["заполоскавши"],
    "заполоскавши": ["заполоскав"],
    "заполоснув": ["заполоснувши"],
    "заполоснувши": ["заполоснув"],
    "заполошно": ["испуганно"],
    "заполучав": ["заполучавши"],
    "заполучавши": ["заполучав"],
    "заполучать": ["раздобывать", "приобретать"],
    "заполучив": ["заполучивши"],
    "заполучивши": ["заполучив"],
    "заполыхав": ["заполыхавши"],
    "заполыхавши": ["заполыхав"],
    "запоминав": ["запоминавши"],
    "запоминавши": ["запоминав"],
    "запоминающее устройство": ["память"],
    "запомнив": ["запомнивши"],
    "запомнивши": ["запомнив"],
    "запомнить": ["записать"],
    "запомниться": ["врезаться в память", "отложиться в памяти"],
    "запонка": ["аграфа", "аграф"],
    "запоносив": ["запоносивши"],
    "запоносивши": ["запоносив"],
    "запонь": ["запань"],
    "запопадливий": ["запопадний"],
    "запор": ["затвор", "замок"],
    "запорашивав": ["запорашивавши"],
    "запорашивавши": ["запорашивав"],
    "запоров": ["запоровши"],
    "запоровши": ["запоров"],
    "запорожская область": ["запорожье"],
    "запорожье": ["александровск"],
    "запороть": ["сломать", "загубить"],
    "запорошив": ["запорошивши"],
    "запорошивши": ["запорошив"],
    "запорскав": ["запорскавши"],
    "запорскавши": ["запорскав"],
    "запортив": ["запортивши"],
    "запортивши": ["запортив"],
    "запоручив": ["запоручивши"],
    "запоручивши": ["запоручив"],
    "запорхав": ["запорхавши"],
    "запорхавши": ["запорхав"],
    "запорхнув": ["запорхнувши"],
    "запорхнувши": ["запорхнув"],
    "запоскрипывав": ["запоскрипывавши"],
    "запоскрипывавши": ["запоскрипывав"],
    "запостив": ["запостивши"],
    "запостивши": ["запостив"],
    "запотев": ["запотевши"],
    "запотевав": ["запотевавши"],
    "запотевавши": ["запотевав"],
    "запотевши": ["запотев"],
    "запотеть": ["вспотеть"],
    "запотчевав": ["запотчевавши"],
    "запотчевавши": ["запотчевав"],
    "запохаживав": ["запохаживавши"],
    "запохаживавши": ["запохаживав"],
    "започив": ["започивши"],
    "започивав": ["започивавши"],
    "започивавши": ["започивав"],
    "започивши": ["започив"],
    "запоясав": ["запоясавши"],
    "запоясавши": ["запоясав"],
    "запоясывав": ["запоясывавши"],
    "запоясывавши": ["запоясывав"],
    "заправив": ["заправивши"],
    "заправивши": ["заправив"],
    "заправлявши": ["заправляв"],
    "заправский": ["подлинный", "настоящий"],
    "заправщик": ["авиазаправщик", "авиатопливозаправщик", "автобензозаправщик", "автогазозаправщик", "автозаправщик", "автомаслозаправщик", "автомаслотопливозаправщик", "автотопливозаправщик", "битумозаправщик", "водозаправщик", "водомаслозаправщик", "воздухозаправщик", "газозаправщик", "дозаправщик", "керосинозаправщик"],
    "запраздновав": ["запраздновавши"],
    "запраздновавши": ["запраздновав"],
    "запрашивав": ["запрашивавши"],
    "запрашивавши": ["запрашивав"],
    "запрев": ["запревши"],
    "запревав": ["запревавши"],
    "запревавши": ["запревав"],
    "запревши": ["запрев"],
    "запредельный": ["невероятный", "непостижимый"],
    "запрезирав": ["запрезиравши"],
    "запрезиравши": ["запрезирав"],
    "запрессовав": ["запрессовавши"],
    "запрессовавши": ["запрессовав"],
    "запрессовать": ["спрессовать"],
    "запрессовывав": ["запрессовывавши"],
    "запрессовывавши": ["запрессовывав"],
    "запрет": ["запрещение"],
    "запретив": ["запретивши"],
    "запретивши": ["запретив"],
    "запретить": ["воспретить"],
    "запретка": ["запретная зона"],
    "запретный": ["запрещённый", "недозволенный"],
    "запрещав": ["запрещавши"],
    "запрещавши": ["запрещав"],
    "запрещать": ["воспрещать", "препятствовать"],
    "запрещение": ["запрещенье", "воспрещение", "воспрещенье", "запрет"],
    "запрещенье": ["запрещение"],
    "запрещённое государство": ["исламское государство", "игил", "даиш"],
    "запрещённый": ["воспрещённый"],
    "заприглашав": ["заприглашавши"],
    "заприглашавши": ["заприглашав"],
    "заприметив": ["заприметивши"],
    "заприметивши": ["заприметив"],
    "заприходовав": ["заприходовавши"],
    "заприходовавши": ["заприходовав"],
    "запричитав": ["запричитавши"],
    "запричитавши": ["запричитав"],
    "запроваживав": ["запроваживавши"],
    "запроваживавши": ["запроваживав"],
    "запрограммировав": ["запрограммировавши"],
    "запрограммировавши": ["запрограммировав"],
    "запродав": ["запродавши"],
    "запродавав": ["запродававши"],
    "запродававши": ["запродавав"],
    "запродавши": ["запродав"],
    "запроектировав": ["запроектировавши"],
    "запроектировавши": ["запроектировав"],
    "запрокидывав": ["запрокидывавши"],
    "запрокидывавши": ["запрокидывав"],
    "запрокинув": ["запрокинувши"],
    "запрокинувши": ["запрокинув"],
    "запропадав": ["запропадавши"],
    "запропадавши": ["запропадав"],
    "запропастив": ["запропастивши"],
    "запропастивши": ["запропастив"],
    "запропаститься": ["затеряться", "исчезнуть", "пропасть"],
    "запропасть": ["пропасть", "запропаститься"],
    "запрос": ["просьба", "требование", "стремление", "потребность", "запрашивание"],
    "запросив": ["запросивши"],
    "запросивши": ["запросив"],
    "запросто": ["по-простому", "на  равных", "легко"],
    "запротестовав": ["запротестовавши"],
    "запротестовавши": ["запротестовав"],
    "запротиворечив": ["запротиворечивши"],
    "запротиворечивши": ["запротиворечив"],
    "запротоколив": ["запротоколивши"],
    "запротоколивши": ["запротоколив"],
    "запротоколировав": ["запротоколировавши"],
    "запротоколировавши": ["запротоколировав"],
    "запроцентовав": ["запроцентовавши"],
    "запроцентовавши": ["запроцентовав"],
    "запрошення": ["запрошування"],
    "запрошлый": ["позапрошлый"],
    "запруда": ["плотина"],
    "запрудив": ["запрудивши"],
    "запрудивши": ["запрудив"],
    "запружав": ["запружавши"],
    "запружавши": ["запружав"],
    "запруживав": ["запруживавши"],
    "запруживавши": ["запруживав"],
    "запруживать": ["запружать", "прудить", "заполонять", "наводнять", "наполнять"],
    "запрыгав": ["запрыгавши"],
    "запрыгавши": ["запрыгав"],
    "запрыгивав": ["запрыгивавши"],
    "запрыгивавши": ["запрыгивав"],
    "запрыгнув": ["запрыгнувши"],
    "запрыгнувши": ["запрыгнув"],
    "запрыскав": ["запрыскавши"],
    "запрыскавши": ["запрыскав"],
    "запрыскивав": ["запрыскивавши"],
    "запрыскивавши": ["запрыскивав"],
    "запрыщавев": ["запрыщавевши"],
    "запрыщавевши": ["запрыщавев"],
    "запрягав": ["запрягавши"],
    "запрягавши": ["запрягав"],
    "запрягать": ["напрягать"],
    "запряжка": ["запрягание"],
    "запрятав": ["запрятавши"],
    "запрятавши": ["запрятав"],
    "запрятывав": ["запрятывавши"],
    "запрятывавши": ["запрятывав"],
    "запрятывающий": ["прячущий"],
    "запсиховав": ["запсиховавши"],
    "запсиховавши": ["запсиховав"],
    "запугав": ["запугавши"],
    "запугавши": ["запугав"],
    "запугивав": ["запугивавши"],
    "запугивавши": ["запугивав"],
    "запугивание": ["запугиванье"],
    "запугиванье": ["запугивание"],
    "запугивать": ["устрашать", "наводить страх", "приводить в трепет", "ужаснуть", "терроризировать", "застращивать", "запужать"],
    "запудрив": ["запудривши"],
    "запудривав": ["запудривавши"],
    "запудривавши": ["запудривав"],
    "запудривши": ["запудрив"],
    "запузырив": ["запузыривши"],
    "запузыривав": ["запузыривавши"],
    "запузыривавши": ["запузыривав"],
    "запузыривши": ["запузырив"],
    "запулив": ["запуливши"],
    "запуливав": ["запуливавши"],
    "запуливавши": ["запуливав"],
    "запуливши": ["запулив"],
    "запульсировав": ["запульсировавши"],
    "запульсировавши": ["запульсировав"],
    "запунцовев": ["запунцовевши"],
    "запунцовевши": ["запунцовев"],
    "запуржив": ["запурживши"],
    "запурживши": ["запуржив"],
    "запуск": ["пуск", "запускание", "старт"],
    "запускав": ["запускавши"],
    "запускавши": ["запускав"],
    "запусковый": ["запускной"],
    "запустев": ["запустевши"],
    "запустевши": ["запустев"],
    "запустив": ["запустивши"],
    "запустивши": ["запустив"],
    "запустить": ["швырнуть", "зашвырнуть", "запульнуть"],
    "запустовав": ["запустовавши"],
    "запустовавши": ["запустовав"],
    "запустошив": ["запустошивши"],
    "запустошивши": ["запустошив"],
    "запутав": ["запутавши"],
    "запутавши": ["запутав"],
    "запутаться": ["спутаться", "зацепиться", "попасться", "заблудиться", "потеряться", "сбиться", "загулять", "пропасть"],
    "запутешествовав": ["запутешествовавши"],
    "запутешествовавши": ["запутешествовав"],
    "запутинский": ["пропутинский"],
    "запутка": ["непонятка"],
    "запутывав": ["запутывавши"],
    "запутывавши": ["запутывав"],
    "запухав": ["запухавши"],
    "запухавши": ["запухав"],
    "запухнув": ["запухнувши"],
    "запухнувши": ["запухнув"],
    "запушив": ["запушивши"],
    "запушивши": ["запушив"],
    "запущав": ["запущавши"],
    "запущавши": ["запущав"],
    "запущение": ["заброшенность", "запустение"],
    "запущенный": ["пущенный"],
    "запхав": ["запхавши"],
    "запхавши": ["запхав"],
    "запчасть": ["запасная часть"],
    "запыжив": ["запыживши"],
    "запыживав": ["запыживавши"],
    "запыживавши": ["запыживав"],
    "запыживши": ["запыжив"],
    "запылав": ["запылавши"],
    "запылавши": ["запылав"],
    "запылив": ["запыливши"],
    "запыливши": ["запылив"],
    "запыляв": ["запылявши"],
    "запылявши": ["запыляв"],
    "запыряв": ["запырявши"],
    "запырявши": ["запыряв"],
    "запытав": ["запытавши"],
    "запытавши": ["запытав"],
    "запытанный": ["замученный", "заморённый", "умерщвлённый", "уморённый"],
    "запытать": ["замучить", "замучать", "затерзать", "заморить", "извести", "умертвить", "уморить", "вопросить", "осведомиться", "прикопаться"],
    "запытывать": ["пытать", "истязать", "морить", "вопрошать", "доставать вопросами", "докапываться", "прикапываться"],
    "запыхтев": ["запыхтевши"],
    "запыхтевши": ["запыхтев"],
    "запьянев": ["запьяневши"],
    "запьяневши": ["запьянев"],
    "запьянствовав": ["запьянствовавши"],
    "запьянствовавши": ["запьянствовав"],
    "запястье": ["запястие", "браслет"],
    "запятая": ["препятствие", "помеха", "затруднение", "зю"],
    "запятив": ["запятивши"],
    "запятивши": ["запятив"],
    "запятнав": ["запятнавши"],
    "запятнавши": ["запятнав"],
    "запятнание": ["замарывание", "загрязнение", "пятнание"],
    "запятнанность": ["замаранность"],
    "запячивав": ["запячивавши"],
    "запячивавши": ["запячивав"],
    "зарабатывав": ["зарабатывавши"],
    "зарабатывавши": ["зарабатывав"],
    "заработав": ["заработавши"],
    "заработавши": ["заработав"],
    "заработать": ["зашибить", "приобрести", "схлопотать"],
    "заработка": ["заработок"],
    "заработная плата": ["зарплата", "жалованье"],
    "заработный": ["заработанный"],
    "заработок": ["зарплата", "заработная плата"],
    "заравнивав": ["заравнивавши"],
    "заравнивавши": ["заравнивав"],
    "заражав": ["заражавши"],
    "заражавши": ["заражав"],
    "заражать": ["инфицировать"],
    "заражаться": ["инфицироваться"],
    "заражение": ["инфицирование", "заражённость"],
    "зараженье": ["заражение"],
    "заражённый": ["заболевший", "зазомбированный", "убеждённый"],
    "зараз": ["сразу", "в момент"],
    "зараза": ["инфекция"],
    "заразив": ["заразивши"],
    "заразивши": ["заразив"],
    "заразительность": ["контагиозный"],
    "заразительный": ["заразный"],
    "заразить": ["инфицировать"],
    "заразность": ["контагиозность", "заразительность"],
    "заразный": ["инфекционный"],
    "заран": ["утрин", "утро", "сутрин"],
    "заране": ["заранее", "заблаговременно", "загодя", "наперёд"],
    "заранее": ["заблаговременно", "загодя", "наперёд", "авансом"],
    "зарастав": ["зараставши"],
    "зараставши": ["зарастав"],
    "зарастив": ["зарастивши"],
    "зарастивши": ["зарастив"],
    "заращение": ["заращивание", "атрезия", "облитерация"],
    "заращивав": ["заращивавши"],
    "заращивавши": ["заращивав"],
    "заращивание": ["засаживание", "заращение", "облитерация"],
    "заращивать": ["засаживать"],
    "зарван": ["зерван"],
    "зардев": ["зардевши"],
    "зардевав": ["зардевавши"],
    "зардевавши": ["зардевав"],
    "зардевши": ["зардев"],
    "зардек": ["сабиз"],
    "зардеться": ["заалеть"],
    "зарев": ["жнивень", "серпень"],
    "заревав": ["заревавши"],
    "заревавши": ["заревав"],
    "заревев": ["заревевши"],
    "заревевши": ["заревев"],
    "заревновав": ["заревновавши"],
    "заревновавши": ["заревновав"],
    "зарегаться": ["зарегиться"],
    "зарегистрировав": ["зарегистрировавши"],
    "зарегистрировавши": ["зарегистрировав"],
    "зарегистрировать": ["зарегить"],
    "зарегистрироваться": ["вступить в брак"],
    "зарегистровав": ["зарегистровавши"],
    "зарегистровавши": ["зарегистровав"],
    "зарегламентировав": ["зарегламентировавши"],
    "зарегламентировавши": ["зарегламентировав"],
    "зареготав": ["зареготавши"],
    "зареготавши": ["зареготав"],
    "зареготать": ["захохотать"],
    "зарегулировав": ["зарегулировавши"],
    "зарегулировавши": ["зарегулировав"],
    "заредактировав": ["заредактировавши"],
    "заредактировавши": ["заредактировав"],
    "заредев": ["заредевши"],
    "заредевши": ["заредев"],
    "зарез": ["беда"],
    "зарезав": ["зарезавши"],
    "зарезавши": ["зарезав"],
    "зарезервировав": ["зарезервировавши"],
    "зарезервировавши": ["зарезервировав"],
    "зарезывав": ["зарезывавши"],
    "зарезывавши": ["зарезывав"],
    "зарезь": ["зазубрины"],
    "зарекав": ["зарекавши"],
    "зарекавши": ["зарекав"],
    "зарекать": ["налагать зарок", "заказывать", "запрещать"],
    "зарекаться": ["клясться"],
    "зарекомендовав": ["зарекомендовавши"],
    "зарекомендовавши": ["зарекомендовав"],
    "зарекомендовывав": ["зарекомендовывавши"],
    "зарекомендовывавши": ["зарекомендовывав"],
    "заремонтировав": ["заремонтировавши"],
    "заремонтировавши": ["заремонтировав"],
    "зарепетировав": ["зарепетировавши"],
    "зарепетировавши": ["зарепетировав"],
    "заретушировав": ["заретушировавши"],
    "заретушировавши": ["заретушировав"],
    "зарецкий": ["заречный"],
    "заречь": ["наложить зарок", "заказать", "запретить"],
    "заречься": ["закаяться", "заклясться", "пообещать"],
    "зарешетив": ["зарешетивши"],
    "зарешетивши": ["зарешетив"],
    "зарешечивав": ["зарешечивавши"],
    "зарешечивавши": ["зарешечивав"],
    "зареяв": ["зареявши"],
    "зареявши": ["зареяв"],
    "заржав": ["заржавши"],
    "заржавев": ["заржавевши"],
    "заржавевши": ["заржавев"],
    "заржаветь": ["угаснуть"],
    "заржавив": ["заржавивши"],
    "заржавивши": ["заржавив"],
    "заржавши": ["заржав"],
    "зарзават": ["зеленчук"],
    "зарив": ["заривши"],
    "заривши": ["зарив"],
    "зарик": ["игральная кость", "кубик"],
    "зарисовав": ["зарисовавши"],
    "зарисовавши": ["зарисовав"],
    "зарисовать": ["нарисовать", "изрисовать"],
    "зарисовка": ["рисунок", "набросок", "эскиз"],
    "зарисовывав": ["зарисовывавши"],
    "зарисовывавши": ["зарисовывав"],
    "зарить": ["зырить"],
    "зарифив": ["зарифивши"],
    "зарифивши": ["зарифив"],
    "зарифляв": ["зарифлявши"],
    "зарифлявши": ["зарифляв"],
    "зарифлять": ["рифить"],
    "зарифмовав": ["зарифмовавши"],
    "зарифмовавши": ["зарифмовав"],
    "зарифмовать": ["срифмовать"],
    "зарифмовывав": ["зарифмовывавши"],
    "зарифмовывавши": ["зарифмовывав"],
    "зарифмовывать": ["рифмовать"],
    "зарифовывать": ["рифить"],
    "зарница": ["молния", "сполох"],
    "заробев": ["заробевши"],
    "заробевши": ["заробев"],
    "заробеть": ["оробеть", "испугаться"],
    "заробив": ["заробивши"],
    "заробивши": ["заробив"],
    "заробитчанин": ["гастарбайтер"],
    "заровняв": ["заровнявши"],
    "заровнявши": ["заровняв"],
    "заровнять": ["сровнять", "выровнять"],
    "зарод": ["скирд", "скирда", "стог", "кладь"],
    "зародив": ["зародивши"],
    "зародивши": ["зародив"],
    "зародить": ["родить", "породить", "спровоцировать", "вызвать", "возбудить", "пробудить"],
    "зародыш": ["эмбрион", "проросток"],
    "зародышевый": ["герминативный"],
    "зарождав": ["зарождавши"],
    "зарождавши": ["зарождав"],
    "зарозовев": ["зарозовевши"],
    "зарозовевши": ["зарозовев"],
    "зароив": ["зароивши"],
    "зароивши": ["зароив"],
    "зарокотав": ["зарокотавши"],
    "зарокотавши": ["зарокотав"],
    "заронив": ["заронивши"],
    "заронивши": ["заронив"],
    "зароняв": ["заронявши"],
    "заронявши": ["зароняв"],
    "зароптав": ["зароптавши"],
    "зароптавши": ["зароптав"],
    "зароптать": ["занегодовать"],
    "заросль": ["чаща", "чащоба", "пуща", "чапыжник", "чепыжник", "бурьян"],
    "зарошувати": ["зрошувати", "росити", "оброшувати"],
    "зарплата": ["получка", "оклад"],
    "заррабин": ["резбин"],
    "заруба": ["заруб", "зарубка", "зарубина", "зарубень", "вырезка", "нарез", "затесь"],
    "зарубав": ["зарубавши"],
    "зарубавши": ["зарубав"],
    "зарубеж": ["заграница", "зарубежье"],
    "зарубежный": ["иностранный", "заграничный"],
    "зарубежье": ["заграница", "эмиграция"],
    "зарубив": ["зарубивши"],
    "зарубивши": ["зарубив"],
    "зарубина": ["зарубка"],
    "зарубить": ["зарезать", "засечь", "отклонить", "уяснить", "запомнить"],
    "зарубить на носу": ["усвоить"],
    "зарубить себе на носу": ["намотать на ус"],
    "зарубцовывав": ["зарубцовывавши"],
    "зарубцовывавши": ["зарубцовывав"],
    "заругав": ["заругавши"],
    "заругавши": ["заругав"],
    "зарукоплескав": ["зарукоплескавши"],
    "зарукоплескавши": ["зарукоплескав"],
    "зарукоприкладствовав": ["зарукоприкладствовавши"],
    "зарукоприкладствовавши": ["зарукоприкладствовав"],
    "зарулив": ["заруливши"],
    "заруливав": ["заруливавши"],
    "заруливавши": ["заруливав"],
    "заруливши": ["зарулив"],
    "зарумянив": ["зарумянивши"],
    "зарумянивав": ["зарумянивавши"],
    "зарумянивавши": ["зарумянивав"],
    "зарумянивши": ["зарумянив"],
    "зарчава": ["куркума"],
    "зарыбив": ["зарыбивши"],
    "зарыбивши": ["зарыбив"],
    "зарыбляв": ["зарыблявши"],
    "зарыблявши": ["зарыбляв"],
    "зарыв": ["зарывши"],
    "зарывав": ["зарывавши"],
    "зарывавши": ["зарывав"],
    "зарывши": ["зарыв"],
    "зарыдав": ["зарыдавши"],
    "зарыдавши": ["зарыдав"],
    "зарыжев": ["зарыжевши"],
    "зарыжевши": ["зарыжев"],
    "зарыжеть": ["зажелтеть"],
    "зарыкав": ["зарыкавши"],
    "зарыкавши": ["зарыкав"],
    "зарысив": ["зарысивши"],
    "зарысивши": ["зарысив"],
    "зарыскав": ["зарыскавши"],
    "зарыскавши": ["зарыскав"],
    "зарытый": ["закопанный"],
    "зарычав": ["зарычавши"],
    "зарычавши": ["зарычав"],
    "зарьяв": ["зарьявши"],
    "зарьявши": ["зарьяв"],
    "зарюмив": ["зарюмивши"],
    "зарюмивши": ["зарюмив"],
    "заря": ["зоря", "любисток"],
    "зарябев": ["зарябевши"],
    "зарябевши": ["зарябев"],
    "зарябив": ["зарябивши"],
    "зарябивши": ["зарябив"],
    "зарявкав": ["зарявкавши"],
    "зарявкавши": ["зарявкав"],
    "заряд": ["взрывчатка", "снаряд", "патрон", "выстрел", "количество электричества", "уровень заряда", "число", "запас", "резерв", "порция", "зарядка"],
    "зарядив": ["зарядивши"],
    "зарядивши": ["зарядив"],
    "зарядить": ["вложить", "запитать"],
    "зарядка": ["подзарядка", "перезарядка", "гимнастика", "физзарядка", "зарядник", "зарядное устройство", "заряд", "уровень заряда"],
    "зарядное устройство": ["зарядка", "зарядник"],
    "зарядный": ["заряжающий"],
    "заряжав": ["заряжавши"],
    "заряжавши": ["заряжав"],
    "заряженный": ["заряжённый"],
    "зарянка": ["малиновка", "ольшанка"],
    "засада": ["подвох", "попадос", "попадалово", "загвоздка"],
    "засадив": ["засадивши"],
    "засадивши": ["засадив"],
    "засадить": ["трахнуть", "совокупиться"],
    "засадить сатану": ["задвинуть сатану", "антихриста втереть"],
    "засадка": ["засев", "посадка", "засада", "западня"],
    "засаднив": ["засаднивши"],
    "засаднивши": ["засаднив"],
    "засажав": ["засажавши"],
    "засажавши": ["засажав"],
    "засаживав": ["засаживавши"],
    "засаживавши": ["засаживав"],
    "засалив": ["засаливши"],
    "засаливав": ["засаливавши"],
    "засаливавши": ["засаливав"],
    "засаливать": ["солить"],
    "засаливши": ["засалив"],
    "засамовольничав": ["засамовольничавши"],
    "засамовольничавши": ["засамовольничав"],
    "засандалив": ["засандаливши"],
    "засандаливши": ["засандалив"],
    "засаривав": ["засаривавши"],
    "засаривавши": ["засаривав"],
    "засасывав": ["засасывавши"],
    "засасывавши": ["засасывав"],
    "засахарив": ["засахаривши"],
    "засахаривав": ["засахаривавши"],
    "засахаривавши": ["засахаривав"],
    "засахаривши": ["засахарив"],
    "засачковав": ["засачковавши"],
    "засачковавши": ["засачковав"],
    "засбоив": ["засбоивши"],
    "засбоивши": ["засбоив"],
    "засватав": ["засватавши"],
    "засватавши": ["засватав"],
    "засватывав": ["засватывавши"],
    "засватывавши": ["засватывав"],
    "засвежев": ["засвежевши"],
    "засвежевав": ["засвежевавши"],
    "засвежевавши": ["засвежевав"],
    "засвежевши": ["засвежев"],
    "засвежевший": ["похолодевший"],
    "засвербев": ["засвербевши"],
    "засвербевши": ["засвербев"],
    "засверкав": ["засверкавши"],
    "засверкавши": ["засверкав"],
    "засверкать": ["заблестеть", "заблистать", "засиять"],
    "засверлив": ["засверливши"],
    "засверливав": ["засверливавши"],
    "засверливавши": ["засверливав"],
    "засверливши": ["засверлив"],
    "засвет": ["засветка"],
    "засветив": ["засветивши"],
    "засветивши": ["засветив"],
    "засветить": ["засиять"],
    "засветиться": ["загореться", "зажечься"],
    "засветка": ["засвечивание"],
    "засветлев": ["засветлевши"],
    "засветлевши": ["засветлев"],
    "засвечивав": ["засвечивавши"],
    "засвечивавши": ["засвечивав"],
    "засвечивание": ["засвечиванье", "засветка"],
    "засвечиванье": ["засвечивание", "засветка"],
    "засвидетельствовав": ["засвидетельствовавши"],
    "засвидетельствовавши": ["засвидетельствовав"],
    "засвиристев": ["засвиристевши"],
    "засвиристевши": ["засвиристев"],
    "засвистав": ["засвиставши"],
    "засвиставши": ["засвистав"],
    "засвистев": ["засвистевши"],
    "засвистевши": ["засвистев"],
    "засвистеть": ["засвистать"],
    "засвистывав": ["засвистывавши"],
    "засвистывавши": ["засвистывав"],
    "засевав": ["засевавши"],
    "засевавши": ["засевав"],
    "заседав": ["заседавши"],
    "заседавши": ["заседав"],
    "заседалово": ["заседание"],
    "заседание": ["собрание"],
    "заседанье": ["заседание"],
    "заседательствовав": ["заседательствовавши"],
    "заседательствовавши": ["заседательствовав"],
    "заседлав": ["заседлавши"],
    "заседлавши": ["заседлав"],
    "заседлать": ["оседлать", "подседлать"],
    "засеивав": ["засеивавши"],
    "засеивавши": ["засеивав"],
    "засеивать": ["засевать"],
    "засекав": ["засекавши"],
    "засекавши": ["засекав"],
    "засекретив": ["засекретивши"],
    "засекретивши": ["засекретив"],
    "засекретничав": ["засекретничавши"],
    "засекретничавши": ["засекретничав"],
    "засекреченность": ["тайность", "конфиденциальность", "секретность", "доверительность", "негласность"],
    "засекреченный": ["секретный"],
    "засекречивав": ["засекречивавши"],
    "засекречивавши": ["засекречивав"],
    "заселив": ["заселивши"],
    "заселивши": ["заселив"],
    "заселяв": ["заселявши"],
    "заселявши": ["заселяв"],
    "заселять": ["населять", "колонизировать", "проживать", "селить", "вселять", "поселять"],
    "засемафорив": ["засемафоривши"],
    "засемафоривши": ["засемафорив"],
    "засеменив": ["засеменивши"],
    "засеменивши": ["засеменив"],
    "засемплировав": ["засемплировавши"],
    "засемплировавши": ["засемплировав"],
    "засентябрив": ["засентябривши"],
    "засентябривши": ["засентябрив"],
    "засеребрив": ["засеребривши"],
    "засеребривши": ["засеребрив"],
    "засерев": ["засеревши"],
    "засеревши": ["засерев"],
    "засерьёзнив": ["засерьёзнивши"],
    "засерьёзнивши": ["засерьёзнив"],
    "засесть": ["усесться", "приступить", "взять", "сесть", "попасть", "застрять"],
    "засечка": ["зарубка", "отметка", "сериф"],
    "засеяв": ["засеявши"],
    "засеявши": ["засеяв"],
    "засигналив": ["засигналивши"],
    "засигналивши": ["засигналив"],
    "засидев": ["засидевши"],
    "засидевши": ["засидев"],
    "засиживав": ["засиживавши"],
    "засиживавши": ["засиживав"],
    "засилив": ["засиливши"],
    "засиливши": ["засилив"],
    "засилие": ["засилье"],
    "засилосовав": ["засилосовавши"],
    "засилосовавши": ["засилосовав"],
    "засилье": ["засилие", "гнёт", "господство", "множество", "обилие"],
    "засим": ["затем", "далее", "дальше"],
    "засинев": ["засиневши"],
    "засиневши": ["засинев"],
    "засинив": ["засинивши"],
    "засинивав": ["засинивавши"],
    "засинивавши": ["засинивав"],
    "засинивать": ["синить", "пересинивать"],
    "засинивши": ["засинив"],
    "засиняв": ["засинявши"],
    "засинявши": ["засиняв"],
    "засипев": ["засипевши"],
    "засипевши": ["засипев"],
    "засирав": ["засиравши"],
    "засиравши": ["засирав"],
    "засирать": ["засорять", "загаживать", "ругать", "охаивать", "поносить", "портить", "коверкать", "похабить"],
    "засирать мозг": ["пускать пыль в глаза", "вешать лапшу на уши", "грузить", "лечить", "наводить тень на плетень", "запутывать"],
    "засияв": ["засиявши"],
    "засиявши": ["засияв"],
    "засиять": ["воссиять"],
    "заскабливав": ["заскабливавши"],
    "заскабливавши": ["заскабливав"],
    "заскакав": ["заскакавши"],
    "заскакавши": ["заскакав"],
    "заскакивав": ["заскакивавши"],
    "заскакивавши": ["заскакивав"],
    "заскамить": ["разыграть"],
    "заскандалив": ["заскандаливши"],
    "заскандаливши": ["заскандалив"],
    "засквозив": ["засквозивши"],
    "засквозивши": ["засквозив"],
    "заскипидарив": ["заскипидаривши"],
    "заскипидаривши": ["заскипидарив"],
    "заскирдовав": ["заскирдовавши"],
    "заскирдовавши": ["заскирдовав"],
    "заскирдовывав": ["заскирдовывавши"],
    "заскирдовывавши": ["заскирдовывав"],
    "заскладировав": ["заскладировавши"],
    "заскладировавши": ["заскладировав"],
    "заскобив": ["заскобивши"],
    "заскобивши": ["заскобив"],
    "заскобленный": ["заскоблённый"],
    "заскоблив": ["заскобливши"],
    "заскобливши": ["заскоблив"],
    "заскоблённый": ["заскобленный"],
    "заскок": ["заскакивание"],
    "заскользив": ["заскользивши"],
    "заскользивши": ["заскользив"],
    "заскорбнув": ["заскорбнувши"],
    "заскорбнувши": ["заскорбнув"],
    "заскородив": ["заскородивши"],
    "заскородивши": ["заскородив"],
    "заскорузлый": ["загрубелый", "задубелый", "чёрствый"],
    "заскорузнув": ["заскорузнувши"],
    "заскорузнувши": ["заскорузнув"],
    "заскочив": ["заскочивши"],
    "заскочивши": ["заскочив"],
    "заскочить": ["запрыгнуть", "ворваться", "запасть", "застрять", "забежать"],
    "заскрежетав": ["заскрежетавши"],
    "заскрежетавши": ["заскрежетав"],
    "заскринив": ["заскринивши"],
    "заскринивши": ["заскринив"],
    "заскринить": ["отскринить", "заскриншотить", "отскриншотить"],
    "заскриншотив": ["заскриншотивши"],
    "заскриншотивши": ["заскриншотив"],
    "заскриншотить": ["отскриншотить", "заскринить", "отскринить"],
    "заскрипев": ["заскрипевши"],
    "заскрипевши": ["заскрипев"],
    "заскромничав": ["заскромничавши"],
    "заскромничавши": ["заскромничав"],
    "заскулив": ["заскуливши"],
    "заскуливши": ["заскулив"],
    "заскучав": ["заскучавши"],
    "заскучавши": ["заскучав"],
    "заслабив": ["заслабивши"],
    "заслабивши": ["заслабив"],
    "заслабнув": ["заслабнувши"],
    "заслабнувши": ["заслабнув"],
    "заслав": ["заславши"],
    "заславши": ["заслав"],
    "засланный": ["направленный", "посланный", "высланный", "отосланный", "сосланный", "насланный"],
    "засланный казачок": ["засланец", "информатор", "лазутчик", "пятая колонна", "свой среди чужих", "свой человек", "стукач", "стукачок", "тайный агент", "шпик", "шпион", "крыса"],
    "засластив": ["засластивши"],
    "засластивши": ["засластив"],
    "засластка": ["десерт"],
    "заслащивав": ["заслащивавши"],
    "заслащивавши": ["заслащивав"],
    "заследив": ["заследивши"],
    "заследивши": ["заследив"],
    "заслеживав": ["заслеживавши"],
    "заслеживавши": ["заслеживав"],
    "заслепив": ["заслепивши"],
    "заслепивши": ["заслепив"],
    "заслепляв": ["заслеплявши"],
    "заслеплявши": ["заслепляв"],
    "заслон": ["барьер", "преграда"],
    "заслонив": ["заслонивши"],
    "заслонивши": ["заслонив"],
    "заслоняв": ["заслонявши"],
    "заслонявши": ["заслоняв"],
    "заслонять": ["закрывать", "загораживать"],
    "заслоуплеив": ["заслоуплеивши"],
    "заслоуплеивши": ["заслоуплеив"],
    "заслуженно": ["достойно", "за дело", "по делу", "по заслугам", "по праву", "поделом", "соизмеримо", "сопоставимо", "справедливо"],
    "заслуженный": ["законный"],
    "заслужив": ["заслуживши"],
    "заслуживав": ["заслуживавши"],
    "заслуживавши": ["заслуживав"],
    "заслуживающий": ["достойный"],
    "заслуживши": ["заслужив"],
    "заслужить": ["снискать", "удостоиться", "заработать"],
    "заслушав": ["заслушавши"],
    "заслушавши": ["заслушав"],
    "заслушать": ["выслушать", "наслушаться"],
    "заслушивав": ["заслушивавши"],
    "заслушивавши": ["заслушивав"],
    "заслышав": ["заслышавши"],
    "заслышавши": ["заслышав"],
    "заслюнив": ["заслюнивши"],
    "заслюнивав": ["заслюнивавши"],
    "заслюнивавши": ["заслюнивав"],
    "заслюнивши": ["заслюнив"],
    "заслюнявив": ["заслюнявивши"],
    "заслюнявивши": ["заслюнявив"],
    "засмага": ["загар", "пригар"],
    "засмаливав": ["засмаливавши"],
    "засмаливавши": ["засмаливав"],
    "засмаркивав": ["засмаркивавши"],
    "засмаркивавши": ["засмаркивав"],
    "засматривав": ["засматривавши"],
    "засматривавши": ["засматривав"],
    "засматривать": ["заглядывать", "смотреть", "запускать глаза"],
    "засматриваться": ["заглядываться", "любоваться"],
    "засмеивав": ["засмеивавши"],
    "засмеивавши": ["засмеивав"],
    "засмердев": ["засмердевши"],
    "засмердевши": ["засмердев"],
    "засмеяв": ["засмеявши"],
    "засмеявши": ["засмеяв"],
    "засмеяться": ["рассмеяться", "зареготать"],
    "засмолив": ["засмоливши"],
    "засмоливши": ["засмолив"],
    "засморкав": ["засморкавши"],
    "засморкавши": ["засморкав"],
    "засмотрев": ["засмотревши"],
    "засмотревши": ["засмотрев"],
    "засмотреться": ["заглядеться"],
    "засмуглив": ["засмугливши"],
    "засмугливши": ["засмуглив"],
    "заснежив": ["заснеживши"],
    "заснеживши": ["заснежив"],
    "заснимав": ["заснимавши"],
    "заснимавши": ["заснимав"],
    "засновав": ["засновавши"],
    "засновавши": ["засновав"],
    "заснув": ["заснувши"],
    "заснувши": ["заснув"],
    "заснуть": ["уснуть"],
    "заснуться": ["уснуться", "задрыхнуться", "закемариться"],
    "засняв": ["заснявши"],
    "заснявши": ["засняв"],
    "заснять": ["снять"],
    "засобачив": ["засобачивши"],
    "засобачивши": ["засобачив"],
    "засобачить": ["зафигачить", "захерачить"],
    "засов": ["задвижка"],
    "засовав": ["засовавши"],
    "засовавши": ["засовав"],
    "засовать": ["засунуть", "сунуть", "впихнуть", "запихнуть", "запихать", "затолкнуть", "затолкать", "затиснуть", "всунуть", "втиснуть"],
    "засовеститься": ["устыдиться"],
    "засовывав": ["засовывавши"],
    "засовывавши": ["засовывав"],
    "засовывать": ["совать", "всовывать"],
    "засолив": ["засоливши"],
    "засоливши": ["засолив"],
    "засолить": ["посолить"],
    "засолонев": ["засолоневши"],
    "засолоневши": ["засолонев"],
    "засоляв": ["засолявши"],
    "засолявши": ["засоляв"],
    "засомневаться": ["посумниться"],
    "засоня": ["соня"],
    "засопев": ["засопевши"],
    "засопевши": ["засопев"],
    "засопливев": ["засопливевши"],
    "засопливевши": ["засопливев"],
    "засор": ["засорение"],
    "засорение": ["загрязнение", "засор"],
    "засорив": ["засоривши"],
    "засоривши": ["засорив"],
    "засорить": ["загрязнить", "замусорить"],
    "засоряв": ["засорявши"],
    "засорявши": ["засоряв"],
    "засоряться": ["замусориваться"],
    "засос": ["засасывание"],
    "засосав": ["засосавши"],
    "засосавши": ["засосав"],
    "засохнув": ["засохнувши"],
    "засохнувши": ["засохнув"],
    "заспав": ["заспавши"],
    "заспавши": ["заспав"],
    "заспесивиться": ["зазнаться", "зачваниться", "заважничать"],
    "заспециализировав": ["заспециализировавши"],
    "заспециализировавши": ["заспециализировав"],
    "заспешив": ["заспешивши"],
    "заспешивши": ["заспешив"],
    "заспинник": ["заплечник"],
    "заспиртовав": ["заспиртовавши"],
    "заспиртовавши": ["заспиртовав"],
    "заспиртовывав": ["заспиртовывавши"],
    "заспиртовывавши": ["заспиртовывав"],
    "засплетничав": ["засплетничавши"],
    "засплетничавши": ["засплетничав"],
    "заспойлерив": ["заспойлеривши"],
    "заспойлеривши": ["заспойлерив"],
    "заспорив": ["заспоривши"],
    "заспоривши": ["заспорив"],
    "засрав": ["засравши"],
    "засравши": ["засрав"],
    "засрамив": ["засрамивши"],
    "засрамивши": ["засрамив"],
    "засранец": ["серун", "говнюк", "паршивец", "поганец", "пакостник", "неряха", "грязнуля"],
    "засрать": ["испортить", "испачкать", "загадить", "загрязнить", "засорить", "замусорить", "исковеркать", "испохабить"],
    "засраться": ["подзасраться"],
    "зассав": ["зассавши"],
    "зассавши": ["зассав"],
    "зассать": ["залить", "замочить", "облить", "испугаться", "забояться", "напустить в штаны", "надуть в штаны", "приссать", "обоссаться", "заочковать", "очко взыграло", "присесть на очко", "накласть в штаны", "наложить в штаны", "бздануть"],
    "застабилизировав": ["застабилизировавши"],
    "застабилизировавши": ["застабилизировав"],
    "застабилизировать": ["стабилизировать"],
    "застав": ["заставши"],
    "заставав": ["застававши"],
    "застававши": ["заставав"],
    "заставать": ["застигать", "обнаруживать"],
    "заставив": ["заставивши"],
    "заставивши": ["заставив"],
    "заставить": ["вынудить", "понудить", "принудить"],
    "заставляв": ["заставлявши"],
    "заставлявши": ["заставляв"],
    "заставши": ["застав"],
    "застаивав": ["застаивавши"],
    "застаивавши": ["застаивав"],
    "застандартизировав": ["застандартизировавши"],
    "застандартизировавши": ["застандартизировав"],
    "застановив": ["застановивши"],
    "застановивши": ["застановив"],
    "застарев": ["застаревши"],
    "застаревав": ["застаревавши"],
    "застаревавши": ["застаревав"],
    "застаревши": ["застарев"],
    "застарелый": ["давний"],
    "застать": ["застигнуть", "застичь", "обнаружить", "захватить", "загнать"],
    "застегав": ["застегавши"],
    "застегавши": ["застегав"],
    "застегнув": ["застегнувши"],
    "застегнувши": ["застегнув"],
    "застекленев": ["застекленевши"],
    "застекленевши": ["застекленев"],
    "застеклив": ["застекливши"],
    "застекливши": ["застеклив"],
    "застекляв": ["застеклявши"],
    "застеклявши": ["застекляв"],
    "застелив": ["застеливши"],
    "застеливши": ["застелив"],
    "застенографировав": ["застенографировавши"],
    "застенографировавши": ["застенографировав"],
    "застенчивость": ["робость", "стыдливость"],
    "застенчивый": ["робкий", "несмелый"],
    "застив": ["застивши"],
    "застивши": ["застив"],
    "застивший": ["заслонявший", "застилавший"],
    "застигав": ["застигавши"],
    "застигавши": ["застигав"],
    "застигнув": ["застигнувши"],
    "застигнувши": ["застигнув"],
    "застил": ["застилание", "застилка"],
    "застилав": ["застилавши"],
    "застилавши": ["застилав"],
    "застирав": ["застиравши"],
    "застиравши": ["застирав"],
    "застирывав": ["застирывавши"],
    "застирывавши": ["застирывав"],
    "застить": ["закрывать"],
    "застлав": ["застлавши"],
    "застлавши": ["застлав"],
    "застлать": ["застелить", "покрыть", "заволочь"],
    "застоговав": ["застоговавши"],
    "застоговавши": ["застоговав"],
    "застой": ["неподвижность", "стагнация"],
    "застолбив": ["застолбивши"],
    "застолбивши": ["застолбив"],
    "застолица": ["застолье", "угощенье"],
    "застонав": ["застонавши"],
    "застонавши": ["застонав"],
    "застонать": ["заныть", "заскулить", "возроптать"],
    "застопорив": ["застопоривши"],
    "застопоривав": ["застопоривавши"],
    "застопоривавши": ["застопоривав"],
    "застопоривши": ["застопорив"],
    "застопорить": ["остановить", "затормозить"],
    "застояв": ["застоявши"],
    "застоявши": ["застояв"],
    "застоялост": ["застой", "спиране", "прекъсване", "задръжка", "спирачка", "бездействие"],
    "застрагивав": ["застрагивавши"],
    "застрагивавши": ["застрагивав"],
    "застраивав": ["застраивавши"],
    "застраивавши": ["застраивав"],
    "застранствовав": ["застранствовавши"],
    "застранствовавши": ["застранствовав"],
    "застраховав": ["застраховавши"],
    "застраховавши": ["застраховав"],
    "застраховка": ["осигуровка"],
    "застраховывав": ["застраховывавши"],
    "застраховывавши": ["застраховывав"],
    "застраховывающий": ["страхующий"],
    "застрачивав": ["застрачивавши"],
    "застрачивавши": ["застрачивав"],
    "застращав": ["застращавши"],
    "застращавши": ["застращав"],
    "застращивав": ["застращивавши"],
    "застращивавши": ["застращивав"],
    "застращиванье": ["застращивание"],
    "застревав": ["застревавши"],
    "застревавши": ["застревав"],
    "застревание": ["застреванье"],
    "застрекотав": ["застрекотавши"],
    "застрекотавши": ["застрекотав"],
    "застреленный": ["пристреленный", "подстреленный"],
    "застреливав": ["застреливавши"],
    "застреливавши": ["застреливав"],
    "застреливать": ["пристреливать"],
    "застреливаться": ["стреляться"],
    "застрелить": ["пристрелить", "подстрелить"],
    "застрелиться": ["пустить себе пулю в лоб"],
    "застрельщик": ["инициатор", "зачинщик", "зачинатель"],
    "застреляв": ["застрелявши"],
    "застрелявши": ["застреляв"],
    "застремав": ["застремавши"],
    "застремавши": ["застремав"],
    "застрематься": ["испугаться"],
    "застригав": ["застригавши"],
    "застригавши": ["застригав"],
    "застрогав": ["застрогавши"],
    "застрогавши": ["застрогав"],
    "застроив": ["застроивши"],
    "застроивши": ["застроив"],
    "застройка": ["застраивание"],
    "застрочив": ["застрочивши"],
    "застрочивши": ["застрочив"],
    "заструга": ["заструг"],
    "застругав": ["застругавши"],
    "застругавши": ["застругав"],
    "застругивав": ["застругивавши"],
    "застругивавши": ["застругивав"],
    "застряв": ["застрявши"],
    "застрявши": ["застряв"],
    "застряпав": ["застряпавши"],
    "застряпавши": ["застряпав"],
    "застуденев": ["застуденевши"],
    "застуденевши": ["застуденев"],
    "застудив": ["застудивши"],
    "застудивши": ["застудив"],
    "застудневав": ["застудневавши"],
    "застудневавши": ["застудневав"],
    "застудневание": ["гелеобразование", "желатинирование"],
    "застуживав": ["застуживавши"],
    "застуживавши": ["застуживав"],
    "застукав": ["застукавши"],
    "застукавши": ["застукав"],
    "застукать": ["застучать", "спалить"],
    "застукивав": ["застукивавши"],
    "застукивавши": ["застукивав"],
    "застукивать": ["палить"],
    "заступав": ["заступавши"],
    "заступавши": ["заступав"],
    "заступать": ["замещать"],
    "заступать дорогу": ["преграждать"],
    "заступив": ["заступивши"],
    "заступивши": ["заступив"],
    "заступленье": ["заступление"],
    "заступник": ["защитник", "покровитель"],
    "заступничество": ["защита", "заступа"],
    "застучав": ["застучавши"],
    "застучавши": ["застучав"],
    "застыв": ["застывши"],
    "застывав": ["застывавши"],
    "застывавши": ["застывав"],
    "застывши": ["застыв"],
    "застыдив": ["застыдивши"],
    "застыдивши": ["застыдив"],
    "застылый": ["замерший", "застывший", "остолбеневший", "оцепеневший"],
    "застынув": ["застынувши"],
    "застынувши": ["застынув"],
    "застынуть": ["застыть", "задубеть", "заледенеть", "застудиться", "задвигаться"],
    "застыть": ["затвердеть", "окаменеть", "замёрзнуть", "замереть", "остолбенеть", "оцепенеть"],
    "застёгивав": ["застёгивавши"],
    "застёгивавши": ["застёгивав"],
    "застёжка": ["застебка", "защепка", "застежница", "запорина", "запоринка", "бабка", "гапелька", "гаплик", "заболока", "остебка"],
    "застёжка-клевант": ["клевант"],
    "застёжка-молния": ["молния", "замок-молния", "патент"],
    "засугробив": ["засугробивши"],
    "засугробивши": ["засугробив"],
    "засудив": ["засудивши"],
    "засудивши": ["засудив"],
    "засуетив": ["засуетивши"],
    "засуетивши": ["засуетив"],
    "засуживав": ["засуживавши"],
    "засуживавши": ["засуживав"],
    "засумасшествовав": ["засумасшествовавши"],
    "засумасшествовавши": ["засумасшествовав"],
    "засунув": ["засунувши"],
    "засунувши": ["засунув"],
    "засунуть язык в жопу": ["засунуть язык в одно известное место"],
    "засупонив": ["засупонивши"],
    "засупонивав": ["засупонивавши"],
    "засупонивавши": ["засупонивав"],
    "засупонивши": ["засупонив"],
    "засуслив": ["засусливши"],
    "засусливав": ["засусливавши"],
    "засусливавши": ["засусливав"],
    "засусливши": ["засуслив"],
    "засусолив": ["засусоливши"],
    "засусоливав": ["засусоливавши"],
    "засусоливавши": ["засусоливав"],
    "засусоливши": ["засусолив"],
    "засуфлировав": ["засуфлировавши"],
    "засуфлировавши": ["засуфлировав"],
    "засуха": ["бездождье", "безводье"],
    "засучив": ["засучивши"],
    "засучив рукава": ["не покладая рук"],
    "засучивав": ["засучивавши"],
    "засучивавши": ["засучивав"],
    "засучивши": ["засучив"],
    "засучить": ["подвернуть", "завернуть"],
    "засушив": ["засушивши"],
    "засушивав": ["засушивавши"],
    "засушивавши": ["засушивав"],
    "засушивши": ["засушив"],
    "засушливо": ["безводно", "сухо"],
    "засушливый": ["сухой"],
    "засчитав": ["засчитавши"],
    "засчитавши": ["засчитав"],
    "засчитывав": ["засчитывавши"],
    "засчитывавши": ["засчитывав"],
    "засылав": ["засылавши"],
    "засылавши": ["засылав"],
    "засыпав": ["засыпавши"],
    "засыпавши": ["засыпав"],
    "засыпанье": ["засыпание"],
    "засыпать": ["завалить", "срезать"],
    "засырев": ["засыревши"],
    "засыревши": ["засырев"],
    "засыхав": ["засыхавши"],
    "засыхавши": ["засыхав"],
    "засыхать": ["высыхать", "сохнуть"],
    "засыхающий": ["сохнущий"],
    "засюсюкав": ["засюсюкавши"],
    "засюсюкавши": ["засюсюкав"],
    "засёдлывав": ["засёдлывавши"],
    "засёдлывавши": ["засёдлывав"],
    "затабанив": ["затабанивши"],
    "затабанивши": ["затабанив"],
    "затаврив": ["затавривши"],
    "затавривши": ["затаврив"],
    "затаенный": ["затаённый", "скрытый", "сокрытый", "тайный", "приглушённый"],
    "затаив": ["затаивши"],
    "затаивав": ["затаивавши"],
    "затаивавши": ["затаивав"],
    "затаивать": ["утаивать"],
    "затаивши": ["затаив"],
    "затаиться": ["притаиться"],
    "заталкивав": ["заталкивавши"],
    "заталкивавши": ["заталкивав"],
    "затальянив": ["затальянивши"],
    "затальянивши": ["затальянив"],
    "затамаживав": ["затамаживавши"],
    "затамаживавши": ["затамаживав"],
    "затаможив": ["затаможивши"],
    "затаможивав": ["затаможивавши"],
    "затаможивавши": ["затаможивав"],
    "затаможивши": ["затаможив"],
    "затампонировав": ["затампонировавши"],
    "затампонировавши": ["затампонировав"],
    "затанцевав": ["затанцевавши"],
    "затанцевавши": ["затанцевав"],
    "затапливав": ["затапливавши"],
    "затапливавши": ["затапливав"],
    "затаптывав": ["затаптывавши"],
    "затаптывавши": ["затаптывав"],
    "затар": ["заатар"],
    "затарабанив": ["затарабанивши"],
    "затарабанивши": ["затарабанив"],
    "затарантив": ["затарантивши"],
    "затарантивши": ["затарантив"],
    "затараторив": ["затараторивши"],
    "затараторивши": ["затараторив"],
    "затарахтев": ["затарахтевши"],
    "затарахтевши": ["затарахтев"],
    "затаращив": ["затаращивши"],
    "затаращивши": ["затаращив"],
    "затарив": ["затаривши"],
    "затаривав": ["затаривавши"],
    "затаривавши": ["затаривав"],
    "затаривши": ["затарив"],
    "затариться": ["закупиться"],
    "затаскав": ["затаскавши"],
    "затаскавши": ["затаскав"],
    "затаскивав": ["затаскивавши"],
    "затаскивавши": ["затаскивав"],
    "затасовав": ["затасовавши"],
    "затасовавши": ["затасовав"],
    "затасовывав": ["затасовывавши"],
    "затасовывавши": ["затасовывав"],
    "затачав": ["затачавши"],
    "затачавши": ["затачав"],
    "затачивав": ["затачивавши"],
    "затачивавши": ["затачивав"],
    "затащив": ["затащивши"],
    "затащивши": ["затащив"],
    "затаяв": ["затаявши"],
    "затаявши": ["затаяв"],
    "затвердев": ["затвердевши"],
    "затвердевав": ["затвердевавши"],
    "затвердевавши": ["затвердевав"],
    "затвердевать": ["твердеть"],
    "затвердевающий": ["отвердевающий", "твердеющий"],
    "затвердевши": ["затвердев"],
    "затвердив": ["затвердивши"],
    "затвердивши": ["затвердив"],
    "затвердити": ["схвалити"],
    "затвердить": ["выучить", "заучить", "зазубрить", "вызубрить", "задолбить", "заладить"],
    "затверживав": ["затверживавши"],
    "затверживавши": ["затверживав"],
    "затвитив": ["затвитивши"],
    "затвитивши": ["затвитив"],
    "затвореност": ["неразговорливост", "необщителност"],
    "затворив": ["затворивши"],
    "затворивши": ["затворив"],
    "затворить": ["закрыть"],
    "затворник": ["отшельник", "домосед"],
    "затворяв": ["затворявши"],
    "затворявши": ["затворяв"],
    "затворять": ["закрывать"],
    "затевав": ["затевавши"],
    "затевавши": ["затевав"],
    "затеивав": ["затеивавши"],
    "затеивавши": ["затеивав"],
    "затейливо": ["причудливо", "замысловато"],
    "затейливый": ["причудливый", "прихотливый", "мудрёный"],
    "затейник": ["забавник", "затейщик", "массовик-затейник"],
    "затейничав": ["затейничавши"],
    "затейничавши": ["затейничав"],
    "затекав": ["затекавши"],
    "затекавши": ["затекав"],
    "затекать": ["втекать"],
    "затем": ["потом", "после", "позже", "далее"],
    "затемнев": ["затемневши"],
    "затемневши": ["затемнев"],
    "затемненье": ["затемнение"],
    "затемнив": ["затемнивши"],
    "затемнивши": ["затемнив"],
    "затемнить": ["запутать"],
    "затемнювання": ["затемнення"],
    "затемняв": ["затемнявши"],
    "затемнявши": ["затемняв"],
    "затемпературив": ["затемпературивши"],
    "затемпературивши": ["затемпературив"],
    "затенив": ["затенивши"],
    "затенивши": ["затенив"],
    "затеняв": ["затенявши"],
    "затенявши": ["затеняв"],
    "затеоретизировав": ["затеоретизировавши"],
    "затеоретизировавши": ["затеоретизировав"],
    "затеплив": ["затепливши"],
    "затепливав": ["затепливавши"],
    "затепливавши": ["затепливав"],
    "затепливать": ["затеплять"],
    "затепливши": ["затеплив"],
    "затепляв": ["затеплявши"],
    "затеплявши": ["затепляв"],
    "затеплять": ["затепливать"],
    "затеребив": ["затеребивши"],
    "затеребивши": ["затеребив"],
    "затерев": ["затёрши"],
    "затерзав": ["затерзавши"],
    "затерзавши": ["затерзав"],
    "затеривав": ["затеривавши"],
    "затеривавши": ["затеривав"],
    "затеривать": ["терять"],
    "затерландский": ["восточнофризский", "восточнофризский язык", "затерландский фризский", "затерландский фризский язык"],
    "затерландский фризский": ["восточнофризский", "восточнофризский язык", "затерландский", "затерландский фризский язык"],
    "затерландский фризский язык": ["восточнофризский", "восточнофризский язык", "затерландский фризский"],
    "затерпнув": ["затерпнувши"],
    "затерпнувши": ["затерпнув"],
    "затерроризировав": ["затерроризировавши"],
    "затерроризировавши": ["затерроризировав"],
    "затерроризированный": ["замордованный", "запуганный"],
    "затерроризировать": ["запугать"],
    "затеряв": ["затерявши"],
    "затерявши": ["затеряв"],
    "затерять": ["потерять", "утратить"],
    "затесав": ["затесавши"],
    "затесавши": ["затесав"],
    "затеснив": ["затеснивши"],
    "затеснивши": ["затеснив"],
    "затесняв": ["затеснявши"],
    "затеснявши": ["затесняв"],
    "затесь": ["затёс", "затёска", "зарубка"],
    "затея": ["предприятие", "замысел", "задумка", "намерение"],
    "затеяв": ["затеявши"],
    "затеявши": ["затеяв"],
    "затеять": ["предпринять", "замыслить"],
    "затеяться": ["начаться", "завязаться"],
    "затикав": ["затикавши"],
    "затикавши": ["затикав"],
    "затирав": ["затиравши"],
    "затиравши": ["затирав"],
    "затиранив": ["затиранивши"],
    "затиранивав": ["затиранивавши"],
    "затиранивавши": ["затиранивав"],
    "затиранивши": ["затиранив"],
    "затираха": ["затируха", "затирка"],
    "затирка": ["затираха"],
    "затируха": ["затирка", "затирушка", "затираха", "саламата"],
    "затискав": ["затискавши"],
    "затискавши": ["затискав"],
    "затискивав": ["затискивавши"],
    "затискивавши": ["затискивав"],
    "затиснув": ["затиснувши"],
    "затиснувши": ["затиснув"],
    "затихав": ["затихавши"],
    "затихавши": ["затихав"],
    "затиханье": ["затихание"],
    "затихариться": ["затаиться", "притаиться", "спрятаться", "заныкаться", "зачулковаться", "затихнуть", "залечь на дно"],
    "затихнув": ["затихнувши"],
    "затихнувши": ["затихнув"],
    "затишок": ["затишек"],
    "затишье": ["замирание", "безветрие", "штиль", "застой", "захолустье"],
    "заткав": ["заткавши"],
    "заткавши": ["заткав"],
    "заткнув": ["заткнувши"],
    "заткнувши": ["заткнув"],
    "заткнуть за пояс": ["показать кузькину мать", "утереть нос", "отнять пальму первенства", "положить на обе лопатки"],
    "заткнуть фонтан": ["закрыть фонтан", "срезать фонтан"],
    "заткнуться": ["закупориться", "подоткнуться", "замолчать", "затихнуть"],
    "затлев": ["затлевши"],
    "затлевав": ["затлевавши"],
    "затлевавши": ["затлевав"],
    "затлевши": ["затлев"],
    "затмевав": ["затмевавши"],
    "затмевавши": ["затмевав"],
    "затмение": ["затменье", "помрачение", "сознание"],
    "затменье": ["затмение"],
    "затмив": ["затмивши"],
    "затмивши": ["затмив"],
    "зато": ["но зато", "но", "в то же время", "однако"],
    "затоварив": ["затоваривши"],
    "затоваривав": ["затоваривавши"],
    "затоваривавши": ["затоваривав"],
    "затоваривши": ["затоварив"],
    "затоковав": ["затоковавши"],
    "затоковавши": ["затоковав"],
    "затолкав": ["затолкавши"],
    "затолкавши": ["затолкав"],
    "затолкнув": ["затолкнувши"],
    "затолкнувши": ["затолкнув"],
    "затолковав": ["затолковавши"],
    "затолковавши": ["затолковав"],
    "затомив": ["затомивши"],
    "затомивши": ["затомив"],
    "затон": ["заводь", "запруда", "плотина"],
    "затонировав": ["затонировавши"],
    "затонировавши": ["затонировав"],
    "затонув": ["затонувши"],
    "затонувши": ["затонув"],
    "затонуть": ["потонуть", "утонуть"],
    "затопав": ["затопавши"],
    "затопавши": ["затопав"],
    "затопив": ["затопивши"],
    "затопивши": ["затопив"],
    "затопляв": ["затоплявши"],
    "затоплявши": ["затопляв"],
    "затоплять": ["затапливать", "заливать", "пускать ко дну", "топить"],
    "затопорщив": ["затопорщивши"],
    "затопорщивши": ["затопорщив"],
    "затопотав": ["затопотавши"],
    "затопотавши": ["затопотав"],
    "затопотать": ["затопать"],
    "затоптав": ["затоптавши"],
    "затоптавши": ["затоптав"],
    "затопывав": ["затопывавши"],
    "затопывавши": ["затопывав"],
    "затор": ["пробка"],
    "заторачивав": ["заторачивавши"],
    "заторачивавши": ["заторачивав"],
    "заторговав": ["заторговавши"],
    "заторговавши": ["заторговав"],
    "заторговывав": ["заторговывавши"],
    "заторговывавши": ["заторговывав"],
    "заторжествовав": ["заторжествовавши"],
    "заторжествовавши": ["заторжествовав"],
    "заторкав": ["заторкавши"],
    "заторкавши": ["заторкав"],
    "затормаживав": ["затормаживавши"],
    "затормаживавши": ["затормаживав"],
    "затормаживающий": ["тормозящий"],
    "затормозив": ["затормозивши"],
    "затормозивши": ["затормозив"],
    "затормошив": ["затормошивши"],
    "затормошивши": ["затормошив"],
    "заторопив": ["заторопивши"],
    "заторопивши": ["заторопив"],
    "заторопиться": ["заспешить"],
    "заторочив": ["заторочивши"],
    "заторочивши": ["заторочив"],
    "заторочить": ["второчить"],
    "заторцевав": ["заторцевавши"],
    "заторцевавши": ["заторцевав"],
    "заторцовывав": ["заторцовывавши"],
    "заторцовывавши": ["заторцовывав"],
    "заторчав": ["заторчавши"],
    "заторчавши": ["заторчав"],
    "затосковав": ["затосковавши"],
    "затосковавши": ["затосковав"],
    "заточав": ["заточавши"],
    "заточавши": ["заточав"],
    "заточив": ["заточивши"],
    "заточивши": ["заточив"],
    "заточка": ["затачивание", "заострение", "острение", "оправка", "очинивание", "пика", "весло", "пыряло", "сажальник", "ступер"],
    "заточковывав": ["заточковывавши"],
    "заточковывавши": ["заточковывав"],
    "заточковывать": ["протоколировать", "брать на карандаш"],
    "заточённый": ["заключённый"],
    "затошнив": ["затошнивши"],
    "затошнивши": ["затошнив"],
    "затощав": ["затощавши"],
    "затощавши": ["затощав"],
    "затравев": ["затравевши"],
    "затравевши": ["затравев"],
    "затравенев": ["затравеневши"],
    "затравеневши": ["затравенев"],
    "затравив": ["затравивши"],
    "затравивши": ["затравив"],
    "затравливав": ["затравливавши"],
    "затравливавши": ["затравливав"],
    "затравливание": ["травля"],
    "затравливать": ["травить", "изводить"],
    "затравочник": ["затравник"],
    "затрагивав": ["затрагивавши"],
    "затрагивавши": ["затрагивав"],
    "затрагивать": ["затрогивать"],
    "затралив": ["затраливши"],
    "затраливав": ["затраливавши"],
    "затраливавши": ["затраливав"],
    "затраливши": ["затралив"],
    "затрамбовав": ["затрамбовавши"],
    "затрамбовавши": ["затрамбовав"],
    "затрамбовать": ["утрамбовать"],
    "затрамбовывав": ["затрамбовывавши"],
    "затрамбовывавши": ["затрамбовывав"],
    "затрамбовывать": ["утрамбовывать"],
    "затранскрибировав": ["затранскрибировавши"],
    "затранскрибировавши": ["затранскрибировав"],
    "затрапезка": ["затрапез"],
    "затратив": ["затративши"],
    "затративши": ["затратив"],
    "затратить": ["израсходовать", "истратить", "потратить"],
    "затратно": ["дорого", "дорогостояще", "затратненько", "стоимостно", "расходно"],
    "затратный": ["дорогой", "дорогостоящий", "стоимостной", "расходный"],
    "затрахав": ["затрахавши"],
    "затрахавши": ["затрахав"],
    "затрахать": ["задолбать", "заколебать", "замаять"],
    "затрахивав": ["затрахивавши"],
    "затрахивавши": ["затрахивав"],
    "затрахидид": ["затрахеид"],
    "затрачивав": ["затрачивавши"],
    "затрачивавши": ["затрачивав"],
    "затребовав": ["затребовавши"],
    "затребовавши": ["затребовав"],
    "затревожив": ["затревоживши"],
    "затревоживши": ["затревожив"],
    "затрезвонив": ["затрезвонивши"],
    "затрезвонивши": ["затрезвонив"],
    "затренькав": ["затренькавши"],
    "затренькавши": ["затренькав"],
    "затрепав": ["затрепавши"],
    "затрепавши": ["затрепав"],
    "затрепать": ["истрепать"],
    "затрепетав": ["затрепетавши"],
    "затрепетавши": ["затрепетав"],
    "затрепетать": ["задрожать", "затрястись", "вострепетать"],
    "затрепыхав": ["затрепыхавши"],
    "затрепыхавши": ["затрепыхав"],
    "затрещав": ["затрещавши"],
    "затрещавши": ["затрещав"],
    "затрещать": ["зашататься", "затараторить"],
    "затрещина": ["оплеуха", "пощёчина"],
    "затрогивав": ["затрогивавши"],
    "затрогивавши": ["затрогивав"],
    "затрогивать": ["затрагивать"],
    "затролив": ["затроливши"],
    "затроливши": ["затролив"],
    "затроллив": ["затролливши"],
    "затролливши": ["затроллив"],
    "затронув": ["затронувши"],
    "затронувши": ["затронув"],
    "затрофеивать": ["трофеить"],
    "затрубив": ["затрубивши"],
    "затрубивши": ["затрубив"],
    "затрудненье": ["затруднение"],
    "затруднив": ["затруднивши"],
    "затруднивши": ["затруднив"],
    "затруднительный": ["трудный", "тяжёлый"],
    "затрудниться": ["усложниться", "утяжелиться"],
    "затрудняв": ["затруднявши"],
    "затруднявши": ["затрудняв"],
    "затруднять": ["усложнять"],
    "затрудняться": ["усложняться", "утяжеляться"],
    "затрусив": ["затрусивши"],
    "затрусивши": ["затрусив"],
    "затруситься": ["затрястись"],
    "затрухлявев": ["затрухлявевши"],
    "затрухлявевши": ["затрухлявев"],
    "затрёпывав": ["затрёпывавши"],
    "затрёпывавши": ["затрёпывав"],
    "затрёпываемый": ["изнашиваемый", "обтрёпываемый"],
    "затужив": ["затуживши"],
    "затуживши": ["затужив"],
    "затукав": ["затукавши"],
    "затукавши": ["затукав"],
    "затуманив": ["затуманивши"],
    "затуманивав": ["затуманивавши"],
    "затуманивавши": ["затуманивав"],
    "затуманивать": ["застилать", "туманить"],
    "затуманивши": ["затуманив"],
    "затупев": ["затупевши"],
    "затупевши": ["затупев"],
    "затупив": ["затупивши"],
    "затупивши": ["затупив"],
    "затуплювати": ["затупляти"],
    "затупляв": ["затуплявши"],
    "затуплявши": ["затупляв"],
    "затуркав": ["затуркавши"],
    "затуркавши": ["затуркав"],
    "затуркать": ["загнать", "затыркать", "затюкать"],
    "затусив": ["затусивши"],
    "затусивши": ["затусив"],
    "затухав": ["затухавши"],
    "затухавши": ["затухав"],
    "затуханье": ["затухание"],
    "затухать": ["тухнуть", "гаснуть"],
    "затухающий": ["угасающий"],
    "затухнув": ["затухнувши"],
    "затухнувши": ["затухнув"],
    "затухнуть": ["потухнуть", "погаснуть", "угаснуть"],
    "затучив": ["затучивши"],
    "затучивши": ["затучив"],
    "затушевав": ["затушевавши"],
    "затушевавши": ["затушевав"],
    "затушение": ["гашение", "загашение", "погашение", "потушение"],
    "затушив": ["затушивши"],
    "затушивши": ["затушив"],
    "затушить": ["потушить", "погасить"],
    "затушковувати": ["затушовувати"],
    "затушёвывав": ["затушёвывавши"],
    "затушёвывавши": ["затушёвывав"],
    "затхлость": ["гнилость", "заплесневелость", "духота", "застой", "закоснелость"],
    "затык": ["затор", "затыка"],
    "затыкав": ["затыкавши"],
    "затыкавши": ["затыкав"],
    "затыкаться": ["закупориваться"],
    "затыловав": ["затыловавши"],
    "затыловавши": ["затыловав"],
    "затыловка": ["затылование"],
    "затылок": ["затылочье", "затылица", "потылица"],
    "затырив": ["затыривши"],
    "затыривши": ["затырив"],
    "затыркав": ["затыркавши"],
    "затыркавши": ["затыркав"],
    "затыркнув": ["затыркнувши"],
    "затыркнувши": ["затыркнув"],
    "затюкав": ["затюкавши"],
    "затюкавши": ["затюкав"],
    "затюкивав": ["затюкивавши"],
    "затюкивавши": ["затюкивав"],
    "затюковав": ["затюковавши"],
    "затюковавши": ["затюковав"],
    "затюковывав": ["затюковывавши"],
    "затюковывавши": ["затюковывав"],
    "затявкав": ["затявкавши"],
    "затявкавши": ["затявкав"],
    "затягивав": ["затягивавши"],
    "затягивавши": ["затягивав"],
    "затяжелев": ["затяжелевши"],
    "затяжелевши": ["затяжелев"],
    "затяжеление": ["отяжеление"],
    "затяжелеть": ["потяжелеть"],
    "затяжной": ["продолжительный", "длительный"],
    "затянув": ["затянувши"],
    "затянувши": ["затянув"],
    "затянутость": ["растянутость"],
    "затянуть ремень потуже": ["затянуть потуже пояс"],
    "затяпав": ["затяпавши"],
    "затяпавши": ["затяпав"],
    "затёрши": ["затерев"],
    "затёс": ["затесь"],
    "затёсывав": ["затёсывавши"],
    "затёсывавши": ["затёсывав"],
    "зауважав": ["зауважавши"],
    "зауважавши": ["зауважав"],
    "зауважити": ["спостерегти"],
    "заувея": ["затёнье"],
    "заугольник": ["выблядок", "ублюдок", "бастард", "байстрюк", "сколоток", "сколотыш", "небрачнорожденный", "семибатечный", "ветер", "крапивник", "холмогорец"],
    "заугрюмев": ["заугрюмевши"],
    "заугрюмевши": ["заугрюмев"],
    "заударный": ["постакцентный"],
    "заудив": ["заудивши"],
    "заудивши": ["заудив"],
    "зауживав": ["зауживавши"],
    "зауживавши": ["зауживав"],
    "зауживание": ["обуживание"],
    "зауживать": ["обуживать"],
    "зауздав": ["зауздавши"],
    "зауздавши": ["зауздав"],
    "зауздаться": ["взнуздаться"],
    "зауздывав": ["зауздывавши"],
    "зауздывавши": ["зауздывав"],
    "заузив": ["заузивши"],
    "заузивши": ["заузив"],
    "заулюлюкав": ["заулюлюкавши"],
    "заулюлюкавши": ["заулюлюкав"],
    "заум": ["мудрагельство"],
    "заумирав": ["заумиравши"],
    "заумиравши": ["заумирав"],
    "заумничав": ["заумничавши"],
    "заумничавши": ["заумничав"],
    "заумный": ["непонятный", "неясный", "непостижимый", "недоступный", "тёмный", "невразумительный", "мудрёный", "вычурный"],
    "заумствовав": ["заумствовавши"],
    "заумствовавши": ["заумствовав"],
    "заумь": ["абракадабра", "абсурд", "бессмыслица", "бред", "набор слов", "нонсенс", "птичий язык", "бодяга", "бред сивой кобылы", "бредятина", "ерунда", "лажа", "сюр", "тарабарщина", "чепуха"],
    "заунывно": ["тоскливо", "уныло"],
    "заунывный": ["грустный", "тоскливый", "унылый"],
    "заупрямиться": ["заартачиться", "заупорствовать"],
    "заурановый": ["трансурановый"],
    "зауропод": ["зауропода", "завропод"],
    "зауропода": ["завропода", "зауропод"],
    "заурчав": ["заурчавши"],
    "заурчавши": ["заурчав"],
    "заурядность": ["неспособный", "бездарный", "бесталанный"],
    "заурядный": ["посредственный", "обыденный", "рядовой", "ординарный"],
    "заусенец": ["заусеница", "заногтица", "заусенок", "заусенка"],
    "заусеница": ["заусенец", "заногтица", "заусенок", "заусенка"],
    "заусенка": ["заусенок", "заусеница", "заусенец", "заногтица"],
    "заусенок": ["заусенка", "тычок", "ложок", "заусенец", "заусеница", "заусёнок", "заусёнка", "заногтица"],
    "заусив": ["заусивши"],
    "заусивши": ["заусив"],
    "зауськав": ["зауськавши"],
    "зауськавши": ["зауськав"],
    "заутреня": ["утреня"],
    "заутюжив": ["заутюживши"],
    "заутюживав": ["заутюживавши"],
    "заутюживавши": ["заутюживав"],
    "заутюживши": ["заутюжив"],
    "заухав": ["заухавши"],
    "заухавши": ["заухав"],
    "заухаживав": ["заухаживавши"],
    "заухаживавши": ["заухаживав"],
    "заучав": ["заучавши"],
    "заучавши": ["заучав"],
    "заучив": ["заучивши"],
    "заучивав": ["заучивавши"],
    "заучивавши": ["заучивав"],
    "заучивание": ["заучиванье"],
    "заучиванье": ["заучивание"],
    "заучивать": ["выучивать", "запоминать"],
    "заучивши": ["заучив"],
    "заучить": ["затвердить"],
    "заушав": ["заушавши"],
    "заушавши": ["заушав"],
    "заушательский": ["грубый", "оскорбительный", "порочащий", "хулительный", "критиканский", "заглазный", "заочный"],
    "заушать": ["оскорблять", "позорить", "поносить", "порочить"],
    "заушение": ["затрещина", "заушина", "оплеуха", "пощечина", "оскорбление"],
    "заушив": ["заушивши"],
    "заушивши": ["заушив"],
    "заушница": ["свинка"],
    "зафальшивив": ["зафальшививши"],
    "зафальшививши": ["зафальшивив"],
    "зафамильярничав": ["зафамильярничавши"],
    "зафамильярничавши": ["зафамильярничав"],
    "зафантазировав": ["зафантазировавши"],
    "зафантазировавши": ["зафантазировав"],
    "зафартить": ["подфартить", "пофартить", "фартануть"],
    "зафаршировав": ["зафаршировавши"],
    "зафаршировавши": ["зафаршировав"],
    "зафейлив": ["зафейливши"],
    "зафейливши": ["зафейлив"],
    "зафейлить": ["испортить"],
    "зафигарив": ["зафигаривши"],
    "зафигаривши": ["зафигарив"],
    "зафигарить": ["запулить", "залупить", "залупенить", "залупешить", "зафигачить", "зафитиленить", "захреначить", "захерачить", "захуячить", "захуярить", "заебенить", "запиздошить"],
    "зафигачив": ["зафигачивши"],
    "зафигачивав": ["зафигачивавши"],
    "зафигачивавши": ["зафигачивав"],
    "зафигачивши": ["зафигачив"],
    "зафиксировав": ["зафиксировавши"],
    "зафиксировавши": ["зафиксировав"],
    "зафиксированность": ["закреплённость"],
    "зафилософствовав": ["зафилософствовавши"],
    "зафилософствовавши": ["зафилософствовав"],
    "зафиндилить": ["захерачить"],
    "зафинтив": ["зафинтивши"],
    "зафинтивши": ["зафинтив"],
    "зафлажив": ["зафлаживши"],
    "зафлаживши": ["зафлажив"],
    "зафлудив": ["зафлудивши"],
    "зафлудивши": ["зафлудив"],
    "зафонив": ["зафонивши"],
    "зафонивши": ["зафонив"],
    "зафонтанировав": ["зафонтанировавши"],
    "зафонтанировавши": ["зафонтанировав"],
    "зафордыбачить": ["заартачиться"],
    "заформализовав": ["заформализовавши"],
    "заформализовавши": ["заформализовав"],
    "заформализовывав": ["заформализовывавши"],
    "заформализовывавши": ["заформализовывав"],
    "заформовав": ["заформовавши"],
    "заформовавши": ["заформовав"],
    "заформовывав": ["заформовывавши"],
    "заформовывавши": ["заформовывав"],
    "зафорсив": ["зафорсивши"],
    "зафорсивши": ["зафорсив"],
    "зафрантив": ["зафрантивши"],
    "зафрантивши": ["зафрантив"],
    "зафрахтовав": ["зафрахтовавши"],
    "зафрахтовавши": ["зафрахтовав"],
    "зафрахтовать": ["ангажировать"],
    "зафрахтовывав": ["зафрахтовывавши"],
    "зафрахтовывавши": ["зафрахтовывав"],
    "зафрендив": ["зафрендивши"],
    "зафрендивши": ["зафрендив"],
    "зафрендить": ["задружить", "подружиться"],
    "зафторив": ["зафторивши"],
    "зафторивав": ["зафторивавши"],
    "зафторивавши": ["зафторивав"],
    "зафторивши": ["зафторив"],
    "зафукав": ["зафукавши"],
    "зафукавши": ["зафукав"],
    "зафункционировав": ["зафункционировавши"],
    "зафункционировавши": ["зафункционировав"],
    "зафутболив": ["зафутболивши"],
    "зафутболивав": ["зафутболивавши"],
    "зафутболивавши": ["зафутболивав"],
    "зафутболивши": ["зафутболив"],
    "зафыркав": ["зафыркавши"],
    "зафыркавши": ["зафыркав"],
    "зафырчав": ["зафырчавши"],
    "зафырчавши": ["зафырчав"],
    "захавав": ["захававши"],
    "захававши": ["захавав"],
    "захаживав": ["захаживавши"],
    "захаживавши": ["захаживав"],
    "захаивав": ["захаивавши"],
    "захаивавши": ["захаивав"],
    "захандрив": ["захандривши"],
    "захандривши": ["захандрив"],
    "захандрить": ["пасть духом", "скиснуть", "заскучать", "скукситься", "затосковать", "упасть духом", "приуныть", "прийти в уныние", "опустить голову", "повесить голову", "нахохлиться"],
    "захапав": ["захапавши"],
    "захапавши": ["захапав"],
    "захапывав": ["захапывавши"],
    "захапывавши": ["захапывав"],
    "захапывать": ["присваивать", "захватывать"],
    "захапывающий": ["хапающий"],
    "захар": ["захарий"],
    "захаркав": ["захаркавши"],
    "захаркавши": ["захаркав"],
    "захаркивав": ["захаркивавши"],
    "захаркивавши": ["захаркивав"],
    "захарович": ["захарыч"],
    "захаяв": ["захаявши"],
    "захаявши": ["захаяв"],
    "захвалив": ["захваливши"],
    "захваливав": ["захваливавши"],
    "захваливавши": ["захваливав"],
    "захваливши": ["захвалив"],
    "захварывав": ["захварывавши"],
    "захварывавши": ["захварывав"],
    "захварывающий": ["заболевающий"],
    "захвастав": ["захваставши"],
    "захваставши": ["захвастав"],
    "захватав": ["захватавши"],
    "захватавши": ["захватав"],
    "захватив": ["захвативши"],
    "захвативши": ["захватив"],
    "захватить": ["схватить", "заграбастать", "овладеть", "занять", "оккупировать", "узурпировать", "прихватить", "заинтересовать", "увлечь", "поглотить"],
    "захватнический": ["завоевательный"],
    "захватчик": ["оккупант", "завоеватель"],
    "захватывав": ["захватывавши"],
    "захватывавши": ["захватывав"],
    "захватывать": ["схватывать", "хватать", "прихватывать", "завладевать", "овладевать"],
    "захватывающе": ["завлекательно", "увлекательно"],
    "захворав": ["захворавши"],
    "захворавши": ["захворав"],
    "захворать": ["заболеть"],
    "захворювання": ["хвороба", "недуга"],
    "захеджировав": ["захеджировавши"],
    "захеджировавши": ["захеджировав"],
    "захекатися": ["задихатися"],
    "захерачив": ["захерачивши"],
    "захерачивши": ["захерачив"],
    "захерив": ["захеривши"],
    "захеривши": ["захерив"],
    "захилев": ["захилевши"],
    "захилевши": ["захилев"],
    "захира": ["пасандоз"],
    "захирев": ["захиревши"],
    "захиревши": ["захирев"],
    "захиреть": ["зачахнуть"],
    "захист": ["оборона", "заступництво", "притулок", "укриття", "захисток", "охорона", "заслона"],
    "захихикав": ["захихикавши"],
    "захихикавши": ["захихикав"],
    "захихикать": ["давиться смехом", "смеяться в бороду", "смеяться в кулак"],
    "захламив": ["захламивши"],
    "захламивши": ["захламив"],
    "захламить": ["засорить", "замусорить"],
    "захламиться": ["засориться", "замусориться"],
    "захламление": ["захламливание", "загромождение", "замусоривание"],
    "захламливав": ["захламливавши"],
    "захламливавши": ["захламливав"],
    "захламляв": ["захламлявши"],
    "захламлявши": ["захламляв"],
    "захламлять": ["засорять", "замусоривать"],
    "захламостив": ["захламостивши"],
    "захламостивши": ["захламостив"],
    "захлебав": ["захлебавши"],
    "захлебавши": ["захлебав"],
    "захлебнув": ["захлебнувши"],
    "захлебнувши": ["захлебнув"],
    "захлебнуться": ["утонуть", "поперхнуться", "задохнуться", "заглохнуть"],
    "захлеснув": ["захлеснувши"],
    "захлеснувши": ["захлеснув"],
    "захлестав": ["захлеставши"],
    "захлеставши": ["захлестав"],
    "захлестнув": ["захлестнувши"],
    "захлестнувши": ["захлестнув"],
    "захлипав": ["захлипавши"],
    "захлипавши": ["захлипав"],
    "захлопав": ["захлопавши"],
    "захлопавши": ["захлопав"],
    "захлопнув": ["захлопнувши"],
    "захлопнувши": ["захлопнув"],
    "захлопотав": ["захлопотавши"],
    "захлопотавши": ["захлопотав"],
    "захлопывав": ["захлопывавши"],
    "захлопывавши": ["захлопывав"],
    "захлороформировав": ["захлороформировавши"],
    "захлороформировавши": ["захлороформировав"],
    "захлюпав": ["захлюпавши"],
    "захлюпавши": ["захлюпав"],
    "захлюстав": ["захлюставши"],
    "захлюставши": ["захлюстав"],
    "захлябав": ["захлябавши"],
    "захлябавши": ["захлябав"],
    "захлёбывав": ["захлёбывавши"],
    "захлёбывавши": ["захлёбывав"],
    "захлёстывав": ["захлёстывавши"],
    "захлёстывавши": ["захлёстывав"],
    "захмарив": ["захмаривши"],
    "захмаривши": ["захмарив"],
    "захмелев": ["захмелевши"],
    "захмелевши": ["захмелев"],
    "захмелеть": ["опьянеть"],
    "захныкав": ["захныкавши"],
    "захныкавши": ["захныкав"],
    "заховав": ["заховавши"],
    "заховавши": ["заховав"],
    "заход": ["визит", "вход", "приход", "обход", "выход", "уход", "попытка", "закат"],
    "заходив": ["заходивши"],
    "заходивши": ["заходив"],
    "заходить": ["войти", "нравиться", "приходиться по душе"],
    "захожанин": ["прохожанин", "невоцерковленный"],
    "захозяйничав": ["захозяйничавши"],
    "захозяйничавши": ["захозяйничав"],
    "захолодав": ["захолодавши"],
    "захолодавши": ["захолодав"],
    "захолодев": ["захолодевши"],
    "захолодевши": ["захолодев"],
    "захолодеть": ["похолодать", "похолодить", "замерзнуть", "озябнуть", "застыть", "оцепенеть"],
    "захолодить": ["похолодать", "захолодеть", "морозить", "заморозить"],
    "захолонув": ["захолонувши"],
    "захолонувши": ["захолонув"],
    "захолонуть": ["застыть", "замереть"],
    "захолустье": ["дыра", "глушь", "глухомань", "медвежий угол", "пердь", "тьмутаракань"],
    "захомутав": ["захомутавши"],
    "захомутавши": ["захомутав"],
    "захомячив": ["захомячивши"],
    "захомячивши": ["захомячив"],
    "захомячить": ["схомячить"],
    "захоранивав": ["захоранивавши"],
    "захоранивавши": ["захоранивав"],
    "захоранивать": ["хоронить", "предавать земле"],
    "захороводив": ["захороводивши"],
    "захороводивши": ["захороводив"],
    "захоронение": ["ингумация"],
    "захороненье": ["захоронение"],
    "захоронив": ["захоронивши"],
    "захоронивши": ["захоронив"],
    "захороняв": ["захоронявши"],
    "захоронявши": ["захороняв"],
    "захоронять": ["ингумировать"],
    "захорошев": ["захорошевши"],
    "захорошевши": ["захорошев"],
    "захотев": ["захотевши"],
    "захотевши": ["захотев"],
    "захотеть": ["возжелать", "пожелать"],
    "захохотав": ["захохотавши"],
    "захохотавши": ["захохотав"],
    "захрапев": ["захрапевши"],
    "захрапевши": ["захрапев"],
    "захребетник": ["тунеядец", "дармоед"],
    "захребетничав": ["захребетничавши"],
    "захребетничавши": ["захребетничав"],
    "захреначив": ["захреначивши"],
    "захреначивав": ["захреначивавши"],
    "захреначивавши": ["захреначивав"],
    "захреначивши": ["захреначив"],
    "захрипев": ["захрипевши"],
    "захрипевши": ["захрипев"],
    "захромав": ["захромавши"],
    "захромавши": ["захромав"],
    "захронометрировав": ["захронометрировавши"],
    "захронометрировавши": ["захронометрировав"],
    "захрумкав": ["захрумкавши"],
    "захрумкавши": ["захрумкав"],
    "захрустев": ["захрустевши"],
    "захрустевши": ["захрустев"],
    "захрюкав": ["захрюкавши"],
    "захрюкавши": ["захрюкав"],
    "захряснув": ["захряснувши"],
    "захряснувши": ["захряснув"],
    "захряснуть": ["загустеть", "затвердеть", "завязнуть"],
    "захудав": ["захудавши"],
    "захудавши": ["захудав"],
    "захуевертив": ["захуевертивши"],
    "захуевертивши": ["захуевертив"],
    "захуевертить": ["захуярить", "захуячить"],
    "захулиганив": ["захулиганивши"],
    "захулиганивши": ["захулиганив"],
    "захуярив": ["захуяривши"],
    "захуяривав": ["захуяривавши"],
    "захуяривавши": ["захуяривав"],
    "захуяривши": ["захуярив"],
    "захуярить": ["захуячить", "въебашить", "заебашить", "впаять", "впилить"],
    "захуячив": ["захуячивши"],
    "захуячивши": ["захуячив"],
    "захуячиться": ["вступить", "вляпаться", "вструмиться", "запиздошиться", "впиздошиться", "вхуячиться", "въебениться", "заебениться"],
    "захуёвничав": ["захуёвничавши"],
    "захуёвничавши": ["захуёвничав"],
    "захуёвничать": ["завредничать", "закапризничать", "зауросить"],
    "зацапав": ["зацапавши"],
    "зацапавши": ["зацапав"],
    "зацапывав": ["зацапывавши"],
    "зацапывавши": ["зацапывав"],
    "зацарапав": ["зацарапавши"],
    "зацарапавши": ["зацарапав"],
    "зацарствовав": ["зацарствовавши"],
    "зацарствовавши": ["зацарствовав"],
    "зацветав": ["зацветавши"],
    "зацветавши": ["зацветав"],
    "зацедив": ["зацедивши"],
    "зацедивши": ["зацедив"],
    "зацеловав": ["зацеловавши"],
    "зацеловавши": ["зацеловав"],
    "зацеловывав": ["зацеловывавши"],
    "зацеловывавши": ["зацеловывав"],
    "зацементировав": ["зацементировавши"],
    "зацементировавши": ["зацементировав"],
    "заценив": ["заценивши"],
    "заценивав": ["заценивавши"],
    "заценивавши": ["заценивав"],
    "заценивши": ["заценив"],
    "зацентрализовав": ["зацентрализовавши"],
    "зацентрализовавши": ["зацентрализовав"],
    "зацентрализовывав": ["зацентрализовывавши"],
    "зацентрализовывавши": ["зацентрализовывав"],
    "зацентровав": ["зацентровавши"],
    "зацентровавши": ["зацентровав"],
    "зацепив": ["зацепивши"],
    "зацепивши": ["зацепив"],
    "зацепиться языками": ["зацепиться языком"],
    "зацепиться языком": ["зацепиться языками", "заболтаться"],
    "зацепляв": ["зацеплявши"],
    "зацеплявши": ["зацепляв"],
    "зацепочный": ["зацепляющий"],
    "зацикленный": ["повёрнутый"],
    "зациклив": ["зацикливши"],
    "зацикливав": ["зацикливавши"],
    "зацикливавши": ["зацикливав"],
    "зацикливши": ["зациклив"],
    "зацитировав": ["зацитировавши"],
    "зацитировавши": ["зацитировав"],
    "зацокав": ["зацокавши"],
    "зацокавши": ["зацокав"],
    "зацурчаць": ["зажурчаць", "зажурчэць"],
    "зацыкав": ["зацыкавши"],
    "зацыкавши": ["зацыкав"],
    "зачав": ["зачавши"],
    "зачавкав": ["зачавкавши"],
    "зачавкавши": ["зачавкав"],
    "зачавши": ["зачав"],
    "зачадив": ["зачадивши"],
    "зачадивши": ["зачадив"],
    "зачалив": ["зачаливши"],
    "зачаливав": ["зачаливавши"],
    "зачаливавши": ["зачаливав"],
    "зачаливши": ["зачалив"],
    "зачаровав": ["зачаровавши"],
    "зачаровавши": ["зачаровав"],
    "зачарованный": ["заворожённый", "заколдованный"],
    "зачаровать": ["околдовать", "заколдовать", "очаровать"],
    "зачаровывав": ["зачаровывавши"],
    "зачаровывавши": ["зачаровывав"],
    "зачаровывать": ["околдовывать", "заколдовывать", "очаровывать", "восхищать", "пленять"],
    "зачастив": ["зачастивши"],
    "зачастивши": ["зачастив"],
    "зачастую": ["нередко", "часто", "во многих случаях"],
    "зачатие": ["оплодотворение"],
    "зачатый": ["начатый"],
    "зачать": ["забрюхатеть", "зародить", "забеременеть"],
    "зачатье": ["зачатие"],
    "зачахнув": ["зачахнувши"],
    "зачахнувши": ["зачахнув"],
    "зачахнуть": ["захиреть", "обессилеть", "завянуть"],
    "зачеканив": ["зачеканивши"],
    "зачеканивав": ["зачеканивавши"],
    "зачеканивавши": ["зачеканивав"],
    "зачеканивши": ["зачеканив"],
    "зачекиниться": ["зарегистрироваться"],
    "зачервивев": ["зачервивевши"],
    "зачервивевши": ["зачервивев"],
    "зачередовав": ["зачередовавши"],
    "зачередовавши": ["зачередовав"],
    "зачеркав": ["зачеркавши"],
    "зачеркавши": ["зачеркав"],
    "зачеркнув": ["зачеркнувши"],
    "зачеркнувши": ["зачеркнув"],
    "зачеркнуть": ["перечеркнуть", "поставить крест"],
    "зачернев": ["зачерневши"],
    "зачерневши": ["зачернев"],
    "зачернив": ["зачернивши"],
    "зачернивши": ["зачернив"],
    "зачерняв": ["зачернявши"],
    "зачернявши": ["зачерняв"],
    "зачернять": ["чернить"],
    "зачерпав": ["зачерпавши"],
    "зачерпавши": ["зачерпав"],
    "зачерпнув": ["зачерпнувши"],
    "зачерпнувши": ["зачерпнув"],
    "зачерпывав": ["зачерпывавши"],
    "зачерпывавши": ["зачерпывав"],
    "зачерствев": ["зачерствевши"],
    "зачерствевав": ["зачерствевавши"],
    "зачерствевавши": ["зачерствевав"],
    "зачерствевать": ["черстветь"],
    "зачерствевши": ["зачерствев"],
    "зачерствелость": ["чёрствость"],
    "зачерствелый": ["чёрствый"],
    "зачерстветь": ["очерстветь"],
    "зачертив": ["зачертивши"],
    "зачертивши": ["зачертив"],
    "зачерчивав": ["зачерчивавши"],
    "зачерчивавши": ["зачерчивав"],
    "зачесав": ["зачесавши"],
    "зачесавши": ["зачесав"],
    "зачесалася пизда": ["чешется манда", "горит пизда", "чешется пиздища", "чешется пиздище", "раззуделася пизда", "пизда чешется", "пизда горит"],
    "зачесться": ["засчитаться"],
    "зачехлив": ["зачехливши"],
    "зачехливши": ["зачехлив"],
    "зачехляв": ["зачехлявши"],
    "зачехлявши": ["зачехляв"],
    "зачехлять": ["чехлить"],
    "зачивикав": ["зачивикавши"],
    "зачивикавши": ["зачивикав"],
    "зачиликав": ["зачиликавши"],
    "зачиликавши": ["зачиликав"],
    "зачин": ["начало", "почин"],
    "зачинав": ["зачинавши"],
    "зачинавши": ["зачинав"],
    "зачинатель": ["основоположник", "инициатор"],
    "зачинив": ["зачинивши"],
    "зачинивав": ["зачинивавши"],
    "зачинивавши": ["зачинивав"],
    "зачинивши": ["зачинив"],
    "зачинщик": ["закопёрщик", "инициатор"],
    "зачипировав": ["зачипировавши"],
    "зачипировавши": ["зачипировав"],
    "зачирикав": ["зачирикавши"],
    "зачирикавши": ["зачирикав"],
    "зачирикать": ["запеть", "заиграть", "замалевать", "зарисовать", "исчирикать"],
    "зачиркав": ["зачиркавши"],
    "зачиркавши": ["зачиркав"],
    "зачислив": ["зачисливши"],
    "зачисливши": ["зачислив"],
    "зачисляв": ["зачислявши"],
    "зачислявши": ["зачисляв"],
    "зачистив": ["зачистивши"],
    "зачистивши": ["зачистив"],
    "зачитав": ["зачитавши"],
    "зачитавши": ["зачитав"],
    "зачитывав": ["зачитывавши"],
    "зачитывавши": ["зачитывав"],
    "зачихав": ["зачихавши"],
    "зачихавши": ["зачихав"],
    "зачичеревев": ["зачичеревевши"],
    "зачичеревевши": ["зачичеревев"],
    "зачищав": ["зачищавши"],
    "зачищавши": ["зачищав"],
    "зачмокав": ["зачмокавши"],
    "зачмокавши": ["зачмокав"],
    "зачморив": ["зачморивши"],
    "зачморивши": ["зачморив"],
    "зачокав": ["зачокавши"],
    "зачокавши": ["зачокав"],
    "зачугунев": ["зачугуневши"],
    "зачугуневши": ["зачугунев"],
    "зачудив": ["зачудивши"],
    "зачудивши": ["зачудив"],
    "зачумлённый": ["очумевший", "очумелый"],
    "зачуфыриться": ["заспесивиться", "зачваниться", "зачуфариться", "зачичвариться"],
    "зачухав": ["зачухавши"],
    "зачухавши": ["зачухав"],
    "зачуханный": ["грязный", "неопрятный", "истрёпанный", "неприглядный", "невзрачный", "замотанный", "занюханный", "малокультурный", "провинциальный", "опустившийся"],
    "зачуяв": ["зачуявши"],
    "зачуявши": ["зачуяв"],
    "зачъе": ["боцъо"],
    "зачёркивав": ["зачёркивавши"],
    "зачёркивавши": ["зачёркивав"],
    "зачёркивать": ["перечёркивать", "сводить на нет"],
    "зачёсывав": ["зачёсывавши"],
    "зачёсывавши": ["зачёсывав"],
    "зачёт": ["отметка", "итог", "расчёт"],
    "зачётка": ["зачётная книжка", "матрикул"],
    "зачётная книжка": ["зачётка"],
    "зашабашив": ["зашабашивши"],
    "зашабашивши": ["зашабашив"],
    "зашагав": ["зашагавши"],
    "зашагавши": ["зашагав"],
    "зашагивав": ["зашагивавши"],
    "зашагивавши": ["зашагивав"],
    "зашагнув": ["зашагнувши"],
    "зашагнувши": ["зашагнув"],
    "зашалив": ["зашаливши"],
    "зашаливши": ["зашалив"],
    "зашаманствовав": ["зашаманствовавши"],
    "зашаманствовавши": ["зашаманствовав"],
    "зашамкав": ["зашамкавши"],
    "зашамкавши": ["зашамкав"],
    "зашарив": ["зашаривши"],
    "зашаривши": ["зашарив"],
    "зашаркав": ["зашаркавши"],
    "зашаркавши": ["зашаркав"],
    "зашаркивав": ["зашаркивавши"],
    "зашаркивавши": ["зашаркивав"],
    "зашарпав": ["зашарпавши"],
    "зашарпавши": ["зашарпав"],
    "зашатав": ["зашатавши"],
    "зашатавши": ["зашатав"],
    "зашататься": ["закачаться"],
    "зашвартовав": ["зашвартовавши"],
    "зашвартовавши": ["зашвартовав"],
    "зашвартовывав": ["зашвартовывавши"],
    "зашвартовывавши": ["зашвартовывав"],
    "зашвартовывание": ["швартовка"],
    "зашвыривав": ["зашвыривавши"],
    "зашвыривавши": ["зашвыривав"],
    "зашвырнув": ["зашвырнувши"],
    "зашвырнувши": ["зашвырнув"],
    "зашвыряв": ["зашвырявши"],
    "зашвырявши": ["зашвыряв"],
    "зашебаршив": ["зашебаршивши"],
    "зашебаршивши": ["зашебаршив"],
    "зашебуршав": ["зашебуршавши"],
    "зашебуршавши": ["зашебуршав"],
    "зашевелив": ["зашевеливши"],
    "зашевеливши": ["зашевелив"],
    "зашед": ["зайдя", "зашедши"],
    "зашедши": ["зайдя", "зашед"],
    "зашеина": ["зашеек"],
    "зашелестев": ["зашелестевши"],
    "зашелестевши": ["зашелестев"],
    "зашелестив": ["зашелестивши"],
    "зашелестивши": ["зашелестив"],
    "зашелохнув": ["зашелохнувши"],
    "зашелохнувши": ["зашелохнув"],
    "зашелудивев": ["зашелудивевши"],
    "зашелудивевши": ["зашелудивев"],
    "зашелушив": ["зашелушивши"],
    "зашелушивши": ["зашелушив"],
    "зашепелявив": ["зашепелявивши"],
    "зашепелявивши": ["зашепелявив"],
    "зашептав": ["зашептавши"],
    "зашептавши": ["зашептав"],
    "зашершавев": ["зашершавевши"],
    "зашершавевши": ["зашершавев"],
    "зашибав": ["зашибавши"],
    "зашибавши": ["зашибав"],
    "зашибать": ["ушибать", "убивать", "ошеломлять", "поражать", "шокировать", "зарабатывать"],
    "зашибив": ["зашибивши"],
    "зашибивши": ["зашибив"],
    "зашибись": ["отлично", "великолепно", "прекрасно", "славно"],
    "зашив": ["зашивши"],
    "зашивав": ["зашивавши"],
    "зашивавши": ["зашивав"],
    "зашивши": ["зашив"],
    "зашигать": ["гонять"],
    "зашикав": ["зашикавши"],
    "зашикавши": ["зашикав"],
    "зашикивав": ["зашикивавши"],
    "зашикивавши": ["зашикивав"],
    "зашипев": ["зашипевши"],
    "зашипевши": ["зашипев"],
    "заширяв": ["заширявши"],
    "заширявши": ["заширяв"],
    "зашить": ["забить", "заколотить"],
    "зашифровав": ["зашифровавши"],
    "зашифровавши": ["зашифровав"],
    "зашифрованный": ["кодированный", "криптический"],
    "зашифровать": ["закодировать"],
    "зашифровка": ["зашифровывание"],
    "зашифровывав": ["зашифровывавши"],
    "зашифровывавши": ["зашифровывав"],
    "зашифровывание": ["зашифровка"],
    "зашкал": ["зашкаливание"],
    "зашкалив": ["зашкаливши"],
    "зашкаливав": ["зашкаливавши"],
    "зашкаливавши": ["зашкаливав"],
    "зашкаливши": ["зашкалив"],
    "зашкандыбав": ["зашкандыбавши"],
    "зашкандыбавши": ["зашкандыбав"],
    "зашквар": ["стыд", "позор"],
    "зашкварив": ["зашкваривши"],
    "зашкваривши": ["зашкварив"],
    "зашкварить": ["осквернить"],
    "зашквариться": ["опозориться", "оскверниться", "законтачиться"],
    "зашкериться": ["зашхериться"],
    "зашкурив": ["зашкуривши"],
    "зашкуривши": ["зашкурив"],
    "зашлаковав": ["зашлаковавши"],
    "зашлаковавши": ["зашлаковав"],
    "зашлаковывав": ["зашлаковывавши"],
    "зашлаковывавши": ["зашлаковывав"],
    "зашлаченный": ["зашлакованный"],
    "зашлифовав": ["зашлифовавши"],
    "зашлифовавши": ["зашлифовав"],
    "зашлифовывав": ["зашлифовывавши"],
    "зашлифовывавши": ["зашлифовывав"],
    "зашлюндав": ["зашлюндавши"],
    "зашлюндавши": ["зашлюндав"],
    "зашлюндать": ["извозюкать"],
    "зашлёпав": ["зашлёпавши"],
    "зашлёпавши": ["зашлёпав"],
    "зашлёпывав": ["зашлёпывавши"],
    "зашлёпывавши": ["зашлёпывав"],
    "зашмыгав": ["зашмыгавши"],
    "зашмыгавши": ["зашмыгав"],
    "зашнуровав": ["зашнуровавши"],
    "зашнуровавши": ["зашнуровав"],
    "зашнуровывав": ["зашнуровывавши"],
    "зашнуровывавши": ["зашнуровывав"],
    "зашнуровывание": ["шнурование"],
    "зашнуровывать": ["шнуровать"],
    "зашнуровывающий": ["шнурующий"],
    "зашнырив": ["зашныривши"],
    "зашныривши": ["зашнырив"],
    "зашныряв": ["зашнырявши"],
    "зашнырявши": ["зашныряв"],
    "зашорив": ["зашоривши"],
    "зашоривши": ["зашорив"],
    "зашпаклевав": ["зашпаклевавши"],
    "зашпаклевавши": ["зашпаклевав"],
    "зашпаклевать": ["зашпатлевать"],
    "зашпаклёвывав": ["зашпаклёвывавши"],
    "зашпаклёвывавши": ["зашпаклёвывав"],
    "зашпандорив": ["зашпандоривши"],
    "зашпандоривав": ["зашпандоривавши"],
    "зашпандоривавши": ["зашпандоривав"],
    "зашпандоривши": ["зашпандорив"],
    "зашпаривав": ["зашпаривавши"],
    "зашпаривавши": ["зашпаривав"],
    "зашпатлевав": ["зашпатлевавши"],
    "зашпатлевавши": ["зашпатлевав"],
    "зашпиговав": ["зашпиговавши"],
    "зашпиговавши": ["зашпиговав"],
    "зашпилив": ["зашпиливши"],
    "зашпиливав": ["зашпиливавши"],
    "зашпиливавши": ["зашпиливав"],
    "зашпиливши": ["зашпилив"],
    "зашпионив": ["зашпионивши"],
    "зашпионивши": ["зашпионив"],
    "зашплинтовав": ["зашплинтовавши"],
    "зашплинтовавши": ["зашплинтовав"],
    "зашплинтовывав": ["зашплинтовывавши"],
    "зашплинтовывавши": ["зашплинтовывав"],
    "зашпунтовав": ["зашпунтовавши"],
    "зашпунтовавши": ["зашпунтовав"],
    "зашпунтовывав": ["зашпунтовывавши"],
    "зашпунтовывавши": ["зашпунтовывав"],
    "зашпыняв": ["зашпынявши"],
    "зашпынявши": ["зашпыняв"],
    "заштабелевав": ["заштабелевавши"],
    "заштабелевавши": ["заштабелевав"],
    "заштабелировав": ["заштабелировавши"],
    "заштабелировавши": ["заштабелировав"],
    "заштабелёвывав": ["заштабелёвывавши"],
    "заштабелёвывавши": ["заштабелёвывав"],
    "заштамповав": ["заштамповавши"],
    "заштамповавши": ["заштамповав"],
    "заштамповывав": ["заштамповывавши"],
    "заштамповывавши": ["заштамповывав"],
    "заштатный": ["внештатный", "сверхштатный", "второстепенный", "заурядный", "обыкновенный", "посредственный"],
    "заштемпелевав": ["заштемпелевавши"],
    "заштемпелевавши": ["заштемпелевав"],
    "заштемпелёвывав": ["заштемпелёвывавши"],
    "заштемпелёвывавши": ["заштемпелёвывав"],
    "заштилев": ["заштилевши"],
    "заштилевав": ["заштилевавши"],
    "заштилевавши": ["заштилевав"],
    "заштилевши": ["заштилев"],
    "заштилеть": ["утихнуть"],
    "заштопав": ["заштопавши"],
    "заштопавши": ["заштопав"],
    "заштопывав": ["заштопывавши"],
    "заштопывавши": ["заштопывав"],
    "зашторив": ["зашторивши"],
    "зашторивав": ["зашторивавши"],
    "зашторивавши": ["зашторивав"],
    "зашторивши": ["зашторив"],
    "зашторить": ["занавесить"],
    "заштормив": ["заштормивши"],
    "заштормивши": ["заштормив"],
    "заштормовав": ["заштормовавши"],
    "заштормовавши": ["заштормовав"],
    "заштриховав": ["заштриховавши"],
    "заштриховавши": ["заштриховав"],
    "заштриховывав": ["заштриховывавши"],
    "заштриховывавши": ["заштриховывав"],
    "заштукатурив": ["заштукатуривши"],
    "заштукатуривав": ["заштукатуривавши"],
    "заштукатуривавши": ["заштукатуривав"],
    "заштукатуривши": ["заштукатурив"],
    "заштуковав": ["заштуковавши"],
    "заштуковавши": ["заштуковав"],
    "заштуковывав": ["заштуковывавши"],
    "заштуковывавши": ["заштуковывав"],
    "зашугав": ["зашугавши"],
    "зашугавши": ["зашугав"],
    "зашугать": ["запугать"],
    "зашумев": ["зашумевши"],
    "зашумевши": ["зашумев"],
    "зашуметь": ["загреметь", "загудеть", "загалдеть", "затуманиться", "поплыть", "защекотать", "забуянить", "заскандалить"],
    "зашуметься": ["загамиться"],
    "зашунтировав": ["зашунтировавши"],
    "зашунтировавши": ["зашунтировав"],
    "зашуршав": ["зашуршавши"],
    "зашуршавши": ["зашуршав"],
    "зашутив": ["зашутивши"],
    "зашутивши": ["зашутив"],
    "зашухерив": ["зашухеривши"],
    "зашухеривши": ["зашухерив"],
    "зашушукав": ["зашушукавши"],
    "зашушукавши": ["зашушукав"],
    "зашёптывав": ["зашёптывавши"],
    "зашёптывавши": ["зашёптывав"],
    "защебенив": ["защебенивши"],
    "защебенивав": ["защебенивавши"],
    "защебенивавши": ["защебенивав"],
    "защебенивши": ["защебенив"],
    "защебетав": ["защебетавши"],
    "защебетавши": ["защебетав"],
    "защеголяв": ["защеголявши"],
    "защеголявши": ["защеголяв"],
    "защекан": ["защеканец", "вафлист", "вафлёр", "молофья"],
    "защеканец": ["минетчик", "вафлёр", "защекан", "хуесос", "хуеглот"],
    "защекотав": ["защекотавши"],
    "защекотавши": ["защекотав"],
    "защекотив": ["защекотивши"],
    "защекотивши": ["защекотив"],
    "защелачивав": ["защелачивавши"],
    "защелачивавши": ["защелачивав"],
    "защемив": ["защемивши"],
    "защемивши": ["защемив"],
    "защемляв": ["защемлявши"],
    "защемлявши": ["защемляв"],
    "защепав": ["защепавши"],
    "защепавши": ["защепав"],
    "защепив": ["защепивши"],
    "защепивши": ["защепив"],
    "защепляв": ["защеплявши"],
    "защеплявши": ["защепляв"],
    "защип": ["защипка", "защипывание"],
    "защипав": ["защипавши"],
    "защипавши": ["защипав"],
    "защипив": ["защипивши"],
    "защипивши": ["защипив"],
    "защипнув": ["защипнувши"],
    "защипнувши": ["защипнув"],
    "защипывав": ["защипывавши"],
    "защипывавши": ["защипывав"],
    "защита": ["оборона"],
    "защитеност": ["безопасност", "сигурност"],
    "защитив": ["защитивши"],
    "защитивши": ["защитив"],
    "защитимый": ["защищённый", "оборонимый"],
    "защитить": ["уберечь"],
    "защитник": ["оборонитель", "бек", "адвокат"],
    "защитное стекло": ["защитка"],
    "защитный": ["хаки", "травянисто-зелёный"],
    "защищав": ["защищавши"],
    "защищавши": ["защищав"],
    "защищать": ["охранять", "оберегать", "оборонять", "защищаться"],
    "защищенье": ["защищение"],
    "защищённость": ["неуязвимость"],
    "защупав": ["защупавши"],
    "защупавши": ["защупав"],
    "защурив": ["защуривши"],
    "защуривав": ["защуривавши"],
    "защуривавши": ["защуривав"],
    "защуривать": ["зажмуривать"],
    "защуриваться": ["зажмуриваться"],
    "защуривши": ["защурив"],
    "защуриться": ["зажмуриться"],
    "защучив": ["защучивши"],
    "защучивши": ["защучив"],
    "защёлкав": ["защёлкавши"],
    "защёлкавши": ["защёлкав"],
    "защёлкивав": ["защёлкивавши"],
    "защёлкивавши": ["защёлкивав"],
    "защёлкнув": ["защёлкнувши"],
    "защёлкнувши": ["защёлкнув"],
    "заэкранировав": ["заэкранировавши"],
    "заэкранировавши": ["заэкранировав"],
    "заэтовать": ["заэтывать"],
    "заюзав": ["заюзавши"],
    "заюзавши": ["заюзав"],
    "заюзать": ["использовать"],
    "заюлив": ["заюливши"],
    "заюливши": ["заюлив"],
    "зая": ["заяц", "зайка", "зайчик", "заинька", "лапочка", "гуля", "солнышко", "милый", "милая"],
    "заябать": ["засношать", "задолбать", "задрать", "затрахать", "достать", "заколебать", "заманать", "остоебенить", "остоёбнуть", "остопиздить", "настоебать", "настоёбнуть", "остохуеть", "одержать верх"],
    "заява": ["заявление"],
    "заявив": ["заявивши"],
    "заявивши": ["заявив"],
    "заявитель": ["заявщик"],
    "заявка": ["заявление", "запрос"],
    "заявление": ["декларация", "провозглашение", "декларирование"],
    "заявляв": ["заявлявши"],
    "заявлявши": ["заявляв"],
    "заявлять": ["сообщать", "объявлять", "предъявлять"],
    "заядлый": ["завзятый", "азартный", "рьяный", "страстный"],
    "заякорив": ["заякоривши"],
    "заякоривав": ["заякоривавши"],
    "заякоривавши": ["заякоривав"],
    "заякоривание": ["заякориванье"],
    "заякориванье": ["заякоривание"],
    "заякоривши": ["заякорив"],
    "заяривав": ["заяривавши"],
    "заяривавши": ["заяривав"],
    "заяснев": ["заясневши"],
    "заясневши": ["заяснев"],
    "заяснеть": ["заясниться"],
    "заяснить": ["пояснить", "объяснить", "втолковать"],
    "заясниться": ["заяснеть"],
    "заяснять": ["пояснять", "объяснять", "втолковывать"],
    "заяц": ["косой", "серый", "зайчатина", "безбилетник"],
    "заячина": ["зайчатина"],
    "заячья капуста": ["валериана", "кислец", "фиалка"],
    "заёб": ["придурь", "заскок", "ерунда", "чепуха", "заёба", "усталость", "опустошённость", "муштра", "муштровка"],
    "заёба": ["подруга", "подружка", "любовница", "милка", "милашка", "ухажёрка", "заёбушка"],
    "заёбанный": ["затраханный", "задроченный", "замученный", "замызганный", "задрипанный", "усталый", "утомлённый", "измученный", "умученный"],
    "заёбисто": ["ёбко", "сексапильно", "задиристо", "драчливо", "упрямо", "неуступчиво", "настырно"],
    "заёбистый": ["ёбкий", "сексапильный", "задиристый", "драчливый", "упрямый", "неуступчивый", "настырный"],
    "заёбывав": ["заёбывавши"],
    "заёбывавши": ["заёбывав"],
    "заёкав": ["заёкавши"],
    "заёкавши": ["заёкав"],
    "заём": ["кредит", "ссуда", "брать", "взять", "займ"],
    "заёрзав": ["заёрзавши"],
    "заёрзавши": ["заёрзав"],
    "збагнути": ["здогадатися"],
    "збитень": ["сбитень"],
    "зблажэць": ["схуднець", "змарнець", "схудзець", "высахнуць", "выпетраць"],
    "звав": ["звавши"],
    "звавши": ["звав"],
    "зважувати": ["виважувати"],
    "званивав": ["званивавши"],
    "званивавши": ["званивав"],
    "звание": ["чин", "титул"],
    "званый": ["приглашённый"],
    "званый ужин": ["званый обед"],
    "звательный падеж": ["вокатив"],
    "звательце": ["тонкое придыхание", "звательцо"],
    "звать": ["подзывать", "призывать", "кликать", "окликать", "именовать", "называть", "величать", "приглашать"],
    "зваться": ["называться", "именоваться"],
    "звезданув": ["звезданувши"],
    "звезданувши": ["звезданув"],
    "звезданутый": ["эксцентричный"],
    "звездануть": ["заехать", "треснуть", "грохнуть"],
    "звездеть": ["пиздеть"],
    "звездец": ["песец"],
    "звездив": ["звездивши"],
    "звездивши": ["звездив"],
    "звездины": ["красные крестины"],
    "звездистый": ["звёздный", "искрящийся", "блестящий", "звездообразный"],
    "звездить": ["выпендриваться"],
    "звездолёт": ["астроплан", "звездоплан", "космический аппарат", "космический корабль", "ракета"],
    "звездолётчик": ["космонавт"],
    "звездомания": ["звёздная болезнь"],
    "звездонос": ["звездорыл"],
    "звездоносец": ["орденоносец"],
    "звездопад": ["звёздный дождь", "метеорный поток"],
    "звездоплаванье": ["звездоплавание"],
    "звездоплаватель": ["космонавт"],
    "звездоплан": ["звездолёт"],
    "звездопоклонник": ["астролатр", "астроспейсор"],
    "звездорыл": ["звездонос"],
    "звездулька": ["звездунья"],
    "звездунья": ["звездулька"],
    "звездюли": ["пиздюли"],
    "звездёж": ["враньё", "брехня", "пиздёж"],
    "звенев": ["звеневши"],
    "звеневши": ["звенев"],
    "звено": ["кольцо", "группа", "команда", "бригада", "венец", "рельсошпальная решётка"],
    "звеновик": ["бригадир"],
    "звеньевой уголок": ["красный уголок"],
    "звенькав": ["звенькавши"],
    "звенькавши": ["звенькав"],
    "зверем смотреть": ["смотреть зверем", "смотреть волком", "волком смотреть"],
    "зверетина": ["зверище", "зверилище"],
    "звереть": ["оскотиниваться", "свирепеть"],
    "зверив": ["зверивши"],
    "зверивши": ["зверив"],
    "зверий": ["звериный"],
    "зверилница": ["менажерия", "зоологическа градина"],
    "зверинец": ["зоопарк", "зоосад"],
    "звериный": ["животный", "зверий", "зверский", "бесчеловечный", "безжалостный", "адский", "чрезвычайный", "чрезмерный"],
    "зверища": ["зверина"],
    "зверище": ["зверилище"],
    "зверовав": ["зверовавши"],
    "зверовавши": ["зверовав"],
    "зверовидный": ["зверообразный", "звероподобный"],
    "зверовод": ["разводчик"],
    "зверовой": ["звериный", "звероловный"],
    "зверок": ["зверёк"],
    "звероногий": ["теропод"],
    "звероподобно": ["зверски", "по-звериному"],
    "зверосовхоз": ["звероводческий", "совхоз", "зверохозяйство"],
    "зверски": ["звероподобно", "бесчеловечно", "жестоко", "садистски", "жутко", "страшно"],
    "зверский": ["звериный", "безжалостный", "садистский", "жуткий", "сильнейший", "чрезвычайный"],
    "зверство": ["жестокость", "бесчеловечность", "садизм", "изуверство"],
    "зверствовав": ["зверствовавши"],
    "зверствовавши": ["зверствовав"],
    "зверушка": ["зверюшка"],
    "зверщина": ["зверство", "диващина", "скотщина", "безчовечие", "жестокост"],
    "зверьё": ["животные", "садист", "негодяй"],
    "зверюшка": ["зверушка"],
    "зверёк": ["зверушка", "зверюшка"],
    "зверёнок": ["зверёныш"],
    "звитяга": ["перемога"],
    "звон": ["трезвон", "гудение", "шум", "шумиха"],
    "звонарь": ["звонец"],
    "звонец": ["погремок", "бубенчик"],
    "звонив": ["звонивши"],
    "звонивши": ["звонив"],
    "звонить": ["звенеть", "вызывать", "трезвонить"],
    "звонить во все колокола": ["трезвонить"],
    "звонкий": ["звучный"],
    "звонко": ["звучно"],
    "звонкоголосный": ["звонкоголосый"],
    "звонкоголосый": ["звонкоголосный", "звонкий"],
    "звонницкий": ["колокольный"],
    "звончатость": ["звучность", "звонкость"],
    "звончатый": ["звучный", "звонкий"],
    "звр": ["золотовалютные резервы"],
    "звук": ["звучание", "аллофон"],
    "звуковая дорожка": ["саундтрек"],
    "звуковая карта": ["аудиоадаптер", "аудиокарта", "аудиоплата"],
    "звуковизор": ["эхограф"],
    "звукозащитный": ["звукоизоляционный", "звукоизолирующий"],
    "звукоизолировав": ["звукоизолировавши"],
    "звукоизолировавши": ["звукоизолировав"],
    "звукоизолирующий": ["звукоизоляционный"],
    "звукоизоляция": ["звукопоглощение", "шумоизоляция"],
    "звукопоглощаемость": ["звукопоглощение", "звукоизоляция"],
    "звукоподражание": ["ономатопея"],
    "звукопроводимость": ["звукопроводность"],
    "звукопроводность": ["звукопроводимость"],
    "звукоряд": ["полихорд"],
    "звукоулавливатель": ["звукоуловитель"],
    "звукофицировав": ["звукофицировавши"],
    "звукофицировавши": ["звукофицировав"],
    "звур": ["внутриутробная гипотрофия"],
    "звучав": ["звучавши"],
    "звучавши": ["звучав"],
    "звучание": ["смысл", "значение"],
    "звучанье": ["звучание"],
    "звучати": ["лунати"],
    "звучать": ["раздаваться", "слышаться"],
    "звучно": ["громко"],
    "звучный": ["громкий"],
    "звякав": ["звякавши"],
    "звякавши": ["звякав"],
    "звякание": ["брякание", "звяк", "бряканье", "звяканье"],
    "звяканье": ["брякание", "звякание", "звяк", "бряканье"],
    "звякнув": ["звякнувши"],
    "звякнувши": ["звякнув"],
    "звякнуть": ["прозвенеть", "брякнуть"],
    "звёзд с неба не хватает": ["посредственность"],
    "звёздно": ["искристо"],
    "звёздно-полосатый": ["американский"],
    "звёздные войны": ["стратегическая оборонная инициатива", "сои"],
    "звёздный": ["сидерический", "известный"],
    "звёздочка": ["астериск", "шестерёнка"],
    "здание": ["дом"],
    "здесь": ["тут", "туточки", "в этот момент", "при этом"],
    "здешний": ["местный"],
    "здзислав": ["здислав", "здзеслав"],
    "зди": ["завод деревоизделий"],
    "здороваться": ["здоровкаться", "ручкаться"],
    "здоровев": ["здоровевши"],
    "здоровевши": ["здоровев"],
    "здоровенный": ["здоровущий", "громадный", "гигантский", "крупный"],
    "здоровенький": ["здоровёшенький", "здоровёхонький"],
    "здорово": ["хорошо", "классно", "сильно"],
    "здоровский": ["клёвый", "офигенный"],
    "здоровско": ["классно", "клёво", "офигенно", "супер", "козырно", "зыбо", "здыбо"],
    "здоровущий": ["здоровенный"],
    "здоровъ": ["сторовъ"],
    "здоровый": ["крепкий", "крепкотелый", "выздоровевший", "цветущий", "полезный", "целебный", "благоразумный", "здравый", "дюжий", "здоровенный", "могучий", "мощный", "неутомимый", "ловкий", "искусный"],
    "здоровый образ жизни": ["зож"],
    "здоровье": ["здравие", "здравье"],
    "здоровьечко": ["здоровье"],
    "здоровьице": ["здоровьечко"],
    "здоровяга": ["здоровяк"],
    "здоровяк": ["крепыш", "громадина"],
    "здоровёхонький": ["здоровёшенький", "здоровенький"],
    "здоровёшенький": ["здоровёхонький", "здоровенький"],
    "здравие": ["здравье", "здоровье"],
    "здравина": ["издръжливост", "крепкост"],
    "здравица": ["заздравица", "заздравный тост"],
    "здравница": ["лечебница", "курорт", "здравица"],
    "здравомыслие": ["рассудительность", "ум"],
    "здравоохранение": ["охрана здоровья"],
    "здравствовав": ["здравствовавши"],
    "здравствовавши": ["здравствовав"],
    "здравствовать": ["процветать"],
    "здравствуйте": ["здравствуйте пожалуйста", "приехали"],
    "здравый": ["разумный", "толковый", "осмысленный"],
    "здравый смысл": ["здравомыслие", "рассудительность"],
    "здравье": ["здравие", "здоровье"],
    "здрасьте": ["здравствуйте", "привет", "здрасте"],
    "здрач": ["мрачина", "мрачевина", "сумрак"],
    "зебра": ["пешеходный переход"],
    "зев": ["зёв", "глотка", "пасть", "рот", "хайло", "устье", "вход", "жерло"],
    "зевав": ["зевавши"],
    "зевавши": ["зевав"],
    "зевака": ["ротозей"],
    "зеванув": ["зеванувши"],
    "зеванувши": ["зеванув"],
    "зевгма": ["силлепс"],
    "зевес": ["зевс"],
    "зевзек": ["шегобиец", "шегаджия", "присмехулник", "присмехулко", "подигравач", "духовит"],
    "зевник": ["зёвник"],
    "зевнув": ["зевнувши"],
    "зевнуть": ["прозевать"],
    "зевный": ["фаукальный"],
    "зевота": ["зевание"],
    "зевс": ["зевес", "юпитер"],
    "зегзица": ["кукушка"],
    "зедонк": ["зонк", "зонки", "ослозебра"],
    "зейгеровав": ["зейгеровавши"],
    "зейгеровавши": ["зейгеровав"],
    "зейдит": ["зайдит"],
    "зек": ["зэка", "заключённый", "осуждённый", "узник", "зк"],
    "зека": ["заключённый", "зэк", "зек", "зэка"],
    "зекономити": ["заощадити"],
    "зеленев": ["зеленевши"],
    "зеленевши": ["зеленев"],
    "зеленеться": ["зеленеть"],
    "зеленив": ["зеленивши"],
    "зеленивши": ["зеленив"],
    "зелений дятел": ["жовна"],
    "зеленная": ["овощная лавка", "овощная", "овощной", "зеленная лавка"],
    "зеленчук": ["зеленчук жёлтый", "зеленчук обыкновенный", "яснотка зеленчуковая"],
    "зелень бриллиантовая": ["зелёнка"],
    "зеленёхонький": ["зеленёшенький"],
    "зеленёшенький": ["зеленёхонький"],
    "зело": ["очень", "оченно", "дюже", "вельми", "чересчур", "чрезмерно", "излишне", "слишком", "сильно", "шибко", "весьма", "больно", "сверх меры", "избыточно", "чрезвычайно"],
    "зелье": ["снадобье", "эликсир"],
    "зельеварение": ["зельеваренье"],
    "зельеваренье": ["зельеварение"],
    "зельтерская": ["сельтерская", "минералка"],
    "зелёнка": ["камуфляж", "камуфляжка", "камуфло", "комок", "доллар", "бакс", "бак", "грин", "зелень", "капуста", "бакинский", "зелёный", "вечнозелёный", "валютная проститутка", "интердевочка"],
    "зелёно-жёлтый": ["зеленовато-жёлтый", "жёлто-зеленоватый", "жёлто-зелёный"],
    "зелёное": ["зелёное вино", "зелено вино"],
    "зелёное масло": ["конопляное масло"],
    "зелёное удобрение": ["травяная бродилка"],
    "зелёные человечки": ["пришелец", "инопланетянин", "вежливые люди"],
    "зелёные щи": ["крапивные щи"],
    "зелёный вездеход": ["доллар сша", "грин", "зелёный", "вечнозелёный", "вечно зелёный", "зелень", "капуста", "бакс"],
    "зелёный змей": ["алкоголь", "алкоголизм", "зелёный змий"],
    "зелёный камуфляж": ["гринвошинг"],
    "зелёный континент": ["австралия"],
    "зелёный стол": ["ломберный стол"],
    "земгале": ["земгалия", "семигалия"],
    "земгалия": ["земгале", "семигалия"],
    "земельно-имущественный": ["имущественно-земельный"],
    "земеля": ["земляк", "зёма"],
    "земледелец": ["землепашец", "крестьянин", "земледелатель"],
    "земледелие": ["агрокультура", "агрикультура", "земледелье"],
    "земледелье": ["земледелие"],
    "земледельческий": ["аграрный", "агрикультурный"],
    "землемер": ["геодезист"],
    "землемерие": ["геометрия"],
    "землеописание": ["география"],
    "землепашеский": ["земледельческий"],
    "землепашец": ["земледелец", "пахарь"],
    "землесос": ["грунтовой насос", "землесосный снаряд"],
    "землетрясенье": ["землетрясение"],
    "землечерпательный": ["землечерпальный"],
    "земли луары": ["пеи-де-ла-луар"],
    "земличка": ["землица"],
    "землища": ["почва"],
    "земля обетованная": ["обетованный край", "рай"],
    "земля пухом": ["пусть земля будет пухом"],
    "земля стекловатой": ["земля бетоном"],
    "земля тысячи холмов": ["руанда"],
    "земляк": ["единоземец", "зёма", "земеля", "одноземец"],
    "землянин": ["земледелец", "крестьянин"],
    "земляничка": ["земляниченька"],
    "земляное яблоко": ["картофель"],
    "земляной орех": ["арахис"],
    "земноводное": ["амфибия"],
    "земноводный": ["водоземный"],
    "земной рай": ["рай земной", "обратный порядок слов"],
    "земнородный": ["смертный"],
    "земобилизация": ["бусификация"],
    "земфира": ["замфира"],
    "зендавеста": ["зенд-авеста", "зенд авеста"],
    "зенит": ["зениф", "апогей", "апофеоз", "вершина"],
    "зенитка": ["зенитное орудие"],
    "зенитный ракетный комплекс": ["зрк"],
    "зенитовец": ["зенитчик"],
    "зенитчик": ["зенитовец"],
    "зеница": ["зрачок", "глаз"],
    "зенкер": ["зенкерный инструмент"],
    "зенкеровав": ["зенкеровавши"],
    "зенкеровавши": ["зенкеровав"],
    "зенкеровка": ["зенкерование"],
    "зенки": ["глаза", "очи", "зеницы"],
    "зенковав": ["зенковавши"],
    "зенковавши": ["зенковав"],
    "зенковка": ["зенкование"],
    "зепь": ["кошель"],
    "зеравшан": ["матча", "акдарья", "каракульдарья", "тайкыр", "сарибазар", "дайтья", "политимет", "нами", "намик", "немахья"],
    "зерафшан": ["зарафшан", "зеравшан"],
    "зерван": ["зурван", "зрван"],
    "зерванизм": ["зрванизм", "зурванизм"],
    "зеркалив": ["зеркаливши"],
    "зеркаливши": ["зеркалив"],
    "зеркалировав": ["зеркалировавши"],
    "зеркалировавши": ["зеркалировав"],
    "зеркалировать": ["зеркалить"],
    "зеркалить": ["отражать", "подражать", "зеркалировать"],
    "зеркалка": ["зеркальная камера", "зеркальный фотоаппарат"],
    "зеркало": ["тувалет", "отражатель", "рефлектор", "поверхность", "гладь", "отражение"],
    "зернив": ["зернивши"],
    "зернивши": ["зернив"],
    "зернистый": ["зерновой", "крупяной", "зернёный", "гранулярный", "шероховатый"],
    "зернить": ["зерновать", "гранулировать"],
    "зерно": ["гранула", "частица", "зернистость", "изюминка"],
    "зерновоз": ["зерновозка"],
    "зерновозка": ["зерновоз"],
    "зерновые": ["зерновая культура"],
    "зерносеющий": ["зернопроизводящий"],
    "зерноторговля": ["хлеботорговля"],
    "зерноуборочный комбайн": ["хлебоуборочный комбайн"],
    "зернь": ["грануляция"],
    "зернёный": ["гранулированный"],
    "зеро": ["ноль", "нуль", "никто", "ничто", "ничтожество", "никчемность", "ноль без палочки", "пустышка", "пустое место", "пешка", "сошка", "мелкая сошка", "старший помощник младшего дворника", "шваль", "шушваль"],
    "зерцало": ["зеркало", "отражение"],
    "зерцаловидный": ["зеркальный"],
    "зетта-": ["гепта-"],
    "зеэр": ["зыкъым"],
    "зжм": ["западный"],
    "зиверт": ["зв"],
    "зиг": ["зиговка"],
    "зиг-машина": ["зиговочная машина"],
    "зигзаг": ["загогулина", "буква зю", "зигзуг"],
    "зигзиця": ["зозуля"],
    "зигмашина": ["зиговочная машина"],
    "зиговав": ["зиговавши"],
    "зиговавши": ["зиговав"],
    "зиговать": ["кидать зигу"],
    "зиговка": ["зиг"],
    "зигомаксиллярный": ["зигомаксилярный"],
    "зигомёт": ["нацик", "нацист"],
    "зигфрид": ["сигурд"],
    "зид": ["стена"],
    "зидар": ["каменоделец", "каменар"],
    "зидарь": ["каменщик"],
    "зидж": ["таблицы", "каталог"],
    "зиждемый": ["основываемый", "созидаемый", "воздвигаемый"],
    "зиждение": ["созидание"],
    "зижденье": ["зиждение"],
    "зиждив": ["зиждивши"],
    "зиждивши": ["зиждив"],
    "зиждимый": ["основываемый", "созидаемый", "воздвигаемый"],
    "зиждитель": ["создатель", "творец", "основатель", "бог"],
    "зиждить": ["создавать", "созидать", "творить", "строить", "возводить", "воздвигать", "основывать", "базировать"],
    "зиждиться": ["основываться", "опираться", "базироваться"],
    "зиждя": ["строя", "создавая", "созидая", "воздвигая", "основывая"],
    "зизания": ["цицания"],
    "зизифус": ["ююба", "китайский финик"],
    "зикршуда": ["зикрёфта"],
    "зикрёфта": ["зикршуда"],
    "зил": ["грузовик"],
    "зилзила": ["заминларза"],
    "зилот": ["зелот"],
    "зим": ["газ"],
    "зима": ["зимушка"],
    "зимбабве": ["республика зимбабве"],
    "зимбабвиец": ["родезиец"],
    "зимбабвийка": ["родезийка"],
    "зимний": ["холодный"],
    "зимник": ["зимница"],
    "зимняя спячка": ["гибернация", "спячка", "диапауза", "анабиоз"],
    "зимовав": ["зимовавши"],
    "зимовавши": ["зимовав"],
    "зимованье": ["зимование"],
    "зимовка": ["перезимовывание", "зимовье", "зимовище"],
    "зимовник": ["зимовка", "зимовье", "омшаник", "колхикум", "собачья смерть"],
    "зимовье": ["зимование", "зимовка", "зимовьё"],
    "зимоген": ["профермент"],
    "зимозиметр": ["квасомер", "кисломер", "зимометр"],
    "зимой": ["зимою"],
    "зимометр": ["зимозиметр"],
    "зимонька": ["зимушка"],
    "зимородок": ["алкион"],
    "зимородок-великан": ["кукабарра"],
    "зимостойкий": ["зимоустойчивый", "морозоустойчивый"],
    "зимоустойчивый": ["зимостойкий", "морозоустойчивый"],
    "зимою": ["зимой"],
    "зимушка": ["зимушка-зима", "зимонька"],
    "зина": ["зинапоя", "нардбон", "пиллагон"],
    "зинапоя": ["зина"],
    "зинзивер": ["просвирник", "проскурник"],
    "зинка": ["зина", "зинаида"],
    "зип": ["ремонтный комплект", "ремкомплект"],
    "зиплок": ["гриппер", "пакет-струна"],
    "зипун": ["чапан", "сермяга"],
    "зипунник": ["мужик"],
    "зира": ["ажгон", "кмин", "кумин", "римский тмин"],
    "зират": ["каберлек", "каберстан", "мазар"],
    "зирк": ["глядь", "глянь", "зырь", "зырк", "зырьк", "зирк-зирк", "зырк-зырк"],
    "зиск": ["прибуток"],
    "зита": ["дзета"],
    "зихер": ["подлость", "косяк", "ляп", "чп"],
    "зиц-председатель": ["зиц-директор", "номинальный директор", "зицпредседатель"],
    "зицпредседатель": ["зиц-председатель", "зиц-директор", "номинальный директор"],
    "зияв": ["зиявши"],
    "зиявши": ["зияв"],
    "зияние": ["пустота", "провал", "хиатус", "гиатус"],
    "зиянье": ["зияние"],
    "зиёуддин": ["зиёваддин", "зиёмуддин"],
    "зла не хватает": ["сыт по горло"],
    "злат": ["монета", "золотой", "злотый", "деньга"],
    "злата": ["хриса", "хрисия"],
    "златив": ["злативши"],
    "злативши": ["златив"],
    "златистый": ["золотистый"],
    "златиться": ["золотиться"],
    "злато": ["золото"],
    "златоглавый": ["москва", "столица"],
    "златогривый": ["золотогривый", "желтогривый"],
    "златокудрый": ["золотокудрый", "златоволосый", "златовласый"],
    "златокузнец": ["золотарь", "золотых дел мастер"],
    "златолобый": ["золотолобый"],
    "златолюбивый": ["сребролюбивый"],
    "златотканый": ["золототканый"],
    "златошвейный": ["золотошвейный"],
    "злачный": ["плодородный"],
    "злев": ["злевши"],
    "злевши": ["злев"],
    "злеть": ["озлобляться"],
    "злец": ["злюка", "злыдень"],
    "злива": ["хлющ"],
    "зливши": ["злив"],
    "зло": ["вред"],
    "злоба": ["злость", "ненависть", "гнев", "жестокость", "лютость", "свирепость", "безжалостность", "беспощадность", "нещадность", "кровожадность", "свирепство"],
    "злоба дня": ["повестка дня"],
    "злобив": ["злобивши"],
    "злобивши": ["злобив"],
    "злобить": ["бесить", "гневить", "злить"],
    "злобный": ["злой", "злостный", "яростный"],
    "злободневно": ["актуально"],
    "злободневность": ["насущность"],
    "злободневный": ["актуальный", "насущный"],
    "злобствовав": ["злобствовавши"],
    "злобствовавши": ["злобствовав"],
    "злобствовать": ["злиться", "злобиться"],
    "зловерный": ["злочестивый"],
    "зловоние": ["смрад", "вонь", "душок"],
    "зловонность": ["зловоние"],
    "зловонный": ["вонючий", "смердящий", "воняющий"],
    "зловонье": ["зловоние"],
    "зловред": ["вредонос", "компьютерный", "вредитель", "вредоносная программа", "зловредная программа", "малварь"],
    "злодей": ["лиходей", "преступник", "негодник"],
    "злодейка": ["лиходейка", "преступница"],
    "злодейски": ["преступно"],
    "злодействовав": ["злодействовавши"],
    "злодействовавши": ["злодействовав"],
    "злодеяние": ["злодейство", "преступление", "лиходейство"],
    "злоехидничав": ["злоехидничавши"],
    "злоехидничавши": ["злоехидничав"],
    "зложелательствовав": ["зложелательствовавши"],
    "зложелательствовавши": ["зложелательствовав"],
    "злоизвестный": ["одиозный"],
    "злой": ["дурной", "порочный", "сердитый", "недобрый", "лютый", "злобный", "губительный", "жестокий", "жгучий", "острый", "неистовый", "яростный"],
    "злой на язык": ["острый на язык"],
    "злой язык": ["острый язык"],
    "злоключение": ["беда", "неудача"],
    "злоключенье": ["злоключение"],
    "злокозненно": ["злонамеренно", "коварно"],
    "злокозненный": ["враждебный", "злобный", "злоковарный", "злостный", "злонамеренный", "злоумышленный", "злохитрый", "коварный", "недоброжелательный", "подлый"],
    "злонамеренный": ["злоумышленный"],
    "злонравие": ["безнравственность", "злобность"],
    "злопамятливый": ["злопамятный"],
    "злопамятный": ["мстительный", "мстивый", "заместчивый"],
    "злополучный": ["злосчастный", "бедственный", "невезучий", "несчастливый", "неудачливый"],
    "злополучье": ["злополучие"],
    "злопыхав": ["злопыхавши"],
    "злопыхавши": ["злопыхав"],
    "злопыхатель": ["ненавистник"],
    "злопыхательствовав": ["злопыхательствовавши"],
    "злопыхательствовавши": ["злопыхательствовав"],
    "злопыхать": ["злобствовать", "хейтствовать"],
    "злорадно": ["торжествующе", "ехидно"],
    "злорадствовав": ["злорадствовавши"],
    "злорадствовавши": ["злорадствовав"],
    "злоречивый": ["злоязыкий", "хулительный"],
    "злоречие": ["злоязычие"],
    "злоречье": ["злоречие"],
    "злословец": ["злоязычник", "злослов", "злословник"],
    "злословив": ["злословивши"],
    "злословивши": ["злословив"],
    "злословие": ["злоречие", "злоязычие", "злопыхательство", "поношение", "хула", "пересуд", "сплетня"],
    "злословить": ["клеветать", "клепать", "осуждать", "порицать"],
    "злословник": ["злоязычник", "злослов", "злословец"],
    "злословье": ["злословие"],
    "злостный": ["злобный"],
    "злосторник": ["пакостник", "вредител", "престъпник", "злодей"],
    "злострадание": ["любострадание"],
    "злость": ["злоба", "гнев", "озлобление", "ярость"],
    "злотворный": ["пагубный", "зловредный"],
    "злотоверхий": ["золотоверхий", "золотоголовий", "золотобанний"],
    "злотоглавий": ["парчевий"],
    "злоумышление": ["злой умысел"],
    "злоумышленный": ["злонамеренный"],
    "злоумышленье": ["злоумышление"],
    "злоумышляв": ["злоумышлявши"],
    "злоумышлявши": ["злоумышляв"],
    "злоупотреба": ["злоупотребление"],
    "злоупотребив": ["злоупотребивши"],
    "злоупотребивши": ["злоупотребив"],
    "злоупотребление": ["беззаконие", "преступление"],
    "злоупотребленье": ["злоупотребление"],
    "злоупотребляв": ["злоупотреблявши"],
    "злоупотреблявши": ["злоупотребляв"],
    "злочестина": ["злощастие", "злина", "злополучие", "несрета", "нещастие", "беда"],
    "злочинный": ["бесчинный"],
    "злоязыкий": ["злоязычный", "злоречивый"],
    "злоязычник": ["злословник", "злослов", "злословец"],
    "злоязычничав": ["злоязычничавши"],
    "злоязычничавши": ["злоязычничав"],
    "злоязычность": ["злоязыкость", "злоязыкатость"],
    "злоязычный": ["злоязыкий", "злоречивый"],
    "злъчност": ["жлъчност", "язвителност"],
    "злыдень": ["злыдарь", "злыдня", "злец", "злюка"],
    "злыдствовать": ["злыдничать", "злорадствовать"],
    "злюка": ["злючка", "злец", "злыдень"],
    "злючка": ["злюка"],
    "змарнець": ["схудзець", "схуднець", "высахнуць", "выпетраць"],
    "змеев": ["змеиный"],
    "змеевидный": ["змееподобный", "змееобразный", "змеистый", "змиевидный", "петляющий"],
    "змееобразный": ["змеевидный", "змеистый", "змееподобный"],
    "змеепитомник": ["серпентарий"],
    "змееподобный": ["змеевидный", "змеистый", "змееобразный", "змиеподобный"],
    "змеепоклонство": ["офиолатрия"],
    "змеехвостка": ["офиура"],
    "змеешейка": ["анхинга"],
    "змееяд": ["крачун", "орёл-змееяд"],
    "змеиная векша": ["вертячий чёрт", "вилюшка вертячий", "голова вертячая"],
    "змеистый": ["змеевидный", "змееобразный", "змееподобный"],
    "змеиться": ["извиваться", "виться"],
    "змей": ["змея", "дракон", "воздушный змей", "негодяй"],
    "змей горыныч": ["горыныч"],
    "змейка": ["большой", "дракончик", "морской дракончик", "змеёк", "змейка рубика", "змеица"],
    "змеюка": ["змея", "гадюка", "гад", "гадина"],
    "змеючий": ["змеиный"],
    "змеюшник": ["гадючник", "гадюшник", "тараканник"],
    "змея": ["гад", "аспид", "жена", "тёща"],
    "змея подколодная": ["гадюка подколодная"],
    "змеёй": ["змеевидно", "змееобразно", "змееподобно", "змеёю", "злобно", "неприязненно", "укоризненно"],
    "змеёнок": ["змеёныш"],
    "змеёныш": ["змеёнок", "гадёныш"],
    "змеёю": ["змеевидно", "змееобразно", "змееподобно", "змеёй"],
    "змога": ["знемажэнне", "знямога"],
    "змярканне": ["прыцемак"],
    "знав": ["знавши"],
    "знавав": ["знававши"],
    "знававши": ["знавав"],
    "знавши": ["знав"],
    "знайка": ["эрудит"],
    "знак": ["обозначение", "сема", "знамение", "цифра"],
    "знак вопроса": ["вопросительный знак"],
    "знак судьбы": ["перст судьбы"],
    "знакомец": ["приятель", "знакомый"],
    "знакомив": ["знакомивши"],
    "знакомивши": ["знакомив"],
    "знакомистый": ["ласковый", "вежливый", "обходительный", "доступный", "знакомитый", "известный", "знаемый", "ведомый", "знакомый"],
    "знакомитый": ["ласковый", "вежливый", "обходительный", "доступный", "знакомистый", "известный", "знаемый", "ведомый", "знакомый"],
    "знакомить": ["представлять"],
    "знакомиться": ["заводить знакомство", "представляться", "узнавать", "встречаться", "ознакомляться"],
    "знакомость": ["известность"],
    "знакомство": ["ознакомление", "осведомлённость"],
    "знакомый": ["известный", "знающий", "осведомлённый", "знакомец", "знакомка"],
    "знаменав": ["знаменавши"],
    "знаменавши": ["знаменав"],
    "знаменитость": ["известность", "слава", "звезда"],
    "знаменитый": ["известный", "достославный", "видный", "прославленный", "славный", "именитый", "знатный", "мировой", "выдающийся", "отличный"],
    "знамено": ["прапор"],
    "знаменовав": ["знаменовавши"],
    "знаменовавши": ["знаменовав"],
    "знаменование": ["знаменованье", "рисование", "рисунок"],
    "знаменованье": ["знаменование"],
    "знаменоносец": ["знаменосец", "знамёнщик", "знаменщик"],
    "знаменоносный": ["знаменосный"],
    "знаменосец": ["знаменоносец", "знамёнщик", "знаменщик"],
    "знаменосный": ["знаменоносный"],
    "знаменщик": ["знаменосец", "знамёнщик", "знаменоносец", "стяговщик", "стягоносец", "флагоносец", "рисовальщик", "знаменатель", "книгопечатник"],
    "знамо": ["знамо дело"],
    "знамёнщик": ["знаменосец", "знаменоносец", "знаменщик"],
    "знание": ["начитанность", "информированность", "образованность", "понимание", "знакомство", "информация"],
    "знанье": ["знание"],
    "знатный": ["известный", "знаменитый", "прославленный"],
    "знаток": ["авторитет", "дока", "мастер", "специалист", "эксперт"],
    "знать": ["видать", "видно", "очевидно", "значит", "по-видимому"],
    "знать толк": ["разбираться"],
    "знахарив": ["знахаривши"],
    "знахаривши": ["знахарив"],
    "знахарша": ["докторша", "лекарка", "врачиха", "врачица"],
    "знахарь": ["врачеватель", "целитель"],
    "знаць": ["ведаць"],
    "значение": ["смысл", "суть", "сущность", "значенье", "важность", "значительность", "роль"],
    "значив": ["значивши"],
    "значивши": ["значив"],
    "значимо": ["важно", "значительно", "существенно", "немаловажно", "эпохально", "судьбоносно"],
    "значимость": ["важность", "значительность"],
    "значимый": ["существенный", "важный", "значительный", "серьезный", "ценный", "авторитетный", "принципиальный", "весомый", "немаловажный", "первостепенный", "общезначимый", "означающий", "обозначающий", "значащий"],
    "значит": ["следовательно", "стало быть", "поэтому", "выходит"],
    "значительнейший": ["важнейший"],
    "значительно": ["важно", "весомо", "намного", "существенно", "неизмеримо"],
    "значительный": ["большой", "крупный", "солидный", "существенный", "важный", "значимый", "приоритетный", "многозначительный", "ёмкий"],
    "значить": ["означать"],
    "значкист": ["фалерист"],
    "зневага": ["неповага"],
    "знемажэнне": ["змога", "знямога"],
    "зно": ["вно"],
    "знобив": ["знобивши"],
    "знобивши": ["знобив"],
    "знобить": ["морозить"],
    "знобиться": ["студиться", "зябнуть", "сожалеть", "соболезновать"],
    "зной": ["жара", "жар", "пылкость", "страстность"],
    "знойно": ["жарко", "паляще", "пылко", "страстно", "жгуче", "пламенно"],
    "знойность": ["раскалённость"],
    "зов": ["призыв", "клич", "приглашение"],
    "зовомый": ["называемый", "именуемый"],
    "зовуур": ["зовуурь"],
    "зовууртай": ["зовлонт"],
    "зодчество": ["архитектура"],
    "зодчий": ["архитектор"],
    "зож": ["здоровый образ жизни"],
    "зожевец": ["зожник"],
    "зожник": ["зожевец"],
    "зоил": ["хулитель", "ругатель", "аристарх", "клеветник"],
    "зоиш": ["таваллуд"],
    "зола": ["пепел"],
    "золив": ["золивши"],
    "золивши": ["золив"],
    "золотарь": ["золотильщик", "ювелир", "ассенизатор", "говночист", "говновоз"],
    "золотев": ["золотевши"],
    "золотевши": ["золотев"],
    "золотив": ["золотивши"],
    "золотивши": ["золотив"],
    "золотильщик": ["позолотчик"],
    "золотинка": ["иенгра"],
    "золотистый": ["солнечный", "золотой"],
    "золотить": ["осветлять", "украшать"],
    "золотиться": ["златиться"],
    "золотной": ["золототканый"],
    "золотовалютные резервы": ["звр"],
    "золотоглавый": ["златоглавый"],
    "золотогривый": ["златогривый"],
    "золотодобытчик": ["старатель"],
    "золотодобытчица": ["старательница"],
    "золотое дно": ["сокровищница", "голконда", "эльдорадо"],
    "золотоискатель": ["золотодобытчик", "старатель"],
    "золотой": ["дорогой", "полезный", "ценный", "драгоценный", "замечательный", "золотистый"],
    "золотой век": ["век астреи"],
    "золотой запас": ["золотой резерв"],
    "золотой резерв": ["золотой запас"],
    "золотокудрый": ["златокудрый", "златовласый", "златоволосый"],
    "золотолобый": ["златолобый"],
    "золотоносный": ["золотосодержащий"],
    "золоторотец": ["босяк", "оборванец"],
    "золототканый": ["златотканый", "золотной"],
    "золотоцвет": ["диморфотека"],
    "золотуха": ["скрофулёз"],
    "золотушный": ["болезненный", "чахлый", "хилый", "истощённый"],
    "золотые руки": ["умелость", "мастер на все руки", "мастер", "умелец"],
    "золоченье": ["золочение"],
    "золочёный": ["позолоченный"],
    "золто": ["золтой"],
    "золтой": ["золто"],
    "золь": ["лиозоль", "коллоидный раствор", "псевдораствор"],
    "зольник": ["зольница", "зольная жидкость", "зольная кукла"],
    "зольница": ["поддувало", "зольник"],
    "зомбак": ["зомбарь"],
    "зомбарь": ["зомбак", "зомбяк", "зомби"],
    "зомби": ["живой мертвец", "ходячий мертвец", "ходячий", "зомбяк", "зомбик", "зомбарь", "зомбированный", "биоробот", "процесс-зомби"],
    "зомбировав": ["зомбировавши"],
    "зомбировавши": ["зомбировав"],
    "зомбированный": ["живой мертвец", "зомби", "безвольный", "ведомый", "марионеточный", "неосознанный", "безотчётный", "внушённый", "внушаемый", "заблуждающийся"],
    "зомбяк": ["зомбак", "зомбарь", "зомби"],
    "зона": ["пояс", "нары", "кича", "лагерь", "стратиграфическая зона", "хронозона"],
    "зона санитарной охраны": ["зсо"],
    "зонг-опера": ["рок-опера"],
    "зонд": ["щуп"],
    "зондаж": ["зондирование"],
    "зондировав": ["зондировавши"],
    "зондировавши": ["зондировав"],
    "зондировать": ["прощупывать"],
    "зонировав": ["зонировавши"],
    "зонировавши": ["зонировав"],
    "зонирование": ["зонировка"],
    "зонировка": ["зонирование"],
    "зонк": ["зедонк", "зонки"],
    "зоноэдр": ["зонотоп"],
    "зонт": ["зонтик", "тент", "козырёк"],
    "зонтик": ["зонт"],
    "зонтикообразный": ["зонтиковидный"],
    "зонтичные": ["сельдереевые"],
    "зооантропоноз": ["антропозооноз"],
    "зоокумарин": ["варфарин"],
    "зоолатрия": ["анимализм", "теротеизм"],
    "зоомагнетизм": ["животный магнетизм"],
    "зооморфный": ["зооморфический"],
    "зооним": ["кличка"],
    "зоопарк": ["зоосад", "зверинец", "отребье", "фрагментация"],
    "зоопсихология": ["психология"],
    "зоосад": ["зверинец", "зоопарк"],
    "зоотеизм": ["зоолатрия", "теротеизм"],
    "зоотехния": ["зоотехника"],
    "зоофаг": ["плотоядный", "хищник"],
    "зоофагия": ["плотоядность", "хищничество"],
    "зоофилия": ["зооэрастия", "скотоложество", "содомия", "бестиализм", "бестиофилия"],
    "зооэрастия": ["зоофилия"],
    "зоревав": ["зоревавши"],
    "зоревавши": ["зоревав"],
    "зорив": ["зоривши"],
    "зоривши": ["зорив"],
    "зоркий": ["орлиный глаз", "глаз-алмаз", "быстроглазый", "глаз-ватерпас", "проницательный", "внимательный", "пристальный"],
    "зорко": ["проницательно", "внимательно", "пристально", "настороже"],
    "зорник": ["хлебопашец", "арендатор"],
    "зорнэн": ["зоракы"],
    "зорька": ["заря", "смолка"],
    "зоря": ["заря", "зоревая церемония"],
    "зосим": ["зосима"],
    "зосима": ["зосим"],
    "зостера": ["взморник"],
    "зп": ["заработная плата", "зарплата"],
    "зппп": ["венерическая болезнь", "венерическое заболевание", "гусарская болезнь", "половая инфекция"],
    "зрада": ["зрадонька"],
    "зрадомога": ["зрадоперемога", "перезрада"],
    "зрадоперемога": ["зрадомога", "перезрада"],
    "зрачок": ["зеница"],
    "зрачочек": ["зрачок"],
    "зрван": ["зерван"],
    "зрев": ["зревши"],
    "зревши": ["зрев"],
    "зрелище": ["картина"],
    "зрелищность": ["смотрибельность"],
    "зрелищный": ["развлекательный"],
    "зрелка": ["матюрка", "милфа"],
    "зрелый": ["спелый", "созревший", "взрослый", "мудрый", "взвешенный"],
    "зренье": ["зрение"],
    "зреть": ["созревать", "поспевать", "спеть", "развиваться", "укрепляться", "крепнуть"],
    "зривши": ["зрив"],
    "зримый": ["видимый", "явственный"],
    "зритель": ["наблюдатель"],
    "зрительная труба": ["подзорная труба"],
    "зрительно": ["визуально", "оптически"],
    "зрительствовав": ["зрительствовавши"],
    "зрительствовавши": ["зрительствовав"],
    "зрить": ["зреть", "смотреть", "видеть"],
    "зробить": ["сделать", "изготовить", "сшить"],
    "зрошення": ["зрошування"],
    "зрошування": ["зрошення"],
    "зря": ["напрасно", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "зрячая": ["видящая"],
    "зрячий": ["видящий", "зрящий", "встреченный", "повстречавшийся", "проницательный", "наблюдательный"],
    "зряшный": ["ненужный", "напрасный", "бессмысленный", "бесполезный", "бесцельный", "пустопорожний", "тщетный", "суетный", "бренный", "тленный", "никчёмный", "негодный", "непригодный", "никудышний", "пустой"],
    "зсо": ["зона санитарной охраны"],
    "зсфср": ["закавказская федерация"],
    "зт": ["зажигательно-трассирующий"],
    "зуб": ["шип", "нарост", "неприязнь"],
    "зуб мудрости": ["восьмёрка"],
    "зубарь": ["зубатка"],
    "зубастый": ["зубатый", "общительный", "говорливый", "языкастый", "разговорчивый", "болтливый", "словоохотливый"],
    "зубатка": ["зубарь"],
    "зубная нить": ["флосс"],
    "зубная эмаль": ["эмаль"],
    "зубник": ["белена"],
    "зубной": ["дентальный"],
    "зубной врач": ["дантист", "стоматолог"],
    "зубовик": ["белена"],
    "зубовный": ["зубной"],
    "зубодесневой": ["зубодесневый"],
    "зубодёр": ["стоматолог"],
    "зубодёрка": ["дантистка"],
    "зубок": ["зубик"],
    "зубоскалив": ["зубоскаливши"],
    "зубоскаливши": ["зубоскалив"],
    "зубоскалить": ["зубоскальничать", "насмехаться"],
    "зубоскальничав": ["зубоскальничавши"],
    "зубоскальничавши": ["зубоскальничав"],
    "зубоскальство": ["скалозубство"],
    "зубоскальствовав": ["зубоскальствовавши"],
    "зубоскальствовавши": ["зубоскальствовав"],
    "зубоскальствовать": ["зубоскальничать"],
    "зуботычина": ["зубочистка"],
    "зубошлифовальщик": ["зубошлифовщик"],
    "зубошлифовщик": ["зубошлифовальщик"],
    "зубр": ["мэтр", "ас"],
    "зубренье": ["зубрение"],
    "зубрив": ["зубривши"],
    "зубривши": ["зубрив"],
    "зубрила": ["зубрилка", "ботан", "ботаник", "заучка"],
    "зубрилка": ["зубрила", "ботан", "ботаник", "заучка"],
    "зубрица": ["зубриха"],
    "зубровый": ["бизоновый"],
    "зубрёж": ["зубрёжка"],
    "зубрёжка": ["зубрёж", "зубрение", "заучивание"],
    "зубцевание": ["перфорирование"],
    "зубцовка": ["перфорация"],
    "зубчатое колесо": ["шестерня"],
    "зубчик": ["зубец", "зубок"],
    "зубы проесть на": ["собаку съесть"],
    "зубянка": ["сердечник"],
    "зуд": ["раздражение", "свербёж"],
    "зуда": ["зудила"],
    "зудев": ["зудевши"],
    "зудевши": ["зудев"],
    "зуденье": ["зудение"],
    "зудеть": ["свербеть"],
    "зудив": ["зудивши"],
    "зудивши": ["зудив"],
    "зудёж": ["повторять", "чесать", "надоедать", "беспокоить", "нудить", "занудить"],
    "зула": ["дэн"],
    "зулу": ["зулусы", "зулус", "зулусский язык"],
    "зулус": ["зулу"],
    "зум-объектив": ["вариообъектив"],
    "зумер": ["хоумлендер", "центениал"],
    "зумирование": ["трансфокация"],
    "зумировать": ["зумить"],
    "зумить": ["зумировать"],
    "зуммер": ["звукоизлучатель", "пищик", "бипер", "жужжалка", "звонилка", "пищалка", "звонок", "гудок"],
    "зуммерив": ["зуммеривши"],
    "зуммеривши": ["зуммерив"],
    "зумрад": ["зумуррад"],
    "зумуррад": ["зумрад"],
    "зунд": ["эресунн"],
    "зурван": ["зерван", "зарван"],
    "зурванизм": ["зерванизм"],
    "зурнач": ["зурнист"],
    "зурнист": ["зурнач"],
    "зурьёт": ["зурёт"],
    "зухвалий": ["зухвальний"],
    "зухвальний": ["зухвалий"],
    "зушка": ["зенитка", "зенитная установка"],
    "зшивка": ["шво", "шов"],
    "зъб": ["зъбец"],
    "зыбав": ["зыбавши"],
    "зыбавши": ["зыбав"],
    "зыбать": ["колебать", "качать"],
    "зыбив": ["зыбивши"],
    "зыбивши": ["зыбив"],
    "зыбить": ["колебать", "качать"],
    "зыбиться": ["колыхаться", "колебаться", "качаться"],
    "зыбка": ["качалка", "колыбель", "люлька"],
    "зыбкий": ["валкий", "зыбучий", "непрочный", "сомнительный", "трясинный", "ненадёжный", "неустойчивый", "нестойкий"],
    "зыбко": ["валко", "глухо", "непостоянно", "сомнительно", "ненадёжно", "неустойчиво", "непрочно"],
    "зыбкость": ["валкость", "зыбучесть", "ненадёжность", "непостоянство", "неустойчивость", "сомнительность", "шаткость"],
    "зыбление": ["колебание", "колыхание"],
    "зыбун": ["зыбь", "трясина"],
    "зыбучий": ["зыбкий"],
    "зыбь": ["рябь", "паволна", "волны", "трясина"],
    "зывав": ["зывавши"],
    "зывавши": ["зывав"],
    "зык": ["крик", "окрик", "рявканье"],
    "зыкав": ["зыкавши"],
    "зыкавши": ["зыкав"],
    "зыкнув": ["зыкнувши"],
    "зыкнувши": ["зыкнув"],
    "зыко": ["баско", "классно", "круто"],
    "зыкъым": ["зеэр"],
    "зынгъарла": ["зынхарла"],
    "зынхарла": ["зынгъарла"],
    "зырив": ["зыривши"],
    "зыривши": ["зырив"],
    "зыркав": ["зыркавши"],
    "зыркавши": ["зыркав"],
    "зыркнув": ["зыркнувши"],
    "зыркнувши": ["зыркнув"],
    "зырянин": ["коми-зырянин"],
    "зырянка": ["коми-зырянка"],
    "зычно": ["громко"],
    "зычный": ["звучный", "громкий"],
    "зыялы": ["окумал"],
    "зэ": ["задающий элемент"],
    "зэк": ["зэка", "заключённый", "осуждённый", "узник"],
    "зэка": ["заключённый", "зека", "зэк", "зек"],
    "зэчка": ["заключенная", "арестантка"],
    "зюганоид": ["коммуняка"],
    "зюзьга": ["сузьга", "сюзьга"],
    "зюйд": ["юг", "полдень"],
    "зя": ["можно", "разрешаться"],
    "зябко": ["прохладно", "холодно"],
    "зяблина": ["морозобоина", "морозобой", "морозная трещина", "расстрел"],
    "зяблый": ["мёрзлый", "помороженный", "замороженный", "зябкий", "озяблый"],
    "зябнув": ["зябнувши"],
    "зябнувши": ["зябнув"],
    "зябнуть": ["мёрзнуть"],
    "зябра": ["жабрей", "пикульник"],
    "зябрив": ["зябривши"],
    "зябривши": ["зябрив"],
    "зябрить": ["жабровать"],
    "зёма": ["земеля", "земляк", "землячок", "друг", "дружбан"],
    "и биться сердце перестало": ["ебиться сердце перестало"],
    "и в хуй не дуть": ["в ус не дуть", "и в ус не дуть", "в хуй не дуть"],
    "и горя мало": ["хоть бы что", "хоть бы хны", "наплевать", "пофиг веники", "как с гуся вода"],
    "и концы в воду": ["хоронить концы в воду", "заметать следы", "прятать концы в воду"],
    "и краткое": ["и с краткой"],
    "и на старуху бывает проруха": ["на всякого мудреца довольно простоты"],
    "и примкнувший к ним шепилов": ["примкнувший шепилов"],
    "и с краткой": ["и краткое"],
    "и стар и млад": ["все"],
    "и так далее": ["и прочее", "и прочие", "и прочая", "и другие", "и тому подобное"],
    "и так и этак": ["двояко", "по-всякому"],
    "и то правда": ["правда", "верно", "точно", "и то верно"],
    "и тому подобное": ["и так далее"],
    "иакинф": ["гиацинт"],
    "иаков": ["яков"],
    "иалу": ["иару"],
    "иамния": ["иавиея", "иавея", "иавнея", "ямния"],
    "ианнуарий": ["януарий"],
    "иару": ["иалу"],
    "ибадит": ["абадит"],
    "ибекс": ["каменный козёл", "горный козёл", "альпийский козёл"],
    "ибер": ["эбро", "ивир"],
    "ибериец": ["ибер"],
    "иберийский полуостров": ["пиренейский полуостров"],
    "иберия": ["иверия", "картли"],
    "ибица": ["ивиса"],
    "иблис": ["эблис", "шайтан", "раджим", "люцифер"],
    "ибн": ["бен", "бин"],
    "ибо": ["потому что", "так как", "зане", "поелику", "понеже", "поскольку"],
    "ибодат": ["тоат", "намоз"],
    "ибс": ["коронарная недостаточность", "ишемия миокарда"],
    "ибяк": ["ибэк"],
    "ив": ["йив", "эв"],
    "ива": ["ветла", "ракита", "лоза", "лозина", "верба", "тальник"],
    "иван": ["ваня", "ванечка", "иванушка", "ванька", "ванёк", "вано", "иоанн", "русский иван"],
    "иван сусанин": ["сусанин", "гид", "проводник", "провожатый"],
    "иван-да-марья": ["марьянник"],
    "иван-чай": ["кипрей", "хамерион", "копорский чай", "копорка", "дремуха", "иван-трава", "хрипняк"],
    "ивано-франковск": ["станислав", "станиславов"],
    "ивано-франковская область": ["ивано-франковщина"],
    "иванович": ["иваныч"],
    "иваново": ["иваново-вознесенск", "текстильная столица", "город первого совета", "город невест"],
    "иванушка": ["иван", "иванушка-дурачок"],
    "иваныч": ["иванович"],
    "иваси": ["дальневосточная сардина"],
    "ивер": ["ибер", "ибериец", "грузин"],
    "иверень": ["щепа", "черепок", "вырез", "зарубка"],
    "иверия": ["иберия", "картли"],
    "ивирон": ["афон"],
    "ивиса": ["ибица"],
    "ивишень": ["вишенник", "вишняк", "ивишенник", "подвишенник", "подвишень", "клитопилус"],
    "ивняк": ["лозняк", "тальник"],
    "ивнячок": ["ивняк"],
    "игарец": ["игарчанин"],
    "игбо": ["ибо"],
    "игемон": ["воевода", "военачальник", "князь"],
    "игил": ["исламское государство ирака и леванта", "исламское государство", "иг", "игиш", "даиш"],
    "игирмэ": ["эгирми"],
    "игит": ["игить", "йигит"],
    "игить": ["игит"],
    "игла": ["остриё", "шип", "спица", "стержень", "иголка", "хвоя", "шпиль", "вершина"],
    "иглица": ["мышиный тёрн", "рускус"],
    "иглобрюх": ["тетраодон"],
    "игловидный": ["иглообразный"],
    "иглорефлексотерапевт": ["иглотерапевт"],
    "иглорефлексотерапия": ["акупунктура", "иглоукалывание", "иглотерапия"],
    "иглотерапевт": ["иглорефлексотерапевт"],
    "иглотерапия": ["акупунктура", "иглорефлексотерапия", "иглоукалывание"],
    "иглоукалывание": ["акупунктура", "иглорефлексотерапия", "иглотерапия", "рефлексотерапия"],
    "иглоукалыватель": ["иглотерапевт"],
    "иглянка": ["багрянка", "мурекс"],
    "игнасио": ["начо"],
    "игнат": ["игнатий"],
    "игнатовец": ["большеигнатовец"],
    "игнатьевич": ["игнатиевич"],
    "игнимбрит": ["туфолава"],
    "игнор": ["блэклист", "бойкот", "пренебрежение"],
    "игноранция": ["невежество", "неосведомленность"],
    "игнорив": ["игноривши"],
    "игноривши": ["игнорив"],
    "игнорировав": ["игнорировавши"],
    "игнорировавши": ["игнорировав"],
    "игнорированье": ["игнорирование"],
    "игнорировать": ["пренебрегать", "не обращать внимания", "не уделять внимания", "не учитывать", "не придавать значения", "не принимать во внимание", "не брать в расчёт"],
    "игностицизм": ["игтеизм"],
    "иго": ["ярмо", "хомут", "бремя", "гнёт", "рабство"],
    "игогокав": ["игогокавши"],
    "игогокавши": ["игогокав"],
    "игогокнув": ["игогокнувши"],
    "игогокнувши": ["игогокнув"],
    "иголка": ["игла", "хвоинка", "шип", "колючка", "нож"],
    "игольник": ["игольница"],
    "игольница": ["игольник", "фонтура"],
    "игольничек": ["игольник"],
    "игоносец": ["раб"],
    "игоносный": ["подневольный"],
    "игорный": ["игровой"],
    "игорный дом": ["казино", "игорное заведение"],
    "игра": ["забава", "вид спорта", "матч", "встреча", "поединок"],
    "игра в одни ворота": ["игра в одну калитку"],
    "игра не стоит свеч": ["овчинка выделки не стоит"],
    "игра слов": ["каламбур"],
    "играв": ["игравши"],
    "игравши": ["играв"],
    "игралище": ["игрушка"],
    "игральная кость": ["жребий", "игральный кубик", "дайс", "зарик"],
    "играние": ["игра"],
    "игранув": ["игранувши"],
    "игранувши": ["игранув"],
    "игранье": ["играние"],
    "играть": ["развлекаться", "забавляться", "резвиться", "исполнять", "музицировать", "ходить", "пренебрегать", "лицедействовать", "имперсонировать", "изображать", "притворяться", "лукавить", "отражаться", "сверкать", "сиять"],
    "играть дёснами": ["хлестаться в десну", "шарахаться в десну", "биться в дёсны", "долбиться в дёсны"],
    "играть роль": ["притворяться", "прикидываться"],
    "играть с огнём": ["ходить по лезвию ножа", "рисковать"],
    "играть со смертью": ["гоняться за смертью"],
    "играючи": ["легко", "непринуждённо", "игриво"],
    "игрек": ["ипсилон"],
    "игреневый": ["игрений"],
    "игрений": ["игреневый"],
    "игрецкий дом": ["игорный дом"],
    "игристое": ["игристое вино"],
    "игристый": ["пенящийся", "шипучий"],
    "игрица": ["игральщица", "игрательница"],
    "игроиндустрия": ["игрострой"],
    "игромания": ["гэмблинг", "лудомания"],
    "игропром": ["игрострой", "геймдев", "игроиндустрия"],
    "игрострой": ["игропром"],
    "игрофикация": ["геймификация"],
    "игроцкий": ["игровой", "игральный", "игорный"],
    "игрочок": ["игруля"],
    "игруля": ["музыкант", "игрок"],
    "игрывав": ["игрывавши"],
    "игрывавши": ["игрывав"],
    "игтеизм": ["игностицизм"],
    "игуанодон": ["игуанодонт"],
    "игуанодонт": ["игуанодон"],
    "игумен": ["настоятель"],
    "игуменствовав": ["игуменствовавши"],
    "игуменствовавши": ["игуменствовав"],
    "игътибар": ["илтифат"],
    "игыр": ["игыт"],
    "идакан": ["яян", "саман"],
    "идальго": ["гидальго", "кабальеро", "дворянин", "господин", "рыцарь"],
    "идеал": ["эталон", "образец"],
    "идеализация": ["идеализирование"],
    "идеализировав": ["идеализировавши"],
    "идеализировавши": ["идеализировав"],
    "идеализированный": ["приукрашенный", "идеалистичный"],
    "идеальничав": ["идеальничавши"],
    "идеальничавши": ["идеальничав"],
    "идеальничание": ["идеальничанье"],
    "идеальничанье": ["идеальничание"],
    "идеальный": ["нереальный", "воображаемый", "образцовый", "возвышенный", "безупречный", "совершенный"],
    "идейный": ["идеологический", "сознательный", "преданный"],
    "идентификатор": ["сигнатура", "дескриптор"],
    "идентифицировав": ["идентифицировавши"],
    "идентифицировавши": ["идентифицировав"],
    "идентифицирование": ["идентификация", "отождествление"],
    "идентифицировать": ["отождествить", "отождествлять", "опознавать", "опознать"],
    "идентифицирующий": ["определяющий"],
    "идентично": ["одинаково", "тождественно", "тожественно", "так же", "аналогично"],
    "идентичность": ["тождественность", "совпадение", "личность"],
    "идентичный": ["одинаковый", "такой же", "тождественный", "эквивалентный", "аналогичный"],
    "идеографический": ["иероглифический"],
    "идеографический словарь": ["тезаурус"],
    "идеографическое письмо": ["идеография"],
    "идеологизировав": ["идеологизировавши"],
    "идеологизировавши": ["идеологизировав"],
    "идеологически": ["идейно", "мировоззренчески"],
    "идеологическое клише": ["политическое клише", "пропагандистское клише"],
    "идеологичность": ["идеологизированность"],
    "идеологичный": ["идеологический"],
    "идеология": ["мировоззрение"],
    "идеомоторный": ["идеокинетический", "психо-двигательный"],
    "идеопластический": ["символический"],
    "идефикс": ["идея фикс"],
    "идея фикс": ["идефикс"],
    "идзанами": ["идзанами-но-ками", "идзанами но ками", "идзанами-но ками"],
    "идиллически": ["идиллично"],
    "идиллический": ["буколический", "безмятежный"],
    "идиллично": ["идиллически"],
    "идилличный": ["идиллический"],
    "идиллия": ["пастораль", "безмятежность", "грёза", "нега", "романтика", "уют"],
    "идиоадаптация": ["алломорфоз"],
    "идиолатрия": ["нарциссизм", "самообожание", "самопоклонение"],
    "идиома": ["фразеологическое сращение", "фразеологизм"],
    "идиоматизм": ["идиома"],
    "идиоматически": ["идиоматично"],
    "идиоматично": ["идиоматически"],
    "идиоматичный": ["идиоматический"],
    "идиоморфный": ["автоморфный"],
    "идиопатический": ["криптогенный"],
    "идиосинкразический": ["идиосинкратический"],
    "идиосинкразия": ["аллергия", "ферментопатия"],
    "идиосинкратический": ["своеобразный", "особый", "уникальный", "эксклюзивный", "отличительный", "характерный", "идиосинкразический", "аллергический", "непереносимый"],
    "идиостиль": ["манера", "почерк"],
    "идиот": ["слабоумный", "дурак", "тупица", "придурок", "кретин", "тормоз"],
    "идиотик": ["дурачок", "дурак", "глупец"],
    "идиотина": ["дурак", "глупец", "простофиля"],
    "идиотически": ["идиотично", "идиотски", "по-идиотски", "бессмысленно", "глупо"],
    "идиотичный": ["идиотический", "идиотский"],
    "идиотия": ["идиотизм"],
    "идиотка": ["дебилка"],
    "идиотничав": ["идиотничавши"],
    "идиотничавши": ["идиотничав"],
    "идиотски": ["по-идиотски"],
    "идиотский": ["идиотический", "глупый", "дурацкий", "нелепый"],
    "идиотство": ["идиотия", "идиотизм"],
    "идиофон": ["автофон"],
    "идиш": ["новоеврейский язык"],
    "идол": ["истукан", "кумир"],
    "идолобес": ["идолопоклонник", "идолочтец", "язычник", "еретик", "неверный", "богоотступник"],
    "идоловерец": ["идолопоклонник"],
    "идолопоклонница": ["идолослужебница", "идолослужительница", "идолочтительница", "кумиропоклонница", "идольщица"],
    "идолопоклонничав": ["идолопоклонничавши"],
    "идолопоклонничавши": ["идолопоклонничав"],
    "идолопоклонство": ["идолопоклонничество", "идолослужение", "низкопоклонство"],
    "идолопоклонствовав": ["идолопоклонствовавши"],
    "идолопоклонствовавши": ["идолопоклонствовав"],
    "идолопоклонствовать": ["идолопоклонничать"],
    "идти к венцу": ["сочетаться браком", "венчаться"],
    "идти ко дну": ["тонуть"],
    "идти на вы": ["объявлять войну"],
    "идти на хуй": ["идти в жопу", "идти лесом", "катиться колбаской", "пешее эротическое путешествие"],
    "идти по трупам": ["шагать по трупам", "перешагнуть через труп"],
    "идумей": ["едомитянин", "эдомитянин", "идумеянин"],
    "идумея": ["эдом", "едом"],
    "идумеянин": ["идумей"],
    "идучи": ["идя"],
    "идфу": ["эдфу"],
    "идь": ["шаба", "тётьмак"],
    "идя": ["идучи"],
    "иегова": ["яхве", "ягве"],
    "иеговист": ["ильинец", "яхвист"],
    "иегуда": ["иуда"],
    "иезуит": ["лицемер"],
    "иезуитничав": ["иезуитничавши"],
    "иезуитничавши": ["иезуитничав"],
    "иезуитски": ["по-иезуитски"],
    "иезуитствовав": ["иезуитствовавши"],
    "иезуитствовавши": ["иезуитствовав"],
    "иераконполь": ["гиераконполис", "нехен", "эдфу"],
    "иерарх": ["архиерей"],
    "иерархизировать": ["иерархизовать"],
    "иерархизовав": ["иерархизовавши"],
    "иерархизовавши": ["иерархизовав"],
    "иерархизовать": ["иерархизировать"],
    "иерархичный": ["иерархический"],
    "иератика": ["иератическое письмо"],
    "иератический": ["гиератический"],
    "иератическое письмо": ["иератика"],
    "иерействовав": ["иерействовавши"],
    "иерействовавши": ["иерействовав"],
    "иеремей": ["еремей", "иеремия"],
    "иеремиада": ["сетование"],
    "иеремия": ["йирмеяху"],
    "иероглиф": ["гиероглиф", "абракадабра", "крокозябра", "каракули", "неясный"],
    "иеродиакон": ["иеродьякон"],
    "иеродиаконский": ["иеродьяконский"],
    "иеродула": ["иеродул"],
    "иеродьякон": ["иеродиакон"],
    "иеродьяконский": ["иеродиаконский"],
    "иероним": ["ероним", "жером", "хиеронюм", "хиеронюмос", "ероня", "джером", "джеронимо", "еремей"],
    "иерофобия": ["агиофобия"],
    "иерусалим": ["ерушалаим", "аль-кудс", "рушалимум", "урусалим", "урсалимму", "урушалим", "шалем", "иевус", "сион", "цион", "элия капитолина", "иеросолима"],
    "ижде": ["идеже"],
    "иждивенец": ["приживал", "приживала", "приживальщик", "прихлебала", "прихлебай", "нахлебник", "прихлебатель"],
    "иждивенка": ["нахлебница", "приживалка"],
    "иждивенчество": ["нахлебничество"],
    "иждивенье": ["иждивение"],
    "ижора": ["ингерманландия", "ингрия", "ижорская земля"],
    "ижорский": ["ингрский"],
    "ижорский язык": ["ижорский"],
    "из": ["от", "между", "среди", "из-за", "по", "за", "благодаря", "по причине", "вследствие", "в результате", "ввиду", "в силу"],
    "из говна и палок": ["на коленке"],
    "из каждого утюга": ["тяжёлая ротация"],
    "из коробки": ["вместе"],
    "из любви к искусству": ["бескорыстно", "без всякой корысти"],
    "из оглобель вон": ["ни в какую", "ни за что", "ни в коем случае", "ни при каких условиях"],
    "из огня да в полымя": ["из хомута да в шлейку"],
    "из первых рук": ["из первоисточника"],
    "из полы в полу": ["из рук в руки", "с рук на руки", "непосредственно", "напрямую"],
    "из рук вон": ["через одно место", "через жопу"],
    "из уст в уста": ["по цепочке"],
    "из-за": ["для", "ради", "на", "за", "во имя", "с целью", "в целях", "из", "от", "по", "благодаря", "по причине", "вследствие", "в результате", "ввиду"],
    "из-под": ["для", "от"],
    "из-под носа": ["на глазах", "из-под носу", "из-под самого носа"],
    "из-под палки": ["принудительно"],
    "из-под полы": ["тайком", "контрабанда", "украдучись", "нелегально", "втихомолку", "тайно"],
    "изад": ["худо", "парвардигор", "яздон", "эзид"],
    "изаллобара": ["изоаллобара"],
    "изаллотерма": ["изоаллотерма"],
    "изаномала": ["изоаномала"],
    "изафет": ["идафа"],
    "изба": ["хата"],
    "изба с краю": ["хата с краю", "дело сторона"],
    "избава": ["избавление", "освобождение", "отърваване", "спасение"],
    "избавив": ["избавивши"],
    "избавивши": ["избавив"],
    "избавитель": ["освободитель", "спаситель", "мессия"],
    "избавить": ["освободить", "спасти"],
    "избавиться": ["отделаться"],
    "избавление": ["спасение", "освобождение"],
    "избавленье": ["избавление"],
    "избавляв": ["избавлявши"],
    "избавлявши": ["избавляв"],
    "избавлять": ["спасать", "освобождать"],
    "избаловав": ["избаловавши"],
    "избаловавши": ["избаловав"],
    "избалованный": ["капризный", "изнеженный", "своенравный", "своевольный"],
    "избаловать": ["изнежить", "распустить", "набаловать", "забаловать", "разбаловать"],
    "избаловывав": ["избаловывавши"],
    "избаловывавши": ["избаловывав"],
    "избач": ["завклубом"],
    "избегав": ["избегавши"],
    "избегавши": ["избегав"],
    "избегать": ["обежать"],
    "избегнув": ["избегнувши"],
    "избегнувши": ["избегнув"],
    "избегнуть": ["избежать"],
    "избежав": ["избежавши"],
    "избежавши": ["избежав"],
    "избежанье": ["избежание"],
    "избежать": ["избегнуть", "избавиться"],
    "избив": ["избивши"],
    "избивав": ["избивавши"],
    "избивавши": ["избивав"],
    "избивши": ["избив"],
    "избирав": ["избиравши"],
    "избиравши": ["избирав"],
    "избирательная комиссия": ["избирком"],
    "избирательная урна": ["избирательный ящик", "урна"],
    "избирательно": ["выборочно", "селективно", "точечно"],
    "избирательность": ["селективность"],
    "избирательный": ["электоральный", "выборочный", "селективный"],
    "избирательный бюллетень": ["бюллетень"],
    "избирательный ящик": ["избирательная урна", "урна"],
    "избирательский": ["избирательный"],
    "избирать": ["выбирать", "отбирать", "отсеивать", "голосовать"],
    "избито": ["пошло", "банально", "тривиально"],
    "избитый": ["банальный", "неоригинальный"],
    "избичевав": ["избичевавши"],
    "избичевавши": ["избичевав"],
    "изблевав": ["изблевавши"],
    "изблевавши": ["изблевав"],
    "изблёвывав": ["изблёвывавши"],
    "изблёвывавши": ["изблёвывав"],
    "избодав": ["избодавши"],
    "избодавши": ["избодав"],
    "изболев": ["изболевши"],
    "изболевши": ["изболев"],
    "изболтав": ["изболтавши"],
    "изболтавши": ["изболтав"],
    "изборождав": ["изборождавши"],
    "изборождавши": ["изборождав"],
    "изборождать": ["бороздить"],
    "избороздив": ["избороздивши"],
    "избороздивши": ["избороздив"],
    "изборонив": ["изборонивши"],
    "изборонивши": ["изборонив"],
    "изборонить": ["взборонить", "выборонить", "взбороновать"],
    "избочиться": ["избочениться", "подбочениться"],
    "избрав": ["избравши"],
    "избравши": ["избрав"],
    "избранив": ["избранивши"],
    "избранивши": ["избранив"],
    "избранить": ["изругать"],
    "избранник": ["любимец", "баловень", "избранный"],
    "избранник судьбы": ["баловень судьбы", "любимец судьбы", "любимец фортуны"],
    "избранье": ["избрание"],
    "избрать": ["выбрать", "предпочесть", "отобрать", "подобрать"],
    "избродив": ["избродивши"],
    "избродивши": ["избродив"],
    "избрызгав": ["избрызгавши"],
    "избрызгавши": ["избрызгав"],
    "избрызгать": ["испрыскать"],
    "избрызгивав": ["избрызгивавши"],
    "избрызгивавши": ["избрызгивав"],
    "избрызгивать": ["испрыскивать"],
    "избура": ["сбура"],
    "избухливост": ["сприхавост", "несдържаност", "невъздържаност"],
    "избушечный": ["избёночный", "избушковый"],
    "избушка": ["избёнка"],
    "избыв": ["избывши"],
    "избывав": ["избывавши"],
    "избывавши": ["избывав"],
    "избываться": ["изживаться"],
    "избывши": ["избыв"],
    "избыток": ["обилие", "изобилие", "чрезмерность", "пресыщение", "перебор", "достаток", "излишек", "лишек"],
    "избыточествовав": ["избыточествовавши"],
    "избыточествовавши": ["избыточествовав"],
    "избыточно": ["чересчур", "чрезмерно", "излишне", "слишком", "обильно", "богато"],
    "избыточный": ["обильный", "остающийся", "лишний"],
    "извадка": ["извлечение", "откъслек", "откъс", "резюме", "пасаж", "цитат"],
    "изваливав": ["изваливавши"],
    "изваливавши": ["изваливав"],
    "изваляв": ["извалявши"],
    "извалявши": ["изваляв"],
    "извалять": ["вывалять"],
    "изваляться": ["вываляться"],
    "изваяв": ["изваявши"],
    "изваявши": ["изваяв"],
    "изваяние": ["статуя", "скульптура", "изваянье"],
    "изваянье": ["изваяние", "статуя", "скульптура"],
    "изваять": ["вылепить", "слепить"],
    "изведав": ["изведавши"],
    "изведавши": ["изведав"],
    "изведение": ["уничтожение", "истребление", "изничтожение"],
    "изведенция": ["изведение", "израсходование", "употребление"],
    "изведывав": ["изведывавши"],
    "изведывавши": ["изведывав"],
    "изверг": ["изгой", "изувер", "негодяй"],
    "извергав": ["извергавши"],
    "извергавши": ["извергав"],
    "извергаться": ["бить", "изливаться"],
    "извергнув": ["извергнувши"],
    "извергнувши": ["извергнув"],
    "извержение": ["исторжение", "изрыгание", "выпыхивание", "выброс", "изверженье"],
    "изверженье": ["извержение"],
    "извериться": ["разувериться"],
    "извертев": ["извертевши"],
    "извертевши": ["извертев"],
    "известив": ["известивши"],
    "известивши": ["известив"],
    "известие": ["весть"],
    "известить": ["проинформировать", "уведомить", "осведомить", "оповестить", "предупредить", "поставить в известность", "сообщить", "доложить", "донести", "заявить", "объявить"],
    "известковав": ["известковавши"],
    "известковавши": ["известковав"],
    "известнейший": ["очень", "известный", "самый"],
    "известно": ["ведомо", "конечно", "понятно"],
    "известный": ["знакомый", "знаменитый", "знатный", "редкий", "редкостный", "определённый"],
    "известташ": ["бур таш"],
    "известь": ["извёстка"],
    "извет": ["донос", "клевета", "навет"],
    "изветренничаться": ["изветреничаться", "поизветреничаться"],
    "изветчик": ["информатор", "осведомитель", "предатель", "секретный сотрудник", "сексот", "соглядатай", "провокатор", "шпион", "ябеда"],
    "изветшав": ["изветшавши"],
    "изветшавши": ["изветшав"],
    "извечность": ["бессменность", "всегдашность", "постоянность"],
    "извечный": ["вечный", "исконный"],
    "извещав": ["извещавши"],
    "извещавши": ["извещав"],
    "извещать": ["информировать", "уведомлять", "осведомлять", "оповещать", "предупреждать", "ставить в известность", "сообщать", "докладывать", "доносить", "заявлять", "объявлять"],
    "извещенье": ["извещение"],
    "извеяв": ["извеявши"],
    "извеявши": ["извеяв"],
    "извивав": ["извивавши"],
    "извивавши": ["извивав"],
    "извивши": ["извив"],
    "извилина": ["изгиб", "извилина мозга"],
    "извин": ["порок", "недостаток", "изъян"],
    "извинение": ["прощение", "оправдание"],
    "извиненье": ["извинение"],
    "извинив": ["извинивши"],
    "извинивши": ["извинив"],
    "извините": ["простите", "прошу прощения", "приношу извинения", "прошу меня извинить", "пардоньте"],
    "извинить": ["простить", "забыть"],
    "извинтив": ["извинтивши"],
    "извинтивши": ["извинтив"],
    "извинчивав": ["извинчивавши"],
    "извинчивавши": ["извинчивав"],
    "извиняв": ["извинявши"],
    "извинявши": ["извиняв"],
    "извинять": ["прощать", "оправдывать"],
    "извиняться": ["приносить извинения", "просить прощения"],
    "извлекав": ["извлекавши"],
    "извлекавши": ["извлекав"],
    "извлечение": ["экстракция"],
    "извлеченье": ["извлечение"],
    "извлечь": ["вынуть", "достать", "выложить", "выхватить", "вытащить", "вытянуть", "выудить"],
    "извне": ["снаружи"],
    "извнутри": ["изнутри", "извнутрь"],
    "изводив": ["изводивши"],
    "изводивши": ["изводив"],
    "изводить": ["тратить", "расходовать", "переводить", "потреблять", "транжирить", "уничтожать", "ликвидировать", "выводить", "истреблять", "мучить", "доставать", "третировать", "досаждать"],
    "изводство": ["произведение", "творение"],
    "извозив": ["извозивши"],
    "извозивши": ["извозив"],
    "извозить": ["извозюкать", "изгваздать"],
    "извозничав": ["извозничавши"],
    "извозничавши": ["извозничав"],
    "извозчик": ["возница", "возчик", "кучер", "ямщик", "ванька", "возничий", "автомедон"],
    "извозюкав": ["извозюкавши"],
    "извозюкавши": ["извозюкав"],
    "извозюкать": ["изгваздать"],
    "извозюкаться": ["испачкаться"],
    "изволение": ["изволенье"],
    "изволенье": ["изволение"],
    "изволив": ["изволивши"],
    "изволивши": ["изволив"],
    "изволить": ["хотеть", "желать", "будьте добры", "будь добр", "будь добра", "будьте любезны", "будь любезен", "будь любезна", "соблаговолите", "хорошо", "ладно", "пожалуйста"],
    "изволок": ["тянигуж", "тянигуз"],
    "изволочив": ["изволочивши"],
    "изволочивши": ["изволочив"],
    "изволоёбив": ["изволоёбивши"],
    "изволоёбивши": ["изволоёбив"],
    "извольничаться": ["избаловаться"],
    "извоняв": ["извонявши"],
    "извонявши": ["извоняв"],
    "изворотистость": ["изворотливость"],
    "изворотистый": ["увёртливый", "изворотливый"],
    "изворотливость": ["находчивость"],
    "изворотливый": ["увёртливый", "изворотистый", "вёрткий", "находчивый", "лукавый"],
    "извратив": ["извративши"],
    "извративши": ["извратив"],
    "извращав": ["извращавши"],
    "извращавши": ["извращав"],
    "извращать": ["портить", "искажать"],
    "извращение": ["извращенье", "ненормальность", "анормальность", "абнормальность"],
    "извращенье": ["извращение", "ненормальность", "анормальность", "абнормальность"],
    "извращуга": ["извращенец", "извращенка"],
    "извращённо": ["искажённо", "превратно", "противоестественно"],
    "извращённый": ["болезненный", "больной", "нездоровый", "патологический", "уродливый", "уродский"],
    "извязав": ["извязавши"],
    "извязавши": ["извязав"],
    "извязывав": ["извязывавши"],
    "извязывавши": ["извязывав"],
    "извялив": ["извяливши"],
    "извяливав": ["извяливавши"],
    "извяливавши": ["извяливав"],
    "извяливаться": ["провяливаться"],
    "извяливши": ["извялив"],
    "извялиться": ["провялиться"],
    "извёртывав": ["извёртывавши"],
    "извёртывавши": ["извёртывав"],
    "извёртываться": ["выкручиваться", "изворачиваться"],
    "изгадив": ["изгадивши"],
    "изгадивши": ["изгадив"],
    "изгаживав": ["изгаживавши"],
    "изгаживавши": ["изгаживав"],
    "изгаляться": ["издеваться", "насмехаться", "глумиться"],
    "изгваздав": ["изгваздавши"],
    "изгваздавши": ["изгваздав"],
    "изгваздать": ["испачкать"],
    "изгиб": ["изгибание", "искривление", "загиб", "поворот", "нюанс"],
    "изгибав": ["изгибавши"],
    "изгибавши": ["изгибав"],
    "изгибание": ["изгибанье", "закругление", "кривизна", "изгиб", "закругленье"],
    "изгибаться": ["сгибаться"],
    "изгибнув": ["изгибнувши"],
    "изгибнувши": ["изгибнув"],
    "изгладив": ["изгладивши"],
    "изгладивши": ["изгладив"],
    "изгладить": ["уничтожить", "стереть", "сгладить"],
    "изгладывав": ["изгладывавши"],
    "изгладывавши": ["изгладывав"],
    "изглаживав": ["изглаживавши"],
    "изглаживавши": ["изглаживав"],
    "изглед": ["вид", "външност", "форма", "образ", "физиономия"],
    "изглодав": ["изглодавши"],
    "изглодавши": ["изглодав"],
    "изглядев": ["изглядевши"],
    "изглядевши": ["изглядев"],
    "изглядывав": ["изглядывавши"],
    "изглядывавши": ["изглядывав"],
    "изгнав": ["изгнавши"],
    "изгнавши": ["изгнав"],
    "изгнание": ["выдворение", "ссылка", "высылка"],
    "изгнанник": ["изгой"],
    "изгнать": ["выгнать", "прогнать", "искоренить"],
    "изгнив": ["изгнивши"],
    "изгнивав": ["изгнивавши"],
    "изгнивавши": ["изгнивав"],
    "изгнивши": ["изгнив"],
    "изговнив": ["изговнивши"],
    "изговнивши": ["изговнив"],
    "изговняв": ["изговнявши"],
    "изговнявши": ["изговняв"],
    "изговорив": ["изговоривши"],
    "изговоривши": ["изговорив"],
    "изгода": ["изгодност", "полза", "печалба", "придобивка", "добив"],
    "изгодиться": ["сгодиться"],
    "изгой": ["изгнанник", "пария", "отщепенец", "аутсайдер"],
    "изголодав": ["изголодавши"],
    "изголодавши": ["изголодав"],
    "изгоняв": ["изгонявши"],
    "изгонявши": ["изгоняв"],
    "изгонять": ["выживать", "выкуривать"],
    "изгорав": ["изгоравши"],
    "изгоравши": ["изгорав"],
    "изгорбив": ["изгорбивши"],
    "изгорбивши": ["изгорбив"],
    "изгорев": ["изгоревши"],
    "изгореваться": ["исстрадаться"],
    "изгоревши": ["изгорев"],
    "изгородь": ["забор"],
    "изготавливав": ["изготавливавши"],
    "изготавливавши": ["изготавливав"],
    "изготавливаться": ["изготовляться"],
    "изготовив": ["изготовивши"],
    "изготовивши": ["изготовив"],
    "изготовить": ["произвести", "создать", "сделать", "выработать", "подготовить", "приготовить", "состряпать"],
    "изготовиться": ["приготовиться"],
    "изготовление": ["выработка", "производство", "приготовление", "фабрикация"],
    "изготовленный": ["сделанный"],
    "изготовленье": ["изготовление"],
    "изготовляв": ["изготовлявши"],
    "изготовлявши": ["изготовляв"],
    "изготовлять": ["создавать", "делать", "производить", "изготавливать", "сооружать", "мастерить", "готовить", "приготовлять", "подготавливать", "стряпать"],
    "изготовляться": ["изготавливаться"],
    "изграфив": ["изграфивши"],
    "изграфивши": ["изграфив"],
    "изграфляв": ["изграфлявши"],
    "изграфлявши": ["изграфляв"],
    "изгрызав": ["изгрызавши"],
    "изгрызавши": ["изгрызав"],
    "изгрязнив": ["изгрязнивши"],
    "изгрязнивши": ["изгрязнив"],
    "изгрязняв": ["изгрязнявши"],
    "изгрязнявши": ["изгрязняв"],
    "изгубив": ["изгубивши"],
    "изгубивши": ["изгубив"],
    "изгубляв": ["изгублявши"],
    "изгублявши": ["изгубляв"],
    "издав": ["издавши"],
    "издавав": ["издававши"],
    "издававши": ["издавав"],
    "издаваемый": ["выпускаемый", "публикуемый", "испускаемый"],
    "издавать": ["публиковать", "выпускать", "печатать", "обнародовать", "испускать", "источать"],
    "издавши": ["издав"],
    "издаивав": ["издаивавши"],
    "издаивавши": ["издаивав"],
    "издалбливав": ["издалбливавши"],
    "издалбливавши": ["издалбливав"],
    "издалека": ["издалёка", "издалече", "издали"],
    "издалеча": ["издалека", "издалёка", "издалече", "издалечка", "издали"],
    "издали": ["издалека", "издалёка", "издалеча", "издалече", "издалечка", "издальки", "издаля"],
    "издальки": ["издалека", "издалёка", "издали", "издалече", "издалечка", "издаля"],
    "издаля": ["издалека", "издалёка", "издали", "издалече", "издалечка", "издальки"],
    "издалёка": ["издалека", "издалече", "издалечка", "издали"],
    "издание": ["публикация", "обнародование", "выпуск", "печать", "наименование", "тираж"],
    "издательство": ["издательский дом", "изд-во"],
    "издательствовав": ["издательствовавши"],
    "издательствовавши": ["издательствовав"],
    "издать": ["напечатать", "опубликовать", "выпустить", "обнародовать", "произвести", "испустить"],
    "издевательски": ["измывательски", "глумливо", "саркастически", "насмешливо"],
    "издеваться": ["измываться", "глумиться", "ашеульничать", "ашаулить"],
    "изделав": ["изделавши"],
    "изделавши": ["изделав"],
    "изделие": ["изготовление", "выделка", "производство", "продукт", "товар"],
    "изделывав": ["изделывавши"],
    "изделывавши": ["изделывав"],
    "изделье": ["барщина"],
    "издержав": ["издержавши"],
    "издержавши": ["издержав"],
    "издержать": ["затратить", "израсходовать", "истратить", "потратить", "прожить", "убухать", "угрохать", "ухлопать", "ухнуть"],
    "издерживав": ["издерживавши"],
    "издерживавши": ["издерживав"],
    "издерживаться": ["тратиться"],
    "издетства": ["сыздетства"],
    "издигнатина": ["височина", "възвишение", "издатина"],
    "издирав": ["издиравши"],
    "издиравши": ["издирав"],
    "издоив": ["издоивши"],
    "издоивши": ["издоив"],
    "издолбив": ["издолбивши"],
    "издолбивши": ["издолбив"],
    "издохнув": ["издохнувши"],
    "издохнувши": ["издохнув"],
    "издохнуть": ["пасть", "сдохнуть", "подохнуть", "околеть", "поколеть"],
    "издразнив": ["издразнивши"],
    "издразнивши": ["издразнив"],
    "издревле": ["издавна", "сыздревле", "искони", "исстари", "с давних пор", "с покон веку"],
    "издробив": ["издробивши"],
    "издробивши": ["издробив"],
    "издробить": ["раздробить"],
    "издробиться": ["раздробиться"],
    "издробляв": ["издроблявши"],
    "издроблявши": ["издробляв"],
    "издроблять": ["раздроблять"],
    "издробляться": ["раздробляться"],
    "издрогнув": ["издрогнувши"],
    "издрогнувши": ["издрогнув"],
    "издръжливост": ["устойчивост"],
    "издырявев": ["издырявевши"],
    "издырявевши": ["издырявев"],
    "издырявив": ["издырявивши"],
    "издырявивши": ["издырявив"],
    "издырявливав": ["издырявливавши"],
    "издырявливавши": ["издырявливав"],
    "издыхав": ["издыхавши"],
    "издыхавши": ["издыхав"],
    "издыханье": ["издыхание"],
    "издыхающий": ["помирающий"],
    "издёргав": ["издёргавши"],
    "издёргавши": ["издёргав"],
    "издёргивав": ["издёргивавши"],
    "издёргивавши": ["издёргивав"],
    "изжалив": ["изжаливши"],
    "изжаливав": ["изжаливавши"],
    "изжаливавши": ["изжаливав"],
    "изжаливши": ["изжалив"],
    "изжарив": ["изжаривши"],
    "изжаривав": ["изжаривавши"],
    "изжаривавши": ["изжаривав"],
    "изжаривать": ["жарить", "перегревать"],
    "изжаривши": ["изжарив"],
    "изжарить": ["зажарить", "пожарить"],
    "изжевав": ["изжевавши"],
    "изжевавши": ["изжевав"],
    "изжелта": ["впрожелть"],
    "изжелта-беловатый": ["изжелта-белый"],
    "изжелта-белый": ["изжелта-беловатый"],
    "изжелта-бледный": ["желтовато-бледный"],
    "изжелтев": ["изжелтевши"],
    "изжелтевши": ["изжелтев"],
    "изжелтив": ["изжелтивши"],
    "изжелтивши": ["изжелтив"],
    "изженив": ["изженивши"],
    "изженивши": ["изженив"],
    "изжечься": ["обжечься"],
    "изжив": ["изживши"],
    "изживав": ["изживавши"],
    "изживавши": ["изживав"],
    "изживать": ["искоренять", "устранять"],
    "изживши": ["изжив"],
    "изжившись": ["забывшись", "изгладившись", "искоренившись", "подзабывшись", "позабывшись", "улетучившись", "уничтожившись"],
    "изжигав": ["изжигавши"],
    "изжигавши": ["изжигав"],
    "изжить": ["искоренить", "устранить"],
    "изжухнув": ["изжухнувши"],
    "изжухнувши": ["изжухнув"],
    "изжёвывав": ["изжёвывавши"],
    "изжёвывавши": ["изжёвывав"],
    "иззеленив": ["иззеленивши"],
    "иззеленивши": ["иззеленив"],
    "иззолотив": ["иззолотивши"],
    "иззолотивши": ["иззолотив"],
    "иззубрив": ["иззубривши"],
    "иззубривав": ["иззубривавши"],
    "иззубривавши": ["иззубривав"],
    "иззубривши": ["иззубрив"],
    "иззябнув": ["иззябнувши"],
    "иззябнувши": ["иззябнув"],
    "иззябнуть": ["продрогнуть"],
    "иззябнуться": ["иззябнуть"],
    "изи": ["легко", "легкотня", "изи-пизи"],
    "изида": ["исида"],
    "изисканост": ["изтънченост", "префиненост", "финност", "деликатност"],
    "изкоп": ["канавка", "ров", "яма"],
    "излавливав": ["излавливавши"],
    "излавливавши": ["излавливав"],
    "излагав": ["излагавши"],
    "излагавши": ["излагав"],
    "излагать": ["рассказывать", "повествовать", "сообщать", "формулировать"],
    "изладив": ["изладивши"],
    "изладивши": ["изладив"],
    "изладить": ["приспособить", "смастерить", "соорудить", "сработать", "устроить"],
    "излаживав": ["излаживавши"],
    "излаживавши": ["излаживав"],
    "излазав": ["излазавши"],
    "излазавши": ["излазав"],
    "излазив": ["излазивши"],
    "излазивши": ["излазив"],
    "излазить": ["излазать", "облазить", "перелазить"],
    "изламывав": ["изламывавши"],
    "изламывавши": ["изламывав"],
    "излатав": ["излатавши"],
    "излатавши": ["излатав"],
    "излаяв": ["излаявши"],
    "излаявши": ["излаяв"],
    "излаять": ["выругать", "выбранить"],
    "излениваться": ["облениваться", "разлениваться"],
    "излениться": ["облениться", "разлениться"],
    "излепив": ["излепивши"],
    "излепивши": ["излепив"],
    "излепливав": ["излепливавши"],
    "излепливавши": ["излепливав"],
    "излепляв": ["излеплявши"],
    "излеплявши": ["излепляв"],
    "излетав": ["излетавши"],
    "излетавши": ["излетав"],
    "излетев": ["излетевши"],
    "излетевши": ["излетев"],
    "излеченье": ["излечение"],
    "излечив": ["излечивши"],
    "излечивав": ["излечивавши"],
    "излечивавши": ["излечивав"],
    "излечивать": ["исцелять", "вылечивать"],
    "излечиваться": ["выздоравливать"],
    "излечивающий": ["исцеляющий"],
    "излечивши": ["излечив"],
    "излечить": ["вылечить", "исцелить"],
    "изливав": ["изливавши"],
    "изливавши": ["изливав"],
    "изливаться": ["выливаться", "вытекать", "литься", "источаться"],
    "изливши": ["излив"],
    "излизав": ["излизавши"],
    "излизавши": ["излизав"],
    "излизывав": ["излизывавши"],
    "излизывавши": ["излизывав"],
    "излиновав": ["излиновавши"],
    "излиновавши": ["излиновав"],
    "излить душу": ["отвести душу"],
    "излиться": ["вылиться", "вытечь", "истечь"],
    "излишек": ["избыток", "излишество"],
    "излишествовав": ["излишествовавши"],
    "излишествовавши": ["излишествовав"],
    "излишне": ["чересчур", "чрезмерно", "очень", "слишком", "сильно", "сверх меры", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно", "шибко", "больно", "оченно"],
    "излишний": ["избыточный", "лишний", "чрезмерный", "непомерный", "ненужный", "бесполезный", "напрасный", "ненадобный", "никчёмный", "неуместный"],
    "излиянье": ["излияние"],
    "изловив": ["изловивши"],
    "изловивши": ["изловив"],
    "изловить": ["поймать", "добыть"],
    "изловляв": ["изловлявши"],
    "изловлявши": ["изловляв"],
    "изловчаться": ["наловчаться", "исхитряться", "изворачиваться", "хитрить"],
    "излог": ["изложина"],
    "изложба": ["изложение", "излагане", "показ", "демонстрация"],
    "изложение": ["изложенье"],
    "изложенье": ["изложение"],
    "изложив": ["изложивши"],
    "изложивши": ["изложив"],
    "изложить": ["высказать", "рассказать"],
    "изломав": ["изломавши"],
    "изломавши": ["изломав"],
    "изломив": ["изломивши"],
    "изломивши": ["изломив"],
    "изломить": ["надломить"],
    "изломиться": ["надломиться"],
    "излохматив": ["излохмативши"],
    "излохмативши": ["излохматив"],
    "излука": ["излучина", "колено"],
    "излукавиться": ["изовраться", "изолгаться"],
    "излупив": ["излупивши"],
    "излупивши": ["излупив"],
    "излупцевав": ["излупцевавши"],
    "излупцевавши": ["излупцевав"],
    "излупцевать": ["отколотить", "поколотить", "измутузить", "исхлестать"],
    "излучав": ["излучавши"],
    "излучавши": ["излучав"],
    "излучательный": ["радиативный"],
    "излучать": ["светиться", "сиять"],
    "излучаться": ["испускаться", "выделяться", "исходить"],
    "излучение": ["испускание"],
    "излучив": ["излучивши"],
    "излучивши": ["излучив"],
    "излучина": ["поворот", "изгиб", "извилина", "колено"],
    "излучистый": ["извилистый"],
    "излюбив": ["излюбивши"],
    "излюбивши": ["излюбив"],
    "изляпав": ["изляпавши"],
    "изляпавши": ["изляпав"],
    "измазав": ["измазавши"],
    "измазавши": ["измазав"],
    "измазать": ["вымазать"],
    "измазывав": ["измазывавши"],
    "измазывавши": ["измазывав"],
    "измазывать": ["вымазывать"],
    "измазюкав": ["измазюкавши"],
    "измазюкавши": ["измазюкав"],
    "измазюкаться": ["измызгаться"],
    "измазюкивав": ["измазюкивавши"],
    "измазюкивавши": ["измазюкивав"],
    "измаил": ["исмаил"],
    "измала": ["сызмала"],
    "измалевав": ["измалевавши"],
    "измалевавши": ["измалевав"],
    "измалывав": ["измалывавши"],
    "измалывавши": ["измалывав"],
    "измальство": ["детство"],
    "измалёвывав": ["измалёвывавши"],
    "измалёвывавши": ["измалёвывав"],
    "измалёвывавшийся": ["раскрашивавшийся", "разрисовывавшийся", "исписывавшийся"],
    "измама": ["лъжа"],
    "измамник": ["лъжец", "шарлатании", "мошеник", "изнудвач"],
    "измарав": ["измаравши"],
    "измаравши": ["измарав"],
    "измарать": ["выпачкать", "изгрязнить"],
    "измараться": ["выпачкаться", "загрязниться"],
    "измарывав": ["измарывавши"],
    "измарывавши": ["измарывав"],
    "измаслив": ["измасливши"],
    "измасливав": ["измасливавши"],
    "измасливавши": ["измасливав"],
    "измасливши": ["измаслив"],
    "изматерив": ["изматеривши"],
    "изматеривши": ["изматерив"],
    "изматывав": ["изматывавши"],
    "изматывавши": ["изматывав"],
    "изматывать": ["выматывать", "изнурять"],
    "измачивав": ["измачивавши"],
    "измачивавши": ["измачивав"],
    "измаяв": ["измаявши"],
    "измаявши": ["измаяв"],
    "измежевав": ["измежевавши"],
    "измежевавши": ["измежевав"],
    "измелив": ["измеливши"],
    "измеливши": ["измелив"],
    "измельчав": ["измельчавши"],
    "измельчавши": ["измельчав"],
    "измельчать": ["скукожиться", "обмельчать", "пасть"],
    "измельчив": ["измельчивши"],
    "измельчивши": ["измельчив"],
    "измельчитель": ["диспоузер"],
    "измельчитель пищевых отходов": ["диспоузер"],
    "измена": ["предательство", "настороженность", "подозрительность"],
    "изменение": ["перемена", "правка"],
    "измененье": ["изменение"],
    "изменив": ["изменивши"],
    "изменивши": ["изменив"],
    "изменимый": ["изменный"],
    "изменить": ["модифицировать", "переиначить"],
    "измениться": ["поменяться", "перемениться"],
    "изменник": ["предатель"],
    "изменница": ["предательница"],
    "изменнический": ["предательский"],
    "изменчиво": ["переменчиво"],
    "изменчивость": ["непостоянство", "переменчивость"],
    "изменчивый": ["непостоянный", "переменчивый", "переменный", "неустойчивый"],
    "изменщик": ["изменник"],
    "изменщица": ["изменница"],
    "изменяв": ["изменявши"],
    "изменявши": ["изменяв"],
    "изменяемый": ["исправимый", "изменчивый"],
    "изменять": ["менять", "модифицировать"],
    "изменять к лучшему": ["улучшать"],
    "изменяться": ["меняться", "модифицироваться", "преобразовываться"],
    "изменяясь": ["меняясь", "модифицируясь", "преобразовываясь"],
    "измерение": ["замер"],
    "измеренье": ["измерение"],
    "измерив": ["измеривши"],
    "измеривши": ["измерив"],
    "измеримость": ["измеряемость"],
    "измерительный инструмент": ["средство изменения", "измерительный прибор"],
    "измеряв": ["измерявши"],
    "измерявши": ["измеряв"],
    "измеряемость": ["измеримость"],
    "измерять": ["мерить"],
    "изметелив": ["изметеливши"],
    "изметеливши": ["изметелив"],
    "измиловав": ["измиловавши"],
    "измиловавши": ["измиловав"],
    "изминав": ["изминавши"],
    "изминавши": ["изминав"],
    "изминаться": ["мяться", "сминаться"],
    "измислица": ["небивалица", "неистина", "недействителност"],
    "измлада": ["смолоду", "сызмальства"],
    "измождав": ["измождавши"],
    "измождавши": ["измождав"],
    "изможденье": ["измождение"],
    "измождённый": ["изнурённый", "измученный", "обессиленный", "замордованный"],
    "измокав": ["измокавши"],
    "измокавши": ["измокав"],
    "измокнув": ["измокнувши"],
    "измокнувши": ["измокнув"],
    "измолачивав": ["измолачивавши"],
    "измолачивавши": ["измолачивав"],
    "измолов": ["измоловши"],
    "измоловши": ["измолов"],
    "измолотив": ["измолотивши"],
    "измолотивши": ["измолотив"],
    "измолоть": ["смолоть"],
    "измордовав": ["измордовавши"],
    "измордовавши": ["измордовав"],
    "изморив": ["изморивши"],
    "изморивши": ["изморив"],
    "изморить": ["изнурить", "приморить"],
    "измориться": ["измучиться", "измордоваться"],
    "изморозив": ["изморозивши"],
    "изморозивши": ["изморозив"],
    "изморозь": ["иней"],
    "изморось": ["морось", "мжичка", "мжица"],
    "изморщив": ["изморщивши"],
    "изморщивши": ["изморщив"],
    "изморщинив": ["изморщинивши"],
    "изморщинивши": ["изморщинив"],
    "измотав": ["измотавши"],
    "измотавши": ["измотав"],
    "измотанность": ["изнурённость"],
    "измотать": ["вымотать", "изнурить"],
    "измочалив": ["измочаливши"],
    "измочаливав": ["измочаливавши"],
    "измочаливавши": ["измочаливав"],
    "измочаливши": ["измочалив"],
    "измочив": ["измочивши"],
    "измочивши": ["измочив"],
    "измудохав": ["измудохавши"],
    "измудохавши": ["измудохав"],
    "измуслив": ["измусливши"],
    "измусливав": ["измусливавши"],
    "измусливавши": ["измусливав"],
    "измусливши": ["измуслив"],
    "измусолив": ["измусоливши"],
    "измусоливав": ["измусоливавши"],
    "измусоливавши": ["измусоливав"],
    "измусоливши": ["измусолив"],
    "измутузив": ["измутузивши"],
    "измутузивши": ["измутузив"],
    "измутузить": ["избить", "побить", "поколотить"],
    "измучав": ["измучавши"],
    "измучавши": ["измучав"],
    "измученно": ["устало"],
    "измучив": ["измучивши"],
    "измучивав": ["измучивавши"],
    "измучивавши": ["измучивав"],
    "измучивши": ["измучив"],
    "измучивший": ["истязавший"],
    "измучить": ["замучить", "замучать"],
    "измучиться": ["исстрадаться", "изволноваться"],
    "измыв": ["измывши"],
    "измываться": ["изгаляться", "издеваться"],
    "измывши": ["измыв"],
    "измызгав": ["измызгавши"],
    "измызгавши": ["измызгав"],
    "измызгаться": ["измазюкаться"],
    "измызгивав": ["измызгивавши"],
    "измызгивавши": ["измызгивав"],
    "измыкав": ["измыкавши"],
    "измыкавши": ["измыкав"],
    "измылив": ["измыливши"],
    "измыливав": ["измыливавши"],
    "измыливавши": ["измыливав"],
    "измыливши": ["измылив"],
    "измыслив": ["измысливши"],
    "измысливав": ["измысливавши"],
    "измысливавши": ["измысливав"],
    "измысливать": ["измышлять", "выдумывать", "придумывать"],
    "измысливши": ["измыслив"],
    "измытарив": ["измытаривши"],
    "измытаривав": ["измытаривавши"],
    "измытаривавши": ["измытаривав"],
    "измытаривши": ["измытарив"],
    "измышление": ["измышленье"],
    "измышленье": ["измышление"],
    "измышляв": ["измышлявши"],
    "измышлявши": ["измышляв"],
    "измышлять": ["выдумывать", "изобретать", "измысливать", "придумывать", "сочинять", "фабриковать"],
    "измяв": ["измявши"],
    "измявши": ["измяв"],
    "измякав": ["измякавши"],
    "измякавши": ["измякав"],
    "измякать": ["намякать", "размякать"],
    "измякнув": ["измякнувши"],
    "измякнувши": ["измякнув"],
    "измяться": ["помяться"],
    "измёрзнув": ["измёрзнувши"],
    "измёрзнувши": ["измёрзнув"],
    "измёрзнуть": ["иззябнуть"],
    "изнаглев": ["изнаглевши"],
    "изнаглевши": ["изнаглев"],
    "изнасиловав": ["изнасиловавши"],
    "изнасиловавши": ["изнасиловав"],
    "изнасилование": ["износ"],
    "изнасилованье": ["изнасилование"],
    "изнасильничав": ["изнасильничавши"],
    "изнасильничавши": ["изнасильничав"],
    "изнасильничать": ["изнасиловать"],
    "изнахратив": ["изнахративши"],
    "изнахративши": ["изнахратив"],
    "изначально": ["искони", "первоначально"],
    "изначальный": ["первоначальный"],
    "изнашивав": ["изнашивавши"],
    "изнашивавши": ["изнашивав"],
    "изневяра": ["измяна", "вероломство"],
    "изнежив": ["изнеживши"],
    "изнеживав": ["изнеживавши"],
    "изнеживавши": ["изнеживав"],
    "изнеживши": ["изнежив"],
    "изнемогав": ["изнемогавши"],
    "изнемогавши": ["изнемогав"],
    "изнемождав": ["изнемождавши"],
    "изнемождавши": ["изнемождав"],
    "изнемождать": ["обессиливать"],
    "изнеможение": ["изнемождение"],
    "изнеможенье": ["изнеможение"],
    "изнеможённый": ["обессиленный"],
    "изнемочь": ["ослабеть"],
    "изнемощялост": ["изнемощение", "отпадналост", "слабост"],
    "изнизав": ["изнизавши"],
    "изнизавши": ["изнизав"],
    "изнизывав": ["изнизывавши"],
    "изнизывавши": ["изнизывав"],
    "изник": ["никея", "исник"],
    "изникав": ["изникавши"],
    "изникавши": ["изникав"],
    "изникнув": ["изникнувши"],
    "изникнувши": ["изникнув"],
    "изнимав": ["изнимавши"],
    "изнимавши": ["изнимав"],
    "изничтожав": ["изничтожавши"],
    "изничтожавши": ["изничтожав"],
    "изничтожение": ["уничтожение", "истребление"],
    "изничтожив": ["изничтоживши"],
    "изничтоживши": ["изничтожив"],
    "изничтожить": ["истребить", "искоренить"],
    "изнищав": ["изнищавши"],
    "изнищавши": ["изнищав"],
    "изноровив": ["изноровивши"],
    "изноровивши": ["изноровив"],
    "износив": ["износивши"],
    "износивши": ["износив"],
    "износостойкий": ["износоустойчивый"],
    "износоустойчивость": ["износостойкость"],
    "износоустойчивый": ["износостойкий"],
    "изнуда": ["принуда", "насилие", "натиск", "принуждение", "шантаж", "изнудване"],
    "изнуренье": ["изнурение"],
    "изнурив": ["изнуривши"],
    "изнуривши": ["изнурив"],
    "изнурительный": ["уморительный"],
    "изнуряв": ["изнурявши"],
    "изнурявши": ["изнуряв"],
    "изнурять": ["утомлять"],
    "изнурённо": ["обессиленно", "утомлённо"],
    "изнутри": ["наружу", "внутри", "вовне", "с изнанки"],
    "изныв": ["изнывши"],
    "изнывав": ["изнывавши"],
    "изнывавши": ["изнывав"],
    "изныванье": ["изнывание"],
    "изнывать": ["томиться", "страдать", "изнемогать"],
    "изнывши": ["изныв"],
    "изныряв": ["изнырявши"],
    "изнырявши": ["изныряв"],
    "изняв": ["изнявши"],
    "изнявши": ["изняв"],
    "изо": ["из", "от", "со"],
    "изо всех сил": ["что есть силы", "что было силы", "со всей мочи", "со всей дури"],
    "изо дня в день": ["ежедневно", "постоянно", "день ото дня"],
    "изо-": ["из-", "ис-"],
    "изоаллобара": ["изаллобара"],
    "изоаллотерма": ["изаллотерма"],
    "изоамилацетат": ["изопентиловый эфир уксусной кислоты", "грушевая эссенция"],
    "изоанемона": ["изанемона"],
    "изоаномала": ["изаномала"],
    "изобарический": ["изобарный"],
    "изобарный": ["изобарический"],
    "изобидев": ["изобидевши"],
    "изобидевши": ["изобидев"],
    "изобижав": ["изобижавши"],
    "изобижавши": ["изобижав"],
    "изобилие": ["обилие", "множество", "щедрость", "изобилье", "гобзование"],
    "изобиловав": ["изобиловавши"],
    "изобиловавши": ["изобиловав"],
    "изобиловать": ["избыточествовать"],
    "изобилующий": ["богатый", "обильный"],
    "изобилье": ["изобилие"],
    "изобильный": ["богатый", "обильный"],
    "изобличав": ["изобличавши"],
    "изобличавши": ["изобличав"],
    "изобличать": ["уличать", "разоблачать"],
    "изобличенье": ["изобличение"],
    "изобличив": ["изобличивши"],
    "изобличивши": ["изобличив"],
    "изобличить": ["выявить", "уличить", "приличить"],
    "изображав": ["изображавши"],
    "изображавши": ["изображав"],
    "изображение": ["рисование", "изображенье", "картинка", "отображение"],
    "изображенье": ["изображение"],
    "изобразив": ["изобразивши"],
    "изобразивши": ["изобразив"],
    "изобразитель": ["отобразитель"],
    "изобретав": ["изобретавши"],
    "изобретавши": ["изобретав"],
    "изобретатель": ["новатор", "открыватель"],
    "изобретательно": ["хитро"],
    "изобретательность": ["находчивость", "хитроумие"],
    "изобретательный": ["находчивый", "созидательный"],
    "изобретать": ["выдумывать", "придумывать", "кулибничать"],
    "изобретенье": ["изобретение"],
    "изобутан": ["метилпропан"],
    "изобутен": ["изобутилен"],
    "изобутилен": ["изобутен"],
    "изовраться": ["изолгаться", "излукавиться"],
    "изовсюду": ["отовсюду"],
    "изогалинный": ["изохалинный"],
    "изогелия": ["постеризация"],
    "изогемолизин": ["изолизин"],
    "изогеотерма": ["геоизотерма"],
    "изогипса": ["горизонталь"],
    "изогнув": ["изогнувши"],
    "изогнувши": ["изогнув"],
    "изогнутый": ["согнутый", "загнутый", "кривой", "криволинейный"],
    "изогнуться": ["выгнуться", "прогнуться"],
    "изогона": ["изогональ"],
    "изографика": ["изография", "изонить", "ниткография"],
    "изоденса": ["изоденсита"],
    "изодрав": ["изодравши"],
    "изодравши": ["изодрав"],
    "изодранный": ["изорванный", "порванный", "исцарапанный", "израненный", "содранный", "драный", "рваный", "дырявый"],
    "изозим": ["изофермент", "изоэнзим"],
    "изок": ["разноцвет", "червень"],
    "изократия": ["равноправие", "равновластие"],
    "изолгаться": ["изовраться"],
    "изолиния": ["линия уровня"],
    "изолировав": ["изолировавши"],
    "изолировавши": ["изолировав"],
    "изолирование": ["изоляция"],
    "изолированность": ["изоляция"],
    "изолированный": ["отдельный", "единичный"],
    "изолирующий": ["изоляционный", "аморфный", "корневой"],
    "изолятор": ["диэлектрик", "больница", "тюрьма"],
    "изоляционный": ["изолирующий"],
    "изомлев": ["изомлевши"],
    "изомлевши": ["изомлев"],
    "изоморфизм": ["изоморфия"],
    "изоморфия": ["изоморфизм"],
    "изонафтол": ["бета-нафтол", "вета-гидроксинафталин"],
    "изониазид": ["тубазид"],
    "изонить": ["нитяная графика", "изографика", "вышивка по картону"],
    "изоосмотический": ["изотонический"],
    "изопаха": ["изопахита"],
    "изопахита": ["изопаха"],
    "изопаченост": ["извращаване", "изопачаване", "изопачение", "извращение", "изкривеност"],
    "изопрев": ["изопревши"],
    "изопревши": ["изопрев"],
    "изопропиловый спирт": ["изопропанол", "диметилкарбинол"],
    "изорвав": ["изорвавши"],
    "изорвавши": ["изорвав"],
    "изоржавев": ["изоржавевши"],
    "изоржавевши": ["изоржавев"],
    "изосейсма": ["изосейста", "изосфигма"],
    "изосейста": ["изосейсма"],
    "изосиллабизм": ["равносложность"],
    "изоспин": ["изотопический спин"],
    "изоспориаз": ["кокцидиоз"],
    "изостлав": ["изостлавши"],
    "изостлавши": ["изостлав"],
    "изострив": ["изостривши"],
    "изостривши": ["изострив"],
    "изострить": ["заострить"],
    "изостриться": ["заостриться"],
    "изостряв": ["изострявши"],
    "изострявши": ["изостряв"],
    "изострять": ["острить", "заострять"],
    "изостряться": ["заостряться"],
    "изоткав": ["изоткавши"],
    "изоткавши": ["изоткав"],
    "изотонический": ["изотоничный", "изотонный"],
    "изотонный": ["изотонический"],
    "изотоп": ["нуклид"],
    "изотропность": ["изотропия"],
    "изотропный": ["изотропический", "однородный"],
    "изофермент": ["изозим", "изоэнзим"],
    "изофот": ["изофота"],
    "изофота": ["изофот"],
    "изохалинный": ["изогалинный"],
    "изохорный": ["изохорический"],
    "изохроматический": ["изохромный", "изохроматичный"],
    "изошкола": ["художественная школа"],
    "изощрив": ["изощривши"],
    "изощривши": ["изощрив"],
    "изощрившийся": ["искусный", "опытный", "изловчившийся", "ловкий", "умелый", "наметавшийся", "наторелый", "способный", "знаток", "мастер"],
    "изощрить": ["отточить", "наточить", "заострить", "развить", "усовершенствовать"],
    "изощряв": ["изощрявши"],
    "изощрявши": ["изощряв"],
    "изощрять": ["точить", "натачивать", "заострять"],
    "изощряться": ["придумывать"],
    "изощрённый": ["виртуозный", "острый", "отточенный", "тонкий", "утончённый", "ловкий", "изобретательный", "изворотливый", "заточенный", "наточенный"],
    "изоэнзим": ["изозим", "изофермент"],
    "изоэнтропа": ["адиабата"],
    "изоэнтропийный": ["изоэнтропический"],
    "изоэнтропический": ["изоэнтропийный"],
    "изработаться": ["износиться"],
    "изработка": ["направа", "работа", "фабрикация", "производство"],
    "израз": ["изречение", "фраза"],
    "изразец": ["кафель"],
    "изразителност": ["образност", "изразност", "експресивност"],
    "изразцовый": ["кафельный"],
    "израилец": ["израильтянин"],
    "израиль": ["государство израиль", "деревня израиловка", "израиловка", "жидостан", "безарабия", "еврей"],
    "израильско-российский": ["российско-израильский"],
    "израильтянин": ["иудей", "израилец", "еврей"],
    "изранив": ["изранивши"],
    "изранивши": ["изранив"],
    "израстав": ["израставши"],
    "израставши": ["израстав"],
    "израсходовав": ["израсходовавши"],
    "израсходовавши": ["израсходовав"],
    "израсходовать": ["истратить", "употребить", "растранжирить"],
    "изредив": ["изредивши"],
    "изредивши": ["изредив"],
    "изредка": ["иногда", "нечасто", "редко", "годом-родом", "кое-где", "местами"],
    "изреживав": ["изреживавши"],
    "изреживавши": ["изреживав"],
    "изреживать": ["прореживать"],
    "изрезав": ["изрезавши"],
    "изрезавши": ["изрезав"],
    "изрезывав": ["изрезывавши"],
    "изрезывавши": ["изрезывав"],
    "изрекав": ["изрекавши"],
    "изрекавши": ["изрекав"],
    "изречение": ["афоризм"],
    "изреченье": ["изречение"],
    "изречь": ["произнести", "сказать", "молвить"],
    "изрешетив": ["изрешетивши"],
    "изрешетивши": ["изрешетив"],
    "изрешечивав": ["изрешечивавши"],
    "изрешечивавши": ["изрешечивав"],
    "изрешечивать": ["решетить"],
    "изрешечиваться": ["решетиться", "дырявиться", "продырявливаться"],
    "изринув": ["изринувши"],
    "изринувши": ["изринув"],
    "изринуть": ["извлечь", "извергнуть", "низринуть"],
    "изрисовав": ["изрисовавши"],
    "изрисовавши": ["изрисовав"],
    "изрисовывав": ["изрисовывавши"],
    "изрисовывавши": ["изрисовывав"],
    "изрисовывать": ["зарисовывать"],
    "изрод": ["урод", "изчадие", "изверг", "дегенерат"],
    "изрубав": ["изрубавши"],
    "изрубавши": ["изрубав"],
    "изрубив": ["изрубивши"],
    "изрубивши": ["изрубив"],
    "изрубцевав": ["изрубцевавши"],
    "изрубцевавши": ["изрубцевав"],
    "изрубцовывав": ["изрубцовывавши"],
    "изрубцовывавши": ["изрубцовывав"],
    "изругав": ["изругавши"],
    "изругавши": ["изругав"],
    "изрыв": ["изрывши"],
    "изрывав": ["изрывавши"],
    "изрывавши": ["изрывав"],
    "изрывши": ["изрыв"],
    "изрыгав": ["изрыгавши"],
    "изрыгавши": ["изрыгав"],
    "изрыгать": ["отрыгивать", "извергать", "исторгать"],
    "изрыгнув": ["изрыгнувши"],
    "изрыгнувши": ["изрыгнув"],
    "изрыскав": ["изрыскавши"],
    "изрыскавши": ["изрыскав"],
    "изрыхлив": ["изрыхливши"],
    "изрыхливши": ["изрыхлив"],
    "изрядно": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "изрядный": ["порядочный", "значительный", "крупный", "большой"],
    "изселник": ["преселник", "емигрант"],
    "изстинка": ["настинка", "простуда", "простудяване", "треска", "болест"],
    "изубрав": ["изубравши"],
    "изубравши": ["изубрав"],
    "изубрать": ["разубрать"],
    "изубыточив": ["изубыточивши"],
    "изубыточивав": ["изубыточивавши"],
    "изубыточивавши": ["изубыточивав"],
    "изубыточивать": ["разорять"],
    "изубыточивши": ["изубыточив"],
    "изубыточить": ["разорить"],
    "изубытчив": ["изубытчивши"],
    "изубытчивши": ["изубытчив"],
    "изувер": ["фанатик", "изверг", "садист"],
    "изуверство": ["жестокость"],
    "изуверствовав": ["изуверствовавши"],
    "изуверствовавши": ["изуверствовав"],
    "изуверствовать": ["зверствовать"],
    "изувесив": ["изувесивши"],
    "изувесивши": ["изувесив"],
    "изувесить": ["изувешать"],
    "изувеситься": ["изувешаться"],
    "изувечив": ["изувечивши"],
    "изувечивав": ["изувечивавши"],
    "изувечивавши": ["изувечивав"],
    "изувечиваться": ["искалечиваться"],
    "изувечивши": ["изувечив"],
    "изувечить": ["искалечить", "покалечить", "изуродовать", "исковеркать", "испортить"],
    "изувечиться": ["искалечиться"],
    "изувешав": ["изувешавши"],
    "изувешавши": ["изувешав"],
    "изувешать": ["изувесить"],
    "изувешаться": ["изувеситься"],
    "изувешивав": ["изувешивавши"],
    "изувешивавши": ["изувешивав"],
    "изузорив": ["изузоривши"],
    "изузоривши": ["изузорив"],
    "изукрасив": ["изукрасивши"],
    "изукрасивши": ["изукрасив"],
    "изукрашивав": ["изукрашивавши"],
    "изукрашивавши": ["изукрашивав"],
    "изумив": ["изумивши"],
    "изумивши": ["изумив"],
    "изумительно": ["восхитительно"],
    "изумительный": ["восхитительный", "поразительный", "удивительный", "превосходный", "великолепный"],
    "изумить": ["поразить", "огорошить", "ошеломить"],
    "изумиться": ["поразиться"],
    "изумление": ["удивление"],
    "изумленье": ["изумление"],
    "изумляв": ["изумлявши"],
    "изумлявши": ["изумляв"],
    "изумлять": ["поражать"],
    "изумлённо": ["удивлённо"],
    "изумлённость": ["изумление"],
    "изумлённый": ["удивлённый", "поражённый", "восхищённый", "потрясённый", "шокированный"],
    "изумруд": ["смарагд"],
    "изумрудно-зелёный": ["ярко-зелёный"],
    "изуродовав": ["изуродовавши"],
    "изуродовавши": ["изуродовав"],
    "изуродовать": ["обезобразить", "исказить", "искалечить", "изувечить"],
    "изурочивать": ["наводить", "порча", "опризоривать"],
    "изурочить": ["сглазить", "опризорить", "испортить"],
    "изучав": ["изучавши"],
    "изучавши": ["изучав"],
    "изучение": ["изученье", "эксплорация"],
    "изученье": ["изучение"],
    "изучив": ["изучивши"],
    "изучивши": ["изучив"],
    "изучить": ["выучить", "проштудировать", "исследовать"],
    "изъебав": ["изъебавши"],
    "изъебавши": ["изъебав"],
    "изъебнуться": ["исхитриться"],
    "изъедав": ["изъедавши"],
    "изъедавши": ["изъедав"],
    "изъездив": ["изъездивши"],
    "изъездивши": ["изъездив"],
    "изъезживав": ["изъезживавши"],
    "изъезживавши": ["изъезживав"],
    "изъелозив": ["изъелозивши"],
    "изъелозивши": ["изъелозив"],
    "изъяв": ["изъявши"],
    "изъявив": ["изъявивши"],
    "изъявивши": ["изъявив"],
    "изъявительное наклонение": ["индикатив"],
    "изъявленье": ["изъявление"],
    "изъявляв": ["изъявлявши"],
    "изъявлявши": ["изъявляв"],
    "изъявлять": ["обнаруживать", "проявлять", "высказывать", "выражать"],
    "изъявляющий": ["выражающий"],
    "изъявши": ["изъяв"],
    "изъязвив": ["изъязвивши"],
    "изъязвивши": ["изъязвив"],
    "изъязвление": ["изъязвленье"],
    "изъязвляв": ["изъязвлявши"],
    "изъязвлявши": ["изъязвляв"],
    "изъян": ["дефект", "недостаток", "пробел", "несовершенство", "убыток", "ущерб", "вред"],
    "изъяснив": ["изъяснивши"],
    "изъяснивши": ["изъяснив"],
    "изъяснить": ["выразить", "высказать", "изложить", "объяснить", "растолковать"],
    "изъясниться": ["объясниться"],
    "изъясняв": ["изъяснявши"],
    "изъяснявши": ["изъясняв"],
    "изъяснять": ["объяснять"],
    "изъясняться": ["объясняться", "говорить"],
    "изъятый": ["выведенный", "выделенный", "отобранный", "исключённый", "взятый", "вынутый", "удалённый", "отнятый"],
    "изъять": ["забрать", "вынуть", "вывести", "отобрать", "конфисковать"],
    "изъятье": ["изъятие"],
    "изъёрзав": ["изъёрзавши"],
    "изъёрзавши": ["изъёрзав"],
    "изъёрзывав": ["изъёрзывавши"],
    "изъёрзывавши": ["изъёрзывав"],
    "изымав": ["изымавши"],
    "изымавши": ["изымав"],
    "изымание": ["изъятие", "устранение"],
    "изыскав": ["изыскавши"],
    "изыскавши": ["изыскав"],
    "изыскание": ["исследование", "изучение", "анализ"],
    "изысканно": ["утончённо", "изящно"],
    "изысканность": ["утончённость"],
    "изысканный": ["найденный", "изобретённый", "исследованный", "открытый"],
    "изысканье": ["изыскание"],
    "изыскательный": ["исследовательский", "изыскательский"],
    "изыскивав": ["изыскивавши"],
    "изыскивавши": ["изыскивав"],
    "изыскивать": ["находить"],
    "изюбр": ["изюбрь", "марал"],
    "изюбрь": ["изюбр", "марал"],
    "изюминка": ["изюмина"],
    "изящество": ["грация"],
    "изящная словесность": ["изящная литература"],
    "изящно": ["элегантно", "изысканно"],
    "изящность": ["грация"],
    "изящный": ["изысканный", "тонкий", "грациозный", "элегантный", "утончённый"],
    "иигх": ["тиигх"],
    "иим": ["тиим"],
    "иис": ["ис", "ий"],
    "иисус": ["хесус", "иешуа"],
    "икав": ["икавши"],
    "икавши": ["икав"],
    "икание": ["иканье"],
    "иканье": ["икание", "икота"],
    "икарос": ["фейлака", "икария", "никария"],
    "икенче": ["башка"],
    "икитос": ["амазонская венеция"],
    "икнофалангометрия": ["дактилоскопия"],
    "икнув": ["икнувши"],
    "икнувши": ["икнув"],
    "икона": ["образ", "лик"],
    "иконоборец": ["иконокласт"],
    "иконоборчество": ["иконоклазм", "иконоборство"],
    "иконоклазм": ["иконоборчество"],
    "иконописец": ["богомаз", "изограф", "образописец"],
    "иконостас": ["красный угол"],
    "икорник": ["икрянщик"],
    "икосаэдр": ["двадцатигранник"],
    "икосаэдральный": ["икосаэдрический", "двадцатигранный"],
    "икосаэдрический": ["икосаэдральный", "двадцатигранный"],
    "икоситетраэдр": ["двадцатичетырёхгранник"],
    "икота": ["икание", "иканье"],
    "икра": ["норос"],
    "икрина": ["икрянина"],
    "икрометание": ["икромёт", "нерест"],
    "икрянина": ["икрина"],
    "икрянщик": ["икорник"],
    "икс": ["экс", "игрек", "зет"],
    "иксодиоз": ["иксодидоз"],
    "икт": ["акцент"],
    "иктеричный": ["желтушный"],
    "ил": ["илос"],
    "ил-": ["а-", "ан-", "им-", "ин-", "ир-"],
    "илава": ["дойч-эйлау"],
    "иланг-иланг": ["аланг-иланг"],
    "илач": ["лекарство", "цяр", "лек", "медикамент"],
    "илбэ": ["увдис"],
    "илд": ["сэлэм", "юлд"],
    "или": ["либо", "иль", "али", "аль", "алибо", "альбо"],
    "или как": ["нет"],
    "илиил": ["илил"],
    "илил": ["илиил"],
    "илим": ["ильм"],
    "илион": ["троя", "дардания", "скамандр"],
    "илистость": ["иловатость"],
    "илистый": ["иловый", "ильный", "тинистый"],
    "илитон": ["литон"],
    "иллатив": ["направительный"],
    "иллирия": ["иллирик"],
    "иллогичный": ["алогичный"],
    "иллокутив": ["иллокуция", "иллокутивный акт"],
    "иллюзия": ["игра воображения", "искаженное восприятие", "видимость", "воздушные замки", "заблуждение", "надежда", "обман", "ложное представление", "химера", "иллюзион", "фокус"],
    "иллюзорно": ["мнимо", "призрачно"],
    "иллюзорность": ["видимость", "призрачность"],
    "иллюзорный": ["призрачный", "кажущийся"],
    "иллюминация": ["освещение", "иррадиация", "озарение"],
    "иллюминировав": ["иллюминировавши"],
    "иллюминировавши": ["иллюминировав"],
    "иллюминированная рукопись": ["лицевая рукопись"],
    "иллюминовав": ["иллюминовавши"],
    "иллюминовавши": ["иллюминовав"],
    "иллюминовать": ["иллюминировать"],
    "иллюстрация": ["иллюстрирование", "картинка", "изображение", "пример"],
    "иллюстрировав": ["иллюстрировавши"],
    "иллюстрировавши": ["иллюстрировав"],
    "иллюстрировать": ["изображать", "демонстрировать", "показывать"],
    "илнар": ["илнур"],
    "иловый": ["илистый", "ильный"],
    "илоканский": ["илокский", "илоканский язык", "илокано"],
    "илъэс": ["гъэ"],
    "иль": ["или", "аль"],
    "ильич": ["ленин"],
    "ильичёвск": ["черноморск"],
    "ильм": ["илим", "вяз"],
    "ильменит": ["титанистый железняк"],
    "ильменитовый": ["ильменитный"],
    "ильный": ["илистый", "иловый"],
    "ильхыдаг": ["ильхидаг"],
    "илья": ["илия", "ильин день"],
    "илюха": ["илья"],
    "илях": ["танъры", "алла", "ярадан", "рабби", "мевля", "худа", "чалап"],
    "илёв": ["ёло", "цябол"],
    "им-": ["а-", "ан-", "ил-", "ин-", "ир-"],
    "имав": ["имавши"],
    "имавши": ["имав"],
    "имагинативный": ["имажитивный", "воображаемый", "порождённый воображением", "порождённый фантазией", "созданный воображением", "созданный фантазией"],
    "имагинация": ["имажинация", "воображение", "представление"],
    "имаджинировать": ["имажинировать", "воображать", "представлять", "выдумывать"],
    "имажинация": ["имагинация", "воображение", "представление"],
    "имажинировать": ["имаджинировать", "воображать", "представлять", "выдумывать"],
    "имать": ["брать", "хватать", "ловить", "умыкать", "набирать", "заключать", "созывать", "доставать", "извлекать", "собирать", "взимать"],
    "имба": ["хорошее", "клёвый", "ништяк"],
    "имбалансный": ["несбалансированный"],
    "имбецил": ["дурак", "придурок"],
    "имбецильность": ["слабоумие", "имбецилизм"],
    "имбибирование": ["имбибиция", "впитывание", "пропитывание"],
    "имбирь": ["инбирь"],
    "имбрикация": ["энбрикация"],
    "имбусовый": ["инбусовый"],
    "имбусовый ключ": ["шестигранный ключ", "ключ аллена", "шестигранник"],
    "имев": ["имевши"],
    "имевши": ["имев"],
    "имевшийся": ["водившийся", "существовавший", "наличествовавший", "бывший"],
    "имение": ["поместье", "имущество", "собственность"],
    "именины": ["тезоименитство", "день ангела", "праздник"],
    "именительный": ["именующий", "называющий", "номинативный", "номинатив", "именительный падеж"],
    "именительный падеж": ["номинатив"],
    "именитый": ["известный", "популярный", "знаменитый", "почтенный", "важный"],
    "именна": ["кеподьксонди"],
    "именная часть составного сказуемого": ["предикатив"],
    "именно": ["как раз", "точно", "поимённо", "конкретно", "в частности", "то есть"],
    "именовав": ["именовавши"],
    "именовавши": ["именовав"],
    "именование": ["величание", "обзывание", "кликание", "номинация"],
    "именовать": ["звать", "называть"],
    "именоваться": ["называться", "зваться"],
    "именуемый": ["называемый"],
    "именьице": ["именье", "дом", "поместье"],
    "имеретин": ["имеретинец"],
    "имеретинец": ["имеретин"],
    "иметь": ["обладать", "владеть", "держать", "хранить", "характеризоваться", "содержать", "располагать", "жарить", "сношать", "трахать"],
    "иметь в виду": ["учитывать", "учесть", "предполагать", "подразумевать", "положить хуй"],
    "иметься": ["наличествовать", "принадлежать"],
    "имеющийся": ["наличный", "существующий"],
    "имже": ["потому", "так как", "иже"],
    "имзо": ["соядаст"],
    "имидж": ["образ"],
    "имиджборд": ["имиджборда", "борда", "доска"],
    "имиджборда": ["имиджборд", "борда", "доска"],
    "имитативность": ["подражательность"],
    "имитативный": ["имитационный", "подражательный"],
    "имитаторски": ["подражательно"],
    "имитационный": ["имитирующий", "подражательный"],
    "имитация": ["подражание", "копирование", "копия", "подделка"],
    "имитация бурной деятельности": ["ибд", "симуляция", "симулирование", "набивать себе цену", "пускать пыль в глаза"],
    "имитировав": ["имитировавши"],
    "имитировавши": ["имитировав"],
    "имитировать": ["изображать", "копировать", "подражать", "подделывать"],
    "имитирующий": ["подражающий"],
    "имитос": ["гимет"],
    "имманентно": ["неотъемлемо"],
    "имманентный": ["неотъемлемый", "исконный", "базисный", "базовый", "свойственный", "присущий", "внутренний"],
    "имматериальный": ["нематериальный", "невещественный", "нетелесный", "духовный"],
    "иммельман": ["полупетля"],
    "иммерсивный": ["погружающий"],
    "иммерсионный": ["иммерсивный"],
    "иммигрировав": ["иммигрировавши"],
    "иммигрировавши": ["иммигрировав"],
    "иммобилайзер": ["противоугонка"],
    "иммобилизатор": ["иммобилайзер"],
    "иммобилизировав": ["иммобилизировавши"],
    "иммобилизировавши": ["иммобилизировав"],
    "иммобилизировать": ["иммобилизовать", "останавливать", "остановить", "блокировать", "заблокировать", "задерживать", "задержать", "сковывать", "сковать"],
    "иммобилизовав": ["иммобилизовавши"],
    "иммобилизовавши": ["иммобилизовав"],
    "иммобилизовать": ["иммобилизировать", "обездвиживать", "обездвижить", "связывать", "связать", "замораживать", "заморозить", "останавливать", "остановить", "блокировать", "заблокировать", "задерживать", "задержать", "сковывать", "сковать"],
    "имморализм": ["аморализм"],
    "имморальный": ["аморальный", "безнравственный"],
    "иммортель": ["бессмертник", "сухоцвет"],
    "иммунизировав": ["иммунизировавши"],
    "иммунизировавши": ["иммунизировав"],
    "иммунитет": ["невосприимчивость", "резистентность", "сопротивляемость"],
    "иммунный ответ": ["иммунная реакция"],
    "иммунобиолог": ["иммунолог"],
    "иммуноглобулин": ["антитело"],
    "иммуногранула": ["иммуносфера"],
    "иммунодепрессант": ["иммуносупрессор"],
    "иммуномодулятор": ["иммуностимулятор"],
    "иммуноподавляющий": ["иммуносупрессивный"],
    "иммуностимулятор": ["иммуномодулятор"],
    "иммуносупрессивный": ["иммуноподавляющий", "иммунодепрессивный"],
    "иммуносупрессия": ["иммунодепрессия"],
    "иммуносупрессор": ["иммунодепрессант"],
    "иммуносфера": ["иммуногранула"],
    "имот": ["имане", "имущество"],
    "имотност": ["заможност", "благосъстояние", "богатство"],
    "импеданс": ["полное сопротивление", "комплексное сопротивление"],
    "императив": ["веление", "требование", "повелительное наклонение"],
    "императивность": ["ультимативность", "категоричность"],
    "императивный": ["необходимый", "неизбежный", "безапелляционный", "повелительный", "внезапный", "непреодолимый", "процедурный"],
    "императивный позыв": ["ургентность"],
    "император": ["единодержец", "самодержец", "монарх", "повелитель"],
    "императорин": ["пейцедин"],
    "императорская гавань": ["советская гавань"],
    "императорствовав": ["императорствовавши"],
    "императорствовавши": ["императорствовав"],
    "императоръ": ["самодержецъ", "монархъ"],
    "империалистическая война": ["империалистическая"],
    "империалистически": ["по-империалистически", "империалистски", "по-империалистски"],
    "империалистический": ["империалистский"],
    "империалистски": ["империалистически", "по-империалистски", "по-империалистически"],
    "империя зла": ["средоточие зла", "центр зла"],
    "имперскость": ["великодержавность"],
    "имперсонация": ["самозванство"],
    "имперфективный": ["несовершенный"],
    "импет": ["сила", "натиск", "напор"],
    "имплант": ["имплантат"],
    "имплантат": ["имплант", "протез"],
    "имплантационный": ["внедрённый", "вживлённый"],
    "имплантировав": ["имплантировавши"],
    "имплантировавши": ["имплантировав"],
    "имплантировать": ["вживлять", "вживить", "вставлять", "вставить"],
    "имплементация": ["разработка"],
    "имплементировав": ["имплементировавши"],
    "имплементировавши": ["имплементировав"],
    "имплементироваться": ["реализовываться"],
    "импликант": ["импликанта", "имплицента"],
    "импликанта": ["импликант", "имплицента"],
    "импликация": ["подразумевание", "подтекст", "следование"],
    "имплицента": ["импликанта"],
    "имплицировав": ["имплицировавши"],
    "имплицировавши": ["имплицировав"],
    "имплицитность": ["неявность", "невыраженность", "скрытость"],
    "имплицитный": ["скрытый", "неявный", "подразумеваемый"],
    "имплозивный": ["аутодеструктивный"],
    "имплувий": ["имплювий"],
    "имплювий": ["имплювиум", "имплувий"],
    "импозантно": ["внушительно", "представительно"],
    "импозантность": ["представительность", "внушительность"],
    "импозантный": ["впечатляющий", "внушительный", "представительный"],
    "импонировав": ["импонировавши"],
    "импонировавши": ["импонировав"],
    "импонировать": ["нравиться", "привлекать", "вызывать симпатию"],
    "импопо": ["импотент", "бесталанный"],
    "импорт": ["ввоз", "импортирование", "загрузка", "добавление", "вставка"],
    "импортировав": ["импортировавши"],
    "импортировавши": ["импортировав"],
    "импортирование": ["импорт"],
    "импортный": ["привозной"],
    "импортозаменяющий": ["импортозамещающий"],
    "импортозаместив": ["импортозаместивши"],
    "импортозаместивши": ["импортозаместив"],
    "импортозамещав": ["импортозамещавши"],
    "импортозамещавши": ["импортозамещав"],
    "импортозамещающий": ["импортозаменяющий"],
    "импортозамещение": ["ввозозамещение"],
    "импоссибилия": ["адината"],
    "импост": ["ригель", "средник"],
    "импотент": ["импопо", "бесталанный"],
    "импотентность": ["импотенция"],
    "импотенция": ["эректильная дисфункция"],
    "импрегнация": ["пропитывание", "пропитка", "импрегнирование", "насыщение"],
    "импрегнировав": ["импрегнировавши"],
    "импрегнировавши": ["импрегнировав"],
    "импрегнирование": ["импрегнация"],
    "импрекация": ["проклятие"],
    "импресарио": ["продюсер"],
    "импрессионистический": ["импрессионистский"],
    "импрессионистичный": ["впечатляющий"],
    "импрессионистский": ["импрессионистический"],
    "импринтинг": ["запечатление"],
    "импринтинговав": ["импринтинговавши"],
    "импринтинговавши": ["импринтинговав"],
    "импровизаторство": ["импровизирование"],
    "импровизация": ["экспромт"],
    "импровизировав": ["импровизировавши"],
    "импровизировавши": ["импровизировав"],
    "импровизирование": ["импровизация"],
    "импульс": ["позыв", "порыв", "стимул", "потенциал действия", "количество движения", "импульс силы", "волновой пакет", "цуг волн", "сигнал"],
    "импульсивный": ["порывистый"],
    "импульсная покупка": ["импульсивная покупка"],
    "имсети": ["амсет"],
    "имущественно-земельный": ["земельно-имущественный"],
    "имущественный": ["материальный"],
    "имущество": ["имение", "собственность", "добро", "вещи", "пожитки", "скарб", "барахло"],
    "имхо": ["по-моему", "на мой взгляд"],
    "имшах": ["йымшах"],
    "имя": ["название", "слава", "репутация"],
    "имя нарицательное": ["апеллятив"],
    "имя прилагательное": ["прилагательное"],
    "имя собственное": ["оним"],
    "имя существительное": ["существительное", "субстантив"],
    "имя числительное": ["числительное"],
    "имябожие": ["имяславие", "имябожничество", "ономатодоксия"],
    "имябожничество": ["имяславие", "имябожие", "ономатодоксия"],
    "имянины": ["именины", "день ангела", "тезоименитство"],
    "имярек": ["некто", "такой-то"],
    "имяславие": ["имябожничество", "имябожие", "ономатодоксия"],
    "ин-": ["в-"],
    "ин-фолио": ["фолио", "фолиант"],
    "инаб": ["ангур"],
    "инако": ["иначе", "по-другому", "по-иному", "а то", "а не то"],
    "инаковер": ["иновер", "иноверец"],
    "инаковерие": ["иноверие"],
    "инаковерный": ["иноверческий"],
    "инаковость": ["неодинаковость", "инакость"],
    "инакость": ["инаковость"],
    "инактиватор": ["ингибитор"],
    "инактивация": ["инактивирование"],
    "инактивировав": ["инактивировавши"],
    "инактивировавши": ["инактивировав"],
    "инактивировать": ["дезактивировать"],
    "инакция": ["бездействие", "праздность"],
    "инамлых": ["инамлык"],
    "инат": ["упорство", "твърдоглавие", "неотстъпчивост", "дебелоглавие"],
    "инаугурация": ["инавгурация", "коронация", "интронизация"],
    "инаугурировав": ["инаугурировавши"],
    "инаугурировавши": ["инаугурировав"],
    "инах": ["инахос"],
    "инахос": ["инах"],
    "иначе": ["по-другому", "по-иному", "а не то", "а то", "в противном случае"],
    "иначе говоря": ["другими словами"],
    "иначив": ["иначивши"],
    "иначивши": ["иначив"],
    "иначить": ["переиначивать"],
    "инбридинг": ["инцухт"],
    "инвагинация": ["впячивание", "инвагинирование"],
    "инвагинировав": ["инвагинировавши"],
    "инвагинировавши": ["инвагинировав"],
    "инвазивный": ["заразный", "паразитарный"],
    "инвазионный": ["инвазивный", "неаборигенный", "чужеродный", "адвентивный"],
    "инвазионный вид": ["инвазивный вид"],
    "инвазировав": ["инвазировавши"],
    "инвазировавши": ["инвазировав"],
    "инвазированность": ["заражённость"],
    "инвазированный": ["заражённый"],
    "инвазировать": ["инфицировать"],
    "инвазия": ["нашествие"],
    "инвайронмент": ["энвайронмент"],
    "инвайронментализм": ["энвайронментализм"],
    "инвалид": ["человек с ограниченными возможностями", "ветеран"],
    "инвалидизировав": ["инвалидизировавши"],
    "инвалидизировавши": ["инвалидизировав"],
    "инвариантность": ["неизменность", "постоянство", "независимость"],
    "инвариантный": ["неизменяемый", "неизменный", "постоянный"],
    "инварстабиль": ["инвар-стабиль"],
    "инвектива": ["выпад", "критика", "брань", "парабаза"],
    "инвективный": ["обличающий", "обличительный", "критический"],
    "инвентаризировав": ["инвентаризировавши"],
    "инвентаризировавши": ["инвентаризировав"],
    "инвентаризовав": ["инвентаризовавши"],
    "инвентаризовавши": ["инвентаризовав"],
    "инвентаризовать": ["инвентаризировать"],
    "инвентарь": ["инструментарий", "оборудование", "опись", "реестр"],
    "инверсионный след": ["конденсационный след", "реактивный след"],
    "инверсировав": ["инверсировавши"],
    "инверсировавши": ["инверсировав"],
    "инверсия": ["обращение", "инвертирование", "изменение"],
    "инвертаза": ["бета-фруктофуранозидаза"],
    "инвертировав": ["инвертировавши"],
    "инвертировавши": ["инвертировав"],
    "инвертировать": ["переворачивать", "перевернуть", "обращать", "обратить"],
    "инвертор": ["инвертер", "преобразователь"],
    "инвестировав": ["инвестировавши"],
    "инвестировавши": ["инвестировав"],
    "инвестировать": ["вкладывать", "вложить"],
    "инвеститор": ["инвестор"],
    "инвестиционное страхование жизни": ["исж"],
    "инвестиционный профиль": ["инвестпрофиль", "риск-профиль"],
    "инвестиция": ["инвестирование"],
    "инвестор": ["инвеститор"],
    "инвестпривлекательность": ["инвестиционная привлекательность"],
    "инвестпрограмма": ["инвестпроект"],
    "инвестпроект": ["инвестпрограмма"],
    "инвит": ["приглашение", "инвитация"],
    "инвитация": ["приглашение"],
    "инвитировать": ["приглашать"],
    "инвойс": ["накладная"],
    "инвойсировав": ["инвойсировавши"],
    "инвойсировавши": ["инвойсировав"],
    "инволюционный": ["пресенильный", "предстарческий"],
    "инволюция": ["атрофия", "антиинволюция", "деволюция"],
    "ингваз": ["ингуз"],
    "ингвинальный": ["паховой", "паховый"],
    "ингерманландец": ["ингр"],
    "ингерманландия": ["ингрия", "ижора", "ижорская земля"],
    "ингибировав": ["ингибировавши"],
    "ингибировавши": ["ингибировав"],
    "ингибирование": ["ингибиция", "подавление"],
    "ингибиция": ["ингибирование", "подавление", "замедление"],
    "инглис": ["англис", "ингилис"],
    "инглистон": ["англия", "ингилистон"],
    "инголь": ["ингольбяль"],
    "ингольбяль": ["инголь"],
    "ингр": ["ингерманландец"],
    "инграмма": ["энграмма"],
    "ингредиент": ["компонент", "компонента", "составляющая"],
    "ингрия": ["ингерманландия", "ижора", "ижорская земля"],
    "ингрский": ["ижорский", "ингерманландский"],
    "ингуз": ["ингваз"],
    "ингул": ["унгул", "иннаху"],
    "ингулец": ["герос", "малый ингул"],
    "ингумация": ["захоронение", "погребение", "предание земле", "трупоположение"],
    "ингумировав": ["ингумировавши"],
    "ингумировавши": ["ингумировав"],
    "ингушетия": ["республика ингушетия"],
    "инд": ["синдху"],
    "инда": ["так что", "прямо", "просто"],
    "инде": ["инуде"],
    "индевев": ["индевевши"],
    "индевевши": ["индевев"],
    "индеец": ["краснокожий"],
    "индеечий": ["индюшачий", "индюшечий", "индюшиный"],
    "индейка": ["индюшка", "индюшатина"],
    "индейский петух": ["индюк", "калкун"],
    "индекс": ["указатель", "перечень", "список", "идентификатор", "показатель"],
    "индексация": ["индексирование"],
    "индексировав": ["индексировавши"],
    "индексировавши": ["индексировав"],
    "индексирование": ["индексация"],
    "индемнитет": ["парламентский иммунитет", "депутатский иммунитет", "парламентская неприкосновенность"],
    "индепендент-рок": ["инди-рок"],
    "инди-игра": ["индюшатина"],
    "инди-рок": ["индепендент-рок"],
    "индианист": ["индолог"],
    "индианистика": ["индология"],
    "индианка": ["индуска", "скво"],
    "индивид": ["индивидуум"],
    "индивидуализировав": ["индивидуализировавши"],
    "индивидуализировавши": ["индивидуализировав"],
    "индивидуализирование": ["индивидуализация"],
    "индивидуалист": ["эгоист"],
    "индивидуалистский": ["индивидуалистический"],
    "индивидуалка": ["индивидуальная гонка"],
    "индивидуально": ["своеобразно", "неповторимо", "оригинально"],
    "индивидуальное вещество": ["составляющее вещество", "компонент"],
    "индивидуальное химическое вещество": ["чистое вещество"],
    "индивидуальность": ["отдельность", "своеобразие", "личность"],
    "индивидуальный инвестиционный счёт": ["иис"],
    "индивидуальный предприниматель": ["ип"],
    "индивидуальщик": ["индивидуал"],
    "индивидуум": ["особь", "индивид", "личность"],
    "индигенат": ["индиженат"],
    "индигенность": ["автохтонность"],
    "индигенный": ["облигатный", "резидентный"],
    "индиго": ["рёбенок-индиго"],
    "индигонос": ["индигофера"],
    "индигофера": ["индигонос"],
    "индиец": ["индус", "дельта-штамм", "дельта"],
    "индиженат": ["индигенат"],
    "индийско-ланкийский": ["индийско-шриланкийский", "индо-ланкийский"],
    "индийско-российский": ["российско-индийский"],
    "индийско-шриланкийский": ["индийско-ланкийский", "индо-ланкийский"],
    "индикатив": ["изъявительное наклонение"],
    "индикативный": ["повествовательный", "рекомендательный", "недирективный", "советующий", "ориентирующий"],
    "индикт": ["индиктион"],
    "индиктион": ["индикт"],
    "индифферентизм": ["индифферентность", "безразличие", "безучастность", "равнодушие", "нейтральность", "апатия"],
    "индифферентно": ["равнодушно", "безучастно", "безразлично", "бесстрастно", "апатично"],
    "индифферентность": ["безразличие", "равнодушие"],
    "индифферентный": ["безразличный", "безучастный", "равнодушный", "нейтральный"],
    "индихенизм": ["индианизм"],
    "индицировав": ["индицировавши"],
    "индицировавши": ["индицировав"],
    "индия": ["республика индия"],
    "индо-ланкийский": ["индийско-ланкийский", "индийско-шриланкийский"],
    "индоариец": ["индоарий"],
    "индоарий": ["индоариец"],
    "индоевропейскоязычный": ["индоевропейский"],
    "индоктринация": ["промывание мозгов", "промывка мозгов", "идеологическая обработка"],
    "индол": ["бензопиррол"],
    "индолилуксусная кислота": ["гетероауксин"],
    "индология": ["индианистика"],
    "индонезийский язык": ["бахаса"],
    "индонезия": ["республика индонезия", "нусантара"],
    "индор-гребля": ["гребля-индор"],
    "индоссамент": ["жиро"],
    "индоссировав": ["индоссировавши"],
    "индоссировавши": ["индоссировав"],
    "индпошивный": ["индпошивочный"],
    "индпошивочный": ["индпошивный"],
    "индра": ["шакра"],
    "индуист": ["индус"],
    "индуктировав": ["индуктировавши"],
    "индуктировавши": ["индуктировав"],
    "индуктировать": ["индуцировать", "наводить", "навести"],
    "индукция": ["математическая индукция"],
    "индульгировав": ["индульгировавши"],
    "индульгировавши": ["индульгировав"],
    "индульгировать": ["потакать", "потворствовать"],
    "индус": ["индуист", "индиец", "кодер", "быдлокодер"],
    "индустриализировав": ["индустриализировавши"],
    "индустриализировавши": ["индустриализировав"],
    "индустриализовав": ["индустриализовавши"],
    "индустриализовавши": ["индустриализовав"],
    "индустриализовать": ["индустриализировать"],
    "индустриална революция": ["промишлена революция"],
    "индустриальный": ["промышленный"],
    "индустрия": ["промышленность"],
    "индуцировав": ["индуцировавши"],
    "индуцировавши": ["индуцировав"],
    "индуцированные стволовые клетки": ["иск"],
    "индуцировать": ["наводить", "вызывать", "инициировать"],
    "индюк": ["индейский петух"],
    "индюшатина": ["инди-игра", "индюшка"],
    "индюшачий": ["индюшечий", "индюшиный"],
    "индюшечий": ["индюшачий", "индюшиный"],
    "индюшиный": ["индюшачий", "индюшечий"],
    "индюшка": ["индейка", "индюшатина"],
    "иней": ["изморозь", "седина"],
    "инер": ["нар"],
    "инерта": ["техническая единица массы"],
    "инертный": ["массивный", "бездеятельный", "пассивный", "безынициативный"],
    "инертный газ": ["благородный газ", "редкий газ"],
    "инерциальный": ["инерционный"],
    "инерционность": ["инерция"],
    "инерционный": ["инерциальный"],
    "инерция": ["инертность", "безынициативность"],
    "инерцоид": ["инерциоид"],
    "инессив": ["внутренне-местный падеж нахождения"],
    "инет": ["интернет", "всемирная паутина", "тырнет"],
    "инжектировав": ["инжектировавши"],
    "инжектировавши": ["инжектировав"],
    "инжектировать": ["инъецировать"],
    "инженерив": ["инженеривши"],
    "инженеривши": ["инженерив"],
    "инженеринг": ["инжиниринг"],
    "инженерия": ["инжиниринг", "инженерное дело", "инженерство"],
    "инженерка": ["инженерша"],
    "инженерный": ["технический"],
    "инженерствовав": ["инженерствовавши"],
    "инженерствовавши": ["инженерствовав"],
    "инженерша": ["инженерка"],
    "инженю": ["субретка"],
    "инжиниринг": ["инженеринг", "инженерное дело", "инженерия"],
    "инжир": ["фиговое дерево", "смоковница", "смоква", "фига"],
    "инициализировав": ["инициализировавши"],
    "инициализировавши": ["инициализировав"],
    "инициализировать": ["запустить"],
    "инициаль": ["инициальная клетка"],
    "инициатива": ["почин", "лидерство", "инициативность"],
    "инициативность": ["активность", "предприимчивость", "энергичность", "самостоятельность", "деятельность"],
    "инициативный": ["предприимчивый", "самостоятельный"],
    "инициатор": ["зачинатель", "зачинщик", "основоположник"],
    "инициатор-терминатор": ["ит"],
    "инициаторша": ["основоположница"],
    "инициация": ["посвящение", "инициирование", "инициализация", "порождение"],
    "инициировав": ["инициировавши"],
    "инициировавши": ["инициировав"],
    "инициированный": ["начатый", "запущенный", "активизированный"],
    "инка": ["перуанский ценолест"],
    "инкантация": ["заклинание"],
    "инкапсулировав": ["инкапсулировавши"],
    "инкапсулировавши": ["инкапсулировав"],
    "инкапсулирование": ["инкапсуляция"],
    "инкапсуляция": ["инкапсулирование"],
    "инкассировав": ["инкассировавши"],
    "инкассировавши": ["инкассировав"],
    "инкассирование": ["инкассация"],
    "инклинация": ["склонность", "деклинация"],
    "инклюзивный": ["включительный"],
    "инклюзия": ["включение", "вкрапление", "гипонимия"],
    "инкогерентность": ["инкогеренция", "бессвязность"],
    "инкогеренция": ["инкогерентность", "бессвязность", "словесная окрошка", "словесный салат"],
    "инкогнито": ["анонимно"],
    "инкорпорация": ["поглощение", "присоединение", "инкорпорирование"],
    "инкорпорировав": ["инкорпорировавши"],
    "инкорпорировавши": ["инкорпорировав"],
    "инкорпорировать": ["соединять", "соединить", "включать", "включить"],
    "инкремент": ["приращение", "инкрементирование"],
    "инкрементальный": ["пошаговый"],
    "инкрементировав": ["инкрементировавши"],
    "инкрементировавши": ["инкрементировав"],
    "инкрементирование": ["инкремент"],
    "инкрементный": ["инкрементальный"],
    "инкрет": ["гормон"],
    "инкретировав": ["инкретировавши"],
    "инкретировавши": ["инкретировав"],
    "инкреторный": ["внутрисекреторный"],
    "инкреция": ["внутренняя секреция"],
    "инкриминация": ["инкриминирование", "обвинение"],
    "инкриминировав": ["инкриминировавши"],
    "инкриминировавши": ["инкриминировав"],
    "инкриминирование": ["вменение", "обвинение"],
    "инкриминировать": ["вменять", "обвинять", "шить"],
    "инкрустация": ["инкрустирование"],
    "инкрустировав": ["инкрустировавши"],
    "инкрустировавши": ["инкрустировав"],
    "инкрустирование": ["инкрустация"],
    "инкса": ["кувалма", "сюнеда"],
    "инкубатор": ["кувез"],
    "инкубационный": ["латентный", "инкубаторный"],
    "инкубировав": ["инкубировавши"],
    "инкубировавши": ["инкубировав"],
    "инкунабула": ["инкунабул"],
    "инкурабельный": ["неизлечимый"],
    "иннервировав": ["иннервировавши"],
    "иннервировавши": ["иннервировав"],
    "инновационно": ["новаторски", "по-новому"],
    "инновационный": ["новаторский"],
    "иннополис": ["ветрополис"],
    "иноверец": ["неверный", "нехристь", "гяур", "кафир", "гой", "безбожник"],
    "иноверный": ["иноверец"],
    "иногда": ["временами", "порой", "подчас", "время от времени", "по временам", "годом-родом", "иной раз"],
    "иноземец": ["чужеземец", "чужестранец", "иностранец"],
    "иноземно": ["инородно", "иностранно", "ино", "забугорно"],
    "иноземный": ["иностранный", "заграничный", "зарубежный"],
    "инозитол": ["инозит"],
    "иной": ["другой", "некоторый", "некий"],
    "инок": ["енох"],
    "инокомма": ["саркомер"],
    "инопланетный": ["чужепланетный"],
    "инопланетянин": ["пришелец"],
    "иносистемный": ["иноязычный"],
    "иносказание": ["аллегория"],
    "иносказанье": ["иносказание"],
    "иносказательно": ["аллегорически", "фигурально", "эзоповым языком"],
    "иносказательность": ["аллегоричность"],
    "иносказательный": ["аллегорический", "аллегоричный", "метафорический", "метафоричный", "образный", "переносный", "эзоповский", "эмблематический", "фигуральный"],
    "иностранец": ["иноземец", "чужеземец", "чужестранец", "приезжий"],
    "иностранка": ["иноземека", "чужестранка"],
    "иностранный": ["чужестранный", "иноземный", "заграничный"],
    "иностранный агент": ["иноагент"],
    "иночествовав": ["иночествовавши"],
    "иночествовавши": ["иночествовав"],
    "иноэтнический": ["иноэтничный", "инородческий"],
    "иноэтничный": ["иноэтнический"],
    "инпу": ["анубис"],
    "инпут": ["анпут"],
    "инс": ["искусственная нейронная сеть"],
    "инсайд": ["центрфорвард"],
    "инсайдерский": ["конфиденциальный", "нераскрытый", "служебный"],
    "инсайт": ["озарение"],
    "инсан": ["чи", "инс"],
    "инсектицидный": ["дезинсекционный"],
    "инсектолог": ["энтомолог"],
    "инсектологический": ["энтомологический"],
    "инсектология": ["энтомология"],
    "инсектонаблюдатель": ["энтомолог"],
    "инсинератор": ["мусоросжигатель"],
    "инсинуатор": ["клеветник"],
    "инсинуация": ["клевета"],
    "инсинуировав": ["инсинуировавши"],
    "инсинуировавши": ["инсинуировав"],
    "инсоляция": ["солнечная терапия", "солнечные ванны", "освещённость"],
    "инсомния": ["асомния", "агрипния", "бессонница", "диссомния"],
    "инсон": ["башар"],
    "инспектировав": ["инспектировавши"],
    "инспектировавши": ["инспектировав"],
    "инспектор": ["контролёр", "наблюдатель", "надзиратель", "ревизор", "смотритель"],
    "инспекторствовав": ["инспекторствовавши"],
    "инспекторствовавши": ["инспекторствовав"],
    "инспекторша": ["контролёрша"],
    "инспектриса": ["инспекторша"],
    "инспиратор": ["подстрекатель"],
    "инспирация": ["внушение", "подстрекательство", "вдыхание", "вдох"],
    "инспирировав": ["инспирировавши"],
    "инспирировавши": ["инспирировав"],
    "инспирирование": ["инспирация", "наущение", "подговор", "подначка", "подстрекание", "подстрекательство"],
    "инспирировать": ["агитировать"],
    "инста": ["инстаграм"],
    "инста-воин": ["селфи-боец", "тик-ток-воин"],
    "инсталлировав": ["инсталлировавши"],
    "инсталлировавши": ["инсталлировав"],
    "инсталлировать": ["устанавливать"],
    "инсталляция": ["представление", "перфоманс", "установка"],
    "инстанс": ["объект"],
    "инстигатор": ["подстрекатель"],
    "инстигация": ["побуждение"],
    "инстиговать": ["подстрекать"],
    "инстинктивно": ["машинально", "неосознанно", "подсознательно"],
    "инстинктивность": ["бессознательность", "неосознанность", "непредумышленность"],
    "институировав": ["институировавши"],
    "институировавши": ["институировав"],
    "институт": ["колледж", "университет", "институция"],
    "институт благородных девиц": ["тепличные условия"],
    "институтка": ["студентка", "наивняк"],
    "институциализация": ["институционализация"],
    "институциализировав": ["институциализировавши"],
    "институциализировавши": ["институциализировав"],
    "институционализация": ["институциализация", "упорядочение"],
    "институционализировав": ["институционализировавши"],
    "институционализировавши": ["институционализировав"],
    "институциональный": ["институционный"],
    "институционный": ["институциональный"],
    "институция": ["институт", "социальный институт", "организация", "заведение"],
    "инструктаж": ["инструктирование"],
    "инструктив": ["падеж образа действия"],
    "инструктировав": ["инструктировавши"],
    "инструктировавши": ["инструктировав"],
    "инструктирование": ["инструктаж"],
    "инструментализировав": ["инструментализировавши"],
    "инструментализировавши": ["инструментализировав"],
    "инструменталис": ["инструментатив", "творительный падеж"],
    "инструментарий": ["инвентарь", "оборудование"],
    "инструментировав": ["инструментировавши"],
    "инструментировавши": ["инструментировав"],
    "инструментировать": ["инструментовать"],
    "инструментовав": ["инструментовавши"],
    "инструментовавши": ["инструментовав"],
    "инструментовать": ["инструментировать"],
    "инсулиннезависимый": ["инсулинорезистентный"],
    "инсулиновая кома": ["инсулиновый шок"],
    "инсулиновый шок": ["инсулиновая кома"],
    "инсулинокоматозный": ["инсулиношоковый"],
    "инсулинотерапия": ["инсулиновая терапия"],
    "инсулома": ["аденома островковой ткани", "незидиобластома"],
    "инсульт": ["апоплексия"],
    "инсультнув": ["инсультнувши"],
    "инсультнувши": ["инсультнув"],
    "инсургент": ["повстанец"],
    "инсургентский": ["повстанческий"],
    "инсуррекция": ["инсюррекция"],
    "инсуффляция": ["нагнетание"],
    "инсценировав": ["инсценировавши"],
    "инсценировавши": ["инсценировав"],
    "инсценирование": ["инсценировка"],
    "инсценировать": ["симулировать"],
    "инсценировка": ["представление"],
    "интактный": ["незатронутый", "неповреждённый", "нетронутый"],
    "интегральная схема": ["ис", "чип", "кристалл"],
    "интегральчик": ["интеграл"],
    "интеграт": ["стек"],
    "интегративный": ["интеграционный", "объединительный"],
    "интеграф": ["интегриметр"],
    "интеграция": ["объединение", "соединение", "сплочение", "интегрирование"],
    "интегриметр": ["интеграф"],
    "интегрировав": ["интегрировавши"],
    "интегрировавши": ["интегрировав"],
    "интегрирование": ["переобразование", "упрощение"],
    "интегрировать": ["брать интеграл", "квадрировать"],
    "интеллект": ["ум", "разум", "рассудок"],
    "интеллектуализировав": ["интеллектуализировавши"],
    "интеллектуализировавши": ["интеллектуализировав"],
    "интеллектуальность": ["интеллект", "ум"],
    "интеллектуальный": ["умственный", "мыслительный", "мыслящий", "разумный", "умный"],
    "интеллигентик": ["интеллигентишка"],
    "интеллигентно": ["интеллигентски", "по-интеллигентски", "культурно"],
    "интеллигентность": ["воспитанность", "культурность"],
    "интеллигентный": ["интеллигентский"],
    "интеллигибельный": ["умопостигаемый"],
    "интензивный": ["интенсивный", "напряжённый"],
    "интенсивно-жёлтый": ["ярко-жёлтый", "насыщенно-жёлтый", "канареечно-жёлтый", "горчично-жёлтый", "золотисто-жёлтый", "грушево-жёлтый", "лимонно-жёлтый", "ярко-лимонный"],
    "интенсивно-оранжевый": ["насыщенно-оранжевый", "ярко-оранжевый"],
    "интенсивный": ["напряжённый", "оптимальный", "неаддитивный"],
    "интенсификация": ["усиление", "увеличение", "укрепление", "приумножение", "углубление"],
    "интенсифицировав": ["интенсифицировавши"],
    "интенсифицировавши": ["интенсифицировав"],
    "интенциональный": ["намеренный", "преднамеренный", "умышленный", "нарочитый"],
    "интенция": ["намерение", "умысел", "замысел", "задумка", "план", "проект", "прожект"],
    "интер-": ["меж-", "междо-", "между-"],
    "интерактивный": ["диалоговый"],
    "интербригадист": ["интербригадовец"],
    "интербригадовец": ["интербригадист"],
    "интервал": ["расстояние", "промежуток", "дистанция", "перерыв", "диапазон"],
    "интервенировав": ["интервенировавши"],
    "интервенировавши": ["интервенировав"],
    "интервент": ["оккупант", "захватчик", "завоеватель"],
    "интервенция": ["вторжение"],
    "интервика": ["интервики-ссылка"],
    "интервики-": ["интервики"],
    "интервью": ["беседа", "собеседование"],
    "интервьюировав": ["интервьюировавши"],
    "интервьюировавши": ["интервьюировав"],
    "интергляциал": ["межледниковье"],
    "интердевочка": ["интерпроститутка", "валютная проститутка"],
    "интересант": ["стяжатель", "корыстолюбец", "заинтересованный", "бенефициар"],
    "интересничав": ["интересничавши"],
    "интересничавши": ["интересничав"],
    "интересничанье": ["интересничание"],
    "интересничать": ["рисоваться"],
    "интересно": ["любопытно", "необычно"],
    "интересно девки пляшут": ["ничего себе"],
    "интересность": ["занятность", "занимательность", "увлекательность", "любопытность", "интересное", "необычное", "любопытное", "диковинное", "редкость", "диковина", "диковинка"],
    "интересный": ["занятный", "занимательный", "любопытный", "увлекательный", "привлекательный"],
    "интересовав": ["интересовавши"],
    "интересовавши": ["интересовав"],
    "интересовать": ["представлять интерес", "занимать"],
    "интеркалат": ["интеркалят"],
    "интеркалировав": ["интеркалировавши"],
    "интеркалировавши": ["интеркалировав"],
    "интеркинез": ["интерфаза"],
    "интерлингве": ["окциденталь"],
    "интерлиньяж": ["междустрочие"],
    "интерлок": ["двуластик"],
    "интерлюдия": ["интермедия", "интермеццо"],
    "интермедия": ["интерлюдия"],
    "интермиттировав": ["интермиттировавши"],
    "интермиттировавши": ["интермиттировав"],
    "интермодальный": ["мультимодальный"],
    "интернатовский": ["интернатский"],
    "интернацик": ["байцзо"],
    "интернационализация": ["глобализация", "локализация"],
    "интернационализировав": ["интернационализировавши"],
    "интернационализировавши": ["интернационализировав"],
    "интернационализм": ["солидарность"],
    "интернационалистически": ["интернационалистски"],
    "интернациональный": ["международный", "интернационалистический"],
    "интернет": ["веб", "всемирная паутина", "паутина", "всемирная сеть", "сеть", "инет", "тырнет"],
    "интернет-": ["веб-", "кибер-", "онлайн-"],
    "интернет-адрес": ["веб-адрес"],
    "интернет-бизнес": ["онлайн-бизнес"],
    "интернет-брокер": ["онлайн-брокер"],
    "интернет-версия": ["веб-версия", "онлайн-версия"],
    "интернет-зависимость": ["интернетомания"],
    "интернет-издание": ["веб-издание", "онлайн-издание"],
    "интернет-издательство": ["веб-издательство"],
    "интернет-казино": ["онлайн-казино"],
    "интернет-карта": ["интернет-карточка"],
    "интернет-кафе": ["киберкафе"],
    "интернет-коммерция": ["онлайн-коммерция"],
    "интернет-конференция": ["веб-конференция", "онлайн-конференция"],
    "интернет-магазин": ["онлайн-магазин"],
    "интернет-мем": ["мемес", "мемас"],
    "интернет-опрос": ["онлайн-опрос"],
    "интернет-площадка": ["маркетплейс", "интернет-магазин"],
    "интернет-пользователь": ["юзер", "интернетчик"],
    "интернет-портал": ["портал", "веб-портал"],
    "интернет-пресса": ["интернет-сми"],
    "интернет-приложение": ["веб-приложение"],
    "интернет-проект": ["веб-проект", "онлайн-проект"],
    "интернет-пространство": ["веб-пространство"],
    "интернет-реклама": ["онлайн-реклама"],
    "интернет-ресурс": ["веб-ресурс", "онлайн-ресурс"],
    "интернет-ретейлер": ["онлайн-ретейлер"],
    "интернет-рынок": ["веб-рынок"],
    "интернет-сайт": ["сайт", "веб-сайт"],
    "интернет-сервер": ["веб-сервер"],
    "интернет-система": ["веб-система", "онлайн-система"],
    "интернет-сми": ["интернет-пресса"],
    "интернет-страница": ["веб-страница", "страница"],
    "интернет-студия": ["веб-студия"],
    "интернет-сёрфер": ["веб-сёрфер"],
    "интернет-сёрфинг": ["веб-сёрфинг"],
    "интернет-технологии": ["веб-технологии"],
    "интернет-торговля": ["онлайн-торговля", "электронная торговля"],
    "интернет-травля": ["кибербуллинг", "кибертравля", "онлайн-травля"],
    "интернет-тролль": ["тролль"],
    "интернет-узел": ["веб-узел"],
    "интернет-услуга": ["онлайн-услуга"],
    "интернет-устройство": ["веб-устройство"],
    "интернет-форум": ["веб-форум", "форум"],
    "интернет-хостинг": ["веб-хостинг", "хостинг"],
    "интернет-энциклопедия": ["сетевая энциклопедия", "онлайн-энциклопедия"],
    "интернетик": ["интернет"],
    "интернетовский": ["интернетный"],
    "интернетомания": ["интернет-зависимость"],
    "интернетский": ["интернетовский"],
    "интернетчик": ["сетянин"],
    "интернировав": ["интернировавши"],
    "интернировавши": ["интернировав"],
    "интерорецептор": ["интероцептор"],
    "интерорецепция": ["интероцепция"],
    "интероцептор": ["интерорецептор", "висцерорецептор"],
    "интероцепция": ["интерорецепция"],
    "интерпеллировав": ["интерпеллировавши"],
    "интерпеллировавши": ["интерпеллировав"],
    "интерполировав": ["интерполировавши"],
    "интерполировавши": ["интерполировав"],
    "интерполирование": ["интерполяция"],
    "интерпретация": ["интерпретирование", "истолкование", "толкование", "трактовка", "переосмысление"],
    "интерпретировав": ["интерпретировавши"],
    "интерпретировавши": ["интерпретировав"],
    "интерпретировать": ["толковать", "истолковывать", "истолковать", "давать объяснение"],
    "интерпретируя": ["толкуя", "истолковывая"],
    "интерпроститутка": ["интердевочка", "валютная проститутка"],
    "интерпункция": ["пунктуация"],
    "интерсексуализм": ["гермафродитизм"],
    "интерсексуальность": ["интерсексуализм", "гермафродитизм"],
    "интерсептальный": ["межперегородочный"],
    "интертриго": ["опрелость"],
    "интерфаза": ["интеркинез"],
    "интерфейс": ["связующее звено", "устройство сопряжения"],
    "интерферировав": ["интерферировавши"],
    "интерферировавши": ["интерферировав"],
    "интерферон": ["ифн"],
    "интерфикс": ["вставка", "пустой морф", "соединительная морфема"],
    "интерцептор": ["спойлер"],
    "интерчейндж": ["взаимообменный сбор", "межбанковская комиссия"],
    "интеръективация": ["интеръективизация"],
    "интеръекция": ["междометие"],
    "интерьер": ["убранство"],
    "интестинальный": ["кишечный"],
    "интестиноскопия": ["энтероскопия"],
    "интим-магазин": ["интим-шоп"],
    "интим-услуги": ["интим-сервис"],
    "интим-шоп": ["интим-магазин"],
    "интимидация": ["угроза", "запугивание"],
    "интимничав": ["интимничавши"],
    "интимничавши": ["интимничав"],
    "интимный": ["личный", "персональный"],
    "интина": ["эндоспорий"],
    "интоксикация": ["отравление", "токсикоз"],
    "интолерантность": ["нетолерантность", "нетерпимость", "непереносимость"],
    "интолерантный": ["нетолерантный", "нетерпимый"],
    "интонационная конструкция": ["интонема"],
    "интонационно": ["просодически"],
    "интонация": ["звук", "тон", "манера"],
    "интонировав": ["интонировавши"],
    "интонировавши": ["интонировав"],
    "интра-": ["внутри-"],
    "интраабдоминальный": ["внутрибрюшной"],
    "интравагинальный": ["внутривлагалищный"],
    "интраваскулярный": ["внутрисосудистый"],
    "интрагастральный": ["внутрижелудочный"],
    "интракраниальный": ["внутричерепной"],
    "интрамеатальный": ["пермеатальный"],
    "интрамембранный": ["внутримембранный"],
    "интранет": ["интрасеть"],
    "интранет-сеть": ["интранет", "интрасеть"],
    "интраплацентарный": ["внутриплацентарный"],
    "интрасеть": ["интранет"],
    "интратекальный": ["подоболочечный", "внутриоболочечный"],
    "интраторакальный": ["внутригрудной"],
    "интрацеребральный": ["внутримозговой"],
    "интрига": ["происки", "козни", "заговор", "сюжет", "фабула", "флирт", "роман", "шашни"],
    "интриган": ["заговорщик", "склочник", "каверзник", "политикан", "лукавец", "химик", "подсидчик"],
    "интриганка": ["каверзница"],
    "интриганствовав": ["интриганствовавши"],
    "интриганствовавши": ["интриганствовав"],
    "интриговав": ["интриговавши"],
    "интриговавши": ["интриговав"],
    "интриговать": ["интриганствовать"],
    "интригующий": ["склочничающий", "загадочный"],
    "интрижка": ["козни", "происки", "флирт", "роман", "шашни"],
    "интровертированность": ["интроверсия"],
    "интровертность": ["интроверсия", "замкнутость"],
    "интровертный": ["интровертивный"],
    "интрогрессия": ["интрогрессивная гибридизация"],
    "интродуцировав": ["интродуцировавши"],
    "интродуцировавши": ["интродуцировав"],
    "интрон": ["интрогенный район"],
    "интронация": ["интронизация"],
    "интронизация": ["интронация", "настолование"],
    "интроспекция": ["самонаблюдение"],
    "интроцикл": ["моноцикл"],
    "интрузив": ["интрузия"],
    "интрузия": ["интрузив", "интрузивный массив"],
    "интубировав": ["интубировавши"],
    "интубировавши": ["интубировав"],
    "интуиция": ["чутьё", "проницательность", "серендипность", "инстинкт", "нюх", "провидение"],
    "инуде": ["инде"],
    "инупиак": ["аляскинско-инуитский язык", "инюпиак"],
    "инфа": ["информация", "данные", "сведение", "новость", "знание", "факт"],
    "инфамия": ["бесчестие", "гнусность"],
    "инфантерист": ["пехотинец"],
    "инфантерия": ["пехота"],
    "инфантил": ["инфант"],
    "инфантилизм": ["детскость", "ребячество", "инфантильность"],
    "инфантильность": ["инфантилизм", "детскость", "ребячество", "ребячливость"],
    "инфантицид": ["детоубийство"],
    "инфатуация": ["тщеславие", "самодовольство"],
    "инфауна": ["эндофауна"],
    "инфектолог": ["инфекционист"],
    "инфекция": ["заражение", "инфекционная болезнь", "зараза", "заразная болезнь"],
    "инфернальная комната": ["карточная комната", "игральная комната", "инфернальная"],
    "инфернальность": ["демоничность", "демонизм", "сатанизм"],
    "инфернальный": ["адский", "демонический", "дьявольский", "сатанинский", "бесовский", "обсценный", "матерный", "нецензурный", "табуированный", "непечатный", "инфернальная комната"],
    "инферно": ["ад"],
    "инфильтрация": ["проникновение", "просачивание"],
    "инфильтрировав": ["инфильтрировавши"],
    "инфильтрировавши": ["инфильтрировав"],
    "инфимум": ["точная нижняя грань"],
    "инфинитив": ["неопределённая форма глагола", "неопределённое наклонение"],
    "инфицировав": ["инфицировавши"],
    "инфицировавши": ["инфицировав"],
    "инфицирование": ["заражение"],
    "инфицировать": ["заражать", "заразить"],
    "инфицироваться": ["заражаться"],
    "инфлировав": ["инфлировавши"],
    "инфлировавши": ["инфлировав"],
    "инфлуэнца": ["инфлюэнца", "грипп"],
    "инфлюэнца": ["инфлуэнца", "грипп"],
    "инфо": ["информация", "инфа"],
    "инфобизнесмен": ["инфоцыган"],
    "информагентство": ["информационное агентство"],
    "информативный": ["содержательный"],
    "информатизировав": ["информатизировавши"],
    "информатизировавши": ["информатизировав"],
    "информатика": ["компьютерная наука"],
    "информатор": ["доносчик", "изветчик", "осведомитель", "предатель", "секретный сотрудник", "сексот", "соглядатай", "провокатор", "шпион", "ябеда", "информант", "докладчик"],
    "информационно-аналитический": ["аналитико-информационный"],
    "информационно-консультационный": ["информационно-консалтинговый"],
    "информационное агентство": ["информагентство"],
    "информационное поле": ["информполе"],
    "информационные технологии": ["ит"],
    "информационный продукт": ["инфопродукт"],
    "информация": ["данные", "сведение", "знание", "факт", "инфо", "инфа", "информирование", "оповещение"],
    "информировав": ["информировавши"],
    "информировавши": ["информировав"],
    "информированность": ["осведомлённость"],
    "информировать": ["осведомить", "осведомлять", "сообщать", "извещать", "уведомлять", "докладывать", "доносить", "заявлять", "объявлять", "оповещать", "предупреждать"],
    "информполе": ["информационное поле"],
    "инфоцентр": ["справочное бюро"],
    "инфоцыган": ["инфобизнесмен"],
    "инфракрасное излучение": ["тепловое излучение"],
    "инфузория-туфелька": ["парамеция хвостатая"],
    "инхар": ["онурис"],
    "инхоативный": ["начинательный"],
    "инцест": ["кровосмешение", "кровосмесительство"],
    "инцестный": ["инцестовый", "кровосмесительный"],
    "инцидент": ["происшествие", "казус"],
    "инцистировав": ["инцистировавши"],
    "инцистировавши": ["инцистировав"],
    "инцухт": ["инбридинг"],
    "инцухтировав": ["инцухтировавши"],
    "инцухтировавши": ["инцухтировав"],
    "инчада": ["инчас"],
    "иншаллах": ["иншалла", "иншала"],
    "инъектор": ["инжектор"],
    "инъецировав": ["инъецировавши"],
    "инъецировавши": ["инъецировав"],
    "инъли": ["энли"],
    "инь-ян": ["инь", "ян"],
    "иньдь": ["иньд"],
    "иньдя": ["инда"],
    "иньский": ["шанский"],
    "иоанн": ["иван"],
    "иоаннит": ["иоаннитка", "хлыст-киселёвец", "госпитальер"],
    "иоахимсталер": ["шликсталер"],
    "иов": ["гиоб", "хиоб", "джоб"],
    "иод": ["йод"],
    "иодат": ["йодат"],
    "иодид": ["йодид", "гидроиодид", "гидройодид", "иодид-ион", "йодид-ион", "иодид-анион", "йодид-анион"],
    "иодировав": ["иодировавши"],
    "иодировавши": ["иодировав"],
    "иодирование": ["йодирование"],
    "иодированный": ["йодированный"],
    "иодировать": ["йодировать"],
    "иодистый": ["йодистый", "иодид", "йодид"],
    "иодометрия": ["йодометрия"],
    "иодюр": ["иодид", "йодид"],
    "ионивеем": ["ёонайвеем", "ионивээм"],
    "иониец": ["ионянин"],
    "ионизировав": ["ионизировавши"],
    "ионизировавши": ["ионизировав"],
    "ионизировать": ["ионизовать", "электризовать"],
    "ионизирующее излучение": ["радиация"],
    "ионизовав": ["ионизовавши"],
    "ионизовавши": ["ионизовав"],
    "ионизовать": ["ионизировать"],
    "ионийский": ["ионический"],
    "ионировав": ["ионировавши"],
    "ионировавши": ["ионировав"],
    "ионистор": ["суперконденсатор", "ультраконденсатор"],
    "ионический": ["ионийский"],
    "ионишкелис": ["иоганишкели"],
    "ионосферист": ["ионосферщик"],
    "ионосферщик": ["ионосферист"],
    "ионотерапия": ["ионтофорез"],
    "ионофорез": ["ионогальванизация", "ионотерапия"],
    "ионянин": ["иониец"],
    "иоппия": ["яффа", "яффо", "яфо"],
    "иорданец": ["трансиорданец"],
    "иордания": ["иорданское хашимитское королевство"],
    "иори": ["иора"],
    "иосиф": ["иосифия", "иосип", "иосифин"],
    "иосифлянин": ["осиплянин"],
    "иота": ["йота"],
    "иохаведа": ["иохабеда", "иокебед", "иохевед", "иохебед"],
    "ип": ["индивидуальный предприниматель"],
    "ипекакуана": ["рвотный корень"],
    "иподиакон": ["поддиакон", "поддьякон", "иподьякон", "субдиакон"],
    "иподиаконствовав": ["иподиаконствовавши"],
    "иподиаконствовавши": ["иподиаконствовав"],
    "иподьякон": ["поддиакон", "поддьякон", "иподиакон", "субдиакон"],
    "иподьяконствовав": ["иподьяконствовавши"],
    "иподьяконствовавши": ["иподьяконствовав"],
    "ипокризия": ["ипокритство", "лицемерие", "ханжество"],
    "ипокрит": ["фарисей", "лицемер", "ханжа", "притворщик"],
    "ипокритка": ["лицемерка", "ханжа", "фарисейка", "притворщица"],
    "ипокритство": ["лицемерие", "ханжество", "фарисейство", "притворство"],
    "ипокритствовать": ["лицемерить", "ханжить", "девотствовать"],
    "ипостазировав": ["ипостазировавши"],
    "ипостазировавши": ["ипостазировав"],
    "ипохондрия": ["ипохондрическое расстройство", "ипохондрический невроз", "ипохондрический синдром", "гипохондрия", "тоска", "уныние", "безнадёжность", "подавленность", "хандра", "сплин", "меланхолия", "депрессия", "депрессуха"],
    "иппокрена": ["гиппокрена"],
    "иппология": ["коневодство"],
    "иппотерапия": ["райттерапия"],
    "иприт": ["горчичный газ"],
    "ипсилатеральный": ["гомолатеральный", "изолатеральный"],
    "ир": ["гавиар", "касатик", "лепешник", "татарский сабельник", "пищалка", "игир"],
    "ир-": ["а-", "ан-", "ил-", "им-", "ин-"],
    "ир-ат": ["ир-егет"],
    "ир-егет": ["ир-ат"],
    "ираклион": ["гераклион"],
    "иракский курдистан": ["южный курдистан"],
    "иран": ["исламская республика иран", "ири", "персия"],
    "иранец": ["перс", "персиянин"],
    "иранист": ["иранолог"],
    "иранистика": ["иранология"],
    "иранолог": ["иранист"],
    "иранский": ["персидский"],
    "иранский экспресс": ["тегерань"],
    "ирбис": ["снежный барс", "снежный леопард"],
    "иргис": ["гиргис"],
    "ирей": ["вырей", "вырий"],
    "иреклек": ["азатлык"],
    "иридирующий": ["иризирующий"],
    "иридодиагностика": ["иридология"],
    "иридофор": ["гуанофор"],
    "иридоциклит": ["передний увеит"],
    "иризация": ["иридисценция", "побежалость", "перелив", "переливание", "переливчатость", "радужность"],
    "иризирующий": ["иридирующий"],
    "ирий": ["вырий"],
    "ирина": ["ира"],
    "ирис": ["касатик", "петушок", "радужная оболочка", "радужка"],
    "ириска": ["ирис"],
    "ирисовые": ["касатиковые"],
    "ирка": ["гирка"],
    "иркен": ["азатлык"],
    "иркин": ["июль"],
    "иркутск": ["середина земли", "иркуцк"],
    "иркутская область": ["приангарье"],
    "ирландия": ["республика ирландия", "эйре"],
    "ирмос": ["ермос"],
    "ирнк": ["мрнк"],
    "ирод": ["злодей", "изверг", "мучитель", "негодяй"],
    "иронизировав": ["иронизировавши"],
    "иронизировавши": ["иронизировав"],
    "иронизировать": ["подшучивать", "насмехаться"],
    "иронически": ["иронично"],
    "иронично": ["иронически", "насмешливо"],
    "ироничный": ["иронический", "саркастический", "саркастичный", "ехидный", "насмешливый", "язвительный"],
    "ирония": ["антифразис", "антифраз"],
    "иррадиировав": ["иррадиировавши"],
    "иррадиировавши": ["иррадиировав"],
    "иррадиировать": ["иррадировать"],
    "иррадировав": ["иррадировавши"],
    "иррадировавши": ["иррадировав"],
    "иррадировать": ["иррадиировать"],
    "иррациональность": ["непостижимость", "трансцендентность", "непознаваемость", "нерациональность", "неразумность", "нелогичность"],
    "иррациональный": ["алогичный", "нелогичный", "нерациональный", "иллогичный"],
    "ирреальный": ["нереальный", "невозможный"],
    "иррегулярный": ["нерегулярный"],
    "ирредента": ["ирредентизм"],
    "иррелевантный": ["нерелевантный"],
    "ирригировав": ["ирригировавши"],
    "ирригировавши": ["ирригировав"],
    "ирригировать": ["орошать", "оросить", "обводнять", "обводнить"],
    "ирфон": ["дониш"],
    "исав": ["эсав", "едом", "эдом"],
    "исаия": ["исайя"],
    "исайя": ["исаия"],
    "исбот": ["далел"],
    "исдес": ["исден"],
    "исем": ["ат", "атама"],
    "исемсез бармак": ["атсыз бармак"],
    "исзф": ["сибизмир"],
    "исида": ["изида", "исет", "исис"],
    "исихазм": ["аскеза"],
    "искав": ["искавши"],
    "искавши": ["искав"],
    "искажав": ["искажавши"],
    "искажавши": ["искажав"],
    "искажатель": ["исказитель"],
    "искажать": ["деформировать", "уродовать", "извращать"],
    "искажение": ["искажённость"],
    "искажённый": ["деформированный", "извращённый", "перекошенный"],
    "исказив": ["исказивши"],
    "исказивши": ["исказив"],
    "исказнив": ["исказнивши"],
    "исказнивши": ["исказнив"],
    "искалечив": ["искалечивши"],
    "искалечивав": ["искалечивавши"],
    "искалечивавши": ["искалечивав"],
    "искалечивши": ["искалечив"],
    "искалечить": ["изувечить"],
    "искалывав": ["искалывавши"],
    "искалывавши": ["искалывав"],
    "искандер": ["александр"],
    "искапав": ["искапавши"],
    "искапавши": ["искапав"],
    "искапнув": ["искапнувши"],
    "искапнувши": ["искапнув"],
    "искапнуть": ["искапать"],
    "искапчивав": ["искапчивавши"],
    "искапчивавши": ["искапчивав"],
    "искапывав": ["искапывавши"],
    "искапывавши": ["искапывав"],
    "искармливав": ["искармливавши"],
    "искармливавши": ["искармливав"],
    "искатав": ["искатавши"],
    "искатавши": ["искатав"],
    "искатель": ["поисковик", "детектор"],
    "искательный": ["заискивающий"],
    "искательство": ["поиски", "заискивание"],
    "искать": ["шукать"],
    "искать вчерашний день": ["искать прошлогодний снег"],
    "искать иголку в стоге сена": ["ищи ветра в поле", "ищи-свищи"],
    "искать прошлогодний снег": ["искать вчерашний день"],
    "искашивав": ["искашивавши"],
    "искашивавши": ["искашивав"],
    "иске": ["элекке"],
    "искивав": ["искивавши"],
    "искивавши": ["искивав"],
    "искладенный": ["отделанный", "украшенный"],
    "искласть": ["украсить", "отделать"],
    "исклевав": ["исклевавши"],
    "исклевавши": ["исклевав"],
    "исклевать": ["расклевать", "склевать"],
    "исключав": ["исключавши"],
    "исключавши": ["исключав"],
    "исключать": ["изымать", "элиминировать", "устранять", "убирать", "вычёркивать", "отвергать", "отклонять"],
    "исключение": ["изъятие", "отчисление", "удаление", "устранение"],
    "исключенье": ["исключение"],
    "исключив": ["исключивши"],
    "исключивши": ["исключив"],
    "исключительная мера наказания": ["смертная казнь", "высшая мера", "вышка", "вышак"],
    "исключительно": ["чрезмерно", "чрезвычайно", "очень", "поразительно", "единственно", "только"],
    "исключительный": ["единичный", "частный", "баснословный", "крайний", "необыкновенный", "необычайный", "необычный", "неимоверный", "неординарный", "неповторимый", "нетривиальный", "особенный", "особый", "редкостный", "уникальный"],
    "исклёвывав": ["исклёвывавши"],
    "исклёвывавши": ["исклёвывав"],
    "иско": ["франсиско"],
    "искоблив": ["искобливши"],
    "искобливши": ["искоблив"],
    "искованный": ["выкованный"],
    "исковать": ["выковать"],
    "исковеркав": ["исковеркавши"],
    "исковеркавши": ["исковеркав"],
    "исковеркивав": ["исковеркивавши"],
    "исковеркивавши": ["исковеркивав"],
    "исковыривав": ["исковыривавши"],
    "исковыривавши": ["исковыривав"],
    "исковыряв": ["исковырявши"],
    "исковырявши": ["исковыряв"],
    "исколачивав": ["исколачивавши"],
    "исколачивавши": ["исколачивав"],
    "исколесив": ["исколесивши"],
    "исколесивши": ["исколесив"],
    "исколесить": ["изъездить", "исходить", "объездить"],
    "исколов": ["исколовши"],
    "исколовши": ["исколов"],
    "исколотив": ["исколотивши"],
    "исколотивши": ["исколотив"],
    "исколошматив": ["исколошмативши"],
    "исколошмативши": ["исколошматив"],
    "исколупав": ["исколупавши"],
    "исколупавши": ["исколупав"],
    "исколупывав": ["исколупывавши"],
    "исколупывавши": ["исколупывав"],
    "искомкав": ["искомкавши"],
    "искомкавши": ["искомкав"],
    "искони": ["в начале", "издавна", "издревле", "исконно", "исстари", "испокон", "испокон веков", "спокон веку", "спокон веков"],
    "исконно": ["изначально", "извечно", "искони"],
    "исконный": ["изначальный", "извечный", "коренной"],
    "исконопатив": ["исконопативши"],
    "исконопативши": ["исконопатив"],
    "исконопачивав": ["исконопачивавши"],
    "исконопачивавши": ["исконопачивав"],
    "ископав": ["ископавши"],
    "ископавши": ["ископав"],
    "ископаемое": ["окаменелость", "фоссилия", "пережиток", "рухлядь"],
    "ископтив": ["ископтивши"],
    "ископтивши": ["ископтив"],
    "ископытив": ["ископытивши"],
    "ископытивши": ["ископытив"],
    "искоренение": ["изничтожение", "изжитие", "уничтожение", "выкорчёвка", "вырывание", "ликвидация", "ликвидирование", "выкорчёвывание", "истребление"],
    "искорененье": ["искоренение"],
    "искоренив": ["искоренивши"],
    "искоренивши": ["искоренив"],
    "искоренить": ["истребить", "уничтожить", "вывести"],
    "искореняв": ["искоренявши"],
    "искоренявши": ["искореняв"],
    "искормив": ["искормивши"],
    "искормивши": ["искормив"],
    "искоробив": ["искоробивши"],
    "искоробивши": ["искоробив"],
    "искорёжив": ["искорёживши"],
    "искорёживав": ["искорёживавши"],
    "искорёживавши": ["искорёживав"],
    "искорёживши": ["искорёжив"],
    "искоса": ["косо"],
    "искосив": ["искосивши"],
    "искосивши": ["искосив"],
    "искра": ["отблеск", "проблеск", "крапинка", "признак", "зачаток"],
    "искраивав": ["искраивавши"],
    "искраивавши": ["искраивав"],
    "искрасив": ["искрасивши"],
    "искрасивши": ["искрасив"],
    "искрашивав": ["искрашивавши"],
    "искрашивавши": ["искрашивав"],
    "искрение": ["искрообразование"],
    "искренне": ["искренно", "правдиво", "откровенно", "честно"],
    "искренний": ["правдивый", "честный", "чистосердечный", "бесхитростный", "откровенный", "прямой", "прямодушный", "непритворный"],
    "искренничав": ["искренничавши"],
    "искренничавши": ["искренничав"],
    "искренно": ["искренне", "правдиво", "откровенно", "честно"],
    "искренность": ["откровенность"],
    "искрестив": ["искрестивши"],
    "искрестивши": ["искрестив"],
    "искрещивав": ["искрещивавши"],
    "искрещивавши": ["искрещивав"],
    "искрив": ["искривши"],
    "искривив": ["искрививши"],
    "искрививши": ["искривив"],
    "искривить": ["изогнуть", "согнуть", "исказить"],
    "искривиться": ["перекоситься", "перекривиться", "покоситься", "покривиться", "скоситься", "завалиться", "скособочиться", "похилиться", "скривиться"],
    "искривление": ["изгибание", "изгиб", "кривизна", "искривлённость"],
    "искривленье": ["искривление"],
    "искривляв": ["искривлявши"],
    "искривлявши": ["искривляв"],
    "искривлять": ["изгибать", "искажать"],
    "искривляться": ["изгибаться"],
    "искривши": ["искрив"],
    "искриться": ["сверкать", "лучиться"],
    "искровавив": ["искровавивши"],
    "искровавивши": ["искровавив"],
    "искровавить": ["искровенить"],
    "искровенив": ["искровенивши"],
    "искровенивши": ["искровенив"],
    "искровенить": ["искровавить"],
    "искровеняв": ["искровенявши"],
    "искровенявши": ["искровеняв"],
    "искровянив": ["искровянивши"],
    "искровянивши": ["искровянив"],
    "искрогаситель": ["искроудержатель", "искроуловитель"],
    "искроив": ["искроивши"],
    "искроивши": ["искроив"],
    "искромсав": ["искромсавши"],
    "искромсавши": ["искромсав"],
    "искромётный": ["жгучий", "сверкающий"],
    "искропив": ["искропивши"],
    "искропивши": ["искропив"],
    "искрошив": ["искрошивши"],
    "искрошивши": ["искрошив"],
    "искрошить": ["покрошить"],
    "искрутив": ["искрутивши"],
    "искрутивши": ["искрутив"],
    "искручивав": ["искручивавши"],
    "искручивавши": ["искручивав"],
    "искупав": ["искупавши"],
    "искупавши": ["искупав"],
    "искупаться": ["выкупаться"],
    "искупив": ["искупивши"],
    "искупивши": ["искупив"],
    "искупленье": ["искупление"],
    "искурив": ["искуривши"],
    "искуривав": ["искуривавши"],
    "искуривавши": ["искуривав"],
    "искуривши": ["искурив"],
    "искус": ["испытание", "искушение", "соблазн"],
    "искусав": ["искусавши"],
    "искусавши": ["искусав"],
    "искусив": ["искусивши"],
    "искусивши": ["искусив"],
    "искуситель": ["соблазнитель"],
    "искусить": ["соблазнить", "прельстить"],
    "искусник": ["мастер", "умелец"],
    "искусница": ["мастерица", "умелица"],
    "искусничав": ["искусничавши"],
    "искусничавши": ["искусничав"],
    "искусный": ["умелый", "профессиональный", "виртуозный"],
    "искусственная вентиляция лёгких": ["искусственное дыхание"],
    "искусственная нейронная сеть": ["инс"],
    "искусственно": ["рукотворно", "умышленно", "притворно", "неискренне", "ненатурально"],
    "искусственное дыхание": ["искусственная вентиляция лёгких"],
    "искусственность": ["неестественность"],
    "искусственный": ["рукотворный", "антропогенный", "вымученный", "деланый", "наигранный", "напускной", "неестественный", "поддельный", "притворный", "фальшивый", "надуманный"],
    "искусственный интеллект": ["ии"],
    "искусство": ["творчество", "мастерство", "умение", "занятие"],
    "искусствоведение": ["искусствознание"],
    "искусывав": ["искусывавши"],
    "искусывавши": ["искусывав"],
    "искусывание": ["искусыванье"],
    "искушав": ["искушавши"],
    "искушавши": ["искушав"],
    "искушать": ["испытывать", "пробовать", "проверять", "соблазнять", "прельщать"],
    "искушение": ["обольщение", "прельщение", "соблазнение", "соблазн", "искус"],
    "искушенье": ["искушение"],
    "искушённый": ["бывалый", "тёртый", "искусный", "опытный", "матёрый"],
    "ислам": ["мусульманство", "магометанство"],
    "исламизировав": ["исламизировавши"],
    "исламизировавши": ["исламизировав"],
    "исламизм": ["ислам", "магометанство", "мусульманство"],
    "исламист": ["мусульманин", "магометанин"],
    "исламофобия": ["антиисламизм"],
    "исламская республика иран": ["иран", "персия"],
    "исламский": ["мусульманский"],
    "исламское государство": ["исламское государство ирака и леванта", "игил", "даиш", "запрещённое государство"],
    "исламское государство ирака и леванта": ["исламское государство ирака и шама", "исламское государство", "игил", "иг", "даиш"],
    "исландия": ["республика исландия"],
    "исландский язык": ["исландский"],
    "исоп": ["иссоп"],
    "испаивав": ["испаивавши"],
    "испаивавши": ["испаивав"],
    "испакостив": ["испакостивши"],
    "испакостивши": ["испакостив"],
    "испакостить": ["загваздать"],
    "испакощивав": ["испакощивавши"],
    "испакощивавши": ["испакощивав"],
    "испанец": ["гишпанец"],
    "испанист": ["испанолог"],
    "испания": ["королевство испания"],
    "испано-американский": ["американо-испанский"],
    "испаноговорящий": ["испаноязычный"],
    "испанолог": ["испанист"],
    "испанский": ["гишпанский", "испанский язык"],
    "испанский стыд": ["кринж", "кукож"],
    "испанский язык": ["кастильский язык"],
    "испаренье": ["испарение"],
    "испарив": ["испаривши"],
    "испаривши": ["испарив"],
    "испарина": ["пот"],
    "испаритель": ["эвапоратор"],
    "испариться": ["выкипеть", "выпариться", "высохнуть", "пропасть", "сгинуть"],
    "испаряв": ["испарявши"],
    "испарявши": ["испаряв"],
    "испаскудив": ["испаскудивши"],
    "испаскудивши": ["испаскудив"],
    "испахав": ["испахавши"],
    "испахавши": ["испахав"],
    "испахивав": ["испахивавши"],
    "испахивавши": ["испахивав"],
    "испачкав": ["испачкавши"],
    "испачкавши": ["испачкав"],
    "испачкать": ["загрязнить", "замарать", "запачкать"],
    "испачкаться": ["изгваздаться"],
    "испекав": ["испекавши"],
    "испекавши": ["испекав"],
    "испекать": ["печь", "выпекать"],
    "испепелив": ["испепеливши"],
    "испепеливши": ["испепелив"],
    "испепеляв": ["испепелявши"],
    "испепелявши": ["испепеляв"],
    "испепелять": ["уничтожать", "губить"],
    "испестрив": ["испестривши"],
    "испестривши": ["испестрив"],
    "испестряв": ["испестрявши"],
    "испестрявши": ["испестряв"],
    "испещрив": ["испещривши"],
    "испещривши": ["испещрив"],
    "испещрить": ["испестрить"],
    "испещряв": ["испещрявши"],
    "испещрявши": ["испещряв"],
    "испещрять": ["испестрять"],
    "испещряться": ["испестряться"],
    "испещрённый": ["усеянный", "полный"],
    "испив": ["испивши"],
    "испивав": ["испивавши"],
    "испивавши": ["испивав"],
    "испивать": ["попивать", "потягивать", "выпивать"],
    "испивши": ["испив"],
    "испиздеться": ["изовраться"],
    "испиздив": ["испиздивши"],
    "испиздивши": ["испиздив"],
    "испиздить": ["измудохать", "отпиздить"],
    "испилив": ["испиливши"],
    "испиливав": ["испиливавши"],
    "испиливавши": ["испиливав"],
    "испиливши": ["испилив"],
    "исписав": ["исписавши"],
    "исписавши": ["исписав"],
    "исписывав": ["исписывавши"],
    "исписывавши": ["исписывав"],
    "испитой": ["измождённый", "изнурённый", "истощённый"],
    "испить": ["выпить", "отпить", "вынести", "вытерпеть", "пережить", "изведать"],
    "исплавав": ["исплававши"],
    "исплававши": ["исплавав"],
    "исплакав": ["исплакавши"],
    "исплакавши": ["исплакав"],
    "исплакаться": ["изрыдаться"],
    "испластав": ["испластавши"],
    "испластавши": ["испластав"],
    "исплачивав": ["исплачивавши"],
    "исплачивавши": ["исплачивав"],
    "исплевав": ["исплевавши"],
    "исплевавши": ["исплевав"],
    "исплесневев": ["исплесневевши"],
    "исплесневевши": ["исплесневев"],
    "исплутав": ["исплутавши"],
    "исплутавши": ["исплутав"],
    "исплёвывав": ["исплёвывавши"],
    "исплёвывавши": ["исплёвывав"],
    "исповедав": ["исповедавши"],
    "исповедавши": ["исповедав"],
    "исповедальня": ["конфессионал"],
    "исповедание": ["исповедование", "исповедь", "религия", "вероисповедание", "конфессия"],
    "исповеданье": ["исповедание"],
    "исповедовав": ["исповедовавши"],
    "исповедовавши": ["исповедовав"],
    "исповедовать": ["верить", "исповедоваться"],
    "исповедывав": ["исповедывавши"],
    "исповедывавши": ["исповедывав"],
    "испоганив": ["испоганивши"],
    "испоганивав": ["испоганивавши"],
    "испоганивавши": ["испоганивав"],
    "испоганивать": ["портить", "осквернять"],
    "испоганивши": ["испоганив"],
    "исподволь": ["понемногу", "постепенно", "помаленьку", "украдкой", "тайком"],
    "исподнее": ["нижнее бельё"],
    "исподний": ["нижний"],
    "исподтишка": ["втихаря", "втихомолку", "исподтиха", "незаметно", "скрытно", "тайно"],
    "испоив": ["испоивши"],
    "испоивши": ["испоив"],
    "испокон": ["издавна", "традиционно", "всегда"],
    "исполать": ["хвала", "слава"],
    "исползав": ["исползавши"],
    "исползавши": ["исползав"],
    "исполин": ["великан", "богатырь", "гигант", "голиаф", "атлант", "амбал", "силач", "здоровяк", "гений", "титан"],
    "исполински": ["колоссально"],
    "исполинский": ["гигантский", "огромный", "колоссальный"],
    "исполком": ["исполнительный комитет"],
    "исполнение": ["выполнение"],
    "исполненный": ["выполненный", "сделанный", "полный"],
    "исполненье": ["исполнение"],
    "исполнив": ["исполнивши"],
    "исполнивши": ["исполнив"],
    "исполнительность": ["старательность"],
    "исполнить": ["осуществить", "выполнить", "претворить", "сыграть", "сбацать", "наполнить", "одушевить"],
    "исполниться": ["осуществиться", "претвориться"],
    "исполняв": ["исполнявши"],
    "исполнявши": ["исполняв"],
    "исполняемый": ["выполняемый"],
    "исполнять": ["выполнять", "осуществлять"],
    "исполнять арию риголетто": ["блевать", "звать ихтиандра", "кормить ихтиандра"],
    "исполняться": ["выполняться", "осуществляться"],
    "исполовничав": ["исполовничавши"],
    "исполовничавши": ["исполовничав"],
    "исполосовав": ["исполосовавши"],
    "исполосовавши": ["исполосовав"],
    "исполосовывав": ["исполосовывавши"],
    "исполосовывавши": ["исполосовывав"],
    "исполохав": ["исполохавши"],
    "исполохавши": ["исполохав"],
    "исполохать": ["всполошить", "исполошить", "исполоховать", "исполохнуть", "испужать"],
    "исполу": ["вполовину", "пополам"],
    "использовав": ["использовавши"],
    "использовавши": ["использовав"],
    "использовавшийся": ["применявшийся"],
    "использование": ["пользование", "применение"],
    "использованность": ["исчерпанность", "израсходованность"],
    "использовать": ["пользоваться", "употреблять", "применять", "прибегать", "эксплуатировать", "утилизировать", "воспользоваться"],
    "использовывав": ["использовывавши"],
    "использовывавши": ["использовывав"],
    "использовывать": ["использовать"],
    "испольничав": ["испольничавши"],
    "испольничавши": ["испольничав"],
    "испомещав": ["испомещавши"],
    "испомещавши": ["испомещав"],
    "испоров": ["испоровши"],
    "испоровши": ["испоров"],
    "испортив": ["испортивши"],
    "испортивши": ["испортив"],
    "испортить воздух": ["пукнуть", "напердеть", "набздеть"],
    "испортить всю обедню": ["всю малину изгадить"],
    "испортиться": ["ухудшиться"],
    "испорченный телефон": ["сосед справа"],
    "испохабив": ["испохабивши"],
    "испохабивши": ["испохабив"],
    "испошлив": ["испошливши"],
    "испошливши": ["испошлив"],
    "исправив": ["исправивши"],
    "исправивши": ["исправив"],
    "исправитель": ["улучшатель", "переправщик", "исправщик"],
    "исправительный": ["пенитенциарный"],
    "исправить": ["поправить", "откорректировать", "починить", "искупить", "загладить"],
    "исправиться": ["поправиться"],
    "исправленье": ["исправление"],
    "исправляв": ["исправлявши"],
    "исправлявши": ["исправляв"],
    "исправлять": ["править", "поправлять", "корректировать", "улучшать", "совершенствовать", "чинить", "починять", "ремонтировать", "искупать", "заглаживать", "исполнять", "служить"],
    "исправник": ["полицмейстер"],
    "исправница": ["исправничиха"],
    "испражнение": ["какание", "дефекация", "кал", "экскременты", "фекалии"],
    "испражненье": ["испражнение"],
    "испражнить": ["очистить", "опорожнить"],
    "испражниться": ["покакать", "посрать", "опростаться", "отложить личинку"],
    "испражнять": ["выкакивать", "опорожнять", "уничтожать"],
    "испражняться": ["какать", "срать", "опрастываться", "дристать"],
    "испражняясь": ["какая"],
    "испрашивав": ["испрашивавши"],
    "испрашивавши": ["испрашивав"],
    "испрев": ["испревши"],
    "испревав": ["испревавши"],
    "испревавши": ["испревав"],
    "испревши": ["испрев"],
    "испробовав": ["испробовавши"],
    "испробовавши": ["испробовав"],
    "испробованный": ["изведанный"],
    "испросив": ["испросивши"],
    "испросивши": ["испросив"],
    "испрыскав": ["испрыскавши"],
    "испрыскавши": ["испрыскав"],
    "испрыскивав": ["испрыскивавши"],
    "испрыскивавши": ["испрыскивав"],
    "испрыскивать": ["избрызгивать"],
    "испрямив": ["испрямивши"],
    "испрямивши": ["испрямив"],
    "испрямить": ["выпрямить", "распрямить"],
    "испрямляв": ["испрямлявши"],
    "испрямлявши": ["испрямляв"],
    "испрямлять": ["выпрямлять"],
    "испуг": ["испуга", "страх", "боязнь", "ужас", "паника"],
    "испугав": ["испугавши"],
    "испугавши": ["испугав"],
    "испуганность": ["несмелость", "малодушие", "боязливость", "робость", "трусливость", "опасливость", "малодушество", "трусость"],
    "испуганный": ["напуганный"],
    "испугаться": ["почувствовать страх", "забояться", "сдрейфить"],
    "испужав": ["испужавши"],
    "испужавши": ["испужав"],
    "испужаться": ["струсить"],
    "испускав": ["испускавши"],
    "испускавши": ["испускав"],
    "испустив": ["испустивши"],
    "испустивши": ["испустив"],
    "испустить": ["издать", "распространить"],
    "испытав": ["испытавши"],
    "испытавши": ["испытав"],
    "испытание": ["проверка", "поверка", "выверка", "проба", "пробование", "опробование", "опробывание", "пробация", "апробация", "апробирование", "пробованье", "опробованье", "опробыванье", "апробированье", "испытанье"],
    "испытанье": ["испытание"],
    "испытательный срок": ["стажировка", "испытание", "послушничество", "условное освобождение на поруки", "искус"],
    "испытать": ["проверить", "протестировать", "пережить", "перенести", "ощутить", "почувствовать"],
    "испытывав": ["испытывавши"],
    "испытывавши": ["испытывав"],
    "испытывать": ["опробовать", "пробовать", "проверять", "тестировать", "ощущать", "переживать", "чувствовать", "претерпевать"],
    "испьянствоваться": ["спиться"],
    "испятнав": ["испятнавши"],
    "испятнавши": ["испятнав"],
    "иссакар": ["иссахар"],
    "иссалив": ["иссаливши"],
    "иссаливав": ["иссаливавши"],
    "иссаливавши": ["иссаливав"],
    "иссаливши": ["иссалив"],
    "иссалить": ["засалить"],
    "иссасывав": ["иссасывавши"],
    "иссасывавши": ["иссасывав"],
    "иссахар": ["иссакар"],
    "иссверлив": ["иссверливши"],
    "иссверливав": ["иссверливавши"],
    "иссверливавши": ["иссверливав"],
    "иссверливши": ["иссверлив"],
    "исседон": ["сармат"],
    "иссекав": ["иссекавши"],
    "иссекавши": ["иссекав"],
    "иссечённый": ["высеченный"],
    "иссинив": ["иссинивши"],
    "иссинивав": ["иссинивавши"],
    "иссинивавши": ["иссинивав"],
    "иссинивши": ["иссинив"],
    "иссиня-чёрный": ["аспидный", "иссиза-чёрный", "лилово-чёрный", "свинцово-чёрный", "угольно-чёрный"],
    "исследив": ["исследивши"],
    "исследивши": ["исследив"],
    "исследовав": ["исследовавши"],
    "исследовавши": ["исследовав"],
    "исследование": ["изучение", "анализ", "испытание", "мониторинг", "изыскание", "эксплорация", "научный труд"],
    "исследование операций": ["ио"],
    "исследованный": ["познанный"],
    "исследованье": ["исследование"],
    "исследователь": ["разыскатель"],
    "исследовательский": ["эксплораторный"],
    "исследовать": ["изучать", "изучить", "анализировать", "проанализировать", "обследовать"],
    "исслеживав": ["исслеживавши"],
    "исслеживавши": ["исслеживав"],
    "исслюнив": ["исслюнивши"],
    "исслюнивав": ["исслюнивавши"],
    "исслюнивавши": ["исслюнивав"],
    "исслюнивавший": ["исслюнявливавший"],
    "исслюнивать": ["исслюнявливать"],
    "исслюнивши": ["исслюнив"],
    "исслюнявив": ["исслюнявивши"],
    "исслюнявивши": ["исслюнявив"],
    "исслюнявливав": ["исслюнявливавши"],
    "исслюнявливавши": ["исслюнявливав"],
    "исслюнявливать": ["исслюнивать"],
    "исслюнявливаться": ["исслюниваться"],
    "иссолив": ["иссоливши"],
    "иссоливши": ["иссолив"],
    "иссосав": ["иссосавши"],
    "иссосавши": ["иссосав"],
    "иссохнув": ["иссохнувши"],
    "иссохнувши": ["иссохнув"],
    "иссохший": ["высохший", "обезвоженный"],
    "иссрамив": ["иссрамивши"],
    "иссрамивши": ["иссрамив"],
    "исстари": ["с давних пор", "издавна", "издревле"],
    "исстегав": ["исстегавши"],
    "исстегавши": ["исстегав"],
    "исстелив": ["исстеливши"],
    "исстеливши": ["исстелив"],
    "исстелить": ["изостлать"],
    "исстилав": ["исстилавши"],
    "исстилавши": ["исстилав"],
    "исстирав": ["исстиравши"],
    "исстиравши": ["исстирав"],
    "исстирывав": ["исстирывавши"],
    "исстирывавши": ["исстирывав"],
    "исстрагивав": ["исстрагивавши"],
    "исстрагивавши": ["исстрагивав"],
    "исстрачивав": ["исстрачивавши"],
    "исстрачивавши": ["исстрачивав"],
    "исстреливав": ["исстреливавши"],
    "исстреливавши": ["исстреливав"],
    "исстреляв": ["исстрелявши"],
    "исстрелявши": ["исстреляв"],
    "исстрогав": ["исстрогавши"],
    "исстрогавши": ["исстрогав"],
    "исстрогать": ["исстругать"],
    "исстрочив": ["исстрочивши"],
    "исстрочивши": ["исстрочив"],
    "исстругав": ["исстругавши"],
    "исстругавши": ["исстругав"],
    "исстругивав": ["исстругивавши"],
    "исстругивавши": ["исстругивав"],
    "исстругивать": ["исстрагивать"],
    "исступление": ["неистовство", "аффект", "исступленье"],
    "исступленье": ["исступление"],
    "исступлённо": ["неистово", "возбуждённо"],
    "исступлённый": ["неистовый"],
    "исстёгивав": ["исстёгивавши"],
    "исстёгивавши": ["исстёгивав"],
    "иссушав": ["иссушавши"],
    "иссушавши": ["иссушав"],
    "иссушать": ["обезвоживать"],
    "иссушив": ["иссушивши"],
    "иссушивав": ["иссушивавши"],
    "иссушивавши": ["иссушивав"],
    "иссушивши": ["иссушив"],
    "иссыхав": ["иссыхавши"],
    "иссыхавши": ["иссыхав"],
    "иссякав": ["иссякавши"],
    "иссякавши": ["иссякав"],
    "иссякание": ["убыль"],
    "иссякать": ["высыхать", "пересыхать", "заканчиваться", "исчерпываться"],
    "иссякнув": ["иссякнувши"],
    "иссякнувши": ["иссякнув"],
    "иссякнуть": ["высохнуть", "пересохнуть", "кончиться", "закончиться", "исчерпаться"],
    "истаивав": ["истаивавши"],
    "истаивавши": ["истаивав"],
    "истапливав": ["истапливавши"],
    "истапливавши": ["истапливав"],
    "истаптывав": ["истаптывавши"],
    "истаптывавши": ["истаптывав"],
    "истаскав": ["истаскавши"],
    "истаскавши": ["истаскав"],
    "истаскивав": ["истаскивавши"],
    "истаскивавши": ["истаскивав"],
    "истаскивать": ["изнашивать", "опошлять"],
    "истачивав": ["истачивавши"],
    "истачивавши": ["истачивав"],
    "истачивать": ["стачивать", "издырявливать"],
    "истаяв": ["истаявши"],
    "истаявши": ["истаяв"],
    "истеблишмент": ["элита", "сливки общества", "номенклатура", "власть имущие", "правящие круги", "политическая элита", "аристократия", "бомонд"],
    "истекав": ["истекавши"],
    "истекавши": ["истекав"],
    "истекать": ["изливаться", "утекать", "выливаться", "вытекать"],
    "истекший": ["прошедший", "окончившийся"],
    "истеребив": ["истеребивши"],
    "истеребивши": ["истеребив"],
    "истерев": ["истёрши"],
    "истерзав": ["истерзавши"],
    "истерзавши": ["истерзав"],
    "истерив": ["истеривши"],
    "истеривши": ["истерив"],
    "истерить": ["закатывать истерику", "истеричить", "плакать", "реветь", "орать"],
    "истерически": ["истерично", "болезненно-страстно"],
    "истерично": ["истерически"],
    "истеричный": ["истерический"],
    "истерия": ["бешенство матки", "психоз"],
    "истесав": ["истесавши"],
    "истесавши": ["истесав"],
    "истец": ["заявитель"],
    "истечение": ["вытекание", "выливание", "окончание"],
    "истеченье": ["истечение"],
    "истечь": ["вытечь", "окончиться", "иссякнуть", "истощиться", "исчерпаться", "выйти"],
    "истина": ["подлинность", "реальность", "факт", "правда"],
    "истинный": ["правильный", "верный", "несомненный", "неподдельный", "подлинный"],
    "истирав": ["истиравши"],
    "истиравши": ["истирав"],
    "истиранив": ["истиранивши"],
    "истиранивши": ["истиранив"],
    "истискав": ["истискавши"],
    "истискавши": ["истискав"],
    "истискивав": ["истискивавши"],
    "истискивавши": ["истискивав"],
    "исткав": ["исткавши"],
    "исткавши": ["исткав"],
    "истлев": ["истлевши"],
    "истлевав": ["истлевавши"],
    "истлевавши": ["истлевав"],
    "истлевши": ["истлев"],
    "истлеть": ["сгнить", "догнить", "перегнить", "разложиться", "дотлеть", "обветшать", "распасться", "рассыпаться", "обратиться в прах", "превратиться в труху", "догореть", "прогореть", "обратиться в пепел", "потухнуть", "угаснуть"],
    "истово": ["должным образом", "надлежаще", "ревностно", "усердно"],
    "истовъ": ["истъ"],
    "истовый": ["адекватный"],
    "истолкав": ["истолкавши"],
    "истолкавши": ["истолкав"],
    "истолковав": ["истолковавши"],
    "истолковавши": ["истолковав"],
    "истолкование": ["истолковывание", "объяснение", "разъяснение", "трактовка", "интерпретация"],
    "истолкованье": ["истолкование"],
    "истолкователь": ["толкователь"],
    "истолковать": ["объяснить", "разъяснить", "интерпретировать"],
    "истолковывав": ["истолковывавши"],
    "истолковывавши": ["истолковывав"],
    "истолковывание": ["истолкование", "объяснение", "разъяснение", "трактовка", "интерпретация"],
    "истолковывать": ["толковать", "понимать", "расценивать"],
    "истома": ["слабость", "томление"],
    "истомив": ["истомивши"],
    "истомивши": ["истомив"],
    "истомляв": ["истомлявши"],
    "истомлявши": ["истомляв"],
    "истомлять": ["мучить", "изнурять"],
    "истончав": ["истончавши"],
    "истончавши": ["истончав"],
    "истончив": ["истончивши"],
    "истончивши": ["истончив"],
    "истопив": ["истопивши"],
    "истопивши": ["истопив"],
    "истоптав": ["истоптавши"],
    "истоптавши": ["истоптав"],
    "исторгав": ["исторгавши"],
    "исторгавши": ["исторгав"],
    "исторгнув": ["исторгнувши"],
    "исторгнувши": ["исторгнув"],
    "исторгнуть": ["извергнуть"],
    "историзм": ["историчность"],
    "исторические воды": ["территориальные воды"],
    "исторический материализм": ["истмат"],
    "историчность": ["историзм"],
    "история": ["прошлое", "рассказ", "переплёт", "происшествие", "приключение", "случай", "скандал", "неприятность"],
    "источав": ["источавши"],
    "источавши": ["источав"],
    "источать": ["испускать"],
    "источив": ["источивши"],
    "источивши": ["источив"],
    "источник бесперебойного питания": ["бесперебойник", "упс", "ибп"],
    "истошно": ["отчаянно"],
    "истошный": ["громкий", "отчаянный", "дикий"],
    "истощав": ["истощавши"],
    "истощавши": ["истощав"],
    "истощение": ["истощенье", "изнурённость", "уменьшение"],
    "истощенье": ["истощение"],
    "истощив": ["истощивши"],
    "истощивши": ["истощив"],
    "истощить": ["ослабить", "обессилить"],
    "истр": ["гистрия", "истрия"],
    "истрактовав": ["истрактовавши"],
    "истрактовавши": ["истрактовав"],
    "истратив": ["истративши"],
    "истративши": ["истратив"],
    "истратить": ["израсходовать", "потратить", "растратить"],
    "истратиться": ["израсходоваться"],
    "истрачивав": ["истрачивавши"],
    "истрачивавши": ["истрачивав"],
    "истрачивать": ["тратить", "расходовать"],
    "истрачиваться": ["тратиться", "расходоваться", "растрачиваться"],
    "истребив": ["истребивши"],
    "истребивши": ["истребив"],
    "истребитель": ["истребительный самолёт", "эскадренный миноносец", "эсминец", "контр-миноносец"],
    "истребить": ["изничтожить", "извести"],
    "истребление": ["уничтожение"],
    "истребленье": ["истребление"],
    "истребляв": ["истреблявши"],
    "истреблявши": ["истребляв"],
    "истреблять": ["уничтожать"],
    "истребовав": ["истребовавши"],
    "истребовавши": ["истребовав"],
    "истрепав": ["истрепавши"],
    "истрепавши": ["истрепав"],
    "истрорумынский": ["истрорумынский язык"],
    "иструхлявев": ["иструхлявевши"],
    "иструхлявевши": ["иструхлявев"],
    "иструхляветь": ["иструхлявиться"],
    "иструхлявив": ["иструхлявивши"],
    "иструхлявивши": ["иструхлявив"],
    "иструхнув": ["иструхнувши"],
    "иструхнувши": ["иструхнув"],
    "иструхнуть": ["иструхляветь"],
    "истрёпывав": ["истрёпывавши"],
    "истрёпывавши": ["истрёпывав"],
    "истрёпываемый": ["истаскиваемый", "изнашиваемый"],
    "истукан": ["божок", "идол"],
    "иступив": ["иступивши"],
    "иступивши": ["иступив"],
    "иступить": ["затупить"],
    "иступляв": ["иступлявши"],
    "иступлявши": ["иступляв"],
    "истъ": ["истовъ"],
    "истый": ["настоящий", "истинный", "подлинный", "ревностный", "убеждённый"],
    "истыкав": ["истыкавши"],
    "истыкавши": ["истыкав"],
    "истыкивав": ["истыкивавши"],
    "истыкивавши": ["истыкивав"],
    "истязав": ["истязавши"],
    "истязавши": ["истязав"],
    "истязание": ["мучение", "пытка"],
    "истязанье": ["истязание"],
    "истязать": ["пытать", "мучить", "терзать"],
    "истёкший": ["исходивший", "вытекший", "утёкший", "вылившийся"],
    "истёрши": ["истерев"],
    "истёсывав": ["истёсывавши"],
    "истёсывавши": ["истёсывав"],
    "исхаживав": ["исхаживавши"],
    "исхаживавши": ["исхаживав"],
    "исхарчив": ["исхарчивши"],
    "исхарчивши": ["исхарчив"],
    "исхаяв": ["исхаявши"],
    "исхаявши": ["исхаяв"],
    "исхитив": ["исхитивши"],
    "исхитивши": ["исхитив"],
    "исхитриться": ["наловчиться", "изловчиться", "ухитриться"],
    "исхитряться": ["изловчаться", "ухитряться"],
    "исхищав": ["исхищавши"],
    "исхищавши": ["исхищав"],
    "исхищряться": ["изощряться"],
    "исхлестав": ["исхлеставши"],
    "исхлеставши": ["исхлестав"],
    "исхлопатывав": ["исхлопатывавши"],
    "исхлопатывавши": ["исхлопатывав"],
    "исхлопотав": ["исхлопотавши"],
    "исхлопотавши": ["исхлопотав"],
    "исхлёстывав": ["исхлёстывавши"],
    "исхлёстывавши": ["исхлёстывав"],
    "исход": ["уход", "отход", "отъезд", "убытие", "выход", "итог", "плод", "результат"],
    "исходатайствовав": ["исходатайствовавши"],
    "исходатайствовавши": ["исходатайствовав"],
    "исходатайствовать": ["выхлопотать"],
    "исходив": ["исходивши"],
    "исходивши": ["исходив"],
    "исходить": ["обойти"],
    "исходный": ["начальный", "изначальный", "отправной", "оригинальный", "элативный"],
    "исходный код": ["программный код", "листинг"],
    "исходный падеж": ["элатив", "элятив", "аблатив", "отложительный падеж"],
    "исходя из": ["опираясь на", "основываясь на", "ссылаясь на", "указывая на"],
    "исхождение": ["исхожденье"],
    "исхудав": ["исхудавши"],
    "исхудавши": ["исхудав"],
    "исхудалый": ["исхудавший"],
    "исхудать": ["отощать"],
    "исхудев": ["исхудевши"],
    "исхудевши": ["исхудев"],
    "исхудеть": ["исхудать"],
    "исхуярив": ["исхуяривши"],
    "исхуяривши": ["исхуярив"],
    "исхуячив": ["исхуячивши"],
    "исхуячивши": ["исхуячив"],
    "исхуячить": ["исхуярить"],
    "исхуёвничаться": ["изговниться"],
    "исцарапав": ["исцарапавши"],
    "исцарапавши": ["исцарапав"],
    "исцарапывав": ["исцарапывавши"],
    "исцарапывавши": ["исцарапывав"],
    "исцеление": ["исцеленье", "излечение", "оздоровление"],
    "исцеленье": ["исцеление"],
    "исцелив": ["исцеливши"],
    "исцеливши": ["исцелив"],
    "исцелимый": ["излечимый"],
    "исцелить": ["вылечить", "излечить"],
    "исцелиться": ["вылечиться", "излечиться"],
    "исцеловав": ["исцеловавши"],
    "исцеловавши": ["исцеловав"],
    "исцеляв": ["исцелявши"],
    "исцелявши": ["исцеляв"],
    "исцелять": ["излечивать"],
    "исчадие": ["детище", "выродок", "отродье"],
    "исчадие ада": ["изверг"],
    "исчадье": ["исчадие", "детище", "выродок", "отродье"],
    "исчахнув": ["исчахнувши"],
    "исчахнувши": ["исчахнув"],
    "исчезав": ["исчезавши"],
    "исчезавши": ["исчезав"],
    "исчезание": ["исчезновение", "пропадание"],
    "исчезать": ["пропадать", "улетучиваться", "теряться"],
    "исчезновенье": ["исчезновение"],
    "исчезнув": ["исчезнувши"],
    "исчезнувши": ["исчезнув"],
    "исчезнуть": ["пропасть"],
    "исчервивев": ["исчервивевши"],
    "исчервивевши": ["исчервивев"],
    "исчеркав": ["исчеркавши"],
    "исчеркавши": ["исчеркав"],
    "исчернив": ["исчернивши"],
    "исчернивши": ["исчернив"],
    "исчерняв": ["исчернявши"],
    "исчернявши": ["исчерняв"],
    "исчерпав": ["исчерпавши"],
    "исчерпавши": ["исчерпав"],
    "исчерпаться": ["закончиться", "израсходоваться"],
    "исчерпывав": ["исчерпывавши"],
    "исчерпывавши": ["исчерпывав"],
    "исчертив": ["исчертивши"],
    "исчертивши": ["исчертив"],
    "исчерчивав": ["исчерчивавши"],
    "исчерчивавши": ["исчерчивав"],
    "исчесав": ["исчесавши"],
    "исчесавши": ["исчесав"],
    "исчиркав": ["исчиркавши"],
    "исчиркавши": ["исчиркав"],
    "исчиркивав": ["исчиркивавши"],
    "исчиркивавши": ["исчиркивав"],
    "исчисленье": ["исчисление"],
    "исчислив": ["исчисливши"],
    "исчисливши": ["исчислив"],
    "исчислимость": ["вычислимость", "вычисляемость"],
    "исчислить": ["подсчитать", "сосчитать"],
    "исчисляв": ["исчислявши"],
    "исчислявши": ["исчисляв"],
    "исчислять": ["подсчитывать", "вычислять", "считать"],
    "исчёркав": ["исчёркавши"],
    "исчёркавши": ["исчёркав"],
    "исчёркивав": ["исчёркивавши"],
    "исчёркивавши": ["исчёркивав"],
    "исшагав": ["исшагавши"],
    "исшагавши": ["исшагав"],
    "исшагать": ["исходить"],
    "исшарив": ["исшаривши"],
    "исшаривав": ["исшаривавши"],
    "исшаривавши": ["исшаривав"],
    "исшаривши": ["исшарив"],
    "исшаркав": ["исшаркавши"],
    "исшаркавши": ["исшаркав"],
    "исшаркивав": ["исшаркивавши"],
    "исшаркивавши": ["исшаркивав"],
    "исшив": ["исшивши"],
    "исшивав": ["исшивавши"],
    "исшивавши": ["исшивав"],
    "исшивши": ["исшив"],
    "исшнырив": ["исшныривши"],
    "исшныривав": ["исшныривавши"],
    "исшныривавши": ["исшныривав"],
    "исшныривши": ["исшнырив"],
    "исшнырить": ["исшнырять"],
    "исшныряв": ["исшнырявши"],
    "исшнырявши": ["исшныряв"],
    "исшоркав": ["исшоркавши"],
    "исшоркавши": ["исшоркав"],
    "исштопав": ["исштопавши"],
    "исштопавши": ["исштопав"],
    "исштопывав": ["исштопывавши"],
    "исштопывавши": ["исштопывав"],
    "исщепав": ["исщепавши"],
    "исщепавши": ["исщепав"],
    "исщербив": ["исщербивши"],
    "исщербивши": ["исщербив"],
    "исщипав": ["исщипавши"],
    "исщипавши": ["исщипав"],
    "исщипывав": ["исщипывавши"],
    "исщипывавши": ["исщипывав"],
    "ит-специалист": ["ит-персонал"],
    "ита": ["эта"],
    "итак": ["таким образом", "следовательно"],
    "италиец": ["италик"],
    "италия": ["итальянская республика", "королевство италия", "итальянская социальная республика", "авзония"],
    "италиянский": ["итальянский"],
    "итальянец": ["итальяшка", "макаронник"],
    "итальянская забастовка": ["обструкция"],
    "итальянская республика": ["италия"],
    "итальянский": ["италиянский"],
    "ительмен": ["камчадал"],
    "ительменский язык": ["камчадальский язык"],
    "итеративный": ["многократный", "итерационный"],
    "итерационный": ["итеративный", "повторный", "повторяющийся"],
    "итербит": ["иттербит"],
    "итерировав": ["итерировавши"],
    "итерировавши": ["итерировав"],
    "итерирование": ["итерация"],
    "итоат": ["итоъат"],
    "итоаткор": ["итоаткеш"],
    "итог": ["результат", "конец", "вывод", "следствие", "плод", "последствие", "продукт", "развязка", "исход", "эффект", "сумма", "остаток"],
    "итого": ["всего", "в итоге"],
    "итожив": ["итоживши"],
    "итоживши": ["итожив"],
    "итожимый": ["обобщаемый", "суммируемый", "подытоживаемый", "резюмируемый"],
    "итожить": ["подводить итоги", "подытоживать"],
    "итоъат": ["итоат"],
    "иттилоот": ["хабар", "ахборот", "маълумот"],
    "иту": ["исправительно-трудовое учреждение"],
    "ить": ["ведь", "иди"],
    "иуда": ["иегуда"],
    "иудаизация": ["насаждение", "принуждение"],
    "иудаизм": ["иудейство", "юдаизм"],
    "иудаика": ["иудаистика"],
    "иудаист": ["иудей"],
    "иудаистика": ["иудаика"],
    "иудей": ["еврей", "иудаист"],
    "иудействовав": ["иудействовавши"],
    "иудействовавши": ["иудействовав"],
    "иудеохристианство": ["иудео-христианство"],
    "иудушка": ["лицемер", "ханжа"],
    "иустин": ["юстин", "устим", "устин"],
    "ифика": ["этика"],
    "ифтихор": ["такаббур"],
    "ифугао": ["батад"],
    "их": ["ихний", "ихий", "ихов", "ихный", "ихый"],
    "их бин больной": ["больной", "болею", "болен"],
    "ихлос": ["самимият"],
    "ихневмон": ["египетский мангуст", "фараонова мышь"],
    "ихний": ["их", "ихов", "ихий", "ихный", "ихый"],
    "ихор": ["гной", "сукровица", "кровь"],
    "ихтамнет": ["настамнет", "потеряшка", "срочник-потеряшка", "нипричёмыш"],
    "ихтиандр": ["ихтиандровец"],
    "ихтиозавр": ["рыбоящер"],
    "ихтиол": ["ихтаммол"],
    "ихтиолог": ["ихтиологист"],
    "ихтиостегалия": ["ихтиостега"],
    "ихтисос": ["пеша", "касб"],
    "иц": ["ич"],
    "ич": ["иц"],
    "иче": ["эне"],
    "ичиг": ["ичег", "ичегот"],
    "ичкерия": ["чеченская республика ичкерия", "чечня", "чри"],
    "ичленюв": ["башланув"],
    "ичэридеми": ["сэвэнчэдеми"],
    "ишак": ["осёл", "ешак", "эшак"],
    "ишачив": ["ишачивши"],
    "ишачивши": ["ишачив"],
    "ишачить": ["вкалывать", "горбатиться", "гнуть спину", "частичн", "батрачить", "надрываться", "пластаться"],
    "ишегалды": ["ишек алды"],
    "ишемия": ["местная анемия", "гипемия", "местное малокровие", "компрессия"],
    "ишиалгия": ["ишиас"],
    "ишиас": ["пояснично-крестцовый радикулит"],
    "ишиатический": ["ишиасный"],
    "ишурия": ["острая задержка мочи"],
    "ишхан": ["севанская форель"],
    "ишь": ["вишь", "ишь ты"],
    "ишь ты": ["смотреть", "вот ещё", "ну да", "как же", "как бы не так", "надо же"],
    "ища": ["ищущи"],
    "ищах": ["охота", "ненаситност", "жажда", "щение", "желание"],
    "ищец": ["проситель", "молител", "тъжител"],
    "ищи дурака": ["разбежаться", "раскатать губу"],
    "июнь": ["червень"],
    "иярчен": ["юлдаш"],
    "йаа": ["йай"],
    "йавлух": ["йавлук", "йавлукъ", "йавлыкъ"],
    "йагъмур": ["йамгъур"],
    "йазык": ["йазых"],
    "йазых": ["йазык", "гюнях"],
    "йай": ["йаа", "йайа"],
    "йайа": ["йай"],
    "йаксы": ["йакшы"],
    "йамгъур": ["йагъмур", "йангъур"],
    "йангъур": ["йамгъур"],
    "йангъый": ["йангъай"],
    "йангъыл": ["йаныл"],
    "йаныл": ["йангъыл"],
    "йапрак": ["йапрах"],
    "йараткан": ["йаратхан"],
    "йаратхан": ["йараткан"],
    "йаратылмах": ["йаратылмак"],
    "йарылгъа": ["йарылкъа"],
    "йарылкъа": ["йарылгъа"],
    "йарым": ["йары"],
    "йасах": ["йасак"],
    "йасот": ["йашот"],
    "йашот": ["йасот"],
    "йезид": ["езид"],
    "йезидизм": ["езидизм"],
    "йемен": ["йеменская республика"],
    "йера": ["йеро", "йер"],
    "йеро": ["йера"],
    "йети": ["снежный человек", "бигфут", "сасквоч", "йетти"],
    "йибермек": ["ёлламакъ"],
    "йив": ["ив", "эв"],
    "йигирми": ["эгирми"],
    "йигит": ["игит"],
    "йилигиц": ["илигиц", "йулуч"],
    "йима": ["яма", "йама"],
    "йип": ["ип"],
    "йит": ["ит"],
    "йифф": ["йифф-арт", "секс"],
    "йихбаскин": ["йэхбашкюнь"],
    "йо-йо": ["чёртик на ниточке"],
    "йог": ["философ", "отшельник"],
    "йога-мудра": ["поза йоги"],
    "йога-терапия": ["йоготерапия", "йогатерапия"],
    "йогатерапия": ["йога-терапия", "йоготерапия"],
    "йогачар": ["виджнянавад", "виджнянавадин"],
    "йогачара": ["виджнянавада", "читтаматра", "виджняптиматра"],
    "йоготерапия": ["йога-терапия"],
    "йогурт": ["катык", "югурт", "ягурт"],
    "йогуртный": ["йогуртовый"],
    "йогуртовый": ["йогуртный"],
    "йод": ["иод", "йодная настойка", "раствор люголя"],
    "йодаргирит": ["йодит", "йодирит"],
    "йодат": ["иодат"],
    "йодид": ["иодид", "гидроиодид", "гидройодид", "иодид-ион", "йодид-ион", "иодид-анион", "йодид-анион"],
    "йодировав": ["йодировавши"],
    "йодировавши": ["йодировав"],
    "йодирование": ["иодирование"],
    "йодированный": ["иодированный"],
    "йодировать": ["иодировать"],
    "йодистый": ["иодистый", "иодид", "йодид"],
    "йодлив": ["йодливши"],
    "йодливши": ["йодлив"],
    "йодлировав": ["йодлировавши"],
    "йодлировавши": ["йодлировав"],
    "йодлировать": ["йодлить"],
    "йодлить": ["йодлировать"],
    "йодный": ["иодный"],
    "йодобромистый": ["йодобромный"],
    "йодобромный": ["йодобромистый"],
    "йодолипол": ["липиодол"],
    "йодометрия": ["иодометрия"],
    "йодоформ": ["иодоформ", "трииодметан"],
    "йозак": ["бик"],
    "йолгъуш": ["йолугъуш"],
    "йолдас": ["йолдаш"],
    "йолдаш": ["йолдас"],
    "йолдуз": ["йулдуз"],
    "йолдызча": ["йолдызчык"],
    "йолдызчык": ["йолдызча"],
    "йолоп": ["дурень", "бевзь", "бевзень", "бовдур"],
    "йомен": ["йоменри"],
    "йоркшир": ["йоркшир-терьер", "йорк"],
    "йотация": ["йотирование"],
    "йотировав": ["йотировавши"],
    "йотировавши": ["йотировав"],
    "йотирование": ["йотация"],
    "йотированный": ["йотованный"],
    "йотованный": ["йотированный"],
    "йоу": ["привет"],
    "йох": ["йок"],
    "йоханнесбург": ["йобург", "йози", "еголи"],
    "йохлух": ["йоклук"],
    "йошкар-ола": ["царевококшайск", "краснококшайск", "йошка"],
    "йти": ["ходити"],
    "йукламах": ["йуку"],
    "йулуч": ["йулгъуч"],
    "йумус": ["йумуш"],
    "йуойэ": ["кукул", "элиэдулбэн"],
    "йыла": ["ила"],
    "йымшах": ["имшах"],
    "йырак": ["йырах"],
    "йырактан": ["йырахтан"],
    "йырах": ["йырак"],
    "йырахтан": ["йырактан"],
    "йэги": ["йэди"],
    "йэдинчи": ["йэдиньци"],
    "йэдиньци": ["йэдинчи"],
    "йэл": ["йэль"],
    "йэль": ["рузгяр"],
    "йэнгиль": ["йэнгил"],
    "йэреньчи": ["йэринчи"],
    "йэхбашкюнь": ["йихбаскин"],
    "к ебене матери": ["прочь", "к чёрту", "к чёрту на рога", "к чертям", "ко всем чертям", "к чертям собачьим", "к чёртовой матери", "к чёртовой бабушке", "к дьяволу", "к дьяволу на рога", "к едрене фене", "к ебене матери в пизду", "к ебеней матери", "к ебёной матери", "кем"],
    "к ебеней матери": ["прочь", "к чёрту", "к чёрту на рога", "к чертям", "ко всем чертям", "к чертям собачьим", "к чёртовой матери", "к чёртовой бабушке", "к дьяволу", "к дьяволу на рога", "к едрене фене", "к ебене матери", "к ебене матери в пизду", "к ебёной матери", "к ебеням"],
    "к ебеням": ["прочь", "к чёрту", "к дьяволу", "к ебене матери", "к ебеней матери", "к хуям", "к хуям собачьим", "в пизду"],
    "к слову": ["кстати", "между прочим"],
    "к сожалению": ["увы", "жаль", "к сожаленью", "к прискорбию", "к несчастью"],
    "к спеху": ["срочно", "спешно"],
    "к тому же": ["кроме того", "вдобавок"],
    "к херам собачьим": ["к чертям собачьим", "к чёрту", "к чёртовой бабушке", "к чёртовой матери", "ко всем чертям", "к хуям собачьим"],
    "к хуям": ["к хуям собачьим"],
    "к хуям собачьим": ["к хуям"],
    "к чертям собачьим": ["к чёрту", "к чёртовой бабушке", "к чёртовой матери", "ко всем чертям", "к херам собачьим", "к хуям собачьим"],
    "к чёртовой бабушке": ["к чёртовой матери", "на хуй"],
    "к чёртовой матери": ["к чёрту", "к чёртовой бабушке", "ко всем чертям", "к дьяволу"],
    "к чёрту": ["ко всем чертям", "к дьяволу", "к чёртовой бабушке", "к чёртовой матери"],
    "к шапочному разбору": ["к разъезду карет"],
    "к-": ["в-", "на-"],
    "ка": ["космический аппарат"],
    "кабак": ["шинок", "корчма", "кружало", "царское кружало", "бедлам", "бардак"],
    "кабалив": ["кабаливши"],
    "кабаливши": ["кабалив"],
    "кабалистика": ["каббалистика"],
    "кабалистический": ["каббалистический"],
    "кабальеро": ["рыцарь", "дворянин", "господин"],
    "кабан": ["вепрь", "секач"],
    "кабанець": ["кабанчик"],
    "кабанячий": ["вепровий"],
    "кабарга": ["сибирская кабарга"],
    "кабарговый": ["кабарожий", "кабаржиный"],
    "кабардино-балкарская республика": ["кбр", "кабардино-балкария"],
    "кабардино-черкесский язык": ["кабардино-черкесский"],
    "кабардинский конь": ["кабардинец"],
    "кабаре": ["кабачок", "ресторанчик", "кафе-шантан", "варьете"],
    "кабаржиный": ["кабарговый", "кабарожий"],
    "кабаркагаз": ["гезит"],
    "кабарожий": ["кабарговый", "кабаржиный"],
    "кабатчик": ["корчмарь", "трактирщик", "целовальник"],
    "каббала": ["каббалистика"],
    "каббалистика": ["колдовство", "оккультизм", "каббала", "кабалистика"],
    "кабелеукладач": ["жильникокладач"],
    "кабель": ["провод", "шнур", "кабельное телевидение"],
    "кабельный": ["проводной"],
    "кабельтовый": ["кабельтов"],
    "каберлек": ["зират", "каберстан", "мазар"],
    "каберстан": ["каберлек", "зират"],
    "кабета": ["жанчына"],
    "кабздун": ["кобздун", "кобздон", "кабздон"],
    "кабина": ["будка", "будочка", "телефонная кабина", "душевая кабина", "кабина лифта"],
    "кабинет": ["отдельный кабинет", "правительство", "совет министров"],
    "кабинет министров": ["кабмин"],
    "кабинетно-бумажный": ["кабинетно-канцелярский"],
    "кабинетно-канцелярский": ["кабинетно-бумажный"],
    "каблук": ["каблучок", "котомка", "пирожковоз", "пирожок", "шиньон", "удар каблуком", "подкаблучник"],
    "кабо-верде": ["республика кабо-верде", "республика острова зелёного мыса"],
    "кабовердианец": ["кабовердец", "кабовердиец"],
    "каботажничав": ["каботажничавши"],
    "каботажничавши": ["каботажничав"],
    "каботажничать": ["каботажить"],
    "каботен": ["актёр-каботен", "каботинец", "комедиант", "лицедей", "скоморох"],
    "каботин": ["каботен", "каботэн"],
    "кабриолет": ["кабрик"],
    "кабриолетка": ["кабриолет"],
    "кабрировав": ["кабрировавши"],
    "кабрировавши": ["кабрировав"],
    "кабувердьяну": ["кабовердийский"],
    "кабургъа": ["къабургъа"],
    "кабы": ["если бы", "ежели бы", "когда бы"],
    "кабысдох": ["шавка", "кляча"],
    "кабэ": ["кб"],
    "кава": ["гематон"],
    "кавай": ["прелесть", "умиление"],
    "кавайно": ["мило", "трогательно"],
    "кавайный": ["милый"],
    "кавалер": ["ухажёр", "поклонник", "бойфренд", "партнёр"],
    "кавалергардия": ["кавалергардский", "полк"],
    "кавалерист": ["конник"],
    "кавалеристка": ["наездница"],
    "кавалерия": ["конница", "кавалерист"],
    "кавалерственная лента": ["кавалерия"],
    "кавалерша": ["награжденная"],
    "кавалок": ["шматок"],
    "кавальер": ["бартизана"],
    "кавалькада": ["кортеж", "процессия", "эскорт", "шествие", "сопровождение", "конвой", "поезд"],
    "кавардак": ["беспорядок", "неразбериха", "куурдак"],
    "кавардачок": ["куурдак"],
    "кавер": ["кавер-версия", "перепевка"],
    "кавер-версия": ["кавер", "перепевка"],
    "каверзив": ["каверзивши"],
    "каверзивши": ["каверзив"],
    "каверзничав": ["каверзничавши"],
    "каверзничавши": ["каверзничав"],
    "каверзно": ["коварно"],
    "каверзность": ["заковыристость", "коварность"],
    "каверзный вопрос": ["вопрос на засыпку", "вопрос с подковыркой"],
    "кавернома": ["кавернозная гемангиома"],
    "каверномер": ["нутромер", "профилограф"],
    "каветто": ["выкружка"],
    "кавиар": ["кавияр", "кавьяр"],
    "кавинтон": ["винпоцетин"],
    "кавкав": ["кавкавши"],
    "кавкавши": ["кавкав"],
    "кавказец": ["кавказская овчарка"],
    "кавказиология": ["кавказоведение"],
    "кавказоведение": ["кавказиология"],
    "кавомолка": ["кавничка", "кавниця"],
    "кавр": ["каурус", "корус"],
    "кавторанг": ["капитан второго ранга", "капдва", "кап-два", "кадваранг"],
    "кавун": ["каун", "арбуз"],
    "кавчати": ["кавкати"],
    "кавыка": ["кратка", "краткая", "завитушка", "каракуля"],
    "кавычив": ["кавычивши"],
    "кавычивши": ["кавычив"],
    "кавычить": ["закавычивать"],
    "кавычка": ["вносной знак", "кавыка", "ковыка", "ковычка", "кратка", "бревис", "бреве", "дуга"],
    "кавычный": ["корректурный"],
    "каган": ["хан"],
    "каганер": ["серун"],
    "каганец": ["коптилка"],
    "каганець": ["жмурка", "мигунець", "блимавка"],
    "кагат": ["бурт"],
    "кагатировав": ["кагатировавши"],
    "кагатировавши": ["кагатировав"],
    "кагатирование": ["буртование"],
    "кагатировать": ["буртовать"],
    "кагатный": ["буртовой"],
    "кагебешник": ["кагебист", "гэбист"],
    "кагуан": ["шерстокрыл"],
    "кагэбист": ["гэбист", "кагэбэшник", "гэбнюк"],
    "кагэбистский": ["кагэбэшный"],
    "кагэбэшник": ["кагэбист", "чекист", "комитетчик"],
    "кадавр": ["труп", "мертвец", "покойник", "зомби"],
    "каданс": ["каденция"],
    "кадансировав": ["кадансировавши"],
    "кадансировавши": ["кадансировав"],
    "кадастр": ["писцовая книга"],
    "каддим": ["кадим"],
    "каденция": ["каданс"],
    "кадерле": ["газиз"],
    "кадетка": ["ученица", "воспитанница", "партийка"],
    "кадив": ["кадивши"],
    "кадивши": ["кадив"],
    "кадий": ["кади", "кази"],
    "кадик": ["адамове яблуко", "борлак"],
    "кадикс": ["кадис"],
    "кадило": ["кадильница", "кадильник"],
    "кадим": ["каддим"],
    "кадис": ["кадикс", "гадир", "гадер", "гадира", "гадейра", "гадес"],
    "кадка": ["кадь"],
    "кадр": ["план", "снимок", "монтажный кадр", "сцена", "кадра"],
    "кадра": ["кадр", "кадры", "костяк", "шваль", "шантропа", "шушера", "сволочь", "сброд", "отребье", "шлюха", "проститутка", "кыдра"],
    "кадрив": ["кадривши"],
    "кадривши": ["кадрив"],
    "кадриль": ["контрданс"],
    "кадрировав": ["кадрировавши"],
    "кадрировавши": ["кадрировав"],
    "кадрить": ["флиртовать", "заигрывать", "клеить"],
    "кадровик": ["контрактник", "эйчар", "херменеджер", "рекрутер"],
    "кадры": ["персонал", "штат", "отдел кадров"],
    "кадуцей": ["керикион"],
    "кадърност": ["способност"],
    "кадык": ["адамово яблоко"],
    "кадыкёй": ["халкидон"],
    "кадым": ["кадим"],
    "кадь": ["кадка", "оков"],
    "кажденье": ["каждение"],
    "каждогодний": ["ежегодный", "каждогодный"],
    "каждодневно": ["ежедневно", "повседневно", "буднично", "обыденно"],
    "каждодневный": ["ежедневный", "постоянный", "повседневный"],
    "каждой бочке затычка": ["в каждой бочке затычка"],
    "каждомесячно": ["ежемесячно"],
    "каждомесячный": ["ежемесячный"],
    "каждоминутный": ["ежеминутный"],
    "каждому встречному и поперечному": ["каждая собака"],
    "каждонедельный": ["еженедельный"],
    "каждосекундно": ["ежесекундно"],
    "каждосекундный": ["ежесекундный"],
    "каждый": ["всякий", "любой"],
    "каждый кулик на своём хую велик": ["всяк кулик на своей кочке велик", "всяк кулик в своём болоте велик"],
    "каждый раз": ["ежежды", "всегда", "неизменно"],
    "кажется": ["как будто", "по-видимому", "по-моему", "кажись", "имхо", "вроде бы"],
    "кажимость": ["видимость", "мнимость"],
    "кажинный": ["каженный"],
    "кажись": ["кажется"],
    "казав": ["казавши"],
    "казавши": ["казав"],
    "казак": ["козак"],
    "казаковав": ["казаковавши"],
    "казаковавши": ["казаковав"],
    "казаковать": ["казачествовать"],
    "казакстан": ["казахстан", "республика казахстан"],
    "казанки": ["казанские сани", "татарские сани"],
    "казанова": ["донжуан"],
    "казань": ["третья столица", "третий город"],
    "казарменно": ["по-казарменному"],
    "казарменный": ["грубый", "пошлый", "примитивный", "неприличный", "непристойный", "для курящих", "сортирный"],
    "казаться": ["выглядеть", "производить впечатление", "сдаваться", "представляться", "думаться", "чудиться", "мерещиться"],
    "казах": ["новая акстафа"],
    "казахская сср": ["казахстан"],
    "казахско-американский": ["казахстанско-американский"],
    "казахско-китайский": ["казахстано-китайский", "казахстанско-китайский"],
    "казахско-российский": ["казахстанско-российский"],
    "казахстан": ["республика казахстан", "казакстан"],
    "казахстано-китайский": ["казахско-китайский", "казахстанско-китайский"],
    "казахстано-российский": ["казахско-российский", "казахстанско-российский", "российско-казахский", "российско-казахстанский"],
    "казахстанский": ["казахский"],
    "казахстанско-американский": ["казахско-американский"],
    "казахстанско-китайский": ["казахско-китайский", "казахстано-китайский"],
    "казахстанско-российский": ["казахско-российский"],
    "казачествовав": ["казачествовавши"],
    "казачествовавши": ["казачествовав"],
    "казачив": ["казачивши"],
    "казачивши": ["казачив"],
    "казачий": ["казацкий"],
    "казачья лопань": ["лопань"],
    "казвам": ["река"],
    "каздимли": ["касдимли"],
    "каземат": ["казематированные помещения", "одиночка", "тюрьма"],
    "казематировав": ["казематировавши"],
    "казематировавши": ["казематировав"],
    "каземир": ["казимир"],
    "кази-кумух": ["казикумух"],
    "казикумух": ["кази-кумух"],
    "казикумык": ["казикумыкец"],
    "казикумыкец": ["казикумык"],
    "казимир": ["каземир"],
    "казинет": ["казенет"],
    "казино": ["игорный дом"],
    "казна": ["фиск", "сокровищница"],
    "казначей": ["кассир", "скарбник", "подскарбий"],
    "казначейша": ["казначея"],
    "казначея": ["казначейша"],
    "казнив": ["казнивши"],
    "казнивши": ["казнив"],
    "казнить": ["истязать", "порицать"],
    "казниться": ["терзаться", "раскаиваться", "страдать", "мучиться"],
    "казнокрад": ["растратчик", "расхититель"],
    "казнохранилище": ["сокровищница"],
    "казнь": ["высшая мера", "высшая мера наказания", "исключительная мера наказания", "смертная казнь", "вышка", "возмездие", "кара", "мучение", "страдание"],
    "казуальний": ["випадковий", "случайний", "нечаянний"],
    "казуальный": ["случайный"],
    "казуист": ["софист"],
    "казуистика": ["игра слов", "софистика", "крючкотворство"],
    "казула": ["орнат"],
    "казус": ["происшествие", "приключение"],
    "казюля": ["гадюка"],
    "казённая часть": ["казённик"],
    "казённик": ["казённая часть"],
    "казённо-официальный": ["чиновнический", "казённый", "официальный"],
    "казённый": ["государственный"],
    "каистр": ["карасу"],
    "каиш": ["ремък"],
    "каишка": ["ремък", "каиш", "ивица", "лента"],
    "кайбер": ["беркайсы"],
    "кайдан": ["каян"],
    "кайдання": ["кайдани"],
    "кайзерский": ["кайзеровский"],
    "кайла": ["кайло"],
    "кайлив": ["кайливши"],
    "кайливши": ["кайлив"],
    "кайло": ["кирка", "кайла"],
    "кайма": ["окаёмка", "окаймление"],
    "каймах": ["каймак"],
    "каймив": ["каймивши"],
    "каймивши": ["каймив"],
    "кайна": ["акайна", "блад"],
    "кайнарджа": ["кючук-кайнарджи"],
    "кайнозой": ["кайнозойская эра", "кайнозойская группа"],
    "кайнозойская эра": ["кайнозой"],
    "кайпиринья": ["кайпериньо"],
    "кайсит": ["кайсики"],
    "кайсия": ["зарзала"],
    "кайсяку": ["кайсякунин"],
    "кайсякунин": ["кайсяку"],
    "кайтер": ["кайтрайдер", "кайтсёрфингист"],
    "кайтинг": ["кайтбординг", "кайтсёрфинг"],
    "кайтсёрфинг": ["кайтбординг", "кайтинг"],
    "кайтсёрфингист": ["кайтер", "кайтрайдер"],
    "кайф": ["эйфория", "кейф", "кеф", "благодать", "удовольствие", "наслаждение", "удовлетворение", "блаженство"],
    "кайфанув": ["кайфанувши"],
    "кайфанувши": ["кайфанув"],
    "кайфный": ["кайфовый"],
    "кайфовав": ["кайфовавши"],
    "кайфовавши": ["кайфовав"],
    "кайфовальщик": ["кайфовщик"],
    "кайфовать": ["блаженствовать", "балдеть", "наслаждаться"],
    "кайфово": ["кайфно", "кайфезно"],
    "кайфовщик": ["кайфовальщик"],
    "кайфовый": ["кайфный"],
    "кайфолов": ["гедонист", "жизнелюб", "сибарит", "кайфист", "кайфовщик", "полуторчок", "наркоман", "нарик", "наркоша", "наркобес", "наркопет", "наркопед", "нар", "торчок", "торчубес"],
    "кайфолом": ["кайфоломщик", "кайфоломище"],
    "кайфоломщик": ["кайфолом"],
    "кайфувати": ["кейфувати"],
    "кайфусафо": ["кайф"],
    "кайфушный": ["кайфовый", "клёвый"],
    "кайыс": ["кайыш"],
    "как": ["каким образом", "насколько", "сколь", "когда", "с тех пор как", "до чего же"],
    "как белка в колесе": ["как уж на сковородке"],
    "как будто": ["словно", "будто", "точно", "вроде", "якобы"],
    "как будто в воду глядеть": ["как в воду глядеть", "будто в воду глядеть", "как в воду смотреть", "будто в воду смотреть"],
    "как бы не так": ["вот ещё"],
    "как бы то ни было": ["во всяком случае", "как то ни есть"],
    "как в воду кануть": ["как сквозь землю провалиться"],
    "как в воду смотреть": ["как в воду глядеть", "будто в воду глядеть", "как будто в воду глядеть", "будто в воду смотреть", "как будто в воду смотреть"],
    "как водится": ["как обычно", "как всегда"],
    "как воды в рот набрать": ["помалкивать в тряпочку", "проглотить язык", "молчать как рыба", "держать язык за зубами", "держать язык на привязи", "играть в молчанку"],
    "как говно в проруби": ["неприкаянно", "как цветок в проруби", "неуместно"],
    "как говорят": ["ходят слухи", "поговаривать"],
    "как гром среди ясного неба": ["как снег на голову"],
    "как губернска верста": ["верзила", "каланча", "детина", "дылда", "жердяй", "дядя стёпа", "коломенская верста", "верста коломенская"],
    "как два байта переслать": ["как два пальца об асфальт", "как два пальца обоссать"],
    "как два пальца об асфальт": ["как нечего делать", "раз плюнуть", "проще пареной репы", "как дважды два", "как два пальца обоссать", "что два пальца обоссать", "как два байта переслать"],
    "как две капли воды": ["неотличимо"],
    "как до луны": ["как до луны пешком", "как до квазара пешком"],
    "как зюзя": ["в зюзю"],
    "как и": ["также"],
    "как из говна пуля": ["как из доярки балерина", "как из меня балерина", "как из зайца машинист", "как из лягушки прокурор", "как из пингвина сокол", "как танк из запорожца", "как из ваты хрен", "как из ваты хер", "как из ваты хуй"],
    "как из пизды на лыжах": ["внезапно"],
    "как из-под земли": ["из ниоткуда"],
    "как ключевая вода": ["семимильными шагами"],
    "как кошка с собакой": ["как собаки"],
    "как курица лапой": ["небрежно", "неряшливо", "нечётко", "неясно", "неразборчиво", "коряво", "кое-как", "как попало", "как ни попадя", "как сорока набродила", "словно куры набродили"],
    "как маков цвет": ["краснощёкий", "румяный", "розовощёкий", "покрасневший"],
    "как миленький": ["беспрекословно", "беспрепятственно"],
    "как мёртвому припарки": ["как собаке пятая нога", "как телеге пятое колесо"],
    "как на собаке": ["само собой"],
    "как не бывало": ["как ни в чём не бывало", "ничуть не бывало"],
    "как не хуй делать": ["просто", "как нечего делать", "раз плюнуть", "проще пареной репы", "как дважды два", "как два пальца об асфальт", "как два байта переслать", "как два пальца обоссать", "что два пальца обоссать", "не хуй делать", "за не хуй делать"],
    "как ни верти": ["всё-таки", "как-никак"],
    "как ни крути": ["хочешь не хочешь", "в любом случае"],
    "как ни странно": ["удивительно", "необъяснимо", "странно"],
    "как облупленного": ["детально", "хорошо"],
    "как пить дать": ["наверняка", "как выпить дать"],
    "как по маслу": ["без сучка без задоринки", "гладко"],
    "как по мне": ["по мне"],
    "как подкошенный": ["со всех ног"],
    "как правило": ["обычно"],
    "как проклятый": ["без продыху", "окаянный", "заколдованный"],
    "как пчела": ["засучив рукава"],
    "как раз": ["впору", "в самый раз", "точно", "в точности", "аккурат", "словно влитой", "тютелька в тютельку"],
    "как ребёнок": ["как маленькие дети", "как дети малые"],
    "как рыба в воде": ["как сыр в масле"],
    "как сажа бела": ["ещё не родила", "голова пока цела"],
    "как скажете": ["как хотите", "без разницы", "безразлично"],
    "как сквозь землю провалиться": ["пропасть", "сгинуть", "раствориться", "испариться"],
    "как снег на голову": ["неожиданно", "внезапно", "откуда ни возьмись", "как гром среди ясного неба"],
    "как собаке пятая нога": ["как телеге пятое колесо", "не пришей кобыле хвост", "не пришей к спине рукав", "не пришей к пизде рукав"],
    "как собаки": ["как кошка с собакой"],
    "как сыр в масле": ["как у христа за пазухой"],
    "как то": ["так то", "а именно"],
    "как то ни есть": ["как бы то ни было"],
    "как только": ["лишь", "лишь только", "едва", "едва только", "только"],
    "как у христа за пазухой": ["как сыр в масле кататься", "как сыр в масле"],
    "как хуй с плеч упал": ["как гора с плеч свалилась"],
    "как черепаха": ["в час по чайной ложке"],
    "как чёрт из табакерки": ["неожиданно", "внезапно"],
    "как электровеник": ["как угорелый", "как оглашенный", "как заведённый"],
    "как-либо": ["как-нибудь"],
    "как-нибудь": ["как-либо", "кое-как", "небрежно", "когда-нибудь"],
    "как-никак": ["всё-таки", "в конце концов", "как бы то ни было", "несмотря ни на что"],
    "как-то": ["каким-то образом", "несколько", "довольно", "когда-то", "однажды", "как-то раз", "как", "как же"],
    "как-то раз": ["однажды"],
    "кака": ["испражнение", "кал", "аа", "какашка", "дрянь", "гадость", "бяка", "задница"],
    "какав": ["какавши"],
    "какавши": ["какав"],
    "какание": ["каканье"],
    "каканье": ["какание"],
    "какао": ["шоколадник", "какао-бобы", "какао-порошок", "какава", "горячий шоколад"],
    "какао-масло": ["масло какао"],
    "какаовый": ["шоколадный"],
    "какапо": ["совиный попугай"],
    "какать": ["срать"],
    "какашка": ["дерьмо", "говно", "кака", "какишон", "кал"],
    "какая": ["испражняясь"],
    "какая жалость": ["вот жалость"],
    "какбычегоневышлизм": ["кабычегоневышлизм"],
    "какбычегоневышлист": ["кабычегоневышлист"],
    "какел": ["украинец", "малоросс", "малороссиянин", "хохол"],
    "каким образом": ["как"],
    "какистократический": ["какократический"],
    "какистократия": ["какократия"],
    "какнасчётизм": ["вотэбаутизм"],
    "каков": ["какой"],
    "какого хуя": ["что", "хуй ли", "хули", "хуле", "хуля", "хуль"],
    "какого чёрта": ["что", "чего", "хуй ли", "хули", "хуле", "хуля", "хуль", "чепуха", "вздор"],
    "какография": ["корректура"],
    "какой-либо": ["какой-нибудь", "какой-то"],
    "какой-нибудь": ["какой-то", "какой-либо"],
    "какой-то": ["некий", "неопределённый", "словно"],
    "какократический": ["какистократический"],
    "какофонический": ["негармонический", "неблагозвучный"],
    "какофония": ["шум", "гам", "гул", "грохот", "неблагозвучие", "дисгармония", "диссонанс"],
    "кактусист": ["кактусовод"],
    "кактусовод": ["кактусист"],
    "какуминальный": ["церебральный"],
    "какуська": ["какашка"],
    "кал": ["испражнения", "стул", "фекалии", "экскременты"],
    "калабалък": ["тълпа", "множество", "многолюдие", "навалица", "орталък"],
    "калабаня": ["калюжа", "баюра"],
    "калак": ["кашык"],
    "каламар": ["чорнильниця"],
    "каламбурец": ["каламбур"],
    "каламбурив": ["каламбуривши"],
    "каламбуривши": ["каламбурив"],
    "каламбурист": ["игрослов", "каламбурщик"],
    "каламбуристка": ["шутница"],
    "каламбурщик": ["каламбурист"],
    "каламитет": ["напаст", "бедствие"],
    "каламондин": ["цитрофортунелла"],
    "каламуття": ["каламуть"],
    "каламуть": ["каламуття"],
    "каламянка": ["коломянка"],
    "каламянковый": ["коломянковый"],
    "калан": ["морская выдра", "камчатский бобр"],
    "каландать": ["греметь"],
    "каландра": ["джурбай"],
    "каландрировав": ["каландрировавши"],
    "каландрировавши": ["каландрировав"],
    "каландрировать": ["каландровать", "плющить", "лощить", "гладить"],
    "каландровав": ["каландровавши"],
    "каландровавши": ["каландровав"],
    "каландрование": ["каландрирование"],
    "каландровка": ["аппретирование", "каландрирование"],
    "каланча": ["башня"],
    "калар": ["чина"],
    "калатало": ["калаталка"],
    "калач": ["крендель", "колач"],
    "калачня": ["калачная"],
    "калачом не заманишь": ["ни за что"],
    "калаш": ["калашник", "калашников", "ак"],
    "калаша": ["калаш"],
    "калашник": ["калачник"],
    "калашников": ["калаш", "калашник"],
    "калб": ["саг"],
    "калбит": ["кельбит", "чучмек", "чурка", "узкоглазый"],
    "калевав": ["калевавши"],
    "калевавши": ["калевав"],
    "калейдоскоп": ["круговерть", "кругозор"],
    "калейдоскопический": ["калейдоскопичный"],
    "калека": ["увечный", "инвалид", "калика", "калика перехожий", "калека перехожий"],
    "калемсап": ["жазгын"],
    "календарь": ["календарик", "график", "расписание"],
    "календула": ["ноготки", "ноготок"],
    "каление": ["жаренье", "закаливание", "накаливание", "паление", "припекание", "прокаливание"],
    "каленье": ["каление"],
    "калеченье": ["калечение"],
    "калечив": ["калечивши"],
    "калечивши": ["калечив"],
    "калечить": ["увечить", "портить", "ломать"],
    "калечный": ["рашпильный", "ущербный", "недоделанный", "вторичный"],
    "кали": ["дурга", "парвати", "ума"],
    "кали-юга": ["калиюга"],
    "калибер": ["колибер", "калиберки"],
    "калибр": ["калибер", "значимость", "масштаб", "величина", "талант"],
    "калибрировав": ["калибрировавши"],
    "калибрировавши": ["калибрировав"],
    "калибровав": ["калибровавши"],
    "калибровавши": ["калибровав"],
    "калибровка": ["калибрование", "градуировка"],
    "калиброметр": ["калибровка"],
    "калив": ["каливши"],
    "каливши": ["калив"],
    "калиевый": ["калийный"],
    "калиесодержащий": ["калийсодержащий"],
    "калий": ["кали"],
    "калийсодержащий": ["калиесодержащий"],
    "калик": ["кальян", "парилка"],
    "калика": ["калика перехожий", "калека перехожий"],
    "каликат": ["каликут", "кожикоде"],
    "каликстинец": ["чашник"],
    "каликут": ["каликат", "кожикоде"],
    "калима": ["сухан", "гап", "вожа"],
    "калимантан": ["борнео"],
    "калимантанский": ["борнейский"],
    "калина": ["калинка"],
    "калинджи": ["сейдана"],
    "калининград": ["кёнигсберг"],
    "калиофилит": ["калиофиллит"],
    "калиперометр": ["калипер"],
    "калиптра": ["гиматий", "пеплос"],
    "калисфен": ["каллисфен"],
    "калита": ["мошна", "кошель", "сума", "кишень", "зепь"],
    "калитка": ["блок"],
    "калить": ["накаливать", "накалять", "палить", "жечь", "закаливать", "закалять", "злить", "бесить", "выбешивать"],
    "калиф на час": ["временщик", "свадебный боярин", "свадебный генерал"],
    "каличный": ["ущербный", "калечный"],
    "каллиграфия": ["чистописание"],
    "каллисфен": ["калисфен"],
    "каллозный": ["каллёзный"],
    "каллус": ["каллюс"],
    "каллюс": ["каллус"],
    "калмыкия": ["республика калмыкия"],
    "калмыцкий": ["калмыцкий язык"],
    "калмыцкий язык": ["калмыцкий"],
    "каломниатор": ["клеветник"],
    "каломния": ["клевета"],
    "калон": ["бузург"],
    "калоризация": ["калорическая проба"],
    "калорийность": ["энергетическая ценность", "питательность"],
    "калорифер": ["нагреватель", "канальный нагреватель"],
    "калорический": ["температурный", "тепловой"],
    "калотипия": ["талботипия"],
    "калофония": ["сладкогласие", "ангелогласие", "прекраснозвучие"],
    "калоша": ["галоша"],
    "калугер": ["монах"],
    "калугерка": ["монахиня"],
    "калуж": ["бара"],
    "калужанин": ["калужец"],
    "калуфер": ["кануфер", "канупер", "пижма бальзамическая"],
    "калъп": ["форма", "фасон"],
    "калъф": ["обвивка", "футляр"],
    "калъч": ["меч", "ятаган", "сабя", "кинжал", "калъчка"],
    "калывав": ["калывавши"],
    "калывавши": ["калывав"],
    "калым": ["вено", "махр", "ирад", "мелче", "могори"],
    "калымив": ["калымивши"],
    "калымивши": ["калымив"],
    "калымщик": ["шабашник"],
    "кальвинистический": ["кальвинистский"],
    "кальвинистский": ["кальвинистический"],
    "кальдяв": ["кържа", "аф", "сатомшка"],
    "калькаринный": ["стриарный"],
    "калькировав": ["калькировавши"],
    "калькировавши": ["калькировав"],
    "калькулировав": ["калькулировавши"],
    "калькулировавши": ["калькулировав"],
    "калькулировать": ["подсчитывать", "исчислять"],
    "калькулятор": ["микрокалькулятор", "счётная машинка", "эквм"],
    "калькулёз": ["камнеобразование", "литиаз"],
    "калькутта": ["колката"],
    "калькуттец": ["колкатец"],
    "калькуттский": ["колкатский"],
    "кальпа": ["калпа", "день брахмы"],
    "кальсоны": ["подштанники", "исподники"],
    "кальцеолярия": ["башмачки"],
    "кальцинат": ["петрификат"],
    "кальцинация": ["обжиг", "кальцинирование"],
    "кальцинировав": ["кальцинировавши"],
    "кальцинировавши": ["кальцинировав"],
    "кальцинированная сода": ["карбонат натрия"],
    "кальцинированный": ["обожжённый"],
    "кальцинировать": ["обжигать", "выжигать"],
    "кальциноз": ["кальцификация"],
    "кальцит": ["известковый шпат"],
    "кальцитонин": ["тиреокальцитонин"],
    "кальцификация": ["кальциноз", "обызвествление"],
    "кальян": ["наргиле"],
    "кальянив": ["кальянивши"],
    "кальянивши": ["кальянив"],
    "калюка": ["колюка"],
    "каляка": ["мазня", "рисунок", "каляка-маляка", "малява"],
    "каляка-маляка": ["мазня", "рисунок", "каляка", "малява"],
    "калякав": ["калякавши"],
    "калякавши": ["калякав"],
    "калякать": ["балакать", "малевать", "мазать", "кропать", "корябать"],
    "калям": ["калам"],
    "калёвка": ["калёвочник"],
    "кама": ["толокно"],
    "камаз": ["каммаз"],
    "камазист": ["челнинец"],
    "камарина": ["халдеополь"],
    "камаринская": ["комаринская"],
    "камас": ["камус"],
    "камбала": ["морская камбала"],
    "камбоджа": ["королевство камбоджа", "кхмерская республика", "кампучия", "демократическая кампучия", "народная республика кампучия", "нрк", "государство камбоджа"],
    "камбоджиец": ["кампучиец"],
    "камбоджийка": ["кампучийка"],
    "камбоджийский": ["кампучийский"],
    "камвхора": ["камхора"],
    "камедетечение": ["гуммоз", "гоммоз"],
    "камедь": ["гумми", "смола", "живица"],
    "каменар": ["зидар", "каменоделец"],
    "каменев": ["каменевши"],
    "каменевши": ["каменев"],
    "каменеть": ["окаменевать", "замирать", "застывать", "цепенеть", "ожесточаться"],
    "каменная соль": ["галит"],
    "каменно-набросный": ["камненабросный"],
    "каменный лук": ["черемша", "каменный чеснок"],
    "каменный чеснок": ["черемша", "каменный лук"],
    "каменолом": ["камнелом"],
    "каменотёс": ["камнетёс"],
    "каменское": ["днепродзержинск"],
    "каменщик": ["зидарь"],
    "камень": ["горная порода", "камык", "кама", "булыжник", "драгоценный камень", "отложение", "налёт", "конкремент", "процессор", "цп", "проц", "кристалл", "кремень", "мозг"],
    "камень плодородия": ["апатит"],
    "камень преткновения": ["камень претыки"],
    "камень претыки": ["камень преткновения"],
    "камень-на-оби": ["камень"],
    "камео": ["роль-камео"],
    "камера": ["темница"],
    "камералив": ["камераливши"],
    "камераливши": ["камералив"],
    "камералистика": ["камеральные науки"],
    "камеральничав": ["камеральничавши"],
    "камеральничавши": ["камеральничав"],
    "камеральничать": ["камералить"],
    "камергер": ["шамбелян"],
    "камериора": ["горничная", "камеристка"],
    "камеристка": ["служанка", "горничная", "камердинер"],
    "камерун": ["республика камерун"],
    "камешек": ["камушек"],
    "камея": ["камей"],
    "камил": ["камиль"],
    "камиль": ["камил"],
    "камин": ["каминчик"],
    "каминг-аут": ["выход из шкафа"],
    "каминный": ["печной"],
    "камка": ["дамаст", "камчатка"],
    "камлав": ["камлавши"],
    "камлавши": ["камлав"],
    "камлать": ["шаманить"],
    "каммаз": ["камаз"],
    "камнелом": ["каменолом"],
    "камнеломка": ["разрыв-трава"],
    "камнемётный": ["камнеметательный"],
    "камнеподборщик": ["камнеуборщик"],
    "камнетёс": ["каменотёс"],
    "камнеуборщик": ["камнеподборщик"],
    "камон": ["давай", "пойти", "да ладно", "перестать"],
    "камора": ["зарядник", "патронник"],
    "каморка": ["комната", "чулан", "подсобка"],
    "кампир": ["пиразан"],
    "кампус": ["городок"],
    "кампучийский": ["камбоджийский"],
    "кампучия": ["демократическая кампучия", "народная республика кампучия", "нрк"],
    "камрад": ["товарищ"],
    "камрип": ["экранка"],
    "камса": ["европейский анчоус", "хамса"],
    "камуфлировав": ["камуфлировавши"],
    "камуфлировавши": ["камуфлировав"],
    "камуфляж": ["деформирующая окраска", "маскировка", "камуфло", "мимикрия"],
    "камушек": ["камень", "камешек"],
    "камфара": ["камфора"],
    "камфора": ["камфара"],
    "камфорний": ["камфоровий"],
    "камчатка": ["галёрка", "камчатник", "камчадал", "двоечник", "второгодник", "хулиган", "шпана", "медвежий угол", "глушь", "глухомань", "даль", "далеко", "далёко"],
    "камчатник": ["камчадал"],
    "камчатский край": ["камчатка"],
    "камчуг": ["подагра"],
    "камчужная трава": ["мать-и-мачеха", "белокопытник"],
    "камшик": ["бич", "нагайка"],
    "камъш": ["тръстика"],
    "камыш": ["рогоз"],
    "камышевка": ["камышовка"],
    "камышница": ["камышовая курочка", "водяная курочка", "болотная курочка"],
    "канава": ["арык", "кювет", "ров", "канал"],
    "канавши": ["канав"],
    "канада": ["канадская конфедерация", "страна кленового листа"],
    "канадец": ["канадон", "канадос", "канадосец"],
    "канадо-американский": ["канадско-американский"],
    "канадо-советский": ["канадско-советский"],
    "канадон": ["канадос", "канадосец"],
    "канадос": ["канадон", "канадосец"],
    "канадосец": ["канадон", "канадос"],
    "канадский хоккей": ["хоккей с шайбой", "хоккей"],
    "канадско-американский": ["канадо-американский"],
    "канадско-российский": ["российско-канадский"],
    "канадско-советский": ["канадо-советский"],
    "канал": ["труба", "пролив", "путь", "средство", "тракт", "бин", "ячейка"],
    "канализационный": ["очистной", "сточный"],
    "канализировав": ["канализировавши"],
    "канализировавши": ["канализировав"],
    "канализирование": ["водоотведение"],
    "канализовав": ["канализовавши"],
    "канализовавши": ["канализовав"],
    "каналья": ["мошенник", "плут", "бестия", "пройдоха", "негодяй", "хитрец"],
    "кананерка": ["кананерская лодка", "канлодка"],
    "канапе": ["канапе-ли", "канапка", "диванчик"],
    "канарец": ["гуанч", "канарий", "канарский дог", "преса канарио"],
    "канарские острова": ["канары"],
    "канат": ["трос", "вата", "беруши", "корпия"],
    "канатка": ["канатная дорога"],
    "канатная дорога": ["канатка"],
    "канатний": ["линвовий", "кодоловий"],
    "канатник": ["абутилон"],
    "канать": ["идти", "проваливать", "валить"],
    "канаус": ["шёлк"],
    "кандалы": ["оковы", "цепи", "наручники", "колодка"],
    "кандальная": ["кандальная тюрьма", "кандальное отделение"],
    "кандальник": ["заключённый", "арестант", "невольник"],
    "кандела": ["свеча"],
    "канделябр": ["канделябра"],
    "канделябра": ["канделябр"],
    "кандидамикоз": ["кандидоз", "молочница"],
    "кандидоз": ["кандидамикоз", "микоз", "дрожжевой", "монилиаз", "оидиомикоз"],
    "кандиль": ["кандиль-синап", "канделябр"],
    "кандёр": ["полевая каша"],
    "канефора": ["кошеносица", "корзиноносица"],
    "канецъ": ["канцы"],
    "канив": ["канивши"],
    "канивши": ["канив"],
    "каниз": ["канизак"],
    "канизак": ["каниз"],
    "каникулы": ["вакация"],
    "канителив": ["канителивши"],
    "канителивши": ["канителив"],
    "канителиться": ["медлить"],
    "канитель": ["возня", "бодяга"],
    "канительщик": ["волокитчик", "волынщик", "копотун", "копун", "копуша", "резинщик", "шишига", "проволакиватель", "проволочитель", "кунктатор"],
    "канить": ["канючить", "дрейфить"],
    "канифолив": ["канифоливши"],
    "канифоливши": ["канифолив"],
    "канифолить": ["наканифоливать"],
    "канканировав": ["канканировавши"],
    "канканировавши": ["канканировав"],
    "канлъи": ["гвангъи"],
    "каннабис": ["дурь", "трава", "конопля"],
    "каннара": ["каннада", "каннадига"],
    "каннелировав": ["каннелировавши"],
    "каннелировавши": ["каннелировав"],
    "каннелюра": ["канелюра"],
    "каннибал": ["людоед", "антропофаг"],
    "каннибализм": ["каннибальство", "людоедство", "зверство", "варварство", "самопожирание"],
    "каннибальский": ["людоедский"],
    "каннибальство": ["каннибализм", "людоедство", "кровожадность", "бесчеловечность"],
    "канны": ["канн", "кан"],
    "канолевый": ["новёхонький", "нулёвый", "нулячий", "нульцовый", "муха не сидела", "муха не какала", "муха не еблась"],
    "каномка": ["канома"],
    "канон": ["монохорд", "канун"],
    "канонерка": ["канонерская лодка"],
    "канонерская лодка": ["канонерка"],
    "канонизация": ["причисление к лику святых", "причисление к сонму святых"],
    "канонизировав": ["канонизировавши"],
    "канонизировавши": ["канонизировав"],
    "канонизировать": ["канонизовать"],
    "канонизовав": ["канонизовавши"],
    "канонизовавши": ["канонизовав"],
    "канонизовать": ["канонизировать"],
    "каноникализация": ["канонизация"],
    "канонир": ["пушкарь"],
    "канонирский": ["пушкарский"],
    "канонично": ["канонно"],
    "каноэ": ["пирога"],
    "кансона": ["канцона"],
    "кантар": ["кантарь"],
    "кантарь": ["кантар", "контарь", "безмен", "контырь"],
    "кантик": ["кант"],
    "кантилевер": ["кораблик климкина"],
    "кантина": ["бар", "кабачок", "подвальчик", "погребок", "таверна"],
    "кантовав": ["кантовавши"],
    "кантовавши": ["кантовав"],
    "кантовский": ["кантианский"],
    "кантон": ["гуанчжоу"],
    "кантонский": ["гуанчжоуский"],
    "кантюжник": ["коробейник", "офеня"],
    "канув": ["канувши"],
    "канувши": ["канув"],
    "канун": ["канунник", "канон"],
    "канунник": ["канун"],
    "кануть": ["капнуть", "погрузиться", "минуть", "пропасть", "исчезнуть"],
    "кануть в лету": ["почить в бозе"],
    "канфар": ["кандаеос"],
    "канфарение": ["чеканка"],
    "канфарив": ["канфаривши"],
    "канфаривши": ["канфарив"],
    "канцелярия": ["бюро", "контора", "офис"],
    "канцелярская крыса": ["промокашка", "офисный планктон"],
    "канцелярский": ["офисный"],
    "канцелярщина": ["бюрократия", "бюрократизм"],
    "канцер": ["рак"],
    "канцерогенез": ["онкогенез", "бластомогенез"],
    "канцерогенность": ["онкогенность"],
    "канцерогенный": ["онкогенный"],
    "канцерофобия": ["карцинофобия", "онкофобия"],
    "канцлер": ["печатник"],
    "канцона": ["кансона"],
    "канцтовары": ["товар", "скрепки"],
    "канчебас": ["кончебас"],
    "канчили": ["азиатский", "оленёк"],
    "кань": ["кась"],
    "каньон": ["овраг"],
    "канюк": ["мышелов", "сарыч"],
    "канючив": ["канючивши"],
    "канючивши": ["канючив"],
    "канючить": ["ныть", "нудить", "выпрашивать"],
    "каон": ["к-мезон"],
    "кап": ["болона"],
    "капав": ["капавши"],
    "капавши": ["капав"],
    "капает с конца": ["с хуёчка капает"],
    "капампанганский": ["пампангский"],
    "капан": ["кафан"],
    "капать": ["идти", "жаловаться", "нажаловаться", "наушничать", "ябедничать", "фискалить", "кляузничать", "доносить", "стучать", "заявлять", "сигнализировать"],
    "капать на мозги": ["долбить", "нудеть", "трындеть", "гнуть свою линию", "проедать плешь"],
    "капдва": ["капитан второго ранга", "кап-два", "кадваранг", "кавторанг"],
    "капе": ["кп"],
    "капелировав": ["капелировавши"],
    "капелировавши": ["капелировав"],
    "капеллировав": ["капеллировавши"],
    "капеллировавши": ["капеллировав"],
    "капельдинер": ["билетёр"],
    "капельку": ["каплю", "крошечку", "крошку", "маленько", "малость", "немножко", "несколько", "слегка", "чуток", "чуточку", "чуть", "чуть-чуть", "крохотку"],
    "капельмейстерский": ["дирижёрский"],
    "капельница": ["пипетка"],
    "капелюха": ["капелюх", "ушанка", "малахай"],
    "капелюшковий": ["капелюшний"],
    "капелюшний": ["капелюшковий"],
    "капер": ["флибустьер", "пират", "приватир"],
    "каперанг": ["капитан первого ранга", "капраз", "кап-раз"],
    "каперский": ["каперный"],
    "каперствовав": ["каперствовавши"],
    "каперствовавши": ["каперствовав"],
    "капетинг": ["капетинец"],
    "капибара": ["водосвинка"],
    "капитал": ["актив", "богатство", "ценность"],
    "капитализация": ["капитал"],
    "капитализировав": ["капитализировавши"],
    "капитализировавши": ["капитализировав"],
    "капитализм": ["свободное предпринимательство", "частное предпринимательство"],
    "капиталист": ["буржуа", "запад"],
    "капиталистически": ["по-капиталистически"],
    "капиталка": ["капремонт"],
    "капиталовложение": ["инвестиция"],
    "капиталоотдача": ["фондоотдача"],
    "капиталосберегающий": ["капиталоэффективный"],
    "капитальный": ["значительный", "существенный", "кардинальный", "определяющий", "основополагающий", "конститутивный", "ценный", "дорогостоящий", "неоценимый", "ростральный"],
    "капитальный ремонт": ["капремонт"],
    "капитан": ["шкипер"],
    "капитан второго ранга": ["кавторанг", "капдва"],
    "капитан очевидность": ["кэп", "ко", "копетан очевидность"],
    "капитан первого ранга": ["каперанг", "капраз"],
    "капитан третьего ранга": ["каптри", "гидромайор"],
    "капитан-командор": ["капитан бригадирского ранга"],
    "капитан-лейтенант": ["каплей"],
    "капитанив": ["капитанивши"],
    "капитанивши": ["капитанив"],
    "капитанить": ["капитанствовать"],
    "капитания": ["капитанство"],
    "капитанствовав": ["капитанствовавши"],
    "капитанствовавши": ["капитанствовав"],
    "капитанствовать": ["капитанить"],
    "капитонировав": ["капитонировавши"],
    "капитонировавши": ["капитонировав"],
    "капитошка": ["капитоха"],
    "капитулировав": ["капитулировавши"],
    "капитулировавши": ["капитулировав"],
    "капитулировать": ["сдаться"],
    "капитуляция": ["сдача"],
    "капкан": ["западня"],
    "капкаптун": ["кавкаптун"],
    "каплевидный": ["каплеобразный", "каплеподобный"],
    "каплеобразный": ["каплевидный", "каплеподобный"],
    "каплеподобный": ["каплевидный", "каплеобразный"],
    "капли датского короля": ["грудной эликсир", "эликсир грудной короля датского"],
    "каплив": ["капливши"],
    "капливши": ["каплив"],
    "капловухий": ["клаповухий"],
    "каплюшка": ["капелька"],
    "капля камень точит": ["вода камень точит"],
    "капнув": ["капнувши"],
    "капнувши": ["капнув"],
    "капнуть": ["наябедничать", "настучать", "пожаловаться"],
    "капоид": ["бушмен"],
    "капоидный": ["койсанский", "койсаноидный", "бушменский"],
    "капор": ["чепчик", "чепец"],
    "капость": ["пакость", "гадость"],
    "капотаж": ["капот", "капотирование"],
    "капотировав": ["капотировавши"],
    "капотировавши": ["капотировав"],
    "капоэйра": ["капуэйра"],
    "капп": ["кап", "кап-кап"],
    "каппа": ["каппах"],
    "каппа-метр": ["каппаметр"],
    "каппадокиец": ["мосх"],
    "каппаметр": ["каппа-метр"],
    "каппах": ["каппа"],
    "капраз": ["каперанг", "капитан первого ранга", "кап-раз"],
    "капральный": ["капральский"],
    "капремонт": ["капитальный ремонт", "капиталка"],
    "каприз": ["упрямство", "причуда", "прихоть"],
    "капризив": ["капризивши"],
    "капризивши": ["капризив"],
    "капризник": ["капризун", "капризуля", "капризка"],
    "капризничав": ["капризничавши"],
    "капризничавши": ["капризничав"],
    "капризничать": ["привередничать", "капризить", "блажить", "упрямиться", "своенравничать"],
    "капризный": ["своенравный", "своевольный", "избалованный"],
    "капризун": ["капризник"],
    "каприновая кислота": ["декановая кислота"],
    "каприфоль": ["жимолость каприфоль", "жимолость козья"],
    "каприфолька": ["каприфоль"],
    "каприччио": ["каприс"],
    "капрон": ["перлон", "поликапролактам"],
    "капроновая кислота": ["гексановая кислота", "изобутило-уксусная кислота"],
    "капстад": ["кейптаун", "капштадт", "капштат"],
    "капстроительство": ["капстрой"],
    "капстрой": ["капстроительство"],
    "капсулировав": ["капсулировавши"],
    "капсулировавши": ["капсулировав"],
    "капсулотомия": ["артротомия"],
    "капсуль": ["капсюль", "пистон", "капсула"],
    "капсульная коллекция": ["капсула"],
    "капсюль": ["капсуль", "пистон"],
    "каптан": ["каптана"],
    "каптировав": ["каптировавши"],
    "каптировавши": ["каптировав"],
    "каптирование": ["каптаж"],
    "каптировать": ["канализировать", "канализовать"],
    "каптур": ["чапец", "капар"],
    "каптча": ["капча"],
    "каптёр": ["каптёрщик"],
    "каптёрщик": ["каптёр"],
    "капуль": ["капульчик"],
    "капуста": ["капустка", "капустища", "кочанная капуста"],
    "капустка": ["капуста"],
    "капустняк": ["капустница", "капустянка"],
    "капустянка": ["ведмедик"],
    "капутджух": ["капыджик"],
    "капшак": ["копшак", "копшук", "копчак", "черноглазка"],
    "капштадт": ["кейптаун", "капстад", "капштат"],
    "капштат": ["кейптаун", "капстад"],
    "капывав": ["капывавши"],
    "капывавши": ["капывав"],
    "кара": ["возмездие"],
    "карабельня": ["верф", "суднаверф"],
    "карабин": ["обрез"],
    "карабинер": ["карабен"],
    "карабкаться": ["вскарабкиваться"],
    "карабожа": ["коробожа"],
    "карабулак": ["орстхоец"],
    "карабулах": ["карабулак"],
    "карав": ["каравши"],
    "каравас": ["караваш"],
    "караваш": ["каравас"],
    "каравши": ["карав"],
    "карагас": ["тофалар"],
    "караемость": ["наказуемость"],
    "караиб": ["кариб"],
    "каракалпакский язык": ["каракалпакский"],
    "каракалпакстан": ["республика каракалпакстан"],
    "каракиргиз": ["киргиз", "кара-киргиз"],
    "караковый": ["каракулый"],
    "караконджул": ["караконджол", "караконджал"],
    "каракуль": ["астрахан"],
    "каракурт": ["вдова степная", "степной паук"],
    "карамбола": ["тропическая звезда", "звёздный фрукт", "звезда-фрукт", "старфрут"],
    "карамболировать": ["карамболить", "безобразничать", "шутить"],
    "карамболь": ["крамболь", "столкновение", "шум", "кутеж"],
    "карамелевий": ["карамельний"],
    "карамелизировав": ["карамелизировавши"],
    "карамелизировавши": ["карамелизировав"],
    "карамелизовав": ["карамелизовавши"],
    "карамелизовавши": ["карамелизовав"],
    "карамелизовать": ["карамелизировать"],
    "карамелька": ["люся", "люся-карамелька", "люська-карамелька", "люсьен"],
    "карамельний": ["карамелевий"],
    "карамоджонг": ["карамоджо"],
    "карамора": ["долгоножка"],
    "карамс": ["сюволямс", "карсемс", "шувомс", "пялемс"],
    "карамультук": ["мультук", "пищаль"],
    "карангъылык": ["каранъгъылых"],
    "карандас": ["карандаш"],
    "карандаш": ["аловак"],
    "карание": ["кара", "наказание"],
    "караница": ["кавга", "крамола", "разпри", "раздор", "разправия", "спор"],
    "караннык": ["каралык"],
    "карантикулы": ["путинские каникулы"],
    "карантинобесие": ["ковидобесие", "коронабесие", "коронаистерия", "коронапаника", "коронапсихоз"],
    "карапет": ["шкет"],
    "карапетина": ["малыш", "коротыш"],
    "карапуз": ["малыш", "спиногрыз"],
    "карарга": ["багарга"],
    "карасий": ["карасёвый", "карасиный"],
    "карасиный": ["карасёвый", "карасий"],
    "карасёвый": ["карасий", "карасиный"],
    "каратеист": ["каратист", "каратека", "каратек", "каратешник"],
    "каратек": ["каратист", "каратеист", "каратешник"],
    "каратека": ["каратист", "каратеист", "каратешник"],
    "карательный": ["репрессивный", "усмирительный", "пенальный", "экзекуционный"],
    "каратешник": ["каратист", "каратеист", "каратека", "каратек"],
    "каратешный": ["каратистский"],
    "каратист": ["каратеист", "каратека", "каратек", "каратешник"],
    "карать": ["наказывать"],
    "каратэист": ["каратист"],
    "каратэт": ["карат эт"],
    "караулив": ["карауливши"],
    "карауливши": ["караулив"],
    "караулить": ["охранять", "стеречь", "сторожить", "поджидать", "подстерегать", "подкарауливать", "стоять на часах"],
    "караулка": ["караульня"],
    "караульная": ["караулка", "караульня"],
    "караульня": ["караульная", "караулка"],
    "карафа": ["карафка", "графин"],
    "карафка": ["карафа"],
    "карафуто": ["южный сахалин", "сахалин"],
    "карафутский": ["сахалинский", "южно-сахалинский"],
    "карачаево-балкарский": ["карачаевский", "балкарский"],
    "карачаево-черкесская республика": ["карачаево-черкесия", "кчр"],
    "карачки": ["четвереньки"],
    "карающий": ["наказывающий", "мстящий"],
    "карбамид": ["мочевина"],
    "карбамоилгидразин": ["семикарбазид"],
    "карбач": ["кнут", "плеть", "процент", "доход"],
    "карбений": ["карбений-ион"],
    "карбкатион": ["карбокатион"],
    "карбованец": ["рубль", "купон", "купоно-карбованец", "хохлобакс"],
    "карбоксил": ["карбоксильная группа"],
    "карбоксилировав": ["карбоксилировавши"],
    "карбоксилировавши": ["карбоксилировав"],
    "карболит": ["бакелит"],
    "карболовая кислота": ["фенол", "карболка"],
    "карбон": ["углепластик", "углеволокно", "углеткань", "каменноугольная система", "каменноугольный период", "углерод"],
    "карбонар": ["карбонарий"],
    "карбонари": ["карбонарий"],
    "карбонаризм": ["карбонарство"],
    "карбонарий": ["карбонар"],
    "карбонарство": ["карбонаризм"],
    "карбонат": ["углекислая соль"],
    "карбонат бария": ["витерит"],
    "карбонатизовав": ["карбонатизовавши"],
    "карбонатизовавши": ["карбонатизовав"],
    "карбонизировав": ["карбонизировавши"],
    "карбонизировавши": ["карбонизировав"],
    "карборунд": ["карбид кремния"],
    "карботермия": ["углетермия"],
    "карбункул": ["анфракс"],
    "карбюрировав": ["карбюрировавши"],
    "карбюрировавши": ["карбюрировав"],
    "карвы": ["карвинг"],
    "карга": ["гарпия", "ведьма", "яга", "кикимора", "хага"],
    "каргала": ["каргалы"],
    "каргъыш": ["къаргъыш"],
    "каргыш": ["наалат"],
    "кардамон": ["кардамом"],
    "кардан": ["карданный вал", "двойная педаль"],
    "карданный": ["рельсовый"],
    "карданный вал": ["кардан"],
    "кардашьян": ["кардашян"],
    "кардашян": ["кардашьян"],
    "кардиальный": ["сердечный"],
    "кардинал": ["кардинальное число"],
    "кардинал-пресвитер": ["кардинал-священник"],
    "кардинально": ["полностью", "радикально"],
    "кардинальный": ["главнейший"],
    "кардио": ["кардиотренировка"],
    "кардиотренировка": ["кардио"],
    "кардний": ["кардовий"],
    "кардовав": ["кардовавши"],
    "кардовавши": ["кардовав"],
    "кардование": ["кардочесание"],
    "кардовий": ["кардний"],
    "кардовщик": ["суконник", "суконщик", "чесальщик", "пастух"],
    "каре": ["карре"],
    "карелия": ["республика карелия"],
    "карен": ["кареанг"],
    "карет": ["знак вставки", "символ вставки"],
    "карета": ["колымага", "рыдван"],
    "карета скорой помощи": ["автомобиль скорой помощи", "реанимобиль", "эмбюленс", "неотложка"],
    "карзубый": ["беззубый", "щербатый", "шепелявый"],
    "кариб": ["караиб"],
    "карибский": ["караибский"],
    "карибское море": ["караибское море"],
    "карибу": ["северный олень"],
    "карибы": ["антильские острова", "карибские острова", "караибы", "караибские острова", "вест-индия"],
    "кариес": ["костоеда"],
    "карий": ["коричневый", "тёмно-коричневый", "тёмно-гнедой", "смуглый"],
    "карийон": ["карильон"],
    "карикатура": ["пасквиль", "пародия"],
    "карикатурив": ["карикатуривши"],
    "карикатуривши": ["карикатурив"],
    "карикатурно": ["гротескно", "пародийно"],
    "карильон": ["карийон"],
    "кариокинез": ["митоз"],
    "кариолемма": ["кариотека", "нуклеолемма"],
    "кариосистематика": ["кариотаксономия"],
    "кариотека": ["нуклеолемма", "кариолемма"],
    "кариофиллоидный": ["диацитный"],
    "карите": ["ши"],
    "каритив": ["абессив"],
    "кария": ["гикори"],
    "каркав": ["каркавши"],
    "каркавши": ["каркав"],
    "каркадан": ["карк"],
    "каркание": ["карканье"],
    "карканье": ["каркание"],
    "каркнув": ["каркнувши"],
    "каркнувши": ["каркнув"],
    "карл": ["карлик"],
    "карла-марла": ["кырла-мырла"],
    "карлетонит": ["карлтонит"],
    "карлик": ["лилипут", "гном", "карл", "коротышка"],
    "карликовый шимпанзе": ["бонобо"],
    "карломарксовец": ["карлмарксовец"],
    "карлскруна": ["карлскрона"],
    "карлуха": ["мурамур"],
    "карма": ["немезида"],
    "кармазин": ["кармуазин"],
    "карман": ["зепь", "кишень", "буфер обмена", "клипборд", "сумка"],
    "кармания": ["карамания"],
    "карманная чахотка": ["безденежье", "ветер в кармане"],
    "карманник": ["вор-карманник", "карманный вор", "щипач", "карманщик"],
    "карманница": ["карманщица"],
    "карманный вор": ["карманник", "щипач"],
    "карманных дел мастер": ["карманник", "щипач"],
    "карманщик": ["карманник"],
    "карманщица": ["карманница"],
    "карминный": ["карминовый"],
    "кармливав": ["кармливавши"],
    "кармливавши": ["кармливав"],
    "карнабит": ["карфиол"],
    "карнавалив": ["карнаваливши"],
    "карнаваливши": ["карнавалив"],
    "карнавальность": ["яркость", "красочность"],
    "карнак": ["фивы"],
    "карнаубский воск": ["воск карнаубский", "бразильский воск", "пальмовый воск"],
    "карнач": ["начкар", "начальник караула"],
    "карнегия": ["сагуаро"],
    "карнеол": ["сердолик"],
    "карниз": ["козырёк"],
    "карнизний": ["карнизовий"],
    "карнитин-ацилтрансфераза": ["кат"],
    "карнозинсинтетаза": ["карнозинсинтаза"],
    "карок": ["карук"],
    "карп": ["карпий", "карпия"],
    "карпатская русь": ["карпатская украина", "карпатская рутения", "угорская русь"],
    "карпаты": ["сарматские горы"],
    "карпаф": ["карпатос"],
    "карпинск": ["богословский", "угольный"],
    "карпообразный": ["карпоподобный"],
    "карпоэкология": ["диаспорология"],
    "карпулинг": ["райдшеринг"],
    "карринг": ["каррирование"],
    "каррирование": ["карринг"],
    "карское море": ["новое северное море", "северное татарское море", "мангазейское море", "нярзомское море", "нарземское море", "тартарское море", "ледовитое море", "ледяное море"],
    "карст": ["галит", "корнелит"],
    "картавив": ["картавивши"],
    "картавивши": ["картавив"],
    "картавить": ["грассировать", "картать", "фальшивить", "фальшить", "кривить"],
    "картвелология": ["картвелистика", "грузиноведение"],
    "картезианский": ["декартовский", "декартов"],
    "картелировав": ["картелировавши"],
    "картелировавши": ["картелировав"],
    "картечница": ["митральеза"],
    "картечь": ["картеча"],
    "картина": ["полотно", "фильм", "кинофильм", "кинокартина", "лента", "кинолента", "вид", "пейзаж", "панорама", "зрелище", "образ", "состояние", "явление"],
    "картина малевича": ["чёрный экран", "негры уголь крадут"],
    "картина маслом": ["приплыли", "не ждали"],
    "картинг": ["картодром"],
    "картинка": ["картина", "рисунок", "иллюстрация", "изображение"],
    "картинная галерея": ["художественная галерея"],
    "картинно": ["эффектно"],
    "картировав": ["картировавши"],
    "картировавши": ["картировав"],
    "картирование": ["картографирование"],
    "картировать": ["картографировать"],
    "картли": ["карталиния"],
    "картлык": ["картлых"],
    "картограмма": ["картодиаграмма"],
    "картографировав": ["картографировавши"],
    "картографировавши": ["картографировав"],
    "картографирование": ["картирование"],
    "картографировать": ["картировать"],
    "картопля": ["бараболя"],
    "картопляник": ["зразы"],
    "картофан": ["картошка"],
    "картофелекопалка": ["картофелекопатель"],
    "картофелекопатель": ["картофелекопалка"],
    "картофелесажатель": ["приспособление"],
    "картофелесортировальный": ["картофелесортировочный"],
    "картофелесортировочный": ["картофелесортировальный"],
    "картофелина": ["картошина"],
    "картофелинка": ["картофелька"],
    "картофель": ["паслён клубненосный", "картошка", "земляное яблоко", "картофелина", "картошина", "второй хлеб", "чёртово яблоко"],
    "картофельная жопа": ["картофельная душа", "картошечная душа"],
    "картофельное пюре": ["толчёнка"],
    "карточка": ["карта", "фотокарточка", "проездной билет", "проездной", "банковская карта"],
    "карточный": ["картёжный"],
    "картошина": ["картофелина"],
    "картошка": ["картофель", "картоха", "паслён клубненосный", "картошина", "картофелина", "колбаска"],
    "картуз": ["кепи", "кепка", "фуражка"],
    "картхолдер": ["картодержатель"],
    "карты": ["карточная игра"],
    "картёж": ["картёжничание"],
    "картёжничав": ["картёжничавши"],
    "картёжничавши": ["картёжничав"],
    "картёжный": ["карточный"],
    "карув": ["къарув"],
    "карув бер": ["къарув бэр"],
    "карук": ["карок"],
    "карусель": ["круговорот", "кутерьма", "круговерть", "кружляние", "мелькание", "суета", "круизное голосование"],
    "карусельный арест": ["карусель"],
    "карфица": ["топлийка"],
    "кархаринообразный": ["кархаридный"],
    "карцер": ["одиночка", "одиночная камера", "кондей"],
    "карциноид": ["аргентаффинома", "энтерохромаффинома"],
    "карша": ["коряга", "карча", "карч"],
    "каршеринг": ["автопрокат"],
    "карьерист": ["честолюбец"],
    "карьхкя пря": ["чакаряз"],
    "каряз": ["копорь"],
    "карячив": ["карячивши"],
    "карячивши": ["карячив"],
    "карёжив": ["карёживши"],
    "карёживши": ["карёжив"],
    "кас": ["каш"],
    "касаемо": ["касательно", "насчёт", "относительно", "что касается"],
    "касал": ["бемор"],
    "касание": ["прикосновение", "прикасание", "соприкосновение"],
    "касанье": ["касание"],
    "касапница": ["кланица", "скотобойна"],
    "касательно": ["относительно"],
    "касательность": ["касательство", "принадлежность", "обстоятельство", "тангенциальность"],
    "касатик": ["дорогой", "милый"],
    "касатка": ["ласточка", "косатка", "орка"],
    "касаться": ["дотрагиваться", "трогать", "соприкасаться", "контактировать", "задевать", "упоминать", "затрагивать", "относиться", "оскулировать"],
    "каска": ["шлем"],
    "каскадировав": ["каскадировавши"],
    "каскадировавши": ["каскадировав"],
    "каскан": ["мантоварка", "мантышница"],
    "каскет": ["кепе", "фуражка", "боне"],
    "каслание": ["перекочевывание", "кочевье", "кочевание"],
    "каспий": ["каспийское море"],
    "каспийское море": ["каспий", "хвалынское море", "хвалисское море", "хазарское море"],
    "касра": ["зер"],
    "кассабанана": ["сикана душистая"],
    "кассава": ["маниок съедобный", "маниока"],
    "кассационный": ["апелляционный"],
    "кассетная бомба": ["бомбовая кассета"],
    "кассетный скандал": ["кучмагейт"],
    "кассетофон": ["кассетный", "магнитофон", "кассетник"],
    "кассировав": ["кассировавши"],
    "кассировавши": ["кассировав"],
    "кассировать": ["уничтожать", "уничтожить", "ликвидировать", "расформировывать", "расформировать", "упразднять", "упразднить", "раскассировать"],
    "касситериды": ["британские острова"],
    "касситерит": ["оловянный камень"],
    "кассия": ["александрийский лист", "теджпатта"],
    "каста": ["варна"],
    "кастальский ключ": ["кастальский источник"],
    "кастив": ["кастивши"],
    "кастивши": ["кастив"],
    "кастилия": ["королевство кастилия"],
    "кастилия и леон": ["кастилия-леон", "кастильская корона"],
    "кастинг": ["проба"],
    "кастинговав": ["кастинговавши"],
    "кастинговавши": ["кастинговав"],
    "кастовав": ["кастовавши"],
    "кастовавши": ["кастовав"],
    "кастодиан": ["депозитарий", "кастоди"],
    "кастомизация": ["адаптация", "настройка"],
    "кастомизировав": ["кастомизировавши"],
    "кастомизировавши": ["кастомизировав"],
    "кастомизируемый": ["настраиваемый"],
    "кастомный": ["оригинальный", "выборочный"],
    "кастореум": ["бобровая струя"],
    "касторка": ["касторовое масло"],
    "касторовое масло": ["касторка"],
    "кастплей": ["косплей"],
    "кастрат": ["скопец"],
    "кастрация": ["кастрирование", "оскопление", "холощение"],
    "кастрировав": ["кастрировавши"],
    "кастрировавши": ["кастрировав"],
    "кастрировать": ["оскоплять", "оскопить", "стерилизовать"],
    "кастрюлеголовый": ["кастрюльня"],
    "касык": ["кашух"],
    "кат": ["палач", "экзекутор"],
    "кат-сцена": ["внутриигровое видео"],
    "ката": ["таолу"],
    "катав": ["катавши"],
    "катавасия": ["суматоха", "суета", "кавардак"],
    "катавей": ["вырез"],
    "катавши": ["катав"],
    "катаклизм": ["катаклизма", "катастрофа"],
    "катакомбний": ["катакомбовий"],
    "катакомбник": ["карловчанин"],
    "катакомбовий": ["катакомбний"],
    "каталанский": ["каталонский"],
    "каталепсический": ["каталептический"],
    "каталепсия": ["оцепенение", "столбняк"],
    "катализатор": ["ускоритель"],
    "катализировав": ["катализировавши"],
    "катализировавши": ["катализировав"],
    "катализировать": ["ускорять"],
    "катализовав": ["катализовавши"],
    "катализовавши": ["катализовав"],
    "каталка": ["кресло-каталка", "носилки", "каталочка"],
    "каталог": ["индекс", "указатель", "перечень", "список", "реестр", "предложение", "директория", "папка", "фолдер"],
    "каталогизация": ["таксонометрия"],
    "каталогизировав": ["каталогизировавши"],
    "каталогизировавши": ["каталогизировав"],
    "каталонизм": ["каталонский национализм", "каталонское национальное движение"],
    "каталония": ["автономное сообщество каталония", "каталонская республика", "республика каталония"],
    "каталонский": ["каталанский"],
    "катамаранив": ["катамаранивши"],
    "катамаранивши": ["катамаранив"],
    "катамит": ["пидор", "опущенный", "петух"],
    "катанец": ["катинар", "кофар"],
    "катание": ["езда"],
    "катанув": ["катанувши"],
    "катанувши": ["катанув"],
    "катапетасма": ["церковная завеса", "горние двери"],
    "катапульта": ["баллиста", "катапульт"],
    "катапультировав": ["катапультировавши"],
    "катапультировавши": ["катапультировав"],
    "катапультировать": ["катапультироваться"],
    "катар": ["государство катар", "катарский полуостров"],
    "катарама": ["тока", "закопчалка", "клипс", "брошка"],
    "катарсис": ["очищение"],
    "катархей": ["гадей", "хэдий", "азой", "преархей", "приской", "прискойский период"],
    "катастрофа": ["бедствие", "трагедия", "катаклизм", "крушение", "авиакатастрофа"],
    "катастрофизация": ["драматизация"],
    "катастрофизировав": ["катастрофизировавши"],
    "катастрофизировавши": ["катастрофизировав"],
    "катастрофический": ["бедственный", "катастрофичный"],
    "кататимность": ["аффектогенность"],
    "кататония": ["кататонический синдром"],
    "катать вату": ["страдать фигнёй", "тратить время"],
    "катафалк": ["рыдван", "ведро с болтами", "гроб на колёсах"],
    "катафора": ["антиципация", "антецедент"],
    "катафот": ["световозвращатель", "светоотражатель", "ретрорефлектор", "фликер"],
    "катахреза": ["катахрезис"],
    "категоризация": ["классификация"],
    "категоризировав": ["категоризировавши"],
    "категоризировавши": ["категоризировав"],
    "категоризовав": ["категоризовавши"],
    "категоризовавши": ["категоризовав"],
    "категорически": ["безапелляционно", "безусловно", "в категорической форме", "в ультимативной форме", "директивно", "императивно", "категорично", "решительно", "твёрдо", "незамедлительно"],
    "категорический": ["категоричный", "безапелляционный"],
    "категоричность": ["безапелляционность"],
    "категоричный": ["категорический", "безапелляционный"],
    "категория": ["понятие", "концепт", "класс", "группа", "сорт", "вид"],
    "категория состояния": ["безлично-предикативное слово", "предикативное наречие", "статив", "предикатив"],
    "катенька": ["сторублёвка"],
    "катер-тральщик": ["тральщик"],
    "катерина": ["екатерина", "катя"],
    "катеринка": ["екатеринка"],
    "катерна": ["кватерна"],
    "катетеризировав": ["катетеризировавши"],
    "катетеризировавши": ["катетеризировав"],
    "катетеризировать": ["катетеризовать"],
    "катетеризовав": ["катетеризовавши"],
    "катетеризовавши": ["катетеризовав"],
    "катетеризовать": ["катетеризировать"],
    "катехизация": ["воцерковление", "оглашение"],
    "катехизировав": ["катехизировавши"],
    "катехизировавши": ["катехизировав"],
    "катехизис": ["катихизис", "кодекс", "закон", "догмат"],
    "катеху": ["кашу"],
    "катехуменат": ["катехизация"],
    "кати ков": ["кати коза"],
    "кати коза": ["кати ков"],
    "кати-кодама": ["кодама-бъди"],
    "кати-мезе": ["мезе-бъди"],
    "катив": ["кативши"],
    "кативши": ["катив"],
    "катинар": ["кофар", "катанец"],
    "катион": ["положительный ион"],
    "катионировав": ["катионировавши"],
    "катионировавши": ["катионировав"],
    "катить бочку": ["бочку катить", "гнать бочку", "вариант", "бочку гнать", "наезжать", "бузить"],
    "катихизис": ["катехизис"],
    "катка": ["игра"],
    "катковав": ["катковавши"],
    "катковавши": ["катковав"],
    "каткы": ["каткызы"],
    "каткызы": ["каткы"],
    "катнув": ["катнувши"],
    "катнувши": ["катнув"],
    "катнуть": ["катануть"],
    "катны": ["каты"],
    "катовице": ["каттовиц", "сталиногруд"],
    "катойконим": ["демоним"],
    "католицизм": ["католичество"],
    "католический": ["папистский", "римско-католический"],
    "католичество": ["католицизм"],
    "катоптрический": ["зеркальный", "отражательный"],
    "каторга": ["каторжник", "каторжанин", "кобылка"],
    "каторжанин": ["каторжник"],
    "каторжанка": ["каторжница", "варначка"],
    "каторжник": ["каторжанин"],
    "каторжница": ["каторжанка", "варначка"],
    "катран": ["крамбе"],
    "каттрино": ["кваттрино"],
    "катун": ["зверун", "чукурун"],
    "катух": ["гайно", "баз", "гайнище", "ганьище", "гойно", "сарай", "котух"],
    "каты": ["къаты"],
    "катывав": ["катывавши"],
    "катывавши": ["катывав"],
    "катын": ["къатын"],
    "катыр": ["мул", "катер", "катырь", "лошак", "осляк"],
    "катышек": ["шарик", "комок"],
    "катюша": ["боевая машина реактивной артиллерии", "гвардейский реактивный миномёт", "раиса сергеевна"],
    "катях": ["какашка"],
    "кау": ["каубыд"],
    "каубой": ["говедарче"],
    "каудальный": ["задний", "хвостовой"],
    "каудекс": ["стеблекорень", "каудокс"],
    "каузальность": ["причинность"],
    "каузальный": ["причинный"],
    "каузатив": ["понудительный залог", "побудительный залог"],
    "каузативный": ["понудительный"],
    "каузатор": ["побудитель", "инициатор"],
    "каузация": ["порождение", "создание"],
    "каузировав": ["каузировавши"],
    "каузировавши": ["каузировав"],
    "каулифлория": ["стволоцветение"],
    "каупер": ["воздухонагреватель"],
    "каустик": ["каустическая сода"],
    "каустический": ["едкий", "жгучий"],
    "кафар": ["новоцианин", "новотианин", "альбигойец"],
    "кафе": ["кофейня", "кафешка", "кафетерий"],
    "кафе-шантан": ["ресторанчик", "кабачок"],
    "кафез": ["клетка"],
    "кафель": ["керамическая плитка", "изразец"],
    "кафельный": ["изразцовый"],
    "кафешка": ["закусочная"],
    "кафир": ["кяфир", "гяур"],
    "кафиристан": ["кафирстан"],
    "кафирстан": ["кафиристан"],
    "кафр": ["негр"],
    "кафушка": ["кафешка"],
    "кафшгар": ["искоф"],
    "кахексия": ["худосочие"],
    "кахи": ["гах"],
    "кахля": ["кахель"],
    "кахолонг": ["полуопал"],
    "кахраманмараш": ["мараш"],
    "кахун": ["эль-лахун", "иллахун", "лахун"],
    "кахыкав": ["кахыкавши"],
    "кахыкавши": ["кахыкав"],
    "кацавейка": ["куцавейка", "душегрея", "душегрейка"],
    "кацап": ["великоросс", "великорус", "североросс", "москаль", "козлобородый", "ватник", "лапотник"],
    "кацапеня": ["москаленя"],
    "кацапня": ["русский"],
    "кацапский": ["москальский"],
    "кацея": ["кация", "кацья"],
    "кацик": ["касик"],
    "кач": ["качни", "качай", "покачай", "культуризм", "бодибилдинг", "культурист", "бодибилдер", "качок"],
    "качав": ["качавши"],
    "качавши": ["качав"],
    "качавшийся": ["шатавшийся"],
    "качановий": ["качанний"],
    "качанье": ["качание"],
    "качать": ["загружать"],
    "качать железо": ["качаться"],
    "качаться": ["шататься", "качать железо"],
    "качачий": ["качиний"],
    "качели": ["качель"],
    "качель": ["качели", "голубель", "зыбель", "гугака", "гугала", "качуля", "гойдалка"],
    "качение": ["катание"],
    "качественный": ["высококачественный"],
    "качивав": ["качивавши"],
    "качивавши": ["качивав"],
    "качим": ["гипсолюбка", "гипсофила"],
    "качиний": ["качачий"],
    "качка": ["зыбка"],
    "качнув": ["качнувши"],
    "качнувши": ["качнув"],
    "качок": ["качание"],
    "качулка": ["гугла"],
    "каша": ["месиво", "жижа", "шмяка", "шуга", "беспорядок", "неразбериха", "путаница"],
    "кашаса": ["ром"],
    "кашаф": ["сангпушт"],
    "кашевар": ["повар"],
    "кашеварив": ["кашеваривши"],
    "кашеваривши": ["кашеварив"],
    "кашеварить": ["стряпать", "кухарничать", "кухарить"],
    "кашель": ["кашляние", "кашлянье"],
    "кашемир": ["пашмина"],
    "кашеобразный": ["пюреобразный"],
    "кашетирование": ["каширование"],
    "кашивав": ["кашивавши"],
    "кашивавши": ["кашивав"],
    "кашировав": ["кашировавши"],
    "кашировавши": ["кашировав"],
    "каширование": ["кашировка"],
    "кашировка": ["каширование"],
    "кашка": ["каша"],
    "кашкадарья": ["обихунда", "шиначасай", "майманакдарья"],
    "кашляв": ["кашлявши"],
    "кашлявши": ["кашляв"],
    "кашляние": ["кашлянье"],
    "кашлянув": ["кашлянувши"],
    "кашлянувши": ["кашлянув"],
    "кашмири": ["кашмирский язык"],
    "кашне": ["шарф"],
    "кашт": ["ровли", "дрэво", "верста"],
    "кашубский": ["поморанский", "кашубский язык"],
    "кашух": ["касык"],
    "кашык": ["калак"],
    "каэр": ["контрреволюционер", "контра", "контрик"],
    "каэтан": ["каетан", "кайетан"],
    "каюк": ["лодка"],
    "каюта": ["кубрик"],
    "каяв": ["каявши"],
    "каявши": ["каяв"],
    "каядыр": ["кайдадыр", "где-то"],
    "каять": ["порицать", "осуждать"],
    "каяться": ["раскаиваться", "виниться", "исповедоваться"],
    "кб": ["кабэ", "клеммный зажим", "клеммный соединитель", "терминальный блок"],
    "кбр": ["кабардино-балкария"],
    "ква-ква": ["ква"],
    "квадра-": ["тетра-"],
    "квадратец": ["квадратик"],
    "квадратив": ["квадративши"],
    "квадративши": ["квадратив"],
    "квадратический": ["квадратичный"],
    "квадратичный": ["квадратический"],
    "квадратноголовый": ["тупой", "туповатый", "тупоголовый", "недалёкий", "ограниченный"],
    "квадратура круга": ["неразрешимый", "не", "поддающийся", "разрешению", "несуществующий", "вечный двигатель"],
    "квадривиум": ["квадривий", "четверопутие"],
    "квадрика": ["многообразие"],
    "квадриллион": ["биллиард", "септиллион"],
    "квадрильон": ["квадриллион"],
    "квадриплегия": ["тетраплегия"],
    "квадрировав": ["квадрировавши"],
    "квадрировавши": ["квадрировав"],
    "квадро-": ["четырёх-", "четверо-"],
    "квадробика": ["квадробинг", "квд"],
    "квадробинг": ["квадробика"],
    "квадрокоптер": ["квадрик", "квадролёт", "тетракоптер", "дрон"],
    "квадроцикл": ["квадрик"],
    "квадтранс": ["квадранс", "кодрант"],
    "квазар": ["квазизвезда", "сверхзвезда"],
    "квази-": ["лже-", "псевдо-", "как бы", "как будто", "почти", "якобы", "словно"],
    "квазибаллистический": ["манёвренный"],
    "квазивалюта": ["квазиденьги"],
    "квазигеодезический": ["квази-геодезический"],
    "квазигосударство": ["псевдогосударство"],
    "квазиденьги": ["квазивалюта"],
    "квазизвезда": ["квазар"],
    "квазилинейный": ["псевдолинейный", "подобный"],
    "квазинаука": ["лженаука", "паранаука", "псевдонаука"],
    "квазинаучный": ["ненаучный", "лженаучный", "паранаучный", "псевдонаучный"],
    "квазинезависимый": ["псевдонезависимый"],
    "квазирелигия": ["парарелигия"],
    "квазисиноним": ["мнимый синоним", "частичный синоним"],
    "квазистабильный": ["квазиустойчивый", "метастабильный"],
    "квазисудебный": ["внесудебный"],
    "квазиучёный": ["псевдоучёный", "лжеучёный"],
    "квазичастица": ["боголон"],
    "квак": ["кваканье"],
    "квакав": ["квакавши"],
    "квакавши": ["квакав"],
    "квакание": ["кваканье", "квак", "вяканье"],
    "кваканье": ["квакание", "квак"],
    "кваква": ["лягушка"],
    "квакерка": ["квакерша"],
    "квакнув": ["квакнувши"],
    "квакнувши": ["квакнув"],
    "квакушка": ["скакушка", "поскакушка", "лягушка"],
    "квакша": ["древесница"],
    "квакша-кузнец": ["булавоногая квакша"],
    "квалитативный": ["качественный"],
    "квалифай": ["квалифаер"],
    "квалифицировав": ["квалифицировавши"],
    "квалифицировавши": ["квалифицировав"],
    "квалифицированная электронная подпись": ["кэп"],
    "квалифицированный": ["расценённый"],
    "квалифицированный инвестор": ["квал"],
    "квантизация": ["квантование", "дискретизация"],
    "квантиль": ["фрактиль"],
    "квантитативность": ["количественность"],
    "квантитативный": ["количественный"],
    "квантификатор": ["квантор"],
    "квантификация": ["квантифицирование"],
    "квантифицировав": ["квантифицировавши"],
    "квантифицировавши": ["квантифицировав"],
    "квантовав": ["квантовавши"],
    "квантовавши": ["квантовав"],
    "квантово-механический": ["квантовомеханический"],
    "квантовомеханический": ["квантово-механический"],
    "квапливий": ["сквапливий"],
    "квартал": ["район"],
    "квартерон": ["шалайка", "шакалайка", "шабака"],
    "квартет": ["четвёрка"],
    "квартиль": ["четверть"],
    "квартир": ["уьй"],
    "квартирант": ["жилец", "постоялец"],
    "квартирантка": ["сожительница", "нахлебница"],
    "квартирная плата": ["квартплата"],
    "квартировав": ["квартировавши"],
    "квартировавши": ["квартировав"],
    "квартиронаниматель": ["квартиросъёмщик"],
    "квартиросъёмщик": ["квартиронаниматель"],
    "квартирёнка": ["квартирёшка"],
    "квартовав": ["квартовавши"],
    "квартовавши": ["квартовав"],
    "квартплата": ["квартирная плата"],
    "кварц": ["кварцевый резонатор", "кварцевая лампа", "кварцевание"],
    "кварцевав": ["кварцевавши"],
    "кварцевавши": ["кварцевав"],
    "кварцитный": ["кварцитовый"],
    "квас": ["квасок", "квасочек", "окрошка"],
    "квасив": ["квасивши"],
    "квасивши": ["квасив"],
    "кваситься": ["горевать", "горюниться", "капризничать", "расстраиваться"],
    "квасной патриотизм": ["лапотный патриотизм", "казённый патриотизм", "лакейский патриотизм", "ура-патриотизм"],
    "квасовар": ["квасодел", "квасник"],
    "квасцевав": ["квасцевавши"],
    "квасцевавши": ["квасцевав"],
    "квасцовав": ["квасцовавши"],
    "квасцовавши": ["квасцовав"],
    "кваттуордециллион": ["кваттордециллион"],
    "квач": ["вантуз", "пинцет", "тампон", "помазок", "салочки", "пятнашки"],
    "квашение": ["квашенье"],
    "квашеный": ["кислый"],
    "квашенье": ["квашение"],
    "квд": ["кожвендиспансер", "лохматкин лазарет"],
    "квебекец": ["квебекуа"],
    "квебекуа": ["квебекец"],
    "квебехсенуф": ["кебехсенуф", "кебехсенеф"],
    "квебрахо": ["кебрачо"],
    "квелия": ["красноклювый ткач"],
    "квельпарт": ["чеджудо"],
    "кверив": ["кверивши"],
    "кверивши": ["кверив"],
    "кверулянт": ["жалобщик", "сутяжник"],
    "кверулянтство": ["сутяжничество"],
    "кверху": ["вверх", "ввысь", "наверх", "на гора", "наружу"],
    "кверцетин": ["кверцитин"],
    "квест": ["бродилка"],
    "кветочек": ["цветочек"],
    "квиз": ["викторина"],
    "квиллинг": ["бумагопластика", "квилинг", "бумагокручение"],
    "квинзи": ["жилище", "укрытие", "убежище"],
    "квинтал": ["центнер"],
    "квинтет": ["пятёрка"],
    "квинтиллион": ["квинтильон"],
    "квинтэссенция": ["эфир", "основа", "сущность", "суть", "воплощение"],
    "квипрокво": ["недоразумение", "путаница", "приключение", "происшествие"],
    "квир": ["гендерквир"],
    "квислинг": ["коллаборационист"],
    "квит": ["квиты", "в расчёте", "конец"],
    "квитанция": ["жировка", "подтверждение"],
    "квитировав": ["квитировавши"],
    "квитировавши": ["квитировав"],
    "квиток": ["квитанция", "билетик", "талончик"],
    "кводлибет": ["попурри"],
    "квок": ["колотушка", "клоктушка"],
    "квоктав": ["квоктавши"],
    "квоктавши": ["квоктав"],
    "квоктать": ["квохтать"],
    "квотерпайп": ["квотер"],
    "квотировав": ["квотировавши"],
    "квотировавши": ["квотировав"],
    "квохнув": ["квохнувши"],
    "квохнувши": ["квохнув"],
    "квохтав": ["квохтавши"],
    "квохтавши": ["квохтав"],
    "квохтанье": ["квохтание"],
    "квохтать": ["кудахтать", "квоктать", "клоктать", "клохтать", "квокать"],
    "квочив": ["квочивши"],
    "квочивши": ["квочив"],
    "квц": ["координационно-вычислительный", "центр"],
    "квёлость": ["вялость"],
    "квёлый": ["слабый", "хилый", "вялый"],
    "кг": ["килограмм"],
    "кгс": ["кг"],
    "кеб": ["кэб"],
    "кебаб": ["кабоб"],
    "кебехсенуф": ["квебехсенуф"],
    "кебрачо": ["квебрахо"],
    "кегль": ["кегель", "кегля"],
    "кед": ["кеда"],
    "кеда": ["кед"],
    "кедр": ["сосна сибирская кедровая", "сибирский кедр"],
    "кедрач": ["кедровник"],
    "кедрачив": ["кедрачивши"],
    "кедрачивши": ["кедрачив"],
    "кедровка": ["ореховка"],
    "кедровник": ["кедрач"],
    "кедь": ["киське", "кедня", "ваткафкст", "кяр"],
    "кездеме": ["мата"],
    "кейген": ["генератор", "ключ"],
    "кейл": ["браунколь", "брунколь", "грюнколь", "кале", "кудрявая капуста"],
    "кейлоггер": ["кейлогер"],
    "кейлогер": ["кейлоггер"],
    "кейлон": ["антикейлон"],
    "кейптаун": ["капстад", "капштадт", "капштат"],
    "кейс": ["дипломат", "портфель", "чемодан", "футляр"],
    "кейф": ["перекур", "кайф"],
    "кейфовав": ["кейфовавши"],
    "кейфовавши": ["кейфовав"],
    "кейфовать": ["кайфовать", "кейфствовать"],
    "кейфствовав": ["кейфствовавши"],
    "кейфствовавши": ["кейфствовав"],
    "кейфувати": ["кайфувати"],
    "кек": ["фильтровальный осадок", "фильтровальная лепёшка"],
    "кекав": ["кекавши"],
    "кекавши": ["кекав"],
    "кекать": ["икать", "вскрикивать"],
    "кеке": ["екатерина", "като"],
    "кеклик": ["каменная куропатка"],
    "кекнув": ["кекнувши"],
    "кекнувши": ["кекнув"],
    "кекнуть": ["икнуть"],
    "келагаи": ["кялагаи"],
    "келдырив": ["келдыривши"],
    "келдыривши": ["келдырив"],
    "келдырить": ["колдырить"],
    "келейничав": ["келейничавши"],
    "келейничавши": ["келейничав"],
    "келейно": ["скрыто", "тайно"],
    "келейность": ["скрытность", "секретность", "тайность"],
    "келейный": ["монастырский", "иноческий", "закулисный", "негласный", "конфиденциальный", "приватный"],
    "келемеж": ["келеке"],
    "келепнемс курга": ["афнемс курга"],
    "келесоо": ["акмак"],
    "келех": ["келих"],
    "кели курга": ["кургонь келепни"],
    "келих": ["кубок", "бокал", "келех"],
    "келишмек": ["ярашмакъ"],
    "келх": ["гих", "бурлдх", "бурх"],
    "келхури": ["южнокурдский язык"],
    "кельбаджар": ["карвачар"],
    "кельбаджарский": ["карвачарский"],
    "кельбит": ["калбит"],
    "кельвин": ["градус кельвина"],
    "кельма": ["мастерок"],
    "кельме": ["мяльфтома", "коське"],
    "кельмяк": ["кёльмяк"],
    "кельнер": ["официант"],
    "келья": ["скит", "келейка", "палата", "комната"],
    "кемарив": ["кемаривши"],
    "кемаривши": ["кемарив"],
    "кемарить": ["кимарить", "дремать", "подрёмывать"],
    "кемах": ["куммаха"],
    "кембридж": ["кембриджский университет"],
    "кембрий": ["кембрийский период"],
    "кембрийский период": ["кембрий"],
    "кембрик": ["батист"],
    "кемеровец": ["кемеровчанин"],
    "кемеровская область": ["кузбасс"],
    "кемеровчанин": ["кемеровец"],
    "кемпер": ["автодом", "дом на колёсах", "трейлер"],
    "кенар": ["кенарь"],
    "кенарь": ["кенар"],
    "кенаф": ["гибискус коноплёвый"],
    "кенгурин": ["бугель", "скотоотбойник"],
    "кенгуру": ["карман-кенгуру"],
    "кенгурушка": ["толстовка"],
    "кенгурятник": ["кенгурин", "бугель"],
    "кенделен": ["кёнделен", "гунделен", "генделен"],
    "кендырь": ["кутра", "душица"],
    "кенийка": ["кенианка"],
    "кения": ["республика кения"],
    "кенкет": ["кинкет", "аргандова лампа"],
    "кеннет": ["кенни"],
    "кенозис": ["кенотизм"],
    "кенотаф": ["памятник", "мемориал", "мавзолей", "дольмен"],
    "кенотизм": ["кенозис"],
    "кент": ["чувак", "кореш"],
    "кентавр": ["центавр", "китоврас", "полкан"],
    "кентурион": ["центурион", "сотник"],
    "кентурия": ["центурия"],
    "кентяра": ["кент", "чувак", "кореш"],
    "кепарь": ["кепка"],
    "кепка": ["кепарь"],
    "кепкувати": ["глузувати"],
    "кеподьксонди": ["именна"],
    "керамик": ["керамист", "гончар"],
    "керамика": ["гончарство"],
    "керамист": ["керамик", "гончар"],
    "керамическая плитка": ["фаянсовая плитка", "кафель"],
    "керамогранит": ["керогранит", "керамический гранит"],
    "кератометр": ["астигмоофтальмометр"],
    "кератоцеле": ["десцеметоцеле"],
    "кераунография": ["фульгурит"],
    "кераунофобия": ["астрапофобия"],
    "кербь": ["керпь"],
    "кержак": ["раскольник", "староверец", "старовер", "старообрядец"],
    "керимли": ["кёрюмлю"],
    "керкинитида": ["каркинитида", "евпатория"],
    "керл": ["кэрл"],
    "керманич": ["кермовий", "стерновий", "стерничий", "вождь"],
    "кермо": ["руль"],
    "кернохранилище": ["керносклад"],
    "керогазив": ["керогазивши"],
    "керогазивши": ["керогазив"],
    "керогазить": ["керосинить"],
    "керомс": ["веляфтомс", "сявордемс", "перямс", "пекстамс", "аердамс", "коламс мяль", "кольфтемс мяль", "обжамс"],
    "керосин": ["карасин", "светильный газ"],
    "керосинив": ["керосинивши"],
    "керосинивши": ["керосинив"],
    "керосинить": ["пьянствовать"],
    "керосинный": ["керосиновый"],
    "керосиновый": ["керосинный"],
    "керсет": ["карсет", "карсетка"],
    "керувати": ["правити"],
    "керувим": ["керувлар"],
    "керф": ["керф васта"],
    "керчанин": ["керченец"],
    "керчанка": ["керченка"],
    "керченец": ["керчанин"],
    "керченский мост": ["крымский мост"],
    "керченский пролив": ["таврический пролив", "еникальский пролив", "киммерийский босфор", "босфор киммерийский"],
    "керчь": ["корчев", "черкио"],
    "керэт": ["керять"],
    "керять": ["керэт"],
    "кес": ["кеш"],
    "кесарив": ["кесаривши"],
    "кесаривши": ["кесарив"],
    "кесарь": ["цезарь", "император", "цесарь"],
    "кесийка": ["торбичка"],
    "кессон": ["погреб"],
    "кессонировав": ["кессонировавши"],
    "кессонировавши": ["кессонировав"],
    "кессонированный": ["лакунарный"],
    "кет": ["остяк", "енисейский остяк", "енисеец"],
    "кетен": ["карбометилен", "этенон"],
    "кето": ["кету"],
    "кетоацидоз": ["кетоз"],
    "кетогенная диета": ["кетодиета", "кето-диета", "кето"],
    "кетоглутаровая кислота": ["оксоглутаровая кислота"],
    "кетодиета": ["кетогенная диета"],
    "кетоз": ["кетоацидоз"],
    "кетокислота": ["оксокислота"],
    "кетон": ["смирных"],
    "кетонемия": ["ацетонемия"],
    "кетоновое тело": ["ацетоновое тело"],
    "кетонурия": ["ацетонурия"],
    "кетоянтарная кислота": ["щавелево-уксусная кислота"],
    "кетский язык": ["кетский"],
    "кету": ["кето"],
    "кетчист": ["кэтчист", "рестлер"],
    "кетюрь": ["кетяр"],
    "кефалокраниокласт": ["базиотриб"],
    "кефи": ["куфия"],
    "кефир": ["кефирчик"],
    "кефирчик": ["кефир"],
    "кеш": ["кэш"],
    "кеш-игра": ["кеш"],
    "кеш-игрок": ["кешевик"],
    "кешбэк": ["каша"],
    "кеше": ["инсан", "зат"],
    "кешелек": ["инсаният"],
    "кешелеклелек": ["кешелек"],
    "кешесез": ["аулак", "кеше аз яши торган"],
    "кеши": ["кэши"],
    "кешировав": ["кешировавши"],
    "кешировавши": ["кешировав"],
    "кешнямс": ["кешнязевемс"],
    "кешью": ["акажу", "анакардиум западный", "индийский орех"],
    "кзади": ["назад"],
    "кзот": ["трудовой кодекс"],
    "кзыл-ординский": ["кызылординский"],
    "ки": ["нинхурсаг"],
    "кианин": ["киянин"],
    "кианит": ["дистен"],
    "кибератака": ["кибернападение"],
    "кибербуллинг": ["интернет-травля", "кибертравля", "онлайн-травля"],
    "кибервойска": ["киберподразделение"],
    "киберзлоумышленник": ["киберпреступник", "хакер"],
    "киберигрок": ["киберспортсмен"],
    "киберкафе": ["интернет-кафе"],
    "киберкомандование": ["кибернетический", "командование"],
    "киберкриминал": ["киберкриминалитет", "киберпреступность"],
    "киберкриминалитет": ["киберкриминал", "киберпреступность"],
    "кибернападение": ["кибератака"],
    "кибернетизировав": ["кибернетизировавши"],
    "кибернетизировавши": ["кибернетизировав"],
    "кибернетизированный": ["автоматизированный", "роботизированный"],
    "киберпанковский": ["киберпанковый"],
    "киберпанковый": ["киберпанковский"],
    "киберподразделение": ["кибервойска"],
    "киберпреступность": ["киберкриминал", "киберкриминалитет"],
    "киберпространство": ["интернет"],
    "киберспекуляция": ["домейнинг"],
    "киберспортсмен": ["киберигрок"],
    "кибертеррорист": ["хакер"],
    "кибертравля": ["интернет-травля"],
    "кибетче": ["сатучы"],
    "киборг": ["кибернетический организм"],
    "кибуцник": ["киббуцник"],
    "кив": ["клуб интересных встреч"],
    "кивав": ["кивавши"],
    "кивавши": ["кивав"],
    "кивание": ["кивок"],
    "кивано": ["ангурия", "антильский огурец", "африканский огурец", "английский помидор", "рогатая дыня"],
    "киванье": ["кивание"],
    "киви": ["актинидия"],
    "кивнув": ["кивнувши"],
    "кивнувши": ["кивнув"],
    "кивок": ["кивание"],
    "киворий": ["надпрестольная сень", "алтарь"],
    "кивот": ["киот", "ковчег"],
    "кигинец": ["верхнекигинец"],
    "кидав": ["кидавши"],
    "кидавши": ["кидав"],
    "кидалово": ["кидок", "кидняк"],
    "кидание": ["бросание"],
    "киданье": ["кидание"],
    "кидать": ["бросать", "швырять", "метать", "разводить", "обманывать", "надувать", "дурить", "оставлять ни с чем"],
    "кидать через хуй": ["накалывать", "кидать через хрен", "кидать через хер", "через хрен кидать", "через хер кидать", "наёбывать", "объёбывать", "через хуй кидать"],
    "кидаться": ["бросаться"],
    "кидок": ["бросание", "бросок", "швырок", "подстава"],
    "кидывав": ["кидывавши"],
    "кидывавши": ["кидывав"],
    "кидь": ["снегопад"],
    "киев": ["мать городов русских", "матерь городов русских", "куяба"],
    "киевлянин": ["киевец", "киянин"],
    "киевская область": ["киевщина"],
    "киевская русь": ["древнерусское государство", "древняя русь", "русь"],
    "киекче": ["аучы"],
    "кизил": ["кизил обыкновенный"],
    "кизильбаш": ["персианин", "кызылбаш"],
    "кизитеринский": ["кизитериновский"],
    "кизяковый": ["кизячный"],
    "кизячный": ["кизяковый"],
    "кий": ["кый"],
    "кийин": ["кийинь"],
    "кик-боксинг": ["кикбоксинг"],
    "кика": ["кичка"],
    "кикбайк": ["велосамокат", "футбайк"],
    "кикбоксинг": ["кикбокс"],
    "кикборд": ["скутер"],
    "кикер": ["фусбол", "кикбоксер", "трамплин", "антрацит", "белая фея", "бешеный порошок", "дутый", "кекс", "кокс", "мел", "мука", "мура", "нюхара", "нюхта"],
    "кикимора": ["шишимора"],
    "киклады": ["кикладские острова"],
    "киклоп": ["циклоп", "чудовище"],
    "кикнув": ["кикнувши"],
    "кикнувши": ["кикнув"],
    "киконго": ["конго"],
    "кикс": ["осечка", "промах"],
    "киксанув": ["киксанувши"],
    "киксанувши": ["киксанув"],
    "кикскутер": ["трюковый", "экстремальный", "самокат"],
    "киксовав": ["киксовавши"],
    "киксовавши": ["киксовав"],
    "кил-йыш": ["килйыш"],
    "килевав": ["килевавши"],
    "килевавши": ["килевав"],
    "килевать": ["кренговать"],
    "килик": ["киликс"],
    "килимар": ["килимарник"],
    "киллер": ["наёмный убийца"],
    "киллеровский": ["киллерский"],
    "киллерский": ["киллеровский"],
    "килмис": ["кюльмюш"],
    "килобайт": ["кбайт", "кибибайт"],
    "килобайтный": ["килобайтовый"],
    "килобайтовый": ["килобайтный", "однокилобайтовый"],
    "килобакс": ["килобак"],
    "килобитный": ["килобитовый"],
    "киловатт-час": ["квтч"],
    "килограмм": ["кило", "кг", "килограмм-сила", "килопонд"],
    "килограммометр": ["килограмм-сила-метр"],
    "килоконь": ["килолошадь"],
    "килолитр": ["кубометр", "кубический метр", "куб"],
    "километр": ["км"],
    "километрит": ["милемания"],
    "килотонна": ["кт", "гигаграмм", "гг"],
    "кильватер": ["кильватерная струя"],
    "кильнув": ["кильнувши"],
    "кильнувши": ["кильнув"],
    "кильнуться": ["перевернуться"],
    "кильчевав": ["кильчевавши"],
    "кильчевавши": ["кильчевав"],
    "киляв": ["килявши"],
    "килявши": ["киляв"],
    "кимарив": ["кимаривши"],
    "кимаривши": ["кимарив"],
    "кимарить": ["кемарить", "кимать", "кималить", "киморить", "кимурить", "кемать", "кемарнуть"],
    "кимис": ["кюмюш"],
    "кимчи": ["кимчхи", "чимча", "чимчи"],
    "кимчхи": ["чимча", "кимчи", "ким-чи", "гимчи", "чимчи"],
    "киназа": ["фосфотрансфераза"],
    "кинантроп": ["псоглавец"],
    "кинантропия": ["собакочеловечность", "собакоочеловечение"],
    "кинговский": ["стивен-кинговский"],
    "кингстон-апон-халл": ["гулль"],
    "киндарк": ["киндарка"],
    "киндарка": ["киндарк"],
    "киндер": ["мелкий", "детёныш"],
    "кинед": ["малакия", "распутник", "развратник"],
    "кинедон": ["андрофил", "патикус"],
    "кинематограф": ["кино", "кинематография", "киноискусство"],
    "кинематографист": ["киношник"],
    "кинематографический": ["киношный"],
    "кинематография": ["кинематограф", "киноискусство", "кино"],
    "кинескоп": ["приёмная телевизионная трубка"],
    "кинестезия": ["мышечное чувство", "ценестезия"],
    "кинетопластида": ["кинетопласт"],
    "кинетохор": ["центромера"],
    "кинешемка": ["кинешемочка"],
    "кинешемочка": ["кинешемка"],
    "кинжал": ["перо"],
    "кинза": ["китайская петрушка", "кориандр"],
    "кинизм": ["цинизм"],
    "киник": ["циник"],
    "кининогенин": ["калликреин", "кининогеназа"],
    "кинк": ["антикинк"],
    "кинкан": ["кумкват", "фортунелла"],
    "кинкет": ["кенкет", "аргандова лампа"],
    "кинки-вечеринка": ["кинки-пати"],
    "киннамон": ["корица"],
    "кино": ["кинематограф", "кинематография", "киноискусство", "кинофильм", "фильм", "кинолента", "лента", "кинокартина", "картина", "кинотеатр"],
    "кино и немцы": ["цирк", "умора", "картина маслом"],
    "киноа": ["квиноа"],
    "киноадаптация": ["экранизация"],
    "киноактриса": ["киноартистка"],
    "киноактёр": ["киноартист"],
    "киноаппарат": ["киносъёмочный аппарат", "кинокамера", "киноустановка"],
    "киноаппаратная": ["кинопроекторная"],
    "киноателье": ["киностудия"],
    "кинобизнесмен": ["кинопредприниматель"],
    "кинобондиана": ["бондиана", "джеймсбондиана"],
    "киноведение": ["киноведенье"],
    "киноведенье": ["киноведение"],
    "киновия": ["ценобий"],
    "киновоплощение": ["киновоплощенье"],
    "киногурман": ["киноэстет"],
    "кинодеятель": ["кинематографист"],
    "кинодива": ["кинозвезда"],
    "кинодраматург": ["киносценарист"],
    "кинозарисовка": ["киноэскиз"],
    "кинозвезда": ["кинодива"],
    "кинознаменитость": ["кинозвезда", "кинодива"],
    "киноиндустрия": ["кинопромышленность"],
    "киноискусство": ["кино", "кинематограф", "кинематография"],
    "кинокамера": ["киноаппарат", "киносъёмочный аппарат"],
    "кинокефал": ["киноцефал", "циноцефал"],
    "кинокомпания": ["кинопредприятие", "кинофирма", "кинопроизводитель"],
    "кинолента": ["кинофильм", "кинокартина"],
    "кинолог": ["собаковед"],
    "кинология": ["собаковедение"],
    "кинолюб": ["киноман", "синефил", "киношник"],
    "киноман": ["синефил", "кинолюбитель", "кинолюб", "киношник"],
    "киномания": ["синефилия"],
    "киномгновение": ["киносцена", "кинокадр"],
    "кинонаграда": ["кинопремия", "киноприз"],
    "кинонеделя": ["кинофестиваль", "еженедельник"],
    "киноплощадка": ["кинопавильон"],
    "кинопостановщик": ["кинорежиссёр"],
    "кинопостер": ["киноафиша"],
    "кинопредприниматель": ["кинобизнесмен"],
    "кинопредприятие": ["кинокомпания", "кинофирма"],
    "кинопремия": ["кинонаграда", "киноприз"],
    "кинопроизводитель": ["кинокомпания"],
    "кинопрокат": ["прокат", "кинопоказ"],
    "киноработа": ["кинофильм", "кинороль"],
    "кинорежиссёр": ["кинопостановщик"],
    "кинорексия": ["булимия"],
    "кинороль": ["киноработа"],
    "киносага": ["киносерия", "кинофраншиза"],
    "киносерия": ["киносага", "кинофраншиза"],
    "киностряпня": ["киноподелка"],
    "киносценарист": ["кинодраматург"],
    "кинотавровский": ["кинотаврский"],
    "кинотаврский": ["кинотавровский"],
    "кинотеатр": ["кино", "иллюзион", "кинематограф", "синематограф"],
    "кинотека": ["фильмотека"],
    "киноужасы": ["фильм ужасов", "хоррор", "ужастик"],
    "кинофан": ["кинофанат"],
    "кинофанат": ["кинофан"],
    "кинофильм": ["кинокартина", "кинолента"],
    "кинофильма": ["кинофильм"],
    "кинофирма": ["кинокомпания", "кинопредприятие"],
    "кинофицировав": ["кинофицировавши"],
    "кинофицировавши": ["кинофицировав"],
    "кинофраншиза": ["киносага", "киносерия"],
    "киноцефал": ["кинокефал", "псоглавец", "песьеглавец", "песиголовец"],
    "киношник": ["кинематографист"],
    "киноэстет": ["киногурман"],
    "киноя": ["рамз"],
    "кинто": ["коробейник", "лоточник"],
    "кинув": ["кинувши"],
    "кинувши": ["кинув"],
    "кинуть": ["бросить", "швырнуть", "швырануть", "покинуть", "оставить", "послать", "перевести", "обворовать", "ограбить", "обмануть", "облапошить", "обуть", "надуть"],
    "кинуть на подвал": ["бросить на подвал"],
    "кинуть под жабры": ["залить жабры", "плеснуть под жабры"],
    "кинуться": ["броситься", "помчаться", "рвануться"],
    "кинцо": ["кино", "кинофильм", "фильм"],
    "киньяруанда": ["руанда"],
    "киос": ["гемлик", "прусиана"],
    "киоск": ["ларёк", "будка"],
    "киот": ["божница", "кивот"],
    "киотоский": ["киотский"],
    "киотский": ["киотоский"],
    "кипарисний": ["кипарисовий"],
    "кипарисный": ["кипарисовый"],
    "кипарисовий": ["кипарисний"],
    "кипарисовый": ["кипарисный"],
    "кипев": ["кипевши"],
    "кипевши": ["кипев"],
    "кипелыч": ["волеро", "лерсаныч"],
    "кипень": ["пена", "крутой кипяток", "вар", "вароток"],
    "кипер": ["иван-чай"],
    "кипеть": ["бурлить"],
    "кипеш": ["крик", "скандал", "ругань", "бунт", "безобразие", "разборка", "шум", "переполох", "беготня", "толкотня", "паника"],
    "кипешив": ["кипешивши"],
    "кипешивши": ["кипешив"],
    "кипиш": ["крик", "скандал", "ругань", "бунт", "безобразие", "разборка", "шум", "переполох", "суета", "суматоха", "волнение", "тревога", "беготня", "толкотня", "паника"],
    "кипишевав": ["кипишевавши"],
    "кипишевавши": ["кипишевав"],
    "кипишевать": ["гнать волну"],
    "кипр": ["республика кипр"],
    "кипрей": ["иван-чай узколистный"],
    "киприда": ["афродита"],
    "кипсей": ["кипсея"],
    "кипсек": ["кипсэк"],
    "кипсея": ["кипсей"],
    "кипсэк": ["кипсек"],
    "кипучий": ["кипящий", "бурлящий", "бурливый", "пенящийся", "деятельный", "азартный", "бешеный", "буйный", "интенсивный", "оживлённый", "страстный", "темпераментный"],
    "кипчакский": ["кыпчакский", "половецкий"],
    "кипятив": ["кипятивши"],
    "кипятивши": ["кипятив"],
    "кипятилка": ["кипятильня"],
    "кипятильник": ["электрокипятильник", "кипятильный", "труба"],
    "кипяток": ["пламень"],
    "кипяченье": ["кипячение"],
    "кир": ["цир", "сир", "куруш"],
    "кирал": ["сыро"],
    "киральность": ["хиральность"],
    "киргизия": ["киргизстан", "кыргызстан", "кыргызская республика"],
    "киргизская республика": ["киргизия", "киргизстан", "кыргызстан", "кыргызская республика"],
    "киргизская сср": ["киргизия"],
    "киргизский": ["кыргызский"],
    "киргизский язык": ["киргизский"],
    "киргизстан": ["кыргызстан", "киргизия", "кыргызская республика"],
    "кирдемс": ["лоткафтомс", "пинге", "ётафтомс", "максомс", "кандомс", "аф мярьгомс", "кардамс", "сюцемс", "аф эряскодомс", "сявомс", "ёрдамс", "ванфтомс мялямса", "кирдемс мяльса", "кирдемс прясот", "мяляфтомс"],
    "кирдык": ["амба", "капут", "каюк", "кранты", "хана", "трындец", "конец", "крышка"],
    "кирзач": ["сапог"],
    "кирибати": ["республика кирибати"],
    "кирилл": ["кирюша", "кирюшка", "кирюшенька", "кирюшечка", "кирюха", "сирил"],
    "кириллица": ["кириллический алфавит", "кирилловский алфавит", "кириллический шрифт"],
    "кириллический": ["кирилловский", "кирилличный"],
    "кирилличный": ["кириллический"],
    "кириллович": ["кирилыч"],
    "кирилловский": ["кириллический", "кирилличный"],
    "кирис": ["кириш"],
    "киришанин": ["киришец"],
    "кирка": ["лютеранская церковь", "кирха"],
    "кирказон": ["аристолохия"],
    "кирказоновые": ["кирказоноцветные", "аристолохиевые"],
    "кирной": ["пьяный", "нетрезвый"],
    "кирнуть": ["бухнуть"],
    "кировец": ["кировчанин"],
    "кировоград": ["кропивницкий"],
    "кировоградская область": ["кировоградщина"],
    "кировск-мурманский": ["кировск"],
    "кирпич": ["кирпичьё", "фолиант", "кирпичик", "буханка", "брик"],
    "кирпичник": ["каменщик"],
    "кирпичный": ["красновато-коричневый", "плиточный", "брикетированный"],
    "кирпичный чай": ["карым", "карымский чай"],
    "кирунди": ["рунди"],
    "кирха": ["кирка"],
    "кирчёный": ["оструганный", "тесаный", "выструганный", "обтёсанный", "остроганный", "отструганный", "обстроганный"],
    "кирьят-ата": ["кфар-ата"],
    "киряв": ["кирявши"],
    "кирявши": ["киряв"],
    "кис-кис": ["кыс"],
    "киса": ["кошка", "киска", "лапа", "лапуля", "зая", "девица", "девка", "вагина", "вульва"],
    "кисея": ["муслин"],
    "киси": ["киши"],
    "киска": ["кошечка", "кисонька"],
    "кислев": ["хислев", "хаслев"],
    "кислевши": ["кислев"],
    "кисленка": ["щавель", "кислинка"],
    "кисленький": ["кисловатый"],
    "кислив": ["кисливши"],
    "кисливши": ["кислив"],
    "кислица": ["кислинка"],
    "кисловав": ["кисловавши"],
    "кисловавши": ["кисловав"],
    "кисловать": ["окислять"],
    "кисловка": ["кислование"],
    "кислород": ["кислотвор"],
    "кислородное голодание": ["гипоксия"],
    "кислородосодержащий": ["кислородсодержащий"],
    "кислота": ["кислота бренстеда", "кислота льюиса", "длк", "лсд"],
    "кислотвор": ["кислород", "оксиген"],
    "кислотомер": ["ацидиметр"],
    "кислотостойкий": ["кислотоупорный"],
    "кислотоупорность": ["кислотостойкость"],
    "киснув": ["киснувши"],
    "киснувши": ["киснув"],
    "киснуть": ["закисать", "прокисать", "скисать", "проквашиваться", "скисаться", "унывать"],
    "кистер": ["кюстер"],
    "кисть": ["гроздь", "пясть"],
    "киське": ["кедь"],
    "киськорямс": ["ангорямс", "ватксемс"],
    "кисэн": ["кинё"],
    "кит": ["коллектив интенсивного труда"],
    "кит-полосатик": ["полосатик"],
    "китаб": ["коран"],
    "китаевед": ["китаист", "синолог"],
    "китаеведение": ["китаистика", "синология"],
    "китаефобия": ["синофобия", "чайнафобия"],
    "китаец": ["китаёза", "китаёзина", "китайса", "китайца", "ханец", "хань"],
    "китаизировав": ["китаизировавши"],
    "китаизировавши": ["китаизировав"],
    "китаист": ["китаевед", "синолог"],
    "китаистика": ["синология", "китаеведение"],
    "китай": ["поднебесная", "китайская народная республика", "кнр"],
    "китайская народная республика": ["китай", "кнр"],
    "китайская республика": ["тайвань"],
    "китайский": ["китайческий", "китайский язык", "дутый"],
    "китайский разведчик": ["японский разведчик", "китайский шпион", "японский шпион"],
    "китайский шпион": ["японский шпион", "китайский разведчик", "японский разведчик"],
    "китайско-восточная железная дорога": ["квжд"],
    "китайско-вьетнамский": ["вьетнамо-китайский"],
    "китайско-российский": ["российско-китайский"],
    "китайщина": ["шинуазри", "китаизм"],
    "китаёза": ["китаец", "китаянка"],
    "китерон": ["киферон"],
    "китив": ["кютюв"],
    "китивци": ["кютювчю"],
    "китира": ["кифера", "цитера", "цериго", "чериго"],
    "китка": ["грозд", "чепка", "кичур", "храст", "букет"],
    "кито": ["сан-франциско-де-кито"],
    "китобойный": ["китоловный"],
    "китф": ["кифт", "шона"],
    "китч": ["псевдоискусство", "кич", "дешёвка", "безвкусица", "цыганщина"],
    "китёнок": ["китёныш"],
    "кифара": ["цитра"],
    "кифоз": ["горб"],
    "кифт": ["китф", "шона"],
    "кич": ["китч", "дешёвка", "безвкусица"],
    "кичение": ["похвальба"],
    "киченье": ["кичение"],
    "кичиться": ["превозноситься", "заноситься", "важничать", "задаваться", "хвалиться", "бахвалиться", "похваляться", "чваниться", "пыжиться"],
    "кичка": ["нос"],
    "кичкене": ["кичик"],
    "кичливо": ["заносчиво", "спесиво", "чванливо"],
    "кичливость": ["высокомерие", "заносчивость"],
    "кичливый": ["заносчивый", "гордый", "высокомерный", "с гонором", "спесивый", "чванливый", "чванный", "зазнавшийся", "надменный", "барственный", "надутый", "напыщенный", "амбициозный", "претенциозный", "важный"],
    "киша": ["лапавица", "кал", "дъжд", "влага", "мокрота"],
    "кишвар": ["мамлакат"],
    "кишев": ["кишевши"],
    "кишевши": ["кишев"],
    "кишень": ["кошелёк", "кишеня"],
    "кишенье": ["кишение"],
    "кишеня": ["кишень", "карман", "зепь", "калита", "мешечек", "кошелек", "брюхо", "желудок"],
    "кишеть": ["копошиться", "сновать", "изобиловать", "роиться"],
    "кишинёв": ["кишинэу"],
    "кишка": ["шланг"],
    "кишки": ["внутренности"],
    "киянин": ["кыянин"],
    "ккал": ["кал"],
    "кку": ["уку"],
    "клава": ["клавиатура"],
    "клавесин": ["аркичембало", "верджинел", "верлжинел", "виргинал", "клавир", "клавицитериум", "клавичембало", "спинет", "хордофон", "чембало"],
    "клавиатура": ["клава", "клавиши"],
    "клавир": ["клавираусцуг"],
    "клавираусцуг": ["клавир"],
    "клавицимбал": ["клавичембало"],
    "клавичембало": ["клавесин", "клавицимбал", "чембало"],
    "клавиш": ["клавиша"],
    "клавиша": ["клавиш", "кнопка"],
    "клавши": ["клав"],
    "клада": ["клад", "кладон", "монофилетический", "таксон"],
    "кладбище": ["некрополь", "погост"],
    "кладезь": ["колодец", "сокровищница"],
    "кладеный": ["кастрированный", "холощёный"],
    "кладмен": ["кладер", "закладчик"],
    "кладовая": ["кладовка", "склад", "сокровищница"],
    "кладовище": ["цвинтар"],
    "кладовка": ["кладовая", "чулан"],
    "кладоискатель": ["археолог-любитель"],
    "кладоискательствовав": ["кладоискательствовавши"],
    "кладоискательствовавши": ["кладоискательствовав"],
    "кладон": ["клад", "клада"],
    "кладония": ["ягель", "олений мох"],
    "кладущий": ["ложащий"],
    "кладывав": ["кладывавши"],
    "кладывавши": ["кладывав"],
    "кладь": ["поклажа", "груз", "багаж"],
    "кладязь": ["колодец", "колодезь"],
    "клаксонив": ["клаксонивши"],
    "клаксонивши": ["клаксонив"],
    "клан": ["род", "племя", "семья", "клика"],
    "кланица": ["касапница", "скотобойна"],
    "клановый": ["родовой"],
    "кланяться": ["бить поклоны", "выпрашивать", "заискивать", "поклоняться"],
    "клаповухий": ["капловухий"],
    "кларк": ["кларковое число"],
    "клас": ["колос"],
    "класико": ["дерби"],
    "классификация": ["классифицирование", "таксонометрия"],
    "классифицировав": ["классифицировавши"],
    "классифицировавши": ["классифицировав"],
    "классицистский": ["классицистический"],
    "классическая музыка": ["академическая музыка", "классика"],
    "классический": ["классицистический", "хрестоматийный", "античный", "типичный", "характерный", "традиционный", "привычный", "обыкновенный", "замечательный", "отличный"],
    "классический стиль": ["классика"],
    "классная комната": ["класс"],
    "классная руководительница": ["классуха"],
    "классно": ["отлично", "здорово", "круто", "супер", "клёво", "кайфово", "жёстко"],
    "классный": ["высококвалифицированный", "клёвый", "обалденный", "кайфовый"],
    "классуха": ["классная руководительница"],
    "кластер": ["сгусток", "скопление", "сектор"],
    "класть в штаны": ["откладывать кирпичи"],
    "класть жизнь": ["гибнуть", "погибать"],
    "класть крепкий хуй": ["класть", "класть с прибором", "класть хуй", "класть хуй в авоське", "хуй класть", "крепкий хуй класть", "хуй в авоське класть", "ложить хуй", "хуй ложить"],
    "класть на музыку": ["класть на ноты"],
    "класть на ноты": ["класть на музыку"],
    "класть поклоны": ["творить поклоны"],
    "клатратный": ["клеточный", "решетчатый", "сетчатый"],
    "клауд-рэп": ["триллвейв"],
    "клац": ["лязг", "стук", "щелчок"],
    "клацав": ["клацавши"],
    "клацавши": ["клацав"],
    "клацать": ["лязгать"],
    "клацнув": ["клацнувши"],
    "клацнувши": ["клацнув"],
    "клевав": ["клевавши"],
    "клевавши": ["клевав"],
    "клевание": ["клеванье"],
    "клевант": ["кневенс", "кневень", "клеванта"],
    "клевать": ["щипать", "вестись"],
    "клевета": ["инсинуация", "наговор", "поклёп", "каломния"],
    "клеветав": ["клеветавши"],
    "клеветавши": ["клеветав"],
    "клеветник": ["каломниатор"],
    "клевец": ["чекан"],
    "клеврет": ["приспешник", "сообщник", "соучастник"],
    "клееварня": ["клееварка"],
    "клеевина": ["клейковина"],
    "клеив": ["клеивши"],
    "клеивши": ["клеив"],
    "клеить": ["приклеивать", "склеивать", "подкатывать", "клеиться", "флиртовать", "кадрить", "приударять", "увиваться", "ухлёстывать", "заигрывать", "пикапить", "шить"],
    "клейкая лента": ["скотч"],
    "клейкий": ["липкий", "склеивающий", "прилипающий"],
    "клейковина": ["глютен"],
    "клеймив": ["клеймивши"],
    "клеймивши": ["клеймив"],
    "клеймление": ["клеймение"],
    "клеймо": ["печать", "тамга", "штамп", "ярлык", "тавро"],
    "клеймовщик": ["клеймитель", "маркировщик", "металлург", "метчик"],
    "клеймувати": ["клеймити", "таврувати"],
    "клейстокарпий": ["клейстотеций"],
    "клейстотеций": ["клейстокарпий"],
    "клекотав": ["клекотавши"],
    "клекотавши": ["клекотав"],
    "клекотание": ["клёкот"],
    "клекотанье": ["клекотание"],
    "клектав": ["клектавши"],
    "клектавши": ["клектав"],
    "клемма": ["винтовой зажим"],
    "клеммная колодка": ["клеммный блок", "кб", "клеммный зажим", "клеммный соединитель", "терминальный блок"],
    "клеммник": ["клеммная колодка"],
    "клеммный": ["зажимный", "клеммовый"],
    "клеммовый": ["клеммный"],
    "клемний": ["клемовий"],
    "клемовий": ["клемний"],
    "кленок": ["клён"],
    "клепав": ["клепавши"],
    "клепавши": ["клепав"],
    "клепало": ["молот", "болванка", "било", "колокол", "язык колокола"],
    "клепать": ["заклёпывать"],
    "клепер": ["клеппер"],
    "клепец": ["белоглазка", "глазач", "сопа", "сапа"],
    "клеппер": ["клепер"],
    "клепсидра": ["водяные часы"],
    "клепсина": ["плоская пиявка"],
    "клептократ": ["ворократ"],
    "клерикальный": ["процерковный"],
    "клеровав": ["клеровавши"],
    "клеровавши": ["клеровав"],
    "клеровка": ["клерование"],
    "клетва": ["обещание", "оброк", "обет", "проклятие", "проклинание", "заклинание", "анатема"],
    "клетка-киллер": ["клетка-убийца"],
    "клетневав": ["клетневавши"],
    "клетневавши": ["клетневав"],
    "клеточное дыхание": ["тканевое дыхание"],
    "клетух": ["хлев", "загон", "сарай", "клетушка", "каморка", "конура"],
    "клетуха": ["клетка", "курятник", "камера"],
    "клетушка": ["клеть", "покой", "комната", "помещение"],
    "клеть": ["сруб", "кладовая"],
    "клечальний": ["клечаний"],
    "клешнятый": ["закостенелый"],
    "клещ": ["зудень", "накожник", "плоскотелка", "краснотелка", "загожья вошь", "лосёвая вошь"],
    "клещевина": ["рицинус", "рицина", "рицин"],
    "клещи": ["охват"],
    "клеёная древесина": ["клеёный массив"],
    "клеёная конструкция": ["кдк"],
    "клеёнка": ["виксатин", "клеёночка", "пигамоид"],
    "клиент": ["заказчик"],
    "клизма": ["клистир"],
    "клизмировав": ["клизмировавши"],
    "клизмировавши": ["клизмировав"],
    "клик": ["клич", "зов", "возглас", "оклик"],
    "клика": ["камарилья", "шайка"],
    "кликабельность": ["привлекательность"],
    "кликав": ["кликавши"],
    "кликавши": ["кликав"],
    "кликандер": ["попандер"],
    "кликбейт": ["кликбэйт"],
    "кликбейтовый": ["тизерный"],
    "кликбэйт": ["кликбейт"],
    "кликнув": ["кликнувши"],
    "кликнувши": ["кликнув"],
    "кликпад": ["трекпад"],
    "кликс": ["щелчок", "щёлкающий согласный"],
    "кликуша": ["бесноватый"],
    "кликушествовав": ["кликушествовавши"],
    "кликушествовавши": ["кликушествовав"],
    "кликушествовать": ["кликушничать"],
    "кликушничав": ["кликушничавши"],
    "кликушничавши": ["кликушничав"],
    "климазон": ["сушуар"],
    "климакс": ["климактерий", "менопауза", "восходящяя градация"],
    "климат": ["атмосфера"],
    "климатизировав": ["климатизировавши"],
    "климатизировавши": ["климатизировав"],
    "клин": ["свинья", "косяк"],
    "клинер": ["уборщик", "уборщица"],
    "клинив": ["клинивши"],
    "клинивши": ["клинив"],
    "клиника": ["больница", "поликлиника", "медклиника", "частная клиника"],
    "клининг": ["уборка"],
    "клининговый": ["уборочный"],
    "клинкеровав": ["клинкеровавши"],
    "клинкеровавши": ["клинкеровав"],
    "клиннер": ["чистильщик"],
    "клиновидный": ["клиноподобный", "клинообразный"],
    "клинок": ["лезвие"],
    "клинометр": ["эклиметр", "уклономер"],
    "клиноподобный": ["клиновидный", "клинообразный"],
    "клинофилия": ["клиномания"],
    "клинч": ["захват"],
    "клинчевав": ["клинчевавши"],
    "клинчевавши": ["клинчевав"],
    "клип": ["видеоклип", "видеоролик", "ролик"],
    "клипак": ["клипчик", "клипец"],
    "клипец": ["клипчик", "клипак"],
    "клипмейкер": ["клипмейстер", "клиподел"],
    "клипмейстер": ["клипмейкер", "клиподел"],
    "клиподел": ["клипмейкер", "клипмейстер"],
    "клипчик": ["клипак", "клипец"],
    "клир": ["причт", "клирос", "певчий"],
    "клиренс": ["дорожный просвет"],
    "клирик": ["церковник"],
    "клирос": ["хоры", "крылос", "певчий"],
    "клистир": ["клизма"],
    "клисура": ["проход", "дефиле", "теснина", "устие", "долина"],
    "клитор": ["похотник", "сикель", "секель"],
    "клифт": ["пиджак", "пальто"],
    "кличка": ["имя"],
    "клише": ["избитое выражение", "штамп", "стереотип"],
    "клишировав": ["клишировавши"],
    "клишировавши": ["клишировав"],
    "клишоногий": ["клишавий"],
    "клоака": ["канал", "помойная яма", "выгребная яма", "выгреб", "помойка", "хлев", "конюшня", "свинарник", "проход"],
    "клоб": ["клуб"],
    "кловня": ["невод"],
    "клозет": ["гальюн", "нужник", "сортир", "туалет"],
    "клозетний": ["клозетовий"],
    "клокастый": ["клочковатый"],
    "клокотав": ["клокотавши"],
    "клокотавши": ["клокотав"],
    "клокотанье": ["клокотание"],
    "клоктав": ["клоктавши"],
    "клоктавши": ["клоктав"],
    "клоктушка": ["квок"],
    "клон": ["крен"],
    "клондайк": ["эльдорадо"],
    "клонив": ["клонивши"],
    "клонивши": ["клонив"],
    "клонировав": ["клонировавши"],
    "клонировавши": ["клонировав"],
    "клонить": ["наклонять"],
    "клониться": ["наклоняться", "склоняться"],
    "клонка": ["клонче", "вейка", "гранка"],
    "клоняв": ["клонявши"],
    "клонявши": ["клоняв"],
    "клоп": ["красный партизан", "постельный клоп", "малыш", "карлик"],
    "клоп-солдатик": ["пожарник"],
    "клоп-черепашка": ["щитник-черепашка"],
    "клопиный": ["клоповный", "клоповый"],
    "клоповка": ["вакциниум превосходный", "дымника", "красника"],
    "клоповыжигалка": ["клоповарка"],
    "клоповый": ["клоповный", "клопиный"],
    "клопотав": ["клопотавши"],
    "клопотавши": ["клопотав"],
    "клопотать": ["кропотать"],
    "клоун": ["паяц", "комик", "рыжий", "шут", "гаер", "балясник"],
    "клоунада": ["буффонада", "паясничание", "шутовство"],
    "клоуничать": ["клоунствовать", "клоунничать"],
    "клоунничав": ["клоунничавши"],
    "клоунничавши": ["клоунничав"],
    "клоунничать": ["клоунствовать", "клоуничать"],
    "клоунски": ["шутовски"],
    "клоунствовав": ["клоунствовавши"],
    "клоунствовавши": ["клоунствовав"],
    "клоунствовать": ["клоунничать"],
    "клофелин": ["клонидин"],
    "клохтав": ["клохтавши"],
    "клохтавши": ["клохтав"],
    "клохтать": ["квохтать"],
    "клочив": ["клочивши"],
    "клочивши": ["клочив"],
    "клочок": ["кусочек", "кусок", "обрывок"],
    "клош": ["колокол", "клёш"],
    "клуазоне": ["перегородчатая эмаль"],
    "клуатр": ["клостер"],
    "клуб": ["клубок"],
    "клуб интересных встреч": ["кив"],
    "клубень": ["корнеплод", "корнеклубень", "клубнелуковица"],
    "клубив": ["клубивши"],
    "клубивши": ["клубив"],
    "клубист": ["клубмен"],
    "клубмен": ["клубист"],
    "клубненосный подсолнечник": ["топинамбур"],
    "клубника": ["клубника садовая", "земляника мускусная", "мускатная земляника", "шпанка", "клубника луговая", "земляника зелёная", "полуница", "клубеника", "глубника", "трусавка", "земляника садовая", "ананасная земляника", "крупноплодная земляника"],
    "клубничка": ["клубника", "эротика"],
    "клубок": ["моток", "ком", "переплетение", "сплетение"],
    "клумак": ["клунок"],
    "клунок": ["клумак"],
    "клуня": ["овин", "рига", "гумно"],
    "клупп": ["плашка", "лерка"],
    "клусничав": ["клусничавши"],
    "клусничавши": ["клусничав"],
    "клуша": ["квочка", "клушка", "клохтунья", "наседка", "клуня", "недотёпа", "курица", "жируха"],
    "клушка": ["клуша", "квочка", "клохтунья"],
    "клык": ["бивень"],
    "клычок": ["клык"],
    "клэ": ["кля"],
    "клэк": ["кляк"],
    "клэн": ["клянь"],
    "клэр": ["клер", "клар"],
    "клюв": ["хлебало", "варежка", "пасть"],
    "клювик": ["трубка излива", "излив", "носик"],
    "клювоголовые": ["хоботноголовые", "ящерогад"],
    "клювонос": ["каймановая рыба", "панцирная щука", "панцирник"],
    "клюворыл": ["средний плавун"],
    "клюка": ["костыль", "обман", "коварство", "хитрец"],
    "клюкав": ["клюкавши"],
    "клюкавши": ["клюкав"],
    "клюкар": ["злословец", "интригант", "доносчик", "сплетник", "клеветник"],
    "клюква": ["журавлиха", "развесистая клюква"],
    "клюкнув": ["клюкнувши"],
    "клюкнувши": ["клюкнув"],
    "клюн": ["човка", "гага"],
    "клюнув": ["клюнувши"],
    "клюнувши": ["клюнув"],
    "ключ": ["источник", "родник"],
    "ключевая вода": ["родниковая вода"],
    "ключевой": ["основной", "главный"],
    "ключик": ["ключ"],
    "кляк": ["клэк"],
    "клякса": ["блямба", "грязь", "нечистота"],
    "клянчив": ["клянчивши"],
    "клянчивши": ["клянчив"],
    "клянчить": ["выпрашивать", "канючить"],
    "клянь": ["килен", "клэн"],
    "кляп": ["брусок", "клин", "кляпец", "тряпка", "завёртка", "закрутка", "кляпыш", "затычка", "пробка"],
    "клясть": ["проклинать"],
    "клятва": ["проклятие"],
    "клятвопреступление": ["предательство"],
    "клятвопреступленье": ["клятвопреступление"],
    "кляуза": ["донос", "наговор"],
    "кляузник": ["доносчик", "сутяга", "сутяжник"],
    "кляузничав": ["кляузничавши"],
    "кляузничавши": ["кляузничав"],
    "кляузничать": ["жаловаться", "наушничать", "ябедничать", "фискалить", "капать", "доносить", "стучать", "заявлять", "сигнализировать"],
    "кляцав": ["кляцавши"],
    "кляцавши": ["кляцав"],
    "клячка": ["ластик-клячка", "кляча", "снимка"],
    "клящий": ["плящий", "тлящий", "клящой"],
    "клёво": ["здорово", "классно", "прекрасно", "хорошо", "удачно", "супер", "здоровско", "офигенно", "козырно", "зыбо", "уматно"],
    "клёвость": ["крутизна", "крутость"],
    "клёкнув": ["клёкнувши"],
    "клёкнувши": ["клёкнув"],
    "клёкот": ["клекотание", "клектание", "клёкт"],
    "клёпка": ["клепание", "заклёпывание", "паркетина"],
    "кмв": ["кавказские минеральные воды", "кавминводы"],
    "кмин": ["комун", "кумин", "римский тмин", "кмин тминовый"],
    "кминний": ["кминовий"],
    "кминовий": ["кминний"],
    "кнааз": ["кнаапо"],
    "кнаапо": ["кнааз"],
    "кнагу": ["кнагту"],
    "кнаружи": ["наружу"],
    "кндр": ["северная корея"],
    "кнехт": ["кнек"],
    "книга": ["том", "книжка"],
    "книггер": ["литературный негр", "литраб"],
    "книговедение": ["библиология"],
    "книгоед": ["книжная вошь", "книгочей", "книжник"],
    "книгоиздатель": ["книжное издательство"],
    "книгоиздательство": ["издательство"],
    "книголюб": ["библиофил"],
    "книгоман": ["книголюб"],
    "книгопечатание": ["типографское дело"],
    "книгопечатанье": ["книгопечатание"],
    "книгопечатный": ["книгопечатнический"],
    "книгопечатня": ["типография"],
    "книгособирательство": ["библиофильство"],
    "книготорговец": ["книгопродавец"],
    "книгочей": ["книжник", "книжный червь", "книголюб"],
    "книжа": ["документи", "бумаги", "преписки", "писма", "хартии"],
    "книженция": ["книжонка"],
    "книжечка": ["книжка"],
    "книжка": ["книга", "сберкнижка"],
    "книжник": ["библиофил", "книгочей", "книголюб", "книжный червь", "книготорговец", "начётчик", "бумажник"],
    "книжный шкаф": ["книжная полка", "этажерка"],
    "книзу": ["вниз"],
    "книксен": ["реверанс"],
    "кнопка": ["клавиша", "канал", "карлик", "лилипут", "клоп", "нос", "шнобель"],
    "кнопкодавив": ["кнопкодавивши"],
    "кнопкодавивши": ["кнопкодавив"],
    "кнороз": ["кабан", "вепрь"],
    "кнр": ["китай", "китайская народная республика"],
    "кнур": ["кабан", "хряк"],
    "кнут": ["хлыст", "бич", "плеть", "палка", "принуждение", "гнёт", "насилие"],
    "кнутик": ["хлыстик", "плёточка", "кнут"],
    "кнутобойничав": ["кнутобойничавши"],
    "кнутобойничавши": ["кнутобойничав"],
    "кнутобойничать": ["кнутобойствовать"],
    "кнутобойствовав": ["кнутобойствовавши"],
    "кнутобойствовавши": ["кнутобойствовав"],
    "кнутобойствовать": ["кнутобойничать"],
    "кнутри": ["внутрь"],
    "княгиня": ["герцогиня"],
    "княжение": ["правление"],
    "княженика": ["мамура", "поленика", "костянка", "хохлушка", "полуденица"],
    "княженье": ["княжение"],
    "княжеский": ["княжий"],
    "княжество андорра": ["андорра"],
    "княжество лихтенштейн": ["лихтенштейн"],
    "княжив": ["княживши"],
    "княживши": ["княжив"],
    "княжий": ["княжеский"],
    "княжий пир": ["княжеский пир", "княжной пир", "княжовый пир", "княжой пир"],
    "княжой": ["княжий"],
    "князишка": ["князёк"],
    "князёк": ["князь", "княжич", "вождь"],
    "ко-": ["со-"],
    "коагель": ["гелеобразный", "осадок"],
    "коагулировав": ["коагулировавши"],
    "коагулировавши": ["коагулировав"],
    "коагулирование": ["коагуляция", "свёртывание", "осаждение"],
    "коагулируемость": ["осаждаемость"],
    "коагулограмма": ["гемостазиограмма"],
    "коагулограф": ["кондуктометрический гемокоагулограф"],
    "коагулолог": ["гемостазиолог"],
    "коагулологический": ["гемостазиологический"],
    "коагулология": ["гемостазиология"],
    "коагулопатия": ["несвёртываемость"],
    "коагулянт": ["осадитель"],
    "коагулят": ["осадок", "коагулюм"],
    "коагуляция": ["осаждение", "свёртывание"],
    "коадаптация": ["приспособление"],
    "коадъютор": ["епископ-коадъютор"],
    "коаксиальность": ["соосность"],
    "коаксиальный": ["соосный"],
    "коактор": ["замыкающий"],
    "коала": ["сумчатый медведь"],
    "коалесценция": ["слияние"],
    "коалесцировав": ["коалесцировавши"],
    "коалесцировавши": ["коалесцировав"],
    "коалировав": ["коалировавши"],
    "коалировавши": ["коалировав"],
    "коалиха": ["самка", "коала"],
    "коалиционер": ["союзник", "соратник"],
    "коалиционно": ["союзнически"],
    "коалиционный": ["союзный"],
    "коалиция": ["союз", "альянс", "объединение", "группировка"],
    "коалёнок": ["детёныш", "коала"],
    "коан": ["гунъань"],
    "коарктация": ["стеноз"],
    "коата": ["обезьяна-паук", "паукообразная обезьяна"],
    "коафьор": ["фризьор", "бръснар", "бербер"],
    "коацервация": ["расслоение"],
    "кобаламин": ["внешний фактор касла"],
    "кобальт": ["станнат"],
    "кобальтиак": ["кобальтамин"],
    "кобальтин": ["кобальтовый блеск"],
    "кобальтовый": ["кобальтосодержащий"],
    "кобальтоцен": ["бис-циклопентадиенил кобальт"],
    "кобамамид": ["аденозилкобаламин"],
    "кобарга": ["кабарга"],
    "кобел": ["кобёл", "кобловка", "лесба", "лесбуха"],
    "кобелиный": ["псовый"],
    "кобелировав": ["кобелировавши"],
    "кобелировавши": ["кобелировав"],
    "кобелировать": ["котовать", "развратничать", "распутствовать", "распутничать"],
    "кобель": ["пёс", "плейбой", "повеса", "волокита", "бабник", "соблазнитель"],
    "кобеляж": ["распутство"],
    "кобелёк": ["щенок", "самец"],
    "кобениться": ["кобяниться", "ломаться", "упрямиться", "упорствовать", "упираться", "сопротивляться", "своенравничать", "кривляться", "выделываться"],
    "кобеняк": ["плащ"],
    "кобзарь": ["бандурист"],
    "кобздун": ["кабздун", "кобздон", "кабздон"],
    "кобина": ["чашм"],
    "кобра": ["очковый", "змея", "кобра пугачёва"],
    "кобрендинг": ["кобейджинг"],
    "кобровидный": ["коброобразный", "коброподобный"],
    "коброобразный": ["кобровидный", "коброподобный"],
    "коброподобный": ["кобровидный", "коброобразный"],
    "кобудо": ["кобу-дзюцу"],
    "кобчик": ["кобец"],
    "кобыз": ["кыл-кобыз"],
    "кобыла": ["лошадь", "конь", "жеребец", "корова", "мымра", "чувырла"],
    "кобылий сын": ["жеребец", "проходимец", "мерзавец", "подлец", "сволочь", "стервец", "гад", "гада", "гадина", "сукин сын", "блядин сын"],
    "кобылица": ["кобыла"],
    "кобылка": ["жеребёнок", "трудяга"],
    "ков": ["умысел"],
    "ков няи сельмоце": ["коза няи сельмоце"],
    "ковав": ["ковавши"],
    "ковавши": ["ковав"],
    "коваль": ["кузнец", "ковач", "ковец"],
    "кование": ["ковка"],
    "кованость": ["чёткость", "чеканность"],
    "кованый": ["окованный", "подкованный", "чёткий", "чеканный"],
    "кованье": ["кование"],
    "ковариантно": ["когредиентно"],
    "ковариантность": ["ковариация", "когредиентность"],
    "ковариантный": ["когредиентный"],
    "коварно": ["вероломно"],
    "коварность": ["коварство", "вероломность"],
    "коварный": ["обманчивый"],
    "коварный альбион": ["великобритания", "англия", "англичанка"],
    "коварство": ["коварность", "хитрость", "вероломство", "подстава"],
    "кователь": ["кузнец", "коваль", "ковач"],
    "ковать": ["подковывать", "готовить", "заковывать"],
    "коваться": ["подковываться", "готовиться"],
    "ковбой": ["мужлан", "сорвиголова", "ястреб"],
    "ковбойка": ["ковбойский", "шляпа"],
    "ковбойская шляпа": ["стетсон"],
    "ковбойство": ["лихость", "дерзость"],
    "ковда": ["ковды", "когда", "когды", "колды", "иногда"],
    "ковды": ["ковда", "когда", "когды", "колды"],
    "ковелец": ["ковельчанин"],
    "ковельчанин": ["ковелец"],
    "коверкав": ["коверкавши"],
    "коверкавши": ["коверкав"],
    "коверкание": ["искажение", "переиначивание", "порча"],
    "коверкать": ["искажать", "уродовать", "лихорадить", "корёжить"],
    "коверкаться": ["искажаться", "портиться", "ломаться", "уродоваться", "кривляться"],
    "ковид": ["ковид-инфекция", "коронавирус", "корона", "ковидла", "коронавир", "барановирус", "ковидарий", "ковид-госпиталь", "ковидник"],
    "ковид-": ["корона-"],
    "ковид-больница": ["ковидарий", "ковид-госпиталь", "ковид-клиника", "ковидник", "ковидница", "ковид-стационар", "ковид-центр", "коронагоспиталь"],
    "ковид-больной": ["ковидник", "коронавирусник"],
    "ковид-госпиталь": ["ковидарий", "ковид-больница", "ковид-клиника", "ковидник", "ковидница", "ковид-стационар", "ковид-центр", "коронагоспиталь"],
    "ковид-диссидент": ["антиковидник", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковид-диссидентство": ["ковид-нигилизм"],
    "ковид-заражённый": ["ковид-инфицированный", "ковид-позитивный", "ковид-положительный", "коронапозитивный"],
    "ковид-инфекция": ["ковид", "коронавирус", "корона", "ковидла", "коронавир", "барановирус"],
    "ковид-инфицированный": ["ковид-заражённый", "ковид-позитивный", "ковид-положительный", "коронапозитивный"],
    "ковид-клиника": ["ковидарий", "ковид-больница", "ковид-госпиталь", "ковидник", "ковидница", "ковид-стационар", "ковид-центр", "коронагоспиталь"],
    "ковид-кризис": ["ковидокризис", "коронакризис"],
    "ковид-нигилизм": ["ковид-диссидентство"],
    "ковид-нигилист": ["антиковидник", "ковид-диссидент", "ковидиот", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковид-отрицатель": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковид-паспорт": ["коронапаспорт"],
    "ковид-пациент": ["коронапациент"],
    "ковид-позитивный": ["ковид-заражённый", "ковид-инфицированный", "ковид-положительный", "коронапозитивный"],
    "ковид-положительный": ["ковид-заражённый", "ковид-инфицированный", "ковид-позитивный", "коронапозитивный"],
    "ковид-сертификат": ["ковид-паспорт", "коронапаспорт"],
    "ковид-скептик": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "коронадиссидент", "коронаскептик"],
    "ковид-стационар": ["ковидарий", "ковид-больница", "ковид-госпиталь", "ковид-клиника", "ковидник", "ковидница", "ковид-центр", "коронагоспиталь"],
    "ковид-тест": ["коронатест"],
    "ковид-центр": ["ковидарий", "ковид-больница", "ковид-госпиталь", "ковид-клиника", "ковидник", "ковидница", "ковид-стационар", "коронагоспиталь"],
    "ковидарий": ["ковид-больница", "ковид-госпиталь", "ковид-клиника", "ковидник", "ковидница", "ковид-стационар", "ковид-центр", "коронагоспиталь"],
    "ковидиот": ["антиковидник", "ковид-диссидент", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковидла": ["ковид", "коронавирус", "корона", "коронавир", "барановирус"],
    "ковидник": ["ковид-больной", "коронавирусник"],
    "ковидный": ["ковидовский", "коронавирусный"],
    "ковидобесие": ["коронабесие", "коронаистерия", "коронапаника", "коронапсихоз"],
    "ковидовский": ["ковидный", "коронавирусный"],
    "ковидодиссидент": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковидокризис": ["ковид-кризис", "коронакризис"],
    "ковидоскептик": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковид-отрицатель", "ковид-скептик", "коронадиссидент", "коронаскептик"],
    "ковила": ["ковил"],
    "ковка": ["кование"],
    "ковкий": ["пластичный"],
    "ковкость": ["пластичность"],
    "ковол": ["туця"],
    "ковочный": ["кузнечный"],
    "коврига": ["каравай"],
    "коврижка": ["пряник", "плюшка"],
    "ковровидный": ["коврообразный", "ковроподобный"],
    "ковровщик": ["ковродел"],
    "ковровщица": ["ковроткачиха"],
    "ковровый": ["сплошной", "пёстрый"],
    "ковродел": ["ковроткач"],
    "ковроделие": ["ковроткачество"],
    "ковроделка": ["ковроткачиха"],
    "коврообразный": ["ковровидный", "ковроподобный"],
    "ковроподобный": ["ковровидный", "коврообразный"],
    "ковроткач": ["ковродел"],
    "ковроткачество": ["ковроделие"],
    "ковроткачиха": ["ковроделка"],
    "ковтання": ["глитання"],
    "ковтати": ["бити", "стукати"],
    "ковчег": ["артофор", "шкаф", "святость", "убежище", "пристанище"],
    "ковчежец": ["рака", "энколпий"],
    "ковш": ["черпак"],
    "ковшевидность": ["ковшеобразность"],
    "ковшевидный": ["ковшеобразный", "ковшеподобный"],
    "ковшеобразность": ["ковшевидность"],
    "ковшеобразный": ["ковшевидный", "ковшеподобный"],
    "ковшеподобный": ["ковшевидный", "ковшеобразный"],
    "ковы": ["злоумышления", "интрига", "заговор", "каверзы", "козни", "происки", "умысел"],
    "ковылий": ["ковыльный"],
    "ковылистый": ["ковыльный"],
    "ковыль": ["ковыль-трава", "кувырк-трава", "тун-трава", "катун-трава"],
    "ковылье": ["ковыльё"],
    "ковыльник": ["степной", "заяц"],
    "ковыльнув": ["ковыльнувши"],
    "ковыльнувши": ["ковыльнув"],
    "ковыльё": ["ковылье"],
    "ковыляв": ["ковылявши"],
    "ковылявши": ["ковыляв"],
    "ковыляние": ["прихрамывание"],
    "ковылянье": ["ковыляние"],
    "ковылять": ["прихрамывать"],
    "ковырнув": ["ковырнувши"],
    "ковырнувши": ["ковырнув"],
    "ковырнуть": ["колупнуть", "взломать"],
    "ковыряв": ["ковырявши"],
    "ковырявши": ["ковыряв"],
    "ковырялка": ["копалка", "палка-копалка", "копорулька", "картофелекопалка"],
    "ковыряльник": ["клинок"],
    "ковыряние": ["копание"],
    "ковырянье": ["ковыряние"],
    "ковырять": ["копать", "рыть", "колупать", "ковыряться", "копаться"],
    "ковыряться": ["копаться", "рыться", "ковырять", "возиться"],
    "ковёр-самолёт": ["волшебный", "ковёр"],
    "когазин": ["синтетический", "бензин"],
    "когда рак на горе свистнет": ["когда рак свистнет", "после дождичка в четверг"],
    "когда рак свистнет": ["когда рак на горе свистнет", "после дождичка в четверг"],
    "когда-либо": ["когда-нибудь"],
    "когда-нибудь": ["когда-либо"],
    "когда-то": ["некогда", "когда-нибудь"],
    "когды": ["когда", "ковда", "ковды", "колды"],
    "когезия": ["сцепление", "связность"],
    "коген": ["коэн", "кохен"],
    "когенит": ["цементит"],
    "когерентность": ["взаимосвязь", "связность"],
    "когерентный": ["сопряжённый", "взаимосвязанный"],
    "когерировав": ["когерировавши"],
    "когерировавши": ["когерировав"],
    "когерирование": ["самосогласование", "взаимозависимость"],
    "когерировать": ["согласовываться", "взаимно", "зависеть"],
    "когипоним": ["согипоним"],
    "когия": ["карликовый", "кашалот"],
    "когнация": ["билатеральный", "родство"],
    "когнитивная наука": ["когнитивистика", "когнитология"],
    "когнитивный": ["познаваемый", "интеллектуальный", "познавательный"],
    "когнитивный диссонанс": ["разрыв шаблона"],
    "когнитология": ["когнитивная наука"],
    "когниция": ["идентификация", "познание"],
    "кого ебёт чужое горе": ["кого ебёт чужая вошь", "кого ебёт чужая жизнь"],
    "когорта": ["плеяда"],
    "когортатив": ["адхортатив"],
    "коготь": ["ноготь", "руки"],
    "когредиентно": ["ковариантно"],
    "когредиентность": ["ковариантность"],
    "когредиентный": ["ковариантный"],
    "когтевидно": ["когтеобразно"],
    "когтевидный": ["когтеобразный"],
    "когтедралка": ["когтеточка", "когтеточилка", "царапалка", "дралка"],
    "когтеносец": ["гименохирус"],
    "когтеобразно": ["когтевидно"],
    "когтеобразный": ["когтевидный"],
    "когтеточилка": ["когтеточка", "когтедралка", "царапалка", "дралка"],
    "когтеточка": ["когтеточилка", "когтедралка", "царапалка", "дралка"],
    "когтив": ["когтивши"],
    "когтивши": ["когтив"],
    "когут": ["тетерук", "тетерюк", "тетеря"],
    "когъень": ["когъэн"],
    "когъэн": ["когъень"],
    "код": ["система", "знак", "шифр", "комбинация", "пароль", "программа", "исходный текст"],
    "кода афоль уле": ["кода тяза уле"],
    "кода тяза уле": ["кода афоль уле"],
    "кодагу": ["кург"],
    "кодама-бъди": ["кати-кодама"],
    "кодамовок": ["кодама-кодама"],
    "кодегидраза": ["никотинамидадениндинуклеотидфосфат", "надф", "козимаза"],
    "кодеинизм": ["кодеиномания"],
    "кодеиномания": ["кодеинизм"],
    "кодеиносодержащий": ["кодеинсодержащий"],
    "кодель": ["вестан"],
    "коджаэли": ["вифиния"],
    "кодив": ["кодивши"],
    "кодивши": ["кодив"],
    "кодиеум": ["кротон"],
    "кодировав": ["кодировавши"],
    "кодировавши": ["кодировав"],
    "кодирование": ["кодировка"],
    "кодировка": ["кодирование"],
    "кодировщик": ["шифровальщик", "программист"],
    "кодификационный": ["законотворческий"],
    "кодифицировав": ["кодифицировавши"],
    "кодифицировавши": ["кодифицировав"],
    "кодифицировать": ["систематизировать"],
    "кодифицироваться": ["систематизироваться"],
    "кодла": ["ватага", "шобла", "кодло", "котло", "кодляк"],
    "кодоимпульсный": ["кодо-импульсный"],
    "кодоловий": ["канатний", "линвовий"],
    "кодон": ["кодирующий тринуклеотид", "триплет"],
    "кодоскоп": ["графопроектор", "оверхед-проектор"],
    "кодрант": ["квадтранс"],
    "кодьяк": ["кадьяк"],
    "кое-где": ["местами", "где-то"],
    "кое-как": ["небрежно", "тяп-ляп", "едва", "еле"],
    "кое-какер": ["халтурщик"],
    "кое-какой": ["какой-то", "некоторый"],
    "кое-когда": ["иногда", "изредка", "порой", "время от времени", "кой-когда"],
    "кое-кто": ["кто-то", "некто", "некоторый"],
    "кое-куда": ["кой-куда", "куда-либо", "куда-нибудь"],
    "кое-откуда": ["кой-откуда"],
    "кое-чей": ["чей-то"],
    "кое-что": ["что-то", "нечто"],
    "коечка": ["кроватка"],
    "кожа": ["кожзаменитель", "кожица", "кожура"],
    "кожа да кости": ["кости да кожа"],
    "кожанка": ["кожан"],
    "кожановит": ["карнасуртит"],
    "кожвендиспансер": ["кожно-венерологический диспансер", "квд", "лохматкин лазарет"],
    "кожевенник": ["кожевник", "скорняк", "кожемяка"],
    "кожевенница": ["кожевница"],
    "кожевник": ["кожевенник", "скорняк"],
    "кожевничав": ["кожевничавши"],
    "кожевничавши": ["кожевничав"],
    "кожезаменитель": ["искусственная кожа", "кожезам", "кожзам"],
    "кожемяка": ["кожевенник", "кожевник"],
    "кожеток": ["коженка", "седло"],
    "кожзам": ["кожезаменитель"],
    "кожзаменитель": ["кожимит", "кожзам", "кожезаменитель"],
    "кожикоде": ["каликут", "каликат"],
    "кожилиться": ["надрываться", "усердствовать"],
    "кожимит": ["кожзаменитель", "кожзам"],
    "кожистая черепаха": ["лут"],
    "кожистокрылые": ["уховёртка"],
    "кожица": ["эпидермис", "кожура", "плёнка"],
    "кожний": ["кождий"],
    "кожник": ["дерматолог"],
    "кожодер": ["грабител", "експлоататор"],
    "кожоюндук": ["экономика"],
    "кожура": ["кожица", "короста"],
    "кожух": ["тулуп", "футляр"],
    "кожухар": ["кожушник"],
    "кожуховый": ["тулупный"],
    "коз": ["къоз"],
    "коза": ["яманка", "яманушка", "иманка", "иманушка"],
    "коза няи сельмоце": ["ков няи сельмоце"],
    "козак": ["казак"],
    "козалит": ["бьелкит", "биелкит"],
    "козан": ["бабка"],
    "козаны": ["бабки"],
    "козелец": ["козельчанин"],
    "козелок": ["трагус", "козлик", "пессулюс"],
    "козельчанин": ["козелец"],
    "козерог": ["горный", "козёл", "альпийский"],
    "козиковец": ["козичанин"],
    "козиковка": ["козичанка"],
    "козимаза": ["никотинамидадениндинуклеотид", "над"],
    "козинак": ["козинаки"],
    "козичанин": ["козиковец"],
    "козичанка": ["козиковка"],
    "козление": ["козёл"],
    "козлец": ["трагус"],
    "козлив": ["козливши"],
    "козливши": ["козлив"],
    "козлик": ["газик"],
    "козлить": ["порочить", "хулить", "фальшивить", "списывать", "передирать"],
    "козлобородник": ["овсяный корень", "овсяной корень", "козья бородка", "козлова бородка"],
    "козловист": ["козлист"],
    "козловистка": ["козлистка"],
    "козлогласие": ["козлогласование"],
    "козлогласно": ["диссонантно"],
    "козлогласный": ["диссонантный"],
    "козлогласование": ["козлогласие"],
    "козлодой": ["козёл"],
    "козлодрание": ["кок-бору", "бузкаши", "купкари", "кокпар"],
    "козлодранье": ["козлодрание"],
    "козлы": ["облучок", "рогатки"],
    "козляк": ["решетник", "болотовик", "коровяк", "коровий гриб"],
    "козлятник": ["галега", "доминошник"],
    "козлячий": ["козлиний", "цапиний"],
    "козны": ["бабки"],
    "козный": ["смешной", "весёлый", "шкодный"],
    "кознь": ["происки"],
    "козобородка": ["барабуля"],
    "козодой": ["обыкновенный козодой"],
    "козон": ["мосёл"],
    "козуб": ["козубень", "козубенька"],
    "козубня": ["козуб", "козубень"],
    "козулий": ["косулий"],
    "козульник": ["дороникум"],
    "козуля": ["дикая коза", "козюля", "косуля"],
    "козулятина": ["косулятина"],
    "козырной": ["козырный", "занимающий", "первое", "место", "отличный", "хороший", "лучший", "наилучший"],
    "козырнув": ["козырнувши"],
    "козырнувши": ["козырнув"],
    "козырнуть": ["откозырять", "похвастаться"],
    "козырные голуби": ["турман"],
    "козырный": ["козырной", "занимающий", "первое", "место", "отличный", "хороший", "лучший", "наилучший"],
    "козыряв": ["козырявши"],
    "козырявши": ["козыряв"],
    "козырянье": ["козыряние"],
    "козырять": ["откозыривать", "хвастаться", "бахвалиться"],
    "козюля": ["сохатый", "лось", "козюлька"],
    "козявка": ["жучок", "букашка", "кузака"],
    "козявочка": ["жучок", "букашка", "крошка"],
    "козёл": ["козлина", "баран", "сволочь", "гад", "урод", "гимнастический козёл", "настыль", "козлик", "газик", "домино"],
    "козёл отпущения": ["крайний", "стрелочник"],
    "коикс": ["бусенник", "иовлевы слёзы"],
    "коинцидентный": ["синхронный"],
    "коипу": ["нутрия", "болотный", "бобр"],
    "коитальный": ["копуляционный", "копулятивный"],
    "коитофоб": ["миксофоб"],
    "коитофобия": ["миксофобия"],
    "коитофобка": ["миксофобка"],
    "кой": ["какой", "который"],
    "кой-какой": ["кое-какой"],
    "кой-когда": ["кое-когда", "иногда", "изредка", "порой", "время от времени"],
    "кой-кона": ["кона-кона"],
    "кой-кто": ["кое-кто"],
    "кой-куда": ["кое-куда", "куда-либо", "куда-нибудь"],
    "койка": ["гамак", "койко-место"],
    "койко-место": ["койка"],
    "койлав": ["койлавши"],
    "койлавши": ["койлав"],
    "койлель": ["колель"],
    "койлонихия": ["ноготь", "ложкообразный"],
    "койнэ": ["арго", "жаргон", "идиолект", "сленг", "социолект"],
    "койол": ["акрокомия"],
    "койот": ["луговой", "волк"],
    "койр": ["кокосовая койра"],
    "койсанский": ["капоидный", "бушменский"],
    "кока": ["кокаиновый куст", "кока-кола", "кокаин", "кокс"],
    "кока с соком": ["богатство", "достаток", "средства", "хитрец", "проныра", "ловкач"],
    "кокав": ["кокавши"],
    "кокавши": ["кокав"],
    "кокаинизм": ["кокаиномания"],
    "кокаинист": ["кокаиноман", "кокаинщик"],
    "кокаинистка": ["кокаиноманка", "кокаинщица"],
    "кокаиноман": ["кокаинист", "кокаинщик"],
    "кокаиномания": ["кокаинизм"],
    "кокаиноманка": ["кокаинистка", "кокаинщица"],
    "кокаинщик": ["кокаиноман", "кокаинист"],
    "кокаинщица": ["кокаиноманка", "кокаинистка"],
    "кокако": ["новозеландский", "скворец"],
    "кокарбоксилаза": ["тиаминпирофосфат"],
    "кокардный": ["кокардовый"],
    "кокардовый": ["кокардный"],
    "кокать": ["разбивать", "убивать", "приканчивать", "мочить", "токовать", "кудахтать"],
    "кокаться": ["раскалываться"],
    "кокетливо": ["игриво"],
    "кокетливый": ["жеманный", "жантильный", "нарядный"],
    "кокетничав": ["кокетничавши"],
    "кокетничавши": ["кокетничав"],
    "кокетничание": ["козыряние"],
    "кокетничанье": ["кокетничание"],
    "кокетничать": ["рисоваться"],
    "кокетство": ["кокетливость", "флирт"],
    "кокетствовав": ["кокетствовавши"],
    "кокетствовавши": ["кокетствовав"],
    "кокильное литьё": ["литьё", "кокиль"],
    "кокимбит": ["блейкит"],
    "кокичка": ["костилка", "семка"],
    "коккаарак": ["кокай"],
    "коккер": ["коккер спаниель"],
    "кокковидный": ["коккообразный", "коккоподобный"],
    "кокколоба": ["морской виноград"],
    "коккообразный": ["кокковидный", "коккоподобный"],
    "коккоподобный": ["кокковидный", "коккообразный"],
    "коккулюс": ["анамирта"],
    "кокнар": ["кукнар", "кухнар", "кукиш", "ханка"],
    "кокнув": ["кокнувши"],
    "кокнувши": ["кокнув"],
    "кокнуть": ["разбить", "раскокать", "расколоть", "пришить", "замочить", "грохнуть", "прикончить", "убить"],
    "кокнуться": ["расколоться"],
    "коко": ["кокушко"],
    "кокоев": ["кокойты"],
    "кокойты": ["кокоев"],
    "коконировав": ["коконировавши"],
    "коконировавши": ["коконировав"],
    "коконировать": ["коконироваться"],
    "коконироваться": ["коконировать"],
    "коконный сдир": ["фризон"],
    "кокономотальная машина": ["кокономотальный станок"],
    "кокономотальный станок": ["кокономотальная машина"],
    "коконообразный": ["коконоподобный"],
    "коконоподобный": ["коконообразный"],
    "кокора": ["лепёшка"],
    "кокорник": ["финовник"],
    "кокорыш": ["собачья петрушка"],
    "кокос": ["кокосовая пальма", "кокосовый орех"],
    "кокосовая пальма": ["кокос", "литокариум"],
    "кокосовый орех": ["кокос"],
    "кокосы": ["яичко", "ятро", "тестис", "тестикул", "семенник", "яйцо", "фаберже", "коко", "кокушко", "муди", "мудо", "мудья", "коконы", "коканки", "коконьки"],
    "кокотав": ["кокотавши"],
    "кокотавши": ["кокотав"],
    "кокотка": ["куртизанка"],
    "кокпар": ["купкари", "козлодрание", "бузкаши", "кок-бору"],
    "кокпит": ["рубка", "кабина"],
    "коксальный": ["тазиковый"],
    "коксиелла": ["возбудитель", "коксиеллёз"],
    "коксиеллёз": ["грипп балканский", "болезнь деррика", "болезнь деррика-бернета"],
    "коксовав": ["коксовавши"],
    "коксовавши": ["коксовав"],
    "коктебелец": ["коктебельчанин"],
    "коктебелка": ["коктебельчанка"],
    "коктебель": ["планерское"],
    "коктебельчанин": ["коктебелец"],
    "коктебельчанка": ["коктебелка"],
    "коктейлевый": ["коктейльный"],
    "коктейлив": ["коктейливши"],
    "коктейливши": ["коктейлив"],
    "коктейлик": ["коктейль"],
    "коктейль": ["смесь", "мешанина"],
    "коктейль молотова": ["бандера-смузи"],
    "коктейльный": ["коктейлевый"],
    "кокушко": ["яичко", "кока", "коко", "кокочка", "коконька", "коконюшка"],
    "кокушник": ["гимнадения"],
    "кокцигодиния": ["анокопчиковый", "болевой", "синдром"],
    "кокцидиоз": ["кокцидоз"],
    "кокцидиоидоз": ["кокцидиоидомикоз", "калифорнийская лихорадка"],
    "кокцидиоидомикоз": ["кокцидиоидоз", "калифорнийская лихорадка", "лихорадка долин"],
    "кокцидоз": ["изоспориаз"],
    "кокцинеллида": ["божья коровка"],
    "кокчетавец": ["кокшетауец"],
    "кокчетавка": ["кокшетаука"],
    "кокшаровит": ["эденит"],
    "кокшетаусец": ["кокчетавец"],
    "кокшетауска": ["кокчетавка"],
    "кол-центр": ["справочная служба"],
    "коламин": ["моноэтаноламин"],
    "колатитуда": ["зенитный", "расстояние"],
    "колачивав": ["колачивавши"],
    "колачивавши": ["колачивав"],
    "колачка": ["касапка"],
    "колба": ["колбочка"],
    "колбаса": ["колбаска", "колбасонька", "колбасочка", "колбасина", "колбасища", "колбасище", "колбасяра"],
    "колбасив": ["колбасивши"],
    "колбасивши": ["колбасив"],
    "колбасина": ["колбасища", "колбасище", "колбасяра"],
    "колбасить": ["плющить"],
    "колбасник": ["фриц", "ганс", "ганц", "немчура", "фашист"],
    "колбень": ["бычок", "колючка", "костюшка"],
    "колбец": ["кольбац", "кольбец"],
    "колбнещука": ["морская уточка"],
    "колбовидно": ["колбообразно"],
    "колбовидный": ["колбообразный"],
    "колбообразно": ["колбовидно"],
    "колбообразный": ["колбовидный"],
    "колга": ["кувалма", "ланга"],
    "колгосп": ["колективне господарство"],
    "колгота": ["колготня", "суета", "беспокойство", "хлопоты"],
    "колготив": ["колготивши"],
    "колготивши": ["колготив"],
    "колготить": ["беспокоить", "будоражить", "теребить"],
    "колготиться": ["суетиться", "хлопотать"],
    "колготно": ["беспокойно", "суетливо"],
    "колготной": ["беспокойный", "вздорный", "суетливый", "непоседливый"],
    "колготня": ["колгота", "суета", "беспокойство", "хлопоты"],
    "колдобина": ["выбоина", "рытвина", "ухаб"],
    "колдовав": ["колдовавши"],
    "колдовавши": ["колдовав"],
    "колдовать": ["ворожить", "шаманить"],
    "колдовской": ["магический", "чародейский"],
    "колдовство": ["магия", "ворожба", "волшебство", "ведовство", "чародейство"],
    "колдоёбина": ["выбоина", "рытвина", "ухаб", "колдобина", "выебина"],
    "колдун": ["волшебник", "маг", "чародей", "знатник"],
    "колдунья": ["волшебница", "ворожея", "чародейка", "ведьма"],
    "колдырив": ["колдыривши"],
    "колдыривши": ["колдырив"],
    "колдырить": ["выпрашивать", "клянчить"],
    "колебав": ["колебавши"],
    "колебавши": ["колебав"],
    "колебание": ["неустойчивость", "изменчивость", "нерешительность"],
    "колебанье": ["колебание"],
    "колебательный": ["осцилятивный"],
    "колебать": ["расшатывать", "подрывать"],
    "колебаться": ["качаться", "сомневаться", "меняться"],
    "колебнув": ["колебнувши"],
    "колебнувши": ["колебнув"],
    "колев": ["колевши"],
    "колевши": ["колев"],
    "коленвал": ["коленчатый вал"],
    "коленка": ["колено"],
    "коленкор": ["дело", "ситуация", "ситуёвина", "переплёт"],
    "колено": ["коленка", "изгиб", "коленце", "фигура", "выходка", "номер", "фортель", "художества", "штука", "штучка", "эскапада", "поколение", "триба"],
    "коленопреклонение": ["коленопреклоненье"],
    "коленопреклоненье": ["коленопреклонение"],
    "коленце": ["колено"],
    "коленчатоногое": ["морской паук"],
    "коленчатый вал": ["коленвал"],
    "колеоидея": ["двужаберный"],
    "колеоникс": ["земляной", "геккон"],
    "колеоптер": ["кольцеплан"],
    "колеоптиле": ["колеоптиль", "влагалищный лист"],
    "колеоптиль": ["влагалищный лист"],
    "колеориза": ["корневой", "влагалище"],
    "колер": ["цвет", "окраска", "оттенок", "расцветка"],
    "колеровав": ["колеровавши"],
    "колеровавши": ["колеровав"],
    "колеровать": ["окрашивать", "окрасить", "расцвечивать", "расцветить"],
    "колерябия": ["кольраби"],
    "колесив": ["колесивши"],
    "колесивши": ["колесив"],
    "колесить": ["разъезжать"],
    "колесница": ["волчеягодник обыкновенный"],
    "колесничий": ["возничий"],
    "колесо": ["круг", "автомобиль", "ролик"],
    "колесо обозрения": ["чёртово колесо"],
    "колесо фортуны": ["колесо счастья"],
    "колесовав": ["колесовавши"],
    "колесовавши": ["колесовав"],
    "колесованье": ["колесование"],
    "колестипол": ["холестипол"],
    "колесцо": ["колёсико"],
    "колечко": ["колечушко"],
    "колея": ["борозда", "рутина"],
    "коли": ["коль", "если", "раз", "когда"],
    "коли-индекс": ["индекс", "кишечная палочка"],
    "коли-инфекция": ["эшерихиоз"],
    "коли-титр": ["титр", "кишечная палочка"],
    "колиба": ["шатра", "хижа", "барака", "бордей", "къщурка"],
    "колибактериальный": ["колибациллярный"],
    "колибактериоз": ["колибациллёз"],
    "колибактерия": ["кишечная палочка", "колибацилла"],
    "колибацилла": ["кишечная палочка", "колибактерия"],
    "колибациллярный": ["колибактериальный"],
    "колибациллёз": ["колибактериоз"],
    "коливинг": ["коммуналка"],
    "коливо": ["канун", "кутья"],
    "колидор": ["коридор"],
    "колика": ["боль", "колотьё", "резь"],
    "коликий": ["сколький", "какой", "который"],
    "колико": ["елико"],
    "колировав": ["колировавши"],
    "колировавши": ["колировав"],
    "колистин": ["полимиксин"],
    "колициногения": ["колициногенность"],
    "колициногенность": ["колициногения"],
    "количественно": ["численно"],
    "количественное наречие": ["наречие степени", "наречие меры"],
    "количественный": ["численный", "счётный"],
    "количество": ["мера", "число"],
    "колка": ["раскалывание"],
    "колката": ["калькутта"],
    "колкий": ["колоться", "язвительный"],
    "колко": ["колюче", "язвительно"],
    "колковый механизм": ["колк", "колка"],
    "колкость": ["язвительность", "шпилька"],
    "колкотар": ["железный сурик", "ювелирный красный"],
    "коллаб": ["коллаборация"],
    "коллаборант": ["коллаборационист"],
    "коллаборативный": ["совместный"],
    "коллаборационизм": ["предательство", "измена"],
    "коллаборационист": ["изменник", "предатель"],
    "коллаборационистка": ["предательница", "изменница"],
    "коллаборационистский": ["предательский", "изменнический"],
    "коллаборация": ["кооперация", "сотрудничество"],
    "коллаборировав": ["коллаборировавши"],
    "коллаборировавши": ["коллаборировав"],
    "коллаген": ["гликопротеин"],
    "коллагенный": ["коллагеновый"],
    "коллагеновый": ["коллагенный"],
    "коллаж": ["аппликация"],
    "коллажность": ["мозаичность"],
    "коллажный": ["мозаичный"],
    "коллайдер": ["хитбокс"],
    "коллапс": ["крах"],
    "коллапс лёгкого": ["компрессионный ателектаз"],
    "коллапсар": ["чёрная дыра"],
    "коллапсировав": ["коллапсировавши"],
    "коллапсировавши": ["коллапсировав"],
    "коллатеральный": ["боковой", "обходной", "окольный", "сопутствующий"],
    "коллбранит": ["людвигит"],
    "коллега": ["соратник", "сослуживец", "сотоварищ", "сотрудник"],
    "коллегиально": ["коллективно", "сообща"],
    "коллегиальный": ["коллективный"],
    "коллегия": ["юридическое лицо", "министерство", "профсоюз"],
    "коллектив": ["команда"],
    "коллектив интенсивного труда": ["кит"],
    "коллективизировав": ["коллективизировавши"],
    "коллективизировавши": ["коллективизировав"],
    "коллективизм": ["коллективность"],
    "коллективно": ["вместе", "сообща"],
    "коллективность": ["совместность", "коллективизм"],
    "коллективный": ["групповой", "общий", "общественный", "совместный"],
    "коллективный договор": ["колдоговор"],
    "коллективный запад": ["запад", "западный мир"],
    "коллектор": ["доимщик"],
    "коллекционер": ["собиратель"],
    "коллекционерка": ["собирательница"],
    "коллекционерша": ["коллекционерка"],
    "коллекционировав": ["коллекционировавши"],
    "коллекционировавши": ["коллекционировав"],
    "коллекция": ["собрание"],
    "коллембола": ["вилохвостка"],
    "коллетида": ["пчела-штукатур"],
    "коллибия": ["денежка"],
    "коллив": ["колливши"],
    "колливши": ["коллив"],
    "коллидин": ["триметилпиридин"],
    "коллидировав": ["коллидировавши"],
    "коллидировавши": ["коллидировав"],
    "коллизия": ["конфликт"],
    "колликул": ["семенной", "бугорок", "предстательная маточка"],
    "коллимация": ["юстировка", "поверка", "погрешность"],
    "коллимировав": ["коллимировавши"],
    "коллимировавши": ["коллимировав"],
    "коллинеация": ["проективное преобразование"],
    "коллинз": ["коллинс"],
    "коллинс": ["коллинз"],
    "коллировав": ["коллировавши"],
    "коллировавши": ["коллировав"],
    "коллировать": ["коллить"],
    "коллодиальный": ["коллодионный"],
    "коллодионный": ["коллодиальный"],
    "коллоид": ["коллоидная система"],
    "коллоидальный": ["коллоидный"],
    "коллоидная система": ["коллоид"],
    "коллоидный": ["коллоидальный"],
    "коллоидный раствор": ["золь"],
    "коллоидоклазис": ["коллоидоклазия", "коллоидоклазический", "шок"],
    "коллоидоклазия": ["коллоидоклазис", "коллоидоклазический", "шок"],
    "коллок": ["коллоквиум"],
    "коллокация": ["полуфразема"],
    "коллоквиализм": ["разговорное выражение"],
    "коллоквиум": ["коллок", "пресвитерия"],
    "коллоксилин": ["нитроцеллюлоза", "динитроцеллюлоза"],
    "коллоксилиновый": ["нитроцеллюлозный"],
    "коллотипия": ["фотогенное рисование", "фототипия", "артотипия", "альбертипия", "гелиотипия", "коллотип"],
    "коллофан": ["гидроксилапатит"],
    "колоб": ["шар", "сфера", "колобок"],
    "колобашка": ["колоб"],
    "колобок": ["колоб", "колобушка", "шарик"],
    "колобродив": ["колобродивши"],
    "колобродивши": ["колобродив"],
    "колобродить": ["слоняться", "околачиваться", "шуметь", "суетиться", "озорничать"],
    "колобродник": ["непоседа", "бездельник"],
    "колобродница": ["бездельница"],
    "колобус": ["толстотел", "гвереца"],
    "колобушка": ["колобок"],
    "колов": ["коловши"],
    "коловерть": ["водоворот", "коловращение", "пучина"],
    "коловрат": ["солнцеворот"],
    "коловратность": ["изменчивость", "непостоянство"],
    "коловратный": ["роторный", "изменчивый", "непостоянный"],
    "коловращав": ["коловращавши"],
    "коловращавши": ["коловращав"],
    "коловращать": ["кружить", "крутить", "вращать"],
    "коловращаться": ["кружиться", "крутиться", "вращаться"],
    "коловращение": ["круговорот"],
    "коловращенье": ["коловращение"],
    "коловши": ["колов"],
    "колодезь": ["колодец"],
    "колодец": ["колодезь", "шахта"],
    "колодка": ["колодочка", "орденская колодка", "кандалы", "наручники", "оковы", "колода"],
    "колокация": ["колокейшн"],
    "колоквинт": ["колоцинт", "горькая тыква"],
    "колоколец": ["колокольчик"],
    "колоколив": ["колоколивши"],
    "колоколивши": ["колоколив"],
    "колоколист": ["звонарь"],
    "колоколо": ["чилийский опоссум"],
    "колоколообразный": ["колоколоподобный"],
    "колоколоподобный": ["колоколообразный"],
    "колокольчик": ["колоколец", "бубенчик"],
    "коломезус": ["иглобрюх-попугайчик", "зебровый тетраодон"],
    "коломенская верста": ["верзила", "каланча", "дылда", "жердяй", "с коломенскую версту", "в коломенскую версту"],
    "коломнитин": ["коломнянин", "коломенец"],
    "коломнянин": ["коломнитин", "коломенец"],
    "коломянка": ["каламянка"],
    "коломянковый": ["коломенковый"],
    "колонизатор": ["захватчик", "угнетатель"],
    "колонизационный": ["переселенческий"],
    "колонизация": ["осваивание", "заселение", "колонизаторство"],
    "колонизировав": ["колонизировавши"],
    "колонизировавши": ["колонизировав"],
    "колонизировать": ["заселять", "осваивать", "захватывать", "порабощать"],
    "колонизироваться": ["заселяться", "осваиваться", "захватываться"],
    "колонизовав": ["колонизовавши"],
    "колонизовавши": ["колонизовав"],
    "колонизовать": ["колонизировать"],
    "колонист": ["переселенец"],
    "колонистский": ["переселенческий"],
    "колония": ["община"],
    "колонка": ["столб", "колонна"],
    "колонна": ["столб"],
    "колонок": ["сибирский", "хорь", "красик"],
    "колоноскоп": ["колонофиброскоп"],
    "колоностаз": ["копростаз"],
    "колонофиброскоп": ["колоноскоп"],
    "колонув": ["колонувши"],
    "колонувши": ["колонув"],
    "колонуть": ["стукнуть", "ударить", "расколоть"],
    "колопроктэктомия": ["проктоколэктомия"],
    "колор-индекс": ["показатель", "цвет"],
    "колорад": ["ватник"],
    "колорадец": ["колорадский жук", "колорадка"],
    "колорадка": ["колорадский жук", "колорадец"],
    "колорадский жук": ["колорадец", "колорадка", "колорад"],
    "колоратка": ["римский воротник"],
    "колоризация": ["окрашивание"],
    "колориметрия": ["цветометрия"],
    "колористика": ["цветоведение"],
    "колорит": ["своеобразие", "отпечаток"],
    "колоритно": ["ярко", "характерно", "выразительно"],
    "колоритность": ["яркость", "характерность", "выразительность"],
    "колоритный": ["яркий", "характерный", "выразительный"],
    "колороним": ["колоратив"],
    "колосовидный": ["колосообразный"],
    "колосовой": ["колосовый"],
    "колосовый": ["колосовой"],
    "колосообразный": ["колосовидный"],
    "колосоуборник": ["стриппер", "колосоуборщик"],
    "колосоуборочный": ["очёсывать"],
    "колосс": ["гигант", "титан"],
    "колосс на глиняных ногах": ["шляпа"],
    "колоссально": ["чрезвычайно"],
    "колоссальность": ["огромность", "громадность"],
    "колоссальный": ["громадный", "огромный", "большой"],
    "колоссома": ["паку", "травоядная пиранья"],
    "колостаз": ["копростаз"],
    "колотив": ["колотивши"],
    "колотивши": ["колотив"],
    "колотило": ["клепало"],
    "колотить": ["ударять", "стучать", "выбивать", "выколачивать", "бить", "избивать", "разбивать", "раскалывать", "трясти"],
    "колотиться": ["биться", "ударяться", "дрожать", "разбиваться"],
    "колотовка": ["колотушка", "пестик", "толкушка", "мутовка"],
    "колотун": ["озноб", "дрожь", "мороз", "дубак"],
    "колотушка": ["киянка", "било"],
    "колоть": ["раскалывать"],
    "колоться": ["раскалываться", "сознаваться", "признаваться"],
    "колотьё": ["колика"],
    "колофен": ["абиетен", "дитеребентил"],
    "колоцинт": ["колоквинт", "горькая тыква"],
    "колоцинтин": ["колоцинтовый", "горечь"],
    "колочение": ["выбивание", "выколачивание", "вычищение"],
    "колоченье": ["колочение"],
    "колош": ["тлинкит"],
    "колошение": ["выколашивание", "вымётывание"],
    "колошка": ["тлинкитка"],
    "колошматив": ["колошмативши"],
    "колошмативши": ["колошматив"],
    "колошматить": ["бить", "гвоздить", "дубасить", "колотить", "костылять", "лупить", "лупцевать", "молотить", "мутузить", "тузить", "утюжить"],
    "колошский": ["тлинкитский"],
    "колпак": ["простак"],
    "колпак кольчатый": ["белый приболотник", "приболотник белый", "розитес тусклый", "турок"],
    "колпаковый": ["колпачный"],
    "колпачив": ["колпачивши"],
    "колпачивши": ["колпачив"],
    "колпачить": ["околпачивать", "дурачить"],
    "колпачный": ["колпаковый"],
    "колпачок": ["диафрагма", "сморчковая шапочка"],
    "колпик": ["колпица", "теслонос"],
    "колпино": ["колпенгаген", "колпак", "колпачок", "полкино", "клопино", "колыпино", "колупино"],
    "колпица": ["колпик", "теслонос"],
    "колтан": ["колумбит-танталит", "колумбо-танталит"],
    "колтка": ["къолткъа", "колтха"],
    "колтт": ["скольт"],
    "колтун": ["трихома", "правец"],
    "колтунный": ["трихомный"],
    "колтха": ["колтка"],
    "колтыхав": ["колтыхавши"],
    "колтыхавши": ["колтыхав"],
    "колтыхнув": ["колтыхнувши"],
    "колтыхнувши": ["колтыхнув"],
    "колумбат": ["ниобат"],
    "колумбий": ["ниобий"],
    "колумбик": ["колумбус"],
    "колумбин": ["колумбиновая горечь"],
    "колумбит": ["ниобит", "байерин", "германнолит", "дианит"],
    "колумбия": ["республика колумбия", "округ колумбия"],
    "колумбо": ["ятеориза дланевидная"],
    "колумбов": ["колумбовский"],
    "колумбовский": ["колумбов"],
    "колупав": ["колупавши"],
    "колупавши": ["колупав"],
    "колупание": ["копание", "ковыряние"],
    "колупать": ["отковыривать", "отшелушивать"],
    "колупаться": ["ковырять", "возиться", "копаться"],
    "колупнув": ["колупнувши"],
    "колупнувши": ["колупнув"],
    "колупнуть": ["ковырнуть", "взломать"],
    "колх": ["колхидец", "лаз"],
    "колхида": ["колхети", "кулха", "арги", "эгриси", "айя", "эа", "колха"],
    "колхикум": ["безвременник", "зимовник"],
    "колхоз": ["коллективное хозяйство", "сельскохозяйственная артель", "толпа"],
    "колхозив": ["колхозивши"],
    "колхозивши": ["колхозив"],
    "колхозить": ["самодельничать", "собирать", "мастерить"],
    "колхозник": ["колхозан", "колхозавр", "деревенщина", "провинциал"],
    "колхозно-совхозный": ["совхозно-колхозный"],
    "колчан": ["тул", "тула", "туло", "сагайдак", "саадак", "сайдак", "сагадак"],
    "колчанник": ["лучник"],
    "колчеданный": ["колчедановый"],
    "колчедановый": ["колчеданный"],
    "колченогий": ["хромоногий", "хромой", "хромый", "шаткий"],
    "колченого": ["хромать", "прихрамывать", "неуклюже", "неловко"],
    "колченогость": ["неуклюжесть", "неловкость"],
    "колыбель": ["люлька", "родина"],
    "колыбельный": ["колыбельная песня"],
    "колымага": ["драндулет"],
    "колымец": ["колымчанин"],
    "колымчанин": ["колымец"],
    "колыхав": ["колыхавши"],
    "колыхавши": ["колыхав"],
    "колыханье": ["колыхание"],
    "колыхать": ["покачивать"],
    "колыхаться": ["покачиваться"],
    "колыхнув": ["колыхнувши"],
    "колыхнувши": ["колыхнув"],
    "колышник": ["единичник", "неуспевающий", "малоуспевающий", "слабоуспевающий"],
    "коль": ["коли", "если", "раз", "ежели"],
    "коль скоро": ["ежели", "если", "как только"],
    "кольбац": ["кольбец", "колбец"],
    "кольбец": ["кольбац", "колбец"],
    "кольеретка": ["кольретка"],
    "кольза": ["яровой рапс"],
    "колька": ["коля", "николай"],
    "кольквиция": ["кольквиция прелестная"],
    "кольматаж": ["кольматация", "кольматирование"],
    "кольматация": ["кольматаж", "кольматирование"],
    "кольматировав": ["кольматировавши"],
    "кольматировавши": ["кольматировав"],
    "кольматирование": ["кольматаж", "кольматация"],
    "кольми": ["сколь", "насколько", "в какой степени", "особенно", "значительный", "тем более что"],
    "кольнув": ["кольнувши"],
    "кольнувши": ["кольнув"],
    "кольнуть": ["уколоть", "съязвить", "поддеть"],
    "кольпит": ["вагинит", "эндокольпит"],
    "кольпография": ["вагинография", "рентгенокольпография"],
    "кольпопексия": ["вагинофиксация", "вагинопексия"],
    "кольпоперинеопластика": ["кольпоперинеорафия"],
    "кольпоперинеорафия": ["кольпоперинеопластика"],
    "кольпорафия": ["кольпоррафия"],
    "кольпоскопия": ["вагиноскопия"],
    "кольпоспазм": ["вагинизм", "вульвизм"],
    "кольпоцитодиагностика": ["метод"],
    "кольраби": ["колерябия"],
    "кольский залив": ["кольская губа", "кольский фьорд"],
    "кольский полуостров": ["мурман", "кола", "терь"],
    "кольцевав": ["кольцевавши"],
    "кольцевавши": ["кольцевав"],
    "кольцевание": ["окольцовывание", "закольцовывание"],
    "кольцевать": ["окольцовывать"],
    "кольцеваться": ["окольцовываться", "закольцовываться", "регистрироваться"],
    "кольцевидно": ["кольцеобразно"],
    "кольцевидность": ["кольцеобразность"],
    "кольцевидный": ["кольцеобразный"],
    "кольцеобразно": ["кольцевидно"],
    "кольцеобразность": ["кольцевидность"],
    "кольцеобразный": ["кольцевидный"],
    "кольцеплан": ["колеоптер"],
    "кольцо": ["корзина", "годичное кольцо"],
    "кольчатая горлица": ["горлинка"],
    "кольчатая нерпа": ["кольчатый тюлень", "акиба"],
    "кольчатый коконопряд": ["кольчатый шелкопряд", "колечник шелкопряд"],
    "кольчатый питон": ["ботрохилюс"],
    "кольчатый тюлень": ["кольчатая нерпа", "акиба"],
    "кольчатый червь": ["кольчец"],
    "кольчатый шелкопряд": ["кольчатый коконопряд"],
    "кольчец": ["кольчатый червь"],
    "кольщик": ["татуировщик"],
    "кольё": ["кол"],
    "колютея": ["пузырник"],
    "колючая проволока": ["колючка"],
    "колючесть": ["колкость", "язвительность", "саркастичность"],
    "колючехвостка": ["жемчужный ствололаз"],
    "колючий": ["колкий"],
    "колючка": ["шип", "остриё", "колючая проволока"],
    "колючковидный": ["колючкообразный"],
    "колючкообразный": ["колючковидный"],
    "колючник": ["карлина"],
    "коля": ["николай"],
    "коляда": ["кутья"],
    "колядовав": ["колядовавши"],
    "колядовавши": ["колядовав"],
    "колядованье": ["колядование"],
    "колядовать": ["христославить"],
    "колян": ["колька"],
    "коляска": ["круг", "нитка", "виток"],
    "колять": ["колоть"],
    "колёсная пара": ["ось"],
    "колёсно-шагающий": ["колёсошагающий"],
    "колёсный блокиратор": ["краб"],
    "колёсовидный": ["колёсообразный"],
    "колёсообразный": ["колёсовидный"],
    "ком": ["комок"],
    "ком в горле": ["комок в горле"],
    "кома": ["коматозное состояние"],
    "команда": ["приказ", "распоряжение", "указание", "инструкция", "руководство", "командование", "начало", "начальствование", "экипаж", "дружина", "группа", "музыкальный коллектив"],
    "командарм": ["командующий", "армия"],
    "командир": ["водила", "шофёр", "шеф", "драйвер"],
    "командировав": ["командировавши"],
    "командировавши": ["командировав"],
    "командирствовав": ["командирствовавши"],
    "командирствовавши": ["командирствовав"],
    "командная высота": ["бразды правления"],
    "командная строка": ["консоль"],
    "командная экономика": ["плановая экономика"],
    "командный": ["приказной", "командирский", "первенствовать", "господствовать"],
    "командный пункт": ["кп"],
    "командный состав": ["комсостав"],
    "командовав": ["командовавши"],
    "командовавши": ["командовав"],
    "командование": ["командный состав"],
    "командованье": ["командование"],
    "командовать": ["руководить", "распоряжаться", "приказывать"],
    "командообразование": ["тимбилдинг"],
    "командувач": ["командуючий"],
    "команч": ["немена"],
    "команчский": ["команче"],
    "комар": ["москит"],
    "комара": ["свод"],
    "комарик": ["комар", "галлица"],
    "комаринская": ["камаринская"],
    "комарит": ["коннарит"],
    "комарник": ["накомарник"],
    "комаровидный": ["комарообразный"],
    "комаровка": ["биттак"],
    "комарообразный": ["комаровидный"],
    "комарьё": ["комар", "гнус"],
    "коматоз": ["коматозное состояние"],
    "коматозное состояние": ["кома", "коматоз"],
    "комашка": ["муравей", "мураш", "мурашка"],
    "комбайнерка": ["комбайнёрша", "комбайнёрка"],
    "комбайнировав": ["комбайнировавши"],
    "комбайнировавши": ["комбайнировав"],
    "комбайнёр": ["комбайнер"],
    "комбайнёрка": ["комбайнёрша"],
    "комбайнёрша": ["комбайнерка"],
    "комбат": ["командир батальона", "командир батареи"],
    "комбатант": ["соперник", "противник", "оппонент"],
    "комбед": ["комитет бедноты"],
    "комбидрес": ["боди"],
    "комбик": ["комбо", "комбоусилитель"],
    "комбинат": ["производственный комбинат", "учкомбинат"],
    "комбинатовский": ["комбинатский"],
    "комбинатор": ["махинатор"],
    "комбинаторная математика": ["комбинаторный анализ"],
    "комбинаторный анализ": ["комбинаторная математика"],
    "комбинатский": ["комбинатовский"],
    "комбинация": ["сочетание", "схема", "план", "замысел"],
    "комбинашка": ["комбинация"],
    "комбинезон": ["комбез"],
    "комбинировав": ["комбинировавши"],
    "комбинировавши": ["комбинировав"],
    "комбинирование": ["сочетание"],
    "комбинированно": ["совместно"],
    "комбинированный": ["составной", "гибридный"],
    "комбинировать": ["сочетать", "компоновать"],
    "комбинироваться": ["сочетаться"],
    "комбо": ["комбик"],
    "комбриг": ["командир", "бригада"],
    "комбустиология": ["ожоговая медицина"],
    "комвзвода": ["взводный"],
    "комдив": ["командир", "дивизия"],
    "комедиант": ["актёр", "лицедей", "притворщик", "исполнитель"],
    "комедиантка": ["исполнительница", "актриса", "лицедейка", "притворщица"],
    "комедиантский": ["актёрский", "лицемерный"],
    "комедиантство": ["притворство", "лицедейство"],
    "комедийность": ["комичность", "водевильность"],
    "комедия": ["притворство", "лицемерие"],
    "комедия дель арте": ["комедия масок"],
    "комедия масок": ["комедия дель арте"],
    "комедокарцинома": ["рак", "угревидный"],
    "комедон": ["чёрный", "угорь"],
    "комендантствовав": ["комендантствовавши"],
    "комендантствовавши": ["комендантствовав"],
    "комендантша": ["комендант"],
    "комендач": ["комендант"],
    "комераж": ["пересуд", "сплетня"],
    "кометарная глобула": ["кометарная туманность"],
    "кометарная туманность": ["кометарная глобула"],
    "кометарный": ["кометный"],
    "кометный": ["кометарный"],
    "кометовидный": ["кометообразный", "кометоподобный"],
    "кометообразный": ["кометовидный", "кометоподобный"],
    "кометоподобный": ["кометовидный", "кометообразный"],
    "коми": ["республика коми", "рк"],
    "коми-зырянин": ["зырянин"],
    "коми-зырянка": ["зырянка"],
    "коми-зырянский": ["коми"],
    "коми-пермяцкий": ["коми"],
    "коми-пермяцкий автономный округ": ["пермяцкий национальный округ", "коми-пермяцкий национальный округ"],
    "комизм": ["юмор"],
    "комик": ["юморист", "весельчак", "шутник", "балагур", "хохмач", "хохмогон", "остряк"],
    "комик-группа": ["комик-труппа"],
    "комик-труппа": ["комик-группа"],
    "комикку": ["манга"],
    "комиковав": ["комиковавши"],
    "комиковавши": ["комиковав"],
    "комилан": ["тамоман"],
    "комильфо": ["приличный"],
    "комильфотно": ["прилично"],
    "комильфотность": ["приличность", "благоприличность", "пристойность", "благопристойность", "порядочность", "бонтонность"],
    "комильфотный": ["приличный", "благоприличный", "пристойный", "благопристойный", "порядочный", "бонтонный"],
    "комиссар": ["политрук", "военком"],
    "комиссарив": ["комиссаривши"],
    "комиссаривши": ["комиссарив"],
    "комиссарить": ["комиссарствовать"],
    "комиссарствовав": ["комиссарствовавши"],
    "комиссарствовавши": ["комиссарствовав"],
    "комиссарствовать": ["комиссарить"],
    "комиссация": ["комиссование"],
    "комиссионерство": ["посредничество"],
    "комиссионерствовав": ["комиссионерствовавши"],
    "комиссионерствовавши": ["комиссионерствовав"],
    "комиссионка": ["комиссионный магазин", "комок"],
    "комиссионный": ["вознаграждение"],
    "комиссионный магазин": ["комиссионка", "комок"],
    "комиссовав": ["комиссовавши"],
    "комиссовавши": ["комиссовав"],
    "комиссование": ["комиссация"],
    "комиссура": ["спайка"],
    "комиссуральный": ["спаечный"],
    "комит": ["комес"],
    "комита": ["въстаник", "революционер", "четник"],
    "комитат": ["графство", "область"],
    "комитатив": ["совместный падеж", "сопроводительный падеж", "социатив", "ассоциатив"],
    "комически": ["комедийно", "комично"],
    "комический": ["комедийный", "смешной", "забавный", "комичный"],
    "комично": ["смешно", "забавно"],
    "комичный": ["смешной", "забавный", "потешный"],
    "комкав": ["комкавши"],
    "комкавши": ["комкав"],
    "комкание": ["сокращение"],
    "комканье": ["комкание"],
    "комкать": ["сминать", "сокращать"],
    "комкаться": ["сминаться"],
    "комковатый": ["бугристый"],
    "комковидный": ["комкообразный"],
    "комкообразный": ["комковидный"],
    "комкор": ["командир", "корпус"],
    "комкорсак": ["ташбаш"],
    "комм": ["комментарий", "реплика", "отклик", "коммент"],
    "комма": ["саркомер", "миофибрилломер"],
    "коммандист": ["коммандитист"],
    "коммандита": ["акционерная коммандита"],
    "коммандитист": ["коммандист", "коммандитор"],
    "коммандитное товарищество": ["товарищество на вере"],
    "коммандитор": ["коммандитист"],
    "коммандос": ["спецназ"],
    "коммеморативный": ["памятный", "мемориальный"],
    "комменсал": ["сотрапезник", "нахлебник"],
    "комменсализм": ["симбиоз"],
    "комменсальный": ["симбиотический"],
    "коммент": ["комментарий", "реплика", "отклик"],
    "комментарий": ["пояснение", "примечание", "толкование", "рассуждение", "коммент"],
    "комментатор": ["диктор", "журналист"],
    "комментировав": ["комментировавши"],
    "комментировавши": ["комментировав"],
    "комментировать": ["пояснять"],
    "коммерс": ["коммерсант", "барыга"],
    "коммерсант": ["негоциант", "купец"],
    "коммерсантша": ["коммерсантка"],
    "коммерциализировав": ["коммерциализировавши"],
    "коммерциализировавши": ["коммерциализировав"],
    "коммерциализовав": ["коммерциализовавши"],
    "коммерциализовавши": ["коммерциализовав"],
    "коммерциализовать": ["коммерциализировать"],
    "коммерция": ["торговля", "жульничество", "мошенничество", "барыжничество", "барышничество", "воровство"],
    "коммерческая концессия": ["франчайзинг", "франшиза"],
    "коммерческая организация": ["фирма"],
    "коммерческая тайна": ["ноу-хау"],
    "коммерчески": ["по-коммерчески"],
    "коммерческий": ["торговый", "доходный", "деловой", "грузовой", "товарный", "дойный"],
    "комми": ["коммунист"],
    "коммивояжёр": ["торговый агент"],
    "коммивояжёрка": ["коммивояжёрша"],
    "коммивояжёрствовав": ["коммивояжёрствовавши"],
    "коммивояжёрствовавши": ["коммивояжёрствовав"],
    "коммивояжёрша": ["коммивояжёрка"],
    "коммодити": ["биржевой товар", "ширпотреб"],
    "коммодитизировав": ["коммодитизировавши"],
    "коммодитизировавши": ["коммодитизировав"],
    "коммоция": ["сотрясение мозга"],
    "коммуналка": ["коммунальная квартира"],
    "коммунальная квартира": ["коммуналка"],
    "коммунальник": ["коммунальщик"],
    "коммунальница": ["коммунальщица"],
    "коммунальное хозяйство": ["жкх", "комхоз"],
    "коммунальные услуги": ["жилищно-коммунальные услуги", "бытовое обслуживание"],
    "коммунальный": ["общинный", "муниципальный"],
    "коммунальщик": ["коммунальник"],
    "коммунальщица": ["коммунальница"],
    "коммуниздив": ["коммуниздивши"],
    "коммуниздивши": ["коммуниздив"],
    "коммуникабельность": ["общительность"],
    "коммуникабельный": ["общительный"],
    "коммуникативность": ["коммуникационность"],
    "коммуникационное устройство": ["устройство связи"],
    "коммуникационность": ["коммуникативность"],
    "коммуникационный": ["связывающий", "информационный"],
    "коммуникация": ["общение", "контакт"],
    "коммунистическая партия": ["компартия"],
    "коммунистическая партия советского союза": ["кпсс", "партия большевиков", "партия"],
    "коммунистический": ["красный"],
    "коммунистичней": ["коммунистичнее"],
    "коммунистский": ["коммунистический"],
    "коммуницировав": ["коммуницировавши"],
    "коммуницировавши": ["коммуницировав"],
    "коммуницирование": ["общение", "соединение", "присоединение"],
    "коммуницировать": ["общаться"],
    "коммуняга": ["коммуняка"],
    "коммуняка": ["коммуняга"],
    "коммутативная группа": ["абелева группа"],
    "коммутативное кольцо": ["абелево кольцо"],
    "коммутативность": ["переместительность"],
    "коммутативный": ["переместительный", "перестановочный"],
    "коммутатор": ["переключатель", "распределитель"],
    "коммутировав": ["коммутировавши"],
    "коммутировавши": ["коммутировав"],
    "коммутировать": ["переключать"],
    "комната": ["дом", "помещение"],
    "комнатка": ["каморка"],
    "комнатное растение": ["цветок"],
    "комнатуха": ["комнатёнка", "комнатёшка"],
    "комнатёшка": ["комнатуха", "комнатёнка"],
    "комо": ["бакомо", "бабира"],
    "комовой": ["комковый"],
    "комодец": ["комод"],
    "комок": ["ком"],
    "комок в горле": ["ком в горле"],
    "комолость": ["безрогость"],
    "комолый": ["безрогий"],
    "комон": ["давай", "пойти", "да ладно", "перестать"],
    "коморец": ["коморитянин"],
    "коморский": ["коморский язык"],
    "комп": ["компьютер", "эвм"],
    "компакт-диск-проигрыватель": ["компакт-проигрыватель", "сд-проигрыватель"],
    "компакт-дисковод": ["дисковод"],
    "компакт-кассета": ["аудиокассета", "кассета"],
    "компакт-проигрыватель": ["компакт-диск-проигрыватель"],
    "компакт-спортинг": ["спортинг-компакт"],
    "компактизировав": ["компактизировавши"],
    "компактизировавши": ["компактизировав"],
    "компактизировать": ["компактировать", "уменьшать", "уменьшить"],
    "компактировав": ["компактировавши"],
    "компактировавши": ["компактировав"],
    "компактирование": ["прессование", "уплотнение"],
    "компактировать": ["прессовать", "уплотнять"],
    "компактироваться": ["прессоваться", "уплотняться"],
    "компактифицировав": ["компактифицировавши"],
    "компактифицировавши": ["компактифицировав"],
    "компактность": ["малогабаритность"],
    "компактор": ["уплотнитель"],
    "компандер": ["компандерный шумоподавитель"],
    "компандерный шумоподавитель": ["компандер"],
    "компанейский": ["общительный"],
    "компанейщина": ["коллективизм"],
    "компания": ["коллектив", "группа", "фирма"],
    "компаньон": ["товарищ", "совладелец", "партнёр"],
    "компаньонский": ["партнёрский"],
    "компаньонша": ["товарка", "совладелица", "партнёрша"],
    "компаратив": ["сравнительная степень"],
    "компаративистский": ["сравнительно-исторический"],
    "компаративность": ["сравнительность"],
    "компаративный": ["сравнительный"],
    "компарировав": ["компарировавши"],
    "компарировавши": ["компарировав"],
    "компартиец": ["коммунист", "коммунистишка"],
    "компартия": ["коммунистическая партия"],
    "компас": ["матка", "маточка"],
    "компасный курс": ["кк"],
    "компатриот": ["соотечественник"],
    "компатриотка": ["соотечественница"],
    "компаунд": ["компаунд-машина", "полимерный компаунд"],
    "компаунд-машина": ["компаунд"],
    "компаундировав": ["компаундировавши"],
    "компаундировавши": ["компаундировав"],
    "компаундирование": ["компаундное возбуждение", "смешанное возбуждение"],
    "компаундировать": ["смешивать", "перемешивать"],
    "компаундироваться": ["смешиваться", "перемешиваться"],
    "компаундное возбуждение": ["компаундирование", "смешанное возбуждение"],
    "компаундный": ["смешанный", "составной"],
    "компаха": ["компашка"],
    "компашка": ["компания"],
    "компендий": ["компендиум"],
    "компендиум": ["компендий", "конспект"],
    "компенсаторный процесс": ["компенсация"],
    "компенсационный заём": ["компенсационный кредит"],
    "компенсационный кредит": ["компенсационный заём"],
    "компенсационный светофильтр": ["монохроматический светофильтр"],
    "компенсация": ["возмещение", "восполнение", "компенсаторный процесс"],
    "компенсировав": ["компенсировавши"],
    "компенсировавши": ["компенсировав"],
    "компенсирование": ["компенсация", "возмещение", "восполнение", "уравновешивание"],
    "компенсировать": ["возмещать", "восполнять", "уравновешивать"],
    "компенсироваться": ["возмещаться", "восполняться", "уравновешиваться"],
    "компенсируемость": ["возместимость"],
    "компетентно": ["квалифицированно"],
    "компетентность": ["правомочность"],
    "компетентный": ["сведущий", "правомочный"],
    "компилировав": ["компилировавши"],
    "компилировавши": ["компилировав"],
    "компилятивность": ["компиляционность"],
    "компилятивный": ["компиляционный"],
    "компиляционность": ["компилятивность"],
    "компиляционный": ["компилятивный"],
    "компиляция": ["компилирование"],
    "комплекс": ["сочетание", "совокупность", "объединение", "ансамбль", "синтез", "геологическая формация"],
    "комплекс гольджи": ["аппарат гольджи"],
    "комплексировав": ["комплексировавши"],
    "комплексировавши": ["комплексировав"],
    "комплексирование": ["сочетание", "объединение"],
    "комплексировать": ["сочетать", "объединять"],
    "комплексироваться": ["сочетаться", "объединяться"],
    "комплексное соединение": ["координационное соединение"],
    "комплексный": ["кватернион"],
    "комплексный анализ": ["тфкп"],
    "комплексовав": ["комплексовавши"],
    "комплексовавши": ["комплексовав"],
    "комплексонометрический": ["хелатометрический", "трилонометрический"],
    "комплексонометрия": ["хелатометрия", "трилонометрия"],
    "комплектация": ["комплектование", "комплектирование", "комплектовка", "комплект", "состав"],
    "комплектировав": ["комплектировавши"],
    "комплектировавши": ["комплектировав"],
    "комплектирование": ["комплектация", "комплектование", "комплектовка"],
    "комплектировать": ["комплектовать"],
    "комплектироваться": ["комплектоваться"],
    "комплектность": ["сформированность", "цельность"],
    "комплектный": ["полномерный", "укомплектованный", "комплексный", "абсолютный", "безнадежный", "законченный", "круглый", "стопроцентный", "тучный", "упитанный", "полный"],
    "комплектовав": ["комплектовавши"],
    "комплектовавши": ["комплектовав"],
    "комплектование": ["комплектация", "комплектирование", "комплектовка"],
    "комплектовать": ["комплектировать"],
    "комплектоваться": ["комплектироваться"],
    "комплектовка": ["комплектация", "комплектирование", "комплектование"],
    "комплекция": ["телосложение", "конституция"],
    "комплемент": ["алексин"],
    "комплементарий": ["комплементёр"],
    "комплементарность": ["дополнительность"],
    "компликация": ["осложнение", "запутанность"],
    "комплиментарно": ["лестно", "хвалебно"],
    "комплиментарность": ["хвалебность", "лестность"],
    "комплиментарный": ["симпатический", "любезный", "похвальный"],
    "комплот": ["заговор"],
    "композит": ["сложное слово"],
    "композитинг": ["компоузинг"],
    "композитный материал": ["композит", "композиционный материал"],
    "композитор": ["проблемист"],
    "композиторствовав": ["композиторствовавши"],
    "композиторствовавши": ["композиторствовав"],
    "композиционный материал": ["композит", "композитный материал"],
    "композиция": ["архитектоника"],
    "комполка": ["полковник"],
    "компонент": ["компонента", "элемент", "составляющая", "часть", "ингредиент"],
    "компонента": ["компонент", "составляющая"],
    "компонировав": ["компонировавши"],
    "компонировавши": ["компонировав"],
    "компонирование": ["компонование", "компоновка"],
    "компонировать": ["компоновать"],
    "компонироваться": ["компоноваться"],
    "компонист": ["композитор"],
    "компоновав": ["компоновавши"],
    "компоновавши": ["компоновав"],
    "компонование": ["компонирование", "компоновка"],
    "компоновать": ["компонировать", "собирать", "монтировать"],
    "компоноваться": ["компонироваться"],
    "компоновка": ["компонирование", "компонование"],
    "компоновщик": ["редактор связей", "линковщик"],
    "компостировав": ["компостировавши"],
    "компостировавши": ["компостировав"],
    "компрессионная барокамера": ["гипербарическая барокамера"],
    "компрессионная кривая": ["кривая сжатия"],
    "компрессионный ателектаз": ["коллапс лёгкого"],
    "компрессия": ["сжатие", "сжатие данных"],
    "компримировав": ["компримировавши"],
    "компримировавши": ["компримировав"],
    "компримирование": ["сжижение"],
    "компримировать": ["сжижать"],
    "компримироваться": ["сжижаться"],
    "компрометация": ["компрометирование"],
    "компрометировав": ["компрометировавши"],
    "компрометировавши": ["компрометировав"],
    "компрометировать": ["порочить"],
    "компромисс": ["консенсус"],
    "компутер": ["компьютер", "эвм"],
    "компьютер": ["эвм", "электронно-вычислительная машина", "комп", "машина", "айбиэмка", "калькулятор", "счётчик"],
    "компьютеризировав": ["компьютеризировавши"],
    "компьютеризировавши": ["компьютеризировав"],
    "компьютеризовав": ["компьютеризовавши"],
    "компьютеризовавши": ["компьютеризовав"],
    "компьютеризованный": ["компьютеризированный"],
    "компьютеризовать": ["компьютеризировать"],
    "компьютерная игра": ["видеоигра", "мобильная игра"],
    "компьютерная сеть": ["вычислительная сеть", "сеть передачи данных"],
    "компьютерный вирус": ["вирус"],
    "компьютероголик": ["компьютероман"],
    "компьютероман": ["компьютероголик"],
    "компьютерщик": ["айтишник"],
    "компьютерщица": ["айтишница"],
    "комроты": ["ротный"],
    "комса": ["комсомолец"],
    "комсомол": ["влксм", "комсомольцы", "ячейка"],
    "комсомолия": ["комсомолец"],
    "комсостав": ["командный состав"],
    "комсоставский": ["командирский"],
    "комфлот": ["ротный"],
    "комфорка": ["камфорка", "конфорка"],
    "комфорт": ["уют", "удобство"],
    "комфортабельность": ["удобность", "удобство", "комфортность", "уютность"],
    "комфортабельный": ["удобный", "уютный"],
    "комфортность": ["удобность", "удобство", "комфортабельность", "благоустроенность"],
    "комфортный": ["удобный", "уютный"],
    "комчванство": ["коммунистический", "чванство"],
    "комшия": ["съсед"],
    "комьюнити": ["сообщество"],
    "кон-тикси-виракоча": ["виракоча"],
    "кона аф кона": ["кона-кона"],
    "кона-кона": ["кой-кона"],
    "конваллария": ["ландыш", "сорочка", "молодило", "молодильник", "виновник"],
    "конвейер": ["транспортёр"],
    "конвейеризировав": ["конвейеризировавши"],
    "конвейеризировавши": ["конвейеризировав"],
    "конвейеризировать": ["конвейеризовать"],
    "конвейеризовав": ["конвейеризовавши"],
    "конвейеризовавши": ["конвейеризовав"],
    "конвейеризовать": ["конвейеризировать"],
    "конвекция": ["адвекция"],
    "конвенция": ["договор", "соглашение"],
    "конвергенция": ["схождение", "сближение"],
    "конвергировав": ["конвергировавши"],
    "конвергировавши": ["конвергировав"],
    "конвергировать": ["сближать", "сблизить", "сближаться", "сблизиться"],
    "конверсация": ["беседа", "разговор", "общение"],
    "конверсив": ["векторный антоним"],
    "конверсировав": ["конверсировавши"],
    "конверсировавши": ["конверсировав"],
    "конвертация": ["конверсия", "конвертирование", "перекодирование", "перекодировка"],
    "конвертировав": ["конвертировавши"],
    "конвертировавши": ["конвертировав"],
    "конвертируемость": ["конвертабельность"],
    "конвертовав": ["конвертовавши"],
    "конвертовавши": ["конвертовав"],
    "конвертор": ["преобразователь"],
    "конвоир": ["охранник", "вертухай", "дубак", "сопровождающий", "конвойный"],
    "конвоировав": ["конвоировавши"],
    "конвоировавши": ["конвоировав"],
    "конвой": ["караван", "кортеж", "обоз", "сопровождение", "эскорт", "охрана", "охранение", "стража", "конвоирование"],
    "конвойний": ["конвойник"],
    "конвойный": ["эскортный", "конвоир"],
    "конволют": ["сборник"],
    "конволюционный": ["свёрточный"],
    "конволюция": ["свёртка"],
    "конвульсивно": ["судорожно"],
    "конвульсивный": ["судорожный", "спазматический"],
    "конвульсия": ["судорога", "агония"],
    "конгениальный": ["близкий", "родственный", "похожий", "аналогичный"],
    "конгестия": ["прилив крови"],
    "конгломерат": ["концерн"],
    "конгломерация": ["объединение", "слияние", "конгломерат"],
    "конго": ["баконго", "конгорот"],
    "конголезец": ["заирец"],
    "конгревова ракета": ["ракета конгрива"],
    "конгрегационный": ["конгрегационалистский"],
    "конгресс": ["съезд", "парламент"],
    "конгрессвумен": ["конгрессменка", "конгрессменша"],
    "конгрессменка": ["конгрессвумен", "конгрессменша"],
    "конгрессменша": ["конгрессвумен", "конгрессменка"],
    "конгривова ракета": ["конгревова ракета", "ракета конгрива"],
    "конгруэнтность": ["конгруэнция"],
    "конгруэнтный": ["равный", "эквивалентный", "гармоничный"],
    "конгруэнция": ["конгруэнтность", "соответствие", "равенство"],
    "кондак": ["тропарь"],
    "кондачок": ["кондак"],
    "кондей": ["кондёр", "кондишн"],
    "конденсировав": ["конденсировавши"],
    "конденсировавши": ["конденсировав"],
    "конденсировать": ["накапливать", "накопить", "аккумулировать", "сгущать", "сгустить"],
    "кондитерский генерал": ["свадебный генерал", "зицпредседатель"],
    "кондитерское изделие": ["сладость"],
    "кондиционал": ["кондиционалис"],
    "кондиционер": ["сплит-система", "кондей", "кондёр", "кондишн", "бальзам-ополаскиватель"],
    "кондиционировав": ["кондиционировавши"],
    "кондиционировавши": ["кондиционировав"],
    "кондиционность": ["качество"],
    "кондиция": ["норма", "стандарт", "условие"],
    "кондовый": ["боровой", "рудовый", "крепкий", "прочный", "здоровый", "мачтовый", "корабельный", "строевой", "ладейный", "могучий", "исконный", "коренной", "родовой", "изначальный", "старинный"],
    "кондом": ["презерватив", "гондон"],
    "кондоминиум": ["кондоминат"],
    "кондрат": ["кондратий", "кондрашка"],
    "кондратий": ["кондрашка", "инсульт"],
    "кондрашка": ["инсульт", "апоплексический удар", "кондрат", "кондратий", "косая"],
    "кондуктанс": ["активная проводимость"],
    "кондьилэ": ["кэлидьэ"],
    "кондястемс": ["яраштомс", "ладямс", "тумс"],
    "коневий": ["конский", "конячий"],
    "коневой": ["конский", "лошадный", "конёвый"],
    "конечно": ["несомненно", "разумеется", "само собой разумеется", "само собой", "естественно", "да", "действительно", "определённо", "однозначно"],
    "конечно же": ["само собой разумеется", "без сомнения", "разумеется", "да"],
    "конечность": ["член"],
    "конечность верхняя свободная": ["рука"],
    "конечный": ["последний", "заключительный", "ограниченный", "главный", "истинный", "выходной", "результирующий"],
    "конжак": ["коньяку", "конняку"],
    "конидиеносец": ["конидионосец", "конидиофор"],
    "конидионосец": ["конидиеносец", "конидиофор"],
    "конидиоспора": ["конидия"],
    "конидия": ["конидиоспора"],
    "коник": ["конь"],
    "коника": ["коническое сечение"],
    "конически": ["конусообразно"],
    "конический": ["конусный", "конусообразный"],
    "конка": ["конно-железная дорога", "конный трамвай"],
    "конкатенация": ["сочленение", "сцепление"],
    "конкатенировав": ["конкатенировавши"],
    "конкатенировавши": ["конкатенировав"],
    "конкатенировать": ["сцеплять", "соединять"],
    "конкорданс": ["конкорданция", "симфония"],
    "конкорданция": ["конкорданс", "симфония"],
    "конкретизация": ["детализация", "уточнение"],
    "конкретизировав": ["конкретизировавши"],
    "конкретизировавши": ["конкретизировав"],
    "конкретизировать": ["уточнять", "уточнить"],
    "конкретизовав": ["конкретизовавши"],
    "конкретизовавши": ["конкретизовав"],
    "конкретно": ["по-настоящему", "всерьёз", "реально"],
    "конкретный": ["определённый"],
    "конкурент": ["соперник"],
    "конкуренция": ["соперничество"],
    "конкурировав": ["конкурировавши"],
    "конкурировавши": ["конкурировав"],
    "конкурировать": ["соперничать"],
    "конланг": ["искусственный язык"],
    "конмебол": ["южноамериканская конфедерация футбола"],
    "коннект": ["соединение", "подключение"],
    "конник": ["кавалерист"],
    "конница": ["кавалерия"],
    "коннозаводский": ["коннозаводческий"],
    "коннотация": ["созначение"],
    "конняку": ["конжак"],
    "коновалив": ["коноваливши"],
    "коноваливши": ["коновалив"],
    "коновка": ["коновь", "жбан", "конобь", "коноб", "кандея", "канька"],
    "коноводив": ["коноводивши"],
    "коноводивши": ["коноводив"],
    "коновонька": ["коновочка"],
    "кононенкино кубло": ["взрыв на макаронной фабрике", "я упала с сеновала", "я у мамы дурочка", "не одна я поле кувыркалась"],
    "конопатив": ["конопативши"],
    "конопативши": ["конопатив"],
    "конопатить": ["законопачивать"],
    "конопаченье": ["конопачение"],
    "конопель": ["коноплё"],
    "коноплеводный": ["коноплеводческий"],
    "коноплеводческий": ["коноплеводный"],
    "конопля": ["конопель", "марихуана", "каннабис", "анаша", "ганджа"],
    "конопляний": ["конопельний"],
    "коноплянка": ["реполов"],
    "коноплё": ["конопель"],
    "коноплёвый": ["конопельный", "конопляный"],
    "конопушка": ["веснушка"],
    "коноёбив": ["коноёбивши"],
    "коноёбивши": ["коноёбив"],
    "коноёбиться": ["возиться", "канителиться", "копаться", "колупаться", "чеханаститься", "ебаться", "ковыряться"],
    "конпропорционирование": ["репропорционирование"],
    "консалтинг": ["консультирование"],
    "консеквент": ["сукцедент"],
    "консеквентный": ["последовательный"],
    "консеквенция": ["результат", "последствие", "итог", "заключение", "вывод"],
    "консенсуальный": ["консенсусный", "согласованный"],
    "консенсус": ["взаимопонимание"],
    "консенсусный": ["консенсуальный"],
    "консервативность": ["консерватизм"],
    "консервативный": ["традиционалистский", "ретроградский", "косный"],
    "консервативный либерализм": ["правый либерализм"],
    "консерватизм": ["консервативность"],
    "консерватор": ["ретроград", "традиционалист", "научный сотрудник", "хранитель"],
    "консервация": ["сохранение"],
    "консервировав": ["консервировавши"],
    "консервировавши": ["консервировав"],
    "консервовскрыватель": ["консервный нож"],
    "консервщик": ["консервник"],
    "консервы": ["консервация"],
    "консидерация": ["уважение", "почтение", "основание", "соображение"],
    "консидерировать": ["рассматривать", "считать"],
    "консистентность": ["согласованность"],
    "конская капуста": ["сибирский ревень"],
    "конский": ["конный", "лошадиный"],
    "консолидация": ["упрочение", "объединение", "сплочение"],
    "консолидировав": ["консолидировавши"],
    "консолидировавши": ["консолидировав"],
    "консоль": ["кронштейн", "кантилевер", "выступ", "модильон", "панель управления", "отладочная панель", "пульт", "индикаторная панель", "приставка", "монитор"],
    "консонанс": ["созвучие", "благозвучие"],
    "консонансный": ["благозвучный"],
    "консонант": ["согласный звук", "согласный"],
    "консонантное письмо": ["абджад"],
    "консонировав": ["консонировавши"],
    "консонировавши": ["консонировав"],
    "консорт": ["принц-консорт"],
    "консорциум": ["синдикат", "соглашение", "объединение", "ассоциация", "сообщество"],
    "конспект": ["реферат", "резюме", "аннотация"],
    "конспективно": ["сжато", "кратко", "тезисно", "в общих чертах"],
    "конспективный": ["краткий", "сжатый"],
    "конспектировав": ["конспектировавши"],
    "конспектировавши": ["конспектировав"],
    "конспецифичный": ["внутривидовой"],
    "конспиративный": ["тайный", "подпольный"],
    "конспирировав": ["конспирировавши"],
    "конспирировавши": ["конспирировав"],
    "конспирология": ["теория заговора"],
    "константа": ["постоянная"],
    "константий": ["констанций"],
    "константинополь": ["стамбул", "царьград"],
    "константия": ["констанция"],
    "константный": ["неизменный", "постоянный", "устойчивый"],
    "констанций": ["константий"],
    "констанция": ["константия"],
    "констатировав": ["констатировавши"],
    "констатировавши": ["констатировав"],
    "констатировать": ["установить", "устанавливать", "удостоверить", "удостоверять", "подтвердить", "подтверждать", "зафиксировать"],
    "констебль": ["полицейский", "полисмен"],
    "констелляция": ["созвездие"],
    "констернация": ["замешательство", "испуг", "смятение"],
    "конституента": ["конституент"],
    "конституировав": ["конституировавши"],
    "конституировавши": ["конституировав"],
    "конституировать": ["придавать силу", "придать силу", "устанавливать", "установить", "организовывать", "организовать", "определять"],
    "конститутивный": ["определяющий", "основополагающий"],
    "конституционно-договорный": ["договорно-конституционный"],
    "конституция": ["основной закон", "габитус", "телосложение"],
    "конституция победившего социализма": ["сталинская конституция"],
    "констративный": ["настилающий"],
    "констриктор": ["сфинктер", "удав"],
    "конструировав": ["конструировавши"],
    "конструировавши": ["конструировав"],
    "конструирование": ["построение", "дизайн"],
    "конструктивный": ["плодотворный"],
    "конструктор": ["дизайнер", "проектировщик"],
    "конструкция": ["структура"],
    "консульство": ["дипломатическое представительство"],
    "консульствовав": ["консульствовавши"],
    "консульствовавши": ["консульствовав"],
    "консультант": ["советчик", "эксперт", "референт", "адвайзер"],
    "консультантка": ["экспертка", "рецензентка"],
    "консультативно-координирующий": ["консультационно-координационный"],
    "консультативно-просветительный": ["консультативно-просветительский"],
    "консультативно-просветительский": ["консультативно-просветительный"],
    "консультационно-координационный": ["консультативно-координирующий"],
    "консультировав": ["консультировавши"],
    "консультировавши": ["консультировав"],
    "консуматор": ["потребител", "купувач", "покупател"],
    "консумент": ["гетеротроф"],
    "консумеризм": ["консьюмеризм"],
    "консумизм": ["консюмеризм"],
    "консьерж": ["вахтёр", "привратник", "надзиратель", "портье"],
    "консьюмеризм": ["консумеризм", "потребительство"],
    "консюмеризм": ["консумизм"],
    "контагий": ["контагиум"],
    "контакт": ["соприкосновение", "соединение"],
    "контактант": ["контактёр"],
    "контактировав": ["контактировавши"],
    "контактировавши": ["контактировав"],
    "контактирование": ["контакт"],
    "контактировать": ["беседовать", "иметь контакты", "поддерживать связь", "знаться", "водиться", "якшаться", "путаться", "тереться", "водить знакомство", "валандаться", "хороводить", "водить хлеб-соль", "знаваться", "контачить", "хороводиться"],
    "контактёр": ["посредник", "контактант"],
    "контактёрка": ["контактёрша"],
    "контактёрша": ["контактёрка"],
    "контаминация": ["словослияние"],
    "контаминировав": ["контаминировавши"],
    "контаминировавши": ["контаминировав"],
    "контарь": ["безмен", "кантарь", "контырь", "кантар"],
    "контачив": ["контачивши"],
    "контачивши": ["контачив"],
    "контбет": ["продолженная ставка"],
    "контбетив": ["контбетивши"],
    "контбетивши": ["контбетив"],
    "контейнер": ["ёмкость"],
    "контейнер-цистерна": ["кц", "танк-контейнер"],
    "контейнерный терминал": ["контейнерная площадка"],
    "контекст": ["окружение", "среда", "фон"],
    "контекстный": ["контекстовый"],
    "контекстуализировав": ["контекстуализировавши"],
    "контекстуализировавши": ["контекстуализировав"],
    "контекстуализировать": ["контекстуализовать"],
    "контекстуализовать": ["контекстуализировать"],
    "контекстуально": ["контекстно"],
    "контекстуальный": ["контекстный", "контекстовый"],
    "контенанс": ["приличие"],
    "контент": ["наполнение"],
    "контингент": ["коллектив", "квота"],
    "контингентировав": ["контингентировавши"],
    "контингентировавши": ["контингентировав"],
    "континент": ["материк"],
    "континентальная кора": ["материковая кора"],
    "континентальный": ["материковый"],
    "континуум": ["непрерывность"],
    "контировав": ["контировавши"],
    "контировавши": ["контировав"],
    "контора": ["отдел", "канцелярия", "управление", "офис"],
    "конторсия": ["конторсионизм"],
    "конторская книга": ["гроссбух"],
    "конторский": ["офисный"],
    "контр-": ["анти-"],
    "контра": ["контрреволюционер"],
    "контрабасовый": ["контрабасный"],
    "контрадировать": ["противоречить"],
    "контракт": ["договор", "соглашение", "сделка"],
    "контрактник": ["кадровик", "наёмник"],
    "контрактный": ["договорной"],
    "контрактовав": ["контрактовавши"],
    "контрактовавши": ["контрактовав"],
    "контралатеральный": ["контрлатеральный", "перекрещенный"],
    "контрамарка": ["контрмарка"],
    "контрамаркировав": ["контрамаркировавши"],
    "контрамаркировавши": ["контрамаркировав"],
    "контрамаркирование": ["контрмаркирование"],
    "контрамаркированный": ["надчеканенный"],
    "контрамаркировать": ["контрмаркировать", "надчеканить", "надчеканивать"],
    "контрапункт": ["полифоническое", "произведение", "полифония"],
    "контрапунктировав": ["контрапунктировавши"],
    "контрапунктировавши": ["контрапунктировав"],
    "контрапунктироваться": ["контрапунктоваться"],
    "контрапунктовав": ["контрапунктовавши"],
    "контрапунктовавши": ["контрапунктовав"],
    "контрапунктовать": ["контрапунктировать"],
    "контраргумент": ["контрдовод"],
    "контрареволюционен": ["антиреволюционен", "реакционен"],
    "контраремонстрант": ["гомарист"],
    "контрасигнатура": ["контрасигнация"],
    "контрасигнация": ["контрасигнатура"],
    "контрасигнировав": ["контрасигнировавши"],
    "контрасигнировавши": ["контрасигнировав"],
    "контрасигнировать": ["контросинировать"],
    "контрасигновав": ["контрасигновавши"],
    "контрасигновавши": ["контрасигновав"],
    "контрассигнация": ["контрассигновка"],
    "контрассигнировав": ["контрассигнировавши"],
    "контрассигнировавши": ["контрассигнировав"],
    "контрассигнировать": ["контрассигновать"],
    "контрассигновав": ["контрассигновавши"],
    "контрассигновавши": ["контрассигновав"],
    "контрассигновать": ["контрассигнировать"],
    "контрассигновка": ["контрассигнация"],
    "контраст": ["контрастность"],
    "контрастировав": ["контрастировавши"],
    "контрастировавши": ["контрастировав"],
    "контрастность": ["контраст"],
    "контрастный": ["контрастирующий", "противоположный", "чёткий"],
    "контратака": ["контрнаступление"],
    "контратаковав": ["контратаковавши"],
    "контратаковавши": ["контратаковав"],
    "контратипировав": ["контратипировавши"],
    "контратипировавши": ["контратипировав"],
    "контрацептив": ["противозачаточное средство", "сволочь", "урод", "мудак"],
    "контрбатарейный": ["контрабатарейный", "противобатарейный"],
    "контрвыпад": ["контр-выпад"],
    "контрив": ["контривши"],
    "контривши": ["контрив"],
    "контрить": ["законтривать"],
    "контрлатеральный": ["контралатеральный"],
    "контрмарка": ["надчеканка", "надчекан"],
    "контрмаркировав": ["контрмаркировавши"],
    "контрмаркировавши": ["контрмаркировав"],
    "контрмаркирование": ["контрамаркирование"],
    "контрмаркировать": ["контрамаркировать"],
    "контрнаступление": ["контратака", "контрудар"],
    "контролировав": ["контролировавши"],
    "контролировавши": ["контролировав"],
    "контролируемый": ["надзираемый", "проверяемый", "управляемый"],
    "контроль": ["надзор", "проверка", "наблюдение", "контролёр", "власть"],
    "контролька": ["пробник", "автотестер"],
    "контрольная": ["контрольная работа"],
    "контрольно-пропускной пункт": ["кпп", "бюро пропусков", "проходная", "блокпост", "пограничный", "переход", "погранпереход"],
    "контрольный браслет": ["браслет-билет"],
    "контрольный идентификационный знак": ["киз"],
    "контросинировав": ["контросинировавши"],
    "контросинировавши": ["контросинировав"],
    "контрошка": ["контрольная работа", "контрольная"],
    "контрпараллелограмм": ["антипараллелограмм"],
    "контрпартизанский": ["противопартизанский"],
    "контрперестроечный": ["антиперестроечный"],
    "контрпрессинговав": ["контрпрессинговавши"],
    "контрпрессинговавши": ["контрпрессинговав"],
    "контрреволюционер": ["контра", "контрик", "каэр"],
    "контрреволюционный": ["антиреволюционный"],
    "контрреформатор": ["контрреформист", "антиреформатор"],
    "контрреформаторский": ["контрреформистский"],
    "контрреформист": ["контрреформатор", "антиреформатор"],
    "контрреформистский": ["контрреформаторский"],
    "контрсанкция": ["антисанкция"],
    "контрснайперский": ["противоснайперский"],
    "контртеррористическая операция": ["кто"],
    "контртеррористический": ["антитеррористический"],
    "контузив": ["контузивши"],
    "контузивши": ["контузив"],
    "контузить": ["оконтузить"],
    "контур": ["очертание", "абрис", "линия"],
    "контуш": ["кунтуш"],
    "конунг": ["король"],
    "конура": ["будка", "хибара", "хижина"],
    "конусний": ["конусовий"],
    "конусообразно": ["конически"],
    "конусообразный": ["конусовидный", "конусоподобный"],
    "конфа": ["веб-конференция", "телеконференция", "конференция"],
    "конфедеративные штаты": ["конфедеративные штаты америки", "кша", "конфедерация", "юг"],
    "конфедеративные штаты америки": ["конфедеративные штаты", "кша", "конфедерация", "юг"],
    "конфедератка": ["кракуска", "рогатывка"],
    "конфедерация": ["конфедеративные штаты америки", "конфедеративные штаты", "кша", "юг"],
    "конфекцион": ["конфекция"],
    "конфекция": ["конфекцион"],
    "конферансье": ["массовик-затейник", "клоун"],
    "конферва": ["нитчатка"],
    "конференсия": ["конфронс"],
    "конференция": ["совещание"],
    "конферировав": ["конферировавши"],
    "конферировавши": ["конферировав"],
    "конфессия": ["исповедание", "вероисповедание", "вера", "деноминация"],
    "конфета": ["конфетка", "конфекта", "конфект"],
    "конфигурировав": ["конфигурировавши"],
    "конфигурировавши": ["конфигурировав"],
    "конфигурировать": ["формировать"],
    "конфидентка": ["наперсница"],
    "конфиденциально": ["доверительно"],
    "конфиденциальность": ["доверительность", "интимность", "скрытность", "секретность", "анонимность", "латентность"],
    "конфиденциальный": ["секретный", "приватный", "интимный", "доверительный"],
    "конфикс": ["циркумфикс"],
    "конфиксальный": ["конфиксный", "префиксально-суффиксальный", "приставочно-суффиксальный"],
    "конфиксация": ["парасинтез"],
    "конфинальный": ["кофинальный"],
    "конфирмат": ["евровинт"],
    "конфирмовав": ["конфирмовавши"],
    "конфирмовавши": ["конфирмовав"],
    "конфирмовать": ["ратифицировать"],
    "конфискация": ["конфискование", "изъятие"],
    "конфисковав": ["конфисковавши"],
    "конфисковавши": ["конфисковав"],
    "конфискование": ["конфискация"],
    "конфисковывав": ["конфисковывавши"],
    "конфисковывавши": ["конфисковывав"],
    "конфисковывать": ["конфисковать"],
    "конфитюр": ["джем", "повидло"],
    "конфликт": ["противостояние", "ссора", "распря", "междоусобица", "противоречие"],
    "конфликтный": ["склочный", "скандальный", "вздорный"],
    "конфликтовав": ["конфликтовавши"],
    "конфликтовавши": ["конфликтовав"],
    "конфликтование": ["вражда"],
    "конфликтовать": ["враждовать"],
    "конфондировать": ["путать", "смешивать", "видеть", "отличать"],
    "конформизм": ["приспособленчество"],
    "конформист": ["приспособленец", "конъюнктурщик", "соглашатель"],
    "конформно": ["конформистски"],
    "конформность": ["податливость", "конформизм", "уступчивость"],
    "конфронтация": ["противостояние", "противоборство", "конфликт"],
    "конфронтировав": ["конфронтировавши"],
    "конфронтировавши": ["конфронтировав"],
    "конфуз": ["конфузия"],
    "конфузив": ["конфузивши"],
    "конфузивши": ["конфузив"],
    "конфузливость": ["застенчивость", "стыдливость", "стеснительность", "смущенность", "робость"],
    "конхилиология": ["конхиология", "конхология"],
    "конхиология": ["конхология", "конхилиология"],
    "конхология": ["конхиология", "конхилиология"],
    "концевик": ["концевой выключатель", "выводной провод", "концевая деталь"],
    "концевой": ["конечный", "терминальный"],
    "концентрационный лагерь": ["концлагерь"],
    "концентрация": ["сосредоточение", "сфокусированность", "сосредоточенность"],
    "концентрировав": ["концентрировавши"],
    "концентрировавши": ["концентрировав"],
    "концентрировать": ["собирать", "накапливать", "скапливать", "направлять", "устремлять", "сосредоточивать", "сосредотачивать", "фокусировать", "насыщать", "сгущать", "обогащать"],
    "концентрироваться": ["скапливаться", "собираться", "сосредотачиваться", "сосредоточиваться", "фиксироваться", "сгущаться"],
    "концентрически": ["концентрично"],
    "концентрический": ["гомоцентрический", "концентричный"],
    "концентричный": ["концентрический", "коаксиальный"],
    "концепт": ["замысел", "проект", "смысл", "понятие", "сигнификат", "сгусток смысла"],
    "концептуализм": ["концептуальное искусство"],
    "концептуализовав": ["концептуализовавши"],
    "концептуализовавши": ["концептуализовав"],
    "концептуальное искусство": ["концептуализм"],
    "концепция": ["идея", "суть", "замысел"],
    "концерн": ["холдинг", "конгломерат"],
    "концерт": ["ругань", "брань", "ссора", "ругачка"],
    "концертировав": ["концертировавши"],
    "концертировавши": ["концертировав"],
    "концертная флейта": ["флейта бёма"],
    "концессия": ["дозволение", "согласие", "одобрение", "уступка", "предоставление"],
    "концесском": ["главный", "концессионный", "комитет", "главконцесск"],
    "конципировав": ["конципировавши"],
    "конципировавши": ["конципировав"],
    "концлагерь": ["концентрационный лагерь", "лагерь смерти", "фабрика смерти"],
    "концы в воду": ["шито-крыто"],
    "конча": ["сперма"],
    "кончав": ["кончавши"],
    "кончавши": ["кончав"],
    "кончать": ["приканчивать", "мочить"],
    "кончаться": ["завершаться", "заканчиваться", "прекращаться", "подходить к концу", "исчерпываться", "умирать", "отдавать концы"],
    "кончаясь": ["заканчиваясь", "завершаясь", "оканчиваясь"],
    "конче": ["жребче"],
    "кончебас": ["канчебас", "канчебаш"],
    "конченный": ["пропащий", "безнадёжный", "отпетый", "конченый"],
    "конченый": ["решённый", "законченный", "пропащий", "безнадёжный"],
    "кончив": ["кончивши"],
    "кончивши": ["кончив"],
    "кончина": ["смерть"],
    "кончиться": ["завершиться", "закончиться", "окончиться", "истечь"],
    "конъюгат": ["сцеплянка"],
    "конъюгировав": ["конъюгировавши"],
    "конъюгировавши": ["конъюгировав"],
    "конъюнктив": ["сослагательное наклонение"],
    "конъюнктура": ["обстановка", "условия"],
    "конъюнктурив": ["конъюнктуривши"],
    "конъюнктуривши": ["конъюнктурив"],
    "конъюнктурщик": ["приспособленец"],
    "конъюнкция": ["логическое произведение", "логическое умножение"],
    "конь": ["лошадь", "скакун", "жеребец", "кобыла", "хлебало"],
    "конь в пальто": ["дед пихто", "некто"],
    "конь не валялся": ["конь не ебался"],
    "коньковый ход": ["конёк"],
    "коньяк": ["бренди"],
    "коню понятно": ["ежу понятно", "ясен пень", "ясен арафат", "ясен хуй", "ясный хуй"],
    "конюх": ["пригривник", "грум", "конюший", "канюк", "зимник"],
    "конюшив": ["конюшивши"],
    "конюшивши": ["конюшив"],
    "конюшничав": ["конюшничавши"],
    "конюшничавши": ["конюшничав"],
    "конюшничать": ["конюшить"],
    "конюшня": ["хлев", "стайка"],
    "коняга": ["коняка"],
    "коняшка": ["лошадка", "коняга"],
    "конёк": ["конь", "коник", "князёк", "охлупень", "морской конёк"],
    "кооз": ["сулуу"],
    "кооздук": ["сулуулук"],
    "кооперативность": ["сотрудничество"],
    "кооперировав": ["кооперировавши"],
    "кооперировавши": ["кооперировав"],
    "кооперирование": ["кооперация"],
    "кооптация": ["кооптирование"],
    "кооптировав": ["кооптировавши"],
    "кооптировавши": ["кооптировав"],
    "кооптирование": ["кооптация"],
    "кооптировать": ["включить"],
    "координат": ["координата"],
    "координата": ["адрес"],
    "координатный": ["позиционный"],
    "координационное соединение": ["комплексное соединение"],
    "координация": ["координирование", "согласование", "увязка", "увязывание", "слаженность", "согласованность"],
    "координировав": ["координировавши"],
    "координировавши": ["координировав"],
    "координировать": ["взаимоувязывать", "взаимоувязать", "согласовывать", "согласовать", "сообразовывать", "сообразовать", "увязывать", "увязать", "скоординировать"],
    "коп": ["фараон"],
    "копав": ["копавши"],
    "копавши": ["копав"],
    "копальщик": ["копач", "копщик", "копатель"],
    "копанув": ["копанувши"],
    "копанувши": ["копанув"],
    "копатель": ["копальщик"],
    "копательный": ["землекопный"],
    "копать": ["рыть", "вскапывать"],
    "копаться": ["рыться", "ковыряться", "возиться", "копошиться"],
    "копач": ["копатель", "копальщик", "могильщик", "гробокопатель"],
    "копеечничав": ["копеечничавши"],
    "копеечничавши": ["копеечничав"],
    "копеешный": ["копеечный"],
    "копейничав": ["копейничавши"],
    "копейничавши": ["копейничав"],
    "копек": ["ит"],
    "копенгаген": ["знаток", "дока", "шарящий"],
    "копепод": ["веслоногие ракообразные"],
    "коперниканский": ["коперникианский", "коперниковский"],
    "коперникианский": ["коперниканский", "коперниковский"],
    "коперниковский": ["коперниканский", "коперникианский"],
    "коперниций": ["коперникий", "унунбий", "эка-ртуть"],
    "копец": ["конец", "пиздец"],
    "копив": ["копивши"],
    "копивши": ["копив"],
    "копипаст": ["клей и ножницы", "копипаста"],
    "копипаста": ["копивио"],
    "копипастив": ["копипастивши"],
    "копипастивши": ["копипастив"],
    "копипейст": ["копипаст", "копипаста"],
    "копипринтер": ["ризограф"],
    "копипэйстнув": ["копипэйстнувши"],
    "копипэйстнувши": ["копипэйстнув"],
    "копипэйстнуть": ["скопипэйстнуть", "скопировать"],
    "копир": ["копировальная машина", "копировальный аппарат", "ксерокс"],
    "копирайт": ["авторское право", "копирайты", "атрибуция"],
    "копирайтер": ["копи"],
    "копирайтерство": ["копирайтинг"],
    "копирайтинг": ["копирайтерство"],
    "копираст": ["копирайт", "фашист"],
    "копирка": ["копировальная бумага"],
    "копировав": ["копировавши"],
    "копировавши": ["копировав"],
    "копировальная бумага": ["копирка"],
    "копировальная машина": ["копировальный аппарат", "копир", "ксерокс"],
    "копировальный аппарат": ["копировальная машина", "копир", "ксерокс"],
    "копировальщик": ["копировщик"],
    "копированье": ["копирование"],
    "копировать": ["воспроизводить", "подражать", "имитировать"],
    "копировочный": ["копировальный"],
    "копить": ["накапливать", "аккумулировать", "собирать", "сберегать", "скрывать", "таить"],
    "копиться": ["накапливаться", "накопляться", "скапливаться", "сосредотачиваться", "прибывать"],
    "копия": ["дубль", "клон", "имитация", "двойник"],
    "копка": ["копание"],
    "копланарность": ["компланарность"],
    "копна": ["стог"],
    "копнив": ["копнивши"],
    "копнивши": ["копнив"],
    "копнув": ["копнувши"],
    "копнувши": ["копнув"],
    "кополимер": ["сополимер"],
    "копорь": ["каряз"],
    "копоткий": ["копотливый"],
    "копотливый": ["копоткий"],
    "копотня": ["копошение", "возня"],
    "копоть": ["сажа", "гарь"],
    "копоушка": ["уховёртка"],
    "копошение": ["возня"],
    "копошенье": ["копошение"],
    "копошив": ["копошивши"],
    "копошивши": ["копошив"],
    "копошиться": ["возиться", "копаться"],
    "копр": ["кроп", "серпник", "бабья соль"],
    "копринус": ["навозник"],
    "копростаз": ["колоностаз"],
    "коптев": ["коптевши"],
    "коптевши": ["коптев"],
    "коптив": ["коптивши"],
    "коптивши": ["коптив"],
    "коптильня": ["помещение", "устройство"],
    "коптить": ["чернить", "вялить"],
    "коптить небо": ["прозябать"],
    "копула": ["связка"],
    "копулировав": ["копулировавши"],
    "копулировавши": ["копулировав"],
    "копулировать": ["сношаться", "прививать"],
    "копулятивный": ["половой", "совокупительный", "связочный"],
    "копулятивный орган": ["гениталии"],
    "копун": ["копуха", "копуша"],
    "копуха": ["копуша"],
    "копуша": ["копун", "копунья"],
    "копчек": ["тегер", "чаркъ"],
    "копченье": ["копчение"],
    "копчик": ["хвостец"],
    "копчёный": ["закоптелый"],
    "копщик": ["копальщик"],
    "копылье": ["копыло", "копыл"],
    "копытень": ["блевунья", "винный корень", "дикий перец", "земляной ладан", "копытник", "лошадиное копыто", "подорешник", "рвотный корень", "скипидарная трава", "скипидарник", "срывная трава"],
    "копытив": ["копытивши"],
    "копытивши": ["копытив"],
    "копытка": ["саджа"],
    "копышиться": ["копошиться"],
    "копь": ["рудник"],
    "копьеметалка": ["атлатль"],
    "копьеметатель": ["метатель копья"],
    "копьеносец": ["дорифор", "копейщик", "ратник"],
    "копьеобразный": ["копьевидный"],
    "копьецо": ["пика"],
    "копёнка": ["копёшка"],
    "копёр": ["шахтный копёр"],
    "копёшка": ["копёнка"],
    "кор": ["хор"],
    "кора": ["кора больших полушарий головного мозга"],
    "кора больших полушарий": ["кора головного мозга"],
    "кора головного мозга": ["кора больших полушарий"],
    "корабел": ["кораблестроитель", "судостроитель"],
    "корабель": ["судно"],
    "корабельничав": ["корабельничавши"],
    "корабельничавши": ["корабельничав"],
    "корабельный червь": ["терединид", "тередо"],
    "корабельщик": ["моряк", "корабел"],
    "кораблебудування": ["суднобудування"],
    "кораблевий": ["корабельний"],
    "кораблевождение": ["судовождение"],
    "кораблекрушение": ["кораблекрушенье"],
    "кораблекрушенье": ["кораблекрушение"],
    "кораблестроение": ["судостроение"],
    "корабли": ["ботинок", "сапог"],
    "кораблик": ["наутилус"],
    "корабль": ["ладья", "парусник", "лайнер"],
    "коракоид": ["воронья кость", "вороновидная кость"],
    "коралловый полип": ["коралл"],
    "коран": ["алкоран", "алькоран"],
    "корван": ["жертвоприношение"],
    "корвет": ["сторожевой корабль"],
    "корволант": ["корволан"],
    "корги": ["вельш-корги"],
    "корда": ["лонжа"],
    "кордегардия": ["гауптвахта"],
    "кордон": ["застава", "оцепление", "граница", "рубеж"],
    "корей": ["корах"],
    "корейская народная армия": ["кна"],
    "корелла": ["нимфа"],
    "корем": ["черва", "стомах", "вътрешности"],
    "коремий": ["коремия"],
    "коремия": ["коремий", "синнема"],
    "коренастый": ["кряжистый"],
    "коренизация": ["этнизация"],
    "коренизировав": ["коренизировавши"],
    "коренизировавши": ["коренизировав"],
    "коренизовав": ["коренизовавши"],
    "коренизовавши": ["коренизовав"],
    "коренная": ["коренник"],
    "коренник": ["коренная"],
    "коренной житель": ["местный", "абориген", "автохтон", "туземец"],
    "коренной зуб": ["моляр"],
    "корень": ["родословная", "поколение", "предки", "основание", "источник", "первопричина", "причина", "основа", "радикал"],
    "коренье": ["корень"],
    "кореопсис": ["ленок", "жёлтая ромашка", "парижская красавица"],
    "корефан": ["кореш"],
    "корец": ["ковш", "ковшик", "жбан"],
    "кореш": ["друг", "приятель", "товарищ", "кент", "друган", "дружбан", "корефан"],
    "корешевав": ["корешевавши"],
    "корешевавши": ["корешевав"],
    "корешив": ["корешивши"],
    "корешивши": ["корешив"],
    "корешить": ["корешиться"],
    "корешиться": ["корешить"],
    "корея": ["корейский полуостров", "северная корея", "кндр", "южная корея", "республика корея", "кр"],
    "кореёза": ["чимчигрыз", "узкоглазый"],
    "корж": ["коржик"],
    "корзина": ["мусорка", "мусорная корзина", "кольцо"],
    "корзинка": ["корзина"],
    "корзиночка": ["корзина", "корзинка", "корбикула", "пыльцевая корзинка"],
    "кориандр": ["кишнец", "кинза", "киндза", "киндзи", "коляндра", "кишнец посевной", "шлёндра", "хамем", "кишниши", "чилантро", "кашнич", "китайская петрушка"],
    "корив": ["коривши"],
    "коривши": ["корив"],
    "коригувати": ["виправляти", "коректувати", "корегувати"],
    "коридор": ["проход", "прихожая", "колидор", "калидор"],
    "корить": ["упрекать", "укорять", "пенять", "журить", "порицать", "ругать"],
    "кориться": ["покоряться", "повиноваться"],
    "кориум": ["дерма", "кутис"],
    "корифей": ["гигант", "титан", "светило", "величина"],
    "корифена": ["дорадо"],
    "корица": ["коричник", "циннамон", "коричное дерево"],
    "коричневато-жёлтый": ["коричневато-желтоватый", "желтовато-коричневатый", "желтовато-коричневый", "коричнево-жёлтый"],
    "коричневая чума": ["фашизм"],
    "коричневев": ["коричневевши"],
    "коричневевши": ["коричневев"],
    "коричнево-песочный": ["песочно-коричневый"],
    "коричнево-серый": ["серо-коричневый", "коричневато-серый"],
    "коричневорубашечник": ["фашист", "фашик"],
    "коричневый": ["фашистский", "ультранационалистический", "крайне правый"],
    "коричневый карлик": ["бурый карлик"],
    "коричневый королёк": ["королёк", "шоколадный королёк", "шоколадная хурма", "шоколадница", "хурма-королёк"],
    "корка": ["ритидом"],
    "корковый": ["кортикальный"],
    "коркув": ["корхув", "къоркъу", "къоркъув", "къоркъы"],
    "корм": ["кормление", "кормёжка", "кормленье"],
    "корм животного происхождения": ["животный корм"],
    "корм растительного происхождения": ["растительный корм"],
    "корма": ["кормица"],
    "кормив": ["кормивши"],
    "кормивши": ["кормив"],
    "кормилица": ["мамка"],
    "кормило": ["правило", "руль", "бразды"],
    "кормить": ["откармливать", "питать", "содержать", "пичкать", "закармливать"],
    "кормление": ["кормленье"],
    "кормленье": ["кормление"],
    "кормовые": ["кормовые деньги"],
    "кормодобывание": ["кормозаготовка"],
    "кормодобывающий": ["кормозаготовительный"],
    "кормозаготовительный": ["кормодобывающий"],
    "кормосклад": ["кормохранилище"],
    "кормосмесь": ["комбикорм"],
    "кормчая": ["кормчая книга"],
    "кормчая книга": ["кормчая", "номоканон"],
    "кормчий": ["рулевой", "лоцман", "чичероне", "гид", "вождь", "глава", "руководитель", "вдохновитель", "вожак", "водитель", "водырь", "поводырь", "водчик", "водильщик", "вожатый"],
    "кормчия": ["машинист", "пилот"],
    "кормёжка": ["кормление"],
    "корнав": ["корнавши"],
    "корнавши": ["корнав"],
    "корнаж": ["зерносенаж"],
    "корневищный": ["корневищевый"],
    "корнеклубень": ["корневой клубень"],
    "корненожка": ["ризопод"],
    "корнеобразный": ["корнеподобный", "корневидный"],
    "корнеплод": ["клубень", "корнеклубень"],
    "корнесловив": ["корнесловивши"],
    "корнесловивши": ["корнесловив"],
    "корнет": ["прапорщик", "подпоручик", "хорунжий"],
    "корнет-а-пистон": ["корнет"],
    "корнишон": ["огурчик"],
    "корнский": ["корнуольский"],
    "корнуолл": ["корнуэлл"],
    "корнуоллский": ["корнуэльский"],
    "корнуэлл": ["корнуолл"],
    "корнуэльский": ["корнуоллский"],
    "коробейничав": ["коробейничавши"],
    "коробейничавши": ["коробейничав"],
    "коробив": ["коробивши"],
    "коробивши": ["коробив"],
    "коробить": ["деформировать", "скособочивать", "корёжить", "покорёживать", "искорёживать", "отвращать"],
    "коробка передач": ["коробка скоростей"],
    "коробка скоростей": ["коробка передач"],
    "коробожа": ["карабожа"],
    "корова": ["бык"],
    "коровница": ["скотница"],
    "коровяк": ["вербаскум"],
    "корогод": ["хоровод", "частокол", "околица"],
    "короед": ["жук-короед", "жучок-короед", "спиногрыз"],
    "короед-типограф": ["типограф"],
    "корожечна": ["корожечня", "корожишна"],
    "королева": ["ферзь", "дама"],
    "королевич": ["принц"],
    "королевна": ["принцесса", "королева"],
    "королевство": ["царство", "правление", "царствование", "королевствование"],
    "королевство дания": ["дания"],
    "королевство испания": ["испания"],
    "королевство марокко": ["марокко"],
    "королевство норвегия": ["норвегия"],
    "королевство швеция": ["швеция"],
    "королевствовав": ["королевствовавши"],
    "королевствовавши": ["королевствовав"],
    "королевствование": ["царствование"],
    "король": ["спец", "специалист", "профи", "профессионал", "мастер", "мастак"],
    "король говна и пара": ["трюмный", "начальник говна и пара"],
    "король ремейков": ["король российской эстрады"],
    "король российской эстрады": ["король ремейков"],
    "королёв": ["королевский"],
    "королёк": ["король"],
    "коромыслив": ["коромысливши"],
    "коромысливши": ["коромыслив"],
    "коромысло": ["водонос"],
    "корона": ["монархия", "коронавирус", "ковид", "ковидла", "коронавир", "барановирус"],
    "корона-": ["ковид-"],
    "коронабесие": ["ковидобесие", "коронаистерия", "коронапаника", "коронапсихоз"],
    "коронавир": ["ковид", "коронавирус", "корона", "ковидла", "барановирус"],
    "коронавирус": ["коронаровирус", "корона", "ковид", "ковидла", "коронавир", "барановирус"],
    "коронавирусник": ["ковид-больной", "ковидник"],
    "коронагоспиталь": ["ковидарий", "ковид-больница", "ковид-госпиталь", "ковид-клиника", "ковидник", "ковидница", "ковид-стационар", "ковид-центр"],
    "коронадиссидент": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронаскептик"],
    "коронаистерия": ["ковидобесие", "коронапаника", "коронапсихоз"],
    "коронакризис": ["ковид-кризис", "ковидокризис"],
    "коронапандемия": ["коронаэпидемия"],
    "коронапаника": ["ковидобесие", "коронаистерия", "коронапсихоз"],
    "коронапациент": ["ковид-пациент"],
    "коронапсихоз": ["ковидобесие", "коронаистерия", "коронапаника"],
    "коронаросклероз": ["коронарокардиосклероз"],
    "коронаскептик": ["антиковидник", "ковид-диссидент", "ковидиот", "ковид-нигилист", "ковидодиссидент", "ковидоскептик", "ковид-отрицатель", "ковид-скептик", "коронадиссидент"],
    "коронатест": ["ковид-тест"],
    "коронафобия": ["ковидофобия"],
    "коронационный": ["короновальный"],
    "коронация": ["коронование"],
    "коронаэпидемия": ["коронапандемия"],
    "коронзон": ["хоронзон"],
    "коронный": ["королевский", "излюбленный", "фирменный"],
    "короновав": ["короновавши"],
    "короновавши": ["короновав"],
    "короновальный": ["коронационный"],
    "коронованье": ["коронование"],
    "коропичь": ["коропъ"],
    "коропъ": ["коропичь"],
    "коростель": ["дергач", "дергун"],
    "коротав": ["коротавши"],
    "коротавши": ["коротав"],
    "коротать": ["проводить", "проживать"],
    "коротенько": ["быстро", "сжато"],
    "коротив": ["коротивши"],
    "коротивши": ["коротив"],
    "коротить": ["укорачивать"],
    "короткий": ["краткий", "недолгий", "кратковременный", "невысокий", "низкий", "приземистый", "немногословный", "близкий", "доверительный"],
    "короткий день": ["укороченный рабочий день"],
    "коротко": ["кратко", "вкратце", "сжато", "накоротко", "близко"],
    "короткоголовость": ["брахицефалия"],
    "короткое замыкание": ["кз"],
    "короткозамыкатель": ["закорачиватель"],
    "короткометр": ["короткометражка"],
    "короткометражка": ["короткометражный фильм", "короткометр"],
    "короткометражный фильм": ["короткометражка", "короткометр"],
    "коротконогость": ["брахискелия"],
    "короткопалость": ["брахидактилия"],
    "короткоствол": ["пистолет", "пушка"],
    "короткошёрстный": ["короткошёрстый", "мелкошёрстный", "мелкошёрстый"],
    "короткошёрстый": ["короткошёрстный"],
    "коротнув": ["коротнувши"],
    "коротнувши": ["коротнув"],
    "коротнуть": ["закоротить"],
    "коротыш": ["коротышка", "карлик", "лилипут"],
    "коротышка": ["коротыш", "недоросток", "шибздик", "шпендрик", "малыш", "подросток", "недомерок"],
    "короче": ["кратче"],
    "короёбочка": ["коробочка"],
    "корпев": ["корпевши"],
    "корпевши": ["корпев"],
    "корпеть": ["трудиться", "копаться", "ковыряться"],
    "корпия": ["линт"],
    "корпоратив": ["корпорат"],
    "корпоративка": ["корпоратив"],
    "корпоратократия": ["корпократия"],
    "корпорация": ["цех", "компания", "фирма", "ассоциация"],
    "корпулентность": ["упитанность", "дородность", "тучность"],
    "корпулентный": ["дородный", "тучный", "упитанный", "тушистый"],
    "корпункт": ["корреспондентский пункт"],
    "корпус": ["туловище", "торс", "стан", "оболочка", "здание", "строение", "шасси", "масса", "земля", "заземление"],
    "корр": ["корреспондент"],
    "коррадировав": ["коррадировавши"],
    "коррадировавши": ["коррадировав"],
    "коррегировав": ["коррегировавши"],
    "коррегировавши": ["коррегировав"],
    "коррекс": ["блистер"],
    "корректива": ["корректив", "поправка"],
    "корректировав": ["корректировавши"],
    "корректировавши": ["корректировав"],
    "корректировка": ["корректирование", "коррекция"],
    "корректный": ["правильный", "верный", "точный"],
    "коррекция": ["исправление", "откат"],
    "коррелировав": ["коррелировавши"],
    "коррелировавши": ["коррелировав"],
    "коррелированный": ["взаимосвязанный", "зависимый"],
    "коррелометр": ["коррелограф"],
    "коррелятивный": ["соотносительный", "корреспондирующий"],
    "корреляция": ["взаимосвязь"],
    "корреспондент": ["репортёр"],
    "корреспондентка": ["журналистка", "рабкорка", "репортёрша"],
    "корреспонденция": ["сообщение"],
    "корреспондировав": ["корреспондировавши"],
    "корреспондировавши": ["корреспондировав"],
    "корреспондировать": ["переписываться", "соответствовать", "соотноситься"],
    "корригировав": ["корригировавши"],
    "корригировавши": ["корригировав"],
    "корригировать": ["корректировать", "исправлять", "поправлять", "подправлять", "рихтовать"],
    "коррида": ["бой быков"],
    "корродировав": ["корродировавши"],
    "корродировавши": ["корродировав"],
    "корродирование": ["коррозия"],
    "корродировать": ["коррозировать"],
    "коррозиестойкий": ["коррозионностойкий", "коррозиеустойчивый", "коррозийно-стойкий", "коррозийно-устойчивый", "коррозионно-стойкий", "коррозионно-устойчивый"],
    "коррозиеустойчивый": ["коррозиестойкий"],
    "коррозийно-стойкий": ["коррозиестойкий", "коррозийно-устойчивый", "коррозионно-стойкий", "коррозионно-устойчивый"],
    "коррозионно-стойкий": ["коррозиестойкий", "коррозийно-стойкий", "коррозийно-устойчивый", "коррозионно-устойчивый"],
    "коррозионностойкий": ["коррозиестойкий", "коррозийно-стойкий", "коррозийно-устойчивый", "коррозионно-устойчивый"],
    "коррозировав": ["коррозировавши"],
    "коррозировавши": ["коррозировав"],
    "коррозия": ["корродирование", "ржавление"],
    "коррумпировав": ["коррумпировавши"],
    "коррумпировавши": ["коррумпировав"],
    "коррумпированный": ["подкупленный", "продажный", "купленный", "подкупный", "подмазанный", "подмасленный"],
    "коррупциогенный фактор": ["коррупциогенная поправка"],
    "коррупционер": ["взяточник", "коррумпант"],
    "коррупция": ["продажность", "подкупность"],
    "корсак": ["китаёза"],
    "корсар": ["пират", "флибустьер"],
    "корсарство": ["пиратство"],
    "кортеж": ["поезд", "процессия", "эскорт", "шествие", "сопровождение", "конвой", "кавалькада", "строка"],
    "кортекс": ["кора головного мозга"],
    "кортиев орган": ["спиральный орган"],
    "кортизол": ["гидрокортизон"],
    "кортик": ["кинжал"],
    "кортикальный": ["корковый"],
    "кортикоид": ["кортикостероид"],
    "кортиколиберин": ["кортикорелин"],
    "кортикостероид": ["кортикоид"],
    "кортомив": ["кортомивши"],
    "кортомивши": ["кортомив"],
    "корточки": ["корт"],
    "коруба": ["хралупа"],
    "корч": ["штевень", "коряга", "драндулет", "ведро"],
    "корча": ["судорога", "конвульсия", "спазм"],
    "корчажка": ["корчага"],
    "корчевав": ["корчевавши"],
    "корчевавши": ["корчевав"],
    "корчевать": ["выкорчёвывать"],
    "корчевье": ["корча"],
    "корчемник": ["корчмарь", "шинкарь"],
    "корчемница": ["шинкарка", "корчма"],
    "корчемничав": ["корчемничавши"],
    "корчемничавши": ["корчемничав"],
    "корчив": ["корчивши"],
    "корчивши": ["корчив"],
    "корчиться": ["извиваться", "содрогаться", "изгибаться"],
    "корчма": ["трактир", "харчевня", "шинок", "кабак"],
    "корчмар": ["шинкар"],
    "корчмарь": ["корчемник", "трактирщик", "харчевник"],
    "корчёвка": ["корчевание"],
    "коршун": ["коршак"],
    "коры": ["как"],
    "корыстолюбивость": ["корыстолюбие"],
    "корыстолюбие": ["жадность", "любостяжание"],
    "корыстолюбье": ["корыстолюбие"],
    "корысть": ["алчность", "прибыль", "выгода"],
    "корытничав": ["корытничавши"],
    "корытничавши": ["корытничав"],
    "корыто": ["лохань"],
    "корючив": ["корючивши"],
    "корючивши": ["корючив"],
    "корябав": ["корябавши"],
    "корябавши": ["корябав"],
    "корябать": ["карябать", "калякать", "карякать"],
    "корябнув": ["корябнувши"],
    "корябнувши": ["корябнув"],
    "корявый": ["искривлённый", "узловатый", "шероховатый", "загрубевший", "грубый"],
    "коряга": ["корча", "кокора", "карч", "карча", "карша", "вакора", "замоина"],
    "корякский автономный округ": ["корякия", "корякский национальный округ"],
    "корячив": ["корячивши"],
    "корячивши": ["корячив"],
    "корёжив": ["корёживши"],
    "корёживши": ["корёжив"],
    "корёжить": ["корчевать", "уродовать", "коробить", "корчить"],
    "кос": ["косс"],
    "косанув": ["косанувши"],
    "косанувши": ["косанув"],
    "косарь": ["косильщик", "косец"],
    "косвенно": ["опосредованно"],
    "косвенность": ["опосредованность"],
    "косвенный": ["косой", "наклонный", "опосредованный", "непрямой", "побочный"],
    "косев": ["косевши"],
    "косевши": ["косев"],
    "косец": ["косес"],
    "коси": ["сапт-коси", "гхугри"],
    "косив": ["косивши"],
    "косивши": ["косив"],
    "косильщик": ["косарь"],
    "косина": ["косоглазие", "косость", "кривизна", "перекос", "искривление"],
    "косить": ["скашивать", "валить с ног", "морить"],
    "коситься": ["кривиться"],
    "косица": ["косичка", "прядка", "прядь", "висок", "откос", "угол"],
    "косичка": ["коса", "выноска", "выкидыш"],
    "косма": ["кузьма"],
    "косматев": ["косматевши"],
    "косматевши": ["косматев"],
    "косматив": ["космативши"],
    "космативши": ["косматив"],
    "косматить": ["взъерошивать", "лохматить"],
    "косматость": ["лохматость"],
    "косматый": ["лохматый", "мохнатый", "патлатый"],
    "космач": ["лохмач"],
    "косметика": ["косметология", "украшение"],
    "космический": ["вселенский", "мировой", "междупланетный", "грандиозный"],
    "космический аппарат": ["космолёт", "космический корабль"],
    "космический корабль": ["космолёт"],
    "космогенный": ["метеоритный"],
    "космография": ["география"],
    "космолёт": ["космический корабль"],
    "космонавт": ["космоплаватель", "звездоплаватель"],
    "космонавтика": ["астронавтика", "космоплавание", "звездоплавание"],
    "космонавтка": ["астронавтка"],
    "космоним": ["астроним"],
    "космополит": ["гражданин мира"],
    "космополитизм": ["безнационализм"],
    "космополитизъм": ["безнационализъм"],
    "космопорт": ["космодром"],
    "космос": ["мир", "вселенная", "космическое пространство"],
    "космофизика": ["астрофизика"],
    "космохлор": ["юриит", "крейит"],
    "космы": ["лохмы", "клочья"],
    "косная лодка": ["косная", "косовая", "косовая лодка"],
    "коснев": ["косневши"],
    "косневши": ["коснев"],
    "косно": ["ретроградски"],
    "косность": ["консерватизм", "ретроградство"],
    "косноязыкий": ["косноязычный"],
    "косноязычив": ["косноязычивши"],
    "косноязычивши": ["косноязычив"],
    "косноязычие": ["косноязычье", "неотчётливость", "невнятность", "нечленораздельность", "неблагозвучие", "неблагозвучье", "безъязыкость", "неразборчивость", "заикание", "заиканье", "дислалия", "батаризм"],
    "косноязычно": ["косноязыко"],
    "косноязычный": ["косноязыкий", "с кашей во рту", "нечленораздельный"],
    "коснуться": ["дотронуться", "прикоснуться", "тронуть", "докоснуться", "упомянуть", "затронуть"],
    "косный": ["малоподвижный", "ленивый", "медлительный", "отсталый", "рутинный", "консервативный", "застарелый"],
    "кособочив": ["кособочивши"],
    "кособочивши": ["кособочив"],
    "косовица": ["косьба"],
    "косово": ["республика косово", "косовский вилайет"],
    "косовоалбанец": ["косовар"],
    "косоглазие": ["косоглазость", "гетеротропия", "страбизм"],
    "косогор": ["откос", "гора"],
    "косолапив": ["косолапивши"],
    "косолапивши": ["косолапив"],
    "косопад": ["оплешивяване", "алопеция"],
    "косорезив": ["косорезивши"],
    "косорезивши": ["косорезив"],
    "косорукий": ["криворукий"],
    "косорукой": ["косорукий"],
    "косорылиться": ["кривиться", "косомордиться", "косоротиться", "возиться", "копаться", "копошиться"],
    "кососимметричность": ["антисимметричность"],
    "косоур": ["ходовая полоса"],
    "косоёбив": ["косоёбивши"],
    "косоёбивши": ["косоёбив"],
    "косплеер": ["косплейщик"],
    "косплеерша": ["косплейщица"],
    "косплеив": ["косплеивши"],
    "косплеивши": ["косплеив"],
    "косплей": ["кастплей"],
    "косплейщик": ["косплеер"],
    "костенев": ["костеневши"],
    "костеневши": ["костенев"],
    "костенеть": ["окостеневать"],
    "костенец": ["костянец", "асплений"],
    "костеобразование": ["остеогенез"],
    "костеобразующий": ["остеогенный"],
    "костер": ["бирдекель", "бирмат"],
    "костерезный": ["косторезный"],
    "костерив": ["костеривши"],
    "костеривши": ["костерив"],
    "костерить": ["бранить", "ругать"],
    "костерок": ["костёрчик"],
    "костехранилище": ["оссуарий", "костница"],
    "кости": ["кубики", "игра", "останки", "прах"],
    "костив": ["костивши"],
    "костивши": ["костив"],
    "костилка": ["кокичка", "семка"],
    "костить": ["бранить", "костерить", "поносить"],
    "костка": ["кость"],
    "костлявая": ["смертная", "безносая", "курносая", "старуха с клюкой", "старуха с косой"],
    "костлявый": ["худой"],
    "костная мука": ["мясокостная мука"],
    "костница": ["оссуарий"],
    "костоеда": ["кариес"],
    "костолом": ["костоломка"],
    "косторез": ["костерез"],
    "косторезный": ["костерезный"],
    "косточка": ["кость"],
    "костра": ["кострика", "костица", "костеря"],
    "кострец": ["ягодица", "костёр"],
    "костромич": ["костромчанин", "костромичанин", "костромитянин", "костромитин"],
    "костромской": ["костромич"],
    "костур": ["милиця"],
    "костык": ["кочедык"],
    "костыль": ["опора", "гвоздь", "хак", "заплатка", "патч"],
    "костыляв": ["костылявши"],
    "костылявши": ["костыляв"],
    "кость": ["останки", "прах", "материал", "происхождение", "порода", "телосложение", "костяк", "косточка", "семя", "ядро", "игральная кость", "игральный кубик", "костяшка", "доминошка", "домино"],
    "костьё": ["кожа да кости"],
    "костюм": ["лепень", "лепёха"],
    "костюм евы": ["ню", "обнажёнка", "костюм адама"],
    "костюмировав": ["костюмировавши"],
    "костюмировавши": ["костюмировав"],
    "костянка": ["косточковый плод"],
    "костёр": ["башня"],
    "костёрчик": ["костерок"],
    "косуля": ["козуля", "дикая коза", "косуля европейская", "коза", "косули"],
    "косуха": ["косушка", "шкалик", "чекушка", "косарь", "косая", "штука"],
    "косушка": ["четвертушка", "чекушка", "шкалик", "косуха"],
    "косъм": ["косъмче", "влакно", "влакънце", "власинка"],
    "косьба": ["покос"],
    "коське": ["коськф", "пужф", "ташта", "калгода", "мяльфтома", "кельме"],
    "косяк": ["клин", "джойнт", "оплошность", "недочёт", "изъян", "огрех", "недоработка", "промах", "промашка", "просчёт", "нарекание", "погрешность", "прегрешение", "нарушение", "недостаток"],
    "косяком": ["наискосок", "наискось"],
    "косячив": ["косячивши"],
    "косячивши": ["косячив"],
    "косячить": ["допускать ошибки", "портачить", "ошибаться"],
    "косячник": ["табунщик"],
    "кот": ["котяра", "киса", "котейка", "кошак", "кошара", "котэ", "котик", "морской котик", "морской кот", "скат", "хвостокол", "бабник", "тачпад", "сутенёр"],
    "кот в мешке": ["тёмная лошадка"],
    "котарнин": ["оксиметилгидрастин"],
    "котва": ["якорь", "верп"],
    "котейка": ["котофейка"],
    "котека": ["холим"],
    "котелка": ["палка"],
    "котелок не варит": ["голова не варит", "не все дома"],
    "котельная": ["бойлерная", "кочегарка"],
    "котельщик": ["котельник", "клепальщик"],
    "котив": ["котивши"],
    "котивши": ["котив"],
    "котик": ["котенька", "котофей", "коток", "кошечка", "морской котик"],
    "котировав": ["котировавши"],
    "котировавши": ["котировав"],
    "котишка": ["котик", "котёнок"],
    "котище": ["котяра"],
    "котлован": ["углубление", "выемка"],
    "котлы": ["часы"],
    "котовав": ["котовавши"],
    "котовавши": ["котовав"],
    "котовник": ["котовик", "будра плющевидная", "будра стелющаяся", "сороканедужник", "собачья мята", "котятник"],
    "коток": ["котенька", "котофей", "котик"],
    "котокафе": ["кошачье кафе"],
    "котонизировав": ["котонизировавши"],
    "котонизировавши": ["котонизировав"],
    "котообразный": ["кошкообразный"],
    "котофей": ["котяра", "котище", "кошак"],
    "коттедж": ["вилла"],
    "коту под хвост": ["впустую", "насмарку", "зазря", "втуне", "напрасно", "понапрасну", "псу под хвост"],
    "котурн": ["платформы", "обувь"],
    "котух": ["хлев", "гайно", "баз", "гайнище", "ганьище", "гойно", "овчарня", "телятник", "свинарник", "свинятник", "сарай", "конура"],
    "котэ": ["кот", "кошак", "котяра"],
    "котюга": ["собака", "пес"],
    "котяра": ["котище"],
    "котёл": ["казан", "мешок", "кольцо"],
    "коуч": ["коучер"],
    "кофактор": ["кофермент"],
    "кофе": ["кофейное дерево", "кофий", "кофей"],
    "кофе-брейк": ["кофе-пауза"],
    "кофе-пауза": ["кофе-брейк"],
    "кофевар": ["бариста"],
    "кофеин": ["матеин", "теин", "гуаранин"],
    "кофей": ["кофий", "кофе"],
    "кофейная": ["кофейня"],
    "кофейничав": ["кофейничавши"],
    "кофейничавши": ["кофейничав"],
    "кофемат": ["кофейный автомат"],
    "кофермент": ["коэнзим", "кофактор"],
    "кофешенк": ["бариста"],
    "кофий": ["кофе"],
    "кофраж": ["рамка", "скелет", "структура", "шаси", "рама"],
    "кофта": ["пальто", "ночнушка"],
    "коффердам": ["оптидам", "раббердам"],
    "кохав": ["кохавши"],
    "кохавши": ["кохав"],
    "коханець": ["кохан", "коханок", "полюбовник", "ласкавець"],
    "коханка": ["коханочка", "дроля"],
    "кохання": ["любов"],
    "кохання з першого погляду": ["любов з першого погляду"],
    "кохати": ["любити", "плекати"],
    "кохен": ["коэн", "коген"],
    "кохия": ["прутняк"],
    "коцав": ["коцавши"],
    "коцавши": ["коцав"],
    "коцать": ["повреждать", "портить", "убивать"],
    "коцит": ["кокитос"],
    "коч": ["коча", "кочмара"],
    "кочан": ["вилок", "кочень", "кочерыжка", "кочешок", "початок"],
    "кочевав": ["кочевавши"],
    "кочевавши": ["кочевав"],
    "кочеванье": ["кочевание"],
    "кочевать": ["кочевничать"],
    "кочевник": ["номад"],
    "кочевничав": ["кочевничавши"],
    "кочевничавши": ["кочевничав"],
    "кочевничество": ["номадизм"],
    "кочевой": ["номадный"],
    "кочеврыга": ["кочерыга", "кочерыжка"],
    "кочевряжиться": ["кривляться", "ломаться", "чиниться", "артачиться", "кобениться", "корячиться", "ерепениться", "важничать", "выделываться", "выламываться", "дурачиться"],
    "кочегар": ["истопник"],
    "кочегарив": ["кочегаривши"],
    "кочегаривши": ["кочегарив"],
    "кочегарка": ["котельная", "кочегарня"],
    "кочедык": ["кочедыг"],
    "коченев": ["коченевши"],
    "коченевши": ["коченев"],
    "коченеть": ["зябнуть", "застывать", "стынуть", "стыть"],
    "коченив": ["коченивши"],
    "коченивши": ["коченив"],
    "кочень": ["кочан", "кочерыжка"],
    "кочерыга": ["кочеврыга", "кочерыжка"],
    "кочияш": ["колар", "файтонджия"],
    "кочка": ["бугорок"],
    "кочкарник": ["биль", "калтус"],
    "кочкор": ["аркар"],
    "кочумав": ["кочумавши"],
    "кочумавши": ["кочумав"],
    "кочь": ["коч"],
    "кош": ["корзина", "кошница", "шалаш", "балаган", "загон", "овчарня"],
    "кошак": ["кот"],
    "кошара": ["овчарня"],
    "кошатина": ["кошка"],
    "кошатник": ["живодёр"],
    "кошева": ["кошевая", "кошёвка"],
    "кошель": ["калита", "кошелёк"],
    "кошелёк": ["сарацинский кисет", "кошелёчек", "портмоне", "бумажник", "купюрник", "шмель", "карман", "доход"],
    "кошемар": ["кошмар"],
    "кошениль": ["кошенильный червец"],
    "кошеня": ["котеня", "котя"],
    "кошерный": ["кашарный", "коширный", "приемлемый"],
    "кошечий": ["кошачий"],
    "кошечка": ["киска", "кисонька"],
    "кошка": ["домашняя кошка", "киса", "киска", "мурка"],
    "кошкар": ["коцкар"],
    "кошке под муда": ["в жопу под муда"],
    "кошкин": ["кошачий"],
    "кошкодав": ["кошатник", "кошкодёр"],
    "кошкодевочка": ["кошкодевка", "нека", "неко", "нэко", "нэкомусумэ"],
    "кошкодёр": ["кошкодав", "кошатник"],
    "кошмар": ["кошемар"],
    "кошмарив": ["кошмаривши"],
    "кошмаривши": ["кошмарив"],
    "кошмарить": ["чморить", "чмырить", "терроризировать", "стращать", "ужасать"],
    "кошмарний": ["жахливий"],
    "кошмарный": ["жуткий", "ужасный", "зверский", "отталкивающий", "отвратительный"],
    "кошмарный сон": ["кошмар", "страшный сон"],
    "кошница": ["корзина"],
    "кошт": ["иждивение", "питание", "довольствие"],
    "коштувати": ["обходитися"],
    "кошурка": ["кошечка"],
    "кощеев": ["кощеевый"],
    "кощеевый": ["кощеев"],
    "кощей": ["кощей бессмертный"],
    "кощунник": ["святотатец", "кощун", "богохульник"],
    "кощунница": ["богохульница"],
    "кощунственно": ["глумливо", "надругательски", "святотатственно"],
    "кощунственный": ["святотатственный"],
    "кощунство": ["надругательство", "святотатство"],
    "кощунствовав": ["кощунствовавши"],
    "кощунствовавши": ["кощунствовав"],
    "коэволюция": ["соэволюция"],
    "коэн": ["коген", "кохен"],
    "коэнзим": ["кофермент"],
    "коэф": ["кэф"],
    "коэффициент": ["показатель", "фактор", "параметр", "множитель"],
    "коэффициент полезного действия": ["кпд"],
    "коэффициент стоячей волны": ["ксв"],
    "коярга": ["агызырга"],
    "кояш торгынлыгы": ["кояш торышы"],
    "кпд": ["коэффициент полезного действия"],
    "кпереди": ["вперёд"],
    "кпз": ["изолятор", "туалет", "сортир", "комплекс с переносом заряда"],
    "кпини": ["кепкування"],
    "кпп": ["коробка передач"],
    "кпсс": ["рсдрп", "ркп", "партия"],
    "крааль": ["бома", "загон", "поселение"],
    "крабий": ["крабовый"],
    "крабовый": ["крабий"],
    "кравай": ["геврек"],
    "крават": ["галстук", "шарф", "платок"],
    "кравецтво": ["кравцювання"],
    "кравцювання": ["кравецтво"],
    "кравчик": ["головач"],
    "кравчиня": ["кравчиха"],
    "кравчучка": ["кучмовоз"],
    "краденый": ["ворованный", "украденный"],
    "крадец": ["крадач"],
    "крадешком": ["скришом"],
    "крадун": ["вор"],
    "крадучись": ["украдкой", "крадчи"],
    "крадёж": ["кража"],
    "краеведение": ["регионоведение", "история"],
    "краеведенье": ["краеведение"],
    "краегранесие": ["акростих"],
    "краеугольный": ["главный"],
    "кража": ["воровство", "хищение"],
    "край": ["конец", "оконечность", "предел", "периферия", "окраина", "страна", "область", "местность"],
    "крайбюро": ["краевой", "бюро"],
    "крайне": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "весьма", "сверх меры", "избыточно", "чрезвычайно", "изрядно", "в высшей степени", "необычайно", "в значительной мере", "зело"],
    "крайнебо": ["небосхил", "горизонт"],
    "крайний": ["предельный", "чрезвычайный", "необычайный", "заключительный", "козёл отпущения", "стрелочник"],
    "крайность": ["экстремальность", "противоположность"],
    "крайняя плоть": ["препуций", "залупа"],
    "крак": ["нога"],
    "кракер": ["крякер", "крэкер"],
    "краков": ["город королей"],
    "кракус": ["краковяк", "краковянин"],
    "кракуска": ["уланка", "конфедератка", "краковянка"],
    "крал": ["цар", "господар", "стопанин", "повелител"],
    "краля": ["красотка"],
    "крамарь": ["коробейник", "разносчик"],
    "краматорск": ["краматорская"],
    "крамола": ["бунт", "мятеж", "смута", "восстание"],
    "крамольник": ["беззаконник", "бунтовщик", "мятежник"],
    "крамольничав": ["крамольничавши"],
    "крамольничавши": ["крамольничав"],
    "крамольный": ["бунтарский", "мятежный", "подрывной"],
    "крамповав": ["крамповавши"],
    "крамповавши": ["крамповав"],
    "кран": ["водопроводный кран", "глаголь", "подъёмный кран"],
    "кран-балка": ["автоэвакуатор", "кранбалка"],
    "кран-букса": ["вентильная головка"],
    "кранбалка": ["кран-балка"],
    "кранец": ["кранц", "фендерс"],
    "краниальный": ["передний", "головной", "капитальный", "ростральный"],
    "краниометр": ["цефалометр", "черепомерка"],
    "краниосиностоз": ["краниостеноз"],
    "краниостеноз": ["краниосиностоз"],
    "крановой": ["крановый", "крановщик", "машинист"],
    "крановый": ["крановой"],
    "крант": ["кран"],
    "крантик": ["кран", "краник"],
    "кранты": ["капут", "каюк", "кирдык", "конец", "крышка", "конец всему"],
    "кранч": ["переработка"],
    "крап": ["рябь", "рубашка"],
    "крапав": ["крапавши"],
    "крапавши": ["крапав"],
    "крапание": ["крапанье", "капание"],
    "крапать": ["капать", "крапить"],
    "крапив": ["крапивши"],
    "крапива": ["жалива", "жегала", "жигалка", "стрекава", "стрекавка"],
    "крапивная лихорадка": ["крапивная сыпь", "крапивница", "уртикария"],
    "крапивник": ["подкоренник", "орешек"],
    "крапивница": ["уртикария", "крапивная лихорадка", "крапивная сыпь"],
    "крапивное семя": ["ублюдок", "бастард", "выблядок", "выебок"],
    "крапивные щи": ["зелёные щи"],
    "крапивши": ["крапив"],
    "крапинка": ["точка", "пятнышко"],
    "крапить": ["вкрапливать"],
    "краплак": ["ализарин"],
    "краповый": ["мареновый", "ярко-красный"],
    "крапп": ["марена"],
    "краса": ["красота", "украшение", "красавица", "прелесть"],
    "красавица": ["красотка", "симпотница", "прелесть"],
    "красавчик": ["красавец", "молодец", "красава"],
    "красив": ["красивши"],
    "красивее": ["привлекательнее", "краше", "красивше"],
    "красивейший": ["великолепнейший", "прекрасный", "великолепный", "прекраснейший", "дивный", "изумительный"],
    "красивий": ["гарний"],
    "красивость": ["привлекательность"],
    "красивши": ["красив"],
    "красивый": ["симпатичный", "очаровательный", "прекрасный", "пригожий", "смазливый", "миловидный", "красивущий"],
    "красить": ["окрашивать", "расцвечивать", "украшать"],
    "краска": ["краситель", "пигмент", "цвет", "оттенок", "тон", "румянец", "менструации", "месячные", "покраска"],
    "красная армия": ["рабоче-крестьянская красная армия", "ркка"],
    "красная головка": ["красноголовик", "подосиновик", "клевер", "красненькая головка"],
    "красная жопа": ["коммуняка", "коммуняга"],
    "красная зона": ["красная крытая", "ментовская зона"],
    "красная линия": ["центральная линия", "средняя линия"],
    "краснев": ["красневши"],
    "красневши": ["краснев"],
    "красненькая": ["десятка", "десятерик"],
    "красненькая головка": ["красная головка", "клевер"],
    "краснеть": ["алеть", "румяниться", "пунцоветь", "багроветь", "розоветь", "стыдиться", "испытывать стыд"],
    "красника": ["вакциниум превосходный", "дымника", "клоповка"],
    "красно-бурый": ["краснобурый"],
    "красно-зелёные": ["кони"],
    "красно-коричневый": ["коммунофашистский"],
    "красно-синие": ["армейцы"],
    "краснобай": ["пустозвон", "пустослов", "говорун", "вития", "ритор", "фразёр"],
    "краснобайствовав": ["краснобайствовавши"],
    "краснобайствовавши": ["краснобайствовав"],
    "красновато-жёлтый": ["красно-жёлтый", "охристый"],
    "красновато-коричневый": ["пюсовый"],
    "красновато-синий": ["фиолетовый"],
    "красноволосый": ["рыжеволосый"],
    "красногалстучник": ["пионер"],
    "красноглинистый": ["красноглиняный"],
    "красноголовик": ["подосиновик"],
    "красноград": ["константиноград"],
    "краснодар": ["екатеринодар"],
    "краснодарский край": ["кубань"],
    "краснодеревец": ["краснодеревщик"],
    "краснодеревщик": ["краснодеревец"],
    "красное": ["красное вино"],
    "красное вино": ["красное"],
    "красное море": ["чермное море"],
    "краснокнижник": ["краснокнижница"],
    "краснокнижница": ["краснокнижник"],
    "краснокнижный": ["охраняемый"],
    "краснокочанная капуста": ["красная капуста"],
    "краснолесье": ["красный лес", "бор"],
    "красномордый": ["краснолицый"],
    "красноперекопск": ["яны капу"],
    "краснопиджачник": ["новые русские"],
    "краснопогодье": ["вёдро"],
    "красноречивость": ["красноречие", "выразительность", "наглядность"],
    "красноречие": ["витийство", "риторика"],
    "краснословье": ["краснословие"],
    "краснота": ["красность", "покраснение"],
    "краснотал": ["ива остролистная", "красная верба", "шелюга"],
    "красноярск": ["город на енисее", "красный яр"],
    "краснуха": ["краснуха коревая", "краснуха скарлатинозная"],
    "красный волк": ["горный волк", "гималайский волк", "буанзу"],
    "красный галстук": ["пионерский галстук", "красная косынка", "красная косыночка", "ошейник"],
    "красный зверь": ["косолапый"],
    "красный лиман": ["лиман"],
    "красный партизан": ["клоп"],
    "красный перец": ["горький перец", "перец чили"],
    "красный угол": ["большой угол", "передний угол", "образной угол", "честной угол"],
    "красный чулок": ["шалава", "прошмандовка", "блядь", "блядина", "блядища", "проблядь"],
    "красовав": ["красовавши"],
    "красовавши": ["красовав"],
    "красоднев": ["лилейник жёлтый", "жёлтая лилия"],
    "красота": ["краса", "великолепие", "лепота", "красивость"],
    "красочность": ["цветистость"],
    "красть": ["воровать", "похищать"],
    "красться": ["подкрадываться", "подбираться"],
    "крат": ["раз"],
    "кратенький": ["коротенький"],
    "кратима": ["краттра"],
    "краткий": ["непродолжительный", "недолгий", "короткий", "сжатый", "немногословный"],
    "кратко": ["коротко"],
    "кратковременно": ["недолговременно"],
    "кратковременный": ["непродолжительный"],
    "краткосрочный": ["короткий", "краткий", "недолгий", "непродолжительный", "кратковременный", "недолговременный", "ограниченный", "ближайший", "неотдалённый", "недалёкий", "ближний"],
    "краткотрайност": ["мимолетност", "кратковременност", "краткост"],
    "кратно": ["повторно", "в разы"],
    "кратон": ["кратоген"],
    "кратък": ["къс"],
    "краудсорсив": ["краудсорсивши"],
    "краудсорсивши": ["краудсорсив"],
    "краудфандив": ["краудфандивши"],
    "краудфандивши": ["краудфандив"],
    "краудфандинг": ["народное финансирование"],
    "краудшуранс": ["взаимозащита"],
    "крафтинг": ["ремесло", "создание"],
    "крафтить": ["мастерить", "сооружать", "изготавливать", "создавать", "делать"],
    "крах": ["разорение", "банкротство"],
    "крах культуры": ["парк культуры имени отдыха", "прах культуры"],
    "крахмал": ["скорбило"],
    "крахмалив": ["крахмаливши"],
    "крахмаливши": ["крахмалив"],
    "крахмалосодержащий": ["крахмалсодержащий"],
    "краш": ["увлечение", "страсть", "возлюбленный", "любимый"],
    "краше": ["красивее"],
    "краше в гроб кладут": ["лица нет", "в чём душа держится"],
    "крашеный": ["крашенный"],
    "крашенье": ["крашение"],
    "крашиха": ["возлюбленная"],
    "краюха": ["краюшка"],
    "краюшка": ["краюха"],
    "краянин": ["земляк"],
    "креативив": ["креатививши"],
    "креатививши": ["креативив"],
    "креатинкиназа": ["креатинфосфокиназа", "кфк"],
    "креатинфосфат": ["фосфокреатин", "креатинфосфорная кислота"],
    "креатинфосфокиназа": ["креатинкиназа", "кфк"],
    "креатинфосфорная кислота": ["креатинфосфат", "фосфокреатин"],
    "креатор": ["креативщик", "криейтор"],
    "креатура": ["ставленник", "ставленница"],
    "креват": ["легло", "одър", "постеля"],
    "креветка": ["криль"],
    "кредит": ["расход"],
    "кредитив": ["кредитное письмо", "аккредитив"],
    "кредитная гарантия": ["банковская гарантия"],
    "кредитная организация": ["кредитное учреждение"],
    "кредитный рейтинг": ["рейтинг кредитоспособности"],
    "кредитовав": ["кредитовавши"],
    "кредитовавши": ["кредитовав"],
    "кредитовать": ["одалживать"],
    "кредитоспособность": ["платёжеспособность"],
    "кредо": ["символ веры", "убеждения"],
    "крез": ["богач", "толстосум", "богатей"],
    "крезол": ["метилфенол", "гидрокситолуол"],
    "крейдовий": ["крейдяний"],
    "крейзанутый": ["крейзи"],
    "крейсерская скорость": ["оптимальная скорость"],
    "крейсировав": ["крейсировавши"],
    "крейсировавши": ["крейсировав"],
    "крейцкопф": ["ползун"],
    "крекер": ["чипсы"],
    "крекировав": ["крекировавши"],
    "крекировавши": ["крекировав"],
    "креманка": ["вазочка"],
    "кремация": ["кремирование"],
    "крембо": ["шоколадный поцелуй", "поцелуй негра"],
    "кремень": ["кремень-парень"],
    "кремировав": ["кремировавши"],
    "кремировавши": ["кремировав"],
    "кремирование": ["кремация"],
    "кремлингейт": ["рашагейт", "руссьягейт"],
    "кремль": ["москва"],
    "кремлёвский решала": ["решало", "решала", "решальщик"],
    "кремнезёмистый": ["кремнезёмный"],
    "кремниевая долина": ["силиконовая долина"],
    "кремний": ["силициум", "силиций"],
    "кремнистый": ["каменистый"],
    "кремнёвый": ["твёрдый", "непреклонный"],
    "крен": ["отклонение"],
    "кренговав": ["кренговавши"],
    "кренговавши": ["кренговав"],
    "крендель": ["завитушка"],
    "кренив": ["кренивши"],
    "кренивши": ["кренив"],
    "крениться": ["клониться", "наклоняться", "накреняться"],
    "креномер": ["кренометр"],
    "креолизировав": ["креолизировавши"],
    "креолизировавши": ["креолизировав"],
    "креп": ["флёр"],
    "креп-жоржетовый": ["жоржетовый"],
    "крепатура": ["синдром отсроченной мышечной боли"],
    "крепжоржет": ["креп-жоржет"],
    "крепив": ["крепивши"],
    "крепивши": ["крепив"],
    "крепировав": ["крепировавши"],
    "крепировавши": ["крепировав"],
    "крепитировав": ["крепитировавши"],
    "крепитировавши": ["крепитировав"],
    "крепить": ["прикреплять", "закреплять", "укреплять", "упрочивать"],
    "крепиться": ["мужаться", "сдерживаться"],
    "крепкий": ["прочный", "надёжный", "устойчивый", "здоровый", "мощный", "сильный", "бодрый", "значительный", "насыщенный", "густой"],
    "крепко": ["прочно", "надёжно"],
    "крепко-накрепко": ["надёжно", "намертво", "крепко", "капитально", "основательно", "прочно", "плотно"],
    "крепкоголовый": ["крепколобый"],
    "крепколобый": ["крепкоголовый"],
    "крепкость": ["крепость", "нерушимость", "твёрдость", "стойкость"],
    "крепленье": ["крепление"],
    "крепнув": ["крепнувши"],
    "крепнувши": ["крепнув"],
    "крепостное право": ["крепостничество"],
    "крепостной": ["крепостнический"],
    "крепость": ["крепкость", "нерушимость", "твёрдость", "стойкость"],
    "крепрашель": ["креп-рашель"],
    "крепчав": ["крепчавши"],
    "крепчавши": ["крепчав"],
    "крепчать": ["усиливаться"],
    "крепыш": ["здоровячок", "кряж", "качок", "сбитень", "огурчик", "здоровяк", "здоровила", "здоровяга", "упрямец", "скряга"],
    "крепёж": ["крепление"],
    "кресав": ["кресавши"],
    "кресавши": ["кресав"],
    "кресать": ["кресить"],
    "кресельце": ["креслице"],
    "кресло-каталка": ["инвалидная коляска", "кресло-коляска", "каталка"],
    "кресло-коляска": ["кресло-каталка", "инвалидная коляска"],
    "кресс-салат": ["клоповник посевной"],
    "крест": ["хер", "страдание", "испытание"],
    "крест-на-крест": ["крестообразно", "крестом", "накрест"],
    "крест-накрест": ["крестообразно", "крестом", "накрест"],
    "крестец": ["крестцовая кость"],
    "крести": ["трефы"],
    "крестив": ["крестивши"],
    "крестивши": ["крестив"],
    "крестик": ["крест", "херик"],
    "крестильница": ["купель"],
    "крестины": ["крещение", "вторые родины"],
    "крестить": ["называть", "нарекать", "обзывать"],
    "креститься": ["делать крестное знамение", "окреститься"],
    "крестовидный": ["крестообразный"],
    "крестовоздвиженье": ["крестовоздвижение"],
    "крестовый": ["трефовый"],
    "крестообразный": ["крестовидный"],
    "крестословица": ["кроссворд"],
    "крестострел": ["октаграмма"],
    "крестоцвет": ["флерон"],
    "крестраж": ["хоркрукс"],
    "кресты": ["бомбей"],
    "крестьянин": ["земледелец", "скотовод", "крепостной", "лапотник"],
    "крестьянин-единоличник": ["единоличник"],
    "крестьянствовав": ["крестьянствовавши"],
    "крестьянствовавши": ["крестьянствовав"],
    "кретен": ["идиот"],
    "кретин": ["тупица", "идиот", "безумный", "дурак", "слабоумный", "идиотина", "дурилка", "дурик", "дегенерат", "недоумок", "маразматик", "олигофрен"],
    "кретинизм": ["атиреоз", "гипотиреоз", "идиотизм", "дурость"],
    "кретонный": ["кретоновый"],
    "кретоновый": ["кретонный"],
    "крехтев": ["крехтевши"],
    "крехтевши": ["крехтев"],
    "кречет": ["сокол благородный"],
    "кречетный": ["кречетовый"],
    "кречётка": ["степная пигалица"],
    "крешендо": ["крещендо"],
    "крещальня": ["баптистерий"],
    "крещендо": ["крешендо"],
    "крещение": ["крещение господне"],
    "крещение господне": ["крещение", "богоявление", "явление"],
    "криббедж": ["криббидж", "крибедж"],
    "кривавиця": ["кров"],
    "кривая": ["линия", "функция"],
    "кривая сжатия": ["компрессионная кривая"],
    "кривев": ["кривевши"],
    "кривевши": ["кривев"],
    "криведный": ["неправедный", "несправедливый"],
    "кривив": ["крививши"],
    "крививши": ["кривив"],
    "кривить душой": ["криводушничать", "лукавить"],
    "кривиться": ["искривляться", "кривляться"],
    "кривляв": ["кривлявши"],
    "кривлявши": ["кривляв"],
    "кривляка": ["жеманник", "жеманница", "ломака"],
    "кривляние": ["кривлянье"],
    "кривлянье": ["кривляние"],
    "кривляться": ["строить рожицы", "жеманиться", "ломаться", "манерничать"],
    "кривобокий": ["кособокий"],
    "криводушие": ["неискренность", "лживость"],
    "криводушничав": ["криводушничавши"],
    "криводушничавши": ["криводушничав"],
    "криводушный": ["двуличный", "лицемерный"],
    "кривожопый": ["жопорукий", "криворукий", "неумелый", "неловкий", "неуклюжий", "нерасторопный"],
    "кривой": ["изогнутый", "неровный", "косой", "асимметричный", "неправильный", "неправедный", "лживый", "одноглазый"],
    "криволицый": ["кривомордый", "криворожий", "криволикий"],
    "кривоногий": ["криволапый"],
    "криворожий": ["криволицый"],
    "криворотый": ["косоротый"],
    "криворукий": ["косорукий", "неумелый"],
    "кривосудие": ["судилище"],
    "кривошейка": ["кривошея"],
    "кривулина": ["кривуля", "кривулька"],
    "кривун": ["меандр", "изгиб", "излучина"],
    "кривуша": ["горбуша"],
    "криейтор": ["креативщик", "креатор"],
    "кризис": ["беда", "обострение", "разорение"],
    "кризис-менеджер": ["антикризисный управляющий"],
    "кризисность": ["критичность"],
    "крик": ["вопль", "восклицание", "возглас", "шум", "писк", "брань", "ругань", "ссора"],
    "крикивав": ["крикивавши"],
    "крикивавши": ["крикивав"],
    "крикливость": ["горластость", "заносчивость"],
    "крикнув": ["крикнувши"],
    "крикнувши": ["крикнув"],
    "крикнуть": ["позвать", "кликнуть"],
    "крикун": ["пустобрёх"],
    "крикуха": ["крикунья", "крикуша", "горлопанка"],
    "криминал": ["преступление", "крамола", "преступник", "преступность", "криминалитет"],
    "криминалац": ["злочинац"],
    "криминализировав": ["криминализировавши"],
    "криминализировавши": ["криминализировав"],
    "криминализировать": ["криминализовать"],
    "криминализовав": ["криминализовавши"],
    "криминализовавши": ["криминализовав"],
    "криминализованный": ["криминализированный"],
    "криминализовать": ["криминализировать"],
    "криминалистика": ["криминология"],
    "криминалитет": ["преступный мир", "преступность", "криминал"],
    "криминально-деловой": ["криминально-коммерческий"],
    "криминально-коммерческий": ["криминально-деловой"],
    "криминальность": ["преступность"],
    "криминальный": ["преступный", "уголовный", "подсудный"],
    "криминальный жаргон": ["феня", "арго"],
    "кримпер": ["пресс"],
    "крин": ["лилия"],
    "кринет": ["криньер"],
    "кринж": ["кукож", "испанский стыд"],
    "кринжовый": ["срамной", "стрёмный"],
    "криница": ["колодец", "родник"],
    "криниченька": ["криничка", "криниця"],
    "кринка": ["крынка"],
    "кринолин": ["гипозома"],
    "криночный": ["крыночный"],
    "криолечение": ["криотерапия"],
    "криолитозона": ["мерзлота"],
    "крионика": ["криогеника"],
    "криопексия": ["криоретинопексия"],
    "криотерапия": ["криолечение"],
    "криофил": ["психрофил"],
    "криоэра": ["гляциоэра"],
    "крип": ["ползучесть"],
    "криперсы": ["криперы"],
    "криперы": ["криперсы"],
    "криповать": ["бояться", "пугаться"],
    "крипово": ["жутко"],
    "криповый": ["жуткий"],
    "крипота": ["жуть"],
    "криптатоклатрат": ["криптато-клатрат"],
    "криптический": ["защитный", "покровительственный"],
    "криптобиоз": ["анабиоз"],
    "криптовалюта": ["крипта"],
    "криптовалютное сообщество": ["криптосообщество"],
    "криптогам": ["тайнобрачное растение"],
    "криптогамия": ["тайнобрачие"],
    "криптогенный": ["идиопатический"],
    "криптограмма": ["шифровка", "шифротекст"],
    "криптоеврей": ["крипт"],
    "криптозой": ["докембрий", "докембрийский период"],
    "криптолалия": ["неоглоссия"],
    "криптомонета": ["криптовалюта"],
    "криптоним": ["тайное имя", "подпись", "псевдоним"],
    "криптонимический": ["криптонимный"],
    "крипторитм": ["альфаметик"],
    "крипторубль": ["битрубль"],
    "крипторхизм": ["крипторхидизм", "крипторхидия"],
    "криптотекст": ["шифртекст", "криптограмма"],
    "криптофтальм": ["криптофтальмия"],
    "криптофтальмия": ["криптофтальм"],
    "крислатий": ["розлогий", "крисатий", "крисастий"],
    "криспация": ["беспокойство", "раздражение"],
    "кристалл": ["чип", "камень"],
    "кристаллизация": ["замерзание"],
    "кристаллизировав": ["кристаллизировавши"],
    "кристаллизировавши": ["кристаллизировав"],
    "кристаллизовав": ["кристаллизовавши"],
    "кристаллизовавши": ["кристаллизовав"],
    "кристаллит": ["зерно"],
    "кристаллический": ["самогранный"],
    "кристалловидный": ["кристаллообразный"],
    "кристаллообразный": ["кристалловидный"],
    "кристина": ["христина", "крис", "кристя", "кристиночка", "кристинка"],
    "кристофер": ["крис"],
    "критархия": ["критократия"],
    "критерий": ["мерило"],
    "критидиальный": ["бокожгутиковый"],
    "критик": ["аристарх"],
    "критика": ["осуждение"],
    "критикан": ["придира", "брюзга"],
    "критиканствовав": ["критиканствовавши"],
    "критиканствовавши": ["критиканствовав"],
    "критикнув": ["критикнувши"],
    "критикнувши": ["критикнув"],
    "критиковав": ["критиковавши"],
    "критиковавши": ["критиковав"],
    "критиковать": ["порицать", "осуждать"],
    "критические дни": ["днюха", "красные дни", "гости из краснодара"],
    "критический": ["ругательный", "недоверчивый", "скептический"],
    "критично": ["критически", "драматично", "непредвзято", "непредубеждённо", "нелестно", "неодобрительно", "придирчиво"],
    "критичный": ["критический"],
    "криця": ["сталь"],
    "крича": ["кричащи"],
    "кричав": ["кричавши"],
    "кричавши": ["кричав"],
    "кричанье": ["кричание"],
    "кричать": ["вопить", "орать", "голосить"],
    "кричать благим матом": ["орать", "вопить"],
    "кричаще": ["броско", "вызывающе", "претенциозно"],
    "кришна": ["кршна", "кистна"],
    "крк": ["велья"],
    "кровавая баня": ["бойня", "резня", "мясорубка"],
    "кровавев": ["кровавевши"],
    "кровавевши": ["кровавев"],
    "кровавив": ["кровавивши"],
    "кровавивши": ["кровавив"],
    "кроваво-красный": ["ярко-красный"],
    "кровавое воскресенье": ["красное воскресенье", "девятое января"],
    "кровавый": ["кровяной", "окровавленный", "кровоточащий", "кровопролитный", "кроваво-красный", "ярко-красный", "багряный", "пунцовый"],
    "кроватка": ["коечка", "колыбелька"],
    "кровать": ["постель", "ложе", "альков"],
    "кровенев": ["кровеневши"],
    "кровеневши": ["кровенев"],
    "кровенив": ["кровенивши"],
    "кровенивши": ["кровенив"],
    "кровенить": ["кровянить"],
    "кровеобразование": ["гемопоэз"],
    "кровеостанавливающий": ["кровоостанавливающий"],
    "кроветворение": ["гемопоэз"],
    "кровив": ["кровивши"],
    "кровивши": ["кровив"],
    "кровиночка": ["кровинушка"],
    "кровинушка": ["кровиночка"],
    "кровища": ["кровь"],
    "кровка": ["кровушка"],
    "кровник": ["родич", "родственник"],
    "кровно": ["глубоко", "сильно", "близко", "непосредственно"],
    "кровожадничав": ["кровожадничавши"],
    "кровожадничавши": ["кровожадничав"],
    "кровожадность": ["жестокость"],
    "кровожадный": ["свирепый", "жестокий", "хищный", "безжалостный", "лютый", "зверский", "безмерно злобный", "злодейский"],
    "кровожаждав": ["кровожаждавши"],
    "кровожаждавши": ["кровожаждав"],
    "кровожаждев": ["кровожаждевши"],
    "кровожаждевши": ["кровожаждев"],
    "кровоизлияние": ["геморрагия", "экстравазат"],
    "кровообращение": ["гемодинамика", "перфузия", "кровообращенье", "кровеобращение", "кровеоборот", "кровооборот"],
    "кровоостанавливающий": ["кровеостанавливающий"],
    "кровопивець": ["кровопивця", "кровожер"],
    "кровопийца": ["кровопивец", "кровопиец"],
    "кровоподтёк": ["синяк"],
    "кровопролитие": ["кровопролитство", "кровопролияние", "кроворазлитие", "бойня", "резня", "убийство"],
    "кровопролитство": ["кровопролитие"],
    "кровопролитье": ["кровопролитие"],
    "кровопусканье": ["кровопускание"],
    "кроворазлитье": ["кроворазлитие"],
    "кровосися": ["кровосись"],
    "кровосмесительство": ["инцест", "кровосмешение"],
    "кровосмешение": ["кровосмесительство", "инцест"],
    "кровосмешенье": ["кровосмешение"],
    "кровоснабжение": ["кровоток"],
    "кровосос": ["гематофаг", "кровопийца"],
    "кровососущий": ["кровосос"],
    "кровотечение": ["геморрагия"],
    "кровотеченье": ["кровотечение"],
    "кровоток": ["гемодинамика", "кровообращение", "кровотечение"],
    "кровоточив": ["кровоточивши"],
    "кровоточивость": ["гемофилия"],
    "кровоточивши": ["кровоточив"],
    "кровохаркав": ["кровохаркавши"],
    "кровохаркавши": ["кровохаркав"],
    "кровохарканье": ["гемоптизис"],
    "кровоядный": ["гематофагический", "кровожадный"],
    "кровь": ["убийство", "кровопролитие", "жизнь"],
    "кровь с молоком": ["пышет здоровьем"],
    "кровь стынет в жилах": ["душа в пятки ушла"],
    "кровянив": ["кровянивши"],
    "кровянивши": ["кровянив"],
    "кровянистый": ["багровый", "алый"],
    "кровянить": ["кровенить"],
    "кровянка": ["кровь", "кровушка", "юшка", "кровотечение", "кровяная колбаса"],
    "кроив": ["кроивши"],
    "кроивши": ["кроив"],
    "крой": ["круа", "круи", "крои"],
    "кройка": ["переделка", "перекройка"],
    "крок": ["кроки"],
    "крокет": ["котлета"],
    "кроки": ["крок", "крока"],
    "крокировав": ["крокировавши"],
    "крокировавши": ["крокировав"],
    "крокодил": ["крокодилище", "грымза", "нво", "низковысотный обнаружитель", "горбатый", "полосатый", "рашпиль", "напильник", "шмель"],
    "крокодилий": ["крокодилов"],
    "крокодилов": ["крокодилий"],
    "крокодилополь": ["шедит", "арсиноя"],
    "крокозябра": ["кракозябра", "крюкозябра", "крякозябра", "квакозябра", "крокозябла", "зюква", "козяблик", "зигазюлина", "бнопня", "опхбер", "модзибакэ", "маймуница", "буква зю", "закаляка"],
    "крокус": ["шафран", "крокос", "шафлор", "сафлор", "желтяница", "щётка", "дикий шафран"],
    "крокусовый": ["шафранный"],
    "кролевик": ["кролист"],
    "кролик": ["крольчатина"],
    "кролист": ["кролевик"],
    "кром": ["кремль"],
    "кроманьонец": ["кроманьонский человек"],
    "кроме": ["помимо", "за исключением", "не считая", "опричь", "окромя", "сверх", "наряду"],
    "кроме того": ["к тому же", "вдобавок", "сверх того", "помимо", "ещё", "вместе с тем", "в дополнение", "в придачу", "за вычетом", "за исключением", "не считая"],
    "кромешний": ["кромешный"],
    "кромешник": ["опричник"],
    "кромешный": ["беспросветный", "непроглядный", "сплошной", "кромешний", "неизбывный"],
    "кромешный ад": ["ад кромешный"],
    "кромид": ["лук"],
    "кромка": ["ребро", "полоска", "кайма"],
    "кромсав": ["кромсавши"],
    "кромсавши": ["кромсав"],
    "крон": ["кронос"],
    "крона": ["вершки"],
    "кронглас": ["крон"],
    "кроненпробка": ["кронен-пробка"],
    "кронос": ["крон", "сатурн"],
    "кронпринц": ["цесаревич"],
    "кронпринцесса": ["цесаревна"],
    "кропав": ["кропавши"],
    "кропавши": ["кропав"],
    "кропалив": ["кропаливши"],
    "кропаливши": ["кропалив"],
    "кропаль": ["кропалёк", "кропалик", "дэха", "дэшечка"],
    "кропанье": ["кропание"],
    "кропив": ["кропивши"],
    "кропивши": ["кропив"],
    "кропило": ["аспергилл"],
    "кропить": ["обрызгивать", "окроплять", "накрапывать", "моросить", "сеяться"],
    "кропотав": ["кропотавши"],
    "кропотавши": ["кропотав"],
    "кропотать": ["ходатайствовать", "возиться"],
    "кропотливо": ["тщательно", "усердно"],
    "кропотливый": ["педантичный"],
    "кропотный": ["кропотливый"],
    "кросс": ["кросс-коунтри", "кроссовок", "кроссовка"],
    "кросс-платформенность": ["переносимость"],
    "кросс-фидинг": ["кроссфидинг"],
    "кроссбридинг": ["метизация"],
    "кроссворд": ["крестословица"],
    "кроссинговер": ["перекрёст"],
    "кроссировав": ["кроссировавши"],
    "кроссировавши": ["кроссировав"],
    "кроссировка": ["кроссирование"],
    "кроссовер": ["универсал", "паркетник", "паркетный внедорожник"],
    "кроссфидинг": ["кросс-фидинг"],
    "крота": ["рота", "кротта"],
    "кроткий": ["покорный", "смиренный", "уступчивый"],
    "кротко": ["смиренно", "мягко", "спокойно", "покорно"],
    "кротон": ["коидеум"],
    "кротость": ["смиренность"],
    "кроукиллер": ["кроухантер"],
    "кроухантер": ["кроукиллер"],
    "кроха": ["крупица", "крошка", "кусочек"],
    "крохал": ["крохаль"],
    "крохаль": ["прилукец"],
    "крохоборка": ["алтынница", "скряга", "скареда"],
    "крохоборничав": ["крохоборничавши"],
    "крохоборничавши": ["крохоборничав"],
    "крохоборничать": ["крохоборствовать"],
    "крохоборство": ["мелочность"],
    "крохоборствовав": ["крохоборствовавши"],
    "крохоборствовавши": ["крохоборствовав"],
    "крохоборствовать": ["крохоборничать"],
    "крохоборческий": ["крохоборский"],
    "крохотный": ["крошечный"],
    "крошечный": ["крохотный", "малюсенький", "миниатюрный", "ничтожный"],
    "крошив": ["крошивши"],
    "крошивши": ["крошив"],
    "крошить": ["измельчать", "искрашивать", "раскрашивать", "перекрошить"],
    "крошиться": ["дробиться", "нарезаться", "рубиться"],
    "крошка": ["крупица", "песок", "измельчение"],
    "кроя": ["раскраивая"],
    "крс": ["крупный рогатый скот"],
    "круги эйлера": ["диаграмма эйлера"],
    "круглев": ["круглевши"],
    "круглевши": ["круглев"],
    "круглив": ["кругливши"],
    "кругливши": ["круглив"],
    "круглолицый": ["круглощёкий", "полнощёкий"],
    "круглота": ["круглость"],
    "круглотелый": ["шарообразный"],
    "круглый": ["округлый"],
    "кругляшка": ["кругляшок"],
    "кругляшок": ["кругляш", "кружок"],
    "круговая порука": ["взаимопомощь", "честь мундира"],
    "круговерть": ["круговорот", "круговращение", "вихрь", "мельтешня", "суета"],
    "круговид": ["видноколо"],
    "круговидный": ["кругообразный"],
    "круговорот": ["циркуляция", "цикл", "ротация", "круговерть", "коловращение", "водоворот"],
    "круговращательный": ["круговой"],
    "круговращенье": ["круговращение"],
    "кругозор": ["горизонт", "охват"],
    "кругом": ["по кругу"],
    "кругообразный": ["круговидный"],
    "кругосветка": ["кругосветное плавание", "кругосветное путешествие"],
    "кругосветочка": ["кругосветка", "кругосветное плавание", "кругосветное путешествие"],
    "кружалив": ["кружаливши"],
    "кружаливши": ["кружалив"],
    "кружевной": ["ажурный"],
    "круженый": ["шебутной"],
    "круженье": ["кружение"],
    "кружив": ["круживши"],
    "круживши": ["кружив"],
    "кружить": ["вращать", "вертеть", "крутить", "кружиться"],
    "кружиться": ["вертеться", "вращаться", "метаться", "блуждать", "крутиться", "хлопотать", "суетиться", "подниматься", "парить"],
    "кружка-термос": ["термокружка"],
    "кружной": ["кружный", "обходный"],
    "кружный": ["кружной"],
    "кружок": ["круг", "клуб"],
    "кружочек": ["кружок"],
    "крузадо": ["крузаду"],
    "крузаду": ["крузадо"],
    "крузак": ["крузер"],
    "крузер": ["крузак"],
    "крумциркуль": ["кронциркуль"],
    "круп": ["перепончатая жаба"],
    "крупинка": ["зёрнышко", "частичка", "песчинка", "крапинка", "крупица", "толика"],
    "крупинчатый": ["крупитчатый"],
    "крупитчатый": ["крупинчатый", "гранулированный"],
    "крупица": ["крупинка", "толика", "частичка"],
    "крупнев": ["крупневши"],
    "крупневши": ["крупнев"],
    "крупнейший": ["наибольший", "величайший", "значительнейший"],
    "крупнеть": ["увеличиваться"],
    "крупнобюджетный": ["высокобюджетный", "высокозатратный"],
    "крупнодисперсный": ["грубодисперсный", "низкодисперсный"],
    "крупнозернистый": ["крупнозёрный"],
    "крупноколосный": ["крупноколосый"],
    "крупноколосый": ["крупноколосный"],
    "крупномасштабный": ["крупный", "детальный", "подробный", "масштабный", "значительный"],
    "крупноносый": ["большеносый", "носатый", "носастый"],
    "крупносерийность": ["масштабность"],
    "крупноструктурный": ["грубый"],
    "крупноузловой": ["отвёрточный", "макронодулярный"],
    "крупноячеистый": ["крупноячейный"],
    "крупноячейковый": ["крупноячеистый", "крупноячейный"],
    "крупноячейный": ["крупноячеистый", "крупноячейковый"],
    "крупный": ["грубый", "крупнозернистый", "большой", "здоровый", "здоровенный", "значительный", "весомый", "выдающийся", "великий"],
    "крупный рогатый скот": ["крс"],
    "крупонировав": ["крупонировавши"],
    "крупонировавши": ["крупонировав"],
    "крупорушка": ["крупорушня"],
    "крупчатник": ["мельник"],
    "крупье": ["банкомёт"],
    "крутанув": ["крутанувши"],
    "крутанувши": ["крутанув"],
    "крутануть": ["крутнуть"],
    "крутануться": ["крутнуться"],
    "крутев": ["крутевши"],
    "крутевши": ["крутев"],
    "крутецкий": ["крутой"],
    "крутив": ["крутивши"],
    "крутивши": ["крутив"],
    "крутизна": ["крутость"],
    "крутильный": ["торзионный"],
    "крутить": ["вращать", "вертеть", "поворачивать", "скручивать", "свивать", "заламывать", "стягивать", "увиливать", "недоговаривать", "встречаться", "мутить", "манипулировать"],
    "крутка": ["кручение", "крученье"],
    "крутнув": ["крутнувши"],
    "крутнувши": ["крутнув"],
    "крутнуться": ["крутануться"],
    "круто": ["отвесно", "резко", "внезапно", "сурово", "упрямо", "строго", "решительно", "жёстко", "клёво", "классно", "здоровско", "здыбо"],
    "крутоберегий": ["бережистый", "высокоберегий", "крутобережный"],
    "крутой": ["обрывистый", "отвесный", "резкий", "внезапный", "суровый", "безжалостный", "грубый", "жестокий", "сильный", "мощный", "решительный", "радикальный", "клёвый", "замечательный", "высококлассный"],
    "крутон": ["гренок"],
    "крутоплечий": ["широкоплечий"],
    "крутость": ["крутизна"],
    "крутота": ["крутизна", "крутость"],
    "крутояр": ["круча", "круть", "крутогор"],
    "круть": ["крутизна", "крутняк"],
    "крутя": ["вертя", "вращая"],
    "крутяк": ["круча"],
    "крутящий момент": ["момент силы", "вращательный момент", "вертящий момент", "вращающий момент", "скручивающий момент"],
    "крутёж": ["кручение", "крутёжка"],
    "крутёжка": ["крутёж"],
    "круциальный": ["критический", "решительный", "решающий"],
    "круцификс": ["распятие"],
    "круча": ["крутояр", "круть", "крутогор"],
    "кручение": ["крученье", "крутка"],
    "крученье": ["кручение", "крутка"],
    "кручивав": ["кручивавши"],
    "кручивавши": ["кручивав"],
    "кручина": ["грусть", "тоска", "печаль"],
    "кручиниться": ["грустить", "горевать", "горюниться", "тосковать", "печалиться"],
    "кручь": ["круча"],
    "кручёный": ["витой", "закрученный"],
    "крушась": ["кручинясь"],
    "крушение": ["разрушение", "ломка", "разламывание", "сокрушение", "катастрофа", "авария", "гибель", "крах", "поражение", "провал", "погибель", "банкротство", "кораблекрушение", "коллапс"],
    "крушенье": ["крушение"],
    "крушив": ["крушивши"],
    "крушивши": ["крушив"],
    "крушина": ["жостер"],
    "крушинник": ["крушняк"],
    "крушинница": ["лимонница"],
    "крушить": ["рушить", "ломать", "громить", "разрушать", "сокрушать"],
    "крушиться": ["разрушаться", "рушиться", "сокрушаться", "уничтожаться", "ломаться", "падать", "разбиваться", "печалиться", "горевать", "тосковать", "унывать", "кручиниться"],
    "кръвник": ["кръвопиец", "убиец", "разбойник"],
    "кръжок": ["кръг", "среда", "група", "кръжец", "общество"],
    "кръстопът": ["пресечка", "средище"],
    "крыв": ["крывши"],
    "крывав": ["крывавши"],
    "крывавши": ["крывав"],
    "крывши": ["крыв"],
    "крыж": ["кантон", "крест", "крестовина с перекрестием"],
    "крыжевав": ["крыжевавши"],
    "крыжевавши": ["крыжевав"],
    "крыжив": ["крыживши"],
    "крыживши": ["крыжив"],
    "крыжик": ["крестик"],
    "крыжить": ["сверять"],
    "крылатая ракета": ["самолёт-снаряд"],
    "крылатая фраза": ["крылатые слова", "крылатое выражение"],
    "крылатое выражение": ["крылатое слово", "крылатая фраза"],
    "крылечко": ["крылечико"],
    "крылос": ["клирос", "хоры"],
    "крым": ["таврида", "таврия", "автономная республика крым", "республика крым"],
    "крымская война": ["восточная война"],
    "крымский мост": ["керченский мост"],
    "крымский татарин": ["татарин"],
    "крымчанин": ["крымец"],
    "крынка": ["кринка"],
    "крыса": ["кемпер"],
    "крысив": ["крысивши"],
    "крысивши": ["крысив"],
    "крысий": ["крысиный"],
    "крысиный": ["крысий"],
    "крысить": ["красть", "воровать", "тырить"],
    "крыситься": ["огрызаться"],
    "крысы бегут с тонущего корабля": ["искать лёгких путей"],
    "крысятничав": ["крысятничавши"],
    "крысятничавши": ["крысятничав"],
    "крысятничать": ["прятать", "утаивать", "воровать", "подворовывать", "пионерить", "комсомолить", "коммуниздить", "заимствовать", "плагиатить"],
    "крысёныш": ["крысёнок"],
    "крытка": ["тюрьма", "кича"],
    "крыть": ["закрывать", "накрывать", "покрывать", "бить"],
    "крыша": ["кровля", "кров", "крышняк", "крышак"],
    "крыша мира": ["памир"],
    "крыша над головой": ["пристанище", "приют", "угол", "обиталище", "обитель", "кров"],
    "крыша поехала": ["рехнуться", "двинуться", "кукуха съехала", "колпак сорвало", "не все дома", "крыша переехала", "крыша съехала", "крыша потекла", "крыша протекла", "чердак протёк"],
    "крышак": ["крышняк"],
    "крышевав": ["крышевавши"],
    "крышевавши": ["крышевав"],
    "крышевать": ["протежировать", "покровительствовать", "патронировать"],
    "крышесносный": ["сногсшибательный", "потрясный"],
    "крышка": ["каюк", "капут", "хана"],
    "крюковатый": ["крючковатый"],
    "крючив": ["крючивши"],
    "крючивши": ["крючив"],
    "крючковатый": ["крюковатый"],
    "крючкообразный": ["крючковидный"],
    "крючкотворец": ["крючкотвор"],
    "крючкотворство": ["казуистика", "придирчивость", "волокитство", "волокита"],
    "крючкотворствовав": ["крючкотворствовавши"],
    "крючкотворствовавши": ["крючкотворствовав"],
    "крючничав": ["крючничавши"],
    "крючничавши": ["крючничав"],
    "крючок": ["загогулина"],
    "кряду": ["один за другим", "подряд", "сряду"],
    "кряж": ["гора", "гряда"],
    "кряжевый": ["кряжистый"],
    "кряжистый": ["крепкий", "плотный", "толстый", "коренастый"],
    "кряк": ["кряканье"],
    "крякав": ["крякавши"],
    "крякавши": ["крякав"],
    "крякание": ["кряк", "кряканье"],
    "кряква": ["кряковая утка", "крякуша"],
    "крякнув": ["крякнувши"],
    "крякнувши": ["крякнув"],
    "крякуша": ["кряква", "кряковая утка"],
    "крясък": ["рев", "вой", "лай"],
    "кряхнув": ["кряхнувши"],
    "кряхнувши": ["кряхнув"],
    "кряхтев": ["кряхтевши"],
    "кряхтевши": ["кряхтев"],
    "кряхтение": ["кряхтенье"],
    "кряхтенье": ["кряхтение"],
    "крёстная": ["восприемница", "кума"],
    "крёстная мать": ["восприемница", "крёстная"],
    "крёстный": ["восприемник", "кум"],
    "крёстный отец": ["восприемник", "крёстный", "божат", "главарь"],
    "ксандрейка": ["александрейка", "александрийка", "касандрейка", "кассандровка"],
    "ксант": ["ксанф"],
    "ксантановая камедь": ["ксантан"],
    "ксантиоксидаза": ["ксантиноксидоредуктаза"],
    "ксантогумол": ["ксантохумол"],
    "ксанторрея": ["травяное дерево"],
    "ксанф": ["ксант"],
    "ксв": ["коэффициент стоячей волны"],
    "ксенизм": ["варваризм"],
    "ксения": ["оксана"],
    "ксенокристалл": ["ксенокрист"],
    "ксеноморф": ["чужой"],
    "ксенотрансплантация": ["ксенопересадка"],
    "ксенофоб": ["шовинист"],
    "ксенофобический": ["ксенофобский", "ксенофобный"],
    "ксенофобный": ["ксенофобский", "ксенофобический"],
    "ксенофобский": ["ксенофобный", "ксенофобический"],
    "ксенофобствовав": ["ксенофобствовавши"],
    "ксенофобствовавши": ["ксенофобствовав"],
    "ксеранув": ["ксеранувши"],
    "ксеранувши": ["ксеранув"],
    "ксерануть": ["отксерить"],
    "ксерив": ["ксеривши"],
    "ксеривши": ["ксерив"],
    "ксерить": ["ксерокопировать", "фотокопировать", "канонить", "эрить", "синить"],
    "ксерография": ["электрофотография", "электрография"],
    "ксеродермия": ["ксероз"],
    "ксерокопировав": ["ксерокопировавши"],
    "ксерокопировавши": ["ксерокопировав"],
    "ксерокопировать": ["фотокопировать", "ксерить", "канонить", "эрить", "синить"],
    "ксерокопироваться": ["фотокопироваться", "ксериться"],
    "ксерокопия": ["фотокопия"],
    "ксерокс": ["копировальная машина", "копировальный аппарат", "копир", "ксерокопия", "синька"],
    "ксерофтальмия": ["офтальмоксероз"],
    "ксива": ["малява", "малявка", "ксивота", "аусвайс"],
    "ксивота": ["ксива"],
    "ксилема": ["древесина"],
    "ксилидин": ["диметиланилин"],
    "ксилит": ["ксилитол"],
    "ксилитол": ["ксилит"],
    "ксилогравюра": ["ксилография"],
    "ксилография": ["гравюра на дереве"],
    "ксилол": ["диметилбензол"],
    "ксилология": ["дендрология"],
    "ксилофон": ["маримба"],
    "ксифоидалгия": ["ксифоидия"],
    "кстати": ["вовремя", "уместно", "к месту", "прилично", "пристойно", "пользуясь случаем", "заодно", "вместе с тем", "в связи с", "в дополнение к"],
    "кт": ["гг", "гигаграмм"],
    "ктенофор": ["гребневик"],
    "ктитор": ["здатель", "донатор", "меценат", "церковный староста"],
    "ктиторствовав": ["ктиторствовавши"],
    "ктиторствовавши": ["ктиторствовав"],
    "кто": ["контртеррористическая операция"],
    "кто-либо": ["кто-нибудь", "кто-то", "некто"],
    "кто-нибудь": ["кто-то", "кто-либо"],
    "кто-то": ["некто", "кое-кто", "кто-нибудь"],
    "ктувим": ["агиограф", "графия"],
    "ктырь": ["муха-разбойник"],
    "ку-клукс-клан": ["ккк"],
    "куаныч": ["шатлык"],
    "куар-код": ["кьюар-код"],
    "куб": ["гексаэдр", "кубометр", "кубик"],
    "куба": ["республика куба", "остров свободы"],
    "кубань": ["кубанщина", "краснодарский край"],
    "кубарем": ["кувырком", "вверх тормашками", "турманом", "стремглав", "стремительно"],
    "кубатура": ["объём"],
    "кубатурив": ["кубатуривши"],
    "кубатуривши": ["кубатурив"],
    "куббе": ["каупо", "каупе", "коббе"],
    "кубик-рубик": ["кубик рубика"],
    "кубкообразный": ["бокалообразный"],
    "кубло": ["жилище", "гнездо", "банда", "шайка"],
    "кубловый": ["гнездовой"],
    "кубо-фут": ["кубический фут", "кубофут"],
    "кубовый": ["тёмно-синий", "индиго"],
    "кубок": ["чаша"],
    "кубофут": ["кубический фут"],
    "кубофутурист": ["будетлянин"],
    "кувалда": ["балда"],
    "кувалдировать": ["кувалдить"],
    "кувалдить": ["кувалдировать"],
    "кувез": ["кроватка-грелка"],
    "кувейт": ["государство кувейт"],
    "кувейтянин": ["кувейтец"],
    "куверт": ["прибор", "конверт", "коверт", "кувертная карточка"],
    "кувшин": ["кукшин"],
    "кувшинка": ["водяная лилия", "нимфея"],
    "кувшинное рыло": ["на руку нечист", "на руку нечистый", "можно купить"],
    "кувыркав": ["кувыркавши"],
    "кувыркавши": ["кувыркав"],
    "кувыркнув": ["кувыркнувши"],
    "кувыркнувши": ["кувыркнув"],
    "кувыркнуть": ["кувырнуть"],
    "кувыркнуться": ["кувырнуться"],
    "кувырком": ["вверх тормашками", "кубарем", "турманом"],
    "кувырнув": ["кувырнувши"],
    "кувырнувши": ["кувырнув"],
    "кувырнуть": ["кувыркнуть"],
    "кувырнуться": ["кувыркнуться"],
    "кувырок": ["перекат", "кувырканье"],
    "куга": ["чакан"],
    "кугуар": ["пума"],
    "куда": ["куды", "зачем", "к чему", "для чего", "на фига", "на кой", "на кой фиг", "какого ляда", "какого лешего", "намного", "гораздо", "значительно", "много", "куда-либо", "куда-нибудь"],
    "куда глаза глядят": ["бесцельно", "наобум", "на все четыре стороны", "с глаз долой"],
    "куда макар телят не гонял": ["на кудыкину гору", "к чёрту на кулички", "к чёрту на рога", "куда ворон костей не заносил", "за тридевять земель"],
    "куда ни шло": ["кое-как", "как-нибудь", "худо-бедно", "более-менее"],
    "куда угодно": ["куда-нибудь"],
    "куда-либо": ["куда-нибудь"],
    "куда-нибудь": ["куда-либо", "куда-то"],
    "куда-то": ["куда-нибудь"],
    "кудакав": ["кудакавши"],
    "кудакавши": ["кудакав"],
    "кудакать": ["кудыкать"],
    "кудахтав": ["кудахтавши"],
    "кудахтавши": ["кудахтав"],
    "кудахтнув": ["кудахтнувши"],
    "кудахтнувши": ["кудахтнув"],
    "куделив": ["куделивши"],
    "куделивши": ["куделив"],
    "кудель": ["куделя", "кужель"],
    "кудере": ["кудэрэ"],
    "кудесив": ["кудесивши"],
    "кудесивши": ["кудесив"],
    "кудесить": ["кудесничать", "проказничать", "шалить", "вытворять"],
    "кудесник": ["волшебник", "волхв", "колдун", "маг", "чародей"],
    "кудесница": ["волшебница", "колдунья", "чаровница", "чудесница"],
    "кудесничав": ["кудесничавши"],
    "кудесничавши": ["кудесничав"],
    "кудластый": ["взлохмаченный", "взъерошенный", "вихрастый", "волосатый", "всклоченный", "встрепанный", "длинношерстный", "длинношерстый", "клочковатый", "косматый", "кудлатый", "лохматый", "мохнатый", "непричесанный", "нечесаный"],
    "кудлатый": ["кудластый", "патлатый", "косматый", "лохматый"],
    "кудри": ["локон"],
    "кудрявенький": ["кучерявенький", "курчавенький"],
    "кудрявив": ["кудрявивши"],
    "кудрявивши": ["кудрявив"],
    "кудрявость": ["кучерявость"],
    "кудрявый": ["кучерявый", "курчавый"],
    "кудряшка": ["завитушка", "локон"],
    "кудук": ["кудух"],
    "куды": ["куда"],
    "кудыкав": ["кудыкавши"],
    "кудыкавши": ["кудыкав"],
    "кудэрэ": ["кудере"],
    "кудюс": ["ерусалим"],
    "куев": ["киев", "мать городов русских", "матерь городов русских", "куяба"],
    "кужелиця": ["кужелина"],
    "кужель": ["кудель", "куделя", "кужень"],
    "кужень": ["кудель", "куделя", "кужель"],
    "кузбасс": ["кемеровская область"],
    "кузика": ["куузику"],
    "кузина": ["двоюродная сестра"],
    "кузнечив": ["кузнечивши"],
    "кузнечивши": ["кузнечив"],
    "кузнечий": ["кузнецкий", "кузнецов"],
    "кузнечик": ["стрекота"],
    "кузнечничав": ["кузнечничавши"],
    "кузнечничавши": ["кузнечничав"],
    "кузнечничать": ["кузнечить"],
    "кузнечный": ["кузнецкий"],
    "кузница": ["кузня"],
    "кузня": ["кузница"],
    "кузов": ["корзина", "короб"],
    "кузькина мать": ["где раки зимуют"],
    "кузьма": ["косма", "косьма"],
    "кузяво": ["классно", "здоровско", "здыбо"],
    "куинстаунит": ["куинстоунит", "квинстаунит", "дарвинское стекло"],
    "куйаба": ["киев"],
    "куйава": ["киуаша", "киев"],
    "куйас": ["куйаш"],
    "куйаш": ["куйас"],
    "куйбышев": ["каинск", "самара"],
    "куйрук": ["куйрух"],
    "куйу": ["къуйу"],
    "кук": ["пыд"],
    "кукабарра": ["кукабара", "смеющийся зимородок", "зимородок-хохотун", "зимородок-великан"],
    "кукарекав": ["кукарекавши"],
    "кукарекавши": ["кукарекав"],
    "кукареканье": ["куроглашение"],
    "кукарекать": ["петь", "кудахтать"],
    "кукарекнув": ["кукарекнувши"],
    "кукарекнувши": ["кукарекнув"],
    "кукати": ["кувати"],
    "кукийана": ["киев"],
    "кукиш": ["фига", "шиш", "дуля"],
    "кукловод": ["пупенмейстер", "кукольник"],
    "кукловодив": ["кукловодивши"],
    "кукловодивши": ["кукловодив"],
    "куковав": ["куковавши"],
    "куковавши": ["куковав"],
    "кукованье": ["кукование"],
    "кукож": ["кринж", "испанский стыд"],
    "кукожиться": ["ёжиться"],
    "куколд": ["терпила", "евнух"],
    "кукольность": ["театральность", "неестественность", "выделанность", "вымученность", "деланность", "фальшивость", "ненатуральность", "наигранность"],
    "кукольный": ["игрушечный"],
    "кукольный театр": ["театр кукол"],
    "куксив": ["куксивши"],
    "куксивши": ["куксив"],
    "кукситься": ["хандрить", "хмуриться"],
    "куксу": ["кукси"],
    "кукузяка": ["бяка", "узюка", "глокая куздра"],
    "кукукнув": ["кукукнувши"],
    "кукукнувши": ["кукукнув"],
    "кукул": ["йуойэ", "элиэдулбэн"],
    "кукундер": ["кукуха", "крыша"],
    "кукурекав": ["кукурекавши"],
    "кукурекавши": ["кукурекав"],
    "кукурекать": ["кукарекать"],
    "кукурекнув": ["кукурекнувши"],
    "кукурекнувши": ["кукурекнув"],
    "кукуруза": ["маис", "царица полей", "золотое зерно", "янтарное зерно"],
    "кукурузина": ["кукурузища"],
    "кукурузник": ["жук", "небесный тихоход", "керосинка", "ан-два", "антоша"],
    "кукурузный": ["кукурузовый", "кукурузяный"],
    "кукурузовый": ["кукурузный"],
    "кукутасана": ["поза петуха"],
    "кукуха": ["кукушка", "крыша", "чердак", "голова"],
    "кукуха съехала": ["кукуху сорвало", "крыша поехала"],
    "кукуху сорвало": ["крыша поехала"],
    "кукушатник": ["кукушкин цвет", "кукушник", "горицвет кукушкин"],
    "кукушица": ["кукушка"],
    "кукушка": ["гжиголка", "загозка", "загонька", "загоска", "зегзица", "зезуля", "зазуля", "зозуля", "жегзица"],
    "кукушкин": ["кокушкин"],
    "кулага": ["саламата", "солодуха", "киселица", "завара", "завариха", "бебеня"],
    "кулажить": ["солодить"],
    "кулак": ["кирпич"],
    "кулан": ["полуосёл", "дикий осёл", "джигетай", "онагр", "осёл"],
    "кулах": ["кулак"],
    "кулачество": ["скупость", "прижимистость", "жадность"],
    "кулачив": ["кулачивши"],
    "кулачивши": ["кулачив"],
    "кулачина": ["кулачище"],
    "кулачить": ["раскулачивать"],
    "кулачиха": ["кулачка"],
    "кулачка": ["кулачиха"],
    "кулачничав": ["кулачничавши"],
    "кулачничавши": ["кулачничав"],
    "кулачок": ["кулачишка", "кулачишко", "кулачонка"],
    "кулдыкав": ["кулдыкавши"],
    "кулдыкавши": ["кулдыкав"],
    "кулемс": ["марямс"],
    "кулер": ["вентилятор", "охладитель", "водораздатчик", "диспенсер"],
    "кулибничав": ["кулибничавши"],
    "кулибничавши": ["кулибничав"],
    "кулибничать": ["изобретать"],
    "куликав": ["куликавши"],
    "куликавши": ["куликав"],
    "куликнув": ["куликнувши"],
    "куликнувши": ["куликнув"],
    "куликовская битва": ["донское побоище", "мамаево побоище"],
    "кулинар": ["повар"],
    "кулинарив": ["кулинаривши"],
    "кулинаривши": ["кулинарив"],
    "кулинария": ["гастрономия"],
    "кулинарка": ["повариха"],
    "кулинхой": ["кулк-аул"],
    "кулирка": ["кулир"],
    "кулировав": ["кулировавши"],
    "кулировавши": ["кулировав"],
    "кулич": ["баба", "артос"],
    "куличик": ["кулич"],
    "куличок": ["песочник"],
    "кулланырга": ["файдаланырга"],
    "куллук": ["куллух"],
    "кулой": ["кула"],
    "кулофтомс": ["аделамс", "стожамс", "шавомс"],
    "култышка": ["культя"],
    "кулуар": ["кулиса", "расселина"],
    "кулуарно": ["неофициально", "негласно"],
    "кулуарный": ["закулисный"],
    "кулхацкер": ["хацкер"],
    "кулъяулык": ["ашъяулык"],
    "кулыны": ["бырыны"],
    "куль": ["мешок", "растяпа"],
    "кульбит": ["акробатический трюк"],
    "кульминационный": ["наивысший"],
    "кульминация": ["апофеоз"],
    "кульминировав": ["кульминировавши"],
    "кульминировавши": ["кульминировав"],
    "кульок": ["кулик"],
    "культивар": ["культиген"],
    "культивировав": ["культивировавши"],
    "культивировавши": ["культивировав"],
    "культивирование": ["культивация"],
    "культивировать": ["разводить", "выращивать"],
    "культмассовый": ["культурно-массовый"],
    "культовый язык": ["церковный язык"],
    "культорг": ["культорганизатор"],
    "культорганизатор": ["культорг"],
    "культпросветучилище": ["кулёк"],
    "культура": ["искусство", "приличие", "традиции", "культивация", "поросль", "штамм"],
    "культурист": ["атлетист", "бодибилдер"],
    "культурная деятельность": ["социально-культурная деятельность"],
    "культурная столица": ["санкт-петербург", "петербург", "питер"],
    "культурненько": ["культурно"],
    "культурник": ["культработник"],
    "культурница": ["культпросветработница", "массовичка"],
    "культурнический": ["просветительский", "культурно-просветительский"],
    "культурно-просветительный": ["культурно-просветительский"],
    "культурно-просветительский": ["культурно-просветительный"],
    "культурнопьющий": ["культурпитейщик"],
    "культурность": ["культура"],
    "культурный шок": ["разрыв шаблона", "аккультурация"],
    "культурпитейщик": ["культурнопьющий"],
    "культуртрегер": ["просветитель"],
    "культя": ["культяпка"],
    "культяпка": ["культя"],
    "кулёк": ["куль", "мешочек", "пакетик"],
    "кулёма": ["тюфяк", "тетёха"],
    "кулёчек": ["мешочек", "свёрточек", "пакетик"],
    "кумай": ["снежный гриф", "гималайский гриф"],
    "куманець": ["куман"],
    "куманика": ["ежевика"],
    "кумар": ["ломка"],
    "кумарив": ["кумаривши"],
    "кумаривши": ["кумарив"],
    "кумарить": ["ломать", "курить", "токсикоманить", "токсить", "кайфовать", "колбасить", "надоедать", "приставать", "мешать", "раздражать", "бесить", "доставать"],
    "кумач": ["пунец"],
    "кумачовый": ["кумачный", "ярко-красный"],
    "кумекав": ["кумекавши"],
    "кумекавши": ["кумекав"],
    "кумекать": ["думать", "мыслить", "мозговать", "соображать", "петрить"],
    "кумин": ["тмин", "зира"],
    "кумкват": ["кинкан", "фортунелла", "японский апельсин"],
    "кумовской капитализм": ["капитализм для своих", "блатной капитализм"],
    "кумовство": ["непотизм"],
    "кумол": ["изопропилбензол"],
    "кумпол": ["голова"],
    "кумпяк": ["шынка"],
    "кумуз": ["агач-кумуз"],
    "кумулянт": ["полуинвариант", "семиинвариант"],
    "кумулятивно-осколочный снаряд": ["многофункциональный снаряд"],
    "кумулятивный эффект": ["эффект манро"],
    "кумыкский": ["кумыкский язык"],
    "кумыкский язык": ["кумыкский"],
    "кумысотерапия": ["кумысолечение"],
    "кунак": ["друг", "приятель"],
    "кунг-фу": ["ушу"],
    "кундюм": ["кундюб", "кундюбок", "кундумец"],
    "кунжут": ["сезам", "тахин"],
    "куни": ["куннилингус"],
    "кунка": ["куна", "куница", "куночка", "куничка", "кунька"],
    "куннилингус": ["кумбитмака", "ламбитус"],
    "кунтуш": ["контуш", "казакин", "кафтан"],
    "кунцемс": ["кундсемс"],
    "куншт": ["малюнок"],
    "кунштик": ["кунштюк", "куншт"],
    "кунштюк": ["кунштик", "каверза", "обман", "трюк", "ухищрение", "фокус", "фокус-покус", "хитрость", "выверт", "закидон", "приём", "приёмчик", "штука", "штучка", "коленце"],
    "куняв": ["кунявши"],
    "кунявши": ["куняв"],
    "кунять": ["клевать носом", "кунять носом", "засыпать на ходу"],
    "кунять носом": ["клевать носом", "кунять", "засыпать на ходу"],
    "кунячий": ["куницевий"],
    "куоклэ": ["кантеле", "канклес", "каннель", "гусли"],
    "купав": ["купавши"],
    "купавши": ["купав"],
    "купаж": ["купажирование"],
    "купажировав": ["купажировавши"],
    "купажировавши": ["купажировав"],
    "купажирование": ["купаж"],
    "купальница": ["троллиус"],
    "купание": ["мытьё", "купальня"],
    "купанье": ["купание"],
    "купать": ["мыть", "окунать"],
    "купейный": ["купированный"],
    "купелировав": ["купелировавши"],
    "купелировавши": ["купелировав"],
    "купелирование": ["капеллирование", "купеляция"],
    "купель": ["крестильница", "крестильная чаша", "водоём", "купальня", "ванна"],
    "купена": ["купень", "кровавник", "воронец", "сындрик", "волчья трава", "волчьи глазки", "вороновы глазки", "сорочьи ягоды"],
    "купероз": ["телеангиэктазия"],
    "купертиновец": ["яблочник"],
    "купец": ["коммерсант", "негоциант", "торговец", "покупатель", "барыга"],
    "купецкий": ["купеческий"],
    "купець": ["покупець"],
    "купеческий": ["торговый", "торгашеский"],
    "купечество": ["торговля"],
    "купечествовав": ["купечествовавши"],
    "купечествовавши": ["купечествовав"],
    "купив": ["купивши"],
    "купивши": ["купив"],
    "купидон": ["эрот", "эрос", "амур"],
    "купина": ["куст", "кустарник"],
    "купировав": ["купировавши"],
    "купировавши": ["купировав"],
    "купировать": ["обрезать", "подрезать", "прерывать", "прервать", "пресекать", "пресечь"],
    "купить": ["приобрести", "выменять", "подкупить"],
    "купля": ["закупка", "покупка", "приобретение"],
    "купно": ["вместе", "совместно", "совокупно"],
    "купол": ["свод"],
    "куполовидный": ["куполообразный", "куполоподобный"],
    "куполообразный": ["куполовидный", "куполоподобный"],
    "куполоподобный": ["куполообразный", "куполовидный"],
    "купонокарбованец": ["карбованец"],
    "купор": ["обручник", "бондарь", "бочар", "штопор", "пробочник", "открывашка"],
    "купорив": ["купоривши"],
    "купоривши": ["купорив"],
    "купорить": ["затыкать", "заделывать", "закатывать"],
    "купорка": ["закатки"],
    "купоросив": ["купоросивши"],
    "купоросивши": ["купоросив"],
    "купоросний": ["купоросовий"],
    "купоросовий": ["купоросний"],
    "купферникель": ["никелин"],
    "купцов": ["купеческий", "купцовский"],
    "купцовский": ["купцов", "купеческий"],
    "купчая": ["купчая крепость"],
    "купчая крепость": ["купчая"],
    "купчина": ["купец"],
    "купшыл": ["купшыл чыпчык"],
    "купюра": ["банкнота", "эллипсис"],
    "купюроприёмник": ["валидатор", "банкнотоприёмник"],
    "купянск-узловой": ["узловая", "узлы"],
    "кур": ["кор", "мтквари"],
    "кура": ["мтквари", "кур", "кир"],
    "курабельность": ["излечимость"],
    "курага": ["абрикос"],
    "кураж": ["бравада", "лихачество", "взбалмошность", "наглость", "нахальство", "развязность", "раскованность", "отвязность", "задор", "энтузиазм", "драйв", "эйфория", "опьянение", "хмель", "хмелёк"],
    "куражив": ["кураживши"],
    "кураживши": ["куражив"],
    "куражистый": ["куражливый", "куражный"],
    "курай": ["курашка", "кураина", "кураинка", "верблюжья трава", "верблюжье сено", "поташник", "зольник", "камчак", "камочка", "качим", "каравин", "колюка", "сарыбарак"],
    "куралесив": ["куралесивши"],
    "куралесивши": ["куралесив"],
    "куралесить": ["колобродить", "бедокурить", "проказничать", "озорничать"],
    "курант": ["тёрочник", "пест", "пестик", "прейскурант", "куранта"],
    "кураторка": ["кураторша"],
    "курахово": ["кураховгрэсстрой", "кураховстрой", "кураховгрэс"],
    "курация": ["курирование", "наблюдение"],
    "курва": ["шлюха", "потаскуха"],
    "курвар": ["развратник", "чапкънин"],
    "курвиметр": ["длиномер"],
    "кургактык": ["континент"],
    "курган": ["холм", "горка"],
    "курганская область": ["курганщина"],
    "кургашларга": ["кургаш"],
    "кургонь келепни": ["кели курга"],
    "кургузив": ["кургузивши"],
    "кургузивши": ["кургузив"],
    "кургузый": ["короткополый", "куцый", "низкорослый", "куцехвостый"],
    "кургъак": ["кургъах"],
    "курдистан": ["иракский курдистан", "южный курдистан"],
    "курдский": ["курдистанский", "курдский язык"],
    "курдский язык": ["курдский", "курдские языки"],
    "курдючий": ["курдючный"],
    "курдянка": ["курдка"],
    "курево": ["курюха", "марево"],
    "курение": ["дымление", "мастика", "парение"],
    "куренье": ["курение"],
    "курессааре": ["аренсбург", "кингисепп"],
    "куреш": ["кураш", "курес"],
    "куржавев": ["куржавевши"],
    "куржавевши": ["куржавев"],
    "куржаветь": ["куржеветь", "индеветь"],
    "куржевев": ["куржевевши"],
    "куржевевши": ["куржевев"],
    "курзал": ["воксал", "курхауз", "кургауз"],
    "курив": ["куривши"],
    "куривав": ["куривавши"],
    "куривавши": ["куривав"],
    "куривши": ["курив"],
    "курилец": ["айн"],
    "курилы": ["курильские острова"],
    "курильня": ["курительная", "курилка"],
    "курильские острова": ["курилы"],
    "курильщик": ["куряга", "курилка", "курец"],
    "курильщица": ["куряга", "курилка"],
    "куриная слепота": ["гемералопия", "никталопия", "ночная слепота", "сумеречная слепота", "белена чёрная", "бересклед", "бубенчики", "желтоголовник", "желтомолочник", "коронария кукушкин цвет", "горицвет кукушкин", "курослеп", "лютик", "лютик едкий", "очный цвет полевой"],
    "куриный": ["курий"],
    "курировав": ["курировавши"],
    "курировавши": ["курировав"],
    "курирование": ["наблюдение", "опека", "надзор", "присмотр", "пригляд", "кураторство"],
    "курировать": ["отвечать", "за", "опекать"],
    "куритель": ["курильщик"],
    "курительная трубка": ["трубка"],
    "курить": ["смолить", "дымить", "лёгкие травить", "жабры травить"],
    "курить бамбук": ["дуть", "дудонить", "курить траву", "курить шмаль", "курить план", "курить шишки", "курить дурь", "прохлаждаться", "филонить", "бить баклуши", "валять дурака"],
    "курить фимиам": ["льстить", "лизать пятки", "шестерить", "угодничать", "подхалимничать", "лакействовать", "холуйствовать", "раболепствовать"],
    "куриться": ["виться"],
    "курица": ["дура", "идиотка"],
    "курка": ["курица"],
    "куркаровый": ["песчаниковый"],
    "куркуль": ["кулак", "стяжатель", "жадина", "скряга", "жмот", "скареда", "скупердяй", "скупец", "казак"],
    "куркульський": ["глитайський"],
    "куркума": ["жёлтый имбирь", "жёлтый корень", "гургемей", "зарчава", "халди", "жёлтый инбирь"],
    "куркыныч": ["коточкыч"],
    "куркынычсызлык": ["иминлек"],
    "курлыкав": ["курлыкавши"],
    "курлыкавши": ["курлыкав"],
    "курлыканье": ["курлыкание"],
    "курлыкнув": ["курлыкнувши"],
    "курлыкнувши": ["курлыкнув"],
    "курляндия": ["курземе", "курония"],
    "курманджи": ["севернокурдский язык", "езидский язык", "курманчи"],
    "курмасана": ["поза черепахи"],
    "курник": ["курятник"],
    "курной": ["чёрный"],
    "курносая": ["смертная", "костлявая", "безносая", "старуха с клюкой", "старуха с косой"],
    "курноситься": ["куражиться", "задаваться"],
    "курнув": ["курнувши"],
    "курнувши": ["курнув"],
    "курныкав": ["курныкавши"],
    "курныкавши": ["курныкав"],
    "куробахнув": ["куробахнувши"],
    "куробахнувши": ["куробахнув"],
    "куроглашение": ["кукареканье", "кукарекание", "первые петухи", "куры", "полночь", "полунощь"],
    "курок": ["собачка", "спусковой крючок"],
    "куролесив": ["куролесивши"],
    "куролесивши": ["куролесив"],
    "куролесить": ["колобродить", "озорничать", "проказничать"],
    "курония": ["курляндия"],
    "куропачий": ["куропаточий"],
    "курорт": ["здравница"],
    "курортничав": ["курортничавши"],
    "курортничавши": ["курортничав"],
    "курослеп": ["куриная слепота", "очной цвет", "воробьиное просо"],
    "курослепник": ["лютик весенний", "жабник", "салата", "салатник", "заячий салат"],
    "курочив": ["курочивши"],
    "курочивши": ["курочив"],
    "курочить": ["раскурочивать"],
    "курочка": ["курица"],
    "курсак": ["курсач", "курсовик", "курсовуха", "курсяк"],
    "курсач": ["курсовик"],
    "курсивив": ["курсививши"],
    "курсививши": ["курсивив"],
    "курсировав": ["курсировавши"],
    "курсировавши": ["курсировав"],
    "курсировать": ["ходить"],
    "курсистка": ["студентка"],
    "курская область": ["курщина"],
    "курсовая": ["курсовая работа", "курсовик", "курсач"],
    "курсовая работа": ["курсовая"],
    "курсовик": ["курсовая работа"],
    "курсяк": ["курсач", "курсовик", "курсовуха", "курсак"],
    "куртаг": ["приём"],
    "куртизанив": ["куртизанивши"],
    "куртизанивши": ["куртизанив"],
    "куртизанка": ["кокотка"],
    "куртизировав": ["куртизировавши"],
    "куртизировавши": ["куртизировав"],
    "куртина": ["грядка", "клумба"],
    "куртка": ["курточка", "куртеечка", "куртяшечка", "куртейка", "куртяшка", "куртяк"],
    "куртуазия": ["куртуазность"],
    "куртуазность": ["учтивость", "любезность", "вежливость", "галантность", "куртуазия"],
    "куртуазный": ["галантный", "рыцарский", "аристократический", "утончённый"],
    "курултай": ["собрание старшин"],
    "курум": ["курумник"],
    "курумник": ["курум"],
    "куруш": ["пиастр", "керш", "кирш"],
    "курфюршество": ["княжество", "княжение"],
    "курчавев": ["курчавевши"],
    "курчавевши": ["курчавев"],
    "курчавенький": ["кудрявенький", "кучерявенький"],
    "курчавив": ["курчавивши"],
    "курчавивши": ["курчавив"],
    "курчавоволосый": ["кучерявый", "курчавый", "кудрявый"],
    "курчатовий": ["резерфордий"],
    "курщина": ["курська область"],
    "курьер": ["посыльный", "посредник"],
    "курьерша": ["разносчица", "почтальонка"],
    "курьёзно": ["смешно", "забавно"],
    "курьёзный": ["смешной", "забавный"],
    "куряв": ["курявши"],
    "курявши": ["куряв"],
    "куряга": ["курильщик", "куряка"],
    "куряка": ["куряга", "курец", "курильщик"],
    "курятина": ["курица"],
    "курять": ["окунать"],
    "курячий": ["куриный"],
    "курёнок": ["цыплёнок", "курчонок"],
    "кус": ["кусок"],
    "кусав": ["кусавши"],
    "кусавши": ["кусав"],
    "кусанув": ["кусанувши"],
    "кусанувши": ["кусанув"],
    "кусанье": ["кусание"],
    "кусать локти": ["кусать себе локти", "досадовать"],
    "кусачка": ["кусака"],
    "кусачки": ["острогубцы"],
    "кусень": ["кусок", "шмат"],
    "кусив": ["кусивши"],
    "кусивши": ["кусив"],
    "кусман": ["кусище"],
    "куснув": ["куснувши"],
    "куснувши": ["куснув"],
    "куснуть": ["укусить", "ужалить", "уязвить", "откусить"],
    "кусок": ["часть", "доля", "кус", "отрез", "фрагмент", "кусман", "прапорщик", "штука"],
    "кусок культуры": ["кусок дурака", "кусок пидораса", "селёдка"],
    "кусочничав": ["кусочничавши"],
    "кусочничавши": ["кусочничав"],
    "кусочничать": ["кусовничать", "побираться", "нищенствовать", "попрошайничать"],
    "кусочничество": ["кусовничество"],
    "куст": ["кустарник", "кустовая площадка"],
    "кустарник": ["куст", "кустик"],
    "кустарничав": ["кустарничавши"],
    "кустарничавши": ["кустарничав"],
    "кустарничек": ["стланик", "стланец", "кустарник"],
    "кустарный": ["самодельный", "крафтовый"],
    "кустарь": ["ремесленник"],
    "кустовав": ["кустовавши"],
    "кустовавши": ["кустовав"],
    "кусур": ["недостатък", "дефект", "порок", "слабост"],
    "кусь": ["цап"],
    "кут": ["угол", "кутник"],
    "кутаба": ["куяба"],
    "кутав": ["кутавши"],
    "кутавши": ["кутав"],
    "кутаиси": ["кутатис", "кутаиа", "кутаис"],
    "кутанье": ["кутание"],
    "кутерьма": ["неразбериха", "суматоха", "мельтешня", "сумятица", "смятеньице", "замешательство", "беспорядок", "беготня", "хлопотня", "суета", "кавардак", "хаос"],
    "кутив": ["кутивши"],
    "кутивши": ["кутив"],
    "кутийка": ["кутия", "сандък", "сандъче"],
    "кутикула": ["надкожица", "эпонихий"],
    "кутис": ["дерма"],
    "кутить": ["пировать", "пьянствовать", "гулять", "бражничать"],
    "кутия": ["сандък", "ковчег", "каса"],
    "куткыж": ["кучкыж"],
    "кутла": ["къутла"],
    "кутнув": ["кутнувши"],
    "кутнувши": ["кутнув"],
    "куток": ["уголок", "закуток"],
    "кутра": ["кендырь", "пуховник"],
    "кутузка": ["каталажка", "тюряга"],
    "кутум": ["вырезуб"],
    "кутылый": ["пахорукий"],
    "кутырка": ["перекувырка"],
    "кутья": ["коливо", "сочиво"],
    "кутюрье": ["модельер"],
    "кутёж": ["пирушка", "пьянка", "попойка", "гулянка", "гульба"],
    "кутёнок": ["щенок", "собачонка"],
    "куузику": ["гибридный", "брюква", "кузика"],
    "кууку-йимитирский": ["кууку-йимитирский язык"],
    "куфайка": ["фуфайка"],
    "куфия": ["кефи"],
    "куха": ["кухен"],
    "кухарив": ["кухаривши"],
    "кухаривши": ["кухарив"],
    "кухарить": ["кухарничать"],
    "кухарка": ["повариха"],
    "кухарничав": ["кухарничавши"],
    "кухарничавши": ["кухарничав"],
    "кухарничать": ["кухарить"],
    "кухина": ["празнина", "дупка", "вдлъбнатина"],
    "кухмистер": ["повар"],
    "кухня": ["поварня", "кашеварня", "стряпная", "стряпущая", "кухонный комплект", "кухонный гарнитур", "кулинария", "механизм", "подоплёка"],
    "кухонка": ["кухонька"],
    "кухонная плита": ["плита"],
    "кухонный боец": ["кухонный боксёр", "кухонный воин"],
    "кухонный боксёр": ["кухонный боец", "кухонный воин"],
    "кухонька": ["кухонка"],
    "куцавейка": ["кацавейка"],
    "куцехвостый": ["короткохвостый"],
    "куцый": ["обрубленный", "куцехвостый", "маленький", "короткий", "плюгавенький", "низкорослый", "краткий"],
    "куч": ["куц"],
    "куча": ["холм", "груда", "скопище", "толпа", "масса"],
    "кучапи": ["пуныпи"],
    "кучевой": ["кучевидный", "кучеобразный", "клубящийся", "холмистый"],
    "кучер": ["возница", "повозчик"],
    "кучерив": ["кучеривши"],
    "кучеривши": ["кучерив"],
    "кучерской": ["кучеров"],
    "кучерявенький": ["кудрявенький"],
    "кучеряво": ["закрученно", "кудряво", "дорого"],
    "кучерявый": ["кудрявый", "курчавый"],
    "кучив": ["кучивши"],
    "кучивав": ["кучивавши"],
    "кучивавши": ["кучивав"],
    "кучивши": ["кучив"],
    "кучински": ["кучинский", "кучиньский"],
    "кучка": ["горстка"],
    "кучковаться": ["толпиться", "скучиваться"],
    "кучно": ["густо"],
    "кучный": ["плотный"],
    "кучова": ["сталин"],
    "кучугура": ["горб", "пагорб", "купа"],
    "кучук": ["саг"],
    "куш": ["мероитское царство"],
    "кушав": ["кушавши"],
    "кушавши": ["кушав"],
    "кушак": ["пояс"],
    "кушание": ["кушанье"],
    "кушанье": ["кушание", "пища", "еда", "яство", "блюдо", "кушань"],
    "кушанькав": ["кушанькавши"],
    "кушанькавши": ["кушанькав"],
    "кушанькать": ["есть", "кушать"],
    "кушать": ["питаться", "поедать", "наворачивать", "лупить", "выпивать", "есть", "лопать", "глотать", "трескать", "лындить", "усиживать", "пожирать", "уписывать", "рубать", "штрявкать"],
    "кушая": ["едя"],
    "кушетка": ["софа", "козетка"],
    "кушивать": ["едать"],
    "кушкав": ["кушкавши"],
    "кушкавши": ["кушкав"],
    "кушкать": ["кутать"],
    "куща": ["заросли", "чаща", "шатёр", "хижина"],
    "кущевав": ["кущевавши"],
    "кущевавши": ["кущевав"],
    "куэрда": ["кордель"],
    "куя": ["кельмовай"],
    "куяба": ["кутаба", "киев"],
    "куян": ["мулкач"],
    "куячный": ["куяшный"],
    "кфм": ["фсфм"],
    "кхекав": ["кхекавши"],
    "кхекавши": ["кхекав"],
    "кхеканье": ["кхекание"],
    "кхекнув": ["кхекнувши"],
    "кхекнувши": ["кхекнув"],
    "кхл": ["континентальная хоккейная лига"],
    "кчр": ["карачаево-черкессия", "карачаево-черкесская республика"],
    "кша": ["конфедеративные штаты америки", "конфедеративные штаты"],
    "кшатрий": ["кшатрия"],
    "къабуз": ["къалиу"],
    "къабургъа": ["кабургъа"],
    "къалиу": ["къабуз"],
    "къанат": ["канат"],
    "къапгъачлыбакъа": ["такъалыбакъа"],
    "къаратавукъ": ["сыйырткъыч"],
    "къаргъа": ["карга"],
    "къаргъыш": ["каргъыш"],
    "къаргъышлы": ["каргъышлы"],
    "къаркъурчакъ": ["къаркъыз"],
    "къарув": ["карув"],
    "къаты": ["каты"],
    "къатын": ["катын"],
    "къде": ["където"],
    "кълдома": ["кърга", "къргапарь"],
    "къоз": ["коз"],
    "къолткъа": ["колтха", "колтка"],
    "къолэбзыу": ["бзыу"],
    "къорг": ["ларам"],
    "къоркъу": ["коркув", "корхув", "къоркъув", "къоркъы"],
    "къоркъув": ["коркув", "къоркъу"],
    "къорола": ["нусиреч"],
    "кър": ["поле", "ниви", "ливади", "пасбища"],
    "кърга": ["сялдаз", "кълдома", "къргапарь"],
    "кърга видева": ["сялдаз видева"],
    "къргапарь": ["кълдома", "кърга"],
    "кърмаче": ["бебе", "детенце", "рожба", "чедо", "пеленаче", "сукалче"],
    "кърчаг": ["делва", "гърне", "каца"],
    "късмет": ["слука", "щастие", "шанс", "сполука"],
    "кът": ["ъгъл", "кьоше"],
    "къуйу": ["куйу"],
    "къул": ["кул"],
    "къумукъ тил": ["къумукъча"],
    "къурдаш": ["ёлдаш", "ювукъ", "дост"],
    "къут": ["кут"],
    "къутла": ["кутла"],
    "къч": ["ритане", "ритник", "ритване"],
    "къшей": ["комат"],
    "къщурка": ["колиба", "къщичка", "стаичка"],
    "къылувчы": ["этиджи"],
    "къылыч": ["кылыч", "кылыц"],
    "къэ": ["хъэ"],
    "кыек": ["бит", "кыйпылчык", "китек", "ватык", "ярчык", "корама", "калдык-постык"],
    "кызанак": ["батинча"],
    "кызгылт": ["кызылсу"],
    "кызсьыв зэр": ["сувтса зэр"],
    "кызылбаш": ["кизильбаш"],
    "кызылказ": ["фламинго"],
    "кызылорда": ["кызыл-орда", "кзыл-орда", "перовск", "ак-мечеть"],
    "кызылсу": ["кызгылт"],
    "кызылырмак": ["кызыл-ирмак", "галис"],
    "кый": ["кий"],
    "кыкав": ["кыкавши"],
    "кыкавши": ["кыкав"],
    "кылабала": ["кылабыла"],
    "кылкойрык": ["безкойрык"],
    "кылыц": ["кылыч"],
    "кыляв": ["кылявши"],
    "кылявши": ["кыляв"],
    "кылять": ["колоть", "тыкать", "бодать"],
    "кынгырлых": ["кынгырлык"],
    "кынхырлых": ["кынгъырлых"],
    "кыпчак": ["кипчак", "половец"],
    "кыпчакский": ["кипчакский", "половецкий"],
    "кырааска": ["ыйданыы"],
    "кыргыз тили": ["кыргызча"],
    "кыргызская республика": ["киргизская республика", "киргизия", "киргизстан", "кыргызстан"],
    "кыргызстан": ["киргизия", "киргизстан", "киргизская республика"],
    "кырла-мырла": ["карла-марла"],
    "кырыйсыз": ["чексиз"],
    "кыс": ["кис-кис"],
    "кысан": ["тар"],
    "кысарга": ["басарга"],
    "кысыклык": ["кысыхлых"],
    "кысыхлых": ["кысыклык"],
    "кытаялма": ["нардан"],
    "кычкырырга": ["акырырга"],
    "кыш": ["брысь", "пшёл", "пошёл вон"],
    "кышномурт": ["кышно"],
    "кыюлык": ["батырлык"],
    "кыянин": ["киянин"],
    "кьопоолу": ["баклажанная икра"],
    "кьюар-код": ["куар-код"],
    "кьят": ["джа", "ча"],
    "кэб": ["кеб"],
    "кэгэбэшник": ["кагэбист", "кагэбэшник"],
    "кэгэбэшный": ["кагебешный", "кагэбэшный"],
    "кэлидьэ": ["кондьилэ"],
    "кэмп": ["камп"],
    "кэмэ": ["км", "километр"],
    "кэп": ["квалифицированная электронная подпись"],
    "кэроб": ["рожковое дерево", "цератония", "цареградский рожок", "кероб"],
    "кэт": ["кэтрин", "екатерина"],
    "кэтрин": ["кэт"],
    "кэтч": ["рестлинг"],
    "кэтчист": ["кетчист", "рестлер"],
    "кэф": ["коэф"],
    "кэч": ["кэча", "кеч"],
    "кэшировав": ["кэшировавши"],
    "кэшировавши": ["кэшировав"],
    "кювет": ["ров"],
    "кюгюрчюнь": ["кёгюрчюнь"],
    "кюз": ["къач"],
    "кюкю": ["кюкя"],
    "кюкя": ["кюкю"],
    "кюлев": ["кюлкю"],
    "кюлкю": ["кюлюу"],
    "кюльмюш": ["килмис"],
    "кюлюу": ["кюлкю"],
    "кюмюр": ["въглен"],
    "кюмюш": ["кимис"],
    "кюре": ["настоятель"],
    "кюретаж": ["выскабливание"],
    "кюсю": ["киу-сиу", "киу-шиу"],
    "кють": ["кит"],
    "кютюв": ["китив"],
    "кютювчю": ["китивци"],
    "кядьса": ["кядьвийса"],
    "кяинат": ["феза"],
    "кялагаи": ["келагаи", "кялагай"],
    "кялагай": ["кялагаи"],
    "кярки": ["кьярки", "керки", "тигранашен"],
    "кяфир": ["кафир", "гяур"],
    "кёгюрчюнь": ["кюгюрчюнь"],
    "кёзь сув": ["кез сув"],
    "кёзьчюк": ["кёзьчёк"],
    "кёзьчёк": ["кёзьчюк"],
    "кёкусинкай": ["кёкусин"],
    "кёкюрек": ["тёш"],
    "кёлда": ["телда", "толда"],
    "кёнделен": ["кенделен", "гунделен", "генделен"],
    "кёнигсберг": ["калининград", "королевец"],
    "кёрлингист": ["кёрлер"],
    "кёрюмлю": ["керимли"],
    "ла-гуайра": ["варгас"],
    "ла-манш": ["ламанш"],
    "лабав": ["лабавши"],
    "лабавши": ["лабав"],
    "лабан": ["шир"],
    "лабане": ["лабанэ"],
    "лабанэ": ["лабане"],
    "лабать": ["играть"],
    "лабиализация": ["огубление"],
    "лабиализировав": ["лабиализировавши"],
    "лабиализировавши": ["лабиализировав"],
    "лабиализировать": ["лабиализовать"],
    "лабиализовав": ["лабиализовавши"],
    "лабиализовавши": ["лабиализовав"],
    "лабиализованный": ["лабиальный", "губной"],
    "лабиализовать": ["огублять", "огубить", "лабиализировать"],
    "лабиальность": ["губность"],
    "лабиальный": ["губной"],
    "лабильный": ["неустойчивый", "нестойкий", "подвижный", "волатильный", "переменный", "конформный"],
    "лабиодентальный": ["губно-зубной"],
    "лабиринтит": ["внутренний отит"],
    "лабиринтный": ["лабиринтовый"],
    "лабиринтовый": ["лабиринтный"],
    "лабиринтодонт": ["батрахоморф"],
    "лабиринтообразный": ["лабиринтоподобный"],
    "лаборантка": ["ассистентка", "практикантка"],
    "лаборатория": ["кухня"],
    "лабораторная": ["лабораторная работа", "лаборатория"],
    "лабораторная работа": ["практикум"],
    "лабрадор-ретривер": ["лабрадор"],
    "лабуда": ["ерунда", "чушь", "чепуха", "лабусня"],
    "лабух": ["джазист"],
    "лабханд": ["табассум"],
    "лаваж": ["промывание"],
    "лавандос": ["бабки"],
    "лаваторий": ["лавабо", "санузел"],
    "лавинний": ["лавиновий"],
    "лавировав": ["лавировавши"],
    "лавировавши": ["лавировав"],
    "лавирование": ["лавировка"],
    "лавированье": ["лавирование"],
    "лавировать": ["идти галсами", "увёртываться", "уклоняться"],
    "лавировка": ["лавирование"],
    "лавиця": ["лава"],
    "лавка": ["скамейка"],
    "лавкрафтианский": ["лавкрафтовский"],
    "лавкрафтовский": ["лавкрафтианский"],
    "лавливав": ["лавливавши"],
    "лавливавши": ["лавливав"],
    "лавомакс": ["тилорон"],
    "лавочка": ["контора", "афёра", "шайка-лейка"],
    "лавочник": ["торговец"],
    "лаврентий": ["лаврен", "лаврент"],
    "лаврий": ["лаврион"],
    "лаврийский": ["лаврионский"],
    "лаврион": ["лаврий"],
    "лавровый венок": ["лавровый венец", "лавры", "лавры победителя", "пальма первенства"],
    "лавророза": ["олеандр"],
    "лаврський": ["монастирський"],
    "лавруссия": ["еврамерика", "каледония"],
    "лавсан": ["полиэтилентерефталат", "полиэстер", "майлар", "терилен", "дакрон"],
    "лавэ": ["бабки", "бабло", "бабосы", "лавэшки", "мани", "тугрики"],
    "лаг": ["задержка", "отставание", "запаздывание"],
    "лагав": ["лагавши"],
    "лагавши": ["лагав"],
    "лагать": ["класть"],
    "лагер": ["лежак"],
    "лагерница": ["ссыльнопоселенка"],
    "лагерь": ["стоянка", "каторга", "союз", "коалиция"],
    "лагерь смерти": ["концентрационный лагерь", "фабрика смерти"],
    "лагода": ["мир", "порядок"],
    "лагтинг": ["ландстинг"],
    "лагуна": ["лагун"],
    "лад": ["ладок"],
    "лада": ["любимая"],
    "ладан": ["фимиам"],
    "ладанка": ["амулет", "оберег", "талисман", "апотропей", "курильница", "ладанница", "кадильница"],
    "ладанний": ["ладановий"],
    "ладанник": ["розан каменный"],
    "ладанница": ["ладанка"],
    "ладзарони": ["лаццарони"],
    "ладив": ["ладивши"],
    "ладивши": ["ладив"],
    "ладино": ["еврейско-испанский язык", "джудекко", "спаньоль", "жудезмо", "хебронео"],
    "ладинский": ["тирольский ретороманский", "доломитский", "трентинский"],
    "ладинский язык": ["тирольский ретороманский", "доломитский", "трентинский"],
    "ладка": ["латка", "жаровня", "оладка", "оладья"],
    "ладки": ["хорошо"],
    "ладком": ["согласно", "дружно", "ладом"],
    "ладно": ["удобно", "мирно", "в ладу", "успешно", "удачно", "хорошо", "лады", "ок", "хорош", "короче"],
    "ладность": ["складность", "гармоничность", "статность", "слаженность", "стройность", "сработанность", "согласованность"],
    "ладный": ["добротный", "хороший", "статный", "стройный"],
    "ладога": ["ладожское озеро", "нево", "старая ладога"],
    "ладожское озеро": ["ладога", "нево"],
    "ладок": ["лад"],
    "ладом": ["дружно", "мирно", "по-хорошему", "ладком"],
    "ладонь": ["длань", "пясть", "ладошка"],
    "ладоша": ["ладонь", "ладошка"],
    "ладошка": ["пясть"],
    "ладунка": ["патронташ"],
    "лады": ["ладно", "ладушки"],
    "ладьевидный": ["ладьеобразный"],
    "ладьеобразный": ["ладьевидный"],
    "ладья": ["драккар", "чёлн", "посудина", "тура", "гондола"],
    "ладямс": ["петемс", "нолдамс тевс", "тумс", "кондястемс", "яраштомс", "вчёк", "кучемс", "эрямс лац", "тяльгфтамс", "путомс", "максомс"],
    "лаж": ["ажио", "промен", "маржа"],
    "лажа": ["чушь", "ерунда", "обман", "выдумка", "ложь", "туфта", "фуфло", "фальшь", "позор"],
    "лажав": ["лажавши"],
    "лажавши": ["лажав"],
    "лажанув": ["лажанувши"],
    "лажанувши": ["лажанув"],
    "лажануться": ["дать маху", "облажаться"],
    "лажать": ["ошибаться", "позорить", "издеваться"],
    "лажно": ["ладно", "удобно"],
    "лаз": ["лазейка"],
    "лазав": ["лазавши"],
    "лазавши": ["лазав"],
    "лазарев": ["лазик"],
    "лазарева суббота": ["вербная суббота", "лазарево воскресенье", "лазарево воскресение"],
    "лазаревец": ["лазаревчанин"],
    "лазарево воскресение": ["лазарево воскресенье", "лазарева суббота", "вербная суббота"],
    "лазарево воскресенье": ["лазарево воскресение", "лазарева суббота", "вербная суббота"],
    "лазаревчанин": ["лазаревец"],
    "лазарет": ["больница", "госпиталь", "лечебница"],
    "лазаретный": ["больничный", "госпитальный"],
    "лазарит": ["госпиталит"],
    "лазарь": ["попрошайка", "побирушка", "лицемер", "двуличник", "ханжа", "льстец", "низкопоклонник", "подлиза", "прихвостень"],
    "лазаря петь": ["плакаться", "плакаться в жилетку", "в жилетку плакаться", "петь лазаря", "тянуть лазаря", "лазаря тянуть"],
    "лазарёк": ["приятель", "друг"],
    "лазать": ["лазить"],
    "лазейка": ["лаз"],
    "лазер": ["оптический квантовый генератор", "бластер"],
    "лазерка": ["лазерник"],
    "лазерная коагуляция сетчатки": ["лазеркоагуляция"],
    "лазерник": ["лазерка"],
    "лазеротерапия": ["лазерная терапия"],
    "лазерпиций": ["сильфий", "асафетида"],
    "лазертаг": ["лазербол", "лазертеч", "лазертак", "лазертач"],
    "лазив": ["лазивши"],
    "лазивши": ["лазив"],
    "лазить": ["лазать"],
    "лазня": ["баня"],
    "лазовая": ["касихо"],
    "лазомс": ["керомс пачк", "лазомс пакш"],
    "лазоревка": ["зелёная лазоревка", "обыкновенная лазоревка"],
    "лазурит": ["лазуревый камень"],
    "лазурний": ["лазуровий"],
    "лазурник": ["гладыш"],
    "лазурный": ["лазоревый"],
    "лазуровий": ["лазурний"],
    "лазурь": ["голубизна", "синева", "бирюза"],
    "лазутничав": ["лазутничавши"],
    "лазутничавши": ["лазутничав"],
    "лазутчик": ["разведчик", "шпион", "доносчик"],
    "лазутчица": ["разведчица", "шпионка"],
    "лай": ["лаяние", "лаянье", "гавканье", "рявканье", "брань", "ругань"],
    "лайбах": ["любляна"],
    "лайдак": ["бездельник", "лентяй"],
    "лайдетектор": ["детектор лжи", "полиграф"],
    "лайк": ["лойс"],
    "лайкав": ["лайкавши"],
    "лайкавши": ["лайкав"],
    "лайкнув": ["лайкнувши"],
    "лайкнувши": ["лайкнув"],
    "лайкнуть": ["гавкнуть"],
    "лайкра": ["эластан", "вайрин", "эспа", "неолан", "спанцель", "ворин"],
    "лайм": ["лима", "зелёный лимон"],
    "лайн-баба": ["лайн баба"],
    "лайт-версия": ["пробная версия"],
    "лайтовенько": ["приятненько"],
    "лайтово": ["легко"],
    "лайфстайл": ["образ жизни"],
    "лайфхак": ["хак"],
    "лакав": ["лакавши"],
    "лакавши": ["лакав"],
    "лаканье": ["лакание"],
    "лакедемон": ["спарта"],
    "лакедемонский": ["спартанский"],
    "лакей": ["подхалим", "лизоблюд"],
    "лакейничав": ["лакейничавши"],
    "лакейничавши": ["лакейничав"],
    "лакейскость": ["лакейство"],
    "лакействовав": ["лакействовавши"],
    "лакействовавши": ["лакействовав"],
    "лакец": ["лак"],
    "лакз": ["лакзан", "лекия", "лакзистан"],
    "лакировав": ["лакировавши"],
    "лакировавши": ["лакировав"],
    "лакировальщик": ["лакировщик"],
    "лакирование": ["лакировка"],
    "лакировать": ["приукрашивать", "зашлифовывать", "шлифовать"],
    "лакку маз": ["лакку"],
    "лакмус": ["лакмусовая бумага"],
    "лакмусовая бумажка": ["индикаторная бумага", "пробный камень"],
    "лакнув": ["лакнувши"],
    "лакнувши": ["лакнув"],
    "лаковый": ["лакированный"],
    "лакомив": ["лакомивши"],
    "лакомивши": ["лакомив"],
    "лакомиться": ["угощаться", "вкушать"],
    "лакомка": ["гурман"],
    "лакомый": ["вкусный", "деликатесный"],
    "лаконизм": ["лаконичность", "немногословность", "лапидарность", "аскетизм"],
    "лаконика": ["лакония"],
    "лаконически": ["лаконично", "немногословно"],
    "лаконично": ["лаконически", "кратко", "ёмко", "немногословно"],
    "лаконичность": ["сжатость", "немногословность"],
    "лаконичный": ["краткий", "немногословный", "лаконический", "аскетичный", "лапидарный"],
    "лакония": ["лаконика"],
    "лакост": ["лакосте"],
    "лакосте": ["лакост"],
    "лакрица": ["лакричник", "солодка"],
    "лакриця": ["локриця"],
    "лакричник": ["лакрица", "солодка"],
    "лакричниковый": ["лакричный", "солодковый"],
    "лакричный": ["солодковый", "лакричниковый"],
    "лакский язык": ["лакский"],
    "лактатдегидрогеназа": ["лдг"],
    "лактоген": ["пролактин", "соматомаммотропин"],
    "лактогенез": ["молокообразование"],
    "лактоза": ["молочный сахар"],
    "лактофлавин": ["рибофлавин"],
    "лакфиоль": ["желтофиоль"],
    "лакшери": ["люкс"],
    "лакшив": ["лакшивши"],
    "лакшивши": ["лакшив"],
    "лал": ["рубин", "шпинель"],
    "лалакав": ["лалакавши"],
    "лалакавши": ["лалакав"],
    "лалеш": ["лалш", "лалиш", "лалыш"],
    "лалыш": ["лалеш"],
    "ламаизм": ["жёлтая вера"],
    "ламанш": ["ла-манш"],
    "ламаркист": ["лысенковец", "мичуринец"],
    "ламба": ["ламборгини", "ламборджини"],
    "ламбдаизм": ["лямбдоцизм"],
    "ламбдацизм": ["параламбдацизм", "ламбдаизм"],
    "ламберсексуал": ["дровосексуал"],
    "ламберт": ["лб"],
    "ламбушка": ["ламба"],
    "ламель": ["пластина", "рейка", "шпонка", "лепесток"],
    "ламентировать": ["жаловаться", "сетовать"],
    "ламер": ["чайник", "профан"],
    "ламех": ["лемех"],
    "ламина": ["ламин"],
    "ламинария": ["морская капуста"],
    "ламинарность": ["безвихревость"],
    "ламинарный": ["слоистый", "плоский", "безвихревой"],
    "ламинация": ["ламинирование"],
    "ламинировав": ["ламинировавши"],
    "ламинировавши": ["ламинировав"],
    "ламинэктомия": ["рахиотомия"],
    "ламоксть": ["аф весть"],
    "лампа": ["лампочка", "радиолампа"],
    "лампа-вспышка": ["фотовспышка"],
    "лампичив": ["лампичивши"],
    "лампичивши": ["лампичив"],
    "лампичить": ["доделывать", "подправлять"],
    "лампово": ["душевно", "уютно"],
    "ламповый": ["лампочный", "световой", "светильный"],
    "лампопо": ["лимпопо"],
    "лампочка висячая": ["электрическая лампочка", "электролампочка", "лампочка ильича"],
    "лампочный": ["ламповый"],
    "лампука": ["дорада"],
    "ламут": ["эвен"],
    "ламывав": ["ламывавши"],
    "ламывавши": ["ламывав"],
    "ланга": ["вельхкс"],
    "лангар": ["мирсот"],
    "лангедокец": ["окситанец"],
    "лангобард": ["ломбард"],
    "ландкарта": ["географическая карта"],
    "ландо": ["ландоле", "фиакр"],
    "ландрин": ["монпансье"],
    "ландромат": ["прачечная-автомат"],
    "ландстинг": ["лагтинг"],
    "ландыш": ["заячьи ушки", "воронец", "мытная трава", "язык лесной"],
    "ланита": ["щека"],
    "ланитный": ["щёчный"],
    "ланка": ["олениха"],
    "ланкиец": ["шриланкиец", "цейлонец"],
    "ланкийский": ["шри-ланкийский"],
    "ланнер": ["средиземноморский сокол"],
    "лансировав": ["лансировавши"],
    "лансировавши": ["лансировав"],
    "лантанид": ["лантаноид"],
    "лантаноид": ["лантанид"],
    "лантух": ["розтелепа", "незграба"],
    "ланцет": ["скарификатор"],
    "ланцетный": ["ланцетовидный"],
    "ланцюг": ["цеп", "кайдани"],
    "ланч": ["ленч"],
    "ланчевав": ["ланчевавши"],
    "ланчевавши": ["ланчевав"],
    "ланчевать": ["ланчеваться"],
    "ланчеваться": ["ланчевать"],
    "лань": ["европейская лань", "даниэль"],
    "лаосец": ["лаотянин"],
    "лаосский": ["лаотянский"],
    "лаотянец": ["лаосец", "лаотянин"],
    "лаотянин": ["лаосец"],
    "лапа": ["рука", "ветвь"],
    "лапав": ["лапавши"],
    "лапавица": ["киша", "кал", "влага", "мокрота", "дъжд", "сняг"],
    "лапавши": ["лапав"],
    "лапанье": ["лапание"],
    "лапароскопия": ["перитонеоскопия"],
    "лапаротомия": ["чревосечение"],
    "лапатий": ["лапастий"],
    "лапать": ["хватать", "трогать", "щупать", "мять", "тискать", "обжимать"],
    "лапив": ["лапивши"],
    "лапивши": ["лапив"],
    "лапидарно": ["лаконично"],
    "лапидарность": ["краткость", "сжатость", "лаконизм", "лаконичность"],
    "лапидарный": ["лаконичный", "аскетичный"],
    "лапка": ["лапа", "след", "немецкий", "кавычка"],
    "лапландец": ["саам", "лопарь"],
    "лапландка": ["саамка"],
    "лапласовский": ["лапласов"],
    "лаповидный": ["лапообразный"],
    "лапообразный": ["лаповидный"],
    "лапотный патриотизм": ["квасной патриотизм", "лапотно-квасной патриотизм", "казённый патриотизм", "лакейский патриотизм", "ура-патриотизм"],
    "лапоть": ["невежда", "недоучка", "неуч", "сибирский валенок", "гроб"],
    "лапочка": ["лапка", "лапа"],
    "лапсердак": ["балахон"],
    "лаптем щи хлебать": ["щи лаптем хлебать", "мух ноздрями ловить"],
    "лапуха студёная": ["мать-и-мачеха"],
    "лапушка": ["лапочка", "лапуля"],
    "лапша быстрого приготовления": ["бич-пакет", "доширак", "бичик", "дошик", "бомж-пакет"],
    "лапшеватый": ["завиральный", "лапшевастый"],
    "лапшевник": ["лапшенник"],
    "лапшица": ["лапшичка"],
    "лапшичка": ["лапшица"],
    "лара": ["ларочка", "лариса"],
    "ларакалла": ["мавры"],
    "ларам": ["къорг"],
    "ларва": ["лярва"],
    "ларец": ["шкатулка", "сундучок", "ковчег", "укладка"],
    "лариат": ["аркан", "лассо"],
    "ларингализация": ["глоттализация"],
    "ларингальный": ["гортанный"],
    "ларингооторинолог": ["лор"],
    "ларс": ["лассе"],
    "ларь": ["сундук", "ящик", "ларёк", "прилавок", "зумпф", "резервуар", "жёлоб"],
    "ларёк": ["киоск", "будка"],
    "лас-вегас": ["игорная столица"],
    "лас-пальмас": ["лас-пальмас-де-гран-канария"],
    "ласка": ["нежность", "любовь", "добросердечность", "доброжелательность"],
    "ласкав": ["ласкавши"],
    "ласкавши": ["ласкав"],
    "ласкатель": ["льстец", "низкопоклонник"],
    "ласкательный": ["ласкающий", "нежный", "льстивый", "уменьшительный"],
    "ласкать": ["нежить", "баловать", "голубить", "тетенькать", "холить", "беречь", "лелеять", "тешить", "утешать", "успокаивать"],
    "ласкаться": ["ластиться", "тешить", "утешать", "успокаивать"],
    "ласково": ["нежно"],
    "ласо": ["аркан"],
    "ласолюб": ["ласолюбець"],
    "ласолюбець": ["ласолюб"],
    "ласочка": ["ласиця", "ласка"],
    "лассо": ["аркан"],
    "ласта": ["равнина", "луг"],
    "ластив": ["ластивши"],
    "ластивши": ["ластив"],
    "ластик": ["резинка", "стирательная резинка", "стёрка", "стирашка"],
    "ластить": ["ласкать"],
    "ластиться": ["ласкаться", "заискивать"],
    "ластовиння": ["ластовинки"],
    "ласувати": ["ласуватися"],
    "лата": ["планка", "рейка"],
    "латав": ["латавши"],
    "латавши": ["латав"],
    "латание": ["залатывание", "заштопывание"],
    "латания": ["пальма"],
    "латанье": ["латание"],
    "латвийская республика": ["латвия"],
    "латвийская сср": ["латвия"],
    "латвийский": ["латышский"],
    "латвийско-российский": ["российско-латвийский"],
    "латвия": ["латвийская республика"],
    "латекс": ["презерватив"],
    "латексный": ["резиновый", "каучуковый"],
    "латентная гонорея": ["гонококконосительство"],
    "латентность": ["неявность", "скрытость", "имплицитность", "задержка", "отклик"],
    "латентный": ["скрытый", "неявный", "невидимый"],
    "латеральный": ["боковой"],
    "латимерия": ["целакант"],
    "латин": ["латинос", "латинянин"],
    "латинизировав": ["латинизировавши"],
    "латинизировавши": ["латинизировав"],
    "латиниця": ["латинська абетка"],
    "латинский": ["древнеримский", "классический", "католический", "латынь"],
    "латинский язык": ["латынь"],
    "латинь": ["латина", "латинська мова"],
    "латка": ["заплата", "нашлёпка", "латание", "залатывание", "салки"],
    "латрина": ["уборная", "туалет", "нужник", "сортир", "форика"],
    "латук": ["салат"],
    "латунировав": ["латунировавши"],
    "латунировавши": ["латунировав"],
    "латунирование": ["латунировка"],
    "латунировка": ["латунирование"],
    "латунний": ["мосяжний", "мосяжевий"],
    "латунь": ["жёлтая медь"],
    "латынь": ["латинский язык", "латиница"],
    "латыхга": ["хрихыц", "ащхъарауа"],
    "латышский": ["латвийский"],
    "лауданум": ["парегорик"],
    "лауреат": ["призёр", "обладатель", "победитель"],
    "лахтак": ["морской заяц"],
    "лахтарь": ["белофинн"],
    "лахудра": ["карга", "грымза", "мымра", "дрянь"],
    "лаца": ["прокс", "кода", "бъта"],
    "лаций": ["лациум"],
    "лациум": ["лаций"],
    "лацци": ["лаццо"],
    "лаццо": ["лацци"],
    "лача": ["лаче"],
    "лаче": ["лача"],
    "лачинский коридор": ["бердзорский коридор"],
    "лачуга": ["хибара", "халупа", "хижина", "хибарка"],
    "лачужка": ["лачуга", "халупа", "хибара", "халабуда"],
    "лашкар": ["урду"],
    "лащити": ["пестити"],
    "лаънат": ["нафрин"],
    "лаяв": ["лаявши"],
    "лаявши": ["лаяв"],
    "лаяние": ["лаянье"],
    "лаянье": ["лаяние", "лай"],
    "лаять": ["гавкать", "брехать", "ругать", "бранить", "хулить"],
    "лаяться": ["браниться", "ругаться"],
    "лбс": ["линия боевого соприкосновения", "передовая", "ленточка", "передок"],
    "лгав": ["лгавши"],
    "лгавши": ["лгав"],
    "лганьё": ["враньё", "обман", "фальшь", "неправда"],
    "лгбт-активизм": ["лгбт-движение"],
    "лгбт-активист": ["гей-активист"],
    "лгбт-движение": ["лгбт-активизм"],
    "лгу": ["спбгу"],
    "лгун": ["врун", "лжец", "обманщик"],
    "лгунья": ["обманщица"],
    "лдк": ["лдок", "лдпк"],
    "лднр": ["новороссия", "ордло"],
    "лдок": ["лдк"],
    "лдпк": ["лдк"],
    "лдсп": ["ламинированная дсп"],
    "лебапский велаят": ["чарджоуская область"],
    "лебеда": ["мучник", "марь", "гусиная лапка"],
    "лебединая песня": ["лебединая песнь"],
    "лебединый": ["лебяжий"],
    "лебедь": ["лебедь-самец", "лебедь-самка", "пава", "ласточка", "лапушка"],
    "лебеза": ["льстец", "подлиза", "угодник", "конопатка"],
    "лебезив": ["лебезивши"],
    "лебезивши": ["лебезив"],
    "лебезить": ["егозить", "льстить", "заискивать", "ластиться", "увиваться", "угодничать", "подъезжать"],
    "лебенсраум": ["лебеншраум"],
    "лебоню": ["ърдазу", "пяндра"],
    "лебяжина": ["лебедятина"],
    "лебёдка": ["лебёдушка"],
    "лебёдушка": ["лебёдка", "голубушка", "голубка"],
    "лев": ["царь зверей", "орёл", "светский лев"],
    "левак": ["леворадикал", "левачок", "оппортунист"],
    "левантиец": ["левантинец"],
    "левантийский": ["левантинский"],
    "левантинец": ["левантиец"],
    "левантинский": ["левантийский"],
    "левачив": ["левачивши"],
    "левачивши": ["левачив"],
    "левачьё": ["левак", "левый"],
    "леве": ["взятка"],
    "левев": ["левевши"],
    "левевши": ["левев"],
    "левзея": ["рапонтикум", "большеголовник"],
    "левиатан": ["лекеон"],
    "левий": ["леви"],
    "левират": ["ужичество", "аменгерство"],
    "левитировав": ["левитировавши"],
    "левитировавши": ["левитировав"],
    "левитирование": ["левитация"],
    "левитировать": ["возноситься"],
    "левитрон": ["сфератор"],
    "левкасив": ["левкасивши"],
    "левкасивши": ["левкасив"],
    "левкасить": ["грунтовать"],
    "левкащик": ["левкасчик"],
    "левкой": ["маттиола"],
    "лево руля": ["лево на борт"],
    "левобережная украина": ["левобережная малороссия"],
    "левовий": ["левиний"],
    "левокарнитин": ["л-карнитин"],
    "левопатриотический": ["левонационалистический"],
    "леворадикал": ["леворадикалист"],
    "леворадикализм": ["левачество"],
    "леворадикальный": ["леворадикалистский"],
    "леворукий": ["левша", "криворукий", "жопорукий"],
    "леворукость": ["левшизм"],
    "леворулевой": ["леворульный"],
    "леворульный": ["леворулевой"],
    "левостороннесть": ["левосторонность"],
    "левосторонний": ["левый"],
    "левосторонность": ["левостороннесть"],
    "левулоза": ["фруктовый сахар", "фруктоза", "фруктопираноза", "арабиногексулоза"],
    "левулёза": ["фруктоза"],
    "левша": ["леворукий"],
    "левшизм": ["леворукость"],
    "легавив": ["легавивши"],
    "легавивши": ["легавив"],
    "легавить": ["лягавить"],
    "легавый": ["лягавый"],
    "легализировав": ["легализировавши"],
    "легализировавши": ["легализировав"],
    "легализировать": ["легализовать"],
    "легализм": ["формализм", "формалистика", "бюрократизм", "буквоедство", "ханжество", "педантизм", "легизм", "фацзя"],
    "легализовав": ["узаконив", "легализовавши"],
    "легализовавши": ["легализовав", "узаконив"],
    "легализовать": ["легализировать"],
    "легализовывав": ["легализовывавши"],
    "легализовывавши": ["легализовывав"],
    "легализовываться": ["легализироваться", "легализоваться"],
    "легализуя": ["узаконивая"],
    "легальный": ["законный", "разрешённый", "дозволенный"],
    "легатарий": ["отказополучатель"],
    "легаш": ["легавый"],
    "леггинсы": ["легинсы", "лосины"],
    "легенда": ["сказание", "сказанье", "житие", "жизнеописание", "четия", "четья", "миф"],
    "легендаризировав": ["легендаризировавши"],
    "легендаризировавши": ["легендаризировав"],
    "легендариум": ["канон"],
    "легендировав": ["легендировавши"],
    "легендировавши": ["легендировав"],
    "легизм": ["фацзя", "легализм"],
    "легинсы": ["лосины"],
    "легионеллёз": ["болезнь легионеров"],
    "легировав": ["легировавши"],
    "легировавши": ["легировав"],
    "легитимация": ["легитимизация"],
    "легитимизация": ["легитимация", "узаконивание"],
    "легитимизировать": ["узаконивать", "узаконить", "легитимизовать", "легитимировать"],
    "легитимизируемый": ["легализируемый", "легализовуемый", "легитимируемый", "узакониваемый"],
    "легитимизовав": ["легитимизовавши"],
    "легитимизовавши": ["легитимизовав"],
    "легитимировав": ["легитимировавши"],
    "легитимировавши": ["легитимировав"],
    "легитимировать": ["узаконивать", "узаконить", "легитимизировать"],
    "легко": ["без труда"],
    "легковагий": ["легковажний"],
    "легковая машина": ["легковой автомобиль", "тачка", "легковушка"],
    "легковерно": ["доверчиво"],
    "легковерность": ["доверчивость", "легковерие"],
    "легковерный": ["доверчивый", "наивный"],
    "легковерье": ["легковерие"],
    "легковесный": ["легкомысленный"],
    "легковой автомобиль": ["легковушка", "легковая машина", "тачка", "тачила"],
    "легковоспламеняемый": ["легковоспламеняющийся", "горючий"],
    "легковушка": ["легковуха"],
    "легковыполнимый": ["легкоисполнимый", "лёгкий", "нетрудный", "несложный"],
    "легкомысленничав": ["легкомысленничавши"],
    "легкомысленничавши": ["легкомысленничав"],
    "легкомысленно": ["необдуманно", "опрометчиво", "поспешно"],
    "легкомысленность": ["легкомыслие"],
    "легкомысленный": ["беспечный", "несерьёзный", "ветреный", "безответственный", "неосторожный", "неосмотрительный", "непредусмотрительный", "неблагоразумный", "опрометчивый", "легковесный"],
    "легкомыслие": ["необдуманность", "несерьёзность", "опрометчивость", "легкомысленность", "ветреность"],
    "легкоплавкий": ["плавкий"],
    "легкоподвижный": ["жидкотекучий"],
    "легкотня": ["пустяк"],
    "легонько": ["легонечко", "слегка"],
    "легчав": ["легчавши"],
    "легчавши": ["легчав"],
    "легче": ["проще"],
    "легчив": ["легчивши"],
    "легчивши": ["легчив"],
    "ледарство": ["ледарювання"],
    "ледащий": ["лядащий"],
    "леденев": ["леденевши"],
    "леденевши": ["леденев"],
    "леденеть": ["застывать", "замерзать", "коченеть", "стынуть"],
    "леденец": ["сосачка", "пастилка"],
    "леденив": ["леденивши"],
    "леденивши": ["леденив"],
    "леди": ["дама"],
    "ледина": ["целина"],
    "ледник": ["глетчер"],
    "ледовая дружина": ["хоккейная команда"],
    "ледовитый океан": ["северный ледовитый океан"],
    "ледовый": ["ледяной", "гляциальный"],
    "ледогенератор": ["льдогенератор"],
    "ледоступ": ["ледоход", "снегоступ"],
    "ледъ": ["ледокъ", "катокъ"],
    "ледышка": ["льдышка", "сосулька"],
    "ледянев": ["ледяневши"],
    "ледяневши": ["ледянев"],
    "ледянив": ["ледянивши"],
    "ледянивши": ["ледянив"],
    "ледянка": ["льдинка"],
    "ледяной": ["ледовый", "холодный"],
    "ледяшка": ["ледышка", "льдинка"],
    "лежав": ["лежавши"],
    "лежавши": ["лежав"],
    "лежак": ["лежень", "висяк"],
    "лежальщик": ["лежатель"],
    "лежание": ["лежанье"],
    "лежать": ["находиться", "покоиться"],
    "лежачий полицейский": ["искусственная неровность"],
    "лежбище": ["залёжка", "лёжка", "колония", "логово", "лежанка", "ложе"],
    "лежень": ["лежебока", "лентяй", "бездельник"],
    "лежит на душе": ["заботить", "гнести"],
    "лежмя": ["влёжку", "лёжа"],
    "лезвие": ["лезьво"],
    "лезги": ["куьре", "лекь", "лекьрен"],
    "лезгистан": ["лакз"],
    "лезечко": ["зеркало"],
    "лезть": ["карабкаться", "проникать", "налезать", "линять", "дырявиться"],
    "лезть в бутылку": ["лезть в пузырь", "вскипать"],
    "лезть в душу": ["в душу лезть"],
    "лезть в залупу": ["в залупу лезть"],
    "лезть из кожи": ["выделываться", "выслуживаться"],
    "лезть на рожон": ["лезть на рога", "лезть в бутылку"],
    "лейб-гвардеец": ["гвардеец"],
    "лейкемия": ["алейкемия", "лейкоз", "белокровие"],
    "лейкодерма": ["витилиго"],
    "лейкоз": ["алейкемия", "лейкемия", "белокровие"],
    "лейкокератоз": ["лейкокератозис"],
    "лейкокератозис": ["лейкокератоз"],
    "лейкома": ["бельмо"],
    "лейкомаляция": ["лейкоэнцефалопатия"],
    "лейкопатия": ["альбинизм"],
    "лейкопения": ["гиполейкоцитоз"],
    "лейкоплазия": ["лейкоплакия"],
    "лейкоплакия": ["лейкоплазия", "прозоплазия", "краурозис", "ксерозис", "пахидермия", "лейкокератозис", "малакоплакия", "псориаз слизистой", "ихтиоз кожи"],
    "лейкопластырь": ["липкий пластырь", "лейкопласт"],
    "лейкопоэз": ["лейкогенез", "лейкоцитопоэз"],
    "лейкоцитный": ["лейкоцитарный"],
    "лейкоцитолизин": ["лейколизин"],
    "лейнеровав": ["лейнеровавши"],
    "лейнеровавши": ["лейнеровав"],
    "лейптинит": ["липтинит"],
    "лейтенант": ["лейтёха", "летёха", "поручик", "сотник"],
    "лейтенант-губернатор": ["губернатор", "вице-губернатор"],
    "лейттема": ["лейтмотив"],
    "лейтёха": ["лейтенант", "летёха", "поручик", "сотник"],
    "лекаж": ["утруска"],
    "лекало": ["шаблон", "модель"],
    "лекарка": ["медичка", "врачиха", "лекарша", "знахарка", "докторша"],
    "лекарничав": ["лекарничавши"],
    "лекарничавши": ["лекарничав"],
    "лекарничество": ["зелейничество"],
    "лекарственное средство": ["лекарство", "медикамент", "препарат"],
    "лекарственный электрофорез": ["ионофорез", "ионогальванизация", "ионотерапия"],
    "лекарство": ["лекарственное средство", "медикамент", "препарат"],
    "лекарша": ["докторша", "лекарка", "врачиха", "врачица"],
    "лекарь": ["врач", "доктор", "медик", "эскулап"],
    "леки": ["лаки"],
    "лекин": ["аммо", "вале", "балки"],
    "лековерие": ["лековерност", "лекомислие", "лекомисленост", "наивност"],
    "лекост": ["лекота"],
    "лекс": ["лекса"],
    "лекса": ["лекс"],
    "лексема": ["слово", "семантическое поле"],
    "лексер": ["лексический анализатор"],
    "лексика": ["словарь", "лексикон"],
    "лексикализировав": ["лексикализировавши"],
    "лексикализировавши": ["лексикализировав"],
    "лексикализовав": ["лексикализовавши"],
    "лексикализовавши": ["лексикализовав"],
    "лексикализовать": ["лексикализировать"],
    "лексикограф": ["словарник"],
    "лексикографировав": ["лексикографировавши"],
    "лексикографировавши": ["лексикографировав"],
    "лексикон": ["лексика", "запас слов", "лексический запас", "словарный запас"],
    "лексикостатистика": ["глоттохронология"],
    "лексическая категория": ["часть речи"],
    "лексический": ["лексикальный", "словарный", "лексиконный"],
    "лексическое значение": ["лексема"],
    "лексическое излишество": ["периссология"],
    "лекторий": ["лекториум"],
    "лектриса": ["чтица", "докладчица", "лекторша"],
    "лекция": ["нотация", "поучение"],
    "лекь": ["лезгин"],
    "лелейный": ["нежный"],
    "лелека": ["чорногуз", "бусел", "бусол", "боцюн"],
    "лелеяв": ["лелеявши"],
    "лелеявши": ["лелеяв"],
    "лелеянье": ["лелеяние"],
    "лелеять": ["ласкать", "нежить", "холить", "пестовать", "тешить", "услаждать"],
    "лель": ["купидон", "амур"],
    "лемент": ["лементування"],
    "лемех": ["лемеш", "сошник"],
    "лемешив": ["лемешивши"],
    "лемешивши": ["лемешив"],
    "лемматизация": ["нормализация"],
    "лемматизировав": ["лемматизировавши"],
    "лемматизировавши": ["лемматизировав"],
    "лемминг": ["пеструшка", "хомячок", "обыватель"],
    "лемок": ["русин"],
    "лемонграсс": ["лимонная трава", "лимонное сорго", "лимонный злак", "цимбопогон", "цитронелла", "челнобородник"],
    "лен": ["феод", "фьеф"],
    "лендинг": ["посадочная страница", "целевая страница"],
    "ленивев": ["ленивевши"],
    "ленивевши": ["ленивев"],
    "ленивец": ["лентяй", "лодырь", "нетяг", "тихоход"],
    "ленивка": ["лентяйка", "рулилка"],
    "леникс": ["натяжной ролик"],
    "ленинградец": ["петербуржец", "петроградец", "питерец"],
    "ленинградка": ["петербуржанка", "петербурженка"],
    "ленинградская область": ["ленобласть"],
    "ленинец": ["ленинист"],
    "ленинск-туркменский": ["ленинск"],
    "ленинский": ["ленинистский"],
    "лениция": ["мягкая мутация", "аспирация"],
    "ленник": ["вассал"],
    "ленный": ["линяющий"],
    "ленобласть": ["ленинградская область"],
    "ленок": ["лён"],
    "леность": ["лень", "безделье"],
    "леночка": ["лена"],
    "ленсовет": ["петросовет"],
    "лента": ["полоса", "полоска", "кинофильм", "фильм", "стена"],
    "лента мёбиуса": ["лист мёбиуса", "петля мёбиуса"],
    "лентец": ["цестода"],
    "лентикулярный": ["линзовидный", "линзообразный", "линзоподобный", "чечевицеобразный", "чечевицеподобный"],
    "лентовидный": ["лентообразный"],
    "лентовщик": ["ленточник"],
    "лентообразный": ["лентовидный"],
    "лентяйка": ["ленивица"],
    "лентяйничав": ["лентяйничавши"],
    "лентяйничавши": ["лентяйничав"],
    "лентяйничание": ["лентяйничанье", "лентяйничество", "бездельничание", "лодырничание"],
    "лентяйничанье": ["лентяйничание"],
    "лентяйничать": ["бездельничать", "лодырничать", "лентяйствовать", "ленивничать"],
    "лентяйство": ["лентяйничание", "лентяйничество", "бездельничание"],
    "ленуголок": ["ленкомната", "ленинская комната", "красный уголок"],
    "ленч": ["ланч", "второй завтрак"],
    "ленчик": ["арчак"],
    "лень": ["леность", "ленца", "празднолюбие", "празднолюбье", "праздность", "нерадивость", "апатия", "апатичность", "байбачество"],
    "лео": ["леонард", "леонардо"],
    "леокадий": ["леокадио"],
    "леонидович": ["леонидыч"],
    "леонист": ["вальденс"],
    "леонович": ["леоныч"],
    "леонора": ["элеонора"],
    "леонтий": ["леонций", "левонтий"],
    "леопард": ["пардус", "барс"],
    "лепестричество": ["электричество"],
    "лепетав": ["лепетавши"],
    "лепетавши": ["лепетав"],
    "лепетание": ["лепет", "лепетанье"],
    "лепетання": ["лепет"],
    "лепетанье": ["лепетание"],
    "лепетать": ["щебетать", "мямлить", "шелестеть", "шептать"],
    "лепив": ["лепивши"],
    "лепивши": ["лепив"],
    "лепидокрокит": ["гидрогётит", "рубиновая слюдка", "пирросидерит"],
    "лепидоптерист": ["лепидоптеролог"],
    "лепидоптеролог": ["лепидоптерист"],
    "лепидосирен": ["чешуйчатник", "американский чешуйчатник"],
    "лепидофаг": ["чешуеед"],
    "лепила": ["коновал"],
    "лепиота": ["чешуйница"],
    "лепнина": ["лепка"],
    "лепота": ["красота", "великолепие"],
    "лепра": ["проказа"],
    "лепта": ["пожертвование", "подаяние", "взнос", "вклад"],
    "лепториния": ["узконосость"],
    "лептосоматический": ["лептосомный", "астенический"],
    "лептосомный": ["узкотелый", "лептосоматический"],
    "лептотена": ["лептонема"],
    "лепший": ["лучший"],
    "лепый": ["пригожий", "красивый", "пристойный", "изящный", "украшенный", "ладный"],
    "лепёшковидный": ["лепёшкообразный", "лепёшкоподобный"],
    "лерка": ["плашка"],
    "лерсаныч": ["волеро", "кипелыч"],
    "лес": ["древесина", "частокол"],
    "лесбианство": ["лесбиянство", "сапфизм", "трибадизм", "трибадия"],
    "лесбиянка": ["лесби", "розовая", "лесбиюха", "пиздолизка"],
    "лесбиянский": ["лесбийский"],
    "лесбиянство": ["лесбианство", "сапфизм", "трибадия", "трибадизм"],
    "лесбуха": ["гомосексуалистка", "гомосексуалка", "лесбиянка", "лесби", "розовая"],
    "леска": ["леса"],
    "лесная капуста": ["бородавник обыкновенный"],
    "лесник": ["лесничий", "лесовик", "леший"],
    "лесничав": ["лесничавши"],
    "лесничавши": ["лесничав"],
    "лесничествовав": ["лесничествовавши"],
    "лесничествовавши": ["лесничествовав"],
    "лесничив": ["лесничивши"],
    "лесничивши": ["лесничив"],
    "лесничий": ["лесник"],
    "лесное хозяйство": ["лесхоз"],
    "лесной ходок": ["охотник", "зверолов"],
    "лесовав": ["лесовавши"],
    "лесовавши": ["лесовав"],
    "лесоводческий": ["лесоводственный"],
    "лесовозобновление": ["лесовосстановление"],
    "лесовосстановление": ["лесовозобновление"],
    "лесовщик": ["лесник", "лесничий", "полесовщик"],
    "лесозаготовитель": ["лесозаготовщик"],
    "лесок": ["рощица"],
    "лесоматериал": ["лесопродукт"],
    "лесопилка": ["лесопильня"],
    "лесопильня": ["лесопилка"],
    "лесополка": ["лесополоса"],
    "лесополоса": ["лесополка"],
    "лесопосадка": ["лесопосев", "лесополоса"],
    "лесопункт": ["лесозаготовительный", "пункт"],
    "лесоразведение": ["лесонасаждение"],
    "лесоруб": ["дровосек", "вальщик леса"],
    "лесорубка": ["лесоруб", "лесосек", "пасека", "посека"],
    "лесорубный": ["лесорубочный"],
    "лесорубочный": ["лесорубный"],
    "лесостепь": ["предстепье"],
    "лесостой": ["древостой"],
    "лесотаска": ["бревнотаска"],
    "лесотехникум": ["лесхоз-техникум"],
    "лесотец": ["лесотовец"],
    "лесото": ["королевство лесото", "басутоленд"],
    "лесочек": ["лесок", "рощица"],
    "лесоэкспорт": ["экспорт", "лес"],
    "леспромхоз": ["лесопромышленный", "хозяйство"],
    "лессиваж": ["лессивирование", "иллимеризация", "первекция"],
    "лессировав": ["лессировавши"],
    "лессировавши": ["лессировав"],
    "лессирование": ["лессировка"],
    "лествица": ["лестница"],
    "лествичное право": ["сеньорат"],
    "лестница": ["лесенка"],
    "лестница-стремянка": ["стремянка"],
    "лестничав": ["лестничавши"],
    "лестничавши": ["лестничав"],
    "лестригон": ["листригон"],
    "лесть": ["угодливость", "раболепство"],
    "лесхоз-техникум": ["лесотехникум"],
    "лета": ["забвение"],
    "летав": ["летавши"],
    "летавши": ["летав"],
    "летадло": ["пепелац"],
    "летальность": ["смертоносность"],
    "летальный": ["смертельный", "фатальный", "гибельный"],
    "летальный исход": ["смерть"],
    "летание": ["лёт", "полёт"],
    "летанье": ["летание"],
    "летаргик": ["кататоник"],
    "летаргичный": ["вялый", "неактивный"],
    "летась": ["год таму"],
    "летательный аппарат": ["ла"],
    "летающая тарелка": ["нло", "летающая тарелочка", "тарелка", "летающий диск", "диск", "фрисби"],
    "летев": ["летевши"],
    "летевши": ["летев"],
    "лететь": ["мчаться", "падать", "ломаться", "нарушаться", "портиться"],
    "летище": ["аеродрум", "аерогара"],
    "летка": ["летка-енка", "летка-енька"],
    "летнаб": ["лётчик-наблюдатель"],
    "летний": ["тёплый"],
    "летник": ["однолетник"],
    "летники": ["однолетник"],
    "летный": ["старый", "многолетный", "пожилой", "древний", "ветхий", "дряхлый", "возрастной"],
    "лето": ["юг", "зюйд"],
    "летовав": ["летовавши"],
    "летовавши": ["летовав"],
    "летоисчисление": ["летосчисление", "времяисчисление"],
    "леток": ["лётка"],
    "летопись": ["анналы"],
    "летосчисление": ["летоисчисление", "времяисчисление"],
    "летось": ["летося", "лони", "лонись"],
    "летошний": ["прошлогодний", "прошлый", "годовалый"],
    "летсплеер": ["летсплейщик"],
    "летсплейщик": ["летсплеер"],
    "летун": ["лётчик", "пилот", "летяга"],
    "летючий": ["летучий"],
    "летяга": ["белка-летяга"],
    "лефтизм": ["левачество", "левизна", "гейство"],
    "лечебница": ["больница", "клиника"],
    "лечебный": ["целебный"],
    "лечение": ["терапия", "леченье"],
    "леченье": ["лечение"],
    "лечив": ["лечивши"],
    "лечивши": ["лечив"],
    "лечить": ["врачевать", "исцелять", "пользовать"],
    "лечь": ["улечься", "упасть"],
    "лечь на дно": ["затаиться"],
    "леш": ["мърша", "труп"],
    "лешачий": ["лешев", "лешаков"],
    "леший": ["лесовик", "лесовой", "лесник", "лешак", "лесной дядя", "лисун", "полисун", "дикий мужичок", "лес", "чёрт"],
    "лещина": ["орешник", "фундук"],
    "лещинный": ["лещиновый"],
    "лещиновый": ["лещинный"],
    "лея": ["лейка"],
    "лжа": ["ложь", "неправда"],
    "лже-": ["псевдо-", "ложно-"],
    "лжеакация": ["белая акация"],
    "лжегражданственность": ["псевдогражданственность"],
    "лжедурнишник": ["циклахена"],
    "лжеименной": ["ложный", "лукавый"],
    "лжекириллица": ["псевдокириллица"],
    "лженаука": ["псевдонаука", "квазинаука"],
    "лженаучность": ["псевдонаучность"],
    "лженаучный": ["квазинаучный", "ненаучный", "паранаучный", "псевдонаучный"],
    "лжепастырствовав": ["лжепастырствовавши"],
    "лжепастырствовавши": ["лжепастырствовав"],
    "лжепатриот": ["псевдопатриот"],
    "лжепророк": ["лжемессия", "шарлатан"],
    "лжепророчествовав": ["лжепророчествовавши"],
    "лжепророчествовавши": ["лжепророчествовав"],
    "лжесвидетельствовав": ["лжесвидетельствовавши"],
    "лжесвидетельствовавши": ["лжесвидетельствовав"],
    "лжетеррор": ["лжетерроризм"],
    "лжетеррорист": ["псевдотеррорист"],
    "лжетолковав": ["лжетолковавши"],
    "лжетолковавши": ["лжетолковав"],
    "лжеурбанизация": ["ложная урбанизация"],
    "лжеученье": ["лжеучение"],
    "лжеучительствовав": ["лжеучительствовавши"],
    "лжеучительствовавши": ["лжеучительствовав"],
    "лжеучёный": ["псевдоучёный"],
    "лжец": ["лгун", "врун", "враль", "врунишка", "брехун", "обманщик", "вруша", "врушка"],
    "лжецерковь": ["псевдоцерковь"],
    "лживив": ["лжививши"],
    "лжививши": ["лживив"],
    "лживо": ["фальшиво", "ложно"],
    "лживость": ["враньё", "неправда"],
    "лживый": ["фальшивый", "обманчивый"],
    "ли": ["ри"],
    "лиаза": ["синтаза"],
    "лианный": ["лиановый"],
    "лиановый": ["лианный"],
    "либерализация": ["дерегуляция"],
    "либерализировав": ["либерализировавши"],
    "либерализировавши": ["либерализировав"],
    "либерализировать": ["либерализовать"],
    "либерализироваться": ["либерализоваться"],
    "либерализм": ["либерастия", "толерастия"],
    "либерализовав": ["либерализовавши"],
    "либерализовавши": ["либерализовав"],
    "либерализовать": ["либерализировать"],
    "либерализоваться": ["либерализироваться"],
    "либералистический": ["либеральный"],
    "либеральничав": ["либеральничавши"],
    "либеральничавши": ["либеральничав"],
    "либеральничанье": ["либеральничание"],
    "либеральный": ["снисходительный", "свободный", "прогрессивный"],
    "либераст": ["либерал", "толераст"],
    "либерастический": ["либеральный"],
    "либерастия": ["либерда"],
    "либераха": ["либераст", "толераст"],
    "либерда": ["либераст"],
    "либерия": ["республика либерия"],
    "либеро": ["защитник"],
    "либертарианство": ["либертаризм"],
    "либертаризм": ["либертарианство"],
    "либертен": ["либертин"],
    "либерти": ["ар-нуво", "югендстиль", "модерн"],
    "либертин": ["либертен", "вольноотпущенник"],
    "либертинаж": ["цинизм", "безбожие", "либертинизм"],
    "либертинизм": ["либертинаж"],
    "либидо": ["похоть"],
    "либо": ["или"],
    "либриум": ["хлордиазепоксид"],
    "лив": ["ливши"],
    "ливав": ["ливавши"],
    "ливавши": ["ливав"],
    "ливан": ["ливанская республика"],
    "ливанизировав": ["ливанизировавши"],
    "ливанизировавши": ["ливанизировав"],
    "ливанув": ["ливанувши"],
    "ливанувши": ["ливанув"],
    "ливануть": ["хлынуть", "налить"],
    "ливар": ["ливарник"],
    "ливенка": ["тальянка"],
    "ливень": ["проливной дождь", "наплыв"],
    "ливер": ["потрипка"],
    "ливерморий": ["унунгексий", "эка-полоний"],
    "ливерная колбаса": ["ливерка"],
    "ливиец": ["либу", "ребу"],
    "ливийка": ["либу", "ребу"],
    "ливия": ["джамахирия"],
    "ливнеприёмник": ["дождеприёмник"],
    "ливнеспуск": ["ливнеотвод"],
    "ливнуть": ["ливануть"],
    "ливши": ["лив"],
    "лига": ["союз", "объединение"],
    "лигавица": ["мукоза"],
    "лигаза": ["синтетаза"],
    "лигерад": ["рикамбент"],
    "лигировав": ["лигировавши"],
    "лигировавши": ["лигировав"],
    "лигнит": ["бурый уголь"],
    "лигнификация": ["одревеснение"],
    "лигроин": ["нафта"],
    "лигула": ["язычок"],
    "лид": ["анонс", "подводка", "введение", "вводка"],
    "лид-гитара": ["лидер-гитара"],
    "лид-гитарист": ["лидер-гитарист"],
    "лиддит": ["тринитрофенол", "пикриновая кислота", "мелинит"],
    "лидер": ["вожак", "глава", "предводитель", "руководитель", "суперэсминец"],
    "лидер-гитара": ["лид-гитара"],
    "лидер-гитарист": ["лид-гитарист"],
    "лидерство": ["превосходство", "отрыв", "приоритет"],
    "лидерствовав": ["лидерствовавши"],
    "лидерствовавши": ["лидерствовав"],
    "лидерствовать": ["лидировать", "первенствовать", "возглавлять", "доминировать"],
    "лидерша": ["командирша", "руководительница"],
    "лидировав": ["лидировавши"],
    "лидировавши": ["лидировав"],
    "лидировать": ["возглавлять", "опережать"],
    "лидирующий": ["ведущий", "первенствующий"],
    "лидия": ["меония", "мэония"],
    "лиемс": ["лийкстамс", "лиезь сувамс", "вишкста", "ардомс", "ласькомс"],
    "лиенальный": ["селезёночный"],
    "лиенит": ["спленит"],
    "лиепая": ["лепая", "либава"],
    "лижва": ["лижа"],
    "лижвар": ["лижник", "лижвяр"],
    "лиза": ["елизавета", "елисавета", "лизавета", "лизонька"],
    "лизав": ["лизавши"],
    "лизавета": ["елизавета", "елисавета", "лиза", "лизонька"],
    "лизавши": ["лизав"],
    "лизанув": ["лизанувши"],
    "лизанувши": ["лизанув"],
    "лизанье": ["лизание"],
    "лизать": ["касаться", "покрывать", "обдавать", "лобызать", "целовать"],
    "лизать жопу": ["подлизываться", "подобострастничать", "выслуживаться"],
    "лизать ноги": ["лизать руки", "лизать пятки"],
    "лизать пятки": ["лизать ноги", "лизать руки"],
    "лизать руки": ["лизать ноги", "лизать пятки"],
    "лизена": ["лопатка"],
    "лизинг": ["финансовая аренда"],
    "лизинговый": ["арендный", "кредитный", "прокатный"],
    "лизингополучатель": ["арендатор"],
    "лизировав": ["лизировавши"],
    "лизировавши": ["лизировав"],
    "лизнув": ["лизнувши"],
    "лизнувши": ["лизнув"],
    "лизоблюд": ["угодник", "прислужник", "льстец", "прихвостень", "подхалим", "жополиз", "блюдолиз", "лизоблюдник", "подлипала", "холуй", "шестерка"],
    "лизоблюдничав": ["лизоблюдничавши"],
    "лизоблюдничавши": ["лизоблюдничав"],
    "лизоблюдство": ["подхалимаж", "подхалимство"],
    "лизоцим": ["мурамидаза"],
    "лик": ["лицо", "икона", "образ", "сонм"],
    "ликабет": ["ликавит"],
    "ликавит": ["ликавиттос", "ликабет"],
    "ликантропия": ["клиническая ликантропия"],
    "ликбез": ["азы", "азбука", "младшая школа"],
    "ликвидация": ["закрытие", "расформирование", "прекращение", "упразднение", "устранение", "изъятие", "уничтожение", "ликвидирование"],
    "ликвидировавши": ["ликвидировав"],
    "ликвидирование": ["уничтожение"],
    "ликвидировать": ["уничтожать", "уничтожить", "распускать", "распустить", "убивать", "убить", "мочить", "замочить"],
    "ликвиднув": ["ликвиднувши"],
    "ликвиднувши": ["ликвиднув"],
    "ликвидный": ["оборачиваемый"],
    "ликворный": ["подпаутинный", "субарахноидальный"],
    "ликовав": ["ликовавши"],
    "ликовавши": ["ликовав"],
    "ликование": ["ликованье"],
    "ликованье": ["ликование"],
    "ликовать": ["торжествовать", "радоваться"],
    "ликорин": ["нарциссин", "галантизин"],
    "ликтрос": ["лик"],
    "ликтус": ["древогрыз"],
    "ликута": ["макута"],
    "ликёрчик": ["ликёр"],
    "лилейник": ["красоднев"],
    "лилейные": ["лилиевые"],
    "лилейный": ["белоснежный"],
    "лилея": ["лилия"],
    "лилиевидный": ["лилиеподобный"],
    "лилиопсиды": ["однодольные"],
    "лилипут": ["карлик", "нанист", "миниатюра", "вошь"],
    "лилия": ["лилея"],
    "лиловев": ["лиловевши"],
    "лиловевши": ["лиловев"],
    "лиловенький": ["фиолетовенький"],
    "лиловый": ["фиалковый", "фиолетовый", "сиреневый"],
    "лиман": ["порт-ильич", "красный лиман", "долбан"],
    "лимарний": ["лимарський"],
    "лимацид": ["моллюскоцид"],
    "лимбе": ["виктория"],
    "лимбическая система": ["лимбический комплекс", "висцеральный мозг", "ринэнцефалон", "тимэнцефалон"],
    "лимбургер": ["лимбургский сыр"],
    "лимбургский": ["лимбургский язык", "лимбуржский язык"],
    "лимитация": ["лимитирование"],
    "лимитировав": ["лимитировавши"],
    "лимитировавши": ["лимитировав"],
    "лимитированный": ["ограниченный"],
    "лимитировать": ["ограничивать", "ограничить"],
    "лимитотип": ["хронотип", "стратотип границы"],
    "лимитроф": ["граница", "приграничье", "фронтир"],
    "лимитчик": ["трудовой мигрант", "гастарбайтер", "понаехавший"],
    "лимитчица": ["приезжая", "гастарбайтерша"],
    "лимниграф": ["мареограф"],
    "лимнический": ["озёрный"],
    "лимнология": ["озероведение"],
    "лимонад": ["ситро"],
    "лимонив": ["лимонивши"],
    "лимонивши": ["лимонив"],
    "лимонний": ["лимоновий"],
    "лимонничав": ["лимонничавши"],
    "лимонничавши": ["лимонничав"],
    "лимонничать": ["миндальничать", "нежничать", "апельсинничать"],
    "лимонно-жёлтый": ["светло-жёлтый"],
    "лимоновец": ["национал-большевик", "нацбол"],
    "лимоновий": ["лимонний"],
    "лимпив": ["лимпивши"],
    "лимпивши": ["лимпив"],
    "лимфангиит": ["лимфангит", "лимфангоит", "ангиолейцит"],
    "лимфангит": ["лимфангиит", "лимфангоит", "ангиолейцит"],
    "лимфангоит": ["лимфангиит", "лимфангит", "ангиолейцит"],
    "лимфатический": ["лимфатичный"],
    "лимфатический узел": ["лимфоузел"],
    "лимфедема": ["лимфангиэктатический отёк"],
    "лимфогранулематоз": ["болезнь ходжкина", "лимфома ходжкина"],
    "лимфоз": ["лимфогранулематоз", "болезнь ходжкина", "лимфома ходжкина"],
    "лимфозный": ["лимфоидный"],
    "лимфоидный": ["лимфозный"],
    "лимфопоэз": ["лимфоцитопоэз", "лимфоцитообразование"],
    "лимфостаз": ["стаз лимфы", "серозный стаз"],
    "лимфоузел": ["лимфатический узел"],
    "лимфоцитопоэз": ["лимфопоэз", "лимфоцитообразование"],
    "линвовий": ["канатний", "кодоловий"],
    "лингала": ["нгала"],
    "лингафон": ["лингафонный кабинет"],
    "лингаята": ["вирашиваизм"],
    "лингвист": ["языковед", "полиглот"],
    "лингвистика": ["языковедение", "языкознание"],
    "лингвистический": ["языковедческий"],
    "лингвогеография": ["геолингвистика"],
    "лингвокреативный": ["словотворческий", "языкотворческий"],
    "лингвостилистика": ["лингвистическая стилистика"],
    "лингвофричив": ["лингвофричивши"],
    "лингвофричивши": ["лингвофричив"],
    "линеаризовав": ["линеаризовавши"],
    "линеаризовавши": ["линеаризовав"],
    "линеарный": ["линейный"],
    "линевав": ["линевавши"],
    "линевавши": ["линевав"],
    "линевальный": ["линовальный"],
    "линевание": ["линеванье", "линование"],
    "линеванье": ["линование", "линевание"],
    "линевать": ["линовать"],
    "линейное отображение": ["линейный оператор"],
    "линейный": ["линейчатый"],
    "линейный корабль": ["линкор"],
    "линейный объект": ["линия", "трасса"],
    "линеметатель": ["линемёт"],
    "линемёт": ["линеметатель"],
    "линер": ["рапидограф"],
    "линзообразный": ["линзовидный", "линзоподобный", "чечевицеобразный", "чечевицеподобный", "лентикулярный"],
    "линия": ["черта", "полоса", "ряд", "родословная линия", "торговый ряд", "фронт", "технологическая линия", "поточная линия"],
    "линия безопалубочного формования": ["лбф"],
    "линия боевого соприкосновения": ["лбс"],
    "линия связи": ["канал связи"],
    "линия формования": ["линия формовки"],
    "линия электропередачи": ["лэп"],
    "линк": ["гиперссылка"],
    "линкер": ["компоновщик"],
    "линковав": ["линковавши"],
    "линковавши": ["линковав"],
    "линкор": ["линейный корабль"],
    "линовав": ["линовавши"],
    "линовавши": ["линовав"],
    "линовальный": ["линевальный"],
    "линовальщик": ["линовщик"],
    "линованный": ["разлинованный", "графлёный", "в линейку"],
    "линовка": ["разлиновка", "линование"],
    "линовщик": ["линовальщик"],
    "линолевый": ["арахидоновый"],
    "линоленовый": ["арахидоновый"],
    "линолеумный": ["линолеумовый"],
    "линолеумовый": ["линолеумный"],
    "линт": ["корпия"],
    "линув": ["линувши"],
    "линувши": ["линув"],
    "линуксист": ["линуксоид"],
    "линуксоид": ["линуксист"],
    "линуя": ["линюя"],
    "линчевав": ["линчевавши"],
    "линчевавши": ["линчевав"],
    "линчевание": ["суд линча", "самосуд", "линчеванье"],
    "линчеватель": ["палач", "убийца"],
    "линька": ["экдизис", "линяние"],
    "линючий": ["выцветающий"],
    "линюя": ["линуя"],
    "линяв": ["линявши"],
    "линявши": ["линяв"],
    "линялый": ["полинявший", "полинялый", "выцветший", "вылинявший"],
    "линять": ["выцветать"],
    "линёк": ["линь"],
    "лиофилизировав": ["лиофилизировавши"],
    "лиофилизировавши": ["лиофилизировав"],
    "лиофилизировать": ["обезвоживать", "обезводить"],
    "лиоцелл": ["лиоцель"],
    "липа": ["олимпиада"],
    "липаза": ["стеапсин"],
    "липарис": ["морской слизень"],
    "липарит": ["риолит"],
    "липемания": ["депрессия", "меланхолия", "баритимия"],
    "липид": ["липоид"],
    "липиздричка": ["электричка"],
    "липкий": ["клейкий", "вязкий", "неотвязный", "навязчивый"],
    "липкость": ["клейкий"],
    "липнув": ["липнувши"],
    "липнувши": ["липнув"],
    "липоаспирация": ["липосакция"],
    "липоид": ["липид"],
    "липома": ["жировик", "липобластома"],
    "липопротеид": ["липопротеин"],
    "липопротеин": ["липопротеид"],
    "липофильность": ["олеофильность", "гидрофобность"],
    "липохром": ["жировой пигмент", "каротин", "каротиноид"],
    "липса": ["недостиг", "недостатъчност", "недоимък", "дефицит", "загуба", "празнина"],
    "липучесть": ["липкость", "прилипчивость"],
    "лиризм": ["лиричность"],
    "лирика": ["поэзия"],
    "лирически": ["лирично"],
    "лиричность": ["лиризм"],
    "лиричный": ["поэтичный", "задушевный"],
    "лиро-эпический": ["лироэпический"],
    "лировидный": ["лирообразный"],
    "лирообразный": ["лировидный", "лироподобный"],
    "лирохвост": ["птица-лира"],
    "лис": ["хитрец", "проныра"],
    "лиса": ["лисица", "хитрец", "проныра"],
    "лисавий": ["лисуватий"],
    "лисапед": ["лисапет", "велик"],
    "лисапет": ["лисапед"],
    "лисапетник": ["велосипедист"],
    "лисив": ["лисивши"],
    "лисивши": ["лисив"],
    "лисий": ["лисиный", "хитрый"],
    "лисиный": ["лисий", "хитрый", "лукавый", "льстивый"],
    "лисировав": ["лисировавши"],
    "лисировавши": ["лисировав"],
    "лисица": ["лиса", "лисичка"],
    "лисичий": ["лисий"],
    "лисищ": ["подлисок"],
    "лиска": ["лисонька"],
    "лиски": ["новая покровка", "свобода", "георгиу-деж"],
    "лискучий": ["блискучий"],
    "лисовав": ["лисовавши"],
    "лисовавши": ["лисовав"],
    "лисовин": ["лис"],
    "лисон": ["забон"],
    "лисонька": ["лисичка"],
    "лисохвост": ["алопекурус", "батлачик", "батлачок", "лисий хвост"],
    "лиссофобия": ["маниофобия"],
    "лист": ["листок", "документ", "бланк", "удостоверение", "формуляр"],
    "лист мёбиуса": ["лента мёбиуса", "петля мёбиуса"],
    "листав": ["листавши"],
    "листавши": ["листав"],
    "листануть": ["листнуть"],
    "листва": ["крона"],
    "лиственев": ["лиственевши"],
    "лиственевши": ["лиственев"],
    "лиственный лес": ["широколиственный лес"],
    "листвие": ["листва"],
    "листель": ["чембия"],
    "листнуть": ["листануть"],
    "листовав": ["листовавши"],
    "листовавши": ["листовав"],
    "листовать": ["листать", "перелистывать"],
    "листовка": ["прокламация", "брошюра"],
    "листогиб": ["листогибочный пресс"],
    "листогибочный пресс": ["листогиб"],
    "листогибочный станок": ["листогиб", "листогибочный пресс"],
    "листодуй": ["воздуходувка", "листодув", "садовый пылесос"],
    "листок": ["листик"],
    "листообразный": ["листовидный"],
    "листопад": ["листомыт", "ноябрь"],
    "листоподобный": ["листовидный"],
    "лисуватий": ["лисавий"],
    "литаврист": ["литаврщик"],
    "литаврный": ["литавровый"],
    "литавровый": ["литаврный"],
    "литаврщик": ["литаврист"],
    "литва": ["литовская республика"],
    "литвин": ["литовец"],
    "литвинизация": ["литуанизация"],
    "литвинка": ["литовка"],
    "литейно-кузнечный": ["кузнечно-литейный"],
    "литер": ["литера"],
    "литера": ["буква"],
    "литеральный": ["буквальный", "дословный", "точный"],
    "литератор": ["литтератор"],
    "литераторство": ["писательство"],
    "литераторствовав": ["литераторствовавши"],
    "литераторствовавши": ["литераторствовав"],
    "литература": ["сочинительство", "письмо", "писательство", "беллетристика", "текст", "библиография"],
    "литературный негр": ["литературный призрак", "призрак пера", "литраб", "безымянный", "автор", "двойник", "гострайтер"],
    "литературный призрак": ["литературный негр", "призрак пера", "литраб", "безымянный", "автор", "двойник"],
    "литературный язык": ["стандартный язык", "нормативный язык"],
    "литературовед": ["филолог"],
    "литературоведение": ["филология"],
    "литературоведенье": ["литературоведение"],
    "литературствовав": ["литературствовавши"],
    "литературствовавши": ["литературствовав"],
    "литературщик": ["бездарь"],
    "литеровав": ["литеровавши"],
    "литеровавши": ["литеровав"],
    "литий": ["литион"],
    "литион": ["литий"],
    "литифицировав": ["литифицировавши"],
    "литифицировавши": ["литифицировав"],
    "лития": ["заупокойная лития", "песнь"],
    "литка": ["слиток"],
    "литклуб": ["литературный клуб"],
    "литнегр": ["книггер", "литраб"],
    "литовав": ["литовавши"],
    "литовавши": ["литовав"],
    "литовец": ["литвин"],
    "литовка": ["литвинка"],
    "литовская республика": ["литва"],
    "литовская сср": ["литва"],
    "литовский": ["литовский язык"],
    "литовский язык": ["литовский"],
    "литогенез": ["литогенезис", "петрогенез"],
    "литогенезис": ["литогенез"],
    "литогоризонт": ["литостратиграфический горизонт"],
    "литограф": ["литографщик"],
    "литографировав": ["литографировавши"],
    "литографировавши": ["литографировав"],
    "литографически": ["литографированно"],
    "литографический": ["литографский"],
    "литозона": ["литостратиграфическая зона"],
    "литон": ["илитон"],
    "литораль": ["литоральная зона", "приливно-отливная зона"],
    "литоральный": ["прибрежный"],
    "литорея": ["тайнопись", "тарабарщина", "шифр"],
    "литория": ["квакша"],
    "литостратиграфический горизонт": ["литогоризонт"],
    "литосфера": ["сиаль"],
    "литосферный": ["сиалический"],
    "литота": ["литотес", "мейозис"],
    "литотамния": ["багрянка каменная"],
    "литотип": ["петротип"],
    "литофит": ["петрофит"],
    "литохромировав": ["литохромировавши"],
    "литохромировавши": ["литохромировав"],
    "литр": ["кубический дециметр"],
    "литраб": ["литературный негр", "книггер"],
    "литработник": ["литератор"],
    "литракон": ["стеклооптикобетон"],
    "литрбол": ["литробол", "литербол"],
    "литред": ["литературный редактор", "литредактор"],
    "литредактор": ["литред", "литературный редактор"],
    "литробол": ["литрбол", "литербол"],
    "литсотрудник": ["литературный сотрудник", "редактор"],
    "литтератор": ["литератор"],
    "литтература": ["литература"],
    "литтературный": ["литературный"],
    "литуанизация": ["литвинизация"],
    "литургийный": ["литургический"],
    "литургисав": ["литургисавши"],
    "литургисавши": ["литургисав"],
    "литургия": ["обедня"],
    "литфак": ["филфак"],
    "лить воду": ["переливать из пустого в порожнее", "врать с три короба"],
    "лить воду на мельницу": ["играть на руку"],
    "лить за щеку": ["заливать за воротник", "заливать за щеку"],
    "лить слёзы": ["плакать", "рыдать"],
    "литься": ["течь", "струиться", "распространяться", "разноситься", "плыть", "катиться", "проливаться", "проникать", "отливаться"],
    "лифак": ["лифон", "бюстгальтер"],
    "лифляндия": ["инфлянты", "ливония"],
    "лифон": ["лифак", "бюстгальтер"],
    "лифт": ["подъемник", "лифтинг", "лифтовка"],
    "лифтинг": ["лифт", "лифтовка"],
    "лифтовав": ["лифтовавши"],
    "лифтовавши": ["лифтовав"],
    "лифтовой": ["лифтовый"],
    "лифтовый": ["лифтовой", "лифтный"],
    "лифчик": ["бюстгальтер"],
    "лиха беда начало": ["лиха беда почин"],
    "лихачив": ["лихачивши"],
    "лихачивши": ["лихачив"],
    "лихачить": ["ухарствовать", "бесшабашничать"],
    "лихва": ["прибыль"],
    "лихварство": ["позика"],
    "лихенамилоидоз": ["амилоидный лихен"],
    "лихеноидный": ["лишаеобразный"],
    "лихим матом": ["неистово", "исступлённо", "истошно", "благим матом", "не благим матом", "божьим матом", "дурным матом", "недаровым матом", "непутным матом", "на лихой мат", "скоро", "мгновенно", "молниеносно", "поспешно", "махом"],
    "лихнис": ["зорька"],
    "лихо": ["зло"],
    "лиходей": ["злодей", "негодяй"],
    "лиходейка": ["злодейка", "бандитка", "мучительница", "разбойница"],
    "лиходейничать": ["лиходействовать", "злодействовать"],
    "лиходействовав": ["лиходействовавши"],
    "лиходействовавши": ["лиходействовав"],
    "лиходействовать": ["лиходейничать"],
    "лихоимец": ["ростовщик", "взяточник", "хапуга", "хапун", "мздоимец", "мшелоимец"],
    "лихоимство": ["лихоимание", "вымогательство", "рвачество", "хапужничество", "любостяжание", "жадность", "алчность"],
    "лихоимствовав": ["лихоимствовавши"],
    "лихоимствовавши": ["лихоимствовав"],
    "лихой": ["бравый", "удалой", "молодецкий", "смелый", "храбрый", "злой", "дурной", "нехороший", "недобрый"],
    "лихолетие": ["лихолетье"],
    "лихолетье": ["лихолетие"],
    "лихорадив": ["лихорадивши"],
    "лихорадивши": ["лихорадив"],
    "лихорадка": ["пирексия", "лихоманка", "трясавица", "малярия", "возбуждение", "волнение", "ажиотаж", "мания", "сумасшествие", "раж", "суд", "цапля"],
    "лихорадка эбола": ["геморрагическая лихорадка"],
    "лихтенштейн": ["княжество лихтенштейн"],
    "лицевав": ["лицевавши"],
    "лицевавши": ["лицевав"],
    "лицевать": ["перелицовывать"],
    "лицедей": ["актёр", "притворщик"],
    "лицедейство": ["спектакль", "представление", "притворство"],
    "лицедействовав": ["лицедействовавши"],
    "лицедействовавши": ["лицедействовав"],
    "лицезрев": ["лицезревши"],
    "лицезревши": ["лицезрев"],
    "лицезрение": ["созерцание"],
    "лицезренье": ["лицезрение"],
    "лицезреть": ["видеть", "зреть", "наблюдать"],
    "лицей": ["колледж"],
    "лицемер": ["двуличник", "лицемеришка"],
    "лицемерив": ["лицемеривши"],
    "лицемеривши": ["лицемерив"],
    "лицемерие": ["притворство", "лицемерье"],
    "лицемерить": ["лицемерствовать", "лицемерничать", "двоедушничать", "притворствовать"],
    "лицемерничав": ["лицемерничавши"],
    "лицемерничавши": ["лицемерничав"],
    "лицемерничать": ["лицемерить", "лицемерствовать"],
    "лицемерный": ["притворный", "неискренний", "двуличный"],
    "лицемерствовав": ["лицемерствовавши"],
    "лицемерствовавши": ["лицемерствовав"],
    "лицемерствовать": ["лицемерничать"],
    "лицемерье": ["лицемерие"],
    "лицензионный": ["лицензированный"],
    "лицензировав": ["лицензировавши"],
    "лицензировавши": ["лицензировав"],
    "лицензировать": ["авторизовать"],
    "лицензия": ["разрешение", "право"],
    "лицеочертание": ["черта", "лицо"],
    "лицеприятие": ["предвзятость", "пристрастность"],
    "лицеприятный": ["пристрастный", "предвзятый", "лицеприемный"],
    "лицеприятствовав": ["лицеприятствовавши"],
    "лицеприятствовавши": ["лицеприятствовав"],
    "лицом к лицу лица не увидать": ["большое видится на расстояньи"],
    "лицьовий": ["лицевий"],
    "лицятися": ["залицятися"],
    "лич": ["личер"],
    "личба": ["знамение", "предзнаменование", "предсказание", "предвещание"],
    "личер": ["лич"],
    "личи": ["лиджи", "лайси", "лиси"],
    "личив": ["личивши"],
    "личивши": ["личив"],
    "личико": ["лицо"],
    "личина": ["маска", "притворство", "личинка"],
    "личинка": ["спиногрыз", "жеребёнок"],
    "личинус": ["ребёнок"],
    "личить": ["приличествовать", "надлежать", "подходить", "идти"],
    "личка": ["приват", "лс"],
    "личная жизнь": ["частная жизнь", "личный фронт"],
    "лично": ["персонально", "индивидуально"],
    "личность": ["лицо", "индивидуальность"],
    "личный": ["персональный", "частный", "собственный", "интимный"],
    "личный фронт": ["личная жизнь", "послужной список"],
    "лишав": ["лишавши"],
    "лишавши": ["лишав"],
    "лишай": ["лихен", "лишайник"],
    "лишайник": ["лишай"],
    "лишать": ["отнимать", "отбирать", "изымать"],
    "лишаться": ["терять", "утрачивать"],
    "лишек": ["излишек", "избыток"],
    "лишение": ["отъём", "отнятие", "изъятие"],
    "лишенье": ["лишение"],
    "лишенько": ["лишечко"],
    "лишив": ["лишивши"],
    "лишивши": ["лишив"],
    "лишительный": ["изъятельный", "абессив"],
    "лишительный падеж": ["абессив"],
    "лишить": ["отобрать", "отнять"],
    "лишиться": ["потерять", "утратить"],
    "лишме": ["алаша"],
    "лишний": ["ненужный", "избыточный", "чрезмерный", "добавочный", "дополнительный", "очередной", "нежелательный"],
    "лишённик": ["бесправник"],
    "лишённый": ["отобранный", "отнятый"],
    "лия масторс": ["омба масторс"],
    "лия масторса": ["омба масторса"],
    "лия пингть": ["оду"],
    "лкм": ["лакокрасочный материал", "левая кнопка мыши"],
    "ллъоннол": ["лъоннол", "лъонол"],
    "лоб": ["чело", "парень", "детина"],
    "лобан": ["лобастик", "кефаль-лобан"],
    "лобарь": ["лобан", "лобырь", "лобастик", "лобатик", "лобовик"],
    "лобастий": ["лобатий"],
    "лобастый": ["большелобый", "широколобый"],
    "лоббизм": ["лоббирование"],
    "лоббировав": ["лоббировавши"],
    "лоббировавши": ["лоббировав"],
    "лоббирование": ["лоббизм"],
    "лоббировать": ["продвигать"],
    "лобз": ["лобзик"],
    "лобзав": ["лобзавши"],
    "лобзавши": ["лобзав"],
    "лобзание": ["целование", "лобызание", "лобзанье", "поцелуй", "безе"],
    "лобзать": ["целовать", "лобызать"],
    "лобзаться": ["лобызаться"],
    "лобковая вошь": ["площица", "вошь лобковая", "мандавошка"],
    "лобково-копчиковая мышца": ["лкм", "мышца хьюстона"],
    "лобное место": ["эшафот"],
    "лобо": ["редька"],
    "лобовик": ["лобовое стекло"],
    "лобовое стекло": ["ветровое стекло", "лобовик", "лобовуха"],
    "лобовой": ["передний", "фронтальный"],
    "лобовуха": ["ветровое стекло", "лобовое стекло", "лобовик"],
    "лобок": ["лобковое возвышение", "лонный холм", "венерин бугорок", "лунный холмик", "лохматка", "мохнушка"],
    "лоботрясничав": ["лоботрясничавши"],
    "лоботрясничавши": ["лоботрясничав"],
    "лобстер": ["омар"],
    "лобулярия приморская": ["лобулярия морская", "газонница приморская"],
    "лобур": ["лобуряка", "бешкетник"],
    "лобуряка": ["лобур"],
    "лобызав": ["лобызавши"],
    "лобызавши": ["лобызав"],
    "лобызание": ["лобзание", "целование", "поцелуй"],
    "лобызанье": ["лобызание"],
    "лобызать": ["лобзать", "целовать"],
    "лобызаться": ["лобзаться"],
    "лобь": ["лов"],
    "лов": ["ловля", "охота", "улов"],
    "ловатя": ["ловбаба", "ловаля"],
    "ловелас": ["бабник", "волокита", "повеса", "казанова"],
    "ловеласничав": ["ловеласничавши"],
    "ловеласничавши": ["ловеласничав"],
    "ловеласнический": ["донжуанский"],
    "ловеласничество": ["волокитство", "донжуанство"],
    "ловец": ["охотник"],
    "ловив": ["ловивши"],
    "ловивши": ["ловив"],
    "ловитва": ["ловля", "лов"],
    "ловить": ["хватать", "улавливать", "имать", "охотиться"],
    "ловить рыбу в мутной воде": ["ловить рыбку в мутной воде", "ловить в мутной воде рыбу", "рыбу в мутной воде ловить", "рыбку в мутной воде ловить"],
    "ловкачествовав": ["ловкачествовавши"],
    "ловкачествовавши": ["ловкачествовав"],
    "ловкачествовать": ["ловчить"],
    "ловкий": ["хваткий", "проворный", "хитроумный", "изощрённый"],
    "ловко": ["проворно", "искусно", "удобно"],
    "ловкость": ["проворность", "сноровка", "умелость"],
    "ловля": ["охота"],
    "ловушка": ["западня"],
    "ловчив": ["ловчивши"],
    "ловчивши": ["ловчив"],
    "ловчила": ["махинатор", "трюкач"],
    "ловчить": ["ловкачествовать", "хитрить"],
    "лог": ["балка", "логовина", "ложбина", "лощина", "распадок", "падь", "суходол", "буерак", "яр", "яруга", "изложина", "дол", "юдоль", "ложок"],
    "логарифмика": ["логарифмическая кривая"],
    "логарифмировав": ["логарифмировавши"],
    "логарифмировавши": ["логарифмировав"],
    "логгер": ["дрифтер"],
    "логизировав": ["логизировавши"],
    "логизировавши": ["логизировав"],
    "логика": ["разумность", "логичность"],
    "логин": ["никнейм", "ник", "вход", "регистрация", "аутентификация"],
    "логиниться": ["регаться"],
    "логировав": ["логировавши"],
    "логировавши": ["логировав"],
    "логист": ["логистик", "логицист"],
    "логистик": ["логист"],
    "логистика": ["матлогика"],
    "логичный": ["последовательный", "разумный", "закономерный"],
    "логово": ["логовище", "нора", "гайно", "гнездо", "кубло", "вертеп", "прибежище", "притон", "схрон", "убежище", "малина", "берлога"],
    "логограмма": ["логограф"],
    "логограф": ["логограмма"],
    "логозня": ["безграмотный", "дурак"],
    "логокомплекс": ["логопарк", "логоцентр"],
    "логомахия": ["словопрение"],
    "логопарк": ["логокомплекс", "логоцентр"],
    "логотип": ["лого", "эмблема", "лигатура"],
    "логофобия": ["глоссофобия"],
    "логоцентр": ["логокомплекс", "логопарк"],
    "логоцентрический": ["логоцентричный"],
    "логоцентричный": ["логоцентрический"],
    "лодарничав": ["лодарничавши"],
    "лодарничавши": ["лодарничав"],
    "лодарничать": ["лодырничать", "лениться", "бездельничать", "бить баклуши", "тунеядствовать"],
    "лодиллар": ["диллар"],
    "лодочка": ["лодка"],
    "лодыга": ["щиколотка", "лодыжка"],
    "лодыжка": ["щиколотка", "щиколка"],
    "лодырничав": ["лодырничавши"],
    "лодырничавши": ["лодырничав"],
    "лодырничание": ["лентяйничание"],
    "лодырничать": ["бездельничать", "лентяйничать"],
    "лодырь": ["бездельник", "лентяй", "разгильдяй", "тунеядец"],
    "ложащий": ["кладущий"],
    "ложе": ["постель", "русло", "ложа"],
    "ложемент": ["пилот-ложемент"],
    "ложесна": ["утроба"],
    "ложечник": ["ложкарь"],
    "ложив": ["ложивши"],
    "ложивши": ["ложив"],
    "ложивший": ["клавший"],
    "ложить": ["класть", "укладывать", "лагать"],
    "ложиться": ["укладываться"],
    "ложка дёгтя в бочке мёда": ["ложка дёгтя портит бочку мёда"],
    "ложкарив": ["ложкаривши"],
    "ложкаривши": ["ложкарив"],
    "ложкарь": ["ложечник"],
    "ложная луна": ["параселена"],
    "ложник": ["ружейник"],
    "ложница": ["спальня", "спальная комната", "опочивальня"],
    "ложно": ["неправильно", "неверно", "по ошибке", "искажённо", "шиворот-навыворот", "мнимо", "притворно", "несправедливо", "искаженно", "фиктивно", "ошибочно", "неточно", "превратно", "облыжно"],
    "ложно-": ["квази-", "лже-", "псевдо-"],
    "ложноножка": ["псевдоподия"],
    "ложность": ["ошибочность"],
    "ложный": ["лживый", "неверный"],
    "ложный друг": ["ложный друг переводчика"],
    "ложь": ["пиздёж"],
    "лоза": ["розга", "хворостина"],
    "лозина": ["лоза", "ива"],
    "лозный": ["лозовый"],
    "лозовий": ["лозяний"],
    "лозовый": ["лозный"],
    "лозоискательство": ["лозоходство", "биолокация"],
    "лозоплетение": ["лозоплетенье"],
    "лозоплетенье": ["лозоплетение"],
    "лозунг": ["пароль", "пропуск", "девиз"],
    "лозунговый": ["слогановый"],
    "лойс": ["лайк"],
    "локав": ["локавши"],
    "локавши": ["локав"],
    "локализационизм": ["анатомолокализационизм"],
    "локализация": ["поиск", "местоположение", "сосредоточение"],
    "локализировав": ["локализировавши"],
    "локализировавши": ["локализировав"],
    "локализированный": ["локализованный"],
    "локализировать": ["локализовать"],
    "локализм": ["провинциализм", "диалектизм"],
    "локализовав": ["локализовавши"],
    "локализовавши": ["локализовав"],
    "локализовать": ["локализировать", "позиционировать"],
    "локализовывав": ["локализовывавши"],
    "локализовывавши": ["локализовывав"],
    "локальная вычислительная сеть": ["лвс"],
    "локальность": ["местность"],
    "локальный": ["местный", "частный", "внутренний"],
    "локатив": ["местный падеж", "второй предложный падеж"],
    "локатор": ["пеленгатор"],
    "локаутировав": ["локаутировавши"],
    "локаутировавши": ["локаутировав"],
    "локация": ["место", "местность"],
    "локаята": ["чарвака", "локаятика"],
    "локва": ["мушмула японская"],
    "локер": ["щиток заднего крыла", "подкрылок"],
    "локи": ["лофт", "лодур", "хведрунг"],
    "локомобиль": ["автомобиль", "паровой", "повозка"],
    "локомоторный": ["двигательный"],
    "локон": ["кудряшка"],
    "локотник": ["подлокотник"],
    "локоть": ["локтевой сустав", "предплечье", "локтевая кость"],
    "локриця": ["солодка", "солодець"],
    "локсодрома": ["локсодромия"],
    "локсодромия": ["локсодрома"],
    "локсодромный": ["локсодромический"],
    "локутив": ["локуция"],
    "локуция": ["речение", "локутив"],
    "локчим": ["локшма", "лочким", "лэкчим"],
    "лол": ["смех", "лулз", "смешной", "забавный", "прикольный", "ха-ха-ха", "ха-ха", "хи-хи-хи", "хи-хи", "гы-гы", "бугага", "смешно", "ржу", "рофл"],
    "лоли": ["лолита", "лоля"],
    "лоликон": ["желание", "похоть", "лоликонщик", "педофил"],
    "лоликонщик": ["педофил"],
    "лоло дывэс": ["свэнко"],
    "ломав": ["ломавши"],
    "ломавши": ["ломав"],
    "ломака": ["жеманница", "кривляка"],
    "ломакон": ["бемакон", "бехонумон"],
    "ломаная": ["ломаная линия"],
    "ломание": ["ломка", "кривляние"],
    "ломаность": ["изломанность"],
    "ломанув": ["ломанувши"],
    "ломанувши": ["ломанув"],
    "ломануть": ["вмазать", "хрястнуть", "сломать", "двинуть", "рвануть", "отправиться"],
    "ломануться": ["ринуться", "ломануть", "рвануться", "щемануться"],
    "ломать": ["разрушать", "уничтожать", "портить"],
    "ломать дурака": ["ломать комедию", "паясничать", "выделываться"],
    "ломать комедию": ["разыгрывать комедию"],
    "ломать копья": ["приломить копья", "изломить копья"],
    "ломать целку": ["целку ломать"],
    "ломать щеку": ["ломать щёку", "ломить щеку", "ломить щёку"],
    "ломать щёку": ["ломать щеку", "ломить щеку", "ломить щёку"],
    "ломаться": ["разрушаться", "приходить в негодность", "портиться", "останавливаться", "кривляться", "выделываться", "выламываться", "жеманничать", "важничать", "чиниться", "упрямиться", "отнекиваться", "кокетничать"],
    "ломберный стол": ["зелёный стол"],
    "ломив": ["ломивши"],
    "ломивши": ["ломив"],
    "ломить щеку": ["ломать щеку", "ломать щёку", "ломить щёку"],
    "ломить щёку": ["ломать щеку", "ломать щёку", "ломить щеку"],
    "ломиться": ["сгибаться", "изобиловать", "полниться", "вламываться", "валить валом"],
    "ломка": ["ломание"],
    "ломкий": ["хрупкий"],
    "ломовая лошадь": ["тяжеловоз", "ломовик", "работяга", "трудяга"],
    "ломонос": ["бородавник", "жигунец", "клематис"],
    "ломоть": ["шмат"],
    "ломтерезка": ["слайсер"],
    "лон-лакей": ["лонлакей"],
    "лона": ["ошьёна", "хона"],
    "лонг-ковид": ["длинный ковид", "постковид", "постковидный синдром"],
    "лонгет": ["лонгета", "лонгетка"],
    "лондон": ["город дождей", "город на темзе"],
    "лондончанин": ["лондонец"],
    "лонлакей": ["лон-лакей"],
    "лопав": ["лопавши"],
    "лопавши": ["лопав"],
    "лопань": ["казачья лопань"],
    "лопасть": ["лопатка", "лезвие"],
    "лопатень": ["кулик-лопатень"],
    "лопати": ["лопатися"],
    "лопатив": ["лопативши"],
    "лопативши": ["лопатив"],
    "лопатник": ["лопаточник", "землекоп"],
    "лопатофон": ["лопата"],
    "лопать": ["поедать"],
    "лопнув": ["лопнувши"],
    "лопнувши": ["лопнув"],
    "лопнутый гондон": ["дырявый гондон"],
    "лопнуть": ["разорваться"],
    "лопотав": ["лопотавши"],
    "лопотавши": ["лопотав"],
    "лопотать": ["лепетать", "щебетать", "болтать"],
    "лопотуха": ["говорун", "говорунья", "лопотунья", "лопотун", "бормотун", "бормотунья"],
    "лопоухий": ["ушастый", "недотёпистый"],
    "лопух": ["дедки", "дедовник", "лопушник", "репей", "репейник"],
    "лопуховий": ["лопушаний"],
    "лопушаний": ["лопуховий"],
    "лопушив": ["лопушивши"],
    "лопушивши": ["лопушив"],
    "лопушник": ["лопух", "мать-и-мачеха"],
    "лор": ["оториноларинголог", "ларингооторинолог", "ухогорлонос"],
    "лорд-лейтенант": ["лорд-наместник"],
    "лорд-наместник": ["лорд-лейтенант"],
    "лоренценит": ["рамзаит"],
    "лорнировав": ["лорнировавши"],
    "лорнировавши": ["лорнировав"],
    "лос-анджелес": ["город ангелов"],
    "лосий": ["лосиный"],
    "лосинный": ["лосиновый"],
    "лосиновый": ["лосинный"],
    "лосины": ["легинсы"],
    "лоск": ["блеск", "глянец"],
    "лоскотний": ["лоскотливий"],
    "лоскут": ["ветошь", "клок", "обрывок", "отрез", "суконка", "тряпка"],
    "лоскутник": ["тряпичник", "оборванец"],
    "лосниться": ["блестеть", "отсвечивать", "маслиться"],
    "лосняк": ["липарис"],
    "лоснящийся": ["лоснистый", "маслянистый", "маслящийся", "сальный", "блестящий", "блещущий", "глянцевитый", "лакированный", "отсвечивающий"],
    "лососевий": ["лососячий"],
    "лососий": ["лососевый", "лососёвый", "лососиный", "лососинный"],
    "лосось": ["лососина"],
    "лось": ["олень", "сохатый", "сохач", "рогач", "лесной великан", "медведь", "увалень"],
    "лосятина": ["лосина"],
    "лосячий": ["лосиный"],
    "лосёвый": ["лосиный"],
    "лот": ["лут"],
    "лотерейный": ["лохотронный"],
    "лотерея": ["лотт", "лотори", "лотерия", "лотария"],
    "лоткамс": ["лоткафтомс", "прядовомс", "аделавомс", "сетьмомс", "ацендемс"],
    "лотковый": ["лоточный"],
    "лотнай ал питнец": ["аф эрявикс", "кальдяв"],
    "лотос": ["кувшинка"],
    "лотошив": ["лотошивши"],
    "лотошивши": ["лотошив"],
    "лотошить": ["лопотать", "трепаться", "лотошиться"],
    "лоукостер": ["авиадискаунтер", "низкобюджетный", "бюджетный", "авиаперевозчик"],
    "лофт": ["локи"],
    "лох": ["джигда", "джида", "джидда", "пшат", "лоховина", "дикая маслина", "маслёнка"],
    "лох узколистный": ["джигда"],
    "лоханка": ["лохань"],
    "лоханск": ["луганск"],
    "лохануться": ["просчитаться", "прогадать", "дать маху", "лажануться", "опростоволоситься"],
    "лохань": ["лоханка"],
    "лохма": ["клок", "косма"],
    "лохматив": ["лохмативши"],
    "лохмативши": ["лохматив"],
    "лохматить": ["ерошить"],
    "лохматый": ["косматый", "кудлатый"],
    "лохмач": ["лохматушка", "лохматушечка"],
    "лохмотник": ["оборванец"],
    "лохмотья": ["рубище"],
    "лохмы": ["космы", "клочья"],
    "лоховина": ["лох"],
    "лохокост": ["холокост"],
    "лохос": ["лох"],
    "лохотрон": ["обман", "обиралово", "обманка", "быдлотрон", "разводилово", "наебалово", "наёбка"],
    "лохуша": ["простофиля"],
    "лохушка": ["лохуша", "простофиля", "лохундра"],
    "лоцировав": ["лоцировавши"],
    "лоцировавши": ["лоцировав"],
    "лочив": ["лочивши"],
    "лочивши": ["лочив"],
    "лочить": ["залочивать"],
    "лошадеподобный": ["конеподобный"],
    "лошадка": ["троян", "троянец", "трой"],
    "лошадь": ["коняшка", "кляча", "кобыла"],
    "лошадёнка": ["лошадёшка"],
    "лошажий": ["лошадиный"],
    "лошак": ["катер", "мул"],
    "лошара": ["лох"],
    "лошарик": ["лошок", "лох", "олух"],
    "лошив": ["лошивши"],
    "лошивши": ["лошив"],
    "лошок": ["лошарик"],
    "лощение": ["полирование", "глянцевание", "полировка"],
    "лощив": ["лощивши"],
    "лощивши": ["лощив"],
    "лощина": ["долина", "лог"],
    "лощить": ["натирать", "полировать", "глянцевать"],
    "лощёный": ["вылощенный"],
    "лоялист": ["верноподданный", "тори"],
    "лояльность": ["верность", "преданность", "благонадёжность"],
    "лояльный": ["верный", "преданный", "благонадежный", "благонамеренный", "верноподданный", "законопослушный", "терпимый", "безоценочный", "толерантный", "снисходительный", "не осуждающий", "благожелательный", "благомысленный", "благомыслящий"],
    "лпнп": ["лнп"],
    "лс": ["личный состав", "логистическая система", "личные сообщения", "личка"],
    "лсд": ["кислота"],
    "лстк": ["лёгкие стальные тонкостенные конструкции"],
    "луб": ["лубок", "флоэма", "подкорье", "исподняя кора", "лыко"],
    "лубенев": ["лубеневши"],
    "лубеневши": ["лубенев"],
    "лубенив": ["лубенивши"],
    "лубенивши": ["лубенив"],
    "лубок": ["луб", "подкорье"],
    "лубочность": ["примитивность", "безвкусность", "некрасивость", "грубоватость", "вульгарность"],
    "лубочный": ["лубовой", "лубковый", "лубяной"],
    "лубрикант": ["смазка"],
    "лубянка": ["лубянская площадь"],
    "лубяной": ["лыковый"],
    "лубянский": ["гебистский", "кгбешный", "чекистский", "фсбешный"],
    "лувомс": ["лувомс эрявикс", "примамс", "морафтомс"],
    "луг": ["поле"],
    "луганда": ["ганда"],
    "лугандон": ["лугандония"],
    "лугандония": ["лугандон"],
    "луганск": ["луганский завод", "ворошиловград", "лоханск"],
    "луганская народная республика": ["лнр", "луганщина", "луганда", "лугандон", "лугандония"],
    "луганская область": ["луганщина"],
    "луганский слесарь": ["первый красный офицер"],
    "луганско-донецкий": ["донецко-луганский"],
    "луганско-российский": ["российско-луганский"],
    "луганщина": ["луганская область", "луганская народная республика"],
    "луговик": ["щучка", "опёнок луговой", "негниючник луговой"],
    "луговина": ["лужок"],
    "лугорез": ["дернорез"],
    "лудив": ["лудивши"],
    "лудивши": ["лудив"],
    "лудоман": ["игроман", "лудик"],
    "лудомания": ["игромания"],
    "лудост": ["умопомрачение", "безразсъдство", "неблагоразумие", "безумие", "глупост"],
    "лужа": ["лужица"],
    "лужаечка": ["лужайка"],
    "лужайка": ["лужок"],
    "лужение": ["луженье"],
    "лужина": ["лужища"],
    "лужицкий": ["серболужицкий", "вендский", "сорбийский"],
    "лужицкий язык": ["серболужицкий язык", "сорбский язык"],
    "лужичанин": ["лужицкий серб", "сорб"],
    "лужичанка": ["сорбка"],
    "лужища": ["лужина"],
    "лужочек": ["лужок"],
    "лужёная глотка": ["горлодёр", "крикун", "горлопан"],
    "луз": ["шакед"],
    "лузг": ["глузг", "лузга"],
    "лузга": ["глузг", "лузг"],
    "лузгав": ["лузгавши"],
    "лузгавши": ["лузгав"],
    "лузгать": ["грызть", "лущить", "щёлкать"],
    "лузер": ["неудачник"],
    "лузерша": ["неудачница"],
    "луидор": ["луи"],
    "луис": ["луиш"],
    "луиш": ["луис"],
    "лук": ["репчатый лук", "луковица", "зелёный лук", "птичий лук", "гейджия", "ургинея приморская"],
    "лук-порей": ["порей", "жемчужный лук"],
    "лука": ["изгиб", "поворот"],
    "лукав": ["лукавши"],
    "лукавив": ["лукавивши"],
    "лукавивши": ["лукавив"],
    "лукавить": ["хитрить"],
    "лукавство": ["неискренность"],
    "лукавствовав": ["лукавствовавши"],
    "лукавствовавши": ["лукавствовав"],
    "лукавши": ["лукав"],
    "лукавый": ["лживый", "обманный", "двоедушный", "лицемерный", "двуличный", "хитренький", "хитроватый", "хитроумный", "хитрый", "плутоватый", "себе на уме"],
    "лукать": ["метать", "бросать"],
    "лукерья": ["гликерия"],
    "лукно": ["изымалка", "имало", "ималка"],
    "лукнув": ["лукнувши"],
    "лукнувши": ["лукнув"],
    "луковица": ["лук"],
    "луковка": ["луковичка"],
    "лукоморье": ["залив", "бухта"],
    "лукошко": ["лукно", "корзина", "корзинка"],
    "лукративный": ["люкративный", "выгодный", "прибыльный"],
    "лукуллов пир": ["лукулловский пир"],
    "лукум": ["локум"],
    "лулз": ["прикол", "смехуёчек"],
    "луна": ["селена"],
    "луна-рыба": ["рыба-луна"],
    "лунати": ["звучати"],
    "лунатизм": ["ноктамбулизм", "сомнамбулизм", "снохождение"],
    "лунатик": ["сомнамбула", "сомнамбул", "неадекват"],
    "лунатический": ["сомнамбулический"],
    "лунатичность": ["сомнамбуличность"],
    "лунатичный": ["сомнамбуличный"],
    "лунда": ["балунда", "чилунда"],
    "лунник": ["лунария", "лунная трава", "месячная трава", "месячник", "месячная фиалка", "месячная рута"],
    "лунный": ["нелунный", "внелунный"],
    "лунный камень": ["адуляр"],
    "лунный холмик": ["лобок", "венерин бугорок"],
    "луноход": ["луномобиль"],
    "лунь": ["степной ястреб", "рябец", "мышелов", "мышатник", "мышеловка", "воробьятник", "белохвостик", "болотный коршун", "болотный ястреб"],
    "лупав": ["лупавши"],
    "лупавши": ["лупав"],
    "лупанув": ["лупанувши"],
    "лупанувши": ["лупанув"],
    "лупануть": ["ударить"],
    "лупасив": ["лупасивши"],
    "лупасивши": ["лупасив"],
    "лупасить": ["лупить", "колотить", "дубасить", "бутузить", "мутузить"],
    "лупив": ["лупивши"],
    "лупивши": ["лупив"],
    "лупить": ["облупливать", "облуплять", "обдирать", "лупцевать", "колотить", "колошматить"],
    "лупка": ["лупцевание", "лупцовка"],
    "лупливав": ["лупливавши"],
    "лупливавши": ["лупливав"],
    "лупоглазый": ["пучеглазый"],
    "лупулин": ["хмелевина"],
    "лупцевав": ["лупцевавши"],
    "лупцевавши": ["лупцевав"],
    "лупцовав": ["лупцовавши"],
    "лупцовавши": ["лупцовав"],
    "луркоёб": ["луркофаг"],
    "лус": ["дузд"],
    "лускав": ["лускавши"],
    "лускавши": ["лускав"],
    "лусон": ["лусония"],
    "лут": ["лот", "мёртвое море"],
    "лутать": ["обирать"],
    "лутер-шутер": ["лут-шутер"],
    "луток": ["малый крохаль"],
    "луффа": ["люффа"],
    "лухит": ["теллу", "краунаон", "дзаю-чу", "чаюйлэхэ"],
    "луцерия": ["лючера"],
    "луч": ["лучевая кость"],
    "лучевая терапия": ["радиотерапия"],
    "лучевидный": ["лучеобразный", "лучеподобный"],
    "лучевик": ["радиолярия"],
    "лучевой": ["лучевидный", "лучеобразный", "радиальный"],
    "лучезарно": ["ликующе", "лучисто", "радостно", "светло", "солнечно", "сверкающе"],
    "лучеиспускав": ["лучеиспускавши"],
    "лучеиспускавши": ["лучеиспускав"],
    "лученье": ["лучение"],
    "лучеобразно": ["радиально"],
    "лучив": ["лучивши"],
    "лучивши": ["лучив"],
    "лучина": ["щепка"],
    "лучистый": ["лучащийся", "радиационный", "лучевой", "лучевидный", "лучеобразный", "радиальный"],
    "лучний": ["луговий"],
    "лучний собачка": ["луговий собачка"],
    "лучше": ["класснее", "баще"],
    "лучший": ["наилучший", "оптимальный"],
    "лучший друг артиллеристов": ["друг артиллеристов", "лучший друг детей", "лучший друг заключённых", "лучший друг угнетённых народов", "лучший друг колхозников", "лучший друг писателей", "лучший друг чекистов", "лучший друг танкистов", "лучший друг горняков", "лучший друг шахтёров", "лучший друг физкультурников"],
    "лушник": ["огород"],
    "лушпайка": ["лушпина"],
    "лушпина": ["лушпайка"],
    "лущив": ["лущивши"],
    "лущивши": ["лущив"],
    "лущить": ["очищать", "лузгать"],
    "лхагва": ["буд"],
    "лъен": ["лълъени"],
    "лъженаука": ["псевдонаука"],
    "лъка": ["ливада", "пасбище", "пасище", "морава", "зеленина"],
    "лълъе": ["лълъен"],
    "лълъен": ["лълъе"],
    "лълъи": ["лълъин"],
    "лъоннол": ["ллъоннол", "лъонол"],
    "лъскавина": ["блясък", "блескавина", "бляскавост", "лъскавост"],
    "лъэгуаджэ": ["лъэгуанджэ"],
    "лъэгуанджэ": ["лъэгуаджэ"],
    "лыбиться": ["ухмыляться", "лыбу давить", "лыбу тянуть", "расплываться в улыбке"],
    "лыва": ["лужа"],
    "лыдка": ["лытка"],
    "лыжа": ["полоз"],
    "лыжи": ["катание на лыжах"],
    "лыжный балет": ["балет на лыжах"],
    "лыко": ["луб"],
    "лымыпог": ["снеговик"],
    "лыняв": ["лынявши"],
    "лынявши": ["лыняв"],
    "лысев": ["лысевши"],
    "лысевши": ["лысев"],
    "лысеть": ["плешиветь", "стираться"],
    "лысина": ["плешь"],
    "лысоголовый": ["лысый"],
    "лысто": ["глезно", "глезна", "голень"],
    "лысун": ["гренландский тюлень"],
    "лысый": ["плешивый", "облезлый", "безволосый", "голый", "оголённый"],
    "лытав": ["лытавши"],
    "лытавши": ["лытав"],
    "лытдыбр": ["дневник", "дневниковая запись", "дыбр"],
    "лытка": ["голень", "икра", "нога", "бедро", "ляжка"],
    "лычка": ["лычко"],
    "лычко": ["лычка"],
    "ль": ["ли"],
    "львиная доля": ["большая часть", "львиная часть"],
    "львиный зев": ["львиная пасть", "львиный ротик"],
    "львов": ["лемберг"],
    "львовская область": ["львовщина"],
    "льгота": ["привилегия"],
    "льготировав": ["льготировавши"],
    "льготировавши": ["льготировав"],
    "льдогенератор": ["ледогенератор"],
    "льдолюбивый": ["пагофильный", "пагетодный"],
    "льдышка": ["ледышка"],
    "льзя": ["можно"],
    "льноводный": ["льноводческий"],
    "льноводческий": ["льноводный"],
    "льноводчество": ["льноводство"],
    "льноволокно": ["льняное волокно"],
    "льноволосый": ["белокурый", "светловолосый"],
    "льнув": ["льнувши"],
    "льнувши": ["льнув"],
    "льняний": ["лляний"],
    "льодяник": ["леденець"],
    "льстец": ["низкопоклонник", "подлиза", "прихвостень"],
    "льстив": ["льстивши"],
    "льстиво": ["вкрадчиво"],
    "льстивши": ["льстив"],
    "льюсальвхейм": ["альвхейм"],
    "льёт как из ведра": ["ливмя лить"],
    "лэ": ["ле"],
    "лэвэрэ": ["хой", "дэт", "булэ", "няру", "дэвгэ", "кута"],
    "лэнгли": ["лангли", "ленгли"],
    "лэндинг": ["посадочная страница", "целевая страница"],
    "лэп": ["линия электропередачи"],
    "лэптоп": ["наколенник"],
    "любвеобилие": ["любвеобильность"],
    "любвеобильность": ["любвеобилие"],
    "любезничав": ["любезничавши"],
    "любезничавши": ["любезничав"],
    "любезничанье": ["любезничание"],
    "любезно": ["вежливо", "учтиво", "галантно"],
    "любезность": ["обходительность", "учтивость"],
    "любеница": ["диня"],
    "любер": ["клетчатый"],
    "любив": ["любивши"],
    "любивши": ["любив"],
    "любимейший": ["излюбленный"],
    "любимец судьбы": ["счастливец", "везунчик", "баловень судьбы", "избранник судьбы"],
    "любимец фортуны": ["баловень судьбы", "любимец судьбы", "избранник судьбы"],
    "любимчик": ["фаворит"],
    "любимый": ["предпочтительный", "излюбленный", "возлюбленный"],
    "любимый человек": ["сексуальный партнёр"],
    "любитель": ["охотник", "дилетант"],
    "любительство": ["дилетантство", "любительщина"],
    "любительщина": ["дилетантство", "любительство"],
    "любитны": ["радейтны", "мусавны"],
    "любить": ["обожать"],
    "любливав": ["любливавши"],
    "любливавши": ["любливав"],
    "любляна": ["лайбах"],
    "любо": ["приятно", "мило"],
    "любо-дорого": ["приятно"],
    "любов з першого погляду": ["кохання з першого погляду"],
    "любовав": ["любовавши"],
    "любовавши": ["любовав"],
    "любовать": ["облюбовывать"],
    "любоваться": ["восхищаться", "заглядеться"],
    "любовница": ["гёрлфренд", "зазноба", "пассия", "хахальница", "возлюбленная", "возлюбленница"],
    "любовничек": ["любовник"],
    "любовный": ["амурный", "любящий", "влюблённый", "заботливый", "внимательный"],
    "любовь": ["любы"],
    "любодеица": ["блудница", "прелюбодейка"],
    "любодей": ["сладострастник", "сластолюбец", "срамник", "греховодник", "бесстыдник", "блудник"],
    "любодейка": ["прелюбодейка", "развратница", "распутница"],
    "любодейство": ["прелюбодейство", "прелюбодеяние"],
    "любодеяние": ["блуд", "прелюбодейство", "прелюбодеяние"],
    "любодеянье": ["любодеяние"],
    "любознание": ["любознательность"],
    "любознательность": ["пытливость", "любопытство"],
    "любознательный": ["пытливый", "любопытный"],
    "любой": ["всякий", "каждый", "кто угодно"],
    "любой ценой": ["во что бы то ни стало", "кровь из носу"],
    "любомолчание": ["молчаливость", "малословие", "безмолвие", "малоговорение"],
    "любомудр": ["философ", "мыслитель"],
    "любомудрие": ["философия"],
    "любомудрый": ["сведущий", "философский"],
    "любоначалие": ["властолюбие"],
    "любопренье": ["любопрение"],
    "любопрительный": ["сварливый", "спорливый"],
    "любопытнейший": ["занятнейший", "увлекательнейший", "занимательнейший", "интереснейший"],
    "любопытничав": ["любопытничавши"],
    "любопытничавши": ["любопытничав"],
    "любопытничание": ["любопытничанье", "любопытствование"],
    "любопытничанье": ["любопытничание"],
    "любопытничать": ["любопытствовать"],
    "любопытство": ["интерес"],
    "любопытствовав": ["любопытствовавши"],
    "любопытствовавши": ["любопытствовав"],
    "любострастие": ["сладострастие"],
    "любострастный": ["сладострастный", "похотливый"],
    "любострастье": ["любострастие"],
    "любостяжание": ["корыстолюбие", "алчность", "ненасытность"],
    "любочестие": ["честолюбие"],
    "любощедрый": ["полезный", "нужный", "щедролюбивый", "щедрый", "чивый", "тороватый"],
    "любый": ["дорогой", "милый", "любимый", "облюбовать"],
    "любэ": ["любой", "всякий", "разный"],
    "люггер": ["люгер"],
    "люгер": ["парабеллум"],
    "люд": ["люди", "толпа"],
    "люда": ["люся", "мила"],
    "людино-година": ["людиногодина"],
    "людиновбивець": ["людиновбивця"],
    "людиновбивця": ["людиновбивець"],
    "людмила": ["люда", "мила", "людочка", "милочка", "людка", "людок", "милка"],
    "люднев": ["людневши"],
    "людневши": ["люднев"],
    "людно": ["многолюдно"],
    "людоед": ["каннибал", "антропофаг", "изверг", "изувер", "садист", "кровопийца", "кровосос", "вурдалак", "тиран", "деспот", "сатрап"],
    "людоедский": ["каннибальский"],
    "людоедство": ["антропофагия", "зверство", "варварство", "жестокость"],
    "людоедствовав": ["людоедствовавши"],
    "людоедствовавши": ["людоедствовав"],
    "людожер": ["людожерець"],
    "людолов": ["тэцэкашник"],
    "люйда": ["далянь"],
    "люк": ["лаз"],
    "люковый": ["лючный"],
    "люкративный": ["лукративный", "выгодный", "прибыльный"],
    "люкс": ["лк"],
    "люксация": ["вывих"],
    "люксембург": ["великое герцогство люксембург"],
    "люксембургский": ["люксембуржский", "люксембургский язык"],
    "люксембурженка": ["люксембуржка"],
    "люксембуржка": ["люксембурженка"],
    "люксембуржский": ["люксембургский"],
    "люксметрия": ["фотометрия"],
    "люлей отхватить": ["отхватить люлей", "выхватить люлей", "огрести люлей", "люлей выхватить", "люлей огрести", "отхватить пиздюлей", "выхватить пиздюлей", "огрести пиздюлей", "пиздюлей отхватить", "пиздюлей выхватить", "пиздюлей огрести"],
    "люли": ["мугат"],
    "люлиберин": ["лютрелин", "гонадотропин-рилизинг-гормон", "гонадолиберин"],
    "люль": ["звездюль", "пендель", "пиздюль"],
    "люлька": ["колыбель", "трубка"],
    "люлюкав": ["люлюкавши"],
    "люлюкавши": ["люлюкав"],
    "люмбаго": ["прострел"],
    "люмбальная пункция": ["прокол квинке"],
    "люмбальный": ["поясничный"],
    "люмбосакральный": ["люмбо-сакральный"],
    "люмен": ["лм"],
    "люминал": ["фенобарбитал"],
    "люминесцировав": ["люминесцировавши"],
    "люминесцировавши": ["люминесцировав"],
    "люмпен-интеллигенция": ["образованщина"],
    "люмпенизация": ["деклассирование"],
    "люмпенизировав": ["люмпенизировавши"],
    "люмпенизировавши": ["люмпенизировав"],
    "люмпенствовав": ["люмпенствовавши"],
    "люмпенствовавши": ["люмпенствовав"],
    "люнет": ["люнетта"],
    "люнетта": ["люнет"],
    "люпилня": ["инкубатор", "развъдник"],
    "люпин": ["волчий боб"],
    "люпус": ["волчанка"],
    "люпштамс": ["тапамс", "матрамс", "таргамс люпштазь", "лоткафтомс", "машфтомс"],
    "люстерко": ["дзеркальце"],
    "люстрация": ["перлюстрация"],
    "люстрировав": ["люстрировавши"],
    "люстрировавши": ["люстрировав"],
    "люська": ["люся"],
    "люся": ["люда", "мила"],
    "лютев": ["лютевши"],
    "лютевши": ["лютев"],
    "лютейший": ["злейший"],
    "лютеотропин": ["лютропин"],
    "лютеция": ["паризий"],
    "лютий": ["злий"],
    "лютовав": ["лютовавши"],
    "лютовавши": ["лютовав"],
    "лютовать": ["зверствовать", "злобствовать", "свирепствовать", "буйствовать", "неистовствовать"],
    "лютость": ["свирепость"],
    "лютропин": ["лютеотропин"],
    "лють": ["злоба", "ненависть", "жестокость", "лютость", "свирепость", "безжалостность", "беспощадность", "нещадность", "кровожадность", "свирепство", "мороз", "стужа", "холод"],
    "лютье": ["скрипичный мастер"],
    "люфа": ["люффа"],
    "люфт": ["зазор", "свободный ход", "разболтанность", "расшатанность", "расхлябанность"],
    "люффа": ["люфа", "луффа"],
    "люцит": ["плексиглас"],
    "люцифер": ["сатана", "демон", "азазель", "мефистофель", "самаэль", "чёрт", "денница", "дьявол", "венера"],
    "лючный": ["люковый"],
    "люэс": ["сифилис"],
    "люэтический": ["сифилитический"],
    "ля": ["соль дубль-диез", "си дубль-бемоль"],
    "ля-бемоль": ["соль-диез"],
    "ля-диез": ["си-бемоль"],
    "ля-ля": ["трёп", "трепотня"],
    "ля-минорный": ["а-мольный"],
    "лягав": ["лягавши"],
    "лягавив": ["лягавивши"],
    "лягавивши": ["лягавив"],
    "лягавши": ["лягав"],
    "лягавый": ["легавый"],
    "ляганье": ["лягание"],
    "лягнув": ["лягнувши"],
    "лягнувши": ["лягнув"],
    "лягуха": ["лягушка"],
    "лягушачий": ["лягушечий"],
    "лягушечий": ["лягушачий", "лягушиный"],
    "лягушиный": ["лягушачий", "лягушечий"],
    "лягушка": ["квакушка", "лягва"],
    "ляд": ["леший", "чёрт", "нечистый"],
    "ляда": ["паль", "посека", "кулига", "пожог", "росчисть"],
    "лядащий": ["ледащий", "дрянной"],
    "лядвея": ["ляжка", "лядвие", "стегно"],
    "лядина": ["ляда"],
    "ляжка": ["бедро", "окорок"],
    "лязг": ["лязгание", "скрежет", "бряцание"],
    "лязгав": ["лязгавши"],
    "лязгавши": ["лязгав"],
    "лязгнув": ["лязгнувши"],
    "лязгнувши": ["лязгнув"],
    "лялякав": ["лялякавши"],
    "лялякавши": ["лялякав"],
    "лям": ["лимон"],
    "лямбда": ["длина волны"],
    "лямбе вайме": ["пара", "цебярь", "ляпе вайме", "паронь арьси"],
    "лямблия": ["жиардия"],
    "лямзив": ["лямзивши"],
    "лямзивши": ["лямзив"],
    "лямзить": ["ляпсить", "тибрить"],
    "лян": ["лан", "таэль", "унция"],
    "ляп": ["промах", "промашка", "лажа", "ляпсус", "оплошность", "просчёт", "плюха", "хлюп"],
    "ляпав": ["ляпавши"],
    "ляпавши": ["ляпав"],
    "ляпалиссиада": ["трюизм"],
    "ляпе вайме": ["пара", "цебярь", "лямбе вайме", "паронь арьси"],
    "ляпис": ["азотнокислый", "серебро", "нитрат", "адский камень"],
    "ляпнув": ["ляпнувши"],
    "ляпнувши": ["ляпнув"],
    "ляпнуть": ["брякнуть", "сморозить"],
    "ляпсив": ["ляпсивши"],
    "ляпсивши": ["ляпсив"],
    "ляпсить": ["лямзить"],
    "ляпсус": ["промах"],
    "лярва": ["ларва", "стерва", "негодяй", "негодяйка", "сволочь"],
    "лярд": ["смалец"],
    "ляск": ["ляскання", "лящання"],
    "ляскав": ["ляскавши"],
    "ляскавши": ["ляскав"],
    "ляскать": ["лязгать"],
    "ляскнув": ["ляскнувши"],
    "ляскнувши": ["ляскнув"],
    "лясничав": ["лясничавши"],
    "лясничавши": ["лясничав"],
    "лясничать": ["точить лясы"],
    "ляссе": ["ленточка-закладка"],
    "лясы точить": ["празднословить", "трепаться", "балаболить", "балясничать", "точить лясы", "точить балясы", "балясы точить"],
    "лятучая мыш": ["кажан", "ушан", "нетапыр"],
    "лях": ["пшек"],
    "ляшка": ["полячка"],
    "лёгкость": ["простота"],
    "лёгонький": ["лёгенький"],
    "лёгочник": ["пузырчатка", "лобария лёгочная", "лёгочный редуктор", "лёгочный автомат"],
    "лёгочный сурфактант": ["сурфактант"],
    "лёд": ["ледок", "каток"],
    "лёживав": ["лёживавши"],
    "лёживавши": ["лёживав"],
    "лёжка": ["лежание"],
    "лёллингит": ["мышьяковое железо"],
    "лёмав": ["лёмавши"],
    "лёмавши": ["лёмав"],
    "лёса": ["леска"],
    "лётка": ["леток", "картечь"],
    "лёша": ["алёша"],
    "лёшка": ["лёша", "лёха"],
    "ма": ["мама", "мать", "маменька"],
    "маараб": ["мараб", "марав"],
    "маарив": ["аравит"],
    "маастрихт": ["маастрихтский ярус"],
    "мабул": ["туфан"],
    "мабута": ["мобутовец", "стройбатовец"],
    "мавераннахр": ["трансоксания", "трансоксиана", "фараруд"],
    "мавзолей": ["гробница", "усыпальница", "саркофаг"],
    "мавиз": ["забиб"],
    "мавка": ["навка", "ундина", "вила", "русалка", "дух", "душа", "призрак", "нимфа", "божество"],
    "мавочка": ["мавка"],
    "мавпиний": ["мавпячий"],
    "мавр": ["араб", "арап", "мавританец"],
    "мавританец": ["мавр"],
    "маврозумена": ["балира"],
    "мавт": ["марг"],
    "маг": ["волшебник", "кудесник", "чародей", "колдун", "фокусник", "иллюзионист", "магистрант"],
    "магаданская область": ["колыма", "магаданщина"],
    "магаз": ["магазин"],
    "магазей": ["комора"],
    "магазин мебели": ["мебельный магазин", "мебель"],
    "магазинировав": ["магазинировавши"],
    "магазинировавши": ["магазинировав"],
    "магазинний": ["магазиновий"],
    "магазинный": ["магазинский"],
    "магазинский": ["магазинный"],
    "магараджа": ["махараджа", "князь", "государь"],
    "магарани": ["махарани"],
    "магарыч": ["бакшиш", "взятка"],
    "магарычничав": ["магарычничавши"],
    "магарычничавши": ["магарычничав"],
    "магас": ["паша", "пашша"],
    "магданоз": ["мерудия"],
    "магендоид": ["гексаграмма"],
    "магизм": ["магия", "идолопоклонничество"],
    "магистр": ["учёный", "мастер", "диктатор", "вождь"],
    "магистраль": ["артерия"],
    "магистрант": ["маг"],
    "магистрский": ["магистерский"],
    "магифрения": ["магифренический синдром"],
    "магически": ["чудодейственно", "волшебно"],
    "магический": ["волшебный", "колдовской", "чародейный", "чародейский", "чародейственный", "чудодейственный", "чудотворный"],
    "магичный": ["магический"],
    "магия": ["ведовство", "волхвование", "волшба", "волшебство", "ворожба", "колдовство", "магизм", "теургия", "чародейство", "чернокнижие", "нигромантия", "некромантия", "чудодействие", "чудотворность", "чудотворство"],
    "магл": ["маггл", "простец", "бачок"],
    "маглев": ["магнитоплан", "поезд на магнитной подушке"],
    "магма": ["группоид"],
    "магнат": ["богач", "олигарх", "аристократ", "вельможа", "сановник"],
    "магнатерия": ["магнатство"],
    "магнезия": ["горькозём", "английская соль", "горькая соль", "эпсомская соль"],
    "магнетизация": ["намагничивание"],
    "магнетизировав": ["магнетизировавши"],
    "магнетизировавши": ["магнетизировав"],
    "магнетизм": ["завлекательность", "заманчивость", "пикантность", "прелесть", "привлекательность", "притягательность", "соблазнительность", "аппетитность", "приманчивость", "внушение", "гипноз", "гипнотизация", "гипнотизирование"],
    "магнетизёр": ["месмерист", "гипнотизёр"],
    "магнетит": ["магнитный железняк"],
    "магнетически": ["магнетично", "гипнотически"],
    "магнетический": ["магнитный", "магнетичный", "гипнотический"],
    "магнетично": ["магнетически", "притягательно"],
    "магнетичность": ["притягательность"],
    "магнетичный": ["магнетический"],
    "магнетосома": ["магнитосома"],
    "магнетохимический": ["магнитохимический"],
    "магнетохимия": ["магнитохимия"],
    "магниесодержащий": ["магнийсодержащий"],
    "магниетермия": ["магнийтермия"],
    "магнийсодержащий": ["магниесодержащий"],
    "магнийтермия": ["магниетермия"],
    "магнитив": ["магнитивши"],
    "магнитивши": ["магнитив"],
    "магнитить": ["намагничивать", "примагничивать", "притягивать"],
    "магнитка": ["магнитогорск"],
    "магнитная гидродинамика": ["мгд", "магнитогидродинамика"],
    "магнитноодноосный": ["магнитно-одноосный"],
    "магнитогидродинамика": ["мгд"],
    "магнитодвижущий": ["намагничивающий"],
    "магнитолента": ["магнитный", "лента"],
    "магнитометрия": ["магниторазведка"],
    "магнитоплан": ["маглев"],
    "магниторельсовый": ["магнитно-рельсовый"],
    "магнитосома": ["магнетосома"],
    "магнитофон": ["маг", "мафон"],
    "магнитохимический": ["магнетохимический"],
    "магнитохимия": ["магнетохимия"],
    "магнитчик": ["магнитолог"],
    "магнолиопсиды": ["двудольные"],
    "магнолия": ["магнолья"],
    "маго": ["магот"],
    "магометанин": ["мусульманин"],
    "магометанский": ["мусульманский"],
    "магометанство": ["ислам", "мусульманство"],
    "магометанський": ["мусульманський"],
    "магот": ["маго", "варварийская обезьяна", "магрибский макак"],
    "магриб": ["эль-магриб"],
    "магрибинец": ["магрибец"],
    "магьосник": ["маг", "чародей", "вълшебник"],
    "магьосница": ["вещица", "вещерица", "вълшебница", "бродница"],
    "мадад": ["имдод", "ёри"],
    "мададгор": ["дастёр", "ёвар", "ёридиханда"],
    "мадам": ["барыня", "госпожа", "пани", "фрау", "миссис", "сеньора"],
    "мадейрец": ["мадейранец", "мадерец"],
    "мадемуазель": ["гувернантка"],
    "мадера": ["вино", "мадерка", "мадерца"],
    "маджлиси милли": ["национальный совет"],
    "маджлиси намояндагон": ["палата представителей"],
    "маджлиси оли": ["высшее собрание"],
    "маджонг": ["мацзян"],
    "мадмуазель": ["мадемуазель", "мамзель", "барышня"],
    "мадомс": ["веляфтомс", "лаподемс", "велямс", "прамс", "аф", "паломс", "лоткамс", "валгомс"],
    "мадрегот": ["мэрдивэн"],
    "мадрепора": ["мадрепор"],
    "мадурский": ["мадурский язык"],
    "мадурский язык": ["мадурский"],
    "мадхьямака": ["мадхьямика"],
    "мадьяр": ["венгр", "угрин", "угорец"],
    "мадьярив": ["мадьяривши"],
    "мадьяривши": ["мадьярив"],
    "мадьяризировав": ["мадьяризировавши"],
    "мадьяризировавши": ["мадьяризировав"],
    "мадьяризировать": ["мадьяризовать"],
    "мадьяризм": ["унгаризм"],
    "мадьяризовав": ["мадьяризовавши"],
    "мадьяризовавши": ["мадьяризовав"],
    "мадьяризовать": ["мадьяризировать"],
    "мадьярка": ["венгерка"],
    "мадьярский": ["венгерский"],
    "мадярка": ["угорка"],
    "мадярський": ["угорський"],
    "мае": ["шобе"],
    "маета": ["томление"],
    "мажор": ["дур"],
    "мажордом": ["дворецкий"],
    "мажорировав": ["мажорировавши"],
    "мажорировавши": ["мажорировав"],
    "мажоритарий": ["мажоритарник", "мажоритарщик"],
    "мажоритарник": ["мажоритарий", "мажоритарщик"],
    "мажоритарщик": ["мажоритарий", "мажоритарник"],
    "мажорно": ["бодро", "весело"],
    "мазав": ["мазавши"],
    "мазавши": ["мазав"],
    "мазал": ["маззал", "бахт"],
    "мазание": ["мазанье"],
    "мазанув": ["мазанувши"],
    "мазанувши": ["мазанув"],
    "мазанье": ["мазание"],
    "мазать": ["намазывать", "смазывать"],
    "мазаться": ["намазываться", "пачкаться"],
    "маздаизм": ["маздеизм"],
    "маздеизм": ["маздаизм"],
    "мазеобразный": ["мазевидный"],
    "мазик": ["маз"],
    "мазилка": ["грязнуля", "мазила"],
    "мазило": ["замазка", "мастило"],
    "мазнина": ["лой", "тлъстина", "мас", "масло", "олио"],
    "мазница": ["мозни"],
    "мазнув": ["мазнувши"],
    "мазнувши": ["мазнув"],
    "мазня": ["пачкотня", "помазня", "халтура", "промах", "промашка"],
    "мазок": ["промах"],
    "мазур": ["мазурист", "мазурщик"],
    "мазурист": ["мазурщик"],
    "мазурничав": ["мазурничавши"],
    "мазурничавши": ["мазурничав"],
    "мазурничать": ["плутовать", "мошенничать"],
    "мазурщик": ["мазурист"],
    "мазута": ["мазут", "нефтяные остатки", "грязнуля", "чернопогонник"],
    "мазутавы": ["мазутны"],
    "мазутний": ["мазутовий"],
    "мазутовий": ["мазутний"],
    "мазь": ["крем", "смазка"],
    "мазюкав": ["мазюкавши"],
    "мазюкавши": ["мазюкав"],
    "маис": ["кукуруза"],
    "майданив": ["майданивши"],
    "майданивши": ["майданив"],
    "майданний": ["майдановий"],
    "майданничать": ["майданить"],
    "майдановий": ["майданний"],
    "майка": ["футболка", "пакет-майка", "маечка"],
    "майка лидера": ["жёлтая майка лидера"],
    "майка-алкоголичка": ["майка-алкашка"],
    "майнав": ["майнавши"],
    "майнавши": ["майнав"],
    "майнер": ["криптомайнер"],
    "майнив": ["майнивши"],
    "майнивши": ["майнив"],
    "майний": ["густолистий"],
    "майнинг": ["добыча"],
    "майнот": ["маниот", "маниат"],
    "майонез": ["мазян", "мазик"],
    "майоратний": ["майоратовий"],
    "майоритет": ["большинство"],
    "майские": ["майские праздники"],
    "майские праздники": ["майские"],
    "майский жук": ["майский хрущ"],
    "майстор": ["специалист"],
    "майстория": ["майсторство", "умение", "опитност", "сръчност", "изкуство"],
    "майя": ["мая"],
    "макабрический": ["жуткий", "мрачный", "чудовищный", "ужасный", "ужасающий", "страшный", "устрашающий"],
    "макав": ["макавши"],
    "макавши": ["макав"],
    "макак": ["макака"],
    "макака": ["макак", "кривляка"],
    "макакёнок": ["макакёныш"],
    "макальный": ["макательный"],
    "макание": ["окунание", "погружение"],
    "макао": ["аомынь"],
    "макар": ["способ"],
    "макара": ["масурче", "вретено", "бобина", "шпула"],
    "макароны": ["макарончики", "макарошки", "макарошечки", "макарохи", "паста"],
    "макарохи": ["макароны", "макарошки"],
    "макарьев": ["макарьево"],
    "макарьевский нищий": ["попрошайка", "нищий"],
    "макать": ["окунать"],
    "макдак": ["макдачная"],
    "македонец": ["македонянин"],
    "македонианство": ["пневматомахия", "духоборчество"],
    "македония": ["древняя македония", "северная македония", "греческая македония"],
    "македонский": ["македонский язык"],
    "македонянин": ["македонец"],
    "макет": ["модель"],
    "макетировав": ["макетировавши"],
    "макетировавши": ["макетировав"],
    "макетировать": ["моделировать"],
    "макиавеллевский": ["макиавеллиевский"],
    "макиавеллиевский": ["макиавеллевский"],
    "макивав": ["макивавши"],
    "макивавши": ["макивав"],
    "макидзуси": ["ролл"],
    "макинтошевский": ["макинтошный"],
    "макинтошный": ["макинтошевский"],
    "макияж": ["мейкап", "косметика"],
    "макияжив": ["макияживши"],
    "макияживши": ["макияжив"],
    "маклак": ["маклер", "посредник"],
    "маклачество": ["маклерство"],
    "маклачив": ["маклачивши"],
    "маклачивши": ["маклачив"],
    "маклачить": ["гондобить", "мастрячить", "гоношить", "ладить"],
    "маклерив": ["маклеривши"],
    "маклеривши": ["маклерив"],
    "маклерить": ["маклерничать", "маклерствовать"],
    "маклерничав": ["маклерничавши"],
    "маклерничавши": ["маклерничав"],
    "маклеровав": ["маклеровавши"],
    "маклеровавши": ["маклеровав"],
    "маклерство": ["маклачество"],
    "маклерствовав": ["маклерствовавши"],
    "маклерствовавши": ["маклерствовав"],
    "маклерствовать": ["маклерничать"],
    "маклерствувати": ["маклерувати"],
    "маклин": ["маклейн"],
    "макнув": ["макнувши"],
    "макнувши": ["макнув"],
    "маковник": ["медовик"],
    "маковой росинки во рту не было": ["в брюхе волки воют", "кишка кишке протокол пишет", "кишка кишке кукиш кажет"],
    "макрасана": ["поза крокодила"],
    "макрелевий": ["макрельний"],
    "макрель": ["скумбрия"],
    "макрельний": ["макрелевий"],
    "макровызов": ["макрокоманда"],
    "макроглоссия": ["мегалоглоссия"],
    "макрогол": ["макроголь", "полиэтиленгликоль"],
    "макрогосударство": ["макро-государство"],
    "макроиндикатор": ["макропоказатель"],
    "макрокосм": ["вселенная", "макрокосмос"],
    "макрокосмический": ["вселенский"],
    "макрокосмос": ["вселенная", "макрокосм"],
    "макромир": ["макрокосм"],
    "макромолекула": ["полимерная молекула"],
    "макропогода": ["климат"],
    "макропоказатель": ["макроиндикатор"],
    "макроспора": ["мегаспора"],
    "макроспорангий": ["мегаспорангий"],
    "макроспорофилл": ["мегаспорофилл"],
    "макротопонимика": ["макротопонимия"],
    "макротопонимия": ["макротопонимика"],
    "макроцефалия": ["мегалоцефалия"],
    "макрочастица": ["макроскопическое тело"],
    "макрурус": ["длиннохвост", "долгохвост"],
    "макс": ["максим", "максимилиан"],
    "макса": ["рыбий жир"],
    "максав": ["максавши"],
    "максавши": ["максав"],
    "максим": ["макс", "максик", "максимочка", "максимка", "максимушка"],
    "максима": ["афоризм", "сентенция"],
    "максимайзер": ["энхансер"],
    "максимализация": ["максимизация"],
    "максимализировав": ["максимализировавши"],
    "максимализировавши": ["максимализировав"],
    "максимализм": ["бескомпромиссность"],
    "максималка": ["максимум"],
    "максимальный": ["наибольший", "наивысший"],
    "максимизировав": ["максимизировавши"],
    "максимизировавши": ["максимизировав"],
    "максимилиан": ["максимильян", "макс"],
    "максимилизировав": ["максимилизировавши"],
    "максимилизировавши": ["максимилизировав"],
    "максимович": ["максимыч"],
    "максимум": ["пик", "вершина", "наибольшее"],
    "максовав": ["максовавши"],
    "максовавши": ["максовав"],
    "максовать": ["платить"],
    "максомс": ["венептемс", "максомс кядьс", "лездомс", "каземс", "кандомс", "тиемс", "явамс", "ётафтомс", "кирдемс", "надияфтомс"],
    "макстерм": ["максимальный терм"],
    "мактаббача": ["мактабхон"],
    "мактуб": ["китоб", "нома"],
    "макута": ["ликута"],
    "макуха": ["жмых", "жмак"],
    "макушка": ["верхушка"],
    "мал мала меньше": ["мал мала мень"],
    "мал-мала меньше": ["мал мала меньше", "мал мала мень"],
    "малави": ["республика малави", "ньясаленд", "ньяса"],
    "малавиец": ["ньясалендец"],
    "малавийский": ["ньясалендский"],
    "малагасиец": ["мальгаш", "мадагаскарец"],
    "малагасийка": ["мадагаскарка", "мальгашка"],
    "малагасийский": ["мальгашский"],
    "маладис": ["афарин"],
    "малаец": ["малайзиец"],
    "малайский": ["малайзийский"],
    "малакав": ["малакавши"],
    "малакавши": ["малакав"],
    "малас": ["ваксс"],
    "маласа": ["ваксса"],
    "малафья": ["семя", "сперма", "эякулят", "малофья", "молофья"],
    "малахитовый": ["зелёный"],
    "малахольный": ["ненормальный", "помешанный", "чокнутый", "умом тронутый", "сумасшедший", "полоумный", "придурковатый", "придурочный", "чудной", "чудаковатый", "вялый", "слабосильный", "малосильный", "тщедушный", "робкий"],
    "малаша": ["мелания"],
    "малая азия": ["анатолия"],
    "малая вода": ["мелководье"],
    "малая земля": ["ораниенбаумский плацдарм", "ораниенбаумский пятачок", "приморский плацдарм", "таменгонтская республика", "лебяжинская республика"],
    "малая пядь": ["толика"],
    "малая рогань": ["пасековка"],
    "малварь": ["вредонос", "зловред", "вредоносная программа", "зловредная программа"],
    "малевав": ["малевавши"],
    "малевавши": ["малевав"],
    "маленький": ["малый", "незначительный", "небольшой", "невеликий", "невысокий", "низкорослый", "малочисленный", "ничтожный", "маловажный", "малолетний", "младшенький", "миниатюрный", "ребёнок", "дитя"],
    "маленько": ["немного", "малость", "чуть-чуть"],
    "малец": ["бутуз", "малолеток", "мальчик", "мальчишка", "мальчонка", "мальчуган", "малыш", "парень", "паренёк", "парнишка", "пацан", "пацанёнок", "подросток", "ребёнок", "оголец"],
    "мали": ["республика мали"],
    "маливав": ["маливавши"],
    "маливавши": ["маливав"],
    "малигнизация": ["озлокачествление"],
    "малигнизировав": ["малигнизировавши"],
    "малигнизировавши": ["малигнизировав"],
    "малина": ["малинник", "рубус"],
    "малиновев": ["малиновевши"],
    "малиновевши": ["малиновев"],
    "малиновка": ["зарянка"],
    "малица": ["шуба"],
    "малкольм": ["малькольм"],
    "мало": ["недостаточно"],
    "мало-мальски": ["сколько-нибудь"],
    "мало-помалу": ["постепенно", "понемногу"],
    "малоазиатский": ["малоазийский"],
    "малобюджетный": ["низкобюджетный"],
    "маловероятный": ["сомнительный", "проблематический"],
    "маловерье": ["маловерие"],
    "маловесный": ["лёгкий", "легковесный"],
    "маловыгодность": ["малорентабельность", "малоприбыльность", "малодоходность"],
    "маловыгодный": ["малодоходный", "малорентабельный", "малоприбыльный"],
    "маловязкий": ["слабовязкий"],
    "малогабаритный": ["малоразмерный"],
    "малограмотний": ["малописьменний"],
    "малограмотность": ["безграмотность", "неграмотность"],
    "малограмотный": ["полуграмотный", "безграмотный", "неграмотный"],
    "малогрузный": ["малогрузовой"],
    "малогрузовой": ["малогрузный"],
    "малодейственный": ["малоэффективный"],
    "малодетный": ["немногодетный"],
    "малодойный": ["малоудойный", "малоудойливый", "тугосисий"],
    "малодоказательный": ["малоубедительный"],
    "малодоходный": ["малоприбыльный"],
    "малодушествовав": ["малодушествовавши"],
    "малодушествовавши": ["малодушествовав"],
    "малодушие": ["трусость", "нерешительность", "безволие", "слабодушие"],
    "малодушничав": ["малодушничавши"],
    "малодушничавши": ["малодушничав"],
    "малодушничать": ["малодушествовать", "трусить"],
    "малодушный": ["слабовольный", "трусливый", "слабодушный"],
    "малодушье": ["малодушие"],
    "малое и среднее предпринимательство": ["мсп"],
    "малозатратный": ["низкозатратный", "бюджетный", "малобюджетный", "дешёвый"],
    "малозначимый": ["малозначащий", "малозначительный"],
    "малозначительный": ["небольшой", "малозначащий", "маловажный"],
    "малоимущий": ["небогатый", "нуждающийся", "малообеспеченный"],
    "малоинвазивный": ["малотравматичный"],
    "малоинтенсивный": ["неинтенсивный", "низкоинтенсивный"],
    "малоинформированный": ["малоосведомлённый", "малосведущий"],
    "малокалиберный": ["мелкокалиберный"],
    "малоконтрастный": ["низкоконтрастный"],
    "малокровие": ["анемия", "малокровье"],
    "малокровье": ["малокровие"],
    "малокультурный": ["некультурный", "необразованный", "неотёсанный"],
    "малолетка": ["малолеток", "ребёнок", "дитя"],
    "малолеток": ["ребёнок", "подлеток", "малолетка"],
    "малолюдство": ["малолюдье"],
    "малолюдье": ["малолюдность", "малолюдство", "безлюдье"],
    "маломерка": ["маломерок"],
    "маломерный": ["малогабаритный"],
    "маломовний": ["мовчазний", "небалакучий"],
    "маломощный": ["малосильный", "незажиточный", "бедный"],
    "малонаучный": ["полунаучный"],
    "малонил-коа": ["малонилкоэнзим а"],
    "малоновая кислота": ["пропандиовая кислота", "метандикарбоновая кислота"],
    "малоновый": ["пропандиовый"],
    "малообеспеченный": ["бедный", "неимущий", "малоимущий", "нищий", "небогатый", "нуждающийся", "необеспеченный"],
    "малооплачиваемый": ["низкооплачиваемый", "невысокооплачиваемый"],
    "малоподъёмный": ["большегрузный"],
    "малопоместительный": ["маловместительный"],
    "малопопулярный": ["непопулярный"],
    "малоправдоподобный": ["сомнительный"],
    "малоприбыльный": ["малодоходный"],
    "малопродуктивный": ["малопроизводительный"],
    "малопроизводительный": ["малопродуктивный"],
    "малопулька": ["мелкашка"],
    "малорастворимый": ["слаборастворимый", "труднорастворимый"],
    "малореалистичный": ["малореальный"],
    "малорентабельный": ["маловыгодный", "малоприбыльный", "малодоходный"],
    "малорослий": ["невисокий"],
    "малорослый": ["низкий", "низкорослый"],
    "малоросс": ["малороссиянин", "украинец"],
    "малороссийский": ["украинский"],
    "малороссия": ["малая русь", "малая россия", "малоруссия"],
    "малороссиянин": ["малоросс", "малорус"],
    "малороссиянка": ["украинка"],
    "малороссияночка": ["украинка"],
    "малоротка": ["морская малоротая корюшка"],
    "малорусский": ["малороссийский", "украинский"],
    "малосильный": ["слабосильный"],
    "малоскоростной": ["низкоскоростной"],
    "малосольный": ["слабосолёный"],
    "малоспособный": ["бездарный"],
    "малотоксичный": ["низкотоксичный"],
    "малотребовательный": ["нетребовательный", "неприхотливый"],
    "малоудойливый": ["малоудойный"],
    "малоудойный": ["малодойный", "малоудойливый", "тугосисий"],
    "малоумие": ["олигофрения"],
    "малоумный": ["глупый"],
    "малоупотребимый": ["редкоупотребимый"],
    "малоустойчивый": ["неустойчивый", "слабоустойчивый"],
    "малохольный": ["ненормальный", "помешанный", "чокнутый"],
    "малоценный": ["неважный", "недорогой"],
    "малочисленный": ["небольшой", "малый", "редкий", "необычный", "нераспространённый", "редкостный"],
    "малошёрстный": ["малошёрстый"],
    "малты": ["палты"],
    "малум": ["маълум"],
    "малчивав": ["малчивавши"],
    "малчивавши": ["малчивав"],
    "малые половые губы": ["брухля"],
    "малый": ["маленький", "незначительный", "небольшой", "тесный", "узкий", "несовершеннолетний", "парень", "пацан", "мальчик", "юноша", "детина"],
    "малый автобус": ["микроавтобус"],
    "малый и средний бизнес": ["малое и среднее предпринимательство", "мсп"],
    "малый конь": ["конь"],
    "малый оленёк": ["канчиль", "яванский малый канчиль"],
    "малыш": ["крошка", "ребёнок"],
    "мальва": ["алтей", "калачики", "просвирник", "просвирняк", "шток-роза"],
    "мальгашский": ["малагасийский"],
    "мальдивская республика": ["мальдивы"],
    "мальдивы": ["мальдивская республика"],
    "малькольм": ["малкольм"],
    "мальпост": ["почтовый дилижанс"],
    "мальпостное сообщение": ["срочно-мальпостное сообщение"],
    "мальта": ["республика мальта"],
    "мальтодекстрин": ["патока"],
    "мальтретировав": ["мальтретировавши"],
    "мальтретировавши": ["мальтретировав"],
    "мальчик": ["малец", "мальчуган", "отрок", "парень", "парнишка", "пацан", "пацанёнок", "подросток", "шкет", "шпингалет"],
    "мальчик для битья": ["мальчик для побоев", "мальчик для сечения", "козёл отпущения", "без вины виноватый"],
    "мальчиковый": ["мальчоночий", "мальчишечий"],
    "мальчиш": ["мальчик"],
    "мальчишеский": ["мальчиковый"],
    "мальчишествовав": ["мальчишествовавши"],
    "мальчишествовавши": ["мальчишествовав"],
    "мальчишечий": ["мальчишеский"],
    "мальчишка": ["мальчик", "мальчуган", "парень", "паренёк", "пацан", "пацанёнок", "юнец", "сосунок", "птенец", "щенок", "щусёнок", "молокосос", "желторотик"],
    "мальчишничав": ["мальчишничавши"],
    "мальчишничавши": ["мальчишничав"],
    "мальчонка": ["мальчуган"],
    "мальчуган": ["мальчик", "мальчонка", "пацан"],
    "мальчуганка": ["пацанка"],
    "малювати": ["рисувати"],
    "малюсенький": ["крохотный", "крошечный"],
    "малютка": ["малышка", "малыш"],
    "малява": ["записка", "сообщение", "письмо", "рисунок", "мазня", "каракули", "каляка-маляка"],
    "малявка": ["маленький", "ребёнок", "малец", "хлопчик", "шмакодявка"],
    "малявочка": ["малышка"],
    "маляка": ["мазня", "рисунок", "каляка", "каляка-маляка", "малява"],
    "маляр": ["мазила"],
    "малярив": ["маляривши"],
    "маляривши": ["малярив"],
    "малярийный комар": ["анофелес"],
    "малярить": ["малярничать"],
    "малярия": ["болотная лихорадка"],
    "малярничав": ["малярничавши"],
    "малярничавши": ["малярничав"],
    "малёхонький": ["малёшенький", "малюсенький", "махонький", "крохотный", "крошечный"],
    "малёхонько": ["малёшенько"],
    "малёшенький": ["малёхонький", "малюсенький", "махонький", "крохотный", "крошечный"],
    "малёшенько": ["малёхонько"],
    "мама": ["мать", "маманя", "мамаша", "мамка", "мамочка", "мамушка", "матушка", "мамулёк", "мамуля", "мамуся", "мамулечка", "маменька", "мамик", "тёща", "свекровь"],
    "мама дорогая": ["мать моя женщина"],
    "мамаев": ["мамайский", "мамаевский"],
    "мамалигар": ["румънец", "влах"],
    "мамалыга": ["гоми", "абыста", "журан-худар", "марамыса"],
    "маманя": ["мамаша", "мать"],
    "мамаша": ["мама", "маманя", "бабуся"],
    "мамашка": ["мамаша"],
    "мамелюк": ["мамлюк"],
    "мамзель": ["гувернантка", "приживалка", "актриска"],
    "мамин": ["маманин", "мамашин", "мамкин", "мамочкин", "материнский"],
    "мамка": ["мать", "материнка"],
    "мамкав": ["мамкавши"],
    "мамкавши": ["мамкав"],
    "мамкин": ["диванный", "доморощенный"],
    "мамкоёб": ["мамоёб"],
    "мамлакат": ["кишвар"],
    "мамлей": ["младший лейтенант"],
    "мамлюк": ["мамелюк"],
    "маммалиология": ["маммалогия", "териология"],
    "маммалогия": ["маммалиология", "териология"],
    "маммиллярия": ["мамиллярия"],
    "мамон": ["мамона", "живот", "пузо", "брюхо", "чрево", "желудок", "моня", "няндомец"],
    "мамона": ["мамон", "утроба"],
    "мамонин": ["мамонов"],
    "мамонов": ["мамонин"],
    "мамонт": ["мамут"],
    "мамот": ["марг", "вафот", "фавт"],
    "мамочкин": ["маменькин", "мамин"],
    "мамоёб": ["мамкоёб"],
    "мамский": ["материнский", "мамин", "мамкин", "мамочкин"],
    "мамулька": ["мамочка"],
    "мамуля": ["мамочка", "мамуся"],
    "мамуня": ["мамуля"],
    "мамура": ["княженика", "поленика", "княженика обыкновенная", "малина арктическая", "куманика", "красная морошка", "облепиха"],
    "мамушка": ["матушка", "маменька", "мамка"],
    "мамык": ["дебет"],
    "манав": ["манавши"],
    "манавши": ["манав"],
    "манагер": ["менеджер"],
    "манай": ["бидний"],
    "манатки": ["пожитки", "добро", "барахло", "тряпки", "шмотки", "шмотьё"],
    "манаття": ["манатки"],
    "манать": ["игнорировать"],
    "манба": ["манбаъ"],
    "манга": ["комикку"],
    "мангал": ["жаровня", "козырёк", "противокумулятивный экран"],
    "мангифера": ["манго"],
    "мангишлак": ["мангышлак"],
    "мангишлакский": ["мангышлакский"],
    "мангль": ["ризофора мангле", "мангровое дерево"],
    "манго": ["мангифера"],
    "мангостан": ["мангустин", "мангостин", "гарциния", "мангкут"],
    "мангулик": ["абадият", "абадийлик"],
    "мангуст": ["мангуста"],
    "мангуста": ["мангуст"],
    "мангышлак": ["мангишлак", "мангистау"],
    "мангышлакский": ["мангишлакский"],
    "манда кобылья": ["манда", "манды кусок"],
    "мандавошечка": ["мандавошка"],
    "мандавошка": ["лобковая вошь", "площица", "вошь", "фтирус", "фтирус пубис", "мандавоха", "мандячка", "девушка", "девчонка", "малолетка", "редиска"],
    "мандаринный": ["мандариновый"],
    "мандев": ["мандевши"],
    "мандевши": ["мандев"],
    "мандеть": ["пиздеть"],
    "мандец": ["пиздец", "пизда", "пипец", "капец", "кабзда", "катастрофа", "крах"],
    "мандив": ["мандивши"],
    "мандивши": ["мандив"],
    "мандрагора": ["адамова голова"],
    "мандраж": ["дрожь"],
    "мандражив": ["мандраживши"],
    "мандраживши": ["мандражив"],
    "мандражировав": ["мандражировавши"],
    "мандражировавши": ["мандражировав"],
    "мандражировать": ["бояться", "волноваться"],
    "мандражить": ["мандражировать"],
    "мандрил": ["сфинкс"],
    "мандрьоха": ["волоцюга", "димтянка", "диптянка", "фрейда", "хльорка", "шлюндра", "шльондра", "шлюха"],
    "мандуб": ["мустахаб", "нафиль"],
    "мандукасана": ["поза жабы"],
    "маневрировав": ["маневрировавши"],
    "маневрировавши": ["маневрировав"],
    "маневрированье": ["маневрирование"],
    "манежив": ["манеживши"],
    "манеживши": ["манежив"],
    "манекен": ["манекенщица", "кукла", "марионетка"],
    "маненечко": ["маленечко", "чуточку"],
    "манерничав": ["манерничавши"],
    "манерничавши": ["манерничав"],
    "манерничать": ["жантильничать", "жеманничать", "жеманиться", "кривляться", "ломаться", "фокусничать", "изламываться"],
    "манерно": ["жеманно"],
    "манерность": ["жеманство", "чопорность", "неестественность"],
    "манерный": ["жеманный", "вычурный"],
    "манетка": ["шифтер"],
    "манефон": ["манетон"],
    "манжета": ["манжет"],
    "манжетний": ["манжетовий"],
    "манжетовий": ["манжетний"],
    "манзил": ["хона"],
    "манзини": ["бремерсдорп"],
    "мани": ["манес"],
    "маниакально-депрессивный": ["циркулярный", "биполярный"],
    "маниакально-депрессивный психоз": ["мдп", "биполярное аффективное расстройство"],
    "маниакальный": ["экспансивный"],
    "маниат": ["майнот", "маниот"],
    "манив": ["манивши"],
    "манивши": ["манив"],
    "маникорд": ["кларихорд"],
    "маникюр": ["холя ногтей"],
    "маникюрша": ["маникюрщица"],
    "маникюрщица": ["маникюрша"],
    "маниловщина": ["обломовщина"],
    "маниок": ["маниока", "маниот", "кассава"],
    "маниок съедобный": ["кассава"],
    "маниока": ["маниок", "эуфорбия"],
    "маниот": ["майнот"],
    "маниофобия": ["лиссофобия"],
    "манипулировав": ["манипулировавши"],
    "манипулировавши": ["манипулировав"],
    "манипулирование": ["манипуляция"],
    "манипулировать": ["орудовать", "оперировать", "жонглировать", "дёргать за нитки"],
    "манипулятивность": ["управляемость"],
    "манипуляционная": ["манипуляционный кабинет"],
    "манипуляция": ["манипулирование"],
    "манить": ["подманивать", "приманивать"],
    "манифест": ["декларация", "заявление"],
    "манифестация": ["проявление"],
    "манифестировав": ["манифестировавши"],
    "манифестировавши": ["манифестировав"],
    "манихеец": ["манихей", "манихеист"],
    "манихеизм": ["манихейство"],
    "манихеист": ["манихей", "манихеец"],
    "манихей": ["мани"],
    "манихейский бред": ["маниизм"],
    "манихейство": ["маницзяо"],
    "мания": ["маниакальный синдром"],
    "мания величия": ["мегаломания"],
    "мания преследования": ["бред преследования"],
    "манка": ["манная крупа", "манная каша"],
    "манки": ["манкис"],
    "манкий": ["манящий", "заманчивый", "соблазнительный"],
    "манкировав": ["манкировавши"],
    "манкировавши": ["манкировав"],
    "манкирование": ["пренебрежение", "уклонение"],
    "манкировать": ["пренебрегать", "отсутствовать", "пропускать", "дерзить"],
    "манкис": ["манки"],
    "манкуртизм": ["беспамятность", "беспамятливость"],
    "манкуртство": ["манкуртизм"],
    "манна небесная": ["подарок судьбы"],
    "манная каша": ["манка"],
    "мановение": ["мановенье"],
    "мановенье": ["мановение"],
    "манок": ["приманка", "крючок", "зацепка", "уловка"],
    "мансарда": ["чердак"],
    "мансардний": ["мансардовий"],
    "манси": ["вогул", "вогулич", "мансиец", "мансийка"],
    "мансиец": ["манси"],
    "мансийка": ["манси"],
    "манта": ["сан-пабло-де-манта"],
    "мантоварка": ["каскан", "мантушница", "мантышница"],
    "мантовница": ["мантоварка"],
    "манту": ["туберкулиновая проба", "реакция манту"],
    "мантулив": ["мантуливши"],
    "мантуливши": ["мантулив"],
    "мантушница": ["мантоварка", "мантышница"],
    "мантышница": ["мантоварка", "мантушница", "мантовница", "каскан"],
    "мануал": ["мануалист", "мануальщик"],
    "мануалист": ["мануал", "мануальщик"],
    "мануальщик": ["мануал", "мануалист"],
    "манул": ["палласов кот"],
    "манускрипт": ["рукопись"],
    "мануфактура": ["ткани", "текстильные изделия"],
    "мануфактурный": ["текстильный"],
    "мануэль": ["мэнни"],
    "манфред": ["мэнни"],
    "манхэттенское расстояние": ["расстояние городских кварталов"],
    "манье": ["мание"],
    "маньерист": ["кривляка", "позёр", "ломака"],
    "маньчжоу-го": ["маньчжурия"],
    "маньчжур": ["маньчжурец"],
    "маньчжурец": ["маньчжур"],
    "маньяк": ["псих", "фанат"],
    "маньяча": ["фанатея"],
    "маньячащий": ["фанатеющий"],
    "маньячив": ["маньячивши", "фанатев"],
    "маньячивши": ["маньячив", "фанатевши", "фанатев"],
    "маньячивший": ["фанатевший"],
    "маньячить": ["фанатеть"],
    "манюка": ["хлус"],
    "манящий": ["привлекательный", "притягательный", "заманчивый"],
    "манёвренный": ["маневренный"],
    "маори": ["маорийский язык"],
    "мапа": ["карта", "уровень"],
    "мапив": ["мапивши"],
    "мапивши": ["мапив"],
    "мапирование": ["маппинг"],
    "мапить": ["маппить"],
    "маппив": ["маппивши"],
    "маппивши": ["маппив"],
    "маппинг": ["мапирование", "дизайн уровней"],
    "маппить": ["мапить"],
    "мара": ["марево", "призрак"],
    "марав": ["маравши"],
    "мараведи": ["мараведис", "маравед"],
    "маравихер": ["вор", "карманник"],
    "маравши": ["марав"],
    "маразматичный": ["маразматический"],
    "маразмировав": ["маразмировавши"],
    "маразмировавши": ["маразмировав"],
    "мараковав": ["мараковавши"],
    "мараковавши": ["мараковав"],
    "мараковать": ["разбираться", "понимать", "мороковать", "мерекать"],
    "маракуйя": ["маракуя", "страстоцвет", "пассифлора"],
    "марал": ["изюбр", "изюбрь"],
    "мараль": ["клевета", "оскорбление"],
    "марание": ["пачкание", "маранье", "пачканье"],
    "маранье": ["марание", "пачкание", "пачканье"],
    "мараскин": ["мараскино"],
    "марат": ["марик"],
    "марать": ["пачкать", "позорить", "бесчестить", "порочить"],
    "марафет": ["порядок", "чистота", "лоск"],
    "марафетив": ["марафетивши"],
    "марафетивши": ["марафетив"],
    "марафонка": ["бегунья"],
    "марвихер": ["блатной"],
    "марганецсодержащий": ["марганцесодержащий"],
    "марганцевав": ["марганцевавши"],
    "марганцевавши": ["марганцевав"],
    "маргарин": ["комбижир"],
    "маргаринный": ["маргариновый"],
    "маргариновый": ["маргаринный"],
    "маргарита": ["марго", "рита", "маргоша", "ритуля", "ритуся", "ритка"],
    "маргинал": ["нигилист", "беспринципный", "люмпен", "изгой", "отморозок", "перекати-поле", "сума перемётная", "асоциальный"],
    "маргинализировав": ["маргинализировавши"],
    "маргинализировавши": ["маргинализировав"],
    "маргинализировать": ["маргинализовать"],
    "маргинализироваться": ["маргинализоваться"],
    "маргинализовав": ["маргинализовавши"],
    "маргинализовавши": ["маргинализовав"],
    "маргинализовать": ["маргинализировать"],
    "маргинализоваться": ["маргинализироваться"],
    "маргинальный": ["немаргинальный"],
    "мардж": ["марджори"],
    "марджори": ["мардж"],
    "мардо": ["чясо", "рублё"],
    "мардум": ["нос"],
    "маревный": ["маревый"],
    "марево": ["марь", "мираж", "дымка", "туман", "мгла", "хмарь", "курево"],
    "маренный": ["мареновый"],
    "мареновый": ["маренный"],
    "мареограф": ["лимниграф", "приливомер", "футшток"],
    "маржинальность": ["предельный доход"],
    "мариамит": ["алеппин", "халабит"],
    "марианна": ["марьяна", "мариамна"],
    "марив": ["маривши"],
    "маривши": ["марив"],
    "мариец": ["черемис"],
    "марий": ["мариус", "марей", "марьюс", "мэриус", "марио"],
    "марик": ["мариуполь"],
    "маринад": ["соленье"],
    "маринистика": ["марина"],
    "мариновав": ["мариновавши"],
    "мариновавши": ["мариновав"],
    "мариновать": ["тянуть"],
    "маринолог": ["океанолог", "океанограф", "гидробиолог", "моревед"],
    "марио": ["марий"],
    "мариолатрия": ["мариология"],
    "мариология": ["мариолатрия", "теотокология"],
    "марионеточный": ["марионетный", "кукольный"],
    "мариуполь": ["марик", "павловск", "жданов"],
    "марихуана": ["каннабис", "мариванна", "мари", "план"],
    "марихуанный": ["марихуановый"],
    "марихуановый": ["марихуанный"],
    "мария": ["марья", "маша", "машка", "маха", "машенька", "машуня", "машуля", "мэри", "мари"],
    "марйам": ["марьям", "мария"],
    "марк": ["марик"],
    "марка": ["жетон", "фишка", "торговый знак", "клеймо", "торговая марка", "бренд", "сорт", "наименование", "качество"],
    "марказит": ["гребенчатый колчедан", "лучистый колчедан", "железный колчедан", "копьевидный колчедан", "ячеистый колчедан"],
    "маркер": ["знак", "признак", "маркерный радиомаяк"],
    "маркетизировав": ["маркетизировавши"],
    "маркетизировавши": ["маркетизировав"],
    "маркетировав": ["маркетировавши"],
    "маркетировавши": ["маркетировав"],
    "маркетри": ["инкрустация по дереву"],
    "маркировав": ["маркировавши"],
    "маркировавши": ["маркировав"],
    "маркирование": ["маркировка"],
    "маркировать": ["выделять"],
    "маркировка": ["маркирование"],
    "маркитанив": ["маркитанивши"],
    "маркитанивши": ["маркитанив"],
    "маркович": ["маркыч"],
    "маркос": ["маркиньос"],
    "марксизм-ленинизм": ["ленинизм", "большевизм"],
    "марксист": ["коммунист"],
    "марксистски": ["по-марксистски"],
    "марксштадт": ["маркс"],
    "маркшейдер": ["горный", "геометр", "межевщик"],
    "маркшейдерия": ["маркшейдерское дело"],
    "марлинь": ["шкимушка"],
    "марля": ["газ", "кисея"],
    "мармеладинка": ["мармеладка"],
    "мармеладка": ["мармеладинка", "мармеладина"],
    "мармеладний": ["мармеладовий"],
    "мармиза": ["пика", "мурло"],
    "мармит": ["гастроёмкость"],
    "мармозетка": ["гельдиевая каллимико", "уистити"],
    "марморировав": ["марморировавши"],
    "марморировавши": ["марморировав"],
    "марморирование": ["мраморирование"],
    "марнотрат": ["марнотратник", "марнотратець"],
    "мародёр": ["акула"],
    "мародёрив": ["мародёривши"],
    "мародёривши": ["мародёрив"],
    "мародёрить": ["мародёрствовать"],
    "мародёрничав": ["мародёрничавши"],
    "мародёрничавши": ["мародёрничав"],
    "мародёрничать": ["мародёрствовать"],
    "мародёрски": ["по-мародёрски"],
    "мародёрство": ["ограбление", "грабёж"],
    "мародёрствовав": ["мародёрствовавши"],
    "мародёрствовавши": ["мародёрствовав"],
    "мародёрствовать": ["мародёрничать"],
    "марокко": ["королевство марокко"],
    "марочник": ["филателист"],
    "марран": ["выкрест", "прыгун"],
    "марризм": ["новое учение о языке", "яфетическая теория", "теория стадиальности", "яфетидология"],
    "марс": ["арей", "арес", "градив"],
    "марсала": ["марсал"],
    "марселин": ["шёлк", "шерсть", "тафта"],
    "марсоведение": ["марсология", "ареология"],
    "март": ["марток", "березозол", "сухий", "брезень"],
    "мартеновская печь": ["мартен"],
    "мартенситный": ["мартенситовый"],
    "мартенситовый": ["мартенситный"],
    "мартенсы": ["мартинсы"],
    "мартин": ["мартын"],
    "мартириум": ["мартирий", "мартирион"],
    "мартиролог": ["мартирологий", "мартирология"],
    "мартирологий": ["мартиролог", "мартирология"],
    "мартирология": ["мартирологий", "мартиролог"],
    "марток": ["мартушка", "марточек"],
    "мартын": ["чайка", "мартышка"],
    "мартышка": ["макака"],
    "мартышкин труд": ["сизифов труд"],
    "маруда": ["марудник", "марудниця"],
    "марудний": ["скучный"],
    "маруся": ["воронок", "автозак"],
    "марципанный": ["марципановый"],
    "марципановый": ["марципанный"],
    "марш": ["прохождение", "поход", "демонстрация", "пролёт"],
    "маршалек": ["маршалок"],
    "маршалловы острова": ["республика маршалловы острова"],
    "маршировав": ["маршировавши"],
    "маршировавши": ["маршировав"],
    "маршировать": ["вышагивать"],
    "маршировка": ["марширование"],
    "маршрутив": ["маршрутивши"],
    "маршрутивши": ["маршрутив"],
    "маршрутизатор": ["рутер", "роутер"],
    "маршрутизировав": ["маршрутизировавши"],
    "маршрутизировавши": ["маршрутизировав"],
    "маршрутка": ["джамшутка", "джихад-арба"],
    "маршрутное такси": ["маршрутка", "джамшутка", "джихад-арба"],
    "мары": ["мерв"],
    "марыйский велаят": ["марыйская область"],
    "марья": ["мария"],
    "марьяж": ["брак", "свадьба"],
    "марьяжный": ["брачный", "свадебный"],
    "марьям": ["мария", "марйам"],
    "марьяна": ["марианна", "мариамна"],
    "марьянник": ["иван-да-марья"],
    "марямс": ["марямс ёжа", "марямс ёжеса", "содамс", "шарьхкодемс", "кулемс"],
    "масдар": ["девербатив"],
    "маска": ["личина", "ряженый", "слепок", "шаблон", "пуансон"],
    "маскара": ["муаскар"],
    "маскарад": ["бал-маскарад", "костюмированный бал", "костюмированный вечер"],
    "маскарон": ["макарон"],
    "маскерад": ["маскарад"],
    "маскировав": ["маскировавши"],
    "маскировавши": ["маскировав"],
    "маскирование": ["мимикрия", "маскировка"],
    "маскировать": ["переодевать", "камуфлировать", "прикрывать"],
    "маскообразный": ["невыразительный", "безжизненный"],
    "маскот": ["талисман"],
    "маскулинизировав": ["маскулинизировавши"],
    "маскулинизировавши": ["маскулинизировав"],
    "маскулинизм": ["вирилизм", "маскулинность", "мужественность", "мачизм"],
    "маскулинность": ["мужественность"],
    "маскхалат": ["маскировочный халат"],
    "масленая": ["масленая неделя"],
    "масленик": ["маслёнок", "масляник"],
    "масленица": ["масляница", "масляная", "масляная неделя", "мясопуст", "мясопустная седмица", "сырная неделя", "сырная седмица"],
    "масленичный": ["масляничный"],
    "масленый": ["масляный", "намасленный", "елейный", "слащавый"],
    "маслив": ["масливши"],
    "масливши": ["маслив"],
    "маслинный": ["маслиновый"],
    "маслить": ["промасливать", "замасливать"],
    "маслодельня": ["маслобойня"],
    "масложировой": ["маслобойно-жировой"],
    "маслоносный": ["масличный", "маслосодержащий"],
    "маслосборник": ["маслоуловитель", "маслоулавливатель"],
    "маслосодержащий": ["маслоносный"],
    "маслосырзавод": ["маслосырозавод"],
    "маслосырозавод": ["маслосырзавод"],
    "маслотопная": ["маслотопня"],
    "маслотопный": ["маслотопенный"],
    "масляная головка": ["маслёнок"],
    "масляная кислота": ["бутановая кислота", "этилуксусная кислота"],
    "масляник": ["масленик"],
    "масляный": ["масленый", "сальный", "похотливый", "замасляный", "замасленный", "засаленный", "слащавый", "льстивый", "заискивающий", "подобострастный"],
    "маслёнок": ["масленик", "маслина"],
    "масон": ["франкмасон", "вольный каменщик", "фармасон", "фармазон", "жидомасон"],
    "масонский": ["франкмасонский"],
    "масонство": ["франкмасонство"],
    "масс-медиа": ["сми", "медийка"],
    "масс-спектрограф": ["масс-спектрометр"],
    "масс-шутинг": ["массшутинг"],
    "массагет": ["абасг"],
    "массаж": ["массирование"],
    "массаж данных": ["причёсывание", "очистка", "искажение", "манипуляция"],
    "массажировав": ["массажировавши"],
    "массажировавши": ["массажировав"],
    "массажирование": ["массаж"],
    "массажировать": ["массировать"],
    "массажироваться": ["массироваться"],
    "массажная": ["массажный кабинет"],
    "массив": ["микрорайон", "таблица", "целиком"],
    "массив дерева": ["массив натурального дерева"],
    "массировав": ["массировавши"],
    "массировавши": ["массировав"],
    "массировать": ["массажировать"],
    "массироваться": ["массажироваться"],
    "массмедиа": ["сми"],
    "массовая доля": ["массовая концентрация"],
    "массовик-затейник": ["аниматор"],
    "массогабаритный": ["массово-габаритный"],
    "массшутинг": ["масс-шутинг"],
    "мастак": ["мастер", "дока", "умелец", "корифей"],
    "мастачив": ["мастачивши"],
    "мастачивши": ["мастачив"],
    "мастачка": ["виртуозка", "искусница", "умелица", "профессионалка"],
    "мастер": ["специалист", "профессионал"],
    "мастер кожаной перчатки": ["боксёр"],
    "мастер-класс": ["тренинг", "семинар"],
    "мастер-ломастер": ["неумеха"],
    "мастербатч": ["мастербетч", "мастербач", "суперконцентрат"],
    "мастерив": ["мастеривши"],
    "мастеривши": ["мастерив"],
    "мастерица": ["виртуозша", "искусница", "ремесленница", "рукодельница"],
    "мастерка": ["олимпийка"],
    "мастеровав": ["мастеровавши"],
    "мастеровавши": ["мастеровав"],
    "мастеровой": ["рабочий"],
    "мастерок": ["кельма"],
    "мастерски": ["по-мастерски", "искусно", "умело", "виртуозно", "отменно", "ловко", "сноровисто", "мастеровито", "талантливо", "со знанием дела", "артистично", "филигранно"],
    "мастерской": ["умелый", "искусный"],
    "мастерство": ["профессия", "ремесло", "виртуозность"],
    "мастивши": ["мастив"],
    "мастиковый": ["мастичный"],
    "мастино": ["мастино-наполетано"],
    "мастино-наполетано": ["мастино"],
    "мастит": ["грудница"],
    "маститый": ["авторитетный", "заслуженный", "почтенный"],
    "мастить": ["умащать", "умащивать"],
    "мастиф": ["английский дог"],
    "мастичный": ["мастиковый"],
    "мастодиния": ["масталгия"],
    "мастопатия": ["фиброаденоматоз"],
    "мастор": ["страна", "свет"],
    "мастрячить": ["мастерить"],
    "мастурбатор": ["онанист", "рукоблудник", "дрочун", "дрочер"],
    "мастурбировав": ["мастурбировавши"],
    "мастурбировавши": ["мастурбировав"],
    "мастырить": ["мастерить", "замастыривать", "мастрячить"],
    "мастырка": ["мостырка"],
    "масштаб": ["размах", "охват"],
    "масштабировав": ["масштабировавши"],
    "масштабировавши": ["масштабировав"],
    "масштабируемость": ["расширяемость"],
    "масштабная инвариантность": ["скейлинг"],
    "масштабно": ["широко", "с размахом"],
    "масштабный": ["обширный", "значительный"],
    "матамата": ["бахромчатая черепаха", "мата-мата"],
    "матан": ["матанализ"],
    "матапан": ["тенарон"],
    "матбах": ["ошпазхона"],
    "матбой": ["математический бой"],
    "матвей": ["матфей"],
    "мателот": ["матлот"],
    "математизировав": ["математизировавши"],
    "математизировавши": ["математизировав"],
    "математика": ["матеша", "мат-ка"],
    "математица": ["математичка"],
    "математический анализ": ["матанализ", "матан", "муть-анализ"],
    "математическое ожидание": ["матожидание"],
    "математичка": ["математица"],
    "матерев": ["матеревши"],
    "матеревши": ["матерев"],
    "матереть": ["взрослеть"],
    "материал": ["вещество", "сырьё", "материя", "источник", "документ"],
    "материализовав": ["материализовавши"],
    "материализовавши": ["материализовав"],
    "материализовать": ["материализовывать", "воплощать", "воплотить", "овеществлять", "овеществить"],
    "материализоваться": ["воплотиться", "реализоваться"],
    "материализовывав": ["материализовывавши"],
    "материализовывавши": ["материализовывав"],
    "материалистически": ["по-материалистски", "по-материалистически"],
    "материалистичный": ["материалистический", "материалистский", "практичный", "узкопрактический"],
    "материально": ["вещественно", "денежно", "финансово"],
    "материальный": ["вещественный", "телесный", "физический", "денежный", "имущественный", "вещный"],
    "материв": ["материвши"],
    "материвши": ["материв"],
    "материковая кора": ["континентальная кора"],
    "материнская плата": ["мама", "мамка", "материнка", "мать"],
    "материнский капитал": ["маткапитал"],
    "материться": ["матерщинничать", "матюгаться", "матюкаться", "выражаться по матери", "выражаться нецензурными словами", "выражаться нецензурно", "нецензурно выражаться", "посылать по матери", "матерно выражаться", "обкладывать трёхэтажным матом"],
    "материя": ["субстанция", "материал", "ткань", "тема"],
    "матерник": ["матерщинник", "похабник", "мать-и-мачеха", "белокопытник"],
    "матернув": ["матернувши"],
    "матернувши": ["матернув"],
    "матернуться": ["матюгнуться", "матюкнуться"],
    "матерчатый": ["тканевый", "тряпочный"],
    "матерщина": ["матюк"],
    "матерщинница": ["матюгальница", "матюгальщица", "матюкальница", "матюкальщица"],
    "матерщинничав": ["матерщинничавши"],
    "матерщинничавши": ["матерщинничав"],
    "матерь": ["мать", "мати"],
    "матерьял": ["материал"],
    "матеша": ["математика"],
    "мати": ["матерь", "мать"],
    "матика": ["матеша"],
    "матинэ": ["утренник", "пеньюар"],
    "матировав": ["матировавши"],
    "матировавши": ["матировав"],
    "матирование": ["матировка"],
    "матка": ["чрево", "утроба", "самка", "мать", "мама", "матушка", "родительница", "тендер", "судно", "маточка", "компас"],
    "маткапитал": ["материнский капитал"],
    "матку наизнанку вывернуть": ["вытряхнуть из кителя", "растереть по переборке", "глаз на жопу натянуть", "из кителя вытряхнуть", "по переборке растереть", "сикель вырвать"],
    "матлет": ["матлот"],
    "матлот": ["мателот", "матлет"],
    "матница": ["сволок", "матица", "матка"],
    "матный": ["матерный"],
    "матовав": ["матовавши"],
    "матовавши": ["матовав"],
    "матовать": ["делать мат", "ставить мат", "объявлять мат"],
    "матожидание": ["математическое ожидание"],
    "маточка": ["матушка", "мамочка", "матка", "компас"],
    "матоъ": ["порча", "газвор"],
    "матрас": ["матрац"],
    "матрасник": ["наматрасник", "матрасовка"],
    "матрац": ["матрас"],
    "матриархат": ["гинекократия"],
    "матримониальный": ["брачный"],
    "матрица": ["массив"],
    "матрица перестановки": ["матрица подстановки"],
    "матрицировав": ["матрицировавши"],
    "матрицировавши": ["матрицировав"],
    "матричная рибонуклеиновая кислота": ["матричная рнк", "мрнк"],
    "матричная рнк": ["матричная рибонуклеиновая кислота", "информационная рнк", "ирнк"],
    "матроклинность": ["матроклиния"],
    "матроним": ["матчество"],
    "матросив": ["матросивши"],
    "матросивши": ["матросив"],
    "матсиендрасана": ["поза бога рыб"],
    "матсьясана": ["поза рыбы"],
    "маттиола": ["левкой"],
    "матушка": ["мать", "мама", "маманя", "мамаша", "бабуся", "бабушка", "монахиня", "монашенка", "попадья", "диакониха", "дьяконица", "богородица", "святая"],
    "матушки": ["батюшки"],
    "матфей": ["матвей"],
    "матч": ["встреча"],
    "матч-пойнт": ["матчбол"],
    "матча": ["маття"],
    "матчасть": ["имущество", "учебная дисциплина", "инструкция"],
    "матчбол": ["матч-пойнт"],
    "матчество": ["матроним"],
    "матчмейкинг": ["мэтчмейкинг"],
    "матывав": ["матывавши"],
    "матывавши": ["матывав"],
    "матылёк": ["матыль"],
    "мать": ["мама", "матушка", "родительница", "матерь", "маменька", "мамаша", "маманя", "матерёночка", "жена", "женщина"],
    "мать-и-мачеха": ["мать-мачеха", "белокопытник", "двоелистник", "камчужная трава", "лапуха студёная", "лопушник", "матерник", "мачеха", "мачехино лицо", "подбел"],
    "мать-мачеха": ["мать-и-мачеха", "подбел", "камчужная трава"],
    "матькивщина": ["батькивщина"],
    "матюгав": ["матюгавши"],
    "матюгавши": ["матюгав"],
    "матюгальник": ["рупор", "громкоговоритель", "радиорепродуктор", "брехунок", "мегафон"],
    "матюгальница": ["матерщинница", "матюгальщица", "матюкальница", "матюкальщица"],
    "матюгальщица": ["матерщинница", "матюгальница", "матюкальница", "матюкальщица"],
    "матюгать": ["матюкать"],
    "матюгаться": ["матюкаться"],
    "матюгнув": ["матюгнувши"],
    "матюгнувши": ["матюгнув"],
    "матюгнуть": ["матюкнуть"],
    "матюкав": ["матюкавши"],
    "матюкавши": ["матюкав"],
    "матюкальница": ["матюгальница", "матюгальщица", "матерщинница", "матюкальщица"],
    "матюкальщица": ["матюгальница", "матюгальщица", "матерщинница"],
    "матюкать": ["матюгать"],
    "матюкнув": ["матюкнувши"],
    "матюкнувши": ["матюкнув"],
    "матёрый": ["зрелый", "бывалый", "опытный", "искушённый", "тёртый", "отъявленный", "закоренелый"],
    "маунтинбайк": ["горный", "велосипед"],
    "мафик": ["мафиози", "мафиозник"],
    "мафиози": ["мафиозник", "мафик"],
    "мафиозник": ["мафиози", "мафик"],
    "мафист": ["мафиози", "мафиозник"],
    "мафический": ["мафитовый"],
    "мафия": ["коза ностра", "братва", "банда", "группировка", "шайка"],
    "мафон": ["магнитофон"],
    "мафорий": ["покров"],
    "махавши": ["махав"],
    "махагон": ["махагони"],
    "махагони": ["махагон"],
    "махадев": ["шива"],
    "махакальпа": ["махакалпа"],
    "махало": ["пугало"],
    "маханина": ["конина", "махан", "мясо"],
    "маханув": ["маханувши"],
    "маханувши": ["маханув"],
    "маханье": ["махание"],
    "махараджа": ["магараджа", "князь", "государь"],
    "махарани": ["магарани"],
    "махать": ["размахивать"],
    "махач": ["махаловка", "махалово", "драка", "свалка", "потасовка"],
    "махачкала": ["петровск-порт"],
    "махаюга": ["юга"],
    "махая": ["маша"],
    "махзан": ["анборча"],
    "махивав": ["махивавши"],
    "махивавши": ["махивав"],
    "махивать": ["помахивать"],
    "махизм": ["эмпириокритицизм"],
    "махина": ["громадина", "дылда"],
    "махинатор": ["ловкач", "аферист"],
    "махинация": ["афера"],
    "махлевав": ["махлевавши"],
    "махлевавши": ["махлевав"],
    "махлевать": ["жульничать", "плутовать", "мошенничать"],
    "махлюя": ["мухлюя"],
    "махляр": ["аферист", "дурилюд", "крутар", "ловкач", "махляй", "ошуканець", "проноза", "шахрай"],
    "махмурлук": ["препиване"],
    "махнув": ["махнувши"],
    "махнувши": ["махнув"],
    "махнуть": ["взмахнуть", "броситься", "кинуться", "ринуться", "сигануть", "рвануть", "податься", "поехать", "отправиться", "обменять", "сменять"],
    "махо": ["махос", "франт"],
    "маховик": ["гироскоп", "волчок", "штурвал", "вентиль"],
    "махолёт": ["орнитоптер"],
    "махонький": ["маленький", "крохотный"],
    "махорка": ["рубанка", "сборка", "серебрянка", "бакун", "тютюн", "папушник", "самосад", "анаша", "марихуана", "драп", "варенье", "цветочек"],
    "махос": ["махо", "франт"],
    "махровев": ["махровевши"],
    "махровевши": ["махровев"],
    "махровый": ["мохнатый", "отъявленный"],
    "махълъэ": ["махъулъэ"],
    "мацав": ["мацавши"],
    "мацавши": ["мацав"],
    "мацать": ["щупать", "лапать", "лапаться", "обнимать", "мять", "цапкать", "жамкать", "тереть"],
    "мацерировав": ["мацерировавши"],
    "мацерировавши": ["мацерировав"],
    "мацеровав": ["мацеровавши"],
    "мацеровавши": ["мацеровав"],
    "мацони": ["мацун"],
    "мацонщик": ["молочник"],
    "мацун": ["мацони"],
    "мачетеро": ["рубака"],
    "мачеха": ["мать-и-мачеха"],
    "мачехино лицо": ["мать-и-мачеха", "белокопытник", "двоелистник", "камчужная трава", "лапуха студёная", "лопушник", "матерник", "мачеха", "подбел"],
    "мачивав": ["мачивавши"],
    "мачивавши": ["мачивав"],
    "мачо": ["мужлан"],
    "мачта": ["машта"],
    "мачта-антенна": ["антенна-мачта"],
    "маш": ["шереметьево"],
    "машварат": ["панд"],
    "машенька": ["маша", "машуня", "машуля", "мария"],
    "машиах": ["мошиах"],
    "машинально": ["безотчётно", "непроизвольно", "бессознательно", "на автомате", "на автопилоте"],
    "машинальный": ["безотчётный", "непроизвольный", "бессознательный", "невольный"],
    "машинизировав": ["машинизировавши"],
    "машинизировавши": ["машинизировав"],
    "машинизировать": ["механизировать", "обездушивать"],
    "машинист": ["механик"],
    "машинистка": ["наборщица"],
    "машинка": ["шприц"],
    "машинно-читаемый словарь": ["машиночитаемый словарь"],
    "машинный": ["механический", "автоматический"],
    "машинный зал": ["машзал"],
    "машинный перевод": ["машперевод"],
    "машинозависимый": ["многоплатформенный"],
    "машиночитаемый словарь": ["машинно-читаемый словарь"],
    "машисто": ["широким шагом"],
    "машта": ["мачта"],
    "маштомс": ["аделавомс", "ётамс", "шумордавомс", "прядовомс", "карьхцявомс", "юмамс", "ацендемс"],
    "машуня": ["маша", "мария"],
    "мащаб": ["пропорция", "мярка", "степен", "мерило"],
    "мащення": ["мазання"],
    "мащивав": ["мащивавши"],
    "мащивавши": ["мащивав"],
    "маълумот": ["иттилоот", "ахборот", "хабар"],
    "маэмай": ["эт"],
    "маюрасана": ["поза павлина", "поза вороны"],
    "маяв": ["маявши"],
    "маявши": ["маяв"],
    "маякнув": ["маякнувши"],
    "маякнувши": ["маякнув"],
    "маянье": ["маяние"],
    "маять": ["мучить", "изнурять", "утомлять"],
    "маяться": ["не находить себе места", "мучиться"],
    "маячащий": ["мелькающий"],
    "маячив": ["маячивши"],
    "маячивши": ["маячив"],
    "маячить": ["показываться", "мельтешить", "мелькать", "надоедать", "предвидеться", "ожидаться", "махать", "намекать", "жестикулировать"],
    "маёвничав": ["маёвничавши"],
    "маёвничавши": ["маёвничав"],
    "мбр": ["межконтинентальная баллистическая ракета"],
    "мв-печь": ["микроволновая печь", "микроволновка", "свч-печь"],
    "мвту": ["мгту"],
    "мгла": ["мрак", "тьма", "темнота"],
    "мгновение": ["миг", "момент", "секунда", "мгновенье"],
    "мгновение ока": ["миг", "мгновение"],
    "мгновенно": ["внезапно", "моментально", "тотчас", "молниеносно"],
    "мгновенность": ["моментальность"],
    "мгновенный": ["немедленный", "молниеносный", "моментальный"],
    "мгновенье": ["мгновение", "миг"],
    "мгту": ["мруз", "имту", "мвту", "ммму", "ммми", "бауманка"],
    "мдф": ["плита мдф"],
    "меандр": ["большой мендерес", "бююк-мендерес", "меандрос"],
    "меандрировав": ["меандрировавши"],
    "меандрировавши": ["меандрировав"],
    "меандрирование": ["меандр", "излучина", "извилина", "лука", "колено"],
    "меандрировать": ["изгибаться"],
    "мебель": ["обстановка", "магазин мебели", "пустышка"],
    "мебельный щит": ["сращённый мебельный щит", "клеёный мебельный щит"],
    "меблировав": ["меблировавши"],
    "меблировавши": ["меблировав"],
    "меблированные комнаты": ["меблирашка"],
    "меблировка": ["меблирование", "мебель", "обстановка"],
    "мева": ["бар", "самар"],
    "мег": ["мегабайт", "метр"],
    "мега-": ["сверх-"],
    "мегаантиклинорий": ["мегантиклинорий"],
    "мегабайт": ["мбайт", "мег", "метр", "мебибайт"],
    "мегабайтный": ["мегабайтовый"],
    "мегабайтовый": ["мегабайтный"],
    "мегагерц": ["мегацикл", "мгц"],
    "мегаграмм": ["тонна"],
    "мегазвезда": ["суперзвезда"],
    "мегалография": ["макрография"],
    "мегаломания": ["мания величия", "бред величия"],
    "мегалополис": ["мегаполис"],
    "мегамир": ["макромир"],
    "мегамост": ["мостище"],
    "мегаомметр": ["мегометр", "мегомметр", "меггер"],
    "мегаполис": ["мегалополис"],
    "мегара": ["мегары"],
    "мегары": ["мегара"],
    "мегаспорофилл": ["макроспорофилл"],
    "мегафон": ["матюгальник", "бубнильник", "орало", "акустический", "рупор", "труба", "громкоговоритель"],
    "мегацикл": ["мегахрон"],
    "мегаэра": ["надэра", "эон"],
    "меггер": ["мегаомметр", "мегомметр", "мегометр"],
    "мегдан": ["площад", "сборище", "пазарище", "пазар", "чаршия"],
    "мегера": ["стерва", "фурия", "гарпия"],
    "мегометр": ["мегаомметр", "мегомметр", "меггер"],
    "мегомметр": ["мегаомметр", "мегометр", "меггер"],
    "мегрел": ["мингрел", "мингрелец"],
    "мед": ["медвуз", "мединститут", "медуниверситет"],
    "медаль": ["орден"],
    "медальон": ["камея", "кулон"],
    "медбрат": ["медицинский брат"],
    "медведесобака": ["амфиционид"],
    "медведиха": ["медведица"],
    "медведица": ["медведиха"],
    "медведь": ["мишка", "топтыгин", "косолапый", "красный зверь", "увалень", "шортист"],
    "медведь-губач": ["губач"],
    "медвежатник": ["шниффер"],
    "медвежатничав": ["медвежатничавши"],
    "медвежатничавши": ["медвежатничав"],
    "медвежачий": ["медвежий"],
    "медвежий угол": ["глушь", "глухомань", "захолустье", "дыра", "пердь", "тьмутаракань"],
    "медвяная роса": ["медовая роса"],
    "медвяные росы": ["иван-гусятник", "завистник птиц", "худые росы", "иван головастый", "иванов день", "иоанн предтеча", "ферапонтовская роса", "ферапонт"],
    "медвяный": ["медовый", "паточный", "слащавый", "сладкий", "хмельной", "жёлтый", "золотисто-жёлтый", "янтарный", "ароматный", "сладковатый", "сладостный", "сладкозвучный"],
    "медиа": ["массмедиа", "средства массовой информации", "сми"],
    "медиабарон": ["медиамагнат", "медиаимператор", "медиакороль", "медиаолигарх"],
    "медиагруппа": ["медиаконгломерат", "медиаконцерн", "медиакорпорация", "медиахолдинг"],
    "медиаизмерение": ["медиаисследование", "медиаметрия"],
    "медиаимператор": ["медиамагнат", "медиабарон", "медиакороль", "медиаолигарх"],
    "медиаискусство": ["медиаарт"],
    "медиаисследование": ["медиаизмерение", "медиаметрия"],
    "медиаконгломерат": ["медиагруппа", "медиаконцерн", "медиакорпорация", "медиахолдинг"],
    "медиаконтейнер": ["мультимедиаконтейнер"],
    "медиаконцерн": ["медиагруппа", "медиаконгломерат", "медиакорпорация", "медиахолдинг"],
    "медиакороль": ["медиамагнат", "медиабарон", "медиаимператор", "медиаолигарх"],
    "медиакорпорация": ["медиагруппа", "медиаконгломерат", "медиаконцерн", "медиахолдинг"],
    "медиальный залог": ["медий", "средний залог", "возвратный залог"],
    "медиамагнат": ["медиабарон", "медиаимператор", "медиакороль", "медиаолигарх"],
    "медиаметрия": ["медиаизмерение", "медиаисследование"],
    "медиаолигарх": ["медиамагнат", "медиабарон", "медиаимператор", "медиакороль"],
    "медиапланер": ["медиапланировщик"],
    "медиапланировщик": ["медиапланер"],
    "медиапроигрыватель": ["проигрыватель", "медиаплеер", "плеер"],
    "медиапространство": ["медиасфера"],
    "медиаселлер": ["селлер"],
    "медиасообщение": ["медиатекст"],
    "медиасфера": ["медиапространство"],
    "медиатекст": ["медиасообщение"],
    "медиатор": ["плектр"],
    "медиафраншиза": ["франшиза"],
    "медиахолдинг": ["медиагруппа", "медиаконгломерат", "медиаконцерн", "медиакорпорация"],
    "медиевалист": ["медиевист"],
    "медиевалистический": ["медиевалистский", "медиевальный"],
    "медиевалистский": ["медиевалистический"],
    "медий": ["медиум"],
    "медик": ["врач", "доктор", "лекарь", "эскулап"],
    "медикамент": ["лекарство", "лекарственное средство", "препарат"],
    "медикаментозный": ["лекарственный"],
    "медина": ["ясриб", "ятриб"],
    "медиобазальный": ["туберальный"],
    "медиолан": ["милан"],
    "медитативный": ["созерцательный"],
    "медитация": ["медитирование"],
    "медитировав": ["медитировавши"],
    "медитировавши": ["медитировав"],
    "медиум": ["спиритуалист"],
    "медицинская работница": ["медработница"],
    "медицинская сестра": ["медсестра", "сестра милосердия", "медичка"],
    "медицинский брат": ["медбрат"],
    "медицинский институт": ["мединститут", "мед"],
    "медицинский персонал": ["медперсонал"],
    "медленно": ["не спеша", "неспешно", "потихоньку", "тихо"],
    "медленноварка": ["тиховарка"],
    "медленный": ["медлительный", "неспешный", "неторопливый", "тихий"],
    "медлив": ["медливши"],
    "медливши": ["медлив"],
    "меднив": ["меднивши"],
    "меднивши": ["меднив"],
    "медник": ["лудильщик"],
    "медно-красный": ["меднокрасный"],
    "медоваренный": ["медоварный"],
    "медоварный": ["медоваренный"],
    "медовая роса": ["медвяная роса"],
    "медовый камень": ["меллит"],
    "медоед": ["лысый барсук", "ратель"],
    "медон": ["мёдон"],
    "медонос": ["нектаронос"],
    "медоносив": ["медоносивши"],
    "медоносивши": ["медоносив"],
    "медорганизация": ["медучреждение"],
    "медосбор": ["взяток"],
    "медоточив": ["медоточивши"],
    "медоточиво": ["неискренне", "елейно"],
    "медоточивши": ["медоточив"],
    "медперсонал": ["медицинский персонал"],
    "медпрепарат": ["лекарство"],
    "медработник": ["медик"],
    "медработница": ["медичка"],
    "медрота": ["медицинская рота"],
    "медсестра": ["медицинская сестра", "сестра милосердия"],
    "медуница": ["лёгочница", "пульмонария"],
    "медучреждение": ["медорганизация"],
    "медянка": ["медяница", "веретеница"],
    "меж": ["между"],
    "меж-": ["междо-", "между-"],
    "межа": ["рубеж", "граница", "раздел", "предел", "грань", "стык"],
    "межведомственный": ["междуведомственный"],
    "межвидовой": ["междувидовой"],
    "межвременной": ["интертемпоральный"],
    "межгород": ["междугородка"],
    "межгорье": ["междугорье"],
    "межгосударственный": ["международный"],
    "междина": ["разстояние", "отстояние", "среда", "промеждутък", "интервал"],
    "междо-": ["интер-", "меж-", "между-"],
    "междометие": ["междуметие"],
    "междометье": ["междометие"],
    "междоусобие": ["междоусобица"],
    "междоусобица": ["междоусобие"],
    "междоусобный": ["междуусобный"],
    "междоусобье": ["междоусобие"],
    "между": ["помежду"],
    "между молотом и наковальней": ["между сциллой и харибдой", "между двух огней", "меж двух огней"],
    "между собой": ["между собою", "друг с другом", "тет-а-тет", "с глазу на глаз"],
    "между сциллой и харибдой": ["между молотом и наковальней", "между двух огней"],
    "между тем": ["при этом", "в это время", "в то же время", "тогда как", "в то время как"],
    "между-": ["интер-", "меж-", "междо-"],
    "междувидовой": ["межвидовой"],
    "междугородка": ["межгород"],
    "междугородный": ["междугородний"],
    "междугорье": ["межгорье"],
    "междуметие": ["междометие"],
    "международный": ["интернациональный"],
    "международный валютный фонд": ["мвф"],
    "международный женский день": ["восьмое марта"],
    "международный комитет красного креста": ["мккк"],
    "международный фонетический алфавит": ["мфа"],
    "междупарье": ["межпарье"],
    "междупланетный": ["межпланетный"],
    "междуплеменной": ["межплеменной"],
    "междурёберный": ["межрёберный"],
    "междуселенный": ["межселенный"],
    "междусобой": ["междусобойчик"],
    "междустрочный": ["межстрочный"],
    "междуфазный": ["межфазный", "межфазовый"],
    "междуцарствие": ["межцарствие", "межначалие"],
    "междуцеховый": ["межцеховой"],
    "междуэлектродный": ["межэлектродный"],
    "межевав": ["межевавши"],
    "межевавши": ["межевав"],
    "межевание": ["кадастрирование"],
    "межеванье": ["межевание"],
    "межевать": ["размежёвывать", "разграничивать"],
    "межзаводской": ["межзаводский"],
    "межзубный": ["интердентальный"],
    "межив": ["меживши"],
    "меживши": ["межив"],
    "межклеточный": ["межклетный"],
    "межконтинентальная баллистическая ракета": ["мбр"],
    "межконтинентальный": ["трансконтинентальный"],
    "межконфессиональный": ["межрелигиозный"],
    "межледниковье": ["интергляциал"],
    "межматериковый": ["междуматериковый"],
    "межносовой": ["лобоносовой"],
    "межоконный": ["междуоконный"],
    "межпалубный": ["междупалубный"],
    "межпланетарный": ["межпланетный"],
    "межпланетный": ["междупланетный", "межпланетарный"],
    "межплеменной": ["междуплеменной"],
    "межпозвоночный": ["интервертебральный"],
    "межпозвоночный диск": ["межпозвонковый диск"],
    "межрасовый": ["межэтнический"],
    "межрегионал": ["межрегиональщик"],
    "межрегиональщик": ["межрегионал"],
    "межрелигиозный": ["межконфессиональный"],
    "межрёберный": ["междурёберный"],
    "межсезонный": ["демисезонный"],
    "межселенный": ["междуселенный"],
    "межславянский язык": ["межславянский"],
    "межстрановой": ["межгосударственный"],
    "межстрочный": ["междустрочный"],
    "межтечка": ["диэструс"],
    "межфазный": ["междуфазный", "межфазовый"],
    "межфазовый": ["междуфазный", "межфазный"],
    "межцарствие": ["междуцарствие", "межначалие"],
    "межцентровой": ["межцентровый"],
    "межцентровый": ["межцентровой"],
    "межцеховой": ["междуцеховый"],
    "мезаденит": ["мезентерит"],
    "мезак": ["шоша", "бавл", "пешоб"],
    "мездрив": ["мездривши"],
    "мездривши": ["мездрив"],
    "мездряной": ["мездровый"],
    "мезе-бъди": ["кати-мезе"],
    "мезентеральный": ["мезентерический", "брыжеечный"],
    "мезентерий": ["брыжейка"],
    "мезенхимальный": ["мезенхимный"],
    "мезиальный": ["медиальный"],
    "мезил": ["метилсульфонил"],
    "мезоамерика": ["месоамерика"],
    "мезоатом": ["мезонный атом"],
    "мезозоида": ["киммерида"],
    "мезозой": ["мезозойская эра"],
    "мезозойская эра": ["мезозой"],
    "мезокефал": ["мезоцефал"],
    "мезокефалия": ["мезоцефалия"],
    "мезолит": ["средний каменный век"],
    "мезоморф": ["нормостеник"],
    "мезонефрос": ["вольфово тело", "почка первичная", "почка средняя", "почка туловищная"],
    "мезонин": ["полуярус"],
    "мезообъект": ["макрообъект"],
    "мезориния": ["средненосость"],
    "мезосомный": ["промежуточный"],
    "мезотрон": ["мюон", "мю-мезон", "мезон"],
    "мезофаринкс": ["ротоглотка"],
    "мезофилл": ["паренхима"],
    "мезоцефал": ["мезокефал"],
    "мезоцефалия": ["мезокефалия"],
    "мейва": ["махсул"],
    "мейкап": ["косметика", "макияж", "грим"],
    "мейнстримный": ["мейнстримовский"],
    "мейнстримовский": ["мейнстримный"],
    "мейнфрейм": ["мэйнфрейм"],
    "мейозис": ["литота"],
    "мейрам": ["мереке"],
    "мейстерзанг": ["мейстерзингер"],
    "мейстерзингер": ["мейстерзанг"],
    "мекав": ["мекавши"],
    "мекавши": ["мекав"],
    "мекенчил": ["атуул"],
    "мекнув": ["мекнувши"],
    "мекнувши": ["мекнув"],
    "мекнуть": ["мемекнуть"],
    "меколи": ["меле", "сяда меле", "оду", "сяльде", "мекпяли"],
    "меконий": ["кал"],
    "мекпяли": ["сяльде", "меле", "сяда меле", "оду"],
    "мекс": ["мексикашка", "мексикос"],
    "мексика": ["мексиканские соединённые штаты"],
    "мексикано-американец": ["чикано"],
    "мексиканские соединённые штаты": ["мексика"],
    "мексикашка": ["мекс"],
    "мел": ["мелок", "меловой период", "кокос", "иней"],
    "меламиновый": ["меламинный"],
    "меланинный": ["меланиновый"],
    "меланиновый": ["меланинный"],
    "меланобластома": ["меланома", "меланокарцинома", "меланоцитома"],
    "меланоз": ["меланизм", "меланопатия"],
    "меланокарцинома": ["меланома", "меланобластома", "меланоцитома"],
    "меланома": ["меланобластома", "меланокарцинома", "меланоцитома", "меланосаркома"],
    "меланотропин": ["меланоцитостимулирующий", "гормон"],
    "меланоцитома": ["меланома", "меланобластома", "меланокарцинома"],
    "мелантерит": ["железный купорос"],
    "меланхолически": ["меланхолично"],
    "меланхолический": ["меланхоличный", "грустный", "унылый"],
    "меланхолично": ["меланхолически"],
    "меланхоличный": ["меланхолический", "грустный", "унылый"],
    "меланхолия": ["тоска", "хандра", "сплин", "депрессия", "подавленность"],
    "меланхольный": ["меланхоличный", "меланхолический"],
    "меле": ["сяда меле", "оду", "сяльде", "мекпяли"],
    "мелев": ["мелевши"],
    "мелевши": ["мелев"],
    "меледа": ["нуда", "рутина"],
    "мелекс": ["гольфкар", "электрокар"],
    "мелеть": ["мельчать"],
    "мелив": ["меливши"],
    "меливши": ["мелив"],
    "мелизматический": ["пападический"],
    "мелинит": ["тринитрофенол", "пикриновая кислота", "лидит", "пикринит"],
    "мелиоотряд": ["мелиоративный", "отряд"],
    "мелиорант": ["удобрение"],
    "мелиорационный": ["мелиоративный"],
    "мелиорировав": ["мелиорировавши"],
    "мелиорировавши": ["мелиорировав"],
    "мелиорирование": ["мелиорация"],
    "мелиорировать": ["окультуривать", "окультурить", "оздоровлять", "оздоровить"],
    "мелипрамин": ["имипрамин"],
    "мелировав": ["мелировавши"],
    "мелировавши": ["мелировав"],
    "мелисса": ["лимонная мята"],
    "мелиссан": ["триаконтан"],
    "мелиссовая кислота": ["триаконтановая кислота"],
    "мелиссовый": ["триаконтановый"],
    "мелитоза": ["рафиноза", "мелицитоза", "мелитриоза", "госсипоза"],
    "мелитриоза": ["рафиноза", "мелицитоза", "мелитоза", "госсипоза"],
    "мелицитоза": ["рафиноза", "мелитоза", "мелитриоза"],
    "мелкий": ["маленький", "малый", "небольшой", "малочисленный", "частый", "дробный", "некрупный", "маломощный", "неродовитый", "простой", "обыкновенный", "малозначительный", "незначительный", "невлиятельный", "малозначимый"],
    "мелкий рогатый скот": ["мрс"],
    "мелковатый": ["маловатый", "некрупный", "неглубокий"],
    "мелководный": ["мелкий"],
    "мелководье": ["маловодье"],
    "мелкодисперсность": ["мелкость"],
    "мелкодисперсный": ["высокодисперсный", "тонкодисперсный"],
    "мелкозубчатый": ["мелкозубый"],
    "мелкозубый": ["мелкозубчатый"],
    "мелкокалиберный": ["малокалиберный"],
    "мелкоколосистый": ["мелкоколосный", "мелкоколосый", "мелкоколостный"],
    "мелкоколосный": ["мелкоколосый", "мелкоколосистый", "мелкоколостный"],
    "мелкоколосый": ["мелкоколосный", "мелкоколосистый", "мелкоколостный"],
    "мелколесье": ["подлесок", "подлесье"],
    "мелкопоместный": ["малопоместный"],
    "мелкопроблемный": ["мелкотемный"],
    "мелкоскоп": ["микроскоп"],
    "мелкочешуйчатый": ["мелкочешуйный"],
    "мелкошёрстный": ["короткошёрстный", "короткошёрстый", "мелкошёрстый"],
    "мелкошёрстый": ["короткошёрстный", "короткошёрстый", "мелкошёрстный"],
    "мелкоячеистый": ["мелкоячейный", "мелкоячейковый"],
    "мелкоячейковый": ["мелкоячеистый", "мелкоячейный"],
    "мелкоячейный": ["мелкоячеистый"],
    "меллит": ["медовый камень"],
    "меловав": ["меловавши"],
    "меловавши": ["меловав"],
    "меловой период": ["мел"],
    "мелодекламировав": ["мелодекламировавши"],
    "мелодекламировавши": ["мелодекламировав"],
    "мелодически": ["мелодично", "благозвучно"],
    "мелодично": ["благозвучно"],
    "мелодия": ["напев", "голос"],
    "мелодраматичный": ["мелодраматический"],
    "мелок": ["мел", "восковой мелок", "полимерный карандаш"],
    "мелочив": ["мелочивши"],
    "мелочивши": ["мелочив"],
    "мелочной": ["мелкий", "мелочный"],
    "мелочность": ["незначительность", "несерьёзность", "ничтожность", "крохоборство", "буквоедство", "ерундовость", "мелкотравчатость", "мелкость", "чепуховость", "придирчивость", "суетность", "частность", "смехотворность", "малосущественность", "крохоборчество"],
    "мелочовка": ["мелочёвка", "мелочь", "пустяки"],
    "мелочь": ["мелюзга", "копейка", "пустяк", "ерунда", "безделица"],
    "мелочёвка": ["мелочь", "пустяки"],
    "мель": ["мелководье", "мелкое место", "банка", "перекат"],
    "мельдоний": ["милдронат"],
    "мельзавод": ["мелькомбинат"],
    "мелькав": ["мелькавши"],
    "мелькавши": ["мелькав"],
    "мельканье": ["мелькание"],
    "мелькарт": ["меликерт", "геракл"],
    "мелькать": ["мельтешить"],
    "мелькнув": ["мелькнувши"],
    "мелькнувши": ["мелькнув"],
    "мельком": ["между прочим", "наскоро", "беглый", "штрих", "на бегу", "на лету"],
    "мелькомбинат": ["мельзавод"],
    "мельник": ["мукомол"],
    "мельница": ["кофемолка"],
    "мельничав": ["мельничавши"],
    "мельничавши": ["мельничав"],
    "мельтешенье": ["мельтешение"],
    "мельтешив": ["мельтешивши"],
    "мельтешивши": ["мельтешив"],
    "мельтешить": ["мельтешиться", "суетиться", "мелькать", "лебезить"],
    "мельтешня": ["мельтешение"],
    "мельчав": ["мельчавши"],
    "мельчавши": ["мельчав"],
    "мельчайший": ["малейший"],
    "мельчать": ["мелеть"],
    "мельче": ["меньше"],
    "мельчив": ["мельчивши"],
    "мельчивши": ["мельчив"],
    "мельчить": ["измельчать"],
    "мелюзга": ["мелкий", "маленький", "ничтожный"],
    "мем": ["интернет-мем", "мемас", "мемес"],
    "мемас": ["интернет-мем", "мемес"],
    "мембрана": ["плёнка", "перепонка", "перегородка", "стенка", "пластина", "кожица", "оболочка", "диафрагма"],
    "мембранний": ["мембрановий"],
    "мемекав": ["мемекавши"],
    "мемекавши": ["мемекав"],
    "мемекнув": ["мемекнувши"],
    "мемекнувши": ["мемекнув"],
    "мемес": ["интернет-мем", "мемас"],
    "мемлекет": ["ел"],
    "мемориал": ["мемориальный комплекс", "мемориальные соревнования", "дневник", "записки", "записи", "доклад", "отчёт", "рапорт", "донесение", "докладная", "докладная записка", "служебная записка", "служебное донесение", "петиция", "прошение"],
    "мемос": ["мемас", "мемес"],
    "мемуар": ["воспоминание", "отчёт", "сборник"],
    "мемуары": ["воспоминание", "хроника"],
    "мена": ["замена", "смена", "обмен", "бартер"],
    "менада": ["вакханка"],
    "менажерия": ["зверилница"],
    "менажировав": ["менажировавши"],
    "менажировавши": ["менажировав"],
    "менди": ["мехенди"],
    "менеджер": ["управляющий", "руководитель", "манагер"],
    "менеджер по продажам": ["продажник"],
    "менеджировав": ["менеджировавши"],
    "менеджировавши": ["менеджировав"],
    "менеджмент": ["управление", "искусство управления", "руководство"],
    "менее": ["меньше"],
    "менестрель": ["трубадур", "трувер", "миннезингер"],
    "менжевав": ["менжевавши"],
    "менжевавши": ["менжевав"],
    "менжевать": ["пугаться", "страшиться", "бояться", "усираться"],
    "менжеваться": ["дрейфить"],
    "менивав": ["менивавши"],
    "менивавши": ["менивав"],
    "менопауза": ["климакс"],
    "меноррагия": ["гиперменорея"],
    "менструация": ["месячные", "регулы", "дни красной луны", "красные дни календаря", "критические дни", "течка", "эти дни", "гости", "месячина"],
    "менструировав": ["менструировавши"],
    "менструировавши": ["менструировав"],
    "мент": ["мусор", "милиционер", "полицейский"],
    "менталист": ["психоаналитик", "ясновидящий", "ясновидец", "ясновидица"],
    "менталитет": ["ментальность", "образ мышления", "характер"],
    "менталочка": ["ментальное здоровье", "психическое здоровье"],
    "ментальное здоровье": ["психическое здоровье"],
    "ментальное расстройство": ["душевная болезнь"],
    "ментальность": ["менталитет", "мироощущение", "мировоззрение"],
    "ментальный": ["умственный", "мыслительный", "интеллектуальный", "психический"],
    "ментовоз": ["ментовозка", "мусоровоз"],
    "ментовозка": ["ментовоз", "мусоровоз"],
    "ментовский": ["милицейский", "ментовской"],
    "ментовской": ["ментовский", "милицейский"],
    "ментор": ["наставник", "воспитатель", "учитель"],
    "менторинг": ["менторство"],
    "менторски": ["нравоучительно", "поучающе"],
    "менторский": ["наставнический", "нравоучительный", "назидательный", "поучающий"],
    "менторствовав": ["менторствовавши"],
    "менторствовавши": ["менторствовав"],
    "менторствовать": ["поучать"],
    "ментура": ["милиция", "легавка", "ментовка", "ментовская", "ментхауз", "мусарня", "мусорка"],
    "ментцелия": ["бартония"],
    "мень": ["налим"],
    "меньжеваться": ["колебаться"],
    "меньшевиствовав": ["меньшевиствовавши"],
    "меньшевиствовавши": ["меньшевиствовав"],
    "меню": ["диета"],
    "меняв": ["менявши"],
    "менявши": ["меняв"],
    "меняла": ["обменщик"],
    "менять": ["обменивать", "выменивать", "заменять", "сменять", "замещать", "преобразовывать", "изменять", "модифицировать", "разменивать"],
    "менять рыло на рыло": ["менять шило на мыло"],
    "менять шило на мыло": ["менять рыло на рыло", "менять шило на свайку", "шило на мыло менять"],
    "меняться": ["изменяться", "модифицироваться", "претерпевать изменение", "обмениваться", "сменяться", "заменяться", "вымениваться"],
    "меняющий": ["изменяющий"],
    "меония": ["лидия", "ликия"],
    "меотида": ["азовское море"],
    "меотский": ["меотийский"],
    "мепакрин": ["акрихин"],
    "мера": ["единица", "соразмерность", "баланс", "мерка", "средство", "мероприятие"],
    "мераге": ["мерага", "марага"],
    "мерак": ["влечение", "увлечение", "стремеж", "ламтеж", "желание"],
    "мергелевый": ["мергельный"],
    "мергель": ["рухляк"],
    "мергельный": ["мергелевый"],
    "мережати": ["мережити"],
    "мережити": ["мережати"],
    "мерекав": ["мерекавши"],
    "мерекавши": ["мерекав"],
    "мерекать": ["мозговать", "думать", "соображать", "размышлять", "мараковать"],
    "меренга": ["безе"],
    "мереть": ["помирать", "подыхать", "издыхать", "лишаться жизни", "отдавать богу душу", "преставляться", "испускать дух", "переходить в мир иной", "отходить", "давать дуба", "замирать"],
    "мерехлюндия": ["хандра", "уныние", "меланхолия", "грусть", "печаль"],
    "мерещиться": ["грезиться", "представляться", "чудиться", "казаться"],
    "мерзавец": ["подлец", "негодяй", "поганец", "гад", "подонок", "отморозок", "мразь", "мерзотник"],
    "мерзавчик": ["мерзавец"],
    "мерзев": ["мерзевши"],
    "мерзевши": ["мерзев"],
    "мерзив": ["мерзивши"],
    "мерзивши": ["мерзив"],
    "мерзкий": ["гадкий", "мерзопакостный", "омерзительный", "отвратительный", "похабный", "противный", "дрянной", "поганый"],
    "мерзко": ["гадко", "омерзительно", "отвратительно"],
    "мерзловатый": ["холодноватый"],
    "мерзлота": ["криолитозона"],
    "мерзлотоведение": ["геокриология"],
    "мерзлявый": ["зябкий"],
    "мерзнути": ["мерзти"],
    "мерзопакостный": ["гадкий", "мерзкий"],
    "мерзостно": ["мерзко"],
    "мерзость": ["гадость", "отвратительность", "дрянь"],
    "мерзота": ["гадость"],
    "мерзотник": ["мерзавец", "мразь"],
    "мерзотный": ["мерзкий"],
    "мерив": ["меривши"],
    "меривав": ["меривавши"],
    "меривавши": ["меривав"],
    "меривши": ["мерив"],
    "мерильщик": ["мерщик"],
    "мериносный": ["мериносовый"],
    "мериносовый": ["мериносный"],
    "мерительный": ["мерильный"],
    "меритировав": ["меритировавши"],
    "меритировавши": ["меритировав"],
    "меритократия": ["ноократия", "технократия"],
    "мерить": ["измерять", "замерять", "примерять", "примеривать"],
    "меркантилизм": ["меркантильность", "торгашество", "утилитаризм"],
    "меркантильность": ["своекорыстие", "меркантилизм"],
    "меркантильный": ["торговый", "коммерческий", "расчётливый", "промышленный", "купеческий", "торгашеский", "мелочный", "скупой"],
    "меркаптан": ["тиол"],
    "меркаптобензол": ["тиофенол"],
    "меркать": ["меркнуть"],
    "мерклый": ["тусклый", "померкший"],
    "меркнув": ["меркнувши"],
    "меркнувши": ["меркнув"],
    "меркнути": ["меркти"],
    "меркурий": ["гермес"],
    "мерлан": ["мерланг"],
    "мерлин": ["шванномин"],
    "мерлушечий": ["мерлушковый", "смушковый"],
    "мерник": ["мерничий"],
    "мерно": ["размеренно"],
    "мерный": ["размеренный", "ритмичный", "измерительный"],
    "мерный стакан": ["мензурка"],
    "мерокриновый": ["мерокринный"],
    "мероним": ["партоним"],
    "мероприятие": ["мероприятье", "шаг", "мера", "инициатива", "действие", "кампания"],
    "мероэ": ["куш", "мероитское царство"],
    "мерседес": ["мерседес-бенц", "мерс", "мерин"],
    "мерсеризировав": ["мерсеризировавши"],
    "мерсеризировавши": ["мерсеризировав"],
    "мерсеризовав": ["мерсеризовавши"],
    "мерсеризовавши": ["мерсеризовав"],
    "мерси": ["спасибо", "благодарить", "хорошо", "удачно"],
    "мертвев": ["мертвевши"],
    "мертвевши": ["мертвев"],
    "мертвенно": ["безжизненно"],
    "мертвенно-бледный": ["синеватый", "синевато-бледный", "иссиня-бледный", "пергаментный"],
    "мертветь": ["отмирать", "умирать", "цепенеть", "неметь", "костенеть", "застывать", "пустеть", "угасать"],
    "мертвец": ["покойник", "мёртвый", "умерший", "усопший", "почивший", "опочивший", "упокойник"],
    "мертвецкая": ["покойницкая", "морг", "трупарня"],
    "мертвець": ["мрець", "мертвий", "померлий", "умерлий", "мерлий", "мертвяк", "порох", "прах"],
    "мертвечина": ["падаль", "дохлятина", "стерва"],
    "мертвив": ["мертвивши"],
    "мертвивши": ["мертвив"],
    "мертвить": ["убивать", "губить"],
    "мертвоград": ["некрополь"],
    "мертвяк": ["мертвец", "покойник", "трупак"],
    "мертвятина": ["мертвечина", "падаль", "дохлятина"],
    "мерти": ["умирати", "гинути", "завмирати"],
    "мерцав": ["мерцавши"],
    "мерцавши": ["мерцав"],
    "мерцание": ["мерцанье"],
    "мерцанье": ["мерцание"],
    "мерцать": ["блистать", "мигать", "вибрировать"],
    "мерч": ["мерчандайз", "мерчендайз"],
    "мерчандайзинг": ["товароведение"],
    "мерчендайзинг": ["мерчандайзинг"],
    "мерщик": ["мерильщик"],
    "меря": ["мерянин"],
    "меряв": ["мерявши"],
    "мерявши": ["меряв"],
    "мерянин": ["меря"],
    "мерять": ["мерить"],
    "мерячение": ["мэнерик", "меряченье", "эмиряченье", "эмирячение", "меняриченье"],
    "меряченье": ["эмиряченье"],
    "мерёжа": ["верша", "морда"],
    "месдоза": ["мессдоза"],
    "месив": ["месивши"],
    "месивши": ["месив"],
    "месить": ["вымешивать"],
    "месить говны": ["говны месить"],
    "мескен": ["бичара"],
    "месмеризм": ["животный магнетизм", "гипнотизм"],
    "месмерист": ["магнетизёр"],
    "месо": ["плът"],
    "месоамерика": ["мезоамерика"],
    "месопотамия": ["двуречье", "междуречье"],
    "мессалина": ["распутница"],
    "мессдоза": ["месдоза"],
    "мессенджер": ["интернет-мессенджер", "почтальонка"],
    "мессения": ["мессиния"],
    "мессианизм": ["мессианство"],
    "мессианистический": ["мессианский"],
    "мессианство": ["мессианизм", "богоизбранность", "избранничество", "избранность"],
    "мессина": ["занкла", "мессена", "мессана", "мусина"],
    "мессир": ["господин", "мессер", "милорд"],
    "мессия": ["иисус христос"],
    "места не столь отдалённые": ["тюрьма"],
    "местечковый": ["провинциальный"],
    "мести": ["подметать"],
    "местком": ["мк", "профком"],
    "местничав": ["местничавши"],
    "местничавши": ["местничав"],
    "местничать": ["местничаться"],
    "местничество": ["клановость", "местечковость"],
    "местноанестезирующий": ["местнообезболивающий"],
    "местность": ["район", "участок", "окрестность"],
    "местный": ["здешний", "автохтонный", "старожильческий", "локальный"],
    "местный падеж": ["второй предложный падеж", "локатив"],
    "место": ["местоположение", "расположение", "точка", "пространство", "объём", "площадь"],
    "местоблюститель": ["исполняющий обязанности", "врио"],
    "местоименье": ["местоимение"],
    "местонахождение": ["адрес", "местоположение", "положение", "пребывание", "расположение", "координата"],
    "местонахожденье": ["местонахождение"],
    "местообитание": ["ареал"],
    "местоположение": ["место", "положение", "расположение", "местонахождение"],
    "местоположенье": ["местоположение"],
    "местопребыванье": ["местопребывание"],
    "месторасположение": ["местоположение"],
    "месторождение": ["залежь"],
    "месторожденье": ["месторождение"],
    "месть": ["возмездие", "мщение", "отмщение", "мстя"],
    "месье": ["мсье"],
    "месяцеслов": ["святцы"],
    "месячишко": ["месяц"],
    "месячная роза": ["китайская роза", "бенгальская роза", "индийская роза"],
    "месячные": ["менструация", "критические дни", "гости", "красная луна"],
    "мета-анализ": ["метаанализ"],
    "метаанализ": ["мета-анализ"],
    "метабазис": ["дигрессия"],
    "метабисульфит": ["пиросульфит", "дисульфит"],
    "метаболизм": ["обмен веществ"],
    "метаболия": ["метаморфоз"],
    "метав": ["метавши"],
    "метавши": ["метав"],
    "метадон": ["амидон", "анадон", "фенадон", "долофин", "физептон", "гептадон"],
    "метаинформация": ["метаданные"],
    "метал": ["металл", "металлический рок", "металлорок", "металл-рок"],
    "металепсис": ["металепса"],
    "металл": ["метал"],
    "металл-рок": ["металл", "металлический рок", "металлорок"],
    "металлага": ["антимерия"],
    "металлизировав": ["металлизировавши"],
    "металлизировавши": ["металлизировав"],
    "металлизировать": ["металлизовать"],
    "металлизовав": ["металлизовавши"],
    "металлизовавши": ["металлизовав"],
    "металлизовать": ["металлизировать"],
    "металлист": ["металлюга"],
    "металлический рок": ["метал", "металл", "металлорок", "металл-рок"],
    "металлодетектор": ["металлоискатель"],
    "металлоид": ["полуметалл"],
    "металлоидный": ["металлоидальный", "полуметаллический"],
    "металлоизделие": ["метиз"],
    "металлоискатель": ["металлодетектор", "металлообнаружитель", "радар"],
    "металлокерамика": ["кермет"],
    "металлопластиковый": ["металлопластмассовый"],
    "металлопротеин": ["металлопротеид"],
    "металлорежущий": ["металлорезательный"],
    "металлорезательный": ["металлорежущий"],
    "металлорок": ["металл", "металл-рок", "металлический рок"],
    "металлофермент": ["металлоэнзим"],
    "металлофон": ["ксилофон"],
    "металлоэнзим": ["металлофермент"],
    "металлург": ["металлист"],
    "металлюга": ["металлист"],
    "металообробка": ["металооброблення"],
    "металооброблення": ["металообробка"],
    "металопрокат": ["прокат"],
    "метальный": ["метательный"],
    "метамерия": ["метамеризм"],
    "метамизол": ["анальгин"],
    "метамодернизм": ["метамодерн"],
    "метаморфизировав": ["метаморфизировавши"],
    "метаморфизировавши": ["метаморфизировав"],
    "метаморфизовав": ["метаморфизовавши"],
    "метаморфизовавши": ["метаморфизовав"],
    "метаморфоз": ["превращение", "видоизменение", "метаболия"],
    "метампсихоз": ["реинкарнация"],
    "метан": ["болотный газ", "рудничный газ", "природный газ"],
    "метаналь": ["формальдегид", "муравьиный альдегид"],
    "метандиенон": ["метандростенолон"],
    "метандиол": ["метиленгликоль"],
    "метанефрос": ["вторичная почка", "тазовая почка"],
    "метановая кислота": ["муравьиная кислота"],
    "метанол": ["метиловый спирт", "древесный спирт"],
    "метаноловый": ["метанольный"],
    "метанольный": ["метаноловый"],
    "метансульфохлорид": ["мезилхлорид"],
    "метантиол": ["метилмеркаптан"],
    "метаплазм": ["метаплазма"],
    "метаплазма": ["метаплазм", "усечение", "искажение"],
    "метаплевра": ["метаплеврон"],
    "метапроза": ["метаповествование", "метафикшн"],
    "метараминол": ["арамин"],
    "метасистема": ["надсистема"],
    "метасоматизм": ["метасоматоз"],
    "метасоматоз": ["метасоматизм", "мигматизация"],
    "метастазировав": ["метастазировавши"],
    "метастазировавши": ["метастазировав"],
    "метастазный": ["метастатический"],
    "метатрон": ["маттатрон"],
    "метать": ["кидать", "швырять", "бросать", "скирдовать"],
    "метать бисер перед свиньями": ["кидать маргаритки перед свиньями"],
    "метаться": ["бегать", "суетиться", "ворочаться", "крутиться"],
    "метафизичный": ["метафизический"],
    "метафора": ["иносказание"],
    "метафоризировав": ["метафоризировавши"],
    "метафоризировавши": ["метафоризировав"],
    "метафоризировать": ["метафоризовать"],
    "метафоризовав": ["метафоризовавши"],
    "метафоризовавши": ["метафоризовав"],
    "метафоризовать": ["метафоризировать"],
    "метафорический": ["метафоричный"],
    "метафоричный": ["метафорический"],
    "метацикличный": ["инвазивный"],
    "метачеловек": ["сверхчеловек"],
    "метающийся": ["мечущийся"],
    "метеж": ["смут", "междуособица", "бунт", "смущение", "въстание", "вълнение", "кипеж", "размирица"],
    "метежник": ["бунтовник", "размирник", "бунтар", "въстаник", "революционер"],
    "метелив": ["метеливши"],
    "метеливши": ["метелив"],
    "метелить": ["вьюжить"],
    "метель": ["метелица", "вьюга"],
    "метельщик": ["дворник"],
    "метемпсихоз": ["метемпсихоза", "реинкарнация"],
    "метемпсихоза": ["метемпсихоз", "реинкарнация"],
    "метенил": ["метин"],
    "метенье": ["метение"],
    "метеозависимый": ["метеолабильный", "метеочувствительный"],
    "метеоинформация": ["метеоданные"],
    "метеолабильный": ["метеозависимый", "метеочувствительный"],
    "метеорен поток": ["метеорен дъжд"],
    "метеорит": ["болид"],
    "метеоритолог": ["метеоритчик"],
    "метеороид": ["метеорное тело"],
    "метеорологический феномен": ["метеорологическое явление"],
    "метеосводка": ["метеорологическая сводка"],
    "метеочувствительный": ["метеозависимый", "метеолабильный"],
    "метив": ["метивши"],
    "метивши": ["метив"],
    "метизация": ["метисация"],
    "метил": ["ме"],
    "метилат": ["метоксид"],
    "метилбензол": ["толуол", "фенилметан"],
    "метилдихлорарсин": ["дихлорметилмышьяк"],
    "метиленгликоль": ["метандиол"],
    "метиленовая группа": ["гомологическая разность"],
    "метилидин": ["метин"],
    "метилировав": ["метилировавши"],
    "метилировавши": ["метилировав"],
    "метилкарбинол": ["этанол"],
    "метилкарнозин": ["анзерин"],
    "метилоранж": ["гелиантин", "метиловый оранжевый"],
    "метилурацил": ["диоксометилтетрагидропиримидин"],
    "метилэтилкетон": ["бутанон"],
    "метин": ["метилидин", "метенил"],
    "метина": ["отметина", "метка"],
    "метис": ["полукровка", "помесь"],
    "метисация": ["мисгенация", "миксгенация"],
    "метить": ["отмечать", "помечать"],
    "метка": ["мета", "отметка", "пометка"],
    "меткий": ["попадать белке в глаз"],
    "метко": ["точно"],
    "метла": ["метёлка"],
    "метлюта": ["метлуда", "мотмота", "ори-цкали"],
    "метнув": ["метнувши"],
    "метнувши": ["метнув"],
    "метнуть": ["бросить", "кинуть"],
    "метнуться": ["броситься", "кинуться"],
    "метод": ["метода"],
    "метод безопалубочного формования": ["метод безопалубочной формовки", "метод безопалубочного формирования", "безопалубочный метод формования", "безопалубочный метод"],
    "метод научного тыка": ["метод тыка"],
    "метод тыка": ["метод народного тыка", "метод научного тыка"],
    "метода": ["метод"],
    "методизм": ["методичность"],
    "методичность": ["систематичность"],
    "методичный": ["методический", "пунктуальный"],
    "метол": ["параметиламинофенолсульфат", "генол"],
    "метоним": ["псевдоним"],
    "метонимичный": ["метонимический"],
    "метоп": ["метопа"],
    "метр": ["мегабайт", "мег"],
    "метранпаж": ["верстальщик"],
    "метреса": ["любовница", "държанка"],
    "метризовав": ["метризовавши"],
    "метризовавши": ["метризовав"],
    "метричка": ["метрика"],
    "метро": ["метрополитен", "метроха"],
    "метровый": ["однометровый"],
    "метрополитен": ["метро", "подземка"],
    "метрополия": ["материк", "большая земля"],
    "метропольный": ["столичный"],
    "метросексуал": ["денди", "франт"],
    "метростроевец": ["метростроитель"],
    "метростроитель": ["метростроевец"],
    "метростроительский": ["метростроевский"],
    "метротрам": ["метротрамвай", "метрам", "мини-метро", "подземный трамвай"],
    "метротрамвай": ["подземный", "трамвай", "метротрам", "мини-метро"],
    "метэпистерн": ["эпистернум", "эпистерн"],
    "метёлка": ["метла", "тёлка"],
    "мефедрон": ["меф"],
    "мефистофелевский": ["мефистофельский"],
    "мефистофель": ["сатана", "люцифер", "азазель", "самаэль", "вельзевул", "дьявол", "демон", "чёрт", "бес"],
    "мефистофельский": ["мефистофелевский"],
    "мефитический": ["зловонный", "смрадный", "вонючий"],
    "мефодий": ["нефёд", "ниход"],
    "мех": ["шерсть", "шкура", "пушнина", "мягкая рухлядь"],
    "меха": ["мех", "меха-робот"],
    "механа": ["кръчма", "пивница", "питиепродавница"],
    "механизировав": ["механизировавши"],
    "механизировавши": ["механизировав"],
    "механизированная колонна": ["мехколонна"],
    "механизм": ["машина", "механицизм"],
    "механик": ["механ", "машинист"],
    "механик-водитель": ["водитель-механик", "вездеходчик", "мехвод", "механ"],
    "механистически": ["механистично"],
    "механистично": ["механистически"],
    "механистичный": ["механистический"],
    "механицизм": ["механизм"],
    "механически": ["бездумно"],
    "механический": ["технический", "двигательный", "машинальный"],
    "механотрон": ["вибротрон"],
    "механохория": ["автомеханохория"],
    "мехвод": ["водитель-механик", "механик-водитель"],
    "мехдоение": ["мехдойка"],
    "мехиа": ["мехия"],
    "мехия": ["мехиа"],
    "мехколонна": ["механизированный", "колонна"],
    "мехлесхоз": ["механизированный", "лесхоз"],
    "мехлопата": ["механический", "лопата"],
    "меховой": ["пушной"],
    "мехон": ["мехоноша"],
    "мехоноша": ["мехон", "простак", "рохля", "чудак"],
    "мехур": ["балон", "пришка"],
    "меценат": ["благотворитель", "покровитель", "благодетель"],
    "меценатство": ["спонсорство"],
    "меценатствовав": ["меценатствовавши"],
    "меценатствовавши": ["меценатствовав"],
    "меченный": ["помеченный", "отмеченный", "прицельный", "меткий", "намеченный"],
    "меченосец": ["мечник"],
    "меченый": ["маркированный", "отмеченный", "помеченный"],
    "меченье": ["мечение"],
    "мечта": ["грёза", "воображение", "фантазия", "мечтание", "мечтанье", "мечталка", "желание", "цель", "заглядение", "загляденье", "первый сорт", "высший класс"],
    "мечтав": ["мечтавши"],
    "мечтавши": ["мечтав"],
    "мечтание": ["мечта"],
    "мечтанье": ["мечтание"],
    "мечтатель": ["витун", "манилов", "не от мира сего", "летатель", "фантазёр", "фантаст", "прожектёр", "идеалист", "утопист", "донкихот"],
    "мечтать": ["фантазировать", "грезить", "воображать", "вожделеть"],
    "мечтать о себе много": ["мечтать о себе высоко"],
    "меш": ["полимеш", "полигональная сетка"],
    "мешав": ["мешавши"],
    "мешавши": ["мешав"],
    "мешанина": ["смесь", "каша"],
    "мешанье": ["мешание"],
    "мешать": ["препятствовать", "ставить препоны", "затруднять", "осложнять"],
    "мешаться": ["смешиваться", "путаться", "перепутываться", "сбиваться", "смущаться", "теряться"],
    "мешивав": ["мешивавши"],
    "мешивавши": ["мешивав"],
    "мешкав": ["мешкавши"],
    "мешкавши": ["мешкав"],
    "мешканье": ["мешкание"],
    "мешкательный": ["медлительный", "неповоротливый"],
    "мешковатый": ["просторный", "не", "стесняющий", "движение", "широкий", "балахонистый", "неповоротливый", "косолапый", "косорукий"],
    "мешкообразный": ["сумкообразный", "мешковидный"],
    "мешкотность": ["медлительность", "неповоротливость", "нерасторопность"],
    "мешок": ["куль", "сумка", "круг", "котёл"],
    "мешочек": ["мешок"],
    "мешочничав": ["мешочничавши"],
    "мешочничавши": ["мешочничав"],
    "мещанин": ["ханжа", "обыватель", "филистер"],
    "мещанка": ["обывательница"],
    "меядин": ["эль-меядин"],
    "меянкиели": ["торнедальский финский", "меянкиельский язык"],
    "мжа": ["мжичка"],
    "мжичка": ["мряка"],
    "мзга": ["мгла", "мга", "мжа", "мжица"],
    "мзда": ["вознаграждение", "воздаяние", "награда", "плата", "барыш", "прибыток", "добыча", "возмездие", "взятка", "подкуп", "корысть", "на лапу", "занос", "подмазка", "кара"],
    "мздоимец": ["взяточник", "хапуга", "хапун", "лихоимец", "мшелоимец"],
    "мздоимство": ["лихоимство", "взяточничество"],
    "мздоимствовав": ["мздоимствовавши"],
    "мздоимствовавши": ["мздоимствовав"],
    "ми": ["фа-бемоль"],
    "ми-бемоль": ["ре-диез"],
    "ми-диез": ["фа"],
    "миазм": ["зловоние", "миазма"],
    "миазма": ["миазм", "зловоние", "вонь", "смрад", "скверна", "язва", "мерзость"],
    "миг": ["мгновение", "момент", "минута"],
    "мигав": ["мигавши"],
    "мигавши": ["мигав"],
    "мигалка": ["глаз", "проблесковый маячок", "ведёрко"],
    "миганье": ["мигание"],
    "мигать": ["моргать", "подмигивать"],
    "мигдаш": ["микдаш"],
    "мигматизация": ["метасоматоз"],
    "мигнув": ["мигнувши"],
    "мигнувши": ["мигнув"],
    "мигом": ["моментально"],
    "мигрант": ["переселенец", "аллохтон"],
    "миграционная карта": ["миграционка"],
    "мигрень": ["гемикрания"],
    "мигрировав": ["мигрировавши"],
    "мигрировавши": ["мигрировав"],
    "мидгард": ["митгард"],
    "мидл-класс": ["средний класс"],
    "миелофиброз": ["миелосклероз", "идиопатическая миелоидная метаплазия"],
    "миз": ["тевкр", "мез"],
    "мизалла": ["соябон", "чатр", "шамсия"],
    "мизандрический": ["мужененавистнический"],
    "мизандрия": ["мужененавистничество"],
    "мизансценировав": ["мизансценировавши"],
    "мизансценировавши": ["мизансценировав"],
    "мизантроп": ["человеконенавистник"],
    "мизантропия": ["человеконенавистничество"],
    "мизгирь": ["паук", "тенётник"],
    "мизер": ["малость"],
    "мизерабельный": ["незначительный", "мизерный", "ничтожный", "скудный", "жалкий", "убогий", "непрезентабельный", "несолидный"],
    "мизерив": ["мизеривши"],
    "мизеривши": ["мизерив"],
    "мизерикорд": ["мизерикордия", "кинжал милосердия"],
    "мизерикордия": ["мизерикорд", "кинжал милосердия"],
    "мизериться": ["мизерить"],
    "мизерник": ["подлец", "безсрамник", "безчестник", "мерзавец"],
    "мизерно": ["на донышке", "кот наплакал"],
    "мизерный": ["микроскопический", "жалкий", "презренный", "ничтожный"],
    "мизинный": ["мизинцевый", "меньшой", "простой", "незначимый", "младший"],
    "мизогин": ["женоненавистник", "мизогинист"],
    "мизогинизм": ["женоненавистничество", "мизогиния"],
    "мизогинист": ["женоненавистник", "мизогин"],
    "мизогинистский": ["женоненавистнический", "мизогинный", "мизогинистичный", "мизогиничный", "мизогинический"],
    "мизогинический": ["женоненавистнический", "мизогинистский"],
    "мизогиния": ["женоненавистничество"],
    "мизогинный": ["женоненавистнический"],
    "мизон": ["тарозу"],
    "мизопедия": ["детоненавистничество"],
    "мизрах": ["мызрах"],
    "микадо": ["тэнно"],
    "микдаш": ["мигдаш"],
    "микоз": ["микотоксикоз"],
    "микола": ["никола", "николай", "миколай"],
    "микориза": ["грибокорень"],
    "микроавтобус": ["минивэн"],
    "микроб": ["микроорганизм"],
    "микробентометр": ["стратометр"],
    "микробизнес": ["микропредпринимательство"],
    "микробизнесмен": ["микропредприниматель"],
    "микробиота": ["микрофлора"],
    "микроблефария": ["микроблефарон"],
    "микроблефарон": ["микроблефария"],
    "микробоценоз": ["микробиоценоз"],
    "микробранова печка": ["микробранова"],
    "микробус": ["микробас"],
    "микровесы": ["нановесы"],
    "микроволновая печь": ["свч-печь", "микроволновка"],
    "микроволновка": ["микроволновая печь", "свч-печь"],
    "микроволокно": ["микрофибра", "фибра"],
    "микрозаймовый": ["микрофинансовый"],
    "микрозаповедник": ["мини-заповедник"],
    "микрокалькулятор": ["калькулятор"],
    "микрокапсулировав": ["микрокапсулировавши"],
    "микрокапсулировавши": ["микрокапсулировав"],
    "микрокапсулирование": ["микрокапсуляция"],
    "микрокафе": ["мини-кафе"],
    "микроколичество": ["следовое количество"],
    "микрокосмос": ["микрокосм"],
    "микрокредит": ["микроссуда"],
    "микром": ["микроом"],
    "микромикрон": ["пикометр"],
    "микромодель": ["мини-модель", "модель"],
    "микромолекула": ["мономер"],
    "микрон": ["микрометр"],
    "микроорганизм": ["микроб"],
    "микроперепись": ["микроценз"],
    "микропериод": ["период"],
    "микропечать": ["микроизображение", "микрооттиск"],
    "микроплатёж": ["микротранзакция"],
    "микроповреждение": ["микротравма"],
    "микропраздник": ["праздник"],
    "микропредприниматель": ["микробизнесмен"],
    "микропредпринимательство": ["микробизнес"],
    "микрораздражитель": ["раздражитель"],
    "микрорайон": ["мкр-н", "мкрн"],
    "микросекунда": ["мкс", "микросекунда дуги", "угловая микросекунда", "микроарксекунда"],
    "микросеть": ["микрогрид"],
    "микроскоп": ["мелкоскоп"],
    "микроскопировав": ["микроскопировавши"],
    "микроскопировавши": ["микроскопировав"],
    "микроскопический": ["скудный"],
    "микросома": ["хромидия"],
    "микроспора": ["пыльца"],
    "микроспория": ["микроспороз"],
    "микроспороз": ["микроспория"],
    "микротопонимика": ["микротопонимия"],
    "микротопонимия": ["микротопонимика"],
    "микроферма": ["мини-ферма"],
    "микрофибра": ["микроволокно", "фибра"],
    "микрофильмировав": ["микрофильмировавши"],
    "микрофильмировавши": ["микрофильмировав"],
    "микрофиша": ["микрокарта"],
    "микрофишировав": ["микрофишировавши"],
    "микрофишировавши": ["микрофишировав"],
    "микрофотография": ["микрофотосъёмка"],
    "микрофотосъёмка": ["микрофотография"],
    "микрофтальм": ["офтальмомикрия"],
    "микрохроматика": ["энармоника"],
    "микроэвм": ["персональный компьютер"],
    "микроядро": ["микронуклеус"],
    "микрургия": ["микродиссекция", "микрохирургия"],
    "микс": ["смесь", "смешение", "мешанина"],
    "микс-болл": ["микс-бол"],
    "миксер": ["бетоновозка", "бетономешалка"],
    "миксовав": ["миксовавши"],
    "миксовавши": ["миксовав"],
    "миксовать": ["сводить"],
    "миксоплодия": ["миксоплоидия"],
    "микшировав": ["микшировавши"],
    "микшировавши": ["микшировав"],
    "мил друг": ["дружок", "милый друг"],
    "милан": ["медиолан"],
    "милана": ["мила", "миланочка", "миланка"],
    "милашечка": ["милашка", "милаша"],
    "милашка": ["душечка", "прелесть", "милка"],
    "милдронат": ["мельдоний"],
    "милев": ["милевши"],
    "милевши": ["милев"],
    "миледи": ["госпожа"],
    "милейший": ["симпатичный", "дорогой", "симпатичнейший", "приятнейший", "любезный"],
    "милена": ["мила"],
    "миленка": ["милена"],
    "миленько": ["мило"],
    "милиписечный": ["крохотный"],
    "милитаризировав": ["милитаризировавши"],
    "милитаризировавши": ["милитаризировав"],
    "милитаризировать": ["милитаризовать", "военизировать"],
    "милитаризовав": ["милитаризовавши"],
    "милитаризовавши": ["милитаризовав"],
    "милитаризовать": ["милитаризировать", "военизировать"],
    "милитарный": ["военный", "воинственный", "милитаристский", "милитаристический"],
    "милитократия": ["казармократия"],
    "милиционный": ["милицейский"],
    "милиция": ["полиция"],
    "милишник": ["рукопашник", "ближник"],
    "миллениал": ["милленит", "эхо-бумер"],
    "миллиампер": ["ма"],
    "миллиард": ["биллион", "тьма тем", "млрд", "лимард", "арбуз", "ярд"],
    "миллиметр": ["мм"],
    "миллиметр ртутного столба": ["торр"],
    "миллиметровая бумага": ["миллиметровка"],
    "миллимикрон": ["нанометр"],
    "миллион": ["лимон", "лям", "тьма", "куча", "множество", "тысяча", "мириада"],
    "миллионер": ["богач"],
    "миллисекунда": ["угловая миллисекунда", "миллисекунда дуги", "миллиарксекунда"],
    "миловав": ["миловавши"],
    "миловавши": ["миловав"],
    "миловидий": ["миловидний"],
    "миловидний": ["миловидий"],
    "миловидный": ["хорошенький", "пригожий"],
    "милок": ["касатик", "соколик"],
    "милорд": ["лорд"],
    "милосердие": ["благоутробие", "сердобольность", "милостивость", "доброта"],
    "милосердно": ["сострадательно"],
    "милосердность": ["милосердие"],
    "милосердный": ["сострадательный", "милосердый"],
    "милосердствовав": ["милосердствовавши"],
    "милосердствовавши": ["милосердствовав"],
    "милосердствувати": ["милосердитися"],
    "милостивец": ["благодетель"],
    "милостивый государь": ["государь мой", "милостивый государь мой", "милостисдарь"],
    "милостиня": ["милостинька", "подаяння"],
    "милостисдарь": ["милостивый государь", "милостивый сударь"],
    "милостыня": ["подаяние", "подачка"],
    "милоть": ["милотарь"],
    "милочек": ["кветочек"],
    "милочка": ["дорогуша"],
    "мильеранизм": ["министериализм"],
    "мильон": ["миллион"],
    "миляга": ["душка", "симпатяга"],
    "милёнок": ["любимый", "ненаглядный", "друг сердечный"],
    "мимезис": ["мимесис"],
    "мимеограф": ["ротатор", "автокопист", "циклостиль"],
    "мимесис": ["мимезис"],
    "миметезит": ["миметизит"],
    "миметизит": ["миметит", "миметезит"],
    "миметик": ["агонист"],
    "миметит": ["миметизит"],
    "миметический": ["подражательный", "похожий", "сходный", "миметичный"],
    "миметичный": ["миметический", "подражательный"],
    "мимик": ["мимист"],
    "мимикрировав": ["мимикрировавши"],
    "мимикрировавши": ["мимикрировав"],
    "мимикрия": ["подражание", "маскирование"],
    "мимимишный": ["милый", "умилительный", "мимишный", "кавайный"],
    "мимировав": ["мимировавши"],
    "мимировавши": ["мимировав"],
    "мимишный": ["милый", "умилительный"],
    "мимо": ["стороной"],
    "мимоговорение": ["мимоответ", "миморечь"],
    "мимоездом": ["проездом"],
    "мимоза": ["акация серебристая", "недотрога"],
    "мимолётно": ["мимолётом", "скоротечно"],
    "мимолётный": ["скоротечный", "быстротечный"],
    "мимолётом": ["пролётом", "мимолётно", "мимоходом", "бегло"],
    "мимоответ": ["мимоговорение", "миморечь"],
    "мимоходом": ["походя"],
    "мина": ["торпеда", "подкоп", "минирный ход", "минный ход"],
    "минати": ["проходити"],
    "мингечаур": ["мингечевир"],
    "мингрел": ["мегрел"],
    "миндалик": ["миндалина"],
    "миндалина": ["миндалевидная железа"],
    "миндаль": ["миндальный орех"],
    "миндальник": ["миндаль"],
    "миндальничав": ["миндальничавши"],
    "миндальничавши": ["миндальничав"],
    "миндальничать": ["сентиментальничать", "деликатничать", "чикаться", "церемониться"],
    "минерализировав": ["минерализировавши"],
    "минерализировавши": ["минерализировав"],
    "минерализовав": ["минерализовавши"],
    "минерализовавши": ["минерализовав"],
    "минерализоваться": ["минерализироваться"],
    "минералка": ["минеральная вода", "сельтерская", "сельтерская вода", "зельтерская", "зельтерская вода"],
    "минералокортикоид": ["минералокортикостероид"],
    "минералокортикостероид": ["минералокортикоид"],
    "минеральная вода": ["минералка"],
    "минеральная кислота": ["неорганическая кислота"],
    "минеральные воды": ["минводы"],
    "минерва": ["афина"],
    "минет": ["минька"],
    "минетив": ["минетивши"],
    "минетивши": ["минетив"],
    "минея": ["четьи-минеи"],
    "минзаг": ["минный заградитель"],
    "мини-": ["микро-"],
    "мини-гостиница": ["мини-отель"],
    "мини-детсад": ["мини-сад", "мини-садик"],
    "мини-заповедник": ["микрозаповедник"],
    "мини-кафе": ["микрокафе"],
    "мини-компьютер": ["мини-эвм"],
    "мини-магазин": ["мини-маркет", "магазинчик"],
    "мини-маркет": ["мини-магазин", "магазинчик"],
    "мини-модель": ["микромодель"],
    "мини-отель": ["мини-гостиница"],
    "мини-пивзавод": ["мини-пивоварня"],
    "мини-пивоварня": ["мини-пивзавод"],
    "мини-фотолаборатория": ["минилаб"],
    "мини-фургон": ["минивэн"],
    "мини-футбол": ["миник"],
    "мини-эвм": ["мини-компьютер"],
    "миниатюризировав": ["миниатюризировавши"],
    "миниатюризировавши": ["миниатюризировав"],
    "миниатюризовав": ["миниатюризовавши"],
    "миниатюризовавши": ["миниатюризовав"],
    "миниатюрный": ["маленький", "крошечный"],
    "минивэн": ["универсал повышенной вместимости", "мини-фургон"],
    "минимализация": ["минимизация", "минимизирование"],
    "минимализировав": ["минимализировавши"],
    "минимализировавши": ["минимализировав"],
    "минимализировать": ["минимизировать"],
    "минимальный": ["наименьший"],
    "минимальный размер оплаты труда": ["мрот"],
    "минимизация": ["минимизирование"],
    "минимизировав": ["минимизировавши"],
    "минимизировавши": ["минимизировав"],
    "минимизирование": ["минимизация"],
    "минимум": ["наименьшее"],
    "минировав": ["минировавши"],
    "минировавши": ["минировав"],
    "министериализм": ["мильеранизм"],
    "министерство просвещения": ["минпрос"],
    "министерство финансов": ["минфин"],
    "министерствовав": ["министерствовавши"],
    "министерствовавши": ["министерствовав"],
    "министр без портфеля": ["государственный министр", "министр по особым поручениям"],
    "минитерм": ["минтерм", "минимальный терм", "совершенный одночлен", "конституента единицы"],
    "минифедерация": ["мини-федерация"],
    "минкульт": ["минкультуры"],
    "минкультуры": ["минкульт"],
    "минна": ["мина"],
    "минный заградитель": ["минзаг"],
    "минобороны": ["мо"],
    "минобр": ["минобрнауки"],
    "миновав": ["миновавши"],
    "миновавши": ["миновав"],
    "минование": ["прошествие"],
    "миновать": ["проходить", "пройти", "проезжать", "проехать"],
    "миноискатель": ["металлодетектор", "металлоискатель"],
    "миномёт": ["мортира"],
    "минор": ["моль"],
    "миноранг": ["минофом"],
    "миноритарный": ["неконтрольный"],
    "миноритет": ["меньшинство"],
    "минпрос": ["минпросвет"],
    "минрегион": ["минрегионразвития"],
    "минрегионразвития": ["минрегион"],
    "минские соглашения": ["минск"],
    "минтака": ["альмантрея"],
    "минтерм": ["минитерм", "минимальный терм", "совершенный одночлен", "конституента единицы"],
    "минув": ["минувши"],
    "минувши": ["минув"],
    "минувший": ["прошедший", "исполнившийся", "прошлый", "исчезнувший"],
    "минусив": ["минусивши"],
    "минусивши": ["минусив"],
    "минусовав": ["минусовавши"],
    "минусовавши": ["минусовав"],
    "минусовка": ["минусовая фонограмма", "минус", "фанера"],
    "минусовой": ["минусовый"],
    "минусовый": ["минусовой"],
    "минуть": ["пройти", "миновать", "избежать", "опустить", "окончиться", "закончиться", "завершиться", "остаться позади", "исполниться", "наступить"],
    "минчс": ["мчс"],
    "минь": ["мин"],
    "миньетчик": ["минетчик"],
    "миньок": ["минь"],
    "миньон": ["сингл", "макси-сингл", "колонель"],
    "минюст": ["министерство юстиции"],
    "миоз": ["миозис"],
    "миолиз": ["миоцитолиз"],
    "миопия": ["близорукость"],
    "миоплазма": ["саркоплазма"],
    "миорелаксация": ["релаксация"],
    "миоцен": ["миоценовая эпоха"],
    "мир": ["спокойствие", "мирный договор", "мирный трактат"],
    "мир иной": ["тот свет", "загробный мир", "потусторонний мир"],
    "мир тесен": ["земля круглая и имеет форму чемодана", "земля круглая и имеет форму рюкзака"],
    "мира": ["мирослава", "дамира", "замира", "владимира"],
    "мирабелевый": ["мирабельный"],
    "мирабилит": ["глауберова соль"],
    "мираж": ["марево", "морок", "подвод", "иллюзия", "фантом", "призрак", "игра воображения"],
    "миражировав": ["миражировавши"],
    "миражировавши": ["миражировав"],
    "миражировать": ["грезиться", "овоскопировать"],
    "миракль": ["мистерия"],
    "мирандский": ["мирандес", "мирандский язык"],
    "мирандский язык": ["мирандес"],
    "мирах": ["мирак"],
    "мирволение": ["потакание", "попущение", "мирволенье"],
    "мирволенье": ["потакание", "попущение", "потаканье", "попущенье", "мирволение"],
    "мирволив": ["мирволивши"],
    "мирволивши": ["мирволив"],
    "мирволить": ["попустительствовать", "давать поблажку", "потакать", "мироволить", "благоволить"],
    "миргын": ["эпы"],
    "мириада": ["множество", "тысяча"],
    "мириам": ["мирьям", "марьям", "мария"],
    "мирив": ["миривши"],
    "миривши": ["мирив"],
    "мирика": ["брахителес"],
    "миристин": ["тримиристин"],
    "мирить": ["примирять"],
    "мириться": ["заключать мир", "примиряться", "смиряться"],
    "мирка": ["мирк"],
    "мирмекофильный": ["симбиотический"],
    "мирно": ["миролюбиво", "ладом"],
    "мирноград": ["димитров"],
    "мирность": ["невоинственность"],
    "мирный": ["миролюбивый", "дружественный", "гражданский", "спокойный", "смирный"],
    "мирняк": ["гражданские", "гражданские лица", "гражданское население", "мирное население"],
    "мировоззрение": ["идеология", "миропонимание"],
    "мировоззренье": ["мировоззрение"],
    "мировой": ["всемирный", "глобальный", "вселенский", "всесветный", "общемировой", "наилучший", "единственный"],
    "мироволив": ["мироволивши"],
    "мироволивши": ["мироволив"],
    "мироволить": ["попустительствовать", "давать поблажку", "потакать", "мирволить", "благоволить"],
    "мировосприятие": ["мироощущение", "мировоззрение"],
    "мироед": ["эксплуататор", "кулак", "жила", "шкуродёр", "жидомор", "рабовладелец"],
    "мироедство": ["эксплуататорство", "шкуродёрство", "жидоморство"],
    "мироздание": ["мирозданье", "вселенная", "мир", "космос"],
    "мирозданье": ["мироздание"],
    "миролог": ["плач"],
    "миролюбивый": ["пацифистский", "безвоинственный", "мирный"],
    "миролюбие": ["миролюбивость", "дружелюбие"],
    "миролюбье": ["миролюбие"],
    "мирообъемлющий": ["обширный", "многостронний", "разносторонний"],
    "мирообъём": ["охват", "содержание", "размах"],
    "мироощущение": ["мировосприятие", "миропонимание"],
    "мироощущенье": ["мироощущение"],
    "миропознание": ["миропознанье"],
    "миропомазав": ["миропомазавши"],
    "миропомазавши": ["миропомазав"],
    "миропомазанник": ["помазанник"],
    "миропомазывав": ["миропомазывавши"],
    "миропомазывавши": ["миропомазывав"],
    "миропонимание": ["мировоззрение"],
    "миропорядок": ["мироустройство"],
    "мирослава": ["мира"],
    "миросозерцание": ["мировоззрение", "мировоззренье", "миросозерцанье"],
    "миросозерцанье": ["миросозерцание"],
    "миротворив": ["миротворивши"],
    "миротворивши": ["миротворив"],
    "миротворить": ["примирять"],
    "мироточив": ["мироточивши"],
    "мироточивши": ["мироточив"],
    "мироустройство": ["миропорядок"],
    "мирочувствование": ["мироощущение"],
    "мирр": ["мирра", "мирро", "мурр", "смирна"],
    "мирра": ["мирр", "мирро", "мурр", "смирна", "шаджара аль-мурр"],
    "мирской": ["общественный", "светский"],
    "мирсот": ["лангар"],
    "мирт": ["мирта"],
    "мирьям": ["мириам"],
    "мисвок": ["савок"],
    "миска": ["плошка", "тарелка"],
    "мискаст": ["мискастинг"],
    "мискастинг": ["мискаст"],
    "мисливий": ["розумний"],
    "мисль": ["думка"],
    "мисмар": ["мых"],
    "мисо-суп": ["мисо"],
    "миспикель": ["арсенопирит"],
    "мисрата": ["мисурата", "мисрат"],
    "мисс": ["миска"],
    "миссионер": ["проповедник"],
    "миссионерка": ["проповедница"],
    "миссионерство": ["проповедничество", "проповедывание"],
    "миссионерствовав": ["миссионерствовавши"],
    "миссионерствовавши": ["миссионерствовав"],
    "миссионерствовать": ["проповедовать"],
    "миссия": ["назначение", "поручение", "задача", "задание", "функция", "роль", "предназначение", "цель"],
    "мистер": ["господин"],
    "мистерия": ["таинство"],
    "мистик": ["мистицист"],
    "мистика": ["мистицизм"],
    "мистификация": ["мистифицирование", "надувательство", "розыгрыш", "введение в заблуждение"],
    "мистифировав": ["мистифировавши"],
    "мистифировавши": ["мистифировав"],
    "мистифировать": ["мистифицировать"],
    "мистифицировав": ["мистифицировавши"],
    "мистифицировавши": ["мистифицировав"],
    "мистифицировать": ["мистифировать"],
    "мистицист": ["мистик"],
    "мистически": ["таинственно"],
    "мистичный": ["мистический"],
    "мистрис": ["миссис", "госпожа", "сударыня"],
    "миськинлик": ["мискинлик"],
    "миськыны": ["пылатыны"],
    "мисюрка": ["шапка", "мисюрский"],
    "мисюрский": ["египетский"],
    "митава": ["елгава"],
    "митенка": ["полуперчатка"],
    "митинг": ["нытинг"],
    "митинговав": ["митинговавши"],
    "митинговавши": ["митинговав"],
    "миткальный": ["миткалевый"],
    "митоз": ["кариокинез"],
    "митотан": ["хлодитан"],
    "митохондрия": ["хондриосома", "пластосома"],
    "митпаппет": ["псевдовиртуал"],
    "митральеза": ["картечница"],
    "митродор": ["метродор"],
    "миттельшпиль": ["середина"],
    "митушка": ["митушница"],
    "митушница": ["митушка"],
    "митьковав": ["митьковавши"],
    "митьковавши": ["митьковав"],
    "митя": ["дима"],
    "миф": ["басня", "выдумка", "небылица"],
    "мифи": ["московский инженерно-физический институт"],
    "мифичный": ["мифический"],
    "мифолог": ["мифологист"],
    "мифологема": ["мифема"],
    "мифологизировав": ["мифологизировавши"],
    "мифологизировавши": ["мифологизировав"],
    "мифологист": ["мифолог"],
    "мифологический": ["мифический", "былинный", "легендарный"],
    "мифологическое существо": ["мифическое существо"],
    "мифомания": ["псевдология"],
    "михаил": ["михайло", "михайла", "миша", "майкл", "михель", "мишель", "микеле", "мигель", "мик", "мики", "миан", "миян", "михайлин", "михайлен", "михалин"],
    "михаила": ["михеля", "михалина", "михайлина", "михайлена", "михалена"],
    "михайла": ["михаил", "михайло"],
    "михайло": ["михаил"],
    "михайлово": ["хашури"],
    "михайловский замок": ["инженерный замок"],
    "михалыч": ["михайлович"],
    "михась": ["миха", "миша", "михаил"],
    "михр": ["мгер", "мхер"],
    "михрютка": ["замухрышка"],
    "мицелий": ["грибница"],
    "мичуринск": ["козлов"],
    "миша": ["мишенька"],
    "мишг": ["тулм"],
    "мишель": ["михаил"],
    "мишенька": ["миша", "михаил"],
    "мишигас": ["безумие", "беспорядок", "сумасбродство", "сумасшествие"],
    "мишка": ["миша", "мишенька"],
    "мишпуха": ["семья"],
    "мишук": ["медведь", "мишка"],
    "мишура": ["химера", "прах"],
    "миътаф": ["ридо"],
    "мкр-н": ["микрорайон", "мкрн"],
    "младеж": ["малък", "юноша"],
    "младенец": ["малыш", "ребёнок", "грудной ребёнок", "сосунок"],
    "младенствовав": ["младенствовавши"],
    "младенствовавши": ["младенствовав"],
    "младенчествовав": ["младенчествовавши"],
    "младенчествовавши": ["младенчествовав"],
    "младенчествовать": ["младенствовать"],
    "младогегельянец": ["левогегельянец"],
    "младой": ["молодой", "юный"],
    "младореформатор": ["завлаб", "чикагские мальчики", "мальчики в коротких штанишках"],
    "младость": ["молодость"],
    "младше": ["моложе"],
    "младший": ["меньшой"],
    "млат": ["молот"],
    "млев": ["млевши"],
    "млевши": ["млев"],
    "млеко": ["молоко"],
    "млекогонный": ["молокогонный"],
    "млекопитающее": ["зверь"],
    "млекопитающие": ["зверь"],
    "мление": ["мленье"],
    "мленье": ["мление"],
    "млечный путь": ["галактика"],
    "мливо": ["помел"],
    "млинар": ["мельник"],
    "млк": ["молоконт"],
    "мля": ["бля"],
    "мнемоника": ["мнемотехника"],
    "мнение": ["суждение", "точка зрения", "оценка", "взгляд"],
    "мненье": ["мнение"],
    "мнив": ["мнивши"],
    "мнивши": ["мнив"],
    "мнимо": ["обманчиво", "воображаемо"],
    "мнимость": ["кажимость"],
    "мнимый": ["воображаемый", "несуществующий", "кажущийся", "фальшивый", "поддельный", "ненастоящий", "ложный"],
    "мнительность": ["впечатлительность", "подозрительность", "недоверчивость", "боязливость", "робость", "трусость"],
    "мнительный": ["недоверчивый", "подозрительный"],
    "мнить": ["думать", "считать", "полагать", "уповать"],
    "мних": ["монах", "чернец", "инок", "черноризец"],
    "многажды": ["часто", "неоднократно", "многократно", "не раз и не два", "много раз", "не раз", "не один раз", "стократно", "тысячекратно", "намного", "во много раз", "не единожды"],
    "многащи": ["многажды"],
    "многий": ["многочисленный"],
    "многоагентный": ["мультиагентный"],
    "многоаспектный": ["многоаспектовый", "разноаспектный"],
    "многобожец": ["многобожник", "политеист"],
    "многобожие": ["политеизм"],
    "многобожник": ["политеист", "язычник"],
    "многобожный": ["политеистичный", "политеистский"],
    "многобрачие": ["полигамия"],
    "многобугорчатые": ["мультитуберкуляты"],
    "многовалентный": ["поливалентный"],
    "многовластье": ["многовластие"],
    "многоводие": ["многоводье"],
    "многоводный": ["полноводный", "обильноводный"],
    "многоводье": ["половодье", "водища"],
    "многогалоидный": ["многогалогенный", "полигалоидный", "полигалоидированный"],
    "многоглаголание": ["многословие", "пустословие", "суесловие", "многоглаголанье", "многословье", "пустословье", "суесловье"],
    "многоглаголанье": ["многоглаголание", "многословие", "пустословие", "суесловие", "многословье", "пустословье", "суесловье"],
    "многоглазый": ["многоокий"],
    "многоголосие": ["многоголосица", "многоголосье", "полифония"],
    "многоголосица": ["многоголосие"],
    "многоголосный": ["многоголосый"],
    "многоголосый": ["многоголосный"],
    "многогранник": ["полиэдр"],
    "многогранный": ["полиэдральный", "многосторонний", "разносторонний"],
    "многожёнство": ["полигиния"],
    "многозвучный": ["полифоничный"],
    "многозначительно": ["со значением", "многоговоряще"],
    "многозначительный": ["важный", "выразительный"],
    "многозначность": ["неоднозначность"],
    "многоимённость": ["полионимия"],
    "многокомпонентный": ["поликомпонентный", "многоэлементный"],
    "многоконфессиональный": ["мультиконфессиональный"],
    "многократный": ["многочисленный", "неоднократный"],
    "многокристальный": ["многочиповый"],
    "многокутник": ["багатокутник"],
    "многолетний": ["долгий"],
    "многолетник": ["многолетнее растение"],
    "многолетье": ["многолетие"],
    "многоликий": ["многолюдный", "многообразный", "разнообразный"],
    "многолонжеронный": ["многостеночный"],
    "многолюдность": ["многолюдство", "многолюдье", "многолюдие"],
    "многолюдный": ["густонаселённый"],
    "многолюдство": ["многолюдье"],
    "многомиллионный": ["многочисленный", "многонаселённый", "дорогой", "дорогостоящий"],
    "многомужие": ["полиандрия", "многомужество"],
    "многонародие": ["многонародство"],
    "многообещающий": ["перспективный"],
    "многообразье": ["многообразие", "многообразность", "разнообразие"],
    "многоокий": ["многоглазый"],
    "многопалость": ["гипердактилия", "полидактилия"],
    "многопалый": ["полидактилический"],
    "многопартийность": ["многопартийная система", "многопартийное общество"],
    "многоплан": ["полиплан"],
    "многоплатформенный": ["многоплатформный", "кроссплатформенный"],
    "многоплатформный": ["многоплатформенный", "кроссплатформенный"],
    "многоплодность": ["многоплодие"],
    "многопроцессорность": ["мультипроцессорность"],
    "многопроцессорный": ["мультипроцессорный"],
    "многоречивость": ["многословие"],
    "многосвещник": ["канделабър"],
    "многословив": ["многословивши"],
    "многословивши": ["многословив"],
    "многословие": ["многословность", "многоречивость"],
    "многословность": ["многословие"],
    "многословный": ["многоречивый"],
    "многословье": ["многословие"],
    "многосложный": ["многослоговой", "многослоговый"],
    "многослойная древесина": ["слоистое дерево"],
    "многослойный": ["слоистый", "двуслойный", "трехслойный"],
    "многосмысленный": ["значительный", "многозначащий", "выразительный", "неоднозначный"],
    "многосоюзие": ["полисиндетон"],
    "многоспектральный": ["мультиспектральный"],
    "многосрезовый": ["мультисрезовый"],
    "многостадийность": ["многоступенчатость", "многоэтапность"],
    "многосторонний": ["универсальный", "разносторонний"],
    "многотонка": ["большегруз", "многотонник"],
    "многотонник": ["большегруз", "многотонка"],
    "многоточие": ["троеточие", "отточие"],
    "многоугольник": ["полигон"],
    "многоформатный": ["мультиформатный"],
    "многофункциональный": ["мультифункциональный"],
    "многофункциональный центр": ["мфц"],
    "многоцветие": ["многоцветье"],
    "многоцветность": ["многоцветие", "многоцветье"],
    "многоцветный": ["разноцветный", "полихроматический", "многокрасочный", "яркий"],
    "многоцветье": ["многоцветие"],
    "многочисленность": ["неисчислимость", "несчётность", "бесчисленность", "несметность", "бессчётность", "полимерия", "огромность", "массовость"],
    "многочлен": ["полином"],
    "многоэтажка": ["высотка", "небоскрёб"],
    "многоэтажный": ["высокоэтажный"],
    "многоэшелонированный": ["многоэшелонный"],
    "многоэшелонный": ["многоэшелонированный"],
    "многоязыкий": ["полиглотический"],
    "многоязычие": ["полилингвизм"],
    "многоязычный": ["мультиязычный", "мультиязыковой"],
    "множественный": ["многочисленный"],
    "множество": ["совокупность"],
    "множив": ["множивши"],
    "множивши": ["множив"],
    "множить": ["умножать", "увеличивать", "размножать", "перемножать"],
    "множиться": ["умножаться"],
    "мнр": ["монгольская народная республика"],
    "мня": ["обжора", "проглот"],
    "мо": ["мабыць"],
    "моавитский": ["моавитянский"],
    "моавитянин": ["моавит"],
    "моб": ["нпс", "непись", "неигровой персонаж"],
    "мобик": ["дух"],
    "мобила": ["мобильник", "мобильный", "мобилка", "сотовый", "труба"],
    "мобилизация": ["могилизация", "призыв", "милитаризация"],
    "мобилизировать": ["мобилизовать"],
    "мобилизовав": ["мобилизовавши"],
    "мобилизовавши": ["мобилизовав"],
    "мобилизовать": ["призывать", "призвать"],
    "мобилизовывав": ["мобилизовывавши"],
    "мобилизовывавши": ["мобилизовывав"],
    "мобилка": ["мобильник", "мобила", "гаджет"],
    "мобильник": ["мобильный", "мобила", "сотовый", "сотик", "сотка", "труба"],
    "мобильность": ["подвижность", "маневренность"],
    "мобильный": ["самодвижущийся", "передвижной", "переносной", "портативный", "сотовый", "мобильник", "мобила"],
    "мобильный телефон": ["сотовый телефон", "мобила", "мобильник", "мобильный", "сотик", "сотка", "труба"],
    "мобутовец": ["мабута", "стройбатовец"],
    "мова": ["украинский язык", "белорусский язык"],
    "мовазнавец": ["мовавед"],
    "мовбито": ["мовби"],
    "моветон": ["дурной тон"],
    "мовешка": ["шалунья", "ленивица", "дурнушка", "страхолюдина", "кикимора"],
    "мовити": ["говорити"],
    "мовник": ["мовознавець"],
    "мовознавець": ["мовник"],
    "мовчазливий": ["мовчазний"],
    "мовчазний": ["мовчазливий"],
    "мовчазник": ["мовчальник", "мовчун", "мовчан"],
    "мовчальник": ["мовчазник"],
    "могарыч": ["бакшиш", "взятка"],
    "могарычничав": ["могарычничавши"],
    "могарычничавши": ["могарычничав"],
    "могиканин": ["махиканин", "магиканин"],
    "могила": ["вековой дом", "кончина", "гибель"],
    "могилевчанин": ["могилёвец"],
    "могильник": ["некрополь", "орёл", "гармала"],
    "могильщик": ["гробокопатель"],
    "могилёвец": ["могилевчанин"],
    "могучий": ["мощный", "могутный", "могущий"],
    "могущественный": ["мощный", "сильный", "могучий"],
    "могущество": ["потенциал", "могущественность", "мощь"],
    "могуществовав": ["могуществовавши"],
    "могуществовавши": ["могуществовав"],
    "могущий": ["способный"],
    "мода": ["привычка", "обыкновение", "поветрие"],
    "модальный": ["несамостоятельный"],
    "модаркалон": ["онакалон"],
    "моде": ["модэ"],
    "моделер": ["моделлер"],
    "моделизм": ["моделирование"],
    "моделировав": ["моделировавши"],
    "моделировавши": ["моделировав"],
    "моделист": ["модельщик", "макетчик"],
    "моделлер": ["моделер"],
    "модель": ["образец", "тип", "марка", "макет", "натурщик", "натурщица", "манекенщик", "манекенщица", "схема", "представление", "картина"],
    "модератор": ["модер", "мудератор"],
    "модераторство": ["модерирование"],
    "модераторша": ["проверяющая"],
    "модерация": ["модерирование"],
    "модерировав": ["модерировавши"],
    "модерировавши": ["модерировав"],
    "модерн": ["ар-нуво", "югендстиль", "либерти"],
    "модерн-данс": ["танец модерн"],
    "модернизатор": ["обновитель"],
    "модернизация": ["модернизирование", "обновление"],
    "модернизировав": ["модернизировавши"],
    "модернизировавши": ["модернизировав"],
    "модернизм": ["модерн"],
    "модернизовав": ["модернизовавши"],
    "модернизовавши": ["модернизовав"],
    "модерный": ["современный", "модерновый"],
    "модестия": ["скромность", "сдержанность"],
    "моджахед": ["моджахеддин", "джихадист"],
    "модильон": ["модульон"],
    "модист": ["кутюрье", "модельер"],
    "модистка": ["швея", "портниха"],
    "модификационный": ["видоизменяющий"],
    "модификация": ["видоизменение", "преобразование", "вариант", "версия"],
    "модифицировав": ["модифицировавши"],
    "модифицировавши": ["модифицировав"],
    "модифицированный": ["изменённый", "трансформированный"],
    "модифицировать": ["видоизменить"],
    "моднив": ["моднивши"],
    "моднивши": ["моднив"],
    "модник": ["франт", "щёголь"],
    "модничав": ["модничавши"],
    "модничавши": ["модничав"],
    "модно": ["фешенебельно"],
    "модный": ["современный", "стильный", "популярный"],
    "моднявый": ["модный", "моднячий", "стиляжный"],
    "моднячий": ["модный", "моднявый", "стиляжный"],
    "мододел": ["моддер"],
    "модулировав": ["модулировавши"],
    "модулировавши": ["модулировав"],
    "модулировать": ["транспонировать"],
    "модуль": ["шаг", "абсолютная величина", "коэффициент", "блок", "узел"],
    "модус": ["звукоряд"],
    "моевка": ["трёхпалая чайка"],
    "может": ["может быть", "быть может", "возможно", "вероятно", "по-видимому", "похоже"],
    "может быть": ["возможно", "вероятно", "может статься", "что ли"],
    "может статься": ["кто знает", "как знать", "вероятно", "может случиться"],
    "можжевельник": ["верес", "арча", "можжевел", "можжа", "можжуха", "мозжуха", "арчевник"],
    "можжевельниковый": ["можжевеловый"],
    "можно": ["возможно", "есть возможность", "дозволительно", "позволительно"],
    "мозазавр": ["питономорф"],
    "мозаика": ["мозаическое искусство", "мозаичное искусство", "мусия", "муссия", "мусивная живопись", "мусийное искусство", "мозаическая картина"],
    "мозаически": ["мозаично"],
    "мозаичист": ["мозаист"],
    "мозаичка": ["мозаечка", "маленькая", "мозайка", "небольшая", "мозаика"],
    "мозаичник": ["мозаист", "мозаичист"],
    "мозаичный": ["мешаный"],
    "мозамбик": ["республика мозамбик"],
    "мозамбикец": ["мозамбиканец"],
    "мозги": ["ум", "интеллект"],
    "мозги ебать": ["морочить", "заморачивать", "грузить", "подгружать"],
    "мозглявый": ["хилый", "слабый", "слабосильный", "немощный", "тщедушный"],
    "мозгляк": ["хиляк"],
    "мозгнув": ["мозгнувши"],
    "мозгнувши": ["мозгнув"],
    "мозгоблуд": ["мозгоёб"],
    "мозговав": ["мозговавши"],
    "мозговавши": ["мозговав"],
    "мозговед": ["мозголог"],
    "мозговитый": ["сообразительный", "толковый", "башковитый"],
    "мозговой штурм": ["брейнсторминг", "мозговая атака"],
    "мозговыносящий": ["абсурдный", "бредовый", "сюрреалистический"],
    "мозгоебательство": ["мозгодроч", "мозгодрочка", "мозгоёбство", "мозгоёбка"],
    "мозгоклюй": ["зануда"],
    "мозголог": ["мозговед"],
    "мозгоправ": ["психолог", "психиатр", "психоаналитик", "психотерапевт"],
    "мозготрашество": ["мозгоёбство"],
    "мозгоёб": ["мозгоклюй", "мозгоблуд", "мозгокрут"],
    "мозгоёбство": ["мозгоклюйство", "мозготрашество", "мозгоебательство", "мозгоебание", "мозгоебанье"],
    "мозгоёбствовать": ["занудствовать", "мозгоёбничать"],
    "мозель": ["мозельское", "мозельвейн", "музель"],
    "мозжив": ["мозживши"],
    "мозживши": ["мозжив"],
    "мозолив": ["мозоливши"],
    "мозоливши": ["мозолив"],
    "мозолистий": ["мозолястий"],
    "мозолить глаза": ["нервировать", "докучать", "досаждать"],
    "моисей": ["мосей", "моше"],
    "мойка": ["мья"],
    "мойщик": ["уборщик", "чистильщик"],
    "мок": ["международный олимпийский комитет"],
    "мокав": ["мокавши"],
    "мокавши": ["мокав"],
    "мокалак": ["придворный"],
    "мокнув": ["мокнувши"],
    "мокнувши": ["мокнув"],
    "мокнуть": ["сыреть", "отсыревать", "намокать", "промокать", "преть", "отмокать", "вымачиваться"],
    "мокпан": ["мукбанг"],
    "мокрая курица": ["размазня", "слюнтяй", "кисляй", "тряпка", "хлюпик", "слизняк", "баба"],
    "мокрев": ["мокревши"],
    "мокревши": ["мокрев"],
    "мокрец": ["подсед"],
    "мокрица": ["мокричник", "звездчатка средняя", "канареечная трава", "грыжник", "сердечная трава", "мокрец"],
    "мокричник": ["мокрица", "мокрец", "звездчатка средняя"],
    "мокро": ["сыро", "влажно"],
    "мокрое дело": ["мокруха", "убийство", "убиение", "умерщвление"],
    "мокрушник": ["убийца", "убивец"],
    "мокрушница": ["убийца"],
    "мокрый": ["влажный", "намоченный", "возбуждённый"],
    "мокрющий": ["мокрущий", "премокрый", "мокрый-премокрый"],
    "мокрядь": ["мокредь", "мокреть"],
    "мокрёхонький": ["мокрёшенький"],
    "мокса-терапия": ["моксатерапия"],
    "моксатерапия": ["термопунктура", "мокса-терапия"],
    "мокша": ["мордва"],
    "мокшанин": ["мокша"],
    "мокшанский язык": ["мокша-мордовский язык"],
    "мокшень": ["мокшень кяль"],
    "мокшень кяль": ["мокшень"],
    "молва": ["молвь", "слух", "толк", "пересуды", "разговор"],
    "молвив": ["молвивши"],
    "молвивши": ["молвив"],
    "молвить": ["говорить", "сказать", "промолвить", "произносить", "произнести"],
    "молдаванин": ["молдавец"],
    "молдавия": ["молдова", "республика молдова", "молдавская сср", "молдавская асср"],
    "молдавская сср": ["молдова"],
    "молдавско-российский": ["российско-молдавский"],
    "молдова": ["молдавия", "республика молдова"],
    "молдовский": ["молдавский"],
    "молдовський": ["молдавський"],
    "молебен": ["молебствие"],
    "молебствовав": ["молебствовавши"],
    "молебствовавши": ["молебствовав"],
    "молекула": ["мелочь", "мелюзга"],
    "молекулярное облако": ["звёздная колыбель"],
    "молекулярный вес": ["молекулярная масса"],
    "молельня": ["молельная", "моленная"],
    "молельщик": ["богомолец"],
    "молемс": ["тумс", "сърхкамс", "таргавомс", "пиземс", "якамс"],
    "молемс верса": ["верыямс"],
    "моленная": ["молельня"],
    "молескин": ["скетчбук"],
    "молескинный": ["молескиновый"],
    "молзавод": ["молокозавод"],
    "молибденировав": ["молибденировавши"],
    "молибденировавши": ["молибденировав"],
    "молибденит": ["молибденовый блеск", "молибденовый колчедан"],
    "моливши": ["молив"],
    "молитва": ["моление"],
    "молитвеник": ["молитовник"],
    "молитвенник": ["молитвослов"],
    "молитвенно": ["молебно", "коленопреклонённо"],
    "молитвив": ["молитвивши"],
    "молитвивши": ["молитвив"],
    "молитвить": ["молиться", "молитвовать"],
    "молитвовав": ["молитвовавши"],
    "молитвовавши": ["молитвовав"],
    "молитвовать": ["молиться", "молитвить"],
    "молитвослов": ["молитвенник"],
    "молитвословив": ["молитвословивши"],
    "молитвословивши": ["молитвословив"],
    "молитвословье": ["молитвословие"],
    "молить": ["просить", "умолять"],
    "молиться": ["боготворить", "обожать"],
    "молкав": ["молкавши"],
    "молкавши": ["молкав"],
    "молкнув": ["молкнувши"],
    "молкнувши": ["молкнув"],
    "молкнуть": ["затихать", "замолкать", "смолкать", "умолкать"],
    "молл": ["торговый центр", "торговый комплекс"],
    "моллировав": ["моллировавши"],
    "моллировавши": ["моллировав"],
    "моллюск": ["черепокожное"],
    "моллюскоцид": ["лимацид"],
    "молниевидный": ["молниеподобный"],
    "молниевый": ["молнийный"],
    "молниеносный": ["стремительный", "мгновенный"],
    "молниеотвод": ["громоотвод", "грозоотвод"],
    "молниеподобный": ["молниевидный"],
    "молнийный": ["молниевый"],
    "молнировав": ["молнировавши"],
    "молнировавши": ["молнировав"],
    "молнировать": ["телеграфировать"],
    "молния": ["патент", "срочная телеграмма", "газета-молния"],
    "молов": ["моловши"],
    "моловши": ["молов"],
    "молодайка": ["молодица", "молодка"],
    "молодая": ["новобрачная", "молодуха"],
    "молодая луна": ["молодой месяц"],
    "молодев": ["молодевши"],
    "молодевши": ["молодев"],
    "молодежь": ["молодёжь"],
    "молодеть": ["юнеть"],
    "молодец": ["храбрец", "удалец", "добрый молодец"],
    "молодеческий": ["молодецкий", "молодцеватый", "удалой", "лихой"],
    "молодечествовав": ["молодечествовавши"],
    "молодечествовавши": ["молодечествовав"],
    "молодив": ["молодивши"],
    "молодивши": ["молодив"],
    "молодило": ["суккулент", "многолетник", "артишок дикий", "домашний лук", "чеснок дикий", "репа степная", "живучка", "живучка кровельная", "кровельник", "скочки", "всегда жив", "громовая трава"],
    "молодить": ["омолаживать"],
    "молодица": ["молодка", "молодайка"],
    "молодичка": ["молодиця"],
    "молодка": ["молодица", "молодуха"],
    "молодожён": ["новобрачный", "жених", "молодой", "супруг"],
    "молодой": ["юный", "младой", "зелёный", "желторотый", "неоперившийся", "начинающий", "новый", "недавний", "свежий", "молодой человек", "молодожён", "салага"],
    "молодой человек": ["юноша", "парень", "вьюнош", "вьюноша", "молчел", "молодой чемодан"],
    "молодушка": ["молодица", "молодка"],
    "молодцевав": ["молодцевавши"],
    "молодцевавши": ["молодцевав"],
    "молодцеватый": ["бравый", "залихватский", "молодеческий"],
    "молодцом": ["огурцом"],
    "молодчага": ["молодчина"],
    "молодчик": ["молодец"],
    "молодчина": ["молодец"],
    "молодь": ["молодняк", "молодяжник", "молодятник"],
    "молодёжь": ["молодое поколение", "молодежь", "молодняк"],
    "моложе": ["младше"],
    "молозиво": ["молоко"],
    "молоко на губах не обсохло": ["молоко материно на губах не обсохло", "молоко материнское на губах не обсохло"],
    "молокогонный": ["млекогонный"],
    "молокозавод": ["молзавод"],
    "молокопродукт": ["молочный продукт", "молочка"],
    "молокосос": ["молокососик"],
    "молонья": ["молния"],
    "молотив": ["молотивши"],
    "молотивши": ["молотив"],
    "молотить": ["колотить", "ударять", "лясы точить", "молоть языком", "говорить", "болтать"],
    "молотковый": ["молоточный", "молоточковый"],
    "молоток": ["молот"],
    "молоточный": ["молотковый", "молоточковый"],
    "молофья": ["семя", "сперма", "эякулят", "малафья", "малофья", "спущёнка", "конча"],
    "молочай": ["млечник"],
    "молочение": ["молотьба"],
    "молочка": ["молочница", "резинка"],
    "молочная железа": ["грудь"],
    "молочная кислота": ["лактат"],
    "молочница": ["молошница"],
    "молочно-консервный": ["молококонсервный"],
    "молочно-овощной": ["овоще-молочный"],
    "молочный сахар": ["лактоза"],
    "молчав": ["молчавши"],
    "молчавши": ["молчав"],
    "молчаливо": ["безмолвно", "молча"],
    "молчаливый": ["неразговорчивый"],
    "молчальник": ["молчун"],
    "молчание": ["немотствование", "немота", "тишина", "безмолвие", "затишье"],
    "молчанка": ["молчание"],
    "молчать": ["помалкивать", "безмолвствовать", "хранить молчание"],
    "молчать в тряпочку": ["помалкивать в тряпочку", "молчать в белую тряпочку"],
    "молчел": ["молодой человек"],
    "молчок": ["молчи", "замолчал"],
    "молчун": ["молчальник"],
    "мольба": ["просьба", "моление"],
    "мольберт": ["станок"],
    "моляр": ["коренной зуб"],
    "молярный": ["коренной"],
    "молящий": ["умоляющий"],
    "момент": ["мгновение", "миг", "минута", "секунда", "этап", "период", "пункт"],
    "момент импульса": ["кинетический момент", "угловой момент", "орбитальный момент", "момент количества движения"],
    "момент силы": ["крутящий момент", "вращательный момент", "вертящий момент", "вращающий момент", "скручивающий момент"],
    "моментально": ["мгновенно"],
    "моментальность": ["мгновенность"],
    "моментарный": ["моментальный", "одномоментный"],
    "моментометр": ["торсиометр", "моментомер"],
    "момодоя": ["доя"],
    "момък": ["юноша", "младеж", "ерген"],
    "момыш-улы": ["момышулы"],
    "момышулы": ["момыш-улы"],
    "монада": ["энтелехия"],
    "монако": ["княжество монако"],
    "монарда": ["бергамот"],
    "монарх": ["король", "царь", "самодержец"],
    "монархизм": ["роялизм"],
    "монархически": ["единовластно"],
    "монаршествовав": ["монаршествовавши"],
    "монаршествовавши": ["монаршествовав"],
    "монастырь": ["обитель"],
    "монах": ["чернец", "аскет"],
    "монахиня": ["монашенка", "черница", "инокиня"],
    "монашенка": ["монашка"],
    "монашествовав": ["монашествовавши"],
    "монашествовавши": ["монашествовав"],
    "монашка": ["монахиня", "монашенка"],
    "монголист": ["монголовед"],
    "монголистика": ["монголоведение"],
    "монголия": ["монгольская империя", "монгольская народная республика", "мнр"],
    "монголо-татарский": ["татаро-монгольский"],
    "монголо-татары": ["татаро-монголы"],
    "монголовед": ["монголист"],
    "монголоведение": ["монголистика"],
    "монголоид": ["азиат"],
    "монгольская народная республика": ["мнр"],
    "монда": ["нагузаранда"],
    "мондегрин": ["ослышка"],
    "мондый": ["андый", "шундый", "тегенди"],
    "монегаск": ["монакец"],
    "монера": ["унирема", "дробянка"],
    "монетаризировав": ["монетаризировавши"],
    "монетаризировавши": ["монетаризировав"],
    "монетаризировать": ["монетаризовать"],
    "монетаризовав": ["монетаризовавши"],
    "монетаризовавши": ["монетаризовав"],
    "монетаризовать": ["монетаризировать"],
    "монетарный": ["денежный"],
    "монетизировав": ["монетизировавши"],
    "монетизировавши": ["монетизировав"],
    "монетка": ["денежка"],
    "монжус": ["монтежю"],
    "монитор": ["дисплей", "экран", "моник", "брызгало", "гидромонитор"],
    "мониторив": ["мониторивши"],
    "мониторивши": ["мониторив"],
    "мониторинг": ["наблюдение", "отслеживание"],
    "мониторировав": ["мониторировавши"],
    "мониторировавши": ["мониторировав"],
    "мониторирование": ["мониторинг"],
    "мониторировать": ["мониторить"],
    "мониторироваться": ["мониториться"],
    "мониторить": ["мониторировать"],
    "мониториться": ["мониторироваться"],
    "моно": ["монозвук", "монозвучание"],
    "моно-": ["уни-"],
    "моноаминоксидаза": ["мао"],
    "моноандрия": ["единомужие"],
    "моноатомный": ["одноатомный"],
    "моноблок": ["агрегат"],
    "монобровь": ["синофриз", "чёлка"],
    "моногамический": ["моногамный"],
    "моногамия": ["единобрачие"],
    "моногамный": ["единобрачный", "моногамический"],
    "моногаплоид": ["моноплоид"],
    "моногенез": ["моногенезис"],
    "моногенезис": ["моногенез"],
    "моногенетический": ["моногенный"],
    "моногенный": ["моногенетический"],
    "моногиния": ["единоженство", "одноженство"],
    "монография": ["фармакопейная статья", "фармстатья"],
    "монозиготный": ["однояйцевый", "однояйцовый"],
    "моноимпульсный": ["одноимпульсный"],
    "монокарпическое растение": ["монокарпик"],
    "монокин": ["интерлейкин"],
    "моноклинальный": ["моноклинический", "моноклинный"],
    "моноклинический": ["моноклинальный", "моноклинный"],
    "моноклинный": ["моноклинический", "моноклинальный", "гермафродитный"],
    "монокомпонентный": ["однокомпонентный"],
    "монокультурный лес": ["монолес"],
    "моноласта": ["моноласт"],
    "монолес": ["монокультурный лес"],
    "монолит": ["глыба"],
    "монолог": ["монологическая речь"],
    "моном": ["одночлен"],
    "мономолекулярный": ["одномолекулярный"],
    "мононить": ["моноволокно"],
    "моноокись": ["моноксид", "монооксид", "закись", "одноокись"],
    "монооксид": ["моноксид", "моноокись", "закись", "одноокись"],
    "монооксид углерода": ["угарный газ", "окись углерода"],
    "моноплан": ["одноплан"],
    "монополизировав": ["монополизировавши"],
    "монополизировавши": ["монополизировав"],
    "монополизировать": ["монополизовать"],
    "монополия": ["конгломерат"],
    "монополь": ["монополия"],
    "монопольный": ["бесконкурентный", "монополистический", "единоличный", "единовластный"],
    "монополярный": ["однополярный"],
    "моноптер": ["моноптерос"],
    "монорельсовый": ["однорельсовый"],
    "моносемантический": ["моносемантичный", "моносемичный", "однозначный"],
    "моносемантичный": ["моносемантический", "моносемичный", "однозначный"],
    "моносемичный": ["моносемантический", "моносемантичный", "однозначный"],
    "моносемия": ["однозначность", "моносемичность"],
    "моносиллаб": ["односложный", "слово"],
    "моноскоп": ["монотрубка"],
    "монотеизм": ["единобожие"],
    "монотонний": ["однотонний", "однозвучний"],
    "монотонно": ["однозвучно", "однотонно", "однообразно"],
    "монотонность": ["однообразие", "однообразность"],
    "монотонный": ["однотонный", "однозвучный", "однообразный"],
    "монофазный": ["однофазный"],
    "монофильный": ["мононитевый"],
    "монофобия": ["аутофобия"],
    "монохорд": ["канон", "однострунник"],
    "монохромазия": ["ахроматопсия"],
    "монохроматический": ["одноцветный", "монохромный", "однотонный", "моноэнергетический"],
    "монохроматичность": ["монохромность", "одноцветность"],
    "монохромный": ["чёрно-белый", "бесцветный", "обесцвеченный", "однотонный"],
    "моноцикл": ["уницикл", "юницикл", "юнисайкл"],
    "моноциклический": ["моноцикличный"],
    "монсеньёр": ["высочество", "светлость", "высокопреосвященство"],
    "монстр": ["чудовище", "чудище", "урод", "зверь", "изверг"],
    "монстранц": ["монстранция"],
    "монстровитый": ["монструозный"],
    "монструозность": ["чудовищность", "огромность", "громадность", "гигантизм"],
    "монструозный": ["чудовищный", "гигантский", "громадный", "огромный"],
    "монтаж": ["сборка", "установка"],
    "монтажик": ["монтаж"],
    "монтажист": ["монтажёр", "монтажник"],
    "монтажка": ["монтировка", "фомка"],
    "монтажничав": ["монтажничавши"],
    "монтажничавши": ["монтажничав"],
    "монтажёр": ["монтажист"],
    "монтана": ["штат сокровищ"],
    "монтанист": ["фриг", "квинтиллианин", "прискиллианин", "пепузианин", "артотирит", "катафригаст", "катафригиец", "аскодругит", "таскодругит"],
    "монтенев": ["монтеневский"],
    "монтировав": ["монтировавши"],
    "монтировавши": ["монтировав"],
    "монтирование": ["монтировка", "монтаж"],
    "монтировать": ["собирать", "устанавливать"],
    "монтировка": ["монтирование", "монтаж", "фомка"],
    "монтировщик": ["монт"],
    "монтёр": ["монтажник", "электромонтёр", "электромонтажник"],
    "монтёрив": ["монтёривши"],
    "монтёривши": ["монтёрив"],
    "монументальный": ["грандиозный", "масштабный"],
    "моншер": ["шикарь", "фат", "форсун", "вивёр", "жуир", "щёголь", "франт", "фешенебль", "денди", "пшют", "хлыщ", "пижон", "стиляга"],
    "монь": ["эсь"],
    "моня": ["мамон", "мамона", "пузо", "брюхо", "чрево", "желудок"],
    "мор": ["поветрие", "эпидемия"],
    "мораковав": ["мораковавши"],
    "мораковавши": ["мораковав"],
    "мораковать": ["мороковать"],
    "морализатор": ["моралист"],
    "морализаторствовать": ["морализировать"],
    "морализировав": ["морализировавши"],
    "морализировавши": ["морализировав"],
    "морализовав": ["морализовавши"],
    "морализовавши": ["морализовав"],
    "морализовать": ["поучать"],
    "моралист": ["нравоучитель", "проповедник"],
    "мораль": ["нравственность", "нравоучение", "наставление"],
    "моральное насилие": ["психологическое насилие"],
    "моральный": ["этический", "нравственный", "высоконравственный", "этичный"],
    "мораторий": ["отсрочка", "моратория", "приостановка"],
    "моратория": ["мораторий", "мораториум"],
    "морбидный": ["болезненный"],
    "морг": ["покойницкая", "мертвецкая"],
    "моргав": ["моргавши"],
    "моргавши": ["моргав"],
    "моргание": ["морганье", "мигание"],
    "морганит": ["воробьевит"],
    "морганье": ["моргание"],
    "моргнув": ["моргнувши"],
    "моргнувши": ["моргнув"],
    "моргнуть": ["мигнуть"],
    "моргослепый": ["подслеповатый"],
    "моргуха": ["моргунья"],
    "морда": ["рыло", "рожа", "храп", "харя", "мордасы", "морда лица", "ряха", "бубен", "пятак", "фетель", "фасад"],
    "мордатенький": ["мордастенький"],
    "мордаш": ["мордашка", "меделян", "меделянка"],
    "мордвинка": ["мордовка"],
    "мордобитие": ["мордобой"],
    "мордобитье": ["мордобитие"],
    "мордобой": ["мордобитие"],
    "мордобойничав": ["мордобойничавши"],
    "мордобойничавши": ["мордобойничав"],
    "мордовав": ["мордовавши"],
    "мордовавши": ["мордовав"],
    "мордовия": ["республика мордовия"],
    "мордовка": ["мордвинка"],
    "мордодел": ["имиджмейкер", "пиарщик"],
    "мордой об стол": ["фейсом об тейбл"],
    "море": ["морейский язык", "мооре", "моши", "мосси"],
    "море лаптевых": ["татарское море", "ленское море", "сибирское море", "ледовитое море", "норденшельдово море", "море норденшельда"],
    "моревед": ["океановед", "океанолог", "океанограф"],
    "мореведение": ["океанология", "океанография", "талассография"],
    "мореман": ["корабельщик", "мореплаватель", "мореход", "мореходец", "морской волк", "моряк", "пловец", "мореманка", "моривумен"],
    "мореописание": ["талассография", "гидрография"],
    "мореплавание": ["мореходство"],
    "мореплаванье": ["мореплавание"],
    "мореплаватель": ["мореход", "моряк"],
    "мореплавательница": ["морячка"],
    "мореход": ["мореплаватель", "моряк"],
    "моржевав": ["моржевавши"],
    "моржевавши": ["моржевав"],
    "морзянка": ["азбука морзе"],
    "морив": ["моривши"],
    "моривши": ["морив"],
    "морилка": ["кокономорилка", "бейц", "кёльнская земля"],
    "морин": ["тетраоксифлавонол"],
    "морква": ["морковь"],
    "морковка": ["морковь", "уступи дорогу"],
    "морковь": ["морковка", "морква"],
    "мормонизм": ["мормонство"],
    "мормонство": ["мормонизм"],
    "мормыш": ["гаммарус", "бормыш", "горбунец", "козявка", "рачок"],
    "мороженник": ["мороженщик"],
    "мороженое": ["мороженка"],
    "мороженщик": ["мороженник"],
    "морожка": ["мороженое"],
    "мороз": ["стужа", "мраз", "холод"],
    "морозив": ["морозивши"],
    "морозивши": ["морозив"],
    "морозилка": ["морозильная камера", "морозильник"],
    "морозильник": ["морозилка"],
    "морозить": ["знобить"],
    "морозиться": ["мяться", "ломаться"],
    "морозко": ["мороз", "студенец", "трескунец", "зюзя", "король мороз", "генерал мороз", "джек фрост", "ледяной джек"],
    "морозная трещина": ["морозобоина", "морозобой", "расстрел", "зяблина", "морозобойная трещина"],
    "морозний": ["морозяний"],
    "морозник": ["зимовник"],
    "морозобоина": ["морозобой", "морозная трещина", "расстрел", "зяблина"],
    "морозостойкий": ["зимостойкий", "морозоустойчивый", "морозоупорный"],
    "морозоупорный": ["морозостойкий"],
    "морозоустойчивый": ["морозостойкий"],
    "морок": ["мрак", "сумрак", "темнота", "марево", "мгла", "обморок", "припадок"],
    "морока": ["возня", "тягомотина", "канитель", "маета"],
    "мороковав": ["мороковавши"],
    "мороковавши": ["мороковав"],
    "мороковать": ["мораковать"],
    "морольф": ["марольф", "маркольф", "маркульф", "маркуль", "морольд"],
    "морон": ["дебил"],
    "моросив": ["моросивши"],
    "моросивши": ["моросив"],
    "морось": ["изморось"],
    "морочив": ["морочивши"],
    "морочивши": ["морочив"],
    "морочить голову": ["обманывать", "дурачить", "темнить", "сбивать", "путать", "запутывать"],
    "морошка": ["северная малина", "моховая смородина", "глошина"],
    "морпех": ["морской пехотинец"],
    "морская болезнь": ["кинетоз"],
    "морская курица": ["камбала", "тунец", "тилапия"],
    "морская свинка": ["гвинейская свинка", "кейви", "кеви"],
    "морские водоросли": ["ламинарии", "морская капуста"],
    "морской виноград": ["кокколоба"],
    "морской дракончик": ["змейка", "рыба-паук", "вива"],
    "морской жёлудь": ["балянус"],
    "морской кот": ["обыкновенный хвостокол"],
    "морской лев": ["сивуч"],
    "морской чёрт": ["удильщик", "европейский удильщик"],
    "морской язык": ["европейская солея"],
    "мортира": ["миномёт"],
    "морф": ["морфа"],
    "морфа": ["морф"],
    "морфий": ["морфин", "ораморф"],
    "морфин": ["морфий", "ораморф"],
    "морфировав": ["морфировавши"],
    "морфировавши": ["морфировав"],
    "морфоанализатор": ["морфологический анализатор"],
    "морфовар": ["морфотип"],
    "морфогенез": ["геоморфогенез"],
    "морфогения": ["морфонез"],
    "морфологизировав": ["морфологизировавши"],
    "морфологизировавши": ["морфологизировав"],
    "морфологизовав": ["морфологизовавши"],
    "морфологизовавши": ["морфологизовав"],
    "морфонема": ["коррелятива", "морфофонема"],
    "морфонология": ["морфофонология", "морфологическая фонология", "фономорфология"],
    "морфофонема": ["коррелятива", "морфонема", "морфологическая фонема"],
    "морфофонемика": ["морфонология"],
    "морщив": ["морщивши"],
    "морщивши": ["морщив"],
    "морщинив": ["морщинивши"],
    "морщинивши": ["морщинив"],
    "морщинистый": ["съёженный", "съёжившийся"],
    "морщить": ["морщинить", "наморщивать", "ёжить", "сморщивать", "хмурить", "гримасничать", "рябить", "колыхать", "волновать"],
    "морщить жопу": ["жопу морщить"],
    "морь": ["адуу"],
    "морянка": ["саук", "алейка", "аллейка"],
    "моряцки": ["по-моряцки"],
    "морячив": ["морячивши"],
    "морячивши": ["морячив"],
    "морячка": ["мореплавательница"],
    "мосинка": ["трёхлинейка"],
    "москаль": ["кацап"],
    "москва-река": ["река"],
    "москвабад": ["москвастан", "москвачкала"],
    "москвит": ["московит"],
    "москвитянин": ["московит", "москвит", "московитянин"],
    "москвитянка": ["россиянка"],
    "москвич": ["столичник", "москвитянин", "московец", "московит", "москаль"],
    "москвичка": ["московочка"],
    "москвичок": ["москвичонок"],
    "москвичонок": ["москвичок"],
    "москвожерство": ["москвоненависництво", "москвофобство", "русоненависництво"],
    "московец": ["неместный"],
    "московий": ["унунпентий", "эка-висмут"],
    "московит": ["москвит", "московитянин"],
    "московиум": ["московий"],
    "московия": ["русь"],
    "московская область": ["подмосковье"],
    "мослак": ["мосол"],
    "мосластый": ["мослатый"],
    "мослатый": ["мосластый"],
    "мосол": ["мослак"],
    "мостивши": ["мостив"],
    "мостик": ["мост"],
    "мостить": ["замащивать", "выкладывать", "настилать", "укладывать", "устраивать"],
    "моститься": ["примащиваться", "замащиваться"],
    "мостище": ["мегамост"],
    "мостки": ["мосток", "леса", "подмостки", "сходни"],
    "мостовая": ["проезжая часть"],
    "мостовщик": ["мостильщик"],
    "мосток": ["мостик", "мостки"],
    "мостра": ["образец"],
    "мостырка": ["мастырка"],
    "мосх": ["месх", "мешех"],
    "моська": ["жучка", "козявка", "чушка"],
    "мосяжевий": ["латунний", "мосяжний"],
    "мосяжний": ["латунний", "мосяжевий"],
    "мот": ["расточитель", "транжир", "транжира"],
    "мотав": ["мотавши"],
    "мотавши": ["мотав"],
    "мотанув": ["мотанувши"],
    "мотанувши": ["мотанув"],
    "мотанье": ["мотание"],
    "мотард": ["супермотард"],
    "мотать": ["наматывать", "махать", "качать", "отбывать", "транжирить", "проматывать"],
    "мотать на ус": ["запоминать", "прислушиваться"],
    "мотать себе на ус": ["намотать себе на ус", "наматывать себе на ус"],
    "мотельный": ["гостиничный"],
    "моти": ["мочи"],
    "мотив": ["напев", "мелодия", "идея", "лейтмотив", "тема", "сюжет", "повод", "причина", "побуждение", "довод"],
    "мотиватор": ["стимул", "побудитель"],
    "мотивация": ["мотивирование", "мотивировка", "стимулирование", "обоснование", "объяснение", "мотив", "стимул"],
    "мотивировав": ["мотивировавши"],
    "мотивировавши": ["мотивировав"],
    "мотивированность": ["мотивация", "заинтересованность"],
    "мотивировать": ["объяснять", "стимулировать"],
    "мотивировка": ["мотивация"],
    "мотик": ["мотоцикл", "мотоциклет", "мотоциклетка", "моцик"],
    "мотнув": ["мотнувши"],
    "мотнувши": ["мотнув"],
    "мотня": ["гузырь", "ширинка", "беготня", "возня", "дёрганье", "мотание", "суета", "суетня", "суматоха", "уполох", "чехарда", "висюлька", "сопля"],
    "мотобур": ["бензобур"],
    "мотоватый": ["расточительный"],
    "мотовило": ["мотовильце"],
    "мотовка": ["транжира"],
    "мотовство": ["расточительность"],
    "мотодельтаплан": ["дельтаплан"],
    "мотокоса": ["триммер", "мотокосилка"],
    "мотолодка": ["моторная лодка", "моторка"],
    "мотолыга": ["мостолыга"],
    "мотомарафон": ["мотопробег"],
    "мотонарты": ["снегоход"],
    "мотопила": ["бензопила"],
    "мотопомпа": ["приводной насос"],
    "мотопоход": ["мотопробег"],
    "мотопробег": ["мотопоход", "мотокросс"],
    "мотор": ["двигатель", "движок", "автомобиль", "такси", "таксо", "таксомотор", "частник", "бомбила"],
    "мотор-шоу": ["автосалон"],
    "моторизировав": ["моторизировавши"],
    "моторизировавши": ["моторизировав"],
    "моторизировать": ["моторизовать"],
    "моторизовав": ["моторизовавши"],
    "моторизовавши": ["моторизовав"],
    "моторизованный": ["моторизированный"],
    "моторизовать": ["моторизировать"],
    "моторикша": ["мототакси"],
    "моторка": ["моторная лодка", "мотолодка"],
    "моторная лодка": ["моторка", "мотолодка"],
    "моторный": ["двигательный", "моторизованный"],
    "моторокер": ["байкер", "рокер"],
    "моторчик": ["мотор"],
    "мотосани": ["снегоход"],
    "мотоспорт": ["мотоциклетный спорт"],
    "мотострелок": ["пехотинец", "чернопиджачник", "серопиджачник", "черносвитник", "чернокнижник", "чёрная пехота"],
    "мотоцикл": ["мотоциклет", "мотоциклетка", "байк", "мототайка", "мотик", "моцик", "мот"],
    "мотоциклетист": ["мотоциклист"],
    "мотоциклетный спорт": ["мотоспорт"],
    "мотриса": ["автомотриса", "автовагон"],
    "мотто": ["девиз"],
    "мотузка": ["мотузок"],
    "мотузок": ["мотузка", "мотуз", "швара", "швора", "шворка", "поворозка", "повороз", "шнурок", "шнур", "шкерт", "ужва"],
    "мотыга": ["тяпка"],
    "мотыжив": ["мотыживши"],
    "мотыживши": ["мотыжив"],
    "мотыль": ["бабочка", "мотылёк"],
    "мотылёк": ["моль", "бабочка"],
    "мотя": ["матвей", "матюша", "матвейка"],
    "моу": ["муниципальное образовательное учреждение"],
    "мохав": ["мохавши"],
    "мохавши": ["мохав"],
    "моханат": ["панорм"],
    "мохнатев": ["мохнатевши"],
    "мохнатевши": ["мохнатев"],
    "мохнатив": ["мохнативши"],
    "мохнативши": ["мохнатив"],
    "мохнатка": ["баба", "женщина", "тёлка"],
    "мохнатый": ["пушистый"],
    "моховев": ["моховевши"],
    "моховевши": ["моховев"],
    "моховка": ["моховица", "смородина моховая"],
    "мохряк": ["оборванец", "нищий", "бомж"],
    "мохэ": ["мукри"],
    "моцион": ["променад", "терренкур"],
    "моча": ["урина", "ссака", "ссаки", "ссаньё", "рассол", "жёлтый дождь"],
    "мочажина": ["мочага"],
    "мочажинный": ["мочажный"],
    "мочажный": ["мочажинный"],
    "мочалив": ["мочаливши"],
    "мочаливши": ["мочалив"],
    "мочалить": ["измочаливать", "мучить", "терзать", "бить", "избивать"],
    "мочевик": ["мочевой пузырь", "писсуар"],
    "мочевина": ["карбамид", "диамид угольной кислоты"],
    "мочевой пузырь": ["мочевик"],
    "мочевыделение": ["мочеиспускание"],
    "мочевыделительная система": ["мочевыводящие пути"],
    "мочегонное": ["диуретик"],
    "мочегонный": ["диуретический"],
    "мочеизнурение": ["полиурия"],
    "мочеиспускание": ["деуринация"],
    "мочеиспускательный канал": ["уретра"],
    "мочекровие": ["уремия"],
    "моченье": ["мочение"],
    "мочеполовой": ["урогенитальный"],
    "мочеприёмник": ["утка"],
    "мочив": ["мочивши"],
    "мочивши": ["мочив"],
    "мочиловка": ["мочилово", "бойня"],
    "мочилово": ["месилово", "бойня", "мочиловка", "заварушка"],
    "мочить в сортире": ["в сортире мочить"],
    "мочиться": ["писать", "ссать", "сцать", "сикать", "ходить по-малому", "ходить по малой нужде", "мокнуть"],
    "мочур": ["мочурище", "тресавище", "блато", "батак"],
    "мочь": ["быть в состоянии", "быть в силах", "уметь"],
    "мошва": ["мошка"],
    "мошенник": ["карманник", "щипач", "карманщик"],
    "мошенница": ["плутовка", "воровка", "прохиндейка", "шулерша", "штукарка"],
    "мошенничав": ["мошенничавши"],
    "мошенничавши": ["мошенничав"],
    "мошенничество": ["жульничество", "плутовство", "мошенство", "мошонка"],
    "мошенство": ["мошенничество", "надувательство", "блеф", "жульство", "развод", "разводилово", "липа"],
    "мошка": ["мшица"],
    "мошкара": ["мошка"],
    "мошна": ["кошель", "кошелёк"],
    "мошня": ["мошенник", "жулик", "жульё"],
    "мошонка": ["мудо", "шары", "мошна", "мошенничество", "мошенство"],
    "мощенье": ["мощение"],
    "мощи": ["прах", "останки", "тело", "труп", "живые мощи", "явленые мощи", "кожа да кости", "краше в гроб кладут", "жертва бухенвальда", "жертва освенцима", "худоба", "худобища", "худышка", "дрыщ"],
    "мощнеть": ["крепнуть", "усиливаться"],
    "мощно": ["сильно"],
    "мощный": ["сильный", "могучий", "мощнецкий", "мощняцкий", "мощнючий", "могущественный", "крепкий", "массивный", "величественный", "грандиозный"],
    "мощь": ["сила", "мощность", "могущество"],
    "моя хата с краю": ["плевать", "не моё дело"],
    "мп": ["малое предприятие", "муниципальное предприятие", "морская пехота", "мобилизационный план", "медицинский пункт", "московский патриархат", "русская православная церковь", "рпц"],
    "мраз": ["мороз", "стужа"],
    "мразота": ["мразь"],
    "мразъ": ["морозъ"],
    "мразь": ["дрянь", "ничтожество"],
    "мразючный": ["мерзкий"],
    "мрак": ["тьма", "темнота", "мгла"],
    "мракобес": ["обскурант"],
    "мракобесие": ["обскурантизм"],
    "мракобесье": ["мракобесие"],
    "мраморировав": ["мраморировавши"],
    "мраморировавши": ["мраморировав"],
    "мраморирование": ["марморирование"],
    "мраморировка": ["марморация", "мраморирование"],
    "мрачив": ["мрачивши"],
    "мрачивши": ["мрачив"],
    "мрачина": ["мрак", "полумрак", "тъмнина", "мрачевина", "мръкнало", "здрач"],
    "мрачнев": ["мрачневши"],
    "мрачневши": ["мрачнев"],
    "мрачный": ["тёмный"],
    "мрачун": ["угрюмец"],
    "мрев": ["мревши"],
    "мревши": ["мрев"],
    "мреть": ["переливаться", "струиться", "брезжить", "мерцать", "расплываться", "маячить", "казаться", "чудиться"],
    "мрець": ["мертвець", "мертвий", "померлий", "умерлий", "мерлий", "мертвяк", "порох", "прах"],
    "мрнк": ["ирнк"],
    "мрот": ["минимальный размер оплаты труда"],
    "мртвац": ["леш"],
    "мрут как мухи": ["дохнут как мухи"],
    "мръсник": ["безсрамник", "подлец", "безчестник", "мизерник", "мерзавец"],
    "мръсота": ["мръсотия", "нечистотия", "низост", "подлост", "безчестие"],
    "мряка": ["туман", "мжичка", "сльота"],
    "мсс": ["международный союз студентов"],
    "мста": ["месть", "мщение"],
    "мстив": ["мстивши"],
    "мстивши": ["мстив"],
    "мстиславец": ["мстиславчанин"],
    "мстиславчанин": ["мстиславец"],
    "мститель": ["отместник", "отместница", "отмститель", "отмстительница", "отомститель", "отомстительница"],
    "мтквари": ["кура"],
    "му": ["пацифида"],
    "муаллим": ["учитель"],
    "муаллиф": ["мусанниф"],
    "муар": ["муаре"],
    "муаре": ["муар", "моар", "моаре"],
    "муарировав": ["муарировавши"],
    "муарировавши": ["муарировав"],
    "муаровый": ["муарный"],
    "мубин": ["равшан"],
    "мубинахон": ["мубина"],
    "мубтадо": ["фоил"],
    "мугат": ["джуг", "люли"],
    "мугеру": ["гагьо", "гогьари", "гампар"],
    "муда": ["муда с пруда", "болван", "дурак", "идиот", "мудак", "мудила", "мудило"],
    "мудаввар": ["даврашакл"],
    "мударрис": ["муаллим"],
    "мудачьё": ["дурачьё", "дебильё"],
    "мудашвили": ["мудачьё"],
    "мудев": ["мудевши"],
    "мудевши": ["мудев"],
    "мудень": ["мудак"],
    "мудеть": ["пиздеть"],
    "мудив": ["мудивши"],
    "мудивши": ["мудив"],
    "мудизм": ["бездумность", "неблагоразумие", "безголовость", "бестолковость", "скудоумие", "скудоумье", "тупоумие", "тупоумье", "тупоголовость", "узколобость", "идиотизм", "кретинизм", "головотяпство", "дурость", "мудачество"],
    "мудила": ["мудак", "мудило"],
    "мудило": ["глупец", "идиот", "болван", "дурак", "мудак", "мудло", "мудила", "мудель", "мудень", "мудик", "мудилка", "мудилоид", "мудильник", "мудильщик", "мудифел"],
    "мудной": ["прикольный"],
    "мудня": ["хуйня", "еботень", "поебень", "поебота", "мудянка", "мудятина", "мудоблядство", "мура", "туфта", "фигня", "херня", "херотень", "глупость", "ахинея", "херовина"],
    "мудо": ["яичко", "тестикула", "яйцо", "мошонка", "мужская добродетель", "хозяйство", "мужское хозяйство", "прибор", "гонады"],
    "мудозвон": ["раздолбай", "яйцетряс"],
    "мудохав": ["мудохавши"],
    "мудохавши": ["мудохав"],
    "мудохаться": ["возиться", "ковыряться"],
    "мудрев": ["мудревши"],
    "мудревши": ["мудрев"],
    "мудреть": ["умнеть"],
    "мудрець": ["вчений"],
    "мудрив": ["мудривши"],
    "мудривши": ["мудрив"],
    "мудрить": ["умничать", "хитрить", "издеваться"],
    "мудровав": ["мудровавши"],
    "мудровавши": ["мудровав"],
    "мудрование": ["умничание"],
    "мудрованье": ["мудрование"],
    "мудровать": ["умничать", "хитрить", "издеваться"],
    "мудрость": ["ум", "разумность", "премудрость", "замысловатость", "сложность", "хитрость", "хитроумность", "афоризм", "высказывание", "максима", "поговорка"],
    "мудрствовав": ["мудрствовавши"],
    "мудрствовавши": ["мудрствовав"],
    "мудрствовать": ["умничать", "мудрить"],
    "мудрёно": ["замысловато"],
    "мудрёный": ["замысловатый", "затейливый", "трудный", "загадочный"],
    "мужав": ["мужавши"],
    "мужавши": ["мужав"],
    "мужаться": ["крепиться"],
    "мужеложеский": ["педерастический"],
    "мужеложество": ["мужеложство", "мужелегание", "содомия"],
    "мужеложествовав": ["мужеложествовавши"],
    "мужеложествовавши": ["мужеложествовав"],
    "мужеложец": ["содомит", "педераст", "гомосексуалист", "гомосексуал", "гей", "педик", "гомик", "патикус", "пидер", "уранист", "урнинг", "голубой", "жопошник"],
    "мужеложство": ["мужеложество", "мужелегание", "содомия"],
    "мужененавистнический": ["мизандрический"],
    "мужененавистничество": ["андрофобия"],
    "муженёк": ["супружник", "муж"],
    "мужеподобный": ["мужеобразный"],
    "мужественно": ["храбро", "отважно", "смело", "доблестно", "бесстрашно"],
    "мужественный": ["стойкий", "энергичный", "храбрый", "женственный", "девчачий"],
    "мужество": ["храбрость", "отвага", "смелость", "доблесть", "бесстрашие"],
    "мужествовав": ["мужествовавши"],
    "мужествовавши": ["мужествовав"],
    "мужик": ["селянин", "селяк"],
    "мужичина": ["мужик"],
    "мужичонка": ["мужичонко"],
    "мужичонко": ["мужичонка"],
    "мужичьё": ["мужик"],
    "мужний": ["мужнин"],
    "мужское достоинство": ["мужская честь"],
    "мужской пол": ["мужчины", "сильный пол", "бабы"],
    "мужской половой орган": ["антеридий", "пенис", "псевдопенис"],
    "мужчина": ["мужик", "дядя", "сильный пол", "муж", "гражданин", "сударь", "месье", "господин", "баба с яйцами"],
    "мужчинка": ["наннандрий"],
    "муза": ["вдохновение", "творчество", "поэзия", "цевница", "лира", "вдохновительница", "вдохновитель"],
    "музгъуллух": ["музгуллук"],
    "муздозвон": ["мудак"],
    "музеевед": ["музеолог"],
    "музееведение": ["музеология", "херитология", "музееведенье"],
    "музееведенье": ["музееведение", "музеология", "херитология"],
    "музеефицировав": ["музеефицировавши"],
    "музеефицировавши": ["музеефицировав"],
    "музеолог": ["музеевед"],
    "музеологический": ["музееведческий"],
    "музеология": ["музееведение"],
    "музики": ["гулянка"],
    "музикувати": ["музичити"],
    "музикус": ["музыкант", "композитор", "лабух"],
    "музицировав": ["музицировавши", "музицируя"],
    "музицировавши": ["музицировав", "музицируя"],
    "музицируя": ["музицировав"],
    "музон": ["музыка"],
    "музшкола": ["музыкалка"],
    "музыка": ["мелодия", "композиция"],
    "музыкальное произведение": ["музыкальная композиция"],
    "музыкальный": ["мелодичный"],
    "музыкальный интервал": ["интервал"],
    "музыкальный центр": ["музцентр"],
    "музыкант": ["игруля", "лабух"],
    "музыкантствовав": ["музыкантствовавши"],
    "музыкантствовавши": ["музыкантствовав"],
    "музыкантствовать": ["музицировать"],
    "музыкантша": ["музыкантка"],
    "музыковедение": ["музыкознание"],
    "музяка": ["музыка"],
    "мука": ["мучение", "страдание", "боль", "мытарство", "пытка", "истязание"],
    "мукарна": ["мукарнас"],
    "мукбанг": ["мокпан"],
    "мукден": ["шэньян"],
    "муковисцидоз": ["кистозный фиброз"],
    "мукоза": ["слизистая"],
    "мукоид": ["мукопротеид"],
    "мукомол": ["мельник"],
    "мукомольничав": ["мукомольничавши"],
    "мукомольничавши": ["мукомольничав"],
    "мукополисахарид": ["гликозаминогликан"],
    "мукопротеин": ["мукополисахарид", "гликопротеин", "гликозаминогликан"],
    "муксун": ["максун", "моксун", "муцун"],
    "мулемул": ["парапар"],
    "мулкуватий": ["мулуватий"],
    "мултук": ["карамультук", "мультук", "пищаль", "мушкет"],
    "мулуватий": ["мулистий"],
    "мульт": ["мультипликационный фильм", "мультфильм", "анимационный фильм", "мультик", "анимашка", "мультяшка", "мультипликаторная катушка"],
    "мультиварка": ["мультя"],
    "мультивектор": ["поливектор"],
    "мультиграф": ["псевдограф"],
    "мультизадачность": ["многозадачность", "мультитаскинг"],
    "мультизадачный": ["многозадачный"],
    "мультик": ["мультфильм"],
    "мультикогерентный": ["многосвязный"],
    "мультиконфессиональный": ["многоконфессиональный", "поликонфессиональный"],
    "мультикультурализм": ["многокультурность"],
    "мультилингв": ["полилингв", "полиглот"],
    "мультилингвизм": ["полилингвизм"],
    "мультилингвистический": ["многоязыковой", "мультиязыковой"],
    "мультимедийность": ["многокомпонентность"],
    "мультиметр": ["авометр", "ампервольтомметр"],
    "мультимодальный": ["многорежимный", "многомодальный"],
    "мультинациональный": ["транснациональный", "многонациональный"],
    "мультиплексировав": ["мультиплексировавши"],
    "мультиплексировавши": ["мультиплексировав"],
    "мультипликат": ["аниматик"],
    "мультипликативный": ["умножающий"],
    "мультипликационный фильм": ["анимационный фильм", "мультфильм"],
    "мультипликация": ["анимация", "мультфильм"],
    "мультиплицировав": ["мультиплицировавши"],
    "мультиплицировавши": ["мультиплицировав"],
    "мультиплицирование": ["размножение", "умножение"],
    "мультипотенциал": ["полимат"],
    "мультисрезовый": ["многосрезовый"],
    "мультитаскер": ["многозадачник"],
    "мультитаскинг": ["многозадачность", "мультизадачность"],
    "мультитейблив": ["мультитейбливши"],
    "мультитейбливши": ["мультитейблив"],
    "мультитул": ["мультиинструмент"],
    "мультифазовый": ["многофазный", "многофазовый"],
    "мультиферроик": ["сегнетомагнетик"],
    "мультифора": ["файл", "папка"],
    "мультифункциональный": ["многофункциональный"],
    "мультиэтнический": ["мультиэтничный", "многоэтнический", "многоэтничный"],
    "мультиязычный": ["многоязычный", "мультиязыковой"],
    "мультук": ["карамультук", "мултук", "пищаль", "мушкет"],
    "мультфильм": ["мультик", "мульт", "анимационный фильм", "мультипликационный фильм"],
    "мультя": ["мультиварка"],
    "мультяшка": ["мульт"],
    "мульчировав": ["мульчировавши"],
    "мульчировавши": ["мульчировав"],
    "муляж": ["макет", "модель", "кукла", "слепок"],
    "муляти": ["мулити"],
    "мумбаец": ["бомбеец"],
    "мумбаи": ["бомбей"],
    "мумифицировав": ["мумифицировавши"],
    "мумифицировавши": ["мумифицировав"],
    "мумифицирование": ["мумификация"],
    "мумиё": ["горный воск", "горное масло", "сибирское горное масло"],
    "мундир": ["униформа", "форма", "форменная одежда", "китель", "роба"],
    "мундштук": ["амбушюр", "удила", "заеда"],
    "мундштуковий": ["мундштучний"],
    "мундштучив": ["мундштучивши"],
    "мундштучивши": ["мундштучив"],
    "мунзурух": ["нузурух"],
    "мунист": ["мунит"],
    "мунистский": ["мунитский", "муновский"],
    "мунит": ["мунист"],
    "мунитский": ["мунистский", "муновский"],
    "муниципализировав": ["муниципализировавши"],
    "муниципализировавши": ["муниципализировав"],
    "муновский": ["мунистский", "мунитский"],
    "мунштук": ["мундштук"],
    "мур": ["мурлык"],
    "муравей": ["мураш", "мурашка", "комашка"],
    "муравейник": ["муравьище", "муравище", "мурашник", "муравельник", "толпа", "сборище", "высотка"],
    "муравив": ["муравивши"],
    "муравивши": ["муравив"],
    "муравление": ["муравленье"],
    "муравушка": ["мурава"],
    "муравчатый": ["травянистый"],
    "муравьиная кислота": ["метановая кислота"],
    "муравьёв-карский": ["муравьёв-карсский"],
    "муравьёвский воротник": ["столыпинский галстук", "муравьёвский галстук", "столыпинский галстух"],
    "мурал": ["мураль"],
    "мураль": ["мурал"],
    "мурамидаза": ["лизоцим"],
    "мурамур": ["карлуха"],
    "мурафет": ["майсторлък", "майстория", "майсторство", "умение", "изкуство"],
    "мураха": ["мурманька"],
    "мураш": ["муравей", "мурашка"],
    "мурашиний": ["мурманьчий"],
    "мурашка": ["муравей", "мураш", "букашка"],
    "мурашкинец": ["большемурашкинец"],
    "мурашник": ["мурманьча громадка"],
    "муреин": ["пептидогликан"],
    "мурзак": ["татарин"],
    "мурзик": ["коротышка"],
    "мурзилка": ["мурзик", "виртуал", "кукловод", "спойлер"],
    "мурзиться": ["рычать"],
    "мурка": ["кошка", "киса"],
    "мурло": ["морда", "рожа", "харя", "рыло", "хайло", "циферблат", "ебало", "еблет", "хамло", "хуйло"],
    "мурлык": ["мур"],
    "мурлыка": ["кот"],
    "мурлыкав": ["мурлыкавши"],
    "мурлыкавши": ["мурлыкав"],
    "мурлыкание": ["мурлыканье", "мурчание"],
    "мурлыканье": ["мурлыкание", "мурчание"],
    "мурлыкать": ["мурчать"],
    "мурлыкнув": ["мурлыкнувши"],
    "мурлыкнувши": ["мурлыкнув"],
    "мурман": ["норманны", "норвежцы", "норманн", "норвежец", "кевролец"],
    "мурманец": ["сторис", "бухта мурманца", "мыс мурманца", "мыс никольского", "пролив мурманца"],
    "мурмания": ["маремания"],
    "мурманка": ["кола", "ленинградка", "кировская железная дорога", "мурванка", "мурмолка", "мурмонка", "шизо", "мурманчанка"],
    "мурманрыбпромовец": ["мурмансельдевец"],
    "мурмансельдевец": ["мурманрыбпромовец"],
    "мурманск": ["романов-на-мурмане", "мурик", "столица заполярья", "столица арктики", "рыбная столица", "мурманский порт", "мурмаши", "килпъявр", "милуоки"],
    "мурманская губерния": ["мурманская область", "мурманский край", "кольский край", "подмурманье", "мурманщина", "мурманчания"],
    "мурманская область": ["мурманская губерния", "мурманский край", "кольский край", "подмурманье", "мурманщина", "мурманчания"],
    "мурманские ворота": ["михаил архангел"],
    "мурманский берег": ["мурман", "поморский берег", "русский берег"],
    "мурманский край": ["мурманский район", "мурманская область", "мурманская губерния", "кольский край", "подмурманье", "мурманщина", "мурманчания"],
    "мурманский уезд": ["александровский уезд", "кольский уезд"],
    "мурманско-норвежский": ["норвежско-мурманский"],
    "мурманское море": ["баренцево море"],
    "мурманцы": ["мурашики"],
    "мурманчанин": ["мурманец"],
    "мурманчания": ["мурманская область", "подмурманье", "мурманщина"],
    "мурманчаночка": ["мурманчанка"],
    "мурманчанский": ["мурманский"],
    "мурманщик": ["мурманянин", "помор"],
    "мурманщина": ["мурманская область", "мурманчания", "подмурманье"],
    "мурманька": ["мураха", "мурвань"],
    "мурманьчий": ["мурашиний"],
    "мурманянин": ["мурманщик", "помор"],
    "мурмиллон": ["мирмилон", "мурмилон"],
    "мурмолка": ["мурманка"],
    "муровав": ["муровавши"],
    "муровавши": ["муровав"],
    "муродиф": ["мутародиф"],
    "муромец": ["муромлянин", "муромчанин"],
    "муромка": ["ширкоисс"],
    "муртад": ["аздингашта"],
    "муртинец": ["большемуртинец"],
    "мурцовка": ["марцовка", "мурсофка", "мурца", "мурцовка-тюря", "тюря", "холодный суп", "пеммикан", "пищевой концентрат", "годинушка", "лихая година", "лихолетье", "бодяга", "байда", "хрень", "шляпа"],
    "мурчав": ["мурчавши"],
    "мурчавши": ["мурчав"],
    "мурчание": ["мурлыкание"],
    "мурчать": ["мурлыкать"],
    "муршид": ["муаллим"],
    "мурыжив": ["мурыживши"],
    "мурыживши": ["мурыжив"],
    "мурыжить": ["оттягивать", "тянуть время", "тянуть канитель", "устраивать волокиту", "досаждать", "мучить", "издеваться", "измываться"],
    "мус": ["гаага"],
    "мусавны": ["радейтны", "любитны"],
    "мусагет": ["музагет", "аполлон"],
    "мусанниф": ["муаллиф"],
    "мусарня": ["милиция", "легавка", "ментовка", "ментовская", "ментура", "ментхауз", "мусорка"],
    "мусат": ["сталька"],
    "мусибат": ["бало", "фалокат"],
    "мусивный": ["мозаиковый", "мозаический", "мозаичный", "музивный", "мусийный", "муссивный", "составной", "многосоставной", "многокомпонентный", "смешанный", "вставочный"],
    "мусикийский": ["музыкальный"],
    "мусикия": ["музыка"],
    "мускари": ["гадючный лук", "мышиный гиацинт"],
    "мускат": ["мускатный орех"],
    "мускатель": ["мюскадель"],
    "мускатник": ["мускатный орех", "мускатное дерево"],
    "мускатный цвет": ["мацис"],
    "мусковит": ["калиевая слюда", "московское стекло"],
    "мусковитный": ["мусковитовый"],
    "мусковитовый": ["мусковитный"],
    "мускул": ["мышца"],
    "мускулатура": ["мышечная система"],
    "мускулатурный": ["мускульный", "мышечный"],
    "мускулистый": ["атлетичный"],
    "мускульный": ["мышечный"],
    "мускульный желудок": ["мускулистый желудок", "мышечный желудок"],
    "мускусний": ["мускусовий"],
    "муслив": ["мусливши"],
    "мусливши": ["муслив"],
    "муслинделин": ["муслинделен"],
    "муслинделиновый": ["муслинделеновый"],
    "мусолив": ["мусоливши"],
    "мусоливши": ["мусолив"],
    "мусолить": ["муслить", "слюнить", "слюнявить", "затягивать", "копаться", "тянуть", "тянуть кота за хвост", "возюкаться"],
    "мусор": ["отходы", "хлам", "грязь", "пыль", "дрязг"],
    "мусорив": ["мусоривши"],
    "мусоривши": ["мусорив"],
    "мусоринка": ["соринка"],
    "мусорить": ["сорить", "загрязнять"],
    "мусорка": ["мусоросборник", "свалка", "мусоровоз", "мусоровозка"],
    "мусорник": ["мусорка"],
    "мусорница": ["мусорка"],
    "мусорное ведро": ["помойное ведро"],
    "мусоровоз": ["мусоровозка"],
    "мусоровозка": ["мусоровоз"],
    "мусорок": ["блюститель порядка", "мент", "коп", "легавый", "легаш", "полицай", "фараон", "мусор"],
    "мусоросжигатель": ["инсинератор"],
    "муссивное золото": ["мусивное золото", "серное золото", "сусальное золото", "сусаль"],
    "муссивный": ["мозаиковый", "мозаический", "мозаичный", "музивный", "мусивный", "мусийный", "составной", "многосоставной", "многокомпонентный", "смешанный", "вставочный"],
    "муссировав": ["муссировавши"],
    "муссировавши": ["муссировав"],
    "муссировать": ["пениться", "играть", "раздувать", "преувеличивать"],
    "муст": ["сусло"],
    "мусульманин": ["магометанин", "агарянин", "сарацин"],
    "мусульманка": ["магометанка"],
    "мусульманский": ["исламский", "магометанский"],
    "мусульманство": ["ислам", "магометанство"],
    "мусьё": ["мосье", "мусье", "мусью", "мисье"],
    "мутародиф": ["муродиф"],
    "мутаротация": ["мультиротация"],
    "муташаккир": ["сипосгузор"],
    "мутив": ["мутивши"],
    "мутивши": ["мутив"],
    "мутировав": ["мутировавши"],
    "мутировавши": ["мутировав"],
    "мутирование": ["мутация"],
    "мутировать": ["видоизменяться", "видоизмениться"],
    "мутить": ["туманить"],
    "мутнев": ["мутневши"],
    "мутневши": ["мутнев"],
    "мутность": ["замутнённость", "загрязнённость"],
    "мутнуватий": ["каламутнуватий"],
    "мутовка": ["венчик", "взбивалка", "сбивалка", "веничек"],
    "муторно": ["тоскливо", "тягостно", "тяжко", "тошно", "фигово"],
    "муторный": ["тошнотворный", "тоскливый", "неприятный", "тягостный", "тяжкий"],
    "мутота": ["мутотень"],
    "мутотень": ["мутота", "тягомотина", "ширли-мырли", "шир-манирли"],
    "мутуалистический": ["взаимовыгодный"],
    "мутузив": ["мутузивши"],
    "мутузивши": ["мутузив"],
    "муфлон": ["мудак", "мудила", "мудило"],
    "муха не сидела": ["новьё", "муха не еблась"],
    "мухаммад": ["мухаммед"],
    "мухаммед": ["мухаммад", "магомет"],
    "мухи дохнут": ["скука", "тоска смертная", "тоска зелёная", "нудятина"],
    "мухи не обидит": ["воды не замутит"],
    "мухит": ["мухут"],
    "мухлевав": ["мухлевавши"],
    "мухлевавши": ["мухлевав"],
    "мухлевать": ["махлевать", "жульничать", "плутовать", "мошенничать"],
    "мухлис": ["тамошобин"],
    "мухлёж": ["мухлевание", "жульничество", "шулерство", "мухляж"],
    "мухобойка": ["мухоловка"],
    "мухоедка": ["бембекс"],
    "мухоловка": ["венерина мухоловка", "скутигер"],
    "мухоподобный": ["мухообразный"],
    "мухортый": ["гнедой", "мухортный"],
    "муху задавить": ["муху зашибить", "муху раздавить", "муху убить", "муху зарубить", "под мухой", "с мухой", "букашку задавить", "выпить", "подвыпить", "накиряться", "захмелеть", "поддатый", "пропустить по маленькой", "заложить за галстук", "заложить за ухо"],
    "муху убить": ["муху зашибить", "муху раздавить", "муху задавить", "муху зарубить", "под мухой", "с мухой", "букашку задавить", "выпить", "подвыпить", "накиряться", "захмелеть", "поддатый", "пропустить по маленькой", "заложить за галстук", "заложить за ухо"],
    "мухъл": ["плесен"],
    "муцин": ["мукопротеин"],
    "муциназа": ["гиалуронидаза"],
    "муцуна": ["мутра", "зурла", "физиономия"],
    "мучав": ["мучавши"],
    "мучавши": ["мучав"],
    "мучать": ["мучить"],
    "мучаться": ["мучиться", "томиться", "беспокоиться", "страдать"],
    "мучение": ["мука", "страдание", "мытарство"],
    "мученик": ["человек-мученик", "страдалец", "несчастный", "исповедник", "богомученик"],
    "мученица": ["страдалица"],
    "мученически": ["страдальчески"],
    "мученический": ["страдальческий"],
    "мученье": ["мучение"],
    "мучив": ["мучивши"],
    "мучивши": ["мучив"],
    "мучительно": ["невыносимо", "нестерпимо"],
    "мучительный": ["болезненный"],
    "мучительский": ["мучительный"],
    "мучить": ["мучать", "долбить"],
    "мучиться": ["мучаться", "страдать", "маяться", "томиться", "болеть"],
    "мушиний": ["мушачий"],
    "мушка": ["муха"],
    "мушмула": ["эзгиль", "чашковое дерево", "чишковое дерево", "шишковник", "шишки"],
    "мушмула японская": ["локва"],
    "мушмуловый": ["мушмульный"],
    "мушмульный": ["мушмуловый"],
    "муштра": ["муштровка"],
    "муштровав": ["муштровавши"],
    "муштровавши": ["муштровав"],
    "муштрование": ["муштровка"],
    "муштровать": ["дрессировать"],
    "муштровка": ["муштра"],
    "мхаре": ["край"],
    "мхат": ["мхт"],
    "мхк": ["мировая художественная культура", "молодёжный хоккейный клуб"],
    "мцхета": ["мцхет"],
    "мцыри": ["послушник"],
    "мчав": ["мчавши"],
    "мчавши": ["мчав"],
    "мчать": ["гнать"],
    "мчаться": ["лететь", "нестись", "проходить", "пролетать"],
    "мшавый": ["мшаный", "мшалый"],
    "мшаник": ["омшаник", "амшанник", "мшенник", "стебник", "пчёльник", "темник", "мшарник"],
    "мшаный": ["мшавый", "мшалый"],
    "мшев": ["мшевши"],
    "мшевши": ["мшев"],
    "мшелоимство": ["накопительство", "стяжательство", "приобретательство"],
    "мшель": ["вещь", "имущество", "мзда", "корысть", "прибыль"],
    "мшив": ["мшивши"],
    "мшивши": ["мшив"],
    "мшу": ["ушм", "болгарка", "угловая шлифовальная машина", "углошлифовальная машина"],
    "мщение": ["месть", "отмщение"],
    "мщенье": ["мщение"],
    "мъзярда": ["кода", "кодак"],
    "мъзярдовок": ["мъзярда-мъзярда", "мъзярдонга"],
    "мъзярдонга": ["мъзярда-мъзярда", "мъзярдовок"],
    "мъзярс аф мъзярс": ["мъзярс-мъзярс"],
    "мъзярс-мъзярс": ["мъзярс аф мъзярс"],
    "мълния": ["светкавица"],
    "мързел": ["леност", "безделие", "лентяйство"],
    "мързелан": ["мързеливец", "лентяй", "безделник", "хайлазин"],
    "мързеливец": ["мързелан", "лентяй", "безделник", "хайлазин"],
    "мъртвец": ["труп", "мъртъв", "покойник", "смъртник"],
    "мърша": ["леш", "труп"],
    "мътеница": ["айран"],
    "мъчнотия": ["трудност", "затруднение", "пречка", "спънка", "мъка"],
    "мыв": ["мывши"],
    "мывав": ["мывавши"],
    "мывавши": ["мывав"],
    "мывши": ["мыв"],
    "мыза": ["хутор"],
    "мызгав": ["мызгавши"],
    "мызгавши": ["мызгав"],
    "мызгать": ["замызгивать"],
    "мызрах": ["мизрах"],
    "мыйы": ["акъыл"],
    "мыкав": ["мыкавши"],
    "мыкавши": ["мыкав"],
    "мыкальщик": ["мыканица"],
    "мыкнув": ["мыкнувши"],
    "мыкнувши": ["мыкнув"],
    "мыкола": ["никола", "николай", "миколай", "мыкол"],
    "мылив": ["мыливши"],
    "мыливши": ["мылив"],
    "мыло": ["электронная почта", "почта"],
    "мыловаренный": ["мылоделательный"],
    "мыломойка": ["моющий", "средство"],
    "мыльно-рыльное": ["мыльное-рыльное"],
    "мыльное-рыльное": ["мыльно-рыльное"],
    "мыльня": ["баня"],
    "мыльнянка": ["сапонария"],
    "мырдь": ["мард"],
    "мырнув": ["мырнувши"],
    "мырнувши": ["мырнув"],
    "мыс": ["полуостров", "выступ"],
    "мыс мурманца": ["мурманец", "мыс никольского"],
    "мыса": ["пыса"],
    "мыслепреступление": ["преступмысль"],
    "мыслете": ["эм", "малый ход", "тихий ход", "змейка", "вензель", "крендель", "петля", "зигзаг", "зигзуг"],
    "мысли": ["ядро", "ятро", "яйцо"],
    "мыслив": ["мысливши"],
    "мысливши": ["мыслив"],
    "мыслимый": ["представимый", "возможный"],
    "мыслитель": ["философ", "интеллектуал"],
    "мыслить": ["рассуждать", "думать", "размышлять", "кумекать"],
    "мысль": ["мышление", "рассуждение", "дума", "помысел", "идея", "концепция"],
    "мыслёнка": ["мыслишка"],
    "мысок": ["мысик", "носок"],
    "мысь": ["белка", "векша"],
    "мыт": ["понос", "диарея", "линька", "линяние"],
    "мытарив": ["мытаривши"],
    "мытаривши": ["мытарив"],
    "мытарство": ["мучение", "мука", "страдание", "испытание"],
    "мытарствовав": ["мытарствовавши"],
    "мытарствовавши": ["мытарствовав"],
    "мытарствовать": ["мучиться"],
    "мытарящий": ["нудящий"],
    "мытница": ["таможня"],
    "мытня": ["таможня"],
    "мыто": ["мыт", "мытная пошлина", "подорожная пошлина", "подорожный сбор"],
    "мыть": ["промывать", "отмывать", "стирать", "домывать", "омывать", "подмывать", "размывать"],
    "мыться": ["купаться"],
    "мытьё": ["мойка", "стирка"],
    "мых": ["мисмар"],
    "мычав": ["мычавши"],
    "мычавши": ["мычав"],
    "мычание": ["мычанье"],
    "мычанье": ["мычание"],
    "мышевидный": ["мышеобразный"],
    "мышелов": ["обыкновенный канюк", "сарыч"],
    "мышеловка": ["западня", "ловушка", "автозак", "воронок"],
    "мышеобразный": ["мышевидный"],
    "мышечный": ["мускульный"],
    "мышив": ["мышивши"],
    "мышивши": ["мышив"],
    "мыший": ["мышиный"],
    "мышиная возня": ["мышиная беготня", "мышья беготня", "мышиная суета", "мышиная сутолока"],
    "мышка": ["плечевой сгиб", "мышца"],
    "мышковав": ["мышковавши"],
    "мышковавши": ["мышковав"],
    "мышление": ["мысль", "думание", "думанье", "мышленье", "менталитет"],
    "мышленье": ["мышление"],
    "мышца": ["мускул"],
    "мышь": ["мышка"],
    "мышьяк": ["арсеникум"],
    "мышьяковый": ["мышьячный"],
    "мышьякосодержащий": ["мышьяксодержащий"],
    "мышьяксодержащий": ["мышьякосодержащий"],
    "мышьячный": ["мышьяковый"],
    "мыщелок": ["мыщелка"],
    "мьюзикл": ["мюзикл"],
    "мьянма": ["бирма", "республика союз мьянма"],
    "мэз": ["мэзы"],
    "мэзчэт": ["мэзкьэт"],
    "мэйнфрейм": ["майнфрейм", "мейнфрейм"],
    "мэм": ["сударыня", "мадам"],
    "мэнос": ["богат", "родник"],
    "мэнский язык": ["мэнский"],
    "мэнэ": ["мана"],
    "мэппинг": ["маппинг"],
    "мэр": ["аким", "бургомистр", "градоначальник", "городской голова"],
    "мэрдивэн": ["мадрегот"],
    "мэрес": ["мэрэс"],
    "мэровский": ["мэрский"],
    "мэрский": ["мэровский"],
    "мэрствовав": ["мэрствовавши"],
    "мэрствовавши": ["мэрствовав"],
    "мэрэс": ["мэрес"],
    "мэтр": ["маэстро", "господин", "владыка"],
    "мэтчмейкинг": ["матчмейкинг"],
    "мэф": ["фрезер"],
    "мю": ["ми"],
    "мю-мезоатом": ["мюонный атом"],
    "мю-мезон": ["мюон", "мезотрон"],
    "мюй": ["мюний", "мюнянгы"],
    "мюнянгы": ["мюй", "мюний"],
    "мюон": ["мю-мезон", "мезотрон"],
    "мюскадель": ["мускатель", "педро", "педро крымский", "педро хименес", "педро хименес крымский"],
    "мютюэлист": ["прудонист"],
    "мющерия": ["купувач", "клиент"],
    "мя": ["меня"],
    "мяв": ["мяуканье", "мявканье"],
    "мявканье": ["мяв", "мяукание", "мяуканье"],
    "мягенький": ["мягонький"],
    "мягкий": ["пластичный", "податливый", "пушистый", "нежный", "тонкий", "учтивый", "вежливый", "воспитанный", "благоприятный", "здоровый", "гашиш", "дурь", "анаша"],
    "мягкий знак": ["ерь"],
    "мягко": ["податливо", "аккуратно", "плавно", "спокойно", "тихо", "комфортно", "уютно"],
    "мягкое место": ["пятая точка"],
    "мягкое мороженое": ["джелато"],
    "мягкосердечный": ["отзывчивый", "добродушный", "сердечный", "добросердечный", "мягкосердый"],
    "мягкосердый": ["мягкосердечный"],
    "мягкотелость": ["слабохарактерность"],
    "мягкошёрстый": ["мягкошёрстный"],
    "мягонький": ["мягенький", "мяконький", "мякенький"],
    "мягчев": ["мягчевши"],
    "мягчевши": ["мягчев"],
    "мягчеть": ["мягчиться", "размягчаться"],
    "мягчив": ["мягчивши"],
    "мягчивши": ["мягчив"],
    "мягчить": ["размягчать"],
    "мякина": ["полова"],
    "мякинное брюхо": ["жадина", "жадюга"],
    "мякнув": ["мякнувши"],
    "мякнувши": ["мякнув"],
    "мяль вельде": ["пара мяльса", "эсь мяльса"],
    "мямлив": ["мямливши"],
    "мямливши": ["мямлив"],
    "мямлить": ["мемекать", "лопотать", "мешкать", "канителиться", "валандаться", "чикаться", "чесаться", "волынить"],
    "мямля": ["рохля"],
    "мяо": ["хмонг"],
    "мярьгомс": ["азомс", "кошардомс", "указовамс"],
    "мяско": ["мясо", "мясцо"],
    "мясная": ["мясной"],
    "мясное": ["мясо"],
    "мясной штурм": ["мясная атака"],
    "мясные пирожки с яблоками": ["ерунда", "несуразица"],
    "мясо": ["мышечная ткань", "плоть", "мускул", "мышца", "убоина", "мясное", "месилово", "месиловка", "мясорубка", "рубиловка"],
    "мясо-молочный": ["мясомолочный"],
    "мясо-шкурковый": ["комбинированный"],
    "мясоед": ["мясоястие", "мясопуст"],
    "мясокостная мука": ["костная мука"],
    "мясомолочный": ["мясо-молочный"],
    "мясорубка": ["бойня", "кровавая баня", "резня", "побоище"],
    "мясохладобойня": ["хладобойня"],
    "мясцо": ["мяско"],
    "мятеж": ["бунт", "путч", "восстание", "ребелия"],
    "мятежник": ["бунтовщик", "инсургент"],
    "мятежница": ["бунтарка", "бунтовщица"],
    "мятежно": ["неспокойно", "тревожно", "страшно", "пугающе"],
    "мятежный": ["бунтарский", "тревожный", "неспокойный", "бурный", "мятущийся"],
    "мятель": ["вьюга", "метель"],
    "мятущийся": ["беспокойный"],
    "мятый": ["помятый", "давленый", "раздавленный", "сплющенный", "измятый"],
    "мять": ["сминать"],
    "мяукав": ["мяукавши"],
    "мяукавши": ["мяукав"],
    "мяукание": ["мяв", "мявканье", "мяуканье"],
    "мяуканье": ["мяв", "мявканье", "мяукание"],
    "мяукать": ["мявкать", "мяучить"],
    "мяукнув": ["мяукнувши"],
    "мяукнувши": ["мяукнув"],
    "мяучив": ["мяучивши"],
    "мяучивши": ["мяучив"],
    "мяучить": ["мяукать"],
    "мяша": ["грязь"],
    "мяште": ["потя"],
    "мёд": ["нектар", "медовуха"],
    "мёд с сахаром": ["благополучно", "зажиточно"],
    "мёрзлый": ["промёрзший", "обледенелый", "мороженый", "замёрзший", "озябший", "окоченевший", "ледяной", "нетопленый", "выстуженный"],
    "мёрзнув": ["мёрзнувши"],
    "мёрзнувши": ["мёрзнув"],
    "мёрзнуть": ["замерзать", "заледеневать", "леденеть", "насмерть", "зябнуть", "коченеть", "стынуть"],
    "мёртвая": ["покойница"],
    "мёртвая вода": ["святая вода", "талая вода", "замороженная вода"],
    "мёртвая голова": ["адамова голова", "саймири"],
    "мёртвая петля": ["петля нестерова"],
    "мёртвого за хуй тянуть": ["медлить", "тянуть мёртвого за хуй"],
    "мёртвое море": ["мёртвое озеро", "лутово озеро", "озеро лута", "озеро лут", "лут", "озеро сирбонида", "асфальтовое море", "содомское море", "лотово море", "лотово озеро"],
    "мёртвое пространство": ["мёртвый сектор"],
    "мёртвость": ["безжизненность"],
    "мёртвый": ["неживой", "неодушевленный", "нежизненный", "бесплодный"],
    "мёртвый сезон": ["несезон"],
    "мёртвый сектор": ["мёртвое пространство"],
    "мёртвый час": ["тихий час"],
    "мёртвых с погоста не носят": ["с погосту домой не носят", "мёртвых с кладбища не возят", "мёртвого от гроба не несут", "мёртвого с погоста не таскают", "мёртвый с погоста не ворочается"],
    "мётчик": ["банкомёт"],
    "мётывав": ["мётывавши"],
    "мётывавши": ["мётывав"],
    "н-да": ["м-да"],
    "на": ["над", "поверх", "сверху", "внутри", "в направлении", "на основе", "для", "в интересах", "ради", "за", "во имя", "на благо", "во благо", "в пользу", "в целях"],
    "на авось": ["наудачу", "метод тыка"],
    "на автомате": ["машинально", "на автопилоте"],
    "на алтарь": ["в жертву"],
    "на безрыбье и рак раком": ["на безрыбье и рак рыба", "на безрыбье и рак щука", "в поле и жук мясо", "в степи и жук мясо", "на чужой стороне и жук мясо", "на безлюдье и фома человек", "на безлюдье и фома дворянин", "на безрыбье и сам раком станешь", "на безрыбье и сам раком встанешь", "на безголосье и жопа соловей", "на бесптичье и жопа соловей", "на безводье и хуй водопровод"],
    "на безрыбье и рак рыба": ["на безрыбье и рак щука", "в поле и жук мясо", "в степи и жук мясо", "на чужой стороне и жук мясо", "на безлюдье и фома человек", "на безлюдье и фома дворянин", "на безрыбье и рак раком", "на безрыбье и сам раком станешь", "на безрыбье и сам раком встанешь", "на безголосье и жопа соловей", "на бесптичье и жопа соловей", "на безводье и хуй водопровод"],
    "на благо": ["для", "в интересах", "ради", "на", "за", "во имя", "во благо", "в пользу"],
    "на бумаге": ["письменно", "на словах", "гипотетически", "теоретически", "умозрительно"],
    "на верную смерть": ["насмерть", "на смерть", "на погибель"],
    "на вес золота": ["бесценно"],
    "на вид": ["внешне"],
    "на виду у": ["на глазах у"],
    "на вкус и цвет все фломастеры разные": ["на вкус и цвет товарищей нет"],
    "на вкус и цвет товарищей нет": ["на вкус и цвет товарища нет", "о вкусах не спорят"],
    "на воре и шапка пизженая": ["на воре и шапка горит"],
    "на все лады": ["и так и сяк", "всячески"],
    "на все сто": ["на всю катушку"],
    "на все четыре стороны": ["куда глаза глядят"],
    "на всех парах": ["вихрем", "во весь дух", "во весь опор", "во все лопатки", "во всю мочь", "во всю прыть"],
    "на всю катушку": ["на все сто", "по полной"],
    "на всякий случай": ["на всякий пожарный", "хуже не будет"],
    "на всякого мудреца довольно простоты": ["и на старуху бывает проруха"],
    "на выбор": ["на усмотрение", "на вкус"],
    "на выплату": ["в рассрочку"],
    "на галстук взять": ["взять на галстук"],
    "на глаз": ["приблизительно", "на глазок"],
    "на говне сметану собирать": ["делать из говна конфетку"],
    "на голубом глазу": ["неискренно", "неискренне", "фальшиво", "лицемерно"],
    "на днях": ["скоро", "в ближайшее время", "недавно", "давеча", "намедни"],
    "на донышке": ["мизерно", "кот наплакал"],
    "на дураков кнутья": ["дурак слов не разумеет", "дуракам закон не писан"],
    "на душе": ["на сердце"],
    "на дыбки": ["на дыбы"],
    "на живую нитку шить": ["намётано", "смётано", "тяп-ляп", "абы как", "небрежно", "халтурно", "через пень-колоду", "с грехом пополам", "второпях", "на скорую руку", "впопыхах", "на соплях", "безалаберно"],
    "на здоровье": ["пожалуйста"],
    "на изготовку": ["наизготове", "наготове"],
    "на каждый чих": ["на любой чих", "каждый чих ловить", "ловить каждый чих", "откликаться на каждый чих", "откликаться буквально на каждый чих", "по каждому чиху", "по каждому вздрагивать", "по любому чиху", "по первому чиху"],
    "на каждый чих не наздравствуешься": ["на каждый роток не накинешь платок"],
    "на казённых харчах": ["на государственных харчах"],
    "на клык взять": ["взять на клык", "принять на клык", "на клык принять"],
    "на кой ляд": ["зачем", "на фига"],
    "на кой хуй": ["зачем", "для чего", "к чему", "с какой целью", "на фига", "на хрена", "на хера", "на кой хер", "кой хер", "какого хера", "на хуя", "кой хуй", "какого хуя", "на хуище"],
    "на кой чёрт": ["что", "хуй ли", "хули", "хуле", "хуля", "хуль"],
    "на коленке": ["на скорую руку", "быстро", "наспех", "вручную"],
    "на короткой ноге": ["накоротке", "близко"],
    "на костях": ["на крови"],
    "на кривых вороных не объедешь": ["на кривой не объедешь", "на вороной не объедешь", "на саврасой не объедешь", "хитрый как лиса", "на мякине не проведёшь", "не у него на лбу гвозди гнуть"],
    "на круг": ["примерно", "около", "в среднем"],
    "на кудыкину гору": ["бог знает куда", "к чёрту на кулички", "к чёрту на рога", "к чёрту в турки", "за тридевять земель", "куда макар телят не гонял"],
    "на курантах": ["на четвереньках"],
    "на лихой мат": ["неистово", "исступлённо", "истошно", "благим матом"],
    "на лицо": ["внешне"],
    "на мели": ["в затруднительном положении", "в бедности"],
    "на месте преступления": ["с поличным"],
    "на мякине не проведёшь": ["стреляный воробей"],
    "на общественных началах": ["бесплатно", "безвозмездно"],
    "на одном дыхании": ["не переводя дух"],
    "на отвали": ["небрежно", "кое-как", "абы-как", "тяп-ляп", "сойдёт", "и так сойдёт", "ради галочки", "на отъебись"],
    "на отъебись": ["небрежно", "кое-как", "абы-как", "тяп-ляп", "сойдёт", "и так сойдёт", "невнимательно", "равнодушно", "неучастливо", "халатно", "чёрство", "для проформы", "для галочки", "ради галочки", "на отвали"],
    "на ощупь": ["наугад"],
    "на память": ["наизусть"],
    "на пару": ["вдвоём"],
    "на пару харить": ["харить на пару"],
    "на первых порах": ["вначале", "сначала"],
    "на перекладных": ["автостопом"],
    "на пинковой тяге": ["пинками", "на пинках"],
    "на поверку": ["на самом деле", "в действительности", "практически", "на практике", "фактически", "на деле", "по сути", "по сути дела", "в результате"],
    "на полном серьёзе": ["серьёзно", "всерьёз", "в полный серьёз", "на самом деле", "в самом деле"],
    "на полную катушку": ["на всю катушку", "по полной"],
    "на попа": ["стоймя", "вертикально"],
    "на порядок": ["в несколько раз"],
    "на практике": ["на деле", "в действительности", "в самом деле"],
    "на предмет": ["касательно", "относительно"],
    "на расстояньи": ["поодаль"],
    "на расшарагу": ["на раскоряку"],
    "на ровном месте": ["на пустом месте", "с нуля", "нежданно-негаданно"],
    "на рогах": ["готовый", "готовенький", "на бровях", "на кочерге", "в дупель", "в дупелину", "в дупло"],
    "на рыбьем меху": ["на стерляжьем меху"],
    "на рыбьем языке чирикать": ["чирикать на рыбьем языке"],
    "на рысях": ["вскачь", "пулей", "на всех парах"],
    "на самом деле": ["в действительности", "в натуре", "собственно говоря", "в самом деле"],
    "на своих двоих": ["пешком", "пешкодралом", "пешкарусом", "одиннадцатый маршрут"],
    "на своих ногах": ["пешочком", "пешкодралом", "пешкодрапом", "одиннадцатым маршрутом"],
    "на свой салтык": ["на свой манер"],
    "на свой страх и риск": ["под свою ответственность"],
    "на свою голову": ["себе во вред"],
    "на серьёзе": ["строго", "без шуток", "кроме шуток", "по серьёзу"],
    "на серьёзных щах": ["на серьёзных щщах"],
    "на серьёзных щщах": ["на серьёзных щах"],
    "на склоне дней": ["на склоне лет", "на склоне жизни"],
    "на склоне лет": ["на склоне дней", "на склоне жизни"],
    "на скорую руку": ["быстро", "наспех"],
    "на службе не без тужбы": ["на службе не без нужды"],
    "на смену": ["вместо"],
    "на смертном одре": ["на смертном ложе", "при смерти", "одной ногой в могиле", "на краю гроба"],
    "на смерть": ["на погибель", "лицом к лицу со смертью"],
    "на снос": ["под снос"],
    "на сносе": ["на сносях"],
    "на сносях": ["в поре"],
    "на совести": ["нести бремя"],
    "на сто процентов": ["точно", "наверняка", "железно", "полностью", "целиком"],
    "на счету": ["в обрез", "на учёте", "на примете"],
    "на фига": ["зачем", "для чего", "пошто", "нахуй", "нахуя"],
    "на фига козе баян": ["на фига волку жилетка", "нафиг мне такая заграница"],
    "на халяву": ["на халявку", "на шару"],
    "на хер": ["на хуй", "к чёрту"],
    "на ход ноги": ["на посошок"],
    "на ходу": ["с ходу"],
    "на ходу подмётки рвать": ["на ходу подмётки резать", "на ходу подметки срезать"],
    "на ходу подмётки резать": ["рвать на ходу подмётки", "срезать на ходу подмётки", "на ходу подмётки рвать", "на ходу подметки срезать"],
    "на хрена": ["на фига", "нахрена"],
    "на хуище": ["зачем", "для чего", "к чему", "с какой целью", "на хуя", "на кой хуй", "кой хуй", "какого хуя", "на фига", "на хрена"],
    "на хуй": ["к чёрту", "ко всем чертям", "к дьяволу", "к чёртовой бабушке", "к чёртовой матери", "на хер", "на хрен", "на фиг", "в сторонку", "на три буквы", "куда подальше", "далеко и надолго", "далеко и без куска хлеба", "к хуям", "ко всем хуям"],
    "на хуй нужен": ["нужен как до пизды дверки", "нужен как до пизды дверца", "нужен как до пизды дверцы", "на хуй не упал"],
    "на хуй нужно": ["на хуй не упало"],
    "на хуй твоя жопа хороша": ["и вас с тем же праздником", "и вас тем же концом по тому же месту", "и тебя тем же концом по тому же месту", "и вам не хворать", "и тебе не хворать", "а давно ты его видела", "а ты давно его видала", "куда вы сказали вас проводить", "дорогу покажешь", "вы мне тоже нравитесь", "только после вас", "там компания не в моём вкусе", "своим помахуй", "не ахай", "а ты не ахай"],
    "на хую вертеть": ["вертеть на хую", "ебать в рот", "ебать в рот и в нос", "в рот ебать", "в рот и в нос ебать"],
    "на час": ["временно"],
    "на честном слове и на одном крыле": ["чудом", "на соплях"],
    "на чужой каравай рот не разевай": ["на чужой каравай рта не разевай"],
    "на чужой роток не накинешь платок": ["на всякий роток не накинешь платок", "на чужой рот пуговицы не нашьёшь"],
    "на чужом горбу в рай въехать": ["въехать в рай на чужом горбу", "на чужом горбу в рай выехать", "въехать в рай на чужом хую", "в рай въехать на чужом хую"],
    "на шаромыгу": ["на дармовщину", "на дармовщинку", "за бесценок", "задаром", "задарма", "на дурака", "на дурачка", "на шармака", "на шармачка"],
    "на шару": ["на халяву", "на шаромыгу", "на удачу"],
    "на широкую ногу": ["богато", "с размахом"],
    "на этот счёт": ["по этому поводу", "в этом случае", "в этом отношении"],
    "на ять": ["безукоризненно", "отлично", "великолепно", "на отлично", "на пять баллов", "на десять баллов", "безукоризненный", "отличный", "великолепный"],
    "на-гора": ["наверх"],
    "на-нет": ["на", "нет"],
    "наабайчылык": ["наабайкана"],
    "наадандык": ["акмактык", "келесоолук"],
    "наалат": ["каргыш"],
    "наасени": ["нагас", "офитес"],
    "набавив": ["набавивши"],
    "набавивши": ["набавив"],
    "набавляв": ["набавлявши"],
    "набавлявши": ["набавляв"],
    "набагрив": ["набагривши"],
    "набагривав": ["набагривавши"],
    "набагривавши": ["набагривав"],
    "набагривши": ["набагрив"],
    "набалагурив": ["набалагуривши"],
    "набалагуривши": ["набалагурив"],
    "набалагурить": ["развеселить", "рассмешить", "набалясничать", "наслотить", "натурусить"],
    "набаламутив": ["набаламутивши"],
    "набаламутивши": ["набаламутив"],
    "набаловав": ["набаловавши"],
    "набаловавши": ["набаловав"],
    "набаловывав": ["набаловывавши"],
    "набаловывавши": ["набаловывав"],
    "набалтывав": ["набалтывавши"],
    "набалтывавши": ["набалтывав"],
    "набальзамировав": ["набальзамировавши"],
    "набальзамировавши": ["набальзамировав"],
    "набальзамированный": ["забальзамированный"],
    "набарабанив": ["набарабанивши"],
    "набарабанивши": ["набарабанив"],
    "набарахлив": ["набарахливши"],
    "набарахливши": ["набарахлив"],
    "набарышничав": ["набарышничавши"],
    "набарышничавши": ["набарышничав"],
    "набат": ["литавра"],
    "набатрачив": ["набатрачивши"],
    "набатрачивши": ["набатрачив"],
    "набег": ["набегание", "налёт", "наскок", "рейд", "наезд", "порыв", "напор"],
    "набегав": ["набегавши"],
    "набегавши": ["набегав"],
    "набедив": ["набедивши"],
    "набедивши": ["набедив"],
    "набедить": ["набедокурить"],
    "набедовав": ["набедовавши"],
    "набедовавши": ["набедовав"],
    "набедовать": ["исстрадаться", "намучиться", "напроказничать", "натворить дел", "набедокурить"],
    "набедокурив": ["набедокуривши"],
    "набедокуривши": ["набедокурив"],
    "набедокурить": ["напроказничать", "наделать дел"],
    "набежав": ["набежавши"],
    "набежавши": ["набежав"],
    "набеззаконничав": ["набеззаконничавши"],
    "набеззаконничавши": ["набеззаконничав"],
    "набезобразив": ["набезобразивши"],
    "набезобразивши": ["набезобразив"],
    "набезобразить": ["набезобразничать"],
    "набезобразничав": ["набезобразничавши"],
    "набезобразничавши": ["набезобразничав"],
    "набезобразничать": ["набезобразить"],
    "набекренив": ["набекренивши"],
    "набекренивши": ["набекренив"],
    "набекрень": ["косо", "криво", "набок", "бекренём", "наперекосяк"],
    "набелив": ["набеливши"],
    "набеливши": ["набелив"],
    "набело": ["начисто"],
    "набережные челны": ["брежнев"],
    "набережный": ["прибрежный"],
    "набздев": ["набздевши"],
    "набздевши": ["набздев"],
    "набздеть": ["напукать", "напердеть"],
    "набив": ["набивши"],
    "набивав": ["набивавши"],
    "набивавши": ["набивав"],
    "набивать себе цену": ["пускать пыль в глаза"],
    "набивка": ["наполнитель"],
    "набивши": ["набив"],
    "набирав": ["набиравши"],
    "набиравши": ["набирав"],
    "набитый": ["наполненный"],
    "набитый дурак": ["дурак набитый", "дурак дураком", "круглый дурак"],
    "набить оскомину": ["приесться"],
    "набить руку": ["насобачиться"],
    "набла": ["гусли", "арфа", "оператор гамильтона", "гамильтониан"],
    "наблажив": ["наблаживши"],
    "наблаживши": ["наблажив"],
    "наблатыканный": ["приблатнённый"],
    "наблатыкаться": ["заблатниться", "наблатоваться", "насобачиться", "наловчиться", "намастрячиться", "поднатореть", "напрактиковаться", "натренироваться"],
    "наблевав": ["наблевавши"],
    "наблевавши": ["наблевав"],
    "наблошнив": ["наблошнивши"],
    "наблошнивши": ["наблошнив"],
    "наблошниться": ["насобачиться", "наблатыкаться"],
    "наблошняв": ["наблошнявши"],
    "наблошнявши": ["наблошняв"],
    "наблудив": ["наблудивши"],
    "наблудивши": ["наблудив"],
    "наблюдав": ["наблюдавши"],
    "наблюдавши": ["наблюдав"],
    "наблюдательность": ["внимательность"],
    "наблюдательный": ["внимательный", "смотровой"],
    "наблюдать": ["следить", "встречать", "изучать", "исследовать", "отслеживать", "надзирать", "за", "ведать", "созерцать", "соблюдать"],
    "наблюдение": ["надзор", "слежение", "заключение", "вывод"],
    "наблёвывав": ["наблёвывавши"],
    "наблёвывавши": ["наблёвывав"],
    "набоб": ["нувориш"],
    "набоечный": ["набойчатый"],
    "набожничав": ["набожничавши"],
    "набожничавши": ["набожничав"],
    "набожничать": ["ханжить"],
    "набожность": ["благочестивость", "благочестие", "богобоязненность", "религиозность"],
    "набожный": ["благочестивый", "богобоязненный"],
    "набойка": ["набивка"],
    "набойчатый": ["набоечный"],
    "набок": ["вкось", "вкривь"],
    "наболев": ["наболевши"],
    "наболевши": ["наболев"],
    "наболевший": ["назревший"],
    "наболтав": ["наболтавши"],
    "наболтавши": ["наболтав"],
    "набор": ["набирание", "совокупность"],
    "наборазживав": ["наборазживавши"],
    "наборазживавши": ["наборазживав"],
    "наборанивав": ["наборанивавши"],
    "наборанивавши": ["наборанивав"],
    "наборматывав": ["наборматывавши"],
    "наборматывавши": ["наборматывав"],
    "набормотав": ["набормотавши"],
    "набормотавши": ["набормотав"],
    "набороздив": ["набороздивши"],
    "набороздивши": ["набороздив"],
    "наборонив": ["наборонивши"],
    "наборонивши": ["наборонив"],
    "набороновав": ["набороновавши"],
    "набороновавши": ["набороновав"],
    "наборщик": ["набиратель"],
    "набрав": ["набравши"],
    "набравши": ["набрав"],
    "набраковав": ["набраковавши"],
    "набраковавши": ["набраковав"],
    "набраковывав": ["набраковывавши"],
    "набраковывавши": ["набраковывав"],
    "набранив": ["набранивши"],
    "набранивав": ["набранивавши"],
    "набранивавши": ["набранивав"],
    "набранивши": ["набранив"],
    "набрасывав": ["набрасывавши"],
    "набрасывавши": ["набрасывав"],
    "набрасывание": ["набрасыванье", "набросанье", "наброшенье", "наброс", "наброска"],
    "набрасывать": ["накидывать", "намечать"],
    "набрать": ["нанять", "завербовать", "зачислить", "принять", "увеличить"],
    "набрать воды в рот": ["держать язык за зубами"],
    "набраться": ["напиться", "надраться"],
    "набредав": ["набредавши"],
    "набредавши": ["набредав"],
    "набредив": ["набредивши"],
    "набредивши": ["набредив"],
    "набрехав": ["набрехавши"],
    "набрехавши": ["набрехав"],
    "набриолинив": ["набриолинивши"],
    "набриолинивав": ["набриолинивавши"],
    "набриолинивавши": ["набриолинивав"],
    "набриолинивши": ["набриолинив"],
    "набродив": ["набродивши"],
    "набродивши": ["набродив"],
    "набронзировав": ["набронзировавши"],
    "набронзировавши": ["набронзировав"],
    "набронзировывав": ["набронзировывавши"],
    "набронзировывавши": ["набронзировывав"],
    "наброс": ["набрасывание"],
    "набросав": ["набросавши"],
    "набросавши": ["набросав"],
    "набросив": ["набросивши"],
    "набросивши": ["набросив"],
    "набросить": ["накинуть"],
    "набросок": ["зарисовка", "эскиз", "прикидка", "черновик"],
    "набросочек": ["эскизик"],
    "набросочный": ["черновой", "эскизный"],
    "набрызгав": ["набрызгавши"],
    "набрызгавши": ["набрызгав"],
    "набрызгивав": ["набрызгивавши"],
    "набрызгивавши": ["набрызгивав"],
    "набрюзжав": ["набрюзжавши"],
    "набрюзжавши": ["набрюзжав"],
    "набряк": ["пухлина"],
    "набрякав": ["набрякавши"],
    "набрякавши": ["набрякав"],
    "набрякание": ["набухание", "отекание"],
    "набрякать": ["отекать"],
    "набрякивав": ["набрякивавши"],
    "набрякивавши": ["набрякивав"],
    "набрякнув": ["набрякнувши"],
    "набрякнувши": ["набрякнув"],
    "набрякнуть": ["отечь", "набухнуть", "обрякнуть"],
    "набрякший": ["набряклый", "набухший"],
    "набсовет": ["совет директоров"],
    "набуздыкать": ["наложить", "накласть"],
    "набузив": ["набузивши"],
    "набузивши": ["набузив"],
    "набуравив": ["набуравивши"],
    "набуравивши": ["набуравив"],
    "набуравливав": ["набуравливавши"],
    "набуравливавши": ["набуравливав"],
    "набурив": ["набуривши"],
    "набуривав": ["набуривавши"],
    "набуривавши": ["набуривав"],
    "набуривать": ["набуравливать"],
    "набуривши": ["набурив"],
    "набуровив": ["набуровивши"],
    "набуровивши": ["набуровив"],
    "набутив": ["набутивши"],
    "набутивши": ["набутив"],
    "набутовав": ["набутовавши"],
    "набутовавши": ["набутовав"],
    "набухав": ["набухавши"],
    "набухавши": ["набухав"],
    "набухание": ["вздувание", "набуханье", "набухлость"],
    "набуханье": ["набухание"],
    "набухать": ["навалить"],
    "набухаться": ["напиться", "наебениться"],
    "набухвостив": ["набухвостивши"],
    "набухвостивши": ["набухвостив"],
    "набухивав": ["набухивавши"],
    "набухивавши": ["набухивав"],
    "набухнув": ["набухнувши"],
    "набухнувши": ["набухнув"],
    "набучив": ["набучивши"],
    "набучивав": ["набучивавши"],
    "набучивавши": ["набучивав"],
    "набучивши": ["набучив"],
    "набушевав": ["набушевавши"],
    "набушевавши": ["набушевав"],
    "набуянив": ["набуянивши"],
    "набуянивши": ["набуянив"],
    "набычив": ["набычивши"],
    "набычивши": ["набычив"],
    "наваждение": ["призрак", "чары"],
    "наважденье": ["наваждение"],
    "наваживав": ["наваживавши"],
    "наваживавши": ["наваживав"],
    "наваксив": ["наваксивши"],
    "наваксивши": ["наваксив"],
    "навалив": ["наваливши"],
    "наваливав": ["наваливавши"],
    "наваливавши": ["наваливав"],
    "наваливать": ["набрасывать", "обременять", "загружать", "перегружать"],
    "наваливши": ["навалив"],
    "навалица": ["тълпа", "множество", "многолюдие", "калабалък"],
    "навалом и россыпью": ["полным-полно"],
    "наваляв": ["навалявши"],
    "навалявши": ["наваляв"],
    "навалять": ["напортачить", "наделать", "надавать", "накостылять", "избить", "побить"],
    "навалять на клыка": ["на клыка навалять"],
    "навар": ["настой", "барыш", "прибыль", "нажива"],
    "наварив": ["наваривши"],
    "наваривав": ["наваривавши"],
    "наваривавши": ["наваривав"],
    "наваривши": ["наварив"],
    "наварин": ["пилос"],
    "наваристий": ["наварний"],
    "наваристый": ["густой", "жирный", "доходный", "прибыльный"],
    "наварра": ["королевство наварра", "памплона", "королевство памплона"],
    "наварх": ["друнгарий"],
    "навастривав": ["навастривавши"],
    "навастривавши": ["навастривав"],
    "наватив": ["навативши"],
    "навативши": ["наватив"],
    "наващивав": ["наващивавши"],
    "наващивавши": ["наващивав"],
    "наващивать": ["вощить"],
    "наваяв": ["наваявши"],
    "наваявши": ["наваяв"],
    "наваять": ["изваять", "сотворить", "сделать", "наделать"],
    "навевав": ["навевавши"],
    "навевавши": ["навевав"],
    "наведав": ["наведавши"],
    "наведавши": ["наведав"],
    "наведаться": ["проведать"],
    "наведенье": ["наведение"],
    "наведывав": ["наведывавши"],
    "наведывавши": ["наведывав"],
    "наведываться": ["заходить"],
    "навезя": ["навёзши"],
    "навеивав": ["навеивавши"],
    "навеивавши": ["навеивав"],
    "навек": ["навеки"],
    "навеки": ["навек", "навсегда", "навечно"],
    "навеличивав": ["навеличивавши"],
    "навеличивавши": ["навеличивав"],
    "навербовав": ["навербовавши"],
    "навербовавши": ["навербовав"],
    "навербовывав": ["навербовывавши"],
    "навербовывавши": ["навербовывав"],
    "наверно": ["точно", "несомненно", "определённо", "наверняка", "возможно", "вероятно", "предположительно", "по всей вероятности", "по всей видимости", "по-видимому"],
    "наверное": ["вероятно", "очевидно", "пожалуй", "наверно", "несомненно", "наверняка", "безусловно", "конечно", "естественно", "непременно"],
    "навернув": ["навернувши"],
    "навернувши": ["навернув"],
    "наверняка": ["несомненно", "верно", "точно", "достоверно", "стопудово", "стопудняк", "железно", "наверное", "наверняк", "безошибочно"],
    "наверстав": ["наверставши"],
    "наверставши": ["наверстав"],
    "наверстать": ["возместить"],
    "навертев": ["навертевши"],
    "навертевши": ["навертев"],
    "навертетенив": ["навертетенивши"],
    "навертетенивши": ["навертетенив"],
    "навертеть": ["навернуть"],
    "наверх": ["вверх", "кверху", "ввысь"],
    "наверху": ["выше", "вверху", "сверху", "в верхах", "над"],
    "наверчивав": ["наверчивавши"],
    "наверчивавши": ["наверчивав"],
    "навеселе": ["под хмельком", "подвыпивши", "спьяну", "спьяна"],
    "навесив": ["навесивши"],
    "навесивши": ["навесив"],
    "навесной": ["нависающий", "навесный", "навешиваемый"],
    "навесный": ["навесной"],
    "навести навет": ["обвинить", "оклеветать"],
    "навестив": ["навестивши"],
    "навестивши": ["навестив"],
    "навестить": ["посетить"],
    "навет": ["клевета", "поклёп", "злословие", "инсинуация", "кознь"],
    "навечно": ["навсегда", "навеки", "навек"],
    "навешав": ["навешавши"],
    "навешавши": ["навешав"],
    "навешать всех собак": ["найти козла отпущения"],
    "навешивав": ["навешивавши"],
    "навешивавши": ["навешивав"],
    "навешивать": ["вешать", "развешивать", "инкриминировать"],
    "навещав": ["навещавши"],
    "навещавши": ["навещав"],
    "навещать": ["посещать", "наведываться"],
    "навеяв": ["навеявши"],
    "навеявши": ["навеяв"],
    "навзничь": ["назад"],
    "навив": ["навивши"],
    "навивав": ["навивавши"],
    "навивавши": ["навивав"],
    "навивать": ["наматывать"],
    "навивка": ["навивание"],
    "навивши": ["навив"],
    "навигатор": ["штурман", "судоводитель", "веб-браузер", "веб-обозреватель", "браузер", "броузер"],
    "навигация": ["судоходство", "мореплавание", "рейс", "ориентация", "аэронавигация", "меню"],
    "навигировать": ["ориентироваться", "перемещаться", "искать"],
    "навидеться": ["навидаться"],
    "навинтив": ["навинтивши"],
    "навинтивши": ["навинтив"],
    "навинтить": ["накрутить"],
    "навинтовав": ["навинтовавши"],
    "навинтовавши": ["навинтовав"],
    "навинчивав": ["навинчивавши"],
    "навинчивавши": ["навинчивав"],
    "навирав": ["навиравши"],
    "навиравши": ["навирав"],
    "нависав": ["нависавши"],
    "нависавши": ["нависав"],
    "нависанда": ["адиб", "нигоранда"],
    "навислый": ["нависший"],
    "нависнув": ["нависнувши"],
    "нависнувши": ["нависнув"],
    "навка": ["мавка", "ундина", "вила", "русалка", "дух", "душа", "призрак", "нимфа", "божество"],
    "навкалывав": ["навкалывавши"],
    "навкалывавши": ["навкалывав"],
    "навластвовав": ["навластвовавши"],
    "навластвовавши": ["навластвовав"],
    "навлекав": ["навлекавши"],
    "навлекавши": ["навлекав"],
    "навлечь": ["накликать", "ввергнуть"],
    "наводив": ["наводивши"],
    "наводивши": ["наводив"],
    "наводить": ["приводить", "целиться", "целить", "нацеливать", "сдавать", "организовывать", "устраивать", "создавать", "строить", "возводить", "вызывать", "порождать"],
    "наводить марафет": ["отводить глаза", "вариант", "глаза отводить", "марафет наводить", "прихорашивать", "прихорашиваться", "чистить пёрышки", "пёрышки чистить"],
    "наводить порядок": ["приводить в порядок", "наводить марафет"],
    "наводить тень на плетень": ["запутывать"],
    "наводить фасад": ["чепуриться", "наводить красоту"],
    "наводка": ["наведение", "индукция"],
    "наводнение": ["потоп", "затопление"],
    "наводненье": ["наводнение"],
    "наводнив": ["наводнивши"],
    "наводнивши": ["наводнив"],
    "наводнить": ["затопить", "заполнить"],
    "наводниться": ["наполниться", "заполниться"],
    "наводняв": ["наводнявши"],
    "наводнявши": ["наводняв"],
    "навоевав": ["навоевавши"],
    "навоевавши": ["навоевав"],
    "навоз": ["азив"],
    "навозив": ["навозивши"],
    "навозивши": ["навозив"],
    "навозник": ["копринус"],
    "навозовец": ["азовец", "азивец"],
    "навозохранилище": ["гноище", "гноевица", "гноянка", "померка"],
    "наволакивав": ["наволакивавши"],
    "наволакивавши": ["наволакивав"],
    "наволочив": ["наволочивши"],
    "наволочивши": ["наволочив"],
    "навоняв": ["навонявши"],
    "навонявши": ["навоняв"],
    "навонять": ["насмердеть", "насмердить"],
    "навораживав": ["навораживавши"],
    "навораживавши": ["навораживав"],
    "наворачивав": ["наворачивавши"],
    "наворачивавши": ["наворачивав"],
    "наворачивать": ["навёртывать", "наматывать", "накручивать", "жевать", "глотать", "лопать", "трескать", "рубать", "уплетать", "уписывать", "уминать"],
    "наворовав": ["наворовавши"],
    "наворовавши": ["наворовав"],
    "наворовывав": ["наворовывавши"],
    "наворовывавши": ["наворовывав"],
    "наворожив": ["навороживши"],
    "навороживши": ["наворожив"],
    "наворот": ["наворачивание", "накручивание", "перипетия", "опция"],
    "наворотив": ["наворотивши"],
    "наворотивши": ["наворотив"],
    "наворотить": ["нагромоздить"],
    "наворочав": ["наворочавши"],
    "наворочавши": ["наворочав"],
    "навороченный": ["усложнённый"],
    "наворошив": ["наворошивши"],
    "наворошивши": ["наворошив"],
    "наворсив": ["наворсивши"],
    "наворсивши": ["наворсив"],
    "наворсовав": ["наворсовавши"],
    "наворсовавши": ["наворсовав"],
    "наворчав": ["наворчавши"],
    "наворчавши": ["наворчав"],
    "навострив": ["навостривши"],
    "навостривши": ["навострив"],
    "навострить уши": ["натянуть уши"],
    "навостряв": ["навострявши"],
    "навострявши": ["навостряв"],
    "навощив": ["навощивши"],
    "навощивши": ["навощив"],
    "наврав": ["навравши"],
    "навравши": ["наврав"],
    "наврать": ["наклеветать", "налгать"],
    "навраться": ["налгаться", "набрехаться"],
    "навредив": ["навредивши"],
    "навредивши": ["навредив"],
    "навроде": ["наподобие"],
    "навряд": ["навряд ли"],
    "навряд ли": ["едва ли", "вряд ли", "сомнительно", "вряд"],
    "навсегда": ["навечно", "навеки", "навек", "на веки вечные", "до скончания века", "до скончания веков"],
    "навскидку": ["наудачу", "произвольно", "случайно", "наспех", "с первого взгляда"],
    "навспоминав": ["навспоминавши"],
    "навспоминавши": ["навспоминав"],
    "навстречу": ["навстреч"],
    "навтыкав": ["навтыкавши"],
    "навтыкавши": ["навтыкав"],
    "навыдумав": ["навыдумавши"],
    "навыдумавши": ["навыдумав"],
    "навыдумывав": ["навыдумывавши"],
    "навыдумывавши": ["навыдумывав"],
    "навыдёргивав": ["навыдёргивавши"],
    "навыдёргивавши": ["навыдёргивав"],
    "навыкав": ["навыкавши"],
    "навыкавши": ["навыкав"],
    "навыкат": ["навыкате"],
    "навыкате": ["навыкат"],
    "навыкнув": ["навыкнувши"],
    "навыкнувши": ["навыкнув"],
    "навыкнуть": ["привыкнуть"],
    "навылет": ["насквозь"],
    "навыписывав": ["навыписывавши"],
    "навыписывавши": ["навыписывав"],
    "навытяжку": ["смирно"],
    "навь": ["призрак"],
    "навьючив": ["навьючивши"],
    "навьючивав": ["навьючивавши"],
    "навьючивавши": ["навьючивав"],
    "навьючивать": ["нагружать"],
    "навьючивши": ["навьючив"],
    "навязав": ["навязавши"],
    "навязавши": ["навязав"],
    "навязать": ["привязать", "понавязать"],
    "навязнув": ["навязнувши"],
    "навязнувши": ["навязнув"],
    "навязчиво": ["назойливо", "неотвязно"],
    "навязчивость": ["назойливость", "докучливость"],
    "навязчивый": ["назойливый"],
    "навязывав": ["навязывавши"],
    "навязывавши": ["навязывав"],
    "навязывать": ["привязывать", "впаривать"],
    "навялив": ["навяливши"],
    "навяливав": ["навяливавши"],
    "навяливавши": ["навяливав"],
    "навяливши": ["навялив"],
    "навёзши": ["навезя"],
    "навёрстывав": ["навёрстывавши"],
    "навёрстывавши": ["навёрстывав"],
    "навёртка": ["навёртывание"],
    "навёртывав": ["навёртывавши"],
    "навёртывавши": ["навёртывав"],
    "навёртывание": ["навёртка"],
    "навёртывать": ["накручивать"],
    "нагадав": ["нагадавши"],
    "нагадавши": ["нагадав"],
    "нагадив": ["нагадивши"],
    "нагадивши": ["нагадив"],
    "нагадувати": ["згадувати"],
    "нагадывав": ["нагадывавши"],
    "нагадывавши": ["нагадывав"],
    "нагайка": ["плётка", "плеть"],
    "наган": ["револьвер", "система"],
    "наганивав": ["наганивавши"],
    "наганивавши": ["наганивав"],
    "нагатив": ["нагативши"],
    "нагативши": ["нагатив"],
    "нагачивав": ["нагачивавши"],
    "нагачивавши": ["нагачивав"],
    "нагвазживав": ["нагвазживавши"],
    "нагвазживавши": ["нагвазживав"],
    "нагвоздив": ["нагвоздивши"],
    "нагвоздивши": ["нагвоздив"],
    "наггетс": ["стрипс"],
    "нагель": ["шкант", "чопик"],
    "нагерь": ["вуадтмушш"],
    "нагиб": ["нагибание"],
    "нагибав": ["нагибавши"],
    "нагибавши": ["нагибав"],
    "нагинав": ["нагинавши"],
    "нагинавши": ["нагинав"],
    "нагината": ["глефа", "гуань дао", "совня"],
    "нагината-дзюцу": ["нагинатадзюцу"],
    "нагинать": ["нагибать"],
    "нагишмя": ["нагишом", "голышом", "голяком"],
    "нагишом": ["голышом", "нагишмя", "голяком"],
    "нагладив": ["нагладивши"],
    "нагладивши": ["нагладив"],
    "наглаживав": ["наглаживавши"],
    "наглаживавши": ["наглаживав"],
    "наглазурив": ["наглазуривши"],
    "наглазуривав": ["наглазуривавши"],
    "наглазуривавши": ["наглазуривав"],
    "наглазуривши": ["наглазурив"],
    "наглев": ["наглевши"],
    "наглевши": ["наглев"],
    "нагледник": ["надзирател", "проверител", "надзорник", "нагледвач", "ревизор", "инспектор", "контрольор"],
    "наглец": ["нахал", "бесстыдник"],
    "наглеца": ["наглинка"],
    "нагличав": ["нагличавши"],
    "нагличавши": ["нагличав"],
    "наглость": ["нахальство"],
    "наглупив": ["наглупивши"],
    "наглупивши": ["наглупив"],
    "наглушив": ["наглушивши"],
    "наглушивши": ["наглушив"],
    "наглый": ["беззастенчивый", "дерзкий"],
    "наглядев": ["наглядевши"],
    "наглядевши": ["наглядев"],
    "наглядный": ["очевидный", "недвусмысленный", "выразительный", "иллюстративный", "демонстративный"],
    "наглядовий": ["наглядний"],
    "наглядывав": ["наглядывавши"],
    "наглядывавши": ["наглядывав"],
    "наглянцевав": ["наглянцевавши"],
    "наглянцевавши": ["наглянцевав"],
    "наглянцовав": ["наглянцовавши"],
    "наглянцовавши": ["наглянцовав"],
    "нагнав": ["нагнавши"],
    "нагнавши": ["нагнав"],
    "нагнаивав": ["нагнаивавши"],
    "нагнаивавши": ["нагнаивав"],
    "нагнетав": ["нагнетавши"],
    "нагнетавши": ["нагнетав"],
    "нагнетать": ["накачивать", "накалять", "усиливать"],
    "нагнив": ["нагнивши"],
    "нагнивав": ["нагнивавши"],
    "нагнивавши": ["нагнивав"],
    "нагнивши": ["нагнив"],
    "нагноив": ["нагноивши"],
    "нагноивши": ["нагноив"],
    "нагнув": ["нагнувши"],
    "нагнувши": ["нагнув"],
    "наговаривав": ["наговаривавши"],
    "наговаривавши": ["наговаривав"],
    "наговаривать": ["насказывать"],
    "наговор": ["клевета", "напраслина", "наговаривание", "оговор", "поклёп"],
    "наговорив": ["наговоривши"],
    "наговоривши": ["наговорив"],
    "наговорить": ["наклеветать", "оговорить", "обвинить", "очернить", "заговорить"],
    "наговорить с три короба": ["наврать с три короба"],
    "нагодувати": ["накормити"],
    "нагой": ["голый", "обнажённый", "неодетый", "непокрытый", "оголённый", "неприкрытый", "декольтированный", "открытый"],
    "наголову": ["окончательно", "совершенно", "полностью", "в пух и прах"],
    "наголосовав": ["наголосовавши"],
    "наголосовавши": ["наголосовав"],
    "нагольный": ["явный"],
    "нагоняв": ["нагонявши"],
    "нагонявши": ["нагоняв"],
    "нагоняй": ["наказание", "взбучка", "вздрючка", "встрёпка", "встряска", "втык", "выволочка", "головомойка", "огрёб", "пистон", "промывка мозгов", "разнос", "шмась", "шмазь", "взъёбка"],
    "нагоняние": ["нагнетание"],
    "нагонять": ["настигать", "догонять"],
    "нагорав": ["нагоравши"],
    "нагоравши": ["нагорав"],
    "нагораживав": ["нагораживавши"],
    "нагораживавши": ["нагораживав"],
    "нагорать": ["закоптиться"],
    "нагорбатиться": ["навкалываться"],
    "нагорев": ["нагоревши"],
    "нагоревши": ["нагорев"],
    "нагорно-карабахская республика": ["нагорный карабах", "арцах", "республика арцах", "карабах", "нкр"],
    "нагорно-карабахский": ["нагорнокарабахский", "арцахский"],
    "нагорнокарабахский": ["нагорно-карабахский"],
    "нагорода": ["винагорода"],
    "нагородив": ["нагородивши"],
    "нагородивши": ["нагородив"],
    "нагородить": ["понастроить", "понаставить", "нагромоздить", "наболтать"],
    "нагорье": ["плато", "плоскогорье"],
    "нагота": ["обнажённость"],
    "наготавливав": ["наготавливавши"],
    "наготавливавши": ["наготавливав"],
    "наготове": ["начеку"],
    "наготовив": ["наготовивши"],
    "наготовивши": ["наготовив"],
    "наготовить": ["запасти", "заготовить", "настряпать"],
    "наготовляв": ["наготовлявши"],
    "наготовлявши": ["наготовляв"],
    "нагофрив": ["нагофривши"],
    "нагофривши": ["нагофрив"],
    "нагофрировав": ["нагофрировавши"],
    "нагофрировавши": ["нагофрировав"],
    "награбастав": ["награбаставши"],
    "награбаставши": ["награбастав"],
    "награбастать": ["нахапать"],
    "награбив": ["награбивши"],
    "награбивши": ["награбив"],
    "награвировав": ["награвировавши"],
    "награвировавши": ["награвировав"],
    "награда": ["вознаграждение", "воздаяние", "компенсация"],
    "наградив": ["наградивши"],
    "наградивши": ["наградив"],
    "наградить": ["поощрить", "похвалить"],
    "наградной": ["призовой"],
    "награждав": ["награждавши"],
    "награждавши": ["награждав"],
    "награждать": ["премировать", "наделять"],
    "награжденье": ["награждение"],
    "награнив": ["награнивши"],
    "награнивши": ["награнив"],
    "награфив": ["награфивши"],
    "награфивши": ["награфив"],
    "нагребав": ["нагребавши"],
    "нагребавши": ["нагребав"],
    "нагрев": ["нагревание"],
    "нагревав": ["нагревавши"],
    "нагревавши": ["нагревав"],
    "нагревать": ["греть", "надувать", "облапошивать", "кидать"],
    "нагреваться": ["греться", "согреваться"],
    "нагревши": ["нагрев"],
    "нагремев": ["нагремевши"],
    "нагремевши": ["нагремев"],
    "нагреть": ["подогреть", "разогреть", "согреть", "обогреть", "облапошить"],
    "нагреховодничав": ["нагреховодничавши"],
    "нагреховодничавши": ["нагреховодничав"],
    "нагрешив": ["нагрешивши"],
    "нагрешивши": ["нагрешив"],
    "нагримировав": ["нагримировавши"],
    "нагримировавши": ["нагримировав"],
    "нагримировывав": ["нагримировывавши"],
    "нагримировывавши": ["нагримировывав"],
    "нагрозив": ["нагрозивши"],
    "нагрозивши": ["нагрозив"],
    "нагромождав": ["нагромождавши"],
    "нагромождавши": ["нагромождав"],
    "нагромождение": ["нагроможденье", "наваливание", "навалка", "наворачивание", "нагораживание", "накладывание", "груда", "куча"],
    "нагроможденье": ["нагромождение"],
    "нагромоздив": ["нагромоздивши"],
    "нагромоздивши": ["нагромоздив"],
    "нагрубив": ["нагрубивши"],
    "нагрубивши": ["нагрубив"],
    "нагрубиянив": ["нагрубиянивши"],
    "нагрубиянивши": ["нагрубиянив"],
    "нагружав": ["нагружавши"],
    "нагружавши": ["нагружав"],
    "нагружать": ["грузить", "загружать", "обременять"],
    "нагруженность": ["загруженность"],
    "нагрузив": ["нагрузивши"],
    "нагрузивши": ["нагрузив"],
    "нагрузиться": ["загрузиться", "набраться", "наклюкаться"],
    "нагрунтовав": ["нагрунтовавши"],
    "нагрунтовавши": ["нагрунтовав"],
    "нагрунтовывав": ["нагрунтовывавши"],
    "нагрунтовывавши": ["нагрунтовывав"],
    "нагрызав": ["нагрызавши"],
    "нагрызавши": ["нагрызав"],
    "нагрязнив": ["нагрязнивши"],
    "нагрязнивши": ["нагрязнив"],
    "нагрянув": ["нагрянувши"],
    "нагрянувши": ["нагрянув"],
    "нагрянуть": ["наскочить"],
    "нагуглив": ["нагугливши"],
    "нагугливши": ["нагуглив"],
    "нагуливав": ["нагуливавши"],
    "нагуливавши": ["нагуливав"],
    "нагуляв": ["нагулявши"],
    "нагулявши": ["нагуляв"],
    "нагуторив": ["нагуторивши"],
    "нагуторивши": ["нагуторив"],
    "над": ["никотинамидадениндинуклеотид"],
    "надаб": ["гарав"],
    "надавав": ["надававши"],
    "надававши": ["надавав"],
    "надавив": ["надавивши"],
    "надавивши": ["надавив"],
    "надавливав": ["надавливавши"],
    "надавливавши": ["надавливав"],
    "надаивав": ["надаивавши"],
    "надаивавши": ["надаивав"],
    "надалбливав": ["надалбливавши"],
    "надалбливавши": ["надалбливав"],
    "надареност": ["заложба", "дарба", "дарование", "даровитост", "талант"],
    "надарив": ["надаривши"],
    "надаривав": ["надаривавши"],
    "надаривавши": ["надаривав"],
    "надаривши": ["надарив"],
    "надбавив": ["надбавивши"],
    "надбавивши": ["надбавив"],
    "надбавляв": ["надбавлявши"],
    "надбавлявши": ["надбавляв"],
    "надбив": ["надбивши"],
    "надбивав": ["надбивавши"],
    "надбивавши": ["надбивав"],
    "надбивши": ["надбив"],
    "надбровная дуга": ["надбровье"],
    "надбровница": ["надбровье"],
    "надбровье": ["надбровная дуга"],
    "надвернув": ["надвернувши"],
    "надвернувши": ["надвернув"],
    "надвив": ["надвивши"],
    "надвивав": ["надвивавши"],
    "надвивавши": ["надвивав"],
    "надвивши": ["надвив"],
    "надвиг": ["надвижка"],
    "надвигав": ["надвигавши"],
    "надвигавши": ["надвигав"],
    "надвижка": ["надвиг"],
    "надвинув": ["надвинувши"],
    "надвинувши": ["надвинув"],
    "надвое": ["пополам", "напополам", "наполы", "двойственно", "двояко"],
    "надвязав": ["надвязавши"],
    "надвязавши": ["надвязав"],
    "надвязывав": ["надвязывавши"],
    "надвязывавши": ["надвязывав"],
    "надвёртывав": ["надвёртывавши"],
    "надвёртывавши": ["надвёртывав"],
    "надгибав": ["надгибавши"],
    "надгибавши": ["надгибав"],
    "надглавье": ["надглавок"],
    "надгнив": ["надгнивши"],
    "надгнивав": ["надгнивавши"],
    "надгнивавши": ["надгнивав"],
    "надгнивши": ["надгнив"],
    "надгробие": ["надгробье"],
    "надгробье": ["надгробие"],
    "надгрызав": ["надгрызавши"],
    "надгрызавши": ["надгрызав"],
    "наддав": ["наддавши"],
    "наддавав": ["наддававши"],
    "наддававши": ["наддавав"],
    "наддавши": ["наддав"],
    "наддалбливав": ["наддалбливавши"],
    "наддалбливавши": ["наддалбливав"],
    "надделав": ["надделавши"],
    "надделавши": ["надделав"],
    "наддержава": ["супердержава"],
    "наддирав": ["наддиравши"],
    "наддиравши": ["наддирав"],
    "наддолбив": ["наддолбивши"],
    "наддолбивши": ["наддолбив"],
    "наддрав": ["наддравши"],
    "наддравши": ["наддрав"],
    "наддував": ["наддувавши"],
    "наддувавши": ["наддував"],
    "наддувши": ["наддув"],
    "надебоширив": ["надебоширивши"],
    "надебоширивши": ["надебоширив"],
    "надебоширить": ["набуянить", "наскандалить"],
    "надевав": ["надевавши"],
    "надевавши": ["надевав"],
    "надеванье": ["надевание"],
    "надевать": ["одевать", "насаживать", "нанизывать"],
    "надевши": ["надев"],
    "надежда": ["надя", "наденька", "надюша", "надька", "надюха"],
    "надел": ["наделение", "участок"],
    "наделав": ["наделавши"],
    "наделавши": ["наделав"],
    "наделать": ["накарбашать", "накулемать", "намастерить", "намухлачить", "наплетюхать", "натворить", "смастерить"],
    "наделив": ["наделивши"],
    "наделивши": ["наделив"],
    "наделить": ["наградить"],
    "наделяв": ["наделявши"],
    "наделявши": ["наделяв"],
    "надерзив": ["надерзивши"],
    "надерзивши": ["надерзив"],
    "надерзить": ["нагрубить"],
    "надеяться": ["рассчитывать", "уповать", "полагаться", "возлагать надежды"],
    "надзирав": ["надзиравши"],
    "надзиравши": ["надзирав"],
    "надзирательный": ["наблюдательный"],
    "надзор": ["слежка", "слежение"],
    "надивив": ["надививши"],
    "надививши": ["надивив"],
    "надиктовав": ["надиктовавши"],
    "надиктовавши": ["надиктовав"],
    "надиктовывав": ["надиктовывавши"],
    "надиктовывавши": ["надиктовывав"],
    "надиктовывать": ["диктовать"],
    "надинамив": ["надинамивши"],
    "надинамивши": ["надинамив"],
    "надирав": ["надиравши"],
    "надиравши": ["надирав"],
    "надисторичный": ["надысторичный"],
    "надкалывав": ["надкалывавши"],
    "надкалывавши": ["надкалывав"],
    "надкашивав": ["надкашивавши"],
    "надкашивавши": ["надкашивав"],
    "надклассовый": ["внеклассовый"],
    "надклевав": ["надклевавши"],
    "надклевавши": ["надклевав"],
    "надклеив": ["надклеивши"],
    "надклеивав": ["надклеивавши"],
    "надклеивавши": ["надклеивав"],
    "надклеивши": ["надклеив"],
    "надклепав": ["надклепавши"],
    "надклепавши": ["надклепав"],
    "надклюнув": ["надклюнувши"],
    "надклюнувши": ["надклюнув"],
    "надклёвывав": ["надклёвывавши"],
    "надклёвывавши": ["надклёвывав"],
    "надклёпывав": ["надклёпывавши"],
    "надклёпывавши": ["надклёпывав"],
    "надковав": ["надковавши"],
    "надковавши": ["надковав"],
    "надковывав": ["надковывавши"],
    "надковывавши": ["надковывав"],
    "надколов": ["надколовши"],
    "надколовши": ["надколов"],
    "надкопав": ["надкопавши"],
    "надкопавши": ["надкопав"],
    "надкосив": ["надкосивши"],
    "надкосивши": ["надкосив"],
    "надкостница": ["периост"],
    "надкус": ["укус"],
    "надкусав": ["надкусавши"],
    "надкусавши": ["надкусав"],
    "надкусанный": ["надкушенный"],
    "надкусив": ["надкусивши"],
    "надкусивши": ["надкусив"],
    "надкусывав": ["надкусывавши"],
    "надкусывавши": ["надкусывав"],
    "надкушенный": ["надкусанный"],
    "надламывав": ["надламывавши"],
    "надламывавши": ["надламывав"],
    "надлежав": ["надлежавши"],
    "надлежавши": ["надлежав"],
    "надлежаще": ["должным образом", "как следует", "как подобает"],
    "надлежащий": ["соответствующий"],
    "надлепливав": ["надлепливавши"],
    "надлепливавши": ["надлепливав"],
    "надлепляв": ["надлеплявши"],
    "надлеплявши": ["надлепляв"],
    "надлеплять": ["надклеивать"],
    "надличностный": ["надындивидуальный"],
    "надлишок": ["лишок"],
    "надлобье": ["темя"],
    "надломав": ["надломавши"],
    "надломавши": ["надломав"],
    "надломив": ["надломивши"],
    "надломивши": ["надломив"],
    "надломить": ["надломать", "подорвать"],
    "надлупив": ["надлупивши"],
    "надлупивши": ["надлупив"],
    "надлупливав": ["надлупливавши"],
    "надлупливавши": ["надлупливав"],
    "надмачивав": ["надмачивавши"],
    "надмачивавши": ["надмачивав"],
    "надмевав": ["надмевавши"],
    "надмевавши": ["надмевав"],
    "надмение": ["надменность", "дутьё"],
    "надменничав": ["надменничавши"],
    "надменничавши": ["надменничав"],
    "надменно": ["высокомерно", "заносчиво", "свысока"],
    "надменность": ["высокомерие", "заносчивость", "кичливость", "спесь"],
    "надменный": ["высокомерный", "пренебрежительный", "гордый", "кичливый", "чванливый"],
    "надмокав": ["надмокавши"],
    "надмокавши": ["надмокав"],
    "надмокнув": ["надмокнувши"],
    "надмокнувши": ["надмокнув"],
    "надмолекула": ["супрамолекула"],
    "надмочив": ["надмочивши"],
    "надмочивши": ["надмочив"],
    "наднациональный": ["международный", "интернациональный", "транснациональный"],
    "надничар": ["работник", "наемник"],
    "надо": ["выше", "поверх"],
    "надобно": ["надо", "нужно", "необходимо"],
    "надобность": ["необходимость", "потребность", "дело", "нужда"],
    "надогнув": ["надогнувши"],
    "надогнувши": ["надогнув"],
    "надодрав": ["надодравши"],
    "надодравши": ["надодрав"],
    "надоеда": ["надоедала"],
    "надоедав": ["надоедавши"],
    "надоедавши": ["надоедав"],
    "надоедала": ["надоеда"],
    "надоедать": ["наскучивать", "докучать"],
    "надоедливо": ["докучливо", "назойливо"],
    "надоедливый": ["докучливый", "назойливый", "вымогной", "надоедный"],
    "надоесть": ["наскучить", "приесться", "опостылеть"],
    "надоив": ["надоивши"],
    "надоивши": ["надоив"],
    "надой": ["надаивание", "удой"],
    "надокучав": ["надокучавши"],
    "надокучавши": ["надокучав"],
    "надокучив": ["надокучивши"],
    "надокучивши": ["надокучив"],
    "надолб": ["зуб дракона"],
    "надолбив": ["надолбивши"],
    "надолбивши": ["надолбив"],
    "надолжав": ["надолжавши"],
    "надолжавши": ["надолжав"],
    "надорвав": ["надорвавши"],
    "надорвавши": ["надорвав"],
    "надосадив": ["надосадивши"],
    "надосадивши": ["надосадив"],
    "надосаждать": ["досаждать"],
    "надоумив": ["надоумивши"],
    "надоумивши": ["надоумив"],
    "надоумить": ["научить", "вразумить", "посоветовать", "подсказать"],
    "надоумливав": ["надоумливавши"],
    "надоумливавши": ["надоумливав"],
    "надпарывав": ["надпарывавши"],
    "надпарывавши": ["надпарывав"],
    "надпаяв": ["надпаявши"],
    "надпаявши": ["надпаяв"],
    "надпаять": ["напаять"],
    "надпереносье": ["глабелла", "глабель"],
    "надпероксид": ["надперекись", "гипероксид", "супероксид"],
    "надпечатав": ["надпечатавши"],
    "надпечатавши": ["надпечатав"],
    "надпив": ["надпивши"],
    "надпивав": ["надпивавши"],
    "надпивавши": ["надпивав"],
    "надпивши": ["надпив"],
    "надпилив": ["надпиливши"],
    "надпиливав": ["надпиливавши"],
    "надпиливавши": ["надпиливав"],
    "надпиливши": ["надпилив"],
    "надписав": ["надписавши"],
    "надписавши": ["надписав"],
    "надписание": ["надписывание", "надпись"],
    "надписывав": ["надписывавши"],
    "надписывавши": ["надписывав"],
    "надпить": ["отпить", "отхлебнуть"],
    "надпоров": ["надпоровши"],
    "надпоровши": ["надпоров"],
    "надпревара": ["съревнование"],
    "надрав": ["надравши"],
    "надравши": ["надрав"],
    "надраив": ["надраивши"],
    "надраивав": ["надраивавши"],
    "надраивавши": ["надраивав"],
    "надраивать": ["начищать", "натирать", "драить"],
    "надраивши": ["надраив"],
    "надраить": ["начистить", "натереть"],
    "надрастав": ["надраставши"],
    "надраставши": ["надрастав"],
    "надрать": ["нарвать", "надёргать"],
    "надрать уши": ["оболтать уши"],
    "надрез": ["надрезание"],
    "надрезав": ["надрезавши"],
    "надрезавши": ["надрезав"],
    "надрезывав": ["надрезывавши"],
    "надрезывавши": ["надрезывав"],
    "надрезывать": ["надрезать"],
    "надрессировав": ["надрессировавши"],
    "надрессировавши": ["надрессировав"],
    "надробив": ["надробивши"],
    "надробивши": ["надробив"],
    "надрогнуться": ["намёрзнуться", "надрожаться"],
    "надрубав": ["надрубавши"],
    "надрубавши": ["надрубав"],
    "надрубив": ["надрубивши"],
    "надрубивши": ["надрубив"],
    "надругание": ["глумление", "осквернение", "кощунство", "издевательство", "издёвка", "оскорбление", "насмешка"],
    "надруганье": ["надругание"],
    "надругательство": ["глумление", "осквернение", "кощунство", "издевательство", "издёвка", "оскорбление", "насмешка"],
    "надругаться": ["унизить", "оскорбить", "осквернить", "опоганить", "испоганить", "наглумиться", "поглумиться", "загадить", "изгадить", "оплевать", "изнасиловать"],
    "надрывав": ["надрывавши"],
    "надрывавши": ["надрывав"],
    "надрызгав": ["надрызгавши"],
    "надрызгавши": ["надрызгав"],
    "надрызгивав": ["надрызгивавши"],
    "надрызгивавши": ["надрызгивав"],
    "надсад": ["надсада", "надсаживание", "натуга"],
    "надсада": ["усилие", "напряжение"],
    "надсадив": ["надсадивши"],
    "надсадивши": ["надсадив"],
    "надсадно": ["надсадливо"],
    "надсадный": ["надрывный", "натужный", "надрывистый"],
    "надсажав": ["надсажавши"],
    "надсажавши": ["надсажав"],
    "надсаживав": ["надсаживавши"],
    "надсаживавши": ["надсаживав"],
    "надсаживание": ["надсад"],
    "надсаживать": ["надрывать"],
    "надсверлив": ["надсверливши"],
    "надсверливав": ["надсверливавши"],
    "надсверливавши": ["надсверливав"],
    "надсверливши": ["надсверлив"],
    "надсекав": ["надсекавши"],
    "надсекавши": ["надсекав"],
    "надсечение": ["надсекание", "надсечка", "надрезание"],
    "надслов": ["надпис", "наименование", "име", "название", "заглавие", "рубрика"],
    "надсматривав": ["надсматривавши"],
    "надсматривавши": ["надсматривав"],
    "надсмехаться": ["насмехаться"],
    "надсмотрщик": ["надзорщик"],
    "надставив": ["надставивши"],
    "надставивши": ["надставив"],
    "надставляв": ["надставлявши"],
    "надставлявши": ["надставляв"],
    "надстрагивав": ["надстрагивавши"],
    "надстрагивавши": ["надстрагивав"],
    "надстраивав": ["надстраивавши"],
    "надстраивавши": ["надстраивав"],
    "надстрогав": ["надстрогавши"],
    "надстрогавши": ["надстрогав"],
    "надстроив": ["надстроивши"],
    "надстроивши": ["надстроив"],
    "надстроить": ["пристроить"],
    "надстругав": ["надстругавши"],
    "надстругавши": ["надстругав"],
    "надстругивав": ["надстругивавши"],
    "надстругивавши": ["надстругивав"],
    "надсыпав": ["надсыпавши"],
    "надсыпавши": ["надсыпав"],
    "надтесав": ["надтесавши"],
    "надтесавши": ["надтесав"],
    "надто": ["занадто"],
    "надтреснув": ["надтреснувши"],
    "надтреснувши": ["надтреснув"],
    "надтёсывав": ["надтёсывавши"],
    "надтёсывавши": ["надтёсывав"],
    "надубив": ["надубивши"],
    "надубивши": ["надубив"],
    "надубляв": ["надублявши"],
    "надублявши": ["надубляв"],
    "надув": ["надувание", "надувка", "надутость", "намёт", "сувой"],
    "надував": ["надувавши"],
    "надувавши": ["надував"],
    "надувала": ["обдувала", "обманщик", "обманщица", "мошенник", "мошенница"],
    "надуванье": ["надувание"],
    "надувательство": ["жульничество", "обдуривание", "мухлёж"],
    "надувать щёки": ["раздувать щёки"],
    "надувной": ["пневматический"],
    "надувши": ["надув"],
    "надудонив": ["надудонивши"],
    "надудонивши": ["надудонив"],
    "надудонить": ["написать", "нассать"],
    "надумав": ["надумавши"],
    "надумавши": ["надумав"],
    "надуманно": ["искусственно", "нарочито"],
    "надумывав": ["надумывавши"],
    "надумывавши": ["надумывав"],
    "надурив": ["надуривши"],
    "надуривши": ["надурив"],
    "надутый": ["вздутый", "высокомерный", "напыщенный", "чванливый", "чванный", "высокопарный", "обиженный", "рассерженный", "сердитый", "недовольный"],
    "надуть губы": ["надуться", "закопылить губы"],
    "надуться как мышь на крупу": ["надуться"],
    "надушив": ["надушивши"],
    "надушивши": ["надушив"],
    "надхрящница": ["перихондр", "перихондрий"],
    "надцарство": ["домен"],
    "надчекан": ["надчеканка", "контрмарка"],
    "надчеканив": ["надчеканивши"],
    "надчеканивав": ["надчеканивавши"],
    "надчеканивавши": ["надчеканивав"],
    "надчеканивши": ["надчеканив"],
    "надчеканка": ["надчекан", "контрмарка"],
    "надшибав": ["надшибавши"],
    "надшибавши": ["надшибав"],
    "надшибив": ["надшибивши"],
    "надшибивши": ["надшибив"],
    "надшив": ["надшивши"],
    "надшивав": ["надшивавши"],
    "надшивавши": ["надшивав"],
    "надшивши": ["надшив"],
    "надъевший": ["надкусивший"],
    "надъедав": ["надъедавши"],
    "надъедавши": ["надъедав"],
    "надъесть": ["надкусить"],
    "надыбав": ["надыбавши"],
    "надыбавши": ["надыбав"],
    "надымив": ["надымивши"],
    "надымивши": ["надымив"],
    "надындивидуальный": ["надличностный"],
    "надысторический": ["надисторический"],
    "надысторичный": ["надисторичный", "сверхисторический"],
    "надысь": ["давеча", "недавно", "намедни", "надыся", "нагдысь", "ономедни", "ономеднись", "ономнясь"],
    "надышав": ["надышавши"],
    "надышавши": ["надышав"],
    "надэра": ["мегаэра", "эон"],
    "надюша": ["надя"],
    "надя": ["надеждушка", "надея", "надёна", "надёха", "надюха", "надюша", "надюня", "надюра", "надюся", "надина", "надиша", "надежа", "надёжа"],
    "надёванный": ["ношеный"],
    "надёжа": ["надежда", "опора"],
    "надёжно": ["безопасно", "прочно", "солидно"],
    "надёжный": ["верный", "прочный", "крепкий", "безопасный", "правильный"],
    "надёргав": ["надёргавши"],
    "надёргавши": ["надёргав"],
    "надёргивав": ["надёргивавши"],
    "надёргивавши": ["надёргивав"],
    "надёрнув": ["надёрнувши"],
    "надёрнувши": ["надёрнув"],
    "наебав": ["наебавши"],
    "наебавши": ["наебав"],
    "наебалово": ["обман", "надувательство", "обувалово", "кидалово", "кидняк", "наебаловка", "наёб", "наёбка", "наебон", "наеботека", "объёб", "объёбка", "объебон", "объебательство", "объебушка"],
    "наебательство": ["надувательство", "наебаловка", "наебалово", "наёб", "наёбка", "наебон", "объебаловка", "объебалово", "объёб", "объёбка", "объебон", "наёбочка", "объебончик", "наеботека"],
    "наебать": ["наебти"],
    "наебаться": ["наебтись"],
    "наебениться": ["набухаться", "нажраться"],
    "наебнув": ["наебнувши"],
    "наебнувши": ["наебнув"],
    "наебнуть": ["ударить", "навернуть", "ёбнуть", "уебать", "сломать", "испортить", "уничтожить", "разъебать", "расхуярить", "расхуячить"],
    "наебнуться": ["упасть", "сверзиться", "навернуться", "ковырнуться", "ёбнуться", "пиздануться", "гакнуться", "накрыться", "накрыться медным тазом", "накрыться пиздой", "пиздой накрыться"],
    "наеборезиться": ["уделаться"],
    "наеборезываться": ["уделываться"],
    "наебтись": ["наебаться"],
    "наегорив": ["наегоривши"],
    "наегоривши": ["наегорив"],
    "наедав": ["наедавши"],
    "наедавши": ["наедав"],
    "наедаться": ["насыщаться", "есть досыта"],
    "наедине": ["тет-а-тет", "с глазу на глаз"],
    "наездив": ["наездивши"],
    "наездивши": ["наездив"],
    "наездник": ["всадник"],
    "наездничав": ["наездничавши"],
    "наездничавши": ["наездничав"],
    "наезжав": ["наезжавши"],
    "наезжавши": ["наезжав"],
    "наезживав": ["наезживавши"],
    "наезживавши": ["наезживав"],
    "наерундив": ["наерундивши"],
    "наерундивши": ["наерундив"],
    "наесться": ["насытиться"],
    "наехав": ["наехавши"],
    "наехавши": ["наехав"],
    "нажав": ["нажавши"],
    "нажавши": ["нажав"],
    "нажалив": ["нажаливши"],
    "нажаливши": ["нажалив"],
    "нажаловаться": ["пожаловаться"],
    "нажарив": ["нажаривши"],
    "нажаривав": ["нажаривавши"],
    "нажаривавши": ["нажаривав"],
    "нажаривши": ["нажарив"],
    "нажать": ["надавить"],
    "нажатье": ["нажатие"],
    "наждав": ["наждавши"],
    "наждавши": ["наждав"],
    "наждачка": ["абразивная бумага", "наждачная бумага", "шлифовальная бумага", "шкурка", "шлифшкурка"],
    "наждачная бумага": ["абразивная бумага", "шлифовальная бумага", "наждачка", "шкурка", "шлифшкурка"],
    "нажевав": ["нажевавши"],
    "нажевавши": ["нажевав"],
    "нажелтив": ["нажелтивши"],
    "нажелтивши": ["нажелтив"],
    "наживав": ["наживавши"],
    "наживавши": ["наживав"],
    "наживаться": ["обогащаться", "нагревать руки", "наживать капитал", "наживать", "богатство"],
    "наживив": ["нажививши"],
    "нажививши": ["наживив"],
    "наживка": ["наживление", "приманка"],
    "наживляв": ["наживлявши"],
    "наживлявши": ["наживляв"],
    "наживши": ["нажив"],
    "нажигав": ["нажигавши"],
    "нажигавши": ["нажигав"],
    "нажидав": ["нажидавши"],
    "нажидавши": ["нажидав"],
    "нажим": ["напор", "натиск", "давление", "принуждение"],
    "нажимав": ["нажимавши"],
    "нажимавши": ["нажимав"],
    "нажимать": ["надавливать", "давить", "жать", "притискивать", "наседать", "налегать"],
    "нажинав": ["нажинавши"],
    "нажинавши": ["нажинав"],
    "нажирав": ["нажиравши"],
    "нажиравши": ["нажирав"],
    "нажираться": ["наедаться", "обжираться"],
    "нажопив": ["нажопивши"],
    "нажопивши": ["нажопив"],
    "нажопный": ["напопный", "наягодичный"],
    "нажористый": ["вкусный", "сытный", "крепкий", "выгодный", "яркий", "необычный", "самобытный", "колоритный"],
    "нажрав": ["нажравши"],
    "нажравши": ["нажрав"],
    "нажраться": ["наесться", "объесться", "надраться", "напиться"],
    "нажужжав": ["нажужжавши"],
    "нажужжавши": ["нажужжав"],
    "нажучив": ["нажучивши"],
    "нажучивши": ["нажучив"],
    "нажучить": ["прижучить"],
    "нажёвывав": ["нажёвывавши"],
    "нажёвывавши": ["нажёвывав"],
    "назавтра": ["завтра", "назавтраго", "назавтре", "назавтрего", "назавтрее", "назавтри", "назавтриго", "назавтрие", "назавтрия"],
    "назад": ["вспять", "взадьпят", "взадпятки", "раком", "обратно"],
    "назакрывав": ["назакрывавши"],
    "назакрывавши": ["назакрывав"],
    "назализировав": ["назализировавши"],
    "назализировавши": ["назализировав"],
    "назализовав": ["назализовавши"],
    "назализовавши": ["назализовав"],
    "назализовать": ["назализировать"],
    "назалировав": ["назалировавши"],
    "назалировавши": ["назалировав"],
    "назальный": ["носовой"],
    "назанимав": ["назанимавши"],
    "назанимавши": ["назанимав"],
    "назаняв": ["назанявши"],
    "назанявши": ["назаняв"],
    "назарабатывав": ["назарабатывавши"],
    "назарабатывавши": ["назарабатывав"],
    "назарей": ["назорей"],
    "назареянин": ["назаретянин"],
    "назвав": ["назвавши"],
    "назвавши": ["назвав"],
    "названивав": ["названивавши"],
    "названивавши": ["названивав"],
    "название": ["нарицание", "прозвание", "имя", "кличка", "погоняло"],
    "названый": ["неродной"],
    "назвать": ["поименовать", "наречь", "охарактеризовать"],
    "назвонив": ["назвонивши"],
    "назвонивши": ["назвонив"],
    "наздравица": ["тост", "напивка"],
    "назеленив": ["назеленивши"],
    "назеленивши": ["назеленив"],
    "наземный": ["сухопутный"],
    "назеркалив": ["назеркаливши"],
    "назеркаливши": ["назеркалив"],
    "назидав": ["назидавши"],
    "назидавши": ["назидав"],
    "назидание": ["наставление", "поучение", "нотация", "урок"],
    "назидательно": ["наставительно", "менторски", "поучительно"],
    "назидательность": ["наставительность", "нравоучительность", "дидактичность"],
    "назирав": ["назиравши"],
    "назиравши": ["назирав"],
    "назират": ["наркомат", "министерство"],
    "назло": ["наперекор", "нарочно"],
    "назначав": ["назначавши"],
    "назначавши": ["назначав"],
    "назначение": ["предназначение", "функция", "миссия", "роль"],
    "назначенье": ["назначение"],
    "назначив": ["назначивши"],
    "назначивши": ["назначив"],
    "назойливость": ["навязчивость", "надоедливость"],
    "назойливый": ["надоедливый", "докучливый", "навязчивый", "неотвязный", "прилипчивый"],
    "назорат": ["тароват"],
    "назораткунанда": ["назоратгар"],
    "назрановский": ["назранский"],
    "назранский": ["назрановский"],
    "назрев": ["назревши"],
    "назревав": ["назревавши"],
    "назревавши": ["назревав"],
    "назревши": ["назрев"],
    "назубок": ["наизусть"],
    "назубрив": ["назубривши"],
    "назубривав": ["назубривавши"],
    "назубривавши": ["назубривав"],
    "назубривши": ["назубрив"],
    "называв": ["называвши"],
    "называвши": ["называв"],
    "называть": ["характеризовать", "прозывать", "звать", "нарекать", "крестить", "окрестить", "указывать", "упоминать", "сообщать", "произносить", "озвучивать", "обнародовать"],
    "называться": ["именоваться", "нарекаться", "быть", "значить", "характеризоваться"],
    "назюзюкаться": ["нажраться", "напиться", "надраться", "набраться", "нарезаться", "наклюкаться"],
    "назябнув": ["назябнувши"],
    "назябнувши": ["назябнув"],
    "назябнуться": ["иззябнуться", "намёрзнуться", "промёрзнуть"],
    "назём": ["навоз"],
    "наи-": ["архи-", "гипер-", "пре-", "сверх-", "супер-", "ультра-"],
    "наиб": ["наместник", "заместитель"],
    "наиболее": ["особенно"],
    "наибольшее": ["максимум"],
    "наибольший общий делитель": ["нод"],
    "наивеличайший": ["величайший"],
    "наивернейший": ["надёжнейший", "достовернейший"],
    "наивничав": ["наивничавши"],
    "наивничавши": ["наивничав"],
    "наивно": ["простодушно", "бесхитростно"],
    "наивность": ["бесхитростность", "простодушие", "непосредственность", "невинность"],
    "наивный": ["неопытный", "простодушный", "безыскусственный", "непосредственный"],
    "наивысший": ["высочайший"],
    "наигигантнейший": ["наигигантский"],
    "наиграв": ["наигравши"],
    "наигравши": ["наиграв"],
    "наигрывав": ["наигрывавши"],
    "наигрывавши": ["наигрывав"],
    "наигрыш": ["аккомпанемент"],
    "наизусть": ["на память", "по памяти"],
    "наилегчайший": ["легчайший", "простейший"],
    "наилучший": ["лучший"],
    "наиля": ["ная"],
    "наименовав": ["наименовавши"],
    "наименовавши": ["наименовав"],
    "наименование": ["называние", "именование", "название", "имя", "позиция", "пункт"],
    "наименованье": ["наименование"],
    "наименовать": ["назвать"],
    "наименовывав": ["наименовывавши"],
    "наименовывавши": ["наименовывав"],
    "наименьшее": ["минимум"],
    "наимпровизировав": ["наимпровизировавши"],
    "наимпровизировавши": ["наимпровизировав"],
    "наиновейший": ["самоновейший"],
    "наинструментовав": ["наинструментовавши"],
    "наинструментовавши": ["наинструментовав"],
    "наинужнейший": ["необходимый"],
    "наипаче": ["тем более", "в особенности", "пуще всего"],
    "наиржачнейший": ["наисмешнейший"],
    "наисветлейший": ["светлейший"],
    "наискосок": ["наискось"],
    "наискось": ["наискосок"],
    "наитие": ["снисшествие", "сошествие", "озарение", "осенение"],
    "наитупейший": ["тупейший"],
    "наитье": ["наитие"],
    "наитяжелейший": ["тяжелейший", "труднейший", "сложнейший"],
    "наихороший": ["наилучший"],
    "наихуёвейший": ["наихудший", "хуёвейший"],
    "наиярчайший": ["ярчайший"],
    "най": ["флейта пана"],
    "найденный": ["обнаруженный", "установленный", "определённый"],
    "найдя": ["нашед", "нашедши"],
    "найдёныш": ["подкидыш"],
    "найки": ["кроссовка", "ботинок", "обувь"],
    "найлон": ["нейлон"],
    "найм": ["наём"],
    "наймитка": ["наймичка", "работница", "наёмница"],
    "наймовав": ["наймовавши"],
    "наймовавши": ["наймовав"],
    "найт-клаб": ["найт-клуб"],
    "найт-клуб": ["найт-клаб"],
    "найти": ["обнаружить", "сыскать", "разыскать", "выискать", "отыскать", "раскопать", "нарыть", "выяснить", "встретить", "рассчитать", "высчитать", "подсчитать", "выбрать", "выкроить", "улучить"],
    "найти моду": ["взять моду"],
    "найтись": ["обнаружиться", "отыскаться", "разыскаться", "сыскаться", "оказаться", "выискаться", "найти выход"],
    "найтов": ["верёвка", "трос"],
    "найтовив": ["найтовивши"],
    "найтовивши": ["найтовив"],
    "нака": ["сладость", "лакомство", "сладенькое", "вкусненькое", "вкуснятина", "вкуснотища", "конфетка", "вкусняшка", "няма", "нямка"],
    "накаверзив": ["накаверзивши"],
    "накаверзивши": ["накаверзив"],
    "накаверзничав": ["накаверзничавши"],
    "накаверзничавши": ["накаверзничав"],
    "накадив": ["накадивши"],
    "накадивши": ["накадив"],
    "наказав": ["наказавши"],
    "наказавши": ["наказав"],
    "наказание": ["воздаяние", "расплата", "месть", "штраф", "кара", "возмездие", "горе"],
    "наказать": ["велеть", "поручить"],
    "наказывав": ["наказывавши"],
    "наказывавши": ["наказывав"],
    "наказывать": ["карать"],
    "накакав": ["накакавши"],
    "накакавши": ["накакав"],
    "накакать": ["насрать"],
    "накал": ["свет", "свечение", "излучение света", "взрывоопасность", "драматизм", "драматичность", "накалённая атмосфера", "напряжённая атмосфера", "накалённая обстановка", "накалка", "напряг", "напряжение", "напряжённость", "напряжённая обстановка", "острота"],
    "накалив": ["накаливши"],
    "накаливав": ["накаливавши"],
    "накаливавши": ["накаливав"],
    "накаливать": ["накалять"],
    "накаливши": ["накалив"],
    "накалывав": ["накалывавши"],
    "накалывавши": ["накалывав"],
    "накаляв": ["накалявши"],
    "накалявши": ["накаляв"],
    "накалякав": ["накалякавши"],
    "накалякавши": ["накалякав"],
    "накалять": ["накаливать", "нагнетать"],
    "накалённость": ["накал"],
    "накана": ["готовност"],
    "наканифолив": ["наканифоливши"],
    "наканифоливав": ["наканифоливавши"],
    "наканифоливавши": ["наканифоливав"],
    "наканифоливать": ["канифолить"],
    "наканифоливши": ["наканифолив"],
    "накануне": ["незадолго", "надысь", "намедни", "давеча", "в преддверии"],
    "накапав": ["накапавши"],
    "накапавши": ["накапав"],
    "накапливав": ["накапливавши"],
    "накапливавши": ["накапливав"],
    "накапливать": ["копить", "накоплять", "собирать", "аккумулировать"],
    "накапливаться": ["копиться"],
    "накапчивав": ["накапчивавши"],
    "накапчивавши": ["накапчивав"],
    "накапывав": ["накапывавши"],
    "накапывавши": ["накапывав"],
    "накаркав": ["накаркавши"],
    "накаркавши": ["накаркав"],
    "накаркать": ["напророчить", "накликать"],
    "накаркивав": ["накаркивавши"],
    "накаркивавши": ["накаркивав"],
    "накармливав": ["накармливавши"],
    "накармливавши": ["накармливав"],
    "накарябав": ["накарябавши"],
    "накарябавши": ["накарябав"],
    "накатав": ["накатавши"],
    "накатавши": ["накатав"],
    "накатать": ["наездить", "настрочить", "укатать"],
    "накатив": ["накативши"],
    "накативши": ["накатив"],
    "накатывав": ["накатывавши"],
    "накатывавши": ["накатывав"],
    "накачав": ["накачавши"],
    "накачавши": ["накачав"],
    "накачивав": ["накачивавши"],
    "накачивавши": ["накачивав"],
    "накашивав": ["накашивавши"],
    "накашивавши": ["накашивав"],
    "наквасив": ["наквасивши"],
    "наквасивши": ["наквасив"],
    "наквашивав": ["наквашивавши"],
    "наквашивавши": ["наквашивав"],
    "накернив": ["накернивши"],
    "накернивши": ["накернив"],
    "накидав": ["накидавши"],
    "накидавши": ["накидав"],
    "накидывав": ["накидывавши"],
    "накидывавши": ["накидывав"],
    "накидываться": ["нападать"],
    "накинув": ["накинувши"],
    "накинувши": ["накинув"],
    "накинуть": ["набросить", "надеть", "надбавить", "прибавить"],
    "накипав": ["накипавши"],
    "накипавши": ["накипав"],
    "накипев": ["накипевши"],
    "накипевши": ["накипев"],
    "накипятив": ["накипятивши"],
    "накипятивши": ["накипятив"],
    "накисав": ["накисавши"],
    "накисавши": ["накисав"],
    "накиснув": ["накиснувши"],
    "накиснувши": ["накиснув"],
    "накит": ["украшение", "скъпоценност", "украса", "гиздило", "труфило"],
    "наклав": ["наложив"],
    "наклавши": ["наложив", "наложивши", "наклав"],
    "наклавший": ["наложивший"],
    "наклад": ["убыток"],
    "накладав": ["накладавши"],
    "накладавши": ["накладав"],
    "накладка": ["молдинг", "облицовка", "обшивка", "пластина", "нашлёпка", "путаница", "ошибка", "промах", "промашка", "недоразумение", "накладывание"],
    "накладывав": ["накладывавши"],
    "накладывавши": ["накладывав"],
    "накладываться": ["налагаться"],
    "накласть": ["наложить", "дать прикурить", "навалять", "надавать"],
    "накласться": ["сложиться", "уложиться"],
    "наклацав": ["наклацавши"],
    "наклацавши": ["наклацав"],
    "наклевав": ["наклевавши"],
    "наклевавши": ["наклевав"],
    "наклеветав": ["наклеветавши"],
    "наклеветавши": ["наклеветав"],
    "наклеив": ["наклеивши"],
    "наклеивав": ["наклеивавши"],
    "наклеивавши": ["наклеивав"],
    "наклеивать": ["приклеивать", "налеплять"],
    "наклеивши": ["наклеив"],
    "наклеить": ["приклеить", "налепить"],
    "наклейка": ["наклеивание", "стикер"],
    "наклепав": ["наклепавши"],
    "наклепавши": ["наклепав"],
    "накликав": ["накликавши"],
    "накликавши": ["накликав"],
    "накликать": ["напророчить", "накаркать"],
    "накликивав": ["накликивавши"],
    "накликивавши": ["накликивав"],
    "наклоненье": ["наклонение"],
    "наклонив": ["наклонивши"],
    "наклонивши": ["наклонив"],
    "наклонить": ["накренить", "нагнуть", "склонить"],
    "наклониться": ["согнуться", "накрениться"],
    "наклонность": ["влечение", "склонность", "расположение", "предрасположение", "предрасположенность", "привычка", "наклонённость", "наклон", "склон", "спуск", "уклон"],
    "наклонный": ["склонный"],
    "наклоняв": ["наклонявши"],
    "наклонявши": ["наклоняв"],
    "наклонясь": ["наклонившись"],
    "наклонять": ["нагибать", "накренять", "склонять"],
    "наклоняться": ["сгибаться", "крениться", "накреняться"],
    "наклонённость": ["склонённость"],
    "наклюкаться": ["надраться"],
    "наклюнув": ["наклюнувши"],
    "наклюнувши": ["наклюнув"],
    "наклянчив": ["наклянчивши"],
    "наклянчивши": ["наклянчив"],
    "накляузничав": ["накляузничавши"],
    "накляузничавши": ["накляузничав"],
    "наклёвывав": ["наклёвывавши"],
    "наклёвывавши": ["наклёвывав"],
    "наклёпывав": ["наклёпывавши"],
    "наклёпывавши": ["наклёпывав"],
    "наковав": ["наковавши"],
    "наковавши": ["наковав"],
    "наковывав": ["наковывавши"],
    "наковывавши": ["наковывав"],
    "наковыривав": ["наковыривавши"],
    "наковыривавши": ["наковыривав"],
    "наковыряв": ["наковырявши"],
    "наковырявши": ["наковыряв"],
    "накоксовав": ["накоксовавши"],
    "накоксовавши": ["накоксовав"],
    "наколачивав": ["наколачивавши"],
    "наколачивавши": ["наколачивав"],
    "наколбасив": ["наколбасивши"],
    "наколбасивши": ["наколбасив"],
    "наколдовав": ["наколдовавши"],
    "наколдовавши": ["наколдовав"],
    "наколдовывав": ["наколдовывавши"],
    "наколдовывавши": ["наколдовывав"],
    "наколесить": ["наездить"],
    "наколка": ["накалывание", "татуировка", "татушка"],
    "наколобродив": ["наколобродивши"],
    "наколобродивши": ["наколобродив"],
    "наколов": ["наколовши"],
    "наколовши": ["наколов"],
    "наколотив": ["наколотивши"],
    "наколотивши": ["наколотив"],
    "наколошматив": ["наколошмативши"],
    "наколошмативши": ["наколошматив"],
    "наколошмачивав": ["наколошмачивавши"],
    "наколошмачивавши": ["наколошмачивав"],
    "наколупав": ["наколупавши"],
    "наколупавши": ["наколупав"],
    "наколупывав": ["наколупывавши"],
    "наколупывавши": ["наколупывав"],
    "накомандовав": ["накомандовавши"],
    "накомандовавши": ["накомандовав"],
    "накомарник": ["москитная сетка", "комарник"],
    "накомкав": ["накомкавши"],
    "накомкавши": ["накомкав"],
    "наконец": ["в конце концов", "в конечном итоге", "если уж на то пошло", "в заключение"],
    "наконец-то": ["наконец"],
    "наконфисковав": ["наконфисковавши"],
    "наконфисковавши": ["наконфисковав"],
    "накопав": ["накопавши"],
    "накопавши": ["накопав"],
    "накопанный": ["нарытый"],
    "накопать": ["выкопать", "нарыть"],
    "накопив": ["накопивши"],
    "накопивши": ["накопив"],
    "накопировав": ["накопировавши"],
    "накопировавши": ["накопировав"],
    "накопировать": ["скопировать"],
    "накопить": ["скопить", "аккумулировать", "приобрести", "нарастить", "набрать"],
    "накопление": ["накапливание", "аккумуляция", "собирание", "сбережения", "запасы"],
    "накопленье": ["накопление"],
    "накопляв": ["накоплявши"],
    "накоплявши": ["накопляв"],
    "накоплять": ["накапливать", "копить"],
    "накоптив": ["накоптивши"],
    "накоптивши": ["накоптив"],
    "накопытив": ["накопытивши"],
    "накопытивши": ["накопытив"],
    "накормив": ["накормивши"],
    "накормивши": ["накормив"],
    "накормити": ["нагодувати"],
    "накоротке": ["близко", "недалеко", "вблизи", "недолго", "на короткой ноге"],
    "накорчевав": ["накорчевавши"],
    "накорчевавши": ["накорчевав"],
    "накорчёвывав": ["накорчёвывавши"],
    "накорчёвывавши": ["накорчёвывав"],
    "накорябав": ["накорябавши"],
    "накорябавши": ["накорябав"],
    "накорябать": ["накарябать", "накалякать", "нацарапать"],
    "накос": ["укос"],
    "накосив": ["накосивши"],
    "накосивши": ["накосив"],
    "накостыляв": ["накостылявши"],
    "накостылявши": ["накостыляв"],
    "накостылять": ["навалять", "надавать", "избить", "побить", "поколотить"],
    "накось": ["косо", "вкось", "наискось", "наискосок"],
    "накосячив": ["накосячивши"],
    "накосячивав": ["накосячивавши"],
    "накосячивавши": ["накосячивав"],
    "накосячивши": ["накосячив"],
    "накосячить": ["напортачить", "напортить"],
    "накрадывав": ["накрадывавши"],
    "накрадывавши": ["накрадывав"],
    "накрадываться": ["подкрадываться"],
    "накраивав": ["накраивавши"],
    "накраивавши": ["накраивав"],
    "накрап": ["крапина"],
    "накрапав": ["накрапавши"],
    "накрапавши": ["накрапав"],
    "накрапать": ["накапать", "набрызгать"],
    "накрапливав": ["накрапливавши"],
    "накрапливавши": ["накрапливав"],
    "накрапывав": ["накрапывавши"],
    "накрапывавши": ["накрапывав"],
    "накрапывать": ["моросить"],
    "накрасив": ["накрасивши"],
    "накрасивши": ["накрасив"],
    "накрахмалив": ["накрахмаливши"],
    "накрахмаливав": ["накрахмаливавши"],
    "накрахмаливавши": ["накрахмаливав"],
    "накрахмаливши": ["накрахмалив"],
    "накрашивав": ["накрашивавши"],
    "накрашивавши": ["накрашивав"],
    "накренив": ["накренивши"],
    "накренивав": ["накренивавши"],
    "накренивавши": ["накренивав"],
    "накренивать": ["накренять", "кренить"],
    "накренивши": ["накренив"],
    "накренивший": ["наклонивший"],
    "накренить": ["наклонить", "нагнуть", "перекосить"],
    "накрениться": ["наклониться", "покоситься", "валиться набок"],
    "накреняв": ["накренявши"],
    "накренявши": ["накреняв"],
    "накренять": ["накренивать", "кренить"],
    "накреняться": ["накрениваться", "наклоняться", "крениться"],
    "накрест": ["крестообразно", "крестом", "крест-накрест"],
    "накрикивав": ["накрикивавши"],
    "накрикивавши": ["накрикивав"],
    "накричав": ["накричавши"],
    "накричавши": ["накричав"],
    "накричать": ["наорать"],
    "накроив": ["накроивши"],
    "накроивши": ["накроив"],
    "накромсав": ["накромсавши"],
    "накромсавши": ["накромсав"],
    "накропав": ["накропавши"],
    "накропавши": ["накропав"],
    "накрошив": ["накрошивши"],
    "накрошивши": ["накрошив"],
    "накрутив": ["накрутивши"],
    "накрутивши": ["накрутив"],
    "накрутить хвост": ["выругать", "отругать", "разбранить"],
    "накрутка": ["накручивание", "намотка", "обман", "жульничество"],
    "накручивав": ["накручивавши"],
    "накручивавши": ["накручивав"],
    "накрыв": ["накрывши"],
    "накрывав": ["накрывавши"],
    "накрывавши": ["накрывав"],
    "накрывать": ["покрывать"],
    "накрывочный": ["отделочный"],
    "накрывши": ["накрыв"],
    "накрыть поляну": ["проставиться"],
    "накрыться медным тазом": ["накрыться", "пропасть", "накрыться пиздой"],
    "накрыться тазом": ["накрыться медным тазом", "накрыться тазиком", "накрыться медным тазиком"],
    "наксада": ["наксатф", "шини", "наксада шини", "куштаф"],
    "наксерив": ["наксеривши"],
    "наксеривши": ["наксерив"],
    "наксерить": ["наксерокопировать", "нафотокопировать", "наканонить"],
    "наксерокопировав": ["наксерокопировавши"],
    "наксерокопировавши": ["наксерокопировав"],
    "наксерокопировать": ["нафотокопировать", "наксерить", "наканонить"],
    "накудесив": ["накудесивши"],
    "накудесивши": ["накудесив"],
    "накуковав": ["накуковавши"],
    "накуковавши": ["накуковав"],
    "накуковать": ["прокуковать", "напророчить"],
    "накуликаться": ["наклюкаться", "нахлюздаться", "нажраться", "надраться"],
    "накулинарив": ["накулинаривши"],
    "накулинаривши": ["накулинарив"],
    "накумекав": ["накумекавши"],
    "накумекавши": ["накумекав"],
    "накупав": ["накупавши"],
    "накупавши": ["накупав"],
    "накупив": ["накупивши"],
    "накупивши": ["накупив"],
    "накупить": ["закупить"],
    "накурив": ["накуривши"],
    "накуривав": ["накуривавши"],
    "накуривавши": ["накуривав"],
    "накуривши": ["накурив"],
    "накурить": ["надымить"],
    "накуриться": ["пыхнуть", "дунуть"],
    "накуролесив": ["накуролесивши"],
    "накуролесивши": ["накуролесив"],
    "накусав": ["накусавши"],
    "накусавши": ["накусав"],
    "накусывав": ["накусывавши"],
    "накусывавши": ["накусывав"],
    "накутав": ["накутавши"],
    "накутавши": ["накутав"],
    "накутив": ["накутивши"],
    "накутивши": ["накутив"],
    "накутывав": ["накутывавши"],
    "накутывавши": ["накутывав"],
    "накушав": ["накушавши"],
    "накушавши": ["накушав"],
    "накушкав": ["накушкавши"],
    "накушкавши": ["накушкав"],
    "накушкать": ["укутать", "накутать"],
    "нал": ["наличные"],
    "налавливав": ["налавливавши"],
    "налавливавши": ["налавливав"],
    "налагав": ["налагавши"],
    "налагавши": ["налагав"],
    "налагать": ["накладывать", "возлагать"],
    "наладив": ["наладивши"],
    "наладивши": ["наладив"],
    "наладить": ["настроить", "устроить", "организовать"],
    "наладка": ["настройка", "налаживание", "отладка", "починка", "регулировка"],
    "наладонник": ["плашка"],
    "налаженность": ["устроенность", "порядок", "система", "ритмичность", "организованность"],
    "налаженный": ["настроенный", "организованный"],
    "налаживав": ["налаживавши"],
    "налаживавши": ["налаживав"],
    "налаживать": ["регулировать", "организовывать", "устраивать"],
    "налазив": ["налазивши"],
    "налазивши": ["налазив"],
    "налакировав": ["налакировавши"],
    "налакировавши": ["налакировав"],
    "налакировывав": ["налакировывавши"],
    "налакировывавши": ["налакировывав"],
    "налакомиться": ["наесться"],
    "наламывав": ["наламывавши"],
    "наламывавши": ["наламывав"],
    "налаяв": ["налаявши"],
    "налаявши": ["налаяв"],
    "налгав": ["налгавши"],
    "налгавши": ["налгав"],
    "налгать": ["обмануть", "наврать", "наклеветать"],
    "налгаться": ["навраться", "набрехаться"],
    "налегав": ["налегавши"],
    "налегавши": ["налегав"],
    "налегке": ["порожняком"],
    "налегнув": ["налегнувши"],
    "налегнувши": ["налегнув"],
    "належав": ["належавши"],
    "належавши": ["належав"],
    "налезав": ["налезавши"],
    "налезавши": ["налезав"],
    "налепив": ["налепивши"],
    "налепивши": ["налепив"],
    "налепливав": ["налепливавши"],
    "налепливавши": ["налепливав"],
    "налепливать": ["налеплять"],
    "налепляв": ["налеплявши"],
    "налеплявши": ["налепляв"],
    "налетав": ["налетавши"],
    "налетавши": ["налетав"],
    "налетев": ["налетевши"],
    "налетевши": ["налетев"],
    "налететь": ["подлететь", "наскочить", "натолкнуться"],
    "наливав": ["наливавши"],
    "наливавши": ["наливав"],
    "наливайка": ["рюмочная", "забегаловка", "рыгаловка", "кабак", "стекляшка"],
    "наливаться": ["назревать"],
    "наливной": ["созревший", "спелый"],
    "наливши": ["налив"],
    "нализав": ["нализавши"],
    "нализавши": ["нализав"],
    "нализывав": ["нализывавши"],
    "нализывавши": ["нализывав"],
    "налик": ["наличные"],
    "налим": ["обыкновенный налим"],
    "налимец": ["налимчик"],
    "налимониться": ["нализаться"],
    "налиневав": ["налиневавши"],
    "налиневавши": ["налиневав"],
    "налиновав": ["налиновавши"],
    "налиновавши": ["налиновав"],
    "налиновывав": ["налиновывавши"],
    "налиновывавши": ["налиновывав"],
    "налипав": ["налипавши"],
    "налипавши": ["налипав"],
    "налипая": ["прилипая"],
    "налипнув": ["налипнувши"],
    "налипнувши": ["налипнув"],
    "налитографировав": ["налитографировавши"],
    "налитографировавши": ["налитографировав"],
    "налиток": ["свинчатка"],
    "налить": ["разлить", "залить"],
    "налицо": ["имеющийся", "доступный"],
    "наличествовав": ["наличествовавши"],
    "наличествовавши": ["наличествовав"],
    "наличествовать": ["иметься"],
    "наличие": ["присутствие", "существование"],
    "наличка": ["наличность", "наличные", "нал"],
    "наличник": ["клипеус"],
    "наличные": ["наличность", "нал"],
    "наличье": ["наличие"],
    "наловив": ["наловивши"],
    "наловивши": ["наловив"],
    "наловчив": ["наловчивши"],
    "наловчивши": ["наловчив"],
    "наловчиться": ["напрактиковаться", "насобачиться"],
    "налог": ["дань", "оброк", "повинность", "пошлина", "тягота", "мыто", "мыт", "контрибуция"],
    "налог на добавленную стоимость": ["ндс"],
    "налог на розовое": ["розовый налог"],
    "налоговая": ["налоговая инспекция"],
    "налогообложение": ["система налогообложения"],
    "наложение": ["накладывание"],
    "наложив": ["наложивши"],
    "наложивши": ["наложив"],
    "наложить": ["накласть"],
    "наложить на себя руки": ["покончить с собой", "свести счёты с жизнью"],
    "налой": ["аналой"],
    "наломав": ["наломавши"],
    "наломавши": ["наломав"],
    "наломать дров": ["наворотить дел", "заварить кашу"],
    "наломив": ["наломивши"],
    "наломивши": ["наломив"],
    "налощив": ["налощивши"],
    "налощивши": ["налощив"],
    "налудив": ["налудивши"],
    "налудивши": ["налудив"],
    "налудничавост": ["лудост", "ненормалност"],
    "налузгав": ["налузгавши"],
    "налузгавши": ["налузгав"],
    "налупив": ["налупивши"],
    "налупивши": ["налупив"],
    "налупить": ["отлупить", "отлупцевать", "вздуть", "накостылять", "навалять", "надавать"],
    "налущив": ["налущивши"],
    "налущивав": ["налущивавши"],
    "налущивавши": ["налущивав"],
    "налущивши": ["налущив"],
    "налысо": ["наголо"],
    "нальнув": ["нальнувши"],
    "нальнувши": ["нальнув"],
    "налягане": ["натиск", "напор", "напрежение"],
    "наляпав": ["наляпавши"],
    "наляпавши": ["наляпав"],
    "наляпывав": ["наляпывавши"],
    "наляпывавши": ["наляпывав"],
    "наляпывать": ["пачкать", "мазать"],
    "налёживав": ["налёживавши"],
    "налёживавши": ["налёживав"],
    "налёживаться": ["вылёживаться"],
    "налёт": ["нападение", "атака", "набег"],
    "налётывав": ["налётывавши"],
    "налётывавши": ["налётывав"],
    "намагнетизировав": ["намагнетизировавши"],
    "намагнетизировавши": ["намагнетизировав"],
    "намагнитив": ["намагнитивши"],
    "намагнитивши": ["намагнитив"],
    "намагничивав": ["намагничивавши"],
    "намагничивавши": ["намагничивав"],
    "намагничивать": ["магнитить"],
    "намаз": ["салат", "салят"],
    "намазав": ["намазавши"],
    "намазавши": ["намазав"],
    "намазать": ["смазать", "намалевать"],
    "намазка": ["намазывание", "намазыванье"],
    "намазлык": ["саджжада"],
    "намазывав": ["намазывавши"],
    "намазывавши": ["намазывав"],
    "намазывать": ["мазать"],
    "намазюкав": ["намазюкавши"],
    "намазюкавши": ["намазюкав"],
    "намайнив": ["намайнивши"],
    "намайнивши": ["намайнив"],
    "намалевав": ["намалевавши"],
    "намалевавши": ["намалевав"],
    "намаливав": ["намаливавши"],
    "намаливавши": ["намаливав"],
    "намалывав": ["намалывавши"],
    "намалывавши": ["намалывав"],
    "намалёвывав": ["намалёвывавши"],
    "намалёвывавши": ["намалёвывав"],
    "наманив": ["наманивши"],
    "наманивав": ["наманивавши"],
    "наманивавши": ["наманивав"],
    "наманивши": ["наманив"],
    "наманикюрив": ["наманикюривши"],
    "наманикюривши": ["наманикюрив"],
    "намарав": ["намаравши"],
    "намаравши": ["намарав"],
    "намариновав": ["намариновавши"],
    "намариновавши": ["намариновав"],
    "намариновывав": ["намариновывавши"],
    "намариновывавши": ["намариновывав"],
    "намарывав": ["намарывавши"],
    "намарывавши": ["намарывав"],
    "намарывать": ["марать", "грязнить", "пачкать"],
    "намаслив": ["намасливши"],
    "намасливав": ["намасливавши"],
    "намасливавши": ["намасливав"],
    "намасливши": ["намаслив"],
    "намастив": ["намастивши"],
    "намастивши": ["намастив"],
    "наматывав": ["наматывавши"],
    "наматывавши": ["наматывав"],
    "намахав": ["намахавши"],
    "намахавши": ["намахав"],
    "намахивав": ["намахивавши"],
    "намахивавши": ["намахивав"],
    "намахнув": ["намахнувши"],
    "намахнувши": ["намахнув"],
    "намахнуться": ["замахнуться"],
    "намачивав": ["намачивавши"],
    "намачивавши": ["намачивав"],
    "намащивав": ["намащивавши"],
    "намащивавши": ["намащивав"],
    "намаяв": ["намаявши"],
    "намаявши": ["намаяв"],
    "намаять": ["умаять"],
    "намедни": ["недавно", "на днях", "давеча", "надысь", "онамедни"],
    "намеднись": ["намедни"],
    "намежевав": ["намежевавши"],
    "намежевавши": ["намежевав"],
    "намежёвывав": ["намежёвывавши"],
    "намежёвывавши": ["намежёвывав"],
    "намекав": ["намекавши"],
    "намекавши": ["намекав"],
    "намекнув": ["намекнувши"],
    "намекнувши": ["намекнув"],
    "намелив": ["намеливши"],
    "намеливав": ["намеливавши"],
    "намеливавши": ["намеливав"],
    "намеливши": ["намелив"],
    "намельчив": ["намельчивши"],
    "намельчивши": ["намельчив"],
    "наменивав": ["наменивавши"],
    "наменивавши": ["наменивав"],
    "наменяв": ["наменявши"],
    "наменявши": ["наменяв"],
    "намереваться": ["собираться", "думать"],
    "намерен": ["готовый", "намереваться", "собираться", "думать", "вознамериться", "запланировать"],
    "намерение": ["замысел", "интенция", "умысел", "задумка", "план", "проект", "прожект", "намеренье"],
    "намеренно": ["умышленно", "преднамеренно", "нарочно", "сознательно"],
    "намеренный": ["преднамеренный", "предумышленный"],
    "намеренье": ["намерение", "замысел", "интенция", "умысел", "задумка", "план", "проект", "прожект"],
    "намерзав": ["намерзавши"],
    "намерзавши": ["намерзав"],
    "намерив": ["намеривши"],
    "намеривав": ["намеривавши"],
    "намеривавши": ["намеривав"],
    "намериваемый": ["предполагаемый"],
    "намеривать": ["намерять"],
    "намеривши": ["намерив"],
    "намерить": ["отмерить", "померить", "измерить", "вознамериться", "намериться", "задумать"],
    "намеряв": ["намерявши"],
    "намерявши": ["намеряв"],
    "намеряться": ["намериваться"],
    "намеса": ["вмешателство", "интервенция"],
    "намесив": ["намесивши"],
    "намесивши": ["намесив"],
    "наместничав": ["наместничавши"],
    "наместничавши": ["наместничав"],
    "наместничий": ["наместнический"],
    "наметав": ["наметавши"],
    "наметавши": ["наметав"],
    "наметаться": ["наловчиться", "навыкнуть", "наостриться"],
    "наметив": ["наметивши"],
    "наметивши": ["наметив"],
    "наметить": ["нацелить"],
    "наметка": ["метка"],
    "намечав": ["намечавши"],
    "намечавши": ["намечав"],
    "намешав": ["намешавши"],
    "намешавши": ["намешав"],
    "намешивав": ["намешивавши"],
    "намешивавши": ["намешивав"],
    "намибия": ["республика намибия", "юго-западная африка", "юза"],
    "намик": ["зеравшан"],
    "наминав": ["наминавши"],
    "наминавши": ["наминав"],
    "намирам": ["откривам", "намирам се", "съм"],
    "намного": ["значительно", "существенно"],
    "намоз": ["тоат", "ибодат"],
    "намозолив": ["намозоливши"],
    "намозоливав": ["намозоливавши"],
    "намозоливавши": ["намозоливав"],
    "намозоливши": ["намозолив"],
    "намокав": ["намокавши"],
    "намокавши": ["намокав"],
    "намокать": ["мокнуть", "промокать", "увлажняться"],
    "намокнув": ["намокнувши"],
    "намокнувши": ["намокнув"],
    "намокнуть": ["замокнуть"],
    "намол": ["намолот", "помол"],
    "намолачивав": ["намолачивавши"],
    "намолачивавши": ["намолачивав"],
    "намолвив": ["намолвивши"],
    "намолвивши": ["намолвив"],
    "намолвка": ["молва"],
    "намолвливав": ["намолвливавши"],
    "намолвливавши": ["намолвливав"],
    "намолвляв": ["намолвлявши"],
    "намолвлявши": ["намолвляв"],
    "намолив": ["намоливши"],
    "намоливши": ["намолив"],
    "намолов": ["намоловши"],
    "намоловши": ["намолов"],
    "намолотив": ["намолотивши"],
    "намолотивши": ["намолотив"],
    "намораживав": ["намораживавши"],
    "намораживавши": ["намораживав"],
    "наморив": ["наморивши"],
    "наморивши": ["наморив"],
    "наморозив": ["наморозивши"],
    "наморозивши": ["наморозив"],
    "наморозиться": ["настудиться"],
    "наморосив": ["наморосивши"],
    "наморосивши": ["наморосив"],
    "наморочив": ["наморочивши"],
    "наморочивши": ["наморочив"],
    "наморщив": ["наморщивши"],
    "наморщивав": ["наморщивавши"],
    "наморщивавши": ["наморщивав"],
    "наморщивши": ["наморщив"],
    "намостив": ["намостивши"],
    "намостивши": ["намостив"],
    "намотав": ["намотавши"],
    "намотавши": ["намотав"],
    "намотка": ["накрутка", "наматывание", "обмотка", "моток"],
    "намотчик": ["намоточник"],
    "намочив": ["намочивши"],
    "намочивши": ["намочив"],
    "намошенничав": ["намошенничавши"],
    "намошенничавши": ["намошенничав"],
    "намудрив": ["намудривши"],
    "намудривши": ["намудрив"],
    "намудрствовав": ["намудрствовавши"],
    "намудрствовавши": ["намудрствовав"],
    "намудрствовать": ["намудрить"],
    "намурлыкав": ["намурлыкавши"],
    "намурлыкавши": ["намурлыкав"],
    "намурлыкивав": ["намурлыкивавши"],
    "намурлыкивавши": ["намурлыкивав"],
    "намуслив": ["намусливши"],
    "намусливав": ["намусливавши"],
    "намусливавши": ["намусливав"],
    "намусливши": ["намуслив"],
    "намуслить": ["намусолить"],
    "намусолив": ["намусоливши"],
    "намусоливав": ["намусоливавши"],
    "намусоливавши": ["намусоливав"],
    "намусоливши": ["намусолив"],
    "намусолить": ["намуслить"],
    "намусорив": ["намусоривши"],
    "намусоривши": ["намусорив"],
    "намусорить": ["насорить"],
    "намутив": ["намутивши"],
    "намутивши": ["намутив"],
    "намучав": ["намучавши"],
    "намучавши": ["намучав"],
    "намучив": ["намучивши"],
    "намучивши": ["намучив"],
    "намучиться": ["намучаться"],
    "намуштровав": ["намуштровавши"],
    "намуштровавши": ["намуштровав"],
    "намцо": ["нам-цо", "тэнгри-нур"],
    "намывав": ["намывавши"],
    "намывавши": ["намывав"],
    "намывши": ["намыв"],
    "намылив": ["намыливши"],
    "намыливав": ["намыливавши"],
    "намыливавши": ["намыливав"],
    "намыливши": ["намылив"],
    "намытарив": ["намытаривши"],
    "намытаривши": ["намытарив"],
    "намытариться": ["намытарствоваться"],
    "намытарствовав": ["намытарствовавши"],
    "намытарствовавши": ["намытарствовав"],
    "намытарствовать": ["измордовать", "измучить"],
    "намытарствоваться": ["намытариться"],
    "намыть": ["настирать", "нанести"],
    "намяв": ["намявши"],
    "намявши": ["намяв"],
    "намякав": ["намякавши"],
    "намякавши": ["намякав"],
    "намякнув": ["намякнувши"],
    "намякнувши": ["намякнув"],
    "намёк": ["аллюзия", "обиняк", "экивок", "признак"],
    "намёрзнув": ["намёрзнувши"],
    "намёрзнувши": ["намёрзнув"],
    "намёт": ["намётка"],
    "намётывав": ["намётывавши"],
    "намётывавши": ["намётывав"],
    "нанаец": ["гольд", "хэчжэ"],
    "нанашивав": ["нанашивавши"],
    "нанашивавши": ["нанашивав"],
    "нанга": ["бундзинга"],
    "нанесенье": ["нанесение"],
    "нанести": ["принести"],
    "нанизав": ["нанизавши"],
    "нанизавши": ["нанизав"],
    "нанизм": ["карликовость", "дварфизм"],
    "нанизывав": ["нанизывавши"],
    "нанизывавши": ["нанизывав"],
    "нанимав": ["нанимавши"],
    "нанимавши": ["нанимав"],
    "наниматель": ["арендатор", "съёмщик", "работодатель"],
    "наничка": ["изнанка"],
    "нанка": ["китайка"],
    "нанкин": ["наньцзин"],
    "наннандрий": ["мужчинка"],
    "нано-": ["миллимикро-"],
    "наноантитело": ["нанотело"],
    "наноаппарат": ["наномашина", "наномеханизм", "наноустройство"],
    "нанобактерия": ["ультрамикробактерия"],
    "нанобиология": ["бионанотехнология", "нанобиотехнология"],
    "нанобот": ["наноробот", "нанит"],
    "наново": ["заново", "вновь", "снова", "по-новому"],
    "нанограмм": ["миллимикрограмм"],
    "наножники": ["оковы для ног"],
    "наномасштаб": ["наноразмер"],
    "наномасштабный": ["наноразмерный"],
    "наномашина": ["наноаппарат", "наномеханизм", "наноустройство"],
    "нанометр": ["миллимикрон", "нм"],
    "наномеханизм": ["наноаппарат", "наномашина", "наноустройство"],
    "наномиг": ["наномгновение", "наносекунда"],
    "наноразмер": ["наномасштаб"],
    "наноразмерный": ["наномасштабный"],
    "наноробот": ["нанобот", "нанит"],
    "наносекунда": ["миллимикросекунда"],
    "наносить вред": ["причинять вред", "вредить"],
    "наносной": ["аллювиальный", "наносный"],
    "наносный": ["нанесённый", "намытый", "намывной", "наплывной", "наносной", "фальшивый", "клеветнический", "лживый"],
    "нанотело": ["наноантитело"],
    "наноустройство": ["наноаппарат", "наномашина", "наномеханизм"],
    "нанюхав": ["нанюхавши"],
    "нанюхавши": ["нанюхав"],
    "нанюхивав": ["нанюхивавши"],
    "нанюхивавши": ["нанюхивав"],
    "наняв": ["нанявши"],
    "нанявши": ["наняв"],
    "нанять": ["подрядить"],
    "наобещав": ["наобещавши"],
    "наобещавши": ["наобещав"],
    "наоборот": ["задом наперёд", "наизнанку", "изнанкою вверх", "навыворот", "шиворот-навыворот", "наизворот", "наопако", "напротив", "вовсе нет", "отнюдь"],
    "наобум": ["наугад", "наудачу"],
    "наодалживав": ["наодалживавши"],
    "наодалживавши": ["наодалживав"],
    "наодеколонив": ["наодеколонивши"],
    "наодеколонивши": ["наодеколонив"],
    "наозорничав": ["наозорничавши"],
    "наозорничавши": ["наозорничав"],
    "наозоровав": ["наозоровавши"],
    "наозоровавши": ["наозоровав"],
    "наопашь": ["внакидку", "внаброску"],
    "наорав": ["наоравши"],
    "наоравши": ["наорав"],
    "наособицу": ["особняком", "врозь", "особенно", "по себе", "особицей"],
    "наоставляв": ["наоставлявши"],
    "наоставлявши": ["наоставляв"],
    "наострив": ["наостривши"],
    "наостривши": ["наострив"],
    "наоткрывав": ["наоткрывавши"],
    "наоткрывавши": ["наоткрывав"],
    "наотмашь": ["беспощадно", "наотлёт", "размахнувшись", "резко", "с маху", "с плеча", "с размаху", "со всего плеча", "со всего размаха", "сплеча"],
    "наотрез": ["безапелляционно", "безоговорочно", "как отрезал", "решительно"],
    "наохачивав": ["наохачивавши"],
    "наохачивавши": ["наохачивав"],
    "наохотив": ["наохотивши"],
    "наохотивши": ["наохотив"],
    "наохрив": ["наохривши"],
    "наохривав": ["наохривавши"],
    "наохривавши": ["наохривав"],
    "наохривать": ["охрить"],
    "наохривши": ["наохрив"],
    "напав": ["напавши"],
    "напавши": ["напав"],
    "нападав": ["нападавши"],
    "нападавши": ["нападав"],
    "нападателност": ["агресивност", "враждебност", "бойкост", "войнственост"],
    "нападатель": ["нападчик"],
    "нападающий": ["атакующий", "агрессивный", "форвард"],
    "нападение": ["атака", "агрессия"],
    "нападенье": ["нападение"],
    "нападки": ["наезд"],
    "нападчик": ["нападатель"],
    "напаивав": ["напаивавши"],
    "напаивавши": ["напаивав"],
    "напайка": ["припайка"],
    "напакостив": ["напакостивши"],
    "напакостивши": ["напакостив"],
    "напакостить": ["напачкать", "нагрязнить", "нагадить", "навредить", "подложить свинью"],
    "напакостничав": ["напакостничавши"],
    "напакостничавши": ["напакостничав"],
    "напалзывав": ["напалзывавши"],
    "напалзывавши": ["напалзывав"],
    "напалив": ["напаливши"],
    "напаливав": ["напаливавши"],
    "напаливавши": ["напаливав"],
    "напаливши": ["напалив"],
    "напалм": ["страсть", "огонь", "эмоциональность", "страстность", "неистовство", "исступление", "буйство", "сумасшествие", "помешательство"],
    "напалывав": ["напалывавши"],
    "напалывавши": ["напалывав"],
    "напарив": ["напаривши"],
    "напаривав": ["напаривавши"],
    "напаривавши": ["напаривав"],
    "напаривши": ["напарив"],
    "напарник": ["партнёр"],
    "напартизанив": ["напартизанивши"],
    "напартизанивши": ["напартизанив"],
    "напарывав": ["напарывавши"],
    "напарывавши": ["напарывав"],
    "напас": ["хапка", "хапок", "напасик"],
    "напасав": ["напасавши"],
    "напасавши": ["напасав"],
    "напаскудив": ["напаскудивши"],
    "напаскудивши": ["напаскудив"],
    "напаскудить": ["нагадить"],
    "напаснуться": ["дунуть", "пыхнуть"],
    "напастись": ["наготовиться", "припастись", "набраться", "запастись"],
    "напасть": ["беда", "несчастье"],
    "напахав": ["напахавши"],
    "напахавши": ["напахав"],
    "напахивав": ["напахивавши"],
    "напахивавши": ["напахивав"],
    "напахтав": ["напахтавши"],
    "напахтавши": ["напахтав"],
    "напачкав": ["напачкавши"],
    "напачкавши": ["напачкав"],
    "напачкать": ["нагрязнить"],
    "напаяв": ["напаявши"],
    "напаявши": ["напаяв"],
    "напаять": ["надпаять"],
    "напев": ["мелодия", "мотив"],
    "напевав": ["напевавши"],
    "напевавши": ["напевав"],
    "напеванье": ["напевание"],
    "напевать": ["мурлыкать", "наговаривать", "ябедничать", "наущать"],
    "напевность": ["мелодичность"],
    "напевши": ["напев"],
    "напекав": ["напекавши"],
    "напекавши": ["напекав"],
    "напенив": ["напенивши"],
    "напенивав": ["напенивавши"],
    "напенивавши": ["напенивав"],
    "напенивши": ["напенив"],
    "наперебой": ["вперебой"],
    "наперев": ["напёрши"],
    "напереводив": ["напереводивши"],
    "напереводивши": ["напереводив"],
    "наперекор": ["вопреки"],
    "наперекос": ["косо", "наперекосяк"],
    "наперекосяк": ["наперекос"],
    "наперерез": ["наперехват"],
    "наперерыв": ["напрерыв", "наперебой"],
    "наперсница": ["любовница", "наложница"],
    "наперчив": ["наперчивши"],
    "наперчивав": ["наперчивавши"],
    "наперчивавши": ["наперчивав"],
    "наперчивши": ["наперчив"],
    "наперёд": ["вперёд", "кпереди"],
    "напестрив": ["напестривши"],
    "напестривши": ["напестрив"],
    "напетляв": ["напетлявши"],
    "напетлявши": ["напетляв"],
    "напеть": ["пропеть", "намурлыкать", "записать", "наисполнять", "спеть", "наплести"],
    "напечатав": ["напечатавши"],
    "напечатавши": ["напечатав"],
    "напечатанный": ["оттиснутый", "отпечатанный", "изданный", "опубликованный"],
    "напечатанье": ["напечатание"],
    "напечатать": ["отпечатать", "издать", "опубликовать"],
    "напечататься": ["опубликоваться", "издаться"],
    "напечатлев": ["напечатлевши"],
    "напечатлевав": ["напечатлевавши"],
    "напечатлевавши": ["напечатлевав"],
    "напечатлевши": ["напечатлев"],
    "напиарив": ["напиаривши"],
    "напиаривши": ["напиарив"],
    "напив": ["напивши"],
    "напивав": ["напивавши"],
    "напивавши": ["напивав"],
    "напиваться": ["надуваться", "налакаться", "натянуться"],
    "напивши": ["напив"],
    "напиздев": ["напиздевши"],
    "напиздевши": ["напиздев"],
    "напиздеть": ["обмануть", "солгать", "наврать"],
    "напиздив": ["напиздивши"],
    "напиздивши": ["напиздив"],
    "напилив": ["напиливши"],
    "напиливав": ["напиливавши"],
    "напиливавши": ["напиливав"],
    "напиливши": ["напилив"],
    "напилок": ["напильник"],
    "напильник": ["подпилок"],
    "напинав": ["напинавши"],
    "напинавши": ["напинав"],
    "напирав": ["напиравши"],
    "напиравши": ["напирав"],
    "написав": ["написавши"],
    "написавши": ["написав"],
    "написанный": ["начертанный", "сочинённый"],
    "написанье": ["написание"],
    "написать": ["начертать", "записать"],
    "написывав": ["написывавши"],
    "написывавши": ["написывав"],
    "написяв": ["написявши"],
    "написявши": ["написяв"],
    "написять": ["написать"],
    "напитав": ["напитавши"],
    "напитавши": ["напитав"],
    "напитать": ["пропитать"],
    "напиток": ["питьё", "пойло"],
    "напитывав": ["напитывавши"],
    "напитывавши": ["напитывав"],
    "напитывать": ["пропитывать"],
    "напиться": ["утолить жажду", "надуться", "надудониться", "опьянеть", "перепить", "упиться", "набраться", "нагрузиться", "хватить через край", "хлебнуть через край", "хватить лишнее", "хватить лишку", "хлебнуть лишнее", "хлебнуть лишку", "надраться"],
    "напихав": ["напихавши"],
    "напихавши": ["напихав"],
    "напиханный": ["напёханный"],
    "напихать": ["всунуть", "впихнуть"],
    "напихивав": ["напихивавши"],
    "напихивавши": ["напихивав"],
    "напичкав": ["напичкавши"],
    "напичкавши": ["напичкав"],
    "напичкивав": ["напичкивавши"],
    "напичкивавши": ["напичкивав"],
    "наплав": ["поплавок"],
    "наплавав": ["наплававши"],
    "наплававши": ["наплавав"],
    "наплавив": ["наплавивши"],
    "наплавивши": ["наплавив"],
    "наплавливав": ["наплавливавши"],
    "наплавливавши": ["наплавливав"],
    "наплавляв": ["наплавлявши"],
    "наплавлявши": ["наплавляв"],
    "наплакав": ["наплакавши"],
    "наплакавши": ["наплакав"],
    "напланировав": ["напланировавши"],
    "напланировавши": ["напланировав"],
    "напластав": ["напластавши"],
    "напластавши": ["напластав"],
    "напластовав": ["напластовавши"],
    "напластовавши": ["напластовав"],
    "напластование": ["наслоение"],
    "напластованье": ["напластование"],
    "напластовывав": ["напластовывавши"],
    "напластовывавши": ["напластовывав"],
    "наплевав": ["наплевавши"],
    "наплевавши": ["наплевав"],
    "наплевательски": ["безответственно", "недобросовестно", "пренебрежительно", "разгильдяйски", "безразлично", "безучастно", "небрежно", "невнимательно", "нерачительно", "прохладно", "равнодушно"],
    "наплевательский": ["пренебрежительный", "халатный", "недобросовестный"],
    "наплевизм": ["пофигизм"],
    "наплеск": ["наплёскивание", "накат"],
    "наплескав": ["наплескавши"],
    "наплескавши": ["наплескав"],
    "наплеснув": ["наплеснувши"],
    "наплеснувши": ["наплеснув"],
    "наплетав": ["наплетавши"],
    "наплетавши": ["наплетав"],
    "наплечник": ["наплешник"],
    "наплешник": ["наплечник", "ермолка", "тафья", "скуфейка", "тюбетейка"],
    "наплодив": ["наплодивши"],
    "наплодивши": ["наплодив"],
    "наплоив": ["наплоивши"],
    "наплоивши": ["наплоив"],
    "наплотив": ["наплотивши"],
    "наплотивши": ["наплотив"],
    "наплутав": ["наплутавши"],
    "наплутавши": ["наплутав"],
    "наплутовав": ["наплутовавши"],
    "наплутовавши": ["наплутовав"],
    "наплыв": ["градиент"],
    "наплывав": ["наплывавши"],
    "наплывавши": ["наплывав"],
    "наплывши": ["наплыв"],
    "наплюнув": ["наплюнувши"],
    "наплюнувши": ["наплюнув"],
    "наплюснув": ["наплюснувши"],
    "наплюснувши": ["наплюснув"],
    "наплюхав": ["наплюхавши"],
    "наплюхавши": ["наплюхав"],
    "наплюхивав": ["наплюхивавши"],
    "наплюхивавши": ["наплюхивав"],
    "наплющив": ["наплющивши"],
    "наплющивав": ["наплющивавши"],
    "наплющивавши": ["наплющивав"],
    "наплющивши": ["наплющив"],
    "наплясав": ["наплясавши"],
    "наплясавши": ["наплясав"],
    "наплясывав": ["наплясывавши"],
    "наплясывавши": ["наплясывав"],
    "наплёскивав": ["наплёскивавши"],
    "наплёскивавши": ["наплёскивав"],
    "наповал": ["насмерть", "сильно", "мощно"],
    "напоганив": ["напоганивши"],
    "напоганивши": ["напоганив"],
    "наподдав": ["наподдавши"],
    "наподдавав": ["наподдававши"],
    "наподдававши": ["наподдавав"],
    "наподдавши": ["наподдав"],
    "наподдать": ["поддать"],
    "наподличав": ["наподличавши"],
    "наподличавши": ["наподличав"],
    "наподобие": ["вроде", "в виде", "подобно", "сродни", "наподобье"],
    "напоив": ["напоивши"],
    "напоивши": ["напоив"],
    "напоказ": ["обозрение", "показушно"],
    "наполаскивав": ["наполаскивавши"],
    "наполаскивавши": ["наполаскивав"],
    "наполеон": ["наполеондор"],
    "наполеондор": ["наполеон"],
    "наползав": ["наползавши"],
    "наползавши": ["наползав"],
    "наполировав": ["наполировавши"],
    "наполировавши": ["наполировав"],
    "наполировывав": ["наполировывавши"],
    "наполировывавши": ["наполировывав"],
    "наполитань": ["политань"],
    "наполненье": ["наполнение"],
    "наполнив": ["наполнивши"],
    "наполнивши": ["наполнив"],
    "наполнить": ["заполнить", "распространить"],
    "наполняв": ["наполнявши"],
    "наполнявши": ["наполняв"],
    "наполнять": ["заполнять", "насыщать", "распространять"],
    "наполов": ["наполовши"],
    "наполовину": ["не до конца", "в некоторой степени", "до некоторой степени", "отчасти"],
    "наполовши": ["наполов"],
    "наполоскав": ["наполоскавши"],
    "наполоскавши": ["наполоскав"],
    "наполосовав": ["наполосовавши"],
    "наполосовавши": ["наполосовав"],
    "наполучав": ["наполучавши"],
    "наполучавши": ["наполучав"],
    "наполы": ["пополам", "напополам", "впополам", "надвое", "напол", "полма", "полмя"],
    "напомадив": ["напомадивши"],
    "напомадивши": ["напомадив"],
    "напомаживав": ["напомаживавши"],
    "напомаживавши": ["напомаживав"],
    "напомаживаться": ["помадиться"],
    "напоминав": ["напоминавши"],
    "напоминавши": ["напоминав"],
    "напоминанье": ["напоминание"],
    "напоминать": ["походить", "быть похожим"],
    "напомнив": ["напомнивши"],
    "напомнивши": ["напомнив"],
    "напомнить": ["навеять"],
    "напомянув": ["напомянувши"],
    "напомянувши": ["напомянув"],
    "напополам": ["пополам", "надвое", "пятьдесят на пятьдесят", "фифти-фифти", "половина на половину"],
    "напор": ["натиск", "лом", "давление", "нажим", "прессинг", "настойчивость"],
    "напористость": ["агрессивность"],
    "напористый": ["настырный", "нахрапистый"],
    "напорный": ["тяговый", "напористый"],
    "напоров": ["напоровши"],
    "напоровши": ["напоров"],
    "напороть": ["напороться"],
    "напороться": ["наткнуться", "натолкнуться"],
    "напорошив": ["напорошивши"],
    "напорошивши": ["напорошив"],
    "напортачив": ["напортачивши"],
    "напортачивши": ["напортачив"],
    "напортачить": ["накосячить"],
    "напортив": ["напортивши"],
    "напортивши": ["напортив"],
    "напоследок": ["в конце концов", "под конец", "в довершение"],
    "напоследях": ["напоследок"],
    "напотев": ["напотевши"],
    "напотевши": ["напотев"],
    "напотчевав": ["напотчевавши"],
    "напотчевавши": ["напотчевав"],
    "направив": ["направивши"],
    "направивши": ["направив"],
    "направительный": ["указательный", "ориентирующий", "аллативный"],
    "направительный падеж": ["латив"],
    "направить": ["наставить", "послать"],
    "направление": ["ориентация", "ориентирование", "устремление", "вектор", "течение", "предписание"],
    "направленье": ["направление"],
    "направляв": ["направлявши"],
    "направлявши": ["направляв"],
    "направлять": ["ориентировать", "нацеливать"],
    "направляющая": ["касательная"],
    "направо": ["вправо", "справа"],
    "напрактиковаться": ["наловчиться"],
    "напрасливость": ["назойливость"],
    "напрасливый": ["несправедливый", "назойливый"],
    "напраслина": ["клевета", "наговор", "понапраслина", "изнапраслина"],
    "напрасно": ["бесплодно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "зря", "зазря", "понапрасну", "попусту", "даром", "вотще", "тщетно", "втуне", "всуе"],
    "напрасность": ["тщетность", "безрезультатность", "бесполезность"],
    "напрасный": ["тщетный", "безрезультатный", "безуспешный", "бесплодный", "бесполезный"],
    "напрашивав": ["напрашивавши"],
    "напрашивавши": ["напрашивав"],
    "напрев": ["напревши"],
    "напревав": ["напревавши"],
    "напревавши": ["напревав"],
    "напревши": ["напрев"],
    "напредки": ["впредь", "в будущем", "в дальнейшем", "отныне", "вперёд", "в другой раз", "в следующий раз", "отселе", "отсель"],
    "напредничавост": ["прогресивност"],
    "напредък": ["ход", "вървеж", "успех", "прогрес", "цъфтеж"],
    "напрерыв": ["наперебой", "наперерыв"],
    "напрессовав": ["напрессовавши"],
    "напрессовавши": ["напрессовав"],
    "напрессовывав": ["напрессовывавши"],
    "напрессовывавши": ["напрессовывав"],
    "напреть": ["сопреть"],
    "напридумав": ["напридумавши"],
    "напридумавши": ["напридумав"],
    "напридумывав": ["напридумывавши"],
    "напридумывавши": ["напридумывав"],
    "наприклад": ["например"],
    "например": ["для примера", "к примеру", "в частности", "в числе прочего"],
    "напринимав": ["напринимавши"],
    "напринимавши": ["напринимав"],
    "наприняв": ["напринявши"],
    "напринявши": ["наприняв"],
    "напринять": ["напринимать"],
    "наприсылав": ["наприсылавши"],
    "наприсылавши": ["наприсылав"],
    "напроворив": ["напроворивши"],
    "напроворивши": ["напроворив"],
    "напроворить": ["напроказить"],
    "напроказив": ["напроказивши"],
    "напроказивши": ["напроказив"],
    "напроказить": ["напроворить"],
    "напроказничав": ["напроказничавши"],
    "напроказничавши": ["напроказничав"],
    "напрокат": ["на подержание", "внаймы", "внаём", "заимообразно"],
    "напрокудив": ["напрокудивши"],
    "напрокудивши": ["напрокудив"],
    "напрокудить": ["напроказничать", "набедокурить"],
    "напролёт": ["непрерывно", "подряд"],
    "напромышляв": ["напромышлявши"],
    "напромышлявши": ["напромышляв"],
    "напропалую": ["отчаянно", "наугад", "вовсю"],
    "напророчествовав": ["напророчествовавши"],
    "напророчествовавши": ["напророчествовав"],
    "напророчив": ["напророчивши"],
    "напророчивши": ["напророчив"],
    "напророчить": ["предсказать", "нагадать", "накаркать", "накликать", "навлечь"],
    "напросив": ["напросивши"],
    "напросивши": ["напросив"],
    "напроситься": ["нарваться"],
    "напрочь": ["полностью", "совсем"],
    "напрудив": ["напрудивши"],
    "напрудивши": ["напрудив"],
    "напрудить": ["описаться", "сделать лужу"],
    "напружив": ["напруживши"],
    "напруживав": ["напруживавши"],
    "напруживавши": ["напруживав"],
    "напруживши": ["напружив"],
    "напружинив": ["напружинивши"],
    "напружинивав": ["напружинивавши"],
    "напружинивавши": ["напружинивав"],
    "напружинивши": ["напружинив"],
    "напрыгав": ["напрыгавши"],
    "напрыгавши": ["напрыгав"],
    "напрыгать": ["завестись", "допрыгаться"],
    "напрыгивав": ["напрыгивавши"],
    "напрыгивавши": ["напрыгивав"],
    "напрыскав": ["напрыскавши"],
    "напрыскавши": ["напрыскав"],
    "напрыскивав": ["напрыскивавши"],
    "напрыскивавши": ["напрыскивав"],
    "напряг": ["усилие", "неприятность", "отсутствие", "нехватка"],
    "напрягав": ["напрягавши"],
    "напрягавши": ["напрягав"],
    "напрягать": ["морщить"],
    "напрядав": ["напрядавши"],
    "напрядавши": ["напрядав"],
    "напряжение": ["сосредоточение", "сосредоточенье", "напряженье", "натянутость", "напряжённость"],
    "напряженье": ["напряжение"],
    "напряжённость": ["напряжение"],
    "напрямик": ["напрямки", "прямиком", "напрямую", "впрямую", "напролом", "прямо", "откровенно", "без обиняков", "непритворно", "начистоту", "честно", "не", "скрывать"],
    "напрямую": ["напрямик", "напрямки", "по прямой", "прямиком", "прямо", "непосредственно", "эксплицитно", "без обиняков", "без околичностей", "в глаза", "в лоб", "впрямую", "искренне", "искренно", "начистоту"],
    "напрятав": ["напрятавши"],
    "напрятавши": ["напрятав"],
    "напрятывав": ["напрятывавши"],
    "напрятывавши": ["напрятывав"],
    "напрячь": ["напружинить"],
    "напрячься": ["напружиниться"],
    "напугав": ["напугавши"],
    "напугавши": ["напугав"],
    "напугать": ["испугать"],
    "напудрив": ["напудривши"],
    "напудривав": ["напудривавши"],
    "напудривавши": ["напудривав"],
    "напудривши": ["напудрив"],
    "напудрить пизду": ["нахохлить пизду"],
    "напужав": ["напужавши"],
    "напужавши": ["напужав"],
    "напужать": ["испужать"],
    "напузырив": ["напузыривши"],
    "напузыривши": ["напузырив"],
    "напулять в голову": ["в голову напулять"],
    "напуск": ["напускание"],
    "напускав": ["напускавши"],
    "напускавши": ["напускав"],
    "напускание": ["напуск"],
    "напускной": ["деланный", "притворный", "фальшивый"],
    "напустив": ["напустивши"],
    "напустивши": ["напустив"],
    "напустословив": ["напустословивши"],
    "напустословивши": ["напустословив"],
    "напутав": ["напутавши"],
    "напутавши": ["напутав"],
    "напутствовав": ["напутствовавши"],
    "напутствовавши": ["напутствовав"],
    "напутывав": ["напутывавши"],
    "напутывавши": ["напутывав"],
    "напухав": ["напухавши"],
    "напухавши": ["напухав"],
    "напухание": ["вздутие", "опухание"],
    "напухать": ["вздуваться", "опухать", "отекать", "набухать"],
    "напухнув": ["напухнувши"],
    "напухнувши": ["напухнув"],
    "напучив": ["напучивши"],
    "напучивав": ["напучивавши"],
    "напучивавши": ["напучивав"],
    "напучивши": ["напучив"],
    "напушив": ["напушивши"],
    "напушивши": ["напушив"],
    "напущав": ["напущавши"],
    "напущавши": ["напущав"],
    "напхав": ["напхавши"],
    "напхавши": ["напхав"],
    "напън": ["напъване", "напор", "натиск", "сила", "насилие", "напрежение"],
    "напыжив": ["напыживши"],
    "напыживав": ["напыживавши"],
    "напыживавши": ["напыживав"],
    "напыживши": ["напыжив"],
    "напылив": ["напыливши"],
    "напыливши": ["напылив"],
    "напыляв": ["напылявши"],
    "напылявши": ["напыляв"],
    "напыщенно": ["высокопарность", "надменность", "надутость", "высокомерность", "чванность"],
    "напыщенность": ["высокопарность"],
    "напыщенный": ["надутый", "кичливый", "высокопарный"],
    "напялив": ["напяливши"],
    "напяливав": ["напяливавши"],
    "напяливавши": ["напяливав"],
    "напяливши": ["напялив"],
    "напятив": ["напятивши"],
    "напятивши": ["напятив"],
    "напячивав": ["напячивавши"],
    "напячивавши": ["напячивав"],
    "напёрши": ["наперев"],
    "нар": ["инер"],
    "нарабатывав": ["нарабатывавши"],
    "нарабатывавши": ["нарабатывав"],
    "нарабатывание": ["наработка"],
    "наработав": ["наработавши"],
    "наработавши": ["наработав"],
    "наравне": ["вровень"],
    "нараздавав": ["нараздававши"],
    "нараздававши": ["нараздавав"],
    "нарамник": ["омофор", "нараменник"],
    "нарангушт": ["шаст"],
    "нараспашку": ["настежь"],
    "нарассказав": ["нарассказавши"],
    "нарассказавши": ["нарассказав"],
    "нарассказывав": ["нарассказывавши"],
    "нарассказывавши": ["нарассказывав"],
    "нарассказывать": ["нарассказать"],
    "нарасследовав": ["нарасследовавши"],
    "нарасследовавши": ["нарасследовав"],
    "нарастав": ["нараставши"],
    "нараставши": ["нарастав"],
    "нарастанье": ["нарастание"],
    "нарастив": ["нарастивши"],
    "нарастивши": ["нарастив"],
    "нарастопашку": ["нараспашку"],
    "наращав": ["наращавши"],
    "наращавши": ["наращав"],
    "наращивав": ["наращивавши"],
    "наращивавши": ["наращивав"],
    "наращённый": ["нарощенный"],
    "нарбада": ["нармада"],
    "нарва": ["нарова", "ругодив"],
    "нарва-йыэсуу": ["нарва-мюндунг", "гунгербург", "усть-нарва"],
    "нарвав": ["нарвавши"],
    "нарвавши": ["нарвав"],
    "нарвал": ["морской единорог"],
    "нарваться": ["напороться"],
    "наргиле": ["кальян"],
    "нард": ["мускусный корень"],
    "нардамс": ["вадендемс", "вадемс", "ёрдамс сёрматфста", "ёрдамс пряста", "юкстамс"],
    "нардбон": ["зина", "суллам"],
    "нардек": ["арбузный мёд"],
    "нардеп": ["народный депутат"],
    "нарды": ["триктрак", "шеш-беш"],
    "наредактировав": ["наредактировавши"],
    "наредактировавши": ["наредактировав"],
    "наредба": ["разпореждане", "разпоредба", "заповед", "повеля", "повеление", "нареждане"],
    "нарез": ["надрез", "надел", "участок", "нарезка"],
    "нарезав": ["нарезавши"],
    "нарезавши": ["нарезав"],
    "нарезка": ["нарезание", "подборка"],
    "нарезывав": ["нарезывавши"],
    "нарезывавши": ["нарезывав"],
    "нарезывание": ["нарезание"],
    "нарезывать": ["нарезать"],
    "нарекав": ["нарекавши"],
    "нарекавши": ["нарекав"],
    "нарекание": ["обвинение", "укор", "упрёк", "укоризна"],
    "нареканье": ["нарекание"],
    "нарекать": ["называть"],
    "наречение": ["наименование"],
    "наречие": ["диалект"],
    "наречный": ["адвербиальный"],
    "наречь": ["назвать", "поименовать"],
    "наречье": ["наречие"],
    "наречься": ["назваться", "поименоваться"],
    "наречённая": ["невеста", "суженая"],
    "наречённый": ["жених"],
    "нарешивав": ["нарешивавши"],
    "нарешивавши": ["нарешивав"],
    "нари": ["хусэ"],
    "нарик": ["наркоша", "наркопет", "наркопед", "торчок", "торчубес", "кайфолов"],
    "нарингин": ["наргенин"],
    "нарине": ["наринэ"],
    "наринэ": ["нарине"],
    "нарисовав": ["нарисовавши"],
    "нарисовавши": ["нарисовав"],
    "нарисовать": ["изобразить"],
    "нарисоваться": ["объявиться", "появиться"],
    "нарицав": ["нарицавши"],
    "нарицавши": ["нарицав"],
    "нарицать": ["нарекать", "называть"],
    "нарицаться": ["называться", "нарекаться"],
    "наркобандит": ["наркопреступник"],
    "наркобарон": ["наркобосс", "наркоглаварь", "наркокороль", "наркомагнат", "наркоолигарх"],
    "наркобосс": ["наркобарон", "наркоглаварь", "наркокороль", "наркомагнат", "наркоолигарх"],
    "наркобум": ["наркореволюция"],
    "наркоглаварь": ["наркобарон", "наркобосс", "наркокороль", "наркомагнат", "наркоолигарх"],
    "наркогруппа": ["наркогруппировка", "наркофирма"],
    "наркогруппировка": ["наркогруппа", "наркофирма"],
    "наркодилер": ["драгдилер"],
    "наркоз": ["наркотический сон", "общая анестезия", "анестезия"],
    "наркокартель": ["наркосиндикат"],
    "наркокафе": ["кофешоп"],
    "наркокороль": ["наркобарон", "наркобосс", "наркоглаварь", "наркомагнат", "наркоолигарх"],
    "наркокурьер": ["наркоперевозчик"],
    "наркокурьерша": ["наркоперевозчица"],
    "нарколаборатория": ["наркоцех"],
    "нарколавка": ["наркомагазин", "наркоточка"],
    "нарком": ["народный комиссар", "министр"],
    "наркомагазин": ["нарколавка", "наркоточка"],
    "наркомагнат": ["наркобарон", "наркобосс", "наркоглаварь", "наркокороль", "наркоолигарх"],
    "наркоман": ["нарик", "наркоша", "нарколыга", "нарконавт", "нарк", "торчок", "ширяла", "наркопет", "наркопед", "наркобес", "объебос"],
    "наркоманив": ["наркоманивши"],
    "наркоманивши": ["наркоманив"],
    "наркомания": ["наркозависимость", "токсикомания", "бред"],
    "наркомат": ["народный комиссариат"],
    "наркомвоенмор": ["народный", "комиссар"],
    "наркоолигарх": ["наркобарон", "наркобосс", "наркоглаварь", "наркокороль", "наркомагнат"],
    "наркоперевозчик": ["наркокурьер"],
    "наркоперевозчица": ["наркокурьерша"],
    "наркореволюция": ["наркобум"],
    "наркосбытчик": ["драгдилер", "наркодилер", "наркоторговец"],
    "наркосиндикат": ["наркокартель"],
    "наркосодержащий": ["наркотикосодержащий"],
    "наркота": ["наркоман"],
    "наркотизировав": ["наркотизировавши"],
    "наркотизировавши": ["наркотизировав"],
    "наркотик": ["наркота", "дурь", "психотропное вещество"],
    "наркотикосодержащий": ["наркосодержащий"],
    "наркотин": ["гиоскапин", "носкапин", "нектодон", "носпен", "анаркотин", "опиан"],
    "наркотическое вещество": ["наркотик"],
    "наркотическое средство": ["наркотик"],
    "наркоторговля": ["наркотрафик"],
    "наркоточка": ["нарколавка", "наркомагазин"],
    "наркофирма": ["наркогруппа", "наркогруппировка"],
    "наркоцех": ["нарколаборатория"],
    "наркоша": ["наркоман", "наркоманка"],
    "нармада": ["нарбада"],
    "наровлянец": ["наровлянин"],
    "наровлянин": ["наровлянец"],
    "народ": ["население", "нация", "род", "племя", "этнос", "люд", "люди", "толпа", "простонародье"],
    "народ-победитель": ["народ-труженик", "народ-воин", "народ-герой"],
    "народец": ["народишко", "народность"],
    "народив": ["народивши"],
    "народивши": ["народив"],
    "народить": ["родить", "нарожать"],
    "народиться": ["родиться"],
    "народишко": ["народец", "людишки"],
    "народная дипломатия": ["гражданская дипломатия"],
    "народная дружина": ["днд"],
    "народная культура": ["фольклор"],
    "народная палата": ["лок сабха"],
    "народная полиция": ["фольксполицай"],
    "народная этимология": ["ложная этимология", "наивная этимология"],
    "народничав": ["народничавши"],
    "народничавши": ["народничав"],
    "народно-освободительная армия китая": ["ноак"],
    "народно-революционная армия": ["нра"],
    "народно-хозяйственный": ["народнохозяйственный"],
    "народное ополчение донбасса": ["нод"],
    "народное творчество": ["фольклор"],
    "народнофронтовец": ["народофронтовец"],
    "народнохозяйственный": ["народно-хозяйственный"],
    "народные республики": ["лднр"],
    "народный депутат": ["нардеп"],
    "народный комиссариат": ["наркомат"],
    "народный комиссариат внутренних дел": ["нквд", "наркомвнудел"],
    "народобожие": ["народничество", "народопоклонство"],
    "народоведение": ["этнология", "этнография"],
    "народовластие": ["демократия"],
    "народовластье": ["народовластие"],
    "народоправство": ["демократия"],
    "народоубийство": ["геноцид", "холокост"],
    "народофронтовец": ["народнофронтовец"],
    "нарожав": ["нарожавши"],
    "нарожавши": ["нарожав"],
    "нарожаться": ["народиться"],
    "нарождав": ["нарождавши"],
    "нарождавши": ["нарождав"],
    "нарожденье": ["нарождение"],
    "нароняв": ["наронявши"],
    "наронявши": ["нароняв"],
    "нарочитость": ["намеренность", "умышленность"],
    "нарочитый": ["умышленный", "преднамеренный", "значительный", "именитый"],
    "нарочно": ["в руки", "с нарочным"],
    "нарочный": ["гонец", "курьер", "посыльный"],
    "нарратор": ["повествователь", "рассказчик"],
    "нарсуд": ["народный суд"],
    "нарта": ["нарты"],
    "нартекс": ["нарфик", "притвор"],
    "нартенный": ["нартовый"],
    "нартутив": ["нартутивши"],
    "нартутивши": ["нартутив"],
    "нартучивав": ["нартучивавши"],
    "нартучивавши": ["нартучивав"],
    "нартучивать": ["ртутить"],
    "нарты": ["нарта"],
    "нарубав": ["нарубавши"],
    "нарубавши": ["нарубав"],
    "нарубив": ["нарубивши"],
    "нарубивши": ["нарубив"],
    "наругав": ["наругавши"],
    "наругавши": ["наругав"],
    "наругавший": ["отругавший"],
    "наружно": ["внешне"],
    "наружность": ["внешность", "облик", "обличье", "видимость"],
    "наружный": ["внешний"],
    "наружу": ["вовне", "изнутри", "внаружу"],
    "нарумянив": ["нарумянивши"],
    "нарумянивав": ["нарумянивавши"],
    "нарумянивавши": ["нарумянивав"],
    "нарумянивши": ["нарумянив"],
    "наруто": ["нарутомаки"],
    "наручни": ["наручники"],
    "наручник": ["наручень", "наручь"],
    "наручники": ["браслеты", "браслетки", "наручни"],
    "нарушав": ["нарушавши"],
    "нарушавши": ["нарушав"],
    "нарушать": ["прерывать", "преступать"],
    "нарушение": ["нарушенье"],
    "нарушив": ["нарушивши"],
    "нарушивши": ["нарушив"],
    "нарх": ["арзиш"],
    "нарцисизъм": ["самовлюбеност"],
    "нарциссизм": ["самовлюблённость", "самолюбование", "аутомоносексуализм", "аутоэротизм", "аутоэрастия"],
    "нарциссист": ["нарцисс"],
    "нарциссичный": ["самовлюблённый"],
    "наръчник": ["справочник", "помагало", "указател"],
    "нары": ["лежак", "шконка"],
    "нарыбачив": ["нарыбачивши"],
    "нарыбачивши": ["нарыбачив"],
    "нарыв": ["гнойник", "абсцесс"],
    "нарывав": ["нарывавши"],
    "нарывавши": ["нарывав"],
    "нарываться": ["провоцировать"],
    "нарывши": ["нарыв"],
    "нарык": ["нарренг", "нарран", "нарек", "нарик"],
    "нарыскав": ["нарыскавши"],
    "нарыскавши": ["нарыскав"],
    "нарытый": ["извлечённый", "накопанный"],
    "нарычав": ["нарычавши"],
    "нарычавши": ["нарычав"],
    "нарэшце": ["урэшце", "у рэшце рэшт"],
    "наряд": ["убранство", "вид"],
    "нарядив": ["нарядивши"],
    "нарядивши": ["нарядив"],
    "нарядить": ["принарядить", "перерядить"],
    "нарядиться": ["украситься"],
    "наряду": ["наравне", "одновременно", "вместе", "при этом"],
    "наряду с": ["наравне с", "помимо", "вместе с"],
    "наряжав": ["наряжавши"],
    "наряжавши": ["наряжав"],
    "наряжание": ["облачение"],
    "наряжать": ["принаряживать", "принаряжать", "прихорашивать", "прихорашиваться", "украшать"],
    "наряжаться": ["украшаться"],
    "наряженный": ["обряженный", "принаряженный", "выряженный", "облачённый"],
    "наряжённый": ["наряженный", "снаряжённый"],
    "насад": ["насада"],
    "насадив": ["насадивши"],
    "насадивши": ["насадив"],
    "насадить": ["посадить"],
    "насадка": ["насаживание"],
    "насадок": ["налёт", "осадок", "накипь", "насадка"],
    "насажав": ["насажавши"],
    "насажавши": ["насажав"],
    "насаждав": ["насаждавши"],
    "насаждавши": ["насаждав"],
    "насаждать": ["сажать", "внедрять", "распространять", "навязывать"],
    "насажденье": ["насаждение"],
    "насаживав": ["насаживавши"],
    "насаживавши": ["насаживав"],
    "насаживать": ["сажать"],
    "насалив": ["насаливши"],
    "насаливав": ["насаливавши"],
    "насаливавши": ["насаливав"],
    "насаливши": ["насалив"],
    "насандалив": ["насандаливши"],
    "насандаливав": ["насандаливавши"],
    "насандаливавши": ["насандаливав"],
    "насандаливать": ["сандалить"],
    "насандаливши": ["насандалив"],
    "насар": ["яман"],
    "насаривав": ["насаривавши"],
    "насаривавши": ["насаривав"],
    "насаривать": ["мусорить"],
    "насасывав": ["насасывавши"],
    "насасывавши": ["насасывав"],
    "насаться": ["носиться", "бегать", "метаться"],
    "насахарив": ["насахаривши"],
    "насахаривав": ["насахаривавши"],
    "насахаривавши": ["насахаривав"],
    "насахаривши": ["насахарив"],
    "насбивав": ["насбивавши"],
    "насбивавши": ["насбивав"],
    "насбивать": ["насшибать"],
    "насбирав": ["насбиравши"],
    "насбиравши": ["насбирав"],
    "насвай": ["нас", "насик"],
    "насвежевав": ["насвежевавши"],
    "насвежевавши": ["насвежевав"],
    "насверлив": ["насверливши"],
    "насверливав": ["насверливавши"],
    "насверливавши": ["насверливав"],
    "насверливши": ["насверлив"],
    "насвинячив": ["насвинячивши"],
    "насвинячивши": ["насвинячив"],
    "насвистав": ["насвиставши"],
    "насвиставши": ["насвистав"],
    "насвистанный": ["продиктованный", "попугайничающий", "индоктринированный"],
    "насвистев": ["насвистевши"],
    "насвистевши": ["насвистев"],
    "насвистеть": ["насвистать"],
    "насвистывав": ["насвистывавши"],
    "насвистывавши": ["насвистывав"],
    "насвистыванье": ["насвистывание"],
    "насвистывать": ["высвистывать", "свистеть", "посвистывать"],
    "насдав": ["насдавши"],
    "насдавав": ["насдававши"],
    "насдававши": ["насдавав"],
    "насдавши": ["насдав"],
    "насевав": ["насевавши"],
    "насевавши": ["насевав"],
    "наседав": ["наседавши"],
    "наседавши": ["наседав"],
    "насеивав": ["насеивавши"],
    "насеивавши": ["насеивав"],
    "насекав": ["насекавши"],
    "насекавши": ["насекав"],
    "насекомое": ["букашка", "вошь"],
    "население": ["народонаселение", "населенье", "житель", "обитатель"],
    "населенье": ["население", "народонаселение", "народонаселенье", "житель", "обитатель"],
    "населив": ["населивши"],
    "населивши": ["населив"],
    "населяв": ["населявши"],
    "населявши": ["населяв"],
    "насеяв": ["насеявши"],
    "насеявши": ["насеяв"],
    "насидев": ["насидевши"],
    "насидевши": ["насидев"],
    "насиживав": ["насиживавши"],
    "насиживавши": ["насиживав"],
    "насикав": ["насикавши"],
    "насикавши": ["насикав"],
    "насилие": ["абьюз", "притеснение", "беззаконие", "изнасилование"],
    "насиловав": ["насиловавши"],
    "насиловавши": ["насиловав"],
    "насиловать": ["сильничать", "притеснять", "неволить"],
    "насиловик": ["оборотень в погонах", "эскадроны смерти"],
    "насилу": ["с трудом", "еле", "едва", "чуть"],
    "насильничав": ["насильничавши"],
    "насильничавши": ["насильничав"],
    "насильственная смерть": ["гибель"],
    "насильственно": ["насильно"],
    "насильственный": ["принуждённый", "вымученный"],
    "насильствовав": ["насильствовавши"],
    "насильствовавши": ["насильствовав"],
    "насинив": ["насинивши"],
    "насинивав": ["насинивавши"],
    "насинивавши": ["насинивав"],
    "насинивши": ["насинив"],
    "насинькаться": ["нажраться", "наклюкаться"],
    "насирав": ["насиравши"],
    "насиравши": ["насирав"],
    "насита": ["насищане", "пресищане", "пресита", "доволство", "задоволяване", "засищане"],
    "наскабливав": ["наскабливавши"],
    "наскабливавши": ["наскабливав"],
    "насказав": ["насказавши"],
    "насказавши": ["насказав"],
    "насказать": ["наговорить", "наклеветать"],
    "насказывав": ["насказывавши"],
    "насказывавши": ["насказывав"],
    "наскакав": ["наскакавши"],
    "наскакавши": ["наскакав"],
    "наскакивав": ["наскакивавши"],
    "наскакивавши": ["наскакивав"],
    "наскакивать": ["наталкиваться"],
    "наскандалив": ["наскандаливши"],
    "наскандаливши": ["наскандалив"],
    "насквернословив": ["насквернословивши"],
    "насквернословивши": ["насквернословив"],
    "насквозный": ["сквозной"],
    "насквозь": ["наскрозь", "полностью", "совершенно", "целиком"],
    "наскипидарив": ["наскипидаривши"],
    "наскипидаривши": ["наскипидарив"],
    "наскоблив": ["наскобливши"],
    "наскобливши": ["наскоблив"],
    "наскок": ["наскакивание", "налёт"],
    "насколько": ["в какой мере", "в какой степени", "до какой степени", "как", "сколь"],
    "наскоро": ["поспешно", "на скорую руку", "наспех", "торопливо"],
    "наскочив": ["наскочивши"],
    "наскочивши": ["наскочив"],
    "наскребав": ["наскребавши"],
    "наскребавши": ["наскребав"],
    "наскрипев": ["наскрипевши"],
    "наскрипевши": ["наскрипев"],
    "наскрёбывав": ["наскрёбывавши"],
    "наскрёбывавши": ["наскрёбывав"],
    "наскулив": ["наскуливши"],
    "наскуливши": ["наскулив"],
    "наскучав": ["наскучавши"],
    "наскучавши": ["наскучав"],
    "наскучив": ["наскучивши"],
    "наскучивав": ["наскучивавши"],
    "наскучивавши": ["наскучивав"],
    "наскучивать": ["надоедать", "докучать"],
    "наскучивши": ["наскучив"],
    "наскучить": ["надоесть", "осточертеть", "приесться", "опостылеть"],
    "наслав": ["наславши"],
    "наславши": ["наслав"],
    "наслада": ["наслаждение"],
    "насладив": ["насладивши"],
    "насладивши": ["насладив"],
    "наслаждав": ["наслаждавши"],
    "наслаждавши": ["наслаждав"],
    "наслаждаться": ["получать удовольствие"],
    "наслажденье": ["наслаждение"],
    "наслаивав": ["наслаивавши"],
    "наслаивавши": ["наслаивав"],
    "насластив": ["насластивши"],
    "насластивши": ["насластив"],
    "наслащивав": ["наслащивавши"],
    "наслащивавши": ["наслащивав"],
    "наследив": ["наследивши"],
    "наследивши": ["наследив"],
    "наследие": ["достояние", "наследство"],
    "наследить": ["наследовать"],
    "наследник": ["наследодатель", "наследодательница", "последователь", "продолжатель", "преемник"],
    "наследовав": ["наследовавши"],
    "наследовавши": ["наследовав"],
    "наследованье": ["наследование"],
    "наследственная изменчивость": ["генотипическая изменчивость"],
    "наследство": ["наследие", "наследование"],
    "наслоенье": ["наслоение"],
    "наслоив": ["наслоивши"],
    "наслоивши": ["наслоив"],
    "наслужив": ["наслуживши"],
    "наслуживав": ["наслуживавши"],
    "наслуживавши": ["наслуживав"],
    "наслуживши": ["наслужив"],
    "наслушивав": ["наслушивавши"],
    "наслушивавши": ["наслушивав"],
    "наслышка": ["молва", "слух", "сплетня", "весть"],
    "наслюнив": ["наслюнивши"],
    "наслюнивав": ["наслюнивавши"],
    "наслюнивавши": ["наслюнивав"],
    "наслюнивши": ["наслюнив"],
    "наслюнявив": ["наслюнявивши"],
    "наслюнявивши": ["наслюнявив"],
    "насмаливав": ["насмаливавши"],
    "насмаливавши": ["насмаливав"],
    "насмарк": ["катар"],
    "насмаркивав": ["насмаркивавши"],
    "насмаркивавши": ["насмаркивав"],
    "насмарку": ["впустую", "прахом", "коту под хвост", "под откос"],
    "насматривав": ["насматривавши"],
    "насматривавши": ["насматривав"],
    "насмердев": ["насмердевши"],
    "насмердевши": ["насмердев"],
    "насмердеть": ["навонять", "насмердить"],
    "насмердив": ["насмердивши"],
    "насмердивши": ["насмердив"],
    "насмердить": ["навонять", "насмердеть"],
    "насмерть": ["до последнего вздоха", "не щадя живота", "до смерти", "до последней капли крови", "вусмерть"],
    "насмехаться": ["насмешничать", "зубоскалить", "высмеивать"],
    "насмешив": ["насмешивши"],
    "насмешивши": ["насмешив"],
    "насмешить": ["рассмешить", "посмешить"],
    "насмешка": ["издёвка", "хохма", "подковырка", "подначка", "шутка", "прикол", "острота", "бонмо", "издевательство", "подтрунивание", "ирония"],
    "насмешник": ["острослов", "остряк", "хохмач", "шутник", "зубоскал", "бонмотист"],
    "насмешничав": ["насмешничавши"],
    "насмешничавши": ["насмешничав"],
    "насмешничество": ["насмехательство", "насмешничанье", "насмешничание"],
    "насмеяться": ["посмеяться", "нахохотаться", "обезживотеть", "со", "смех", "обсмеяться", "обхохотаться", "смешной", "вид", "вышутить", "засмеять", "потешиться", "проехаться", "счёт", "адрес"],
    "насмолив": ["насмоливши"],
    "насмоливши": ["насмолив"],
    "насмолиться": ["накуриться"],
    "насморк": ["ринит"],
    "насморкав": ["насморкавши"],
    "насморкавши": ["насморкав"],
    "насмотрев": ["насмотревши"],
    "насмотревши": ["насмотрев"],
    "наснага": ["натхнення"],
    "наснежив": ["наснеживши"],
    "наснеживши": ["наснежив"],
    "наснимав": ["наснимавши"],
    "наснимавши": ["наснимав"],
    "насняв": ["наснявши"],
    "наснявши": ["насняв"],
    "наснять": ["наснимать", "сфотографировать"],
    "насобачиться": ["приноровиться", "научиться"],
    "насобирав": ["насобиравши"],
    "насобиравши": ["насобирав"],
    "насовав": ["насовавши"],
    "насовавши": ["насовав"],
    "насоветовав": ["насоветовавши"],
    "насоветовавши": ["насоветовав"],
    "насовсем": ["навсегда", "навеки"],
    "насовывав": ["насовывавши"],
    "насовывавши": ["насовывав"],
    "насодомив": ["насодомивши"],
    "насодомивши": ["насодомив"],
    "насолив": ["насоливши"],
    "насоливши": ["насолив"],
    "насолить": ["пересолить"],
    "насолодев": ["насолодевши"],
    "насолодевши": ["насолодев"],
    "насолодив": ["насолодивши"],
    "насолодивши": ["насолодив"],
    "насопев": ["насопевши"],
    "насопевши": ["насопев"],
    "насорив": ["насоривши"],
    "насоривши": ["насорив"],
    "насортировав": ["насортировавши"],
    "насортировавши": ["насортировав"],
    "насортировывав": ["насортировывавши"],
    "насортировывавши": ["насортировывав"],
    "насос": ["помпа"],
    "насосав": ["насосавши"],
    "насосавши": ["насосав"],
    "насохнув": ["насохнувши"],
    "насохнувши": ["насохнув"],
    "насочинив": ["насочинивши"],
    "насочинивши": ["насочинив"],
    "насочинить": ["насочинять"],
    "насочиняв": ["насочинявши"],
    "насочинявши": ["насочиняв"],
    "наспав": ["наспавши"],
    "наспавши": ["наспав"],
    "наспев": ["наспевши"],
    "наспевав": ["наспевавши"],
    "наспевавши": ["наспевав"],
    "наспевши": ["наспев"],
    "наспех": ["наскоро", "второпях", "на скорую руку"],
    "наспиртовав": ["наспиртовавши"],
    "наспиртовавши": ["наспиртовав"],
    "наспиртовывав": ["наспиртовывавши"],
    "наспиртовывавши": ["наспиртовывав"],
    "насплетничав": ["насплетничавши"],
    "насплетничавши": ["насплетничав"],
    "насрав": ["насравши"],
    "насравши": ["насрав"],
    "насрать": ["накакать", "сходить по-большому", "навалить", "наложить", "нагадить", "напакостить", "поднасрать", "наплевать", "начхать", "посрать"],
    "нассав": ["нассавши"],
    "нассавши": ["нассав"],
    "нассать": ["насрать"],
    "наст": ["череп"],
    "настав": ["наставши"],
    "наставав": ["настававши"],
    "настававши": ["наставав"],
    "наставать": ["наступать"],
    "наставив": ["наставивши"],
    "наставивши": ["наставив"],
    "наставить рога": ["изменить"],
    "наставленье": ["наставление"],
    "наставляв": ["наставлявши"],
    "наставлявши": ["наставляв"],
    "наставлять": ["учить", "поучать", "ставить"],
    "наставник": ["учитель", "педагог"],
    "наставши": ["настав"],
    "настаивав": ["настаивавши"],
    "настаивавши": ["настаивав"],
    "насталив": ["насталивши"],
    "насталивав": ["насталивавши"],
    "насталивавши": ["насталивав"],
    "насталивши": ["насталив"],
    "настанавливав": ["настанавливавши"],
    "настанавливавши": ["настанавливав"],
    "настановив": ["настановивши"],
    "настановивши": ["настановив"],
    "настать": ["начаться", "прийти", "наступить"],
    "настегав": ["настегавши"],
    "настегавши": ["настегав"],
    "настегать": ["исхлестать", "высечь", "отхлестать"],
    "настелив": ["настеливши"],
    "настеливши": ["настелив"],
    "настелить": ["настлать"],
    "настенька": ["настёна"],
    "настигав": ["настигавши"],
    "настигавши": ["настигав"],
    "настигать": ["догонять", "застигать"],
    "настигнув": ["настигнувши"],
    "настигнувши": ["настигнув"],
    "настигнуть": ["догнать", "застичь", "застигнуть"],
    "настижение": ["достижение"],
    "настил": ["перекрытие"],
    "настилав": ["настилавши"],
    "настилавши": ["настилав"],
    "настилка": ["настил", "настилание", "подстилка"],
    "настильный": ["настилочный"],
    "настирав": ["настиравши"],
    "настиравши": ["настирав"],
    "настирывав": ["настирывавши"],
    "настирывавши": ["настирывав"],
    "настичь": ["настигнуть"],
    "настлав": ["настлавши"],
    "настлавши": ["настлав"],
    "настоебав": ["настоебавши"],
    "настоебавши": ["настоебав"],
    "настоебать": ["настоёбнуть", "остоебать", "остоебенить", "остопиздить", "остохуеть", "заебать"],
    "настоечка": ["наливочка"],
    "настойник": ["настойщик", "настоятель", "наставник", "спорщик", "правдолюб"],
    "настойчивость": ["упорство"],
    "настойчивый": ["упорный", "твёрдый", "волевой", "неотступный", "назойливый", "навязчивый"],
    "настолка": ["настольная игра"],
    "настолование": ["интронизация"],
    "настолько": ["столь", "так", "до такой степени"],
    "настольная игра": ["настолка"],
    "настольный": ["необходимый", "востребованный"],
    "настольный компьютер": ["десктоп"],
    "настольный теннис": ["пинг-понг"],
    "настопиздев": ["настопиздевши"],
    "настопиздевши": ["настопиздев"],
    "настопиздеть": ["опротиветь", "осточертеть", "осточертенеть", "остохренеть", "остофигеть", "остохереть", "настоебать", "остоебенить", "остохуеть", "остохуенить", "остопиздеть"],
    "настораживав": ["настораживавши"],
    "настораживавши": ["настораживав"],
    "настороже": ["начеку", "наготове"],
    "настороженность": ["насторожённость"],
    "насторожив": ["настороживши"],
    "настороживши": ["насторожив"],
    "настояв": ["настоявши"],
    "настоявши": ["настояв"],
    "настоянье": ["настояние"],
    "настоятель": ["игумен"],
    "настоятельница": ["игуменья"],
    "настоящее время": ["презенс"],
    "настоящий": ["подлинный", "неподдельный", "всамделишный", "реальный", "истинный", "образцовый", "типичный", "совершенный", "правильный", "теперешний", "нынешний", "актуальный", "этот", "данный"],
    "настрагивав": ["настрагивавши"],
    "настрагивавши": ["настрагивав"],
    "настраивав": ["настраивавши"],
    "настраивавши": ["настраивав"],
    "настраиванье": ["настраивание", "настройка"],
    "настрачивав": ["настрачивавши"],
    "настрачивавши": ["настрачивав"],
    "настращав": ["настращавши"],
    "настращавши": ["настращав"],
    "настращивав": ["настращивавши"],
    "настращивавши": ["настращивав"],
    "настрекав": ["настрекавши"],
    "настрекавши": ["настрекав"],
    "настреливав": ["настреливавши"],
    "настреливавши": ["настреливав"],
    "настреляв": ["настрелявши"],
    "настрелявши": ["настреляв"],
    "настригав": ["настригавши"],
    "настригавши": ["настригав"],
    "настригание": ["настриг"],
    "настрогав": ["настрогавши"],
    "настрогавши": ["настрогав"],
    "настрогать": ["настругать"],
    "настроение": ["состояние", "настрой"],
    "настроенье": ["настроение", "состоянье", "настрой"],
    "настроив": ["настроивши"],
    "настроивши": ["настроив"],
    "настройщик": ["наладчик"],
    "настропалив": ["настропаливши"],
    "настропаливши": ["настропалив"],
    "настропалиться": ["намылиться", "собраться", "поднатореть", "наловчиться"],
    "настропаляв": ["настропалявши"],
    "настропалявши": ["настропаляв"],
    "настрочив": ["настрочивши"],
    "настрочивши": ["настрочив"],
    "настругав": ["настругавши"],
    "настругавши": ["настругав"],
    "настругивав": ["настругивавши"],
    "настругивавши": ["настругивав"],
    "настряв": ["настрявши"],
    "настрявши": ["настряв"],
    "настряпав": ["настряпавши"],
    "настряпавши": ["настряпав"],
    "настряпывав": ["настряпывавши"],
    "настряпывавши": ["настряпывав"],
    "настудив": ["настудивши"],
    "настудивши": ["настудив"],
    "настужав": ["настужавши"],
    "настужавши": ["настужав"],
    "настуживав": ["настуживавши"],
    "настуживавши": ["настуживав"],
    "настукав": ["настукавши"],
    "настукавши": ["настукав"],
    "настукивав": ["настукивавши"],
    "настукивавши": ["настукивав"],
    "наступ": ["атака"],
    "наступав": ["наступавши"],
    "наступавши": ["наступав"],
    "наступательность": ["агрессивность"],
    "наступать": ["надвигаться"],
    "наступать на грабли": ["наступать на те же грабли", "наступать на одни и те же грабли"],
    "наступать на одни и те же грабли": ["наступать на грабли", "наступать на те же грабли"],
    "наступать на те же грабли": ["наступать на грабли", "наступать на одни и те же грабли"],
    "наступив": ["наступивши"],
    "наступивши": ["наступив"],
    "наступить": ["ступить", "начаться", "прийти", "настать"],
    "наступление": ["наступленье"],
    "наступленье": ["наступление"],
    "настуран": ["уранинит"],
    "настурция": ["капуцин"],
    "настучав": ["настучавши"],
    "настучавши": ["настучав"],
    "настучать": ["настукать"],
    "настучать по щам": ["отрихтовать щи"],
    "настыв": ["настывши"],
    "настывав": ["настывавши"],
    "настывавши": ["настывав"],
    "настывши": ["настыв"],
    "настыль": ["гарнисаж"],
    "настынув": ["настынувши"],
    "настынувши": ["настынув"],
    "настынуть": ["настывать", "настыть"],
    "настырничав": ["настырничавши"],
    "настырничавши": ["настырничав"],
    "настырность": ["настойчивость"],
    "настырный": ["упорный", "настойчивый", "надоедливый", "назойливый", "навязчивый", "докучный", "настырчивый"],
    "настыть": ["настынуть", "намёрзть", "намёрзнуть", "выстудиться", "настудиться", "выстыть"],
    "настюшка": ["настенька"],
    "настёгивав": ["настёгивавши"],
    "настёгивавши": ["настёгивав"],
    "настёна": ["нястя"],
    "насудачив": ["насудачивши"],
    "насудачивши": ["насудачив"],
    "насулив": ["насуливши"],
    "насуливши": ["насулив"],
    "насумасбродив": ["насумасбродивши"],
    "насумасбродивши": ["насумасбродив"],
    "насумасбродничав": ["насумасбродничавши"],
    "насумасбродничавши": ["насумасбродничав"],
    "насумасбродничать": ["насумасбродить"],
    "насунув": ["насунувши"],
    "насунувши": ["насунув"],
    "насупив": ["насупивши"],
    "насупивши": ["насупив"],
    "насупившийся": ["нахмурившийся", "угрюмый", "нахохлившийся"],
    "насупленность": ["нахмуренность"],
    "насупленный": ["нахмуренный", "угрюмый"],
    "насупливав": ["насупливавши"],
    "насупливавши": ["насупливав"],
    "насупливаться": ["супиться", "хмуриться"],
    "насупротив": ["напротив", "против"],
    "насургучив": ["насургучивши"],
    "насургучивав": ["насургучивавши"],
    "насургучивавши": ["насургучивав"],
    "насургучивши": ["насургучив"],
    "насурьмив": ["насурьмивши"],
    "насурьмивши": ["насурьмив"],
    "насурьмить": ["посурьмить", "начернить"],
    "насурьмиться": ["посурьмиться"],
    "насуслив": ["насусливши"],
    "насусливав": ["насусливавши"],
    "насусливавши": ["насусливав"],
    "насусливши": ["насуслив"],
    "насутулив": ["насутуливши"],
    "насутуливав": ["насутуливавши"],
    "насутуливавши": ["насутуливав"],
    "насутуливши": ["насутулив"],
    "насутяжив": ["насутяживши"],
    "насутяживши": ["насутяжив"],
    "насутяжничав": ["насутяжничавши"],
    "насутяжничавши": ["насутяжничав"],
    "насухо": ["досуха"],
    "насучив": ["насучивши"],
    "насучивав": ["насучивавши"],
    "насучивавши": ["насучивав"],
    "насучивши": ["насучив"],
    "насушив": ["насушивши"],
    "насушивав": ["насушивавши"],
    "насушивавши": ["насушивав"],
    "насушивши": ["насушив"],
    "насущно": ["актуально", "существенно", "важно", "необходимо", "непосредственно", "именно", "собственно"],
    "насущный": ["необходимый"],
    "насцав": ["насцавши"],
    "насцавши": ["насцав"],
    "насчитав": ["насчитавши"],
    "насчитавши": ["насчитав"],
    "насчитывав": ["насчитывавши"],
    "насчитывавши": ["насчитывав"],
    "насчитывать": ["включать", "содержать", "присчитывать"],
    "насчитывающий": ["содержащий", "имеющий", "включающий"],
    "насчёт": ["об", "касательно", "относительно", "по поводу"],
    "насшибав": ["насшибавши"],
    "насшибавши": ["насшибав"],
    "насылав": ["насылавши"],
    "насылавши": ["насылав"],
    "насыпав": ["насыпавши"],
    "насыпавши": ["насыпав"],
    "насыпание": ["насыпка"],
    "насырев": ["насыревши"],
    "насыревши": ["насырев"],
    "насытив": ["насытивши"],
    "насытивши": ["насытив"],
    "насыхав": ["насыхавши"],
    "насыхавши": ["насыхав"],
    "насыщав": ["насыщавши"],
    "насыщавши": ["насыщав"],
    "насыщаться": ["наедаться"],
    "насыщение": ["насыщенность"],
    "насыщенно-жёлтый": ["ярко-жёлтый", "интенсивно-жёлтый", "блестяще-жёлтый", "горчичный", "горчично-жёлтый", "золотистый", "золотисто-жёлтый", "грушевый", "грушево-жёлтый", "лимонный", "лимонно-жёлтый", "ярко-лимонный"],
    "насыщенный": ["концентрированный", "содержательный", "обильный", "богатый", "яркий", "сочный", "густой"],
    "насыщенье": ["насыщение"],
    "нат": ["нэт"],
    "натаивав": ["натаивавши"],
    "натаивавши": ["натаивав"],
    "натаксовав": ["натаксовавши"],
    "натаксовавши": ["натаксовав"],
    "наталия": ["наталья"],
    "наталкивав": ["наталкивавши"],
    "наталкивавши": ["наталкивав"],
    "натамицин": ["пимарицин"],
    "натапливав": ["натапливавши"],
    "натапливавши": ["натапливав"],
    "натаптывав": ["натаптывавши"],
    "натаптывавши": ["натаптывав"],
    "натараджа": ["натарадж", "натараджан"],
    "натараторив": ["натараторивши"],
    "натараторивши": ["натараторив"],
    "натаскав": ["натаскавши"],
    "натаскавши": ["натаскав"],
    "натаскивав": ["натаскивавши"],
    "натаскивавши": ["натаскивав"],
    "натаскивание": ["принесение", "притаскивание"],
    "натаскиванье": ["натаскивание"],
    "натасовав": ["натасовавши"],
    "натасовавши": ["натасовав"],
    "натасовывав": ["натасовывавши"],
    "натасовывавши": ["натасовывав"],
    "нататуировав": ["нататуировавши"],
    "нататуировавши": ["нататуировав"],
    "натачав": ["натачавши"],
    "натачавши": ["натачав"],
    "натачивав": ["натачивавши"],
    "натачивавши": ["натачивав"],
    "натащив": ["натащивши"],
    "натащивши": ["натащив"],
    "натаяв": ["натаявши"],
    "натаявши": ["натаяв"],
    "натвердив": ["натвердивши"],
    "натвердивши": ["натвердив"],
    "натверживав": ["натверживавши"],
    "натверживавши": ["натверживав"],
    "натворив": ["натворивши"],
    "натворивши": ["натворив"],
    "натворить": ["наломать дров"],
    "нате": ["брать", "взять", "держать", "получать", "получить", "получите и распишитесь"],
    "натекав": ["натекавши"],
    "натекавши": ["натекав"],
    "нательный": ["нижний"],
    "нательный крест": ["тельник", "наперсный крест"],
    "натеребив": ["натеребивши"],
    "натеребивши": ["натеребив"],
    "натерев": ["натёрши"],
    "натереться": ["намазаться"],
    "натеряв": ["натерявши"],
    "натерявши": ["натеряв"],
    "натесав": ["натесавши"],
    "натесавши": ["натесав"],
    "натешив": ["натешивши"],
    "натешивши": ["натешив"],
    "натибрив": ["натибривши"],
    "натибривши": ["натибрив"],
    "нативно": ["естественно", "натурально"],
    "нативный": ["необработанный", "неизменённый", "природный", "интактный", "врождённый", "прирождённый", "машинозависимый", "платформозависимый"],
    "натирав": ["натиравши"],
    "натиравши": ["натирав"],
    "натиральщик": ["натирщик"],
    "натиральщица": ["натирщица"],
    "натирать": ["намазывать", "втирать", "надраивать", "тереть", "протирать"],
    "натираться": ["намазываться"],
    "натирщик": ["натиральщик"],
    "натирщица": ["натиральщица"],
    "натиск": ["давление", "нажим", "напор", "напористость", "настойчивость", "наступление", "прессинг"],
    "натискав": ["натискавши"],
    "натискавши": ["натискав"],
    "натискивав": ["натискивавши"],
    "натискивавши": ["натискивав"],
    "наткав": ["наткавши"],
    "наткавши": ["наткав"],
    "наткнув": ["наткнувши"],
    "наткнувши": ["наткнув"],
    "нато": ["североатлантический договор", "североатлантический альянс", "североатлантический блок", "североатлантический пакт"],
    "натовский": ["пронатовский"],
    "натолкав": ["натолкавши"],
    "натолкавши": ["натолкав"],
    "натолкнув": ["натолкнувши"],
    "натолкнувши": ["натолкнув"],
    "натолковав": ["натолковавши"],
    "натолковавши": ["натолковав"],
    "натолковать": ["натолковаться"],
    "натолковывав": ["натолковывавши"],
    "натолковывавши": ["натолковывав"],
    "натомив": ["натомивши"],
    "натомивши": ["натомив"],
    "натомиться": ["намучиться", "намаяться"],
    "натопав": ["натопавши"],
    "натопавши": ["натопав"],
    "натопаться": ["натоптаться", "нагуляться"],
    "натопив": ["натопивши"],
    "натопивши": ["натопив"],
    "натопорщив": ["натопорщивши"],
    "натопорщивши": ["натопорщив"],
    "натопорщить": ["встопорщить"],
    "натоптав": ["натоптавши"],
    "натоптавши": ["натоптав"],
    "натопывав": ["натопывавши"],
    "натопывавши": ["натопывав"],
    "наторговав": ["наторговавши"],
    "наторговавши": ["наторговав"],
    "наторговывав": ["наторговывавши"],
    "наторговывавши": ["наторговывав"],
    "наторев": ["наторевши"],
    "наторевши": ["наторев"],
    "наторив": ["наторивши"],
    "наторивши": ["наторив"],
    "наторкав": ["наторкавши"],
    "наторкавши": ["наторкав"],
    "наторосив": ["наторосивши"],
    "наторосивши": ["наторосив"],
    "наточив": ["наточивши"],
    "наточивши": ["наточив"],
    "наточка": ["наташа", "наташенька"],
    "натравив": ["натравивши"],
    "натравивши": ["натравив"],
    "натравка": ["натравливание"],
    "натравливав": ["натравливавши"],
    "натравливавши": ["натравливав"],
    "натравляв": ["натравлявши"],
    "натравлявши": ["натравляв"],
    "натратив": ["натративши"],
    "натративши": ["натратив"],
    "натрахав": ["натрахавши"],
    "натрахавши": ["натрахав"],
    "натребовав": ["натребовавши"],
    "натребовавши": ["натребовав"],
    "натрезвонив": ["натрезвонивши"],
    "натрезвонивши": ["натрезвонив"],
    "натренировав": ["натренировавши"],
    "натренировавши": ["натренировав"],
    "натренькивав": ["натренькивавши"],
    "натренькивавши": ["натренькивав"],
    "натрепав": ["натрепавши"],
    "натрепавши": ["натрепав"],
    "натрескаться": ["набарабаниться", "набраться", "набухаться", "навакситься", "нагрузиться", "надраться", "нажраться", "назюзиться", "назюзюкаться", "накачаться", "накваситься", "накидаться", "наклюкаться", "нализаться", "напиться"],
    "натреснув": ["натреснувши"],
    "натреснувши": ["натреснув"],
    "натрещав": ["натрещавши"],
    "натрещавши": ["натрещав"],
    "натрещаться": ["наговориться", "наболтаться", "налялякаться", "натарахтеться"],
    "натрий": ["содиум", "содий", "натриум"],
    "натристый": ["натровый", "натронный"],
    "натролит": ["мезотип"],
    "натрон": ["натрит"],
    "натрубив": ["натрубивши"],
    "натрубивши": ["натрубив"],
    "натрудив": ["натрудивши"],
    "натрудивши": ["натрудив"],
    "натружав": ["натружавши"],
    "натружавши": ["натружав"],
    "натруждав": ["натруждавши"],
    "натруждавши": ["натруждав"],
    "натруженный": ["тянутый", "умаянный", "переутомленный", "уставший", "утомлённый"],
    "натруживав": ["натруживавши"],
    "натруживавши": ["натруживав"],
    "натрусив": ["натрусивши"],
    "натрусивши": ["натрусив"],
    "натрушивав": ["натрушивавши"],
    "натрушивавши": ["натрушивав"],
    "натрясав": ["натрясавши"],
    "натрясавши": ["натрясав"],
    "натуга": ["напряжение"],
    "натужив": ["натуживши"],
    "натуживав": ["натуживавши"],
    "натуживавши": ["натуживав"],
    "натуживши": ["натужив"],
    "натузив": ["натузивши"],
    "натузивши": ["натузив"],
    "натурал": ["гетеросексуал", "гетераст", "гетеросек", "гетеросексуалист"],
    "натурализовав": ["натурализовавши"],
    "натурализовавши": ["натурализовав"],
    "натурализоваться": ["акклиматизироваться"],
    "натурализовывав": ["натурализовывавши"],
    "натурализовывавши": ["натурализовывав"],
    "натуралистически": ["натуралистично", "откровенно"],
    "натуралистично": ["натуралистически", "откровенно"],
    "натуралистичный": ["натуралистический"],
    "натуралистка": ["естественница", "естествоиспытательница", "юннатка"],
    "натуральная древесина": ["натуральное дерево"],
    "натурально": ["ещё бы", "в самом деле", "естественно", "конечно", "а то", "точно", "отож"],
    "натуральное число": ["естественное число"],
    "натуральность": ["естественность", "неискусственность", "неподдельность", "непосредственность"],
    "натуральный": ["природный", "естественный", "действительный", "настоящий", "подлинный", "реальный", "товарный", "неперовский"],
    "натуральный продукт": ["натурпродукт"],
    "натуризм": ["нудизм"],
    "натуропатия": ["натуропатическая медицина"],
    "натушив": ["натушивши"],
    "натушивши": ["натушив"],
    "натъженост": ["тъга", "горест", "печал"],
    "натыкав": ["натыкавши"],
    "натыкавши": ["натыкав"],
    "натыкаться": ["наскакивать", "напарываться"],
    "натырив": ["натыривши"],
    "натыривши": ["натырив"],
    "натюрмортист": ["натюрморист"],
    "натягав": ["натягавши"],
    "натягавши": ["натягав"],
    "натягивав": ["натягивавши"],
    "натягивавши": ["натягивав"],
    "натягивать": ["растягивать", "надвигать", "тащить"],
    "натягивать сову на глобус": ["притягивать за уши"],
    "натягиваться": ["растягиваться"],
    "натяжение": ["натяженье", "растяжение", "натяжка", "срастание"],
    "натяженье": ["натяжение"],
    "натяжка": ["натягивание", "натянутость"],
    "натяк": ["натякання"],
    "натянув": ["натянувши"],
    "натянувши": ["натянув"],
    "натянутый": ["тугой"],
    "натянуть": ["растянуть", "надвинуть", "натащить"],
    "натянуть нос": ["провести", "обхитрить", "одурачить", "объегорить"],
    "натянуть сову на глобус": ["притянуть за уши"],
    "натянуться": ["налакаться"],
    "натёрши": ["натерев"],
    "натёсывав": ["натёсывавши"],
    "натёсывавши": ["натёсывав"],
    "науатль": ["нахуатль"],
    "наугад": ["наудачу", "вслепую", "наобум"],
    "науглеродив": ["науглеродивши"],
    "науглеродивши": ["науглеродив"],
    "науглероживав": ["науглероживавши"],
    "науглероживавши": ["науглероживав"],
    "наугольник": ["рейсшина", "угольник", "винкель"],
    "наудачу": ["вслепую", "наугад", "как придётся", "на авось"],
    "наудив": ["наудивши"],
    "наудивши": ["наудив"],
    "науживав": ["науживавши"],
    "науживавши": ["науживав"],
    "наузнав": ["наузнавши"],
    "наузнавав": ["наузнававши"],
    "наузнававши": ["наузнавав"],
    "наузнавши": ["наузнав"],
    "наузнать": ["разузнать"],
    "наука": ["знание", "умение", "урок"],
    "наукоград": ["технополис"],
    "наукообразие": ["наукоподобие"],
    "наукоподобие": ["наукообразие"],
    "наум": ["нахум"],
    "науру": ["республика науру"],
    "наустив": ["наустивши"],
    "наустивши": ["наустив"],
    "науськав": ["науськавши"],
    "науськавши": ["науськав"],
    "науськивав": ["науськивавши"],
    "науськивавши": ["науськивав"],
    "науськивание": ["подстрекательство"],
    "науськиванье": ["науськивание"],
    "науськивать": ["уськать", "натравливать"],
    "наутилус": ["кораблик"],
    "наутро": ["поутру"],
    "наутюжив": ["наутюживши"],
    "наутюживав": ["наутюживавши"],
    "наутюживавши": ["наутюживав"],
    "наутюживши": ["наутюжив"],
    "наутюжить": ["нагладить"],
    "наутёк": ["бегом", "прочь"],
    "научав": ["научавши"],
    "научавши": ["научав"],
    "научаться": ["учиться", "обучаться"],
    "наученье": ["научение"],
    "научив": ["научивши"],
    "научивши": ["научив"],
    "научить": ["обучить", "подговорить", "подбить", "показать"],
    "научиться": ["выучиться"],
    "научная дисциплина": ["дисциплина научная"],
    "научная фантастика": ["нф"],
    "наушник": ["доносчик", "ябедник"],
    "наушники": ["уши"],
    "наушница": ["доносчица", "ябедница"],
    "наушничав": ["наушничавши"],
    "наушничавши": ["наушничав"],
    "наушничать": ["жаловаться", "ябедничать", "фискалить", "капать", "кляузничать", "доносить", "стучать", "заявлять", "сигнализировать"],
    "наущав": ["наущавши"],
    "наущавши": ["наущав"],
    "наущать": ["подговаривать", "подстрекать", "наущивать"],
    "наущение": ["внушение", "совет", "подстрекательство", "подговаривание", "науськивание", "подговор", "подуськивание", "возбуждение", "настропаление", "подзуживание", "заводка", "подначка", "подучивание", "подстрекание", "инспирирование"],
    "наущенье": ["наущение"],
    "нафабрив": ["нафабривши"],
    "нафабривав": ["нафабривавши"],
    "нафабривавши": ["нафабривав"],
    "нафабривши": ["нафабрив"],
    "нафабриковав": ["нафабриковавши"],
    "нафабриковавши": ["нафабриковав"],
    "нафантазировав": ["нафантазировавши"],
    "нафантазировавши": ["нафантазировав"],
    "нафаршировав": ["нафаршировавши"],
    "нафаршировавши": ["нафаршировав"],
    "нафаршировать": ["начинить", "наполнить"],
    "нафаршировывав": ["нафаршировывавши"],
    "нафаршировывавши": ["нафаршировывав"],
    "нафасовав": ["нафасовавши"],
    "нафасовавши": ["нафасовав"],
    "нафигачив": ["нафигачивши"],
    "нафигачивши": ["нафигачив"],
    "нафиксатуарив": ["нафиксатуаривши"],
    "нафиксатуаривав": ["нафиксатуаривавши"],
    "нафиксатуаривавши": ["нафиксатуаривав"],
    "нафиксатуаривши": ["нафиксатуарив"],
    "нафилософствовав": ["нафилософствовавши"],
    "нафилософствовавши": ["нафилософствовав"],
    "нафискалив": ["нафискаливши"],
    "нафискаливши": ["нафискалив"],
    "нафлективный": ["флективный"],
    "наформовав": ["наформовавши"],
    "наформовавши": ["наформовав"],
    "наформовывав": ["наформовывавши"],
    "наформовывавши": ["наформовывав"],
    "нафоткав": ["нафоткавши"],
    "нафоткавши": ["нафоткав"],
    "нафоткать": ["нафотографировать", "наснимать"],
    "нафотографировав": ["нафотографировавши"],
    "нафотографировавши": ["нафотографировав"],
    "нафотографировать": ["наснимать"],
    "нафрин": ["лаънат"],
    "нафс": ["дил"],
    "нафта": ["нефть", "лигроин"],
    "нафталин": ["нафталинчик"],
    "нафталинный": ["нафталиновый"],
    "нафталиновый": ["нафталинный"],
    "нафтосклад": ["нафтобаза"],
    "нафыркав": ["нафыркавши"],
    "нафыркавши": ["нафыркав"],
    "нах": ["нахуй"],
    "нахаба": ["нахабник", "нахабниця"],
    "нахаживав": ["нахаживавши"],
    "нахаживавши": ["нахаживав"],
    "нахал": ["бесстыдник", "наглец"],
    "нахалка": ["бесстыдница"],
    "нахаловка": ["нахалстрой"],
    "нахалстрой": ["нахаловка"],
    "нахалтурив": ["нахалтуривши"],
    "нахалтуривши": ["нахалтурив"],
    "нахальничав": ["нахальничавши"],
    "нахальничавши": ["нахальничав"],
    "нахальный": ["дерзкий", "наглый"],
    "нахальство": ["нахальность", "наглость"],
    "нахальствовав": ["нахальствовавши"],
    "нахальствовавши": ["нахальствовав"],
    "нахамив": ["нахамивши"],
    "нахамивши": ["нахамив"],
    "нахапав": ["нахапавши"],
    "нахапавши": ["нахапав"],
    "нахапать": ["награбастать", "нахватать"],
    "нахапывав": ["нахапывавши"],
    "нахапывавши": ["нахапывав"],
    "нахаркав": ["нахаркавши"],
    "нахаркавши": ["нахаркав"],
    "нахвалив": ["нахваливши"],
    "нахваливав": ["нахваливавши"],
    "нахваливавши": ["нахваливав"],
    "нахваливши": ["нахвалив"],
    "нахвастав": ["нахваставши"],
    "нахваставши": ["нахвастав"],
    "нахвастать": ["нахвастаться"],
    "нахватав": ["нахватавши"],
    "нахватавши": ["нахватав"],
    "нахвататься": ["набраться", "понахвататься", "понабраться"],
    "нахватывав": ["нахватывавши"],
    "нахватывавши": ["нахватывав"],
    "нахезав": ["нахезавши"],
    "нахезавши": ["нахезав"],
    "нахезать": ["нагадить", "накакать", "насрать"],
    "нахимичив": ["нахимичивши"],
    "нахимичивши": ["нахимичив"],
    "нахимичить": ["наколдовать", "схимичить"],
    "нахитрив": ["нахитривши"],
    "нахитривши": ["нахитрив"],
    "нахичеванская автономная республика": ["нахичевань", "нахичеванский автономный край", "нахичеванская асср"],
    "нахламив": ["нахламивши"],
    "нахламивши": ["нахламив"],
    "нахламить": ["нахламостить"],
    "нахламостив": ["нахламостивши"],
    "нахламостивши": ["нахламостив"],
    "нахламостить": ["нахламить"],
    "нахлебник": ["приживал", "приживальщик", "дармоед", "чужеяд", "тунеядец", "прихлебатель"],
    "нахлебничав": ["нахлебничавши"],
    "нахлебничавши": ["нахлебничав"],
    "нахлестав": ["нахлеставши"],
    "нахлеставши": ["нахлестав"],
    "нахлестнув": ["нахлестнувши"],
    "нахлестнувши": ["нахлестнув"],
    "нахлобучив": ["нахлобучивши"],
    "нахлобучивав": ["нахлобучивавши"],
    "нахлобучивавши": ["нахлобучивав"],
    "нахлобучивши": ["нахлобучив"],
    "нахлобучить": ["надвинуть", "надеть", "напялить", "взбучить"],
    "нахлопав": ["нахлопавши"],
    "нахлопавши": ["нахлопав"],
    "нахлопнув": ["нахлопнувши"],
    "нахлопнувши": ["нахлопнув"],
    "нахлопывав": ["нахлопывавши"],
    "нахлопывавши": ["нахлопывав"],
    "нахлынивав": ["нахлынивавши"],
    "нахлынивавши": ["нахлынивав"],
    "нахлынув": ["нахлынувши"],
    "нахлынувши": ["нахлынув"],
    "нахлыстав": ["нахлыставши"],
    "нахлыставши": ["нахлыстав"],
    "нахлёст": ["нахлёстка"],
    "нахлёстка": ["нахлёст"],
    "нахлёстом": ["внахлёст"],
    "нахлёстывав": ["нахлёстывавши"],
    "нахлёстывавши": ["нахлёстывав"],
    "нахмурив": ["нахмуривши"],
    "нахмуривав": ["нахмуривавши"],
    "нахмуривавши": ["нахмуривав"],
    "нахмуривши": ["нахмурив"],
    "нахмуриться": ["нахмурить", "сдвинуть", "бровь", "насупиться"],
    "находив": ["находивши"],
    "находивши": ["находив"],
    "находить": ["обнаруживать", "отыскивать", "выискивать", "локализовывать", "добиваться", "достигать", "встречать", "натыкаться", "полагать", "считать", "думать", "рассматривать", "усматривать", "видеть", "оценивать"],
    "находиться": ["располагаться", "быть", "присутствовать", "обретаться", "пребывать", "ошиваться", "шариться", "выходить из положения"],
    "находкинский городской округ": ["нго"],
    "находчивость": ["сообразительность", "изворотливость"],
    "находчивый": ["сообразительный", "изворотливый"],
    "нахождение": ["присутствие", "выискивание", "отыскивание"],
    "нахожденье": ["нахождение"],
    "нахозяйничав": ["нахозяйничавши"],
    "нахозяйничавши": ["нахозяйничав"],
    "нахозяйствовав": ["нахозяйствовавши"],
    "нахозяйствовавши": ["нахозяйствовав"],
    "нахолаживав": ["нахолаживавши"],
    "нахолаживавши": ["нахолаживав"],
    "нахолив": ["нахоливши"],
    "нахоливав": ["нахоливавши"],
    "нахоливавши": ["нахоливав"],
    "нахоливши": ["нахолив"],
    "нахолодав": ["нахолодавши"],
    "нахолодавши": ["нахолодав"],
    "нахолодев": ["нахолодевши"],
    "нахолодевши": ["нахолодев"],
    "нахолодив": ["нахолодивши"],
    "нахолодивши": ["нахолодив"],
    "нахомутав": ["нахомутавши"],
    "нахомутавши": ["нахомутав"],
    "нахохлив": ["нахохливши"],
    "нахохливав": ["нахохливавши"],
    "нахохливавши": ["нахохливав"],
    "нахохливши": ["нахохлив"],
    "нахохлить пизду": ["напудрить пизду"],
    "нахрамывав": ["нахрамывавши"],
    "нахрамывавши": ["нахрамывав"],
    "нахрап": ["бесцеремонность", "наглость", "нахальство", "беззастенчивость", "бесстыдство"],
    "нахрапистый": ["наглый", "бесцеремонный"],
    "нахрапом": ["нахально", "нагло", "насильно", "бесцеремонно", "беззастенчиво", "бесстыдно"],
    "нахреначив": ["нахреначивши"],
    "нахреначивши": ["нахреначив"],
    "нахуатль": ["науатль"],
    "нахуевертив": ["нахуевертивши"],
    "нахуевертивши": ["нахуевертив"],
    "нахуевертить": ["натворить", "наделать делов", "наломать дров"],
    "нахуй": ["зачем", "к чему", "для чего", "нахуя", "нах", "нахуй-нахуй"],
    "нахулиганив": ["нахулиганивши"],
    "нахулиганивши": ["нахулиганив"],
    "нахуя": ["нахуй"],
    "нахуяриться": ["напиться", "уделаться", "нахерачиться", "нахреначиться", "нахуячиться"],
    "нахуячив": ["нахуячивши"],
    "нахуячиваться": ["нахуяриваться", "нажираться"],
    "нахуячивши": ["нахуячив"],
    "нахуячить": ["наделать", "наизготавливать", "наклепать", "настрогать"],
    "нахуячиться": ["упиться", "натрескаться", "нажраться", "накидаться", "назюзюкаться", "набухаться", "нахуяриться", "наебениться", "объебениться"],
    "нацарапав": ["нацарапавши"],
    "нацарапавши": ["нацарапав"],
    "нацарапывав": ["нацарапывавши"],
    "нацарапывавши": ["нацарапывав"],
    "нацарствовав": ["нацарствовавши"],
    "нацарствовавши": ["нацарствовав"],
    "нацбат": ["националистический батальон", "нацбатальон"],
    "нацбатальон": ["националистический батальон", "нацбат"],
    "нацбол": ["национал-большевик", "лимоновец"],
    "нацедив": ["нацедивши"],
    "нацедивши": ["нацедив"],
    "нацеживав": ["нацеживавши"],
    "нацеживавши": ["нацеживав"],
    "нацелив": ["нацеливши"],
    "нацеливав": ["нацеливавши"],
    "нацеливавши": ["нацеливав"],
    "нацеливать": ["целить", "прицеливаться", "ориентировать", "устремлять"],
    "нацеливши": ["нацелив"],
    "нацело": ["полностью", "целиком", "без остатка"],
    "нацеловав": ["нацеловавши"],
    "нацеловавши": ["нацеловав"],
    "наценив": ["наценивши"],
    "наценивав": ["наценивавши"],
    "наценивавши": ["наценивав"],
    "наценивши": ["наценив"],
    "наценять": ["наценивать", "наценовать"],
    "нацепив": ["нацепивши"],
    "нацепивши": ["нацепив"],
    "нацепляв": ["нацеплявши"],
    "нацеплявши": ["нацепляв"],
    "наци-скин": ["скинхед"],
    "нацик": ["нацист"],
    "национал-патриот": ["нацпот"],
    "национал-предатель": ["пятая колонна", "враг народа"],
    "национал-радикал": ["нацрадикал"],
    "национал-социализм": ["нс", "нацизм"],
    "национал-социалист": ["нацист"],
    "национализация": ["экспроприация"],
    "национализировав": ["национализировавши"],
    "национализировавши": ["национализировав"],
    "национализировать": ["деприватизировать"],
    "национализм": ["ксенофобия", "шовинизм"],
    "национализовав": ["национализовавши"],
    "национализовавши": ["национализовав"],
    "национализъм": ["шовинизъм"],
    "националистический батальон": ["нацбатальон", "нацбат"],
    "национальная народная армия": ["нна", "фольксармее"],
    "национально-русский": ["русско-национальный"],
    "национальное меньшинство": ["нацменьшинство"],
    "национальное собрание": ["нацсобрание", "нс"],
    "национальный округ": ["автономный округ"],
    "национальный совет": ["национальрат", "маджлиси милли"],
    "нацист": ["национал-социалист"],
    "нацистка": ["фашистка", "шовинистка"],
    "нацистская германия": ["гитлеровская германия", "третий рейх", "фашистская германия"],
    "нацистское приветствие": ["гитлеровское приветствие", "партийное приветствие", "зига"],
    "нация": ["народ", "государство", "страна"],
    "нацмен": ["инородец", "нерусский"],
    "нацменовский": ["нацменский"],
    "нацпарк": ["национальный парк"],
    "начав": ["начавши"],
    "начавши": ["начав"],
    "начадив": ["начадивши"],
    "начадивши": ["начадив"],
    "началив": ["началивши"],
    "началивши": ["началив"],
    "началка": ["начальная школа"],
    "начало": ["старт", "почин", "основа", "руководство", "главенство"],
    "начальник": ["руководитель", "шеф", "босс", "патрон"],
    "начальница": ["глава", "руководительница"],
    "начальничий": ["начальнический"],
    "начальный": ["первоначальный", "исходный", "первичный", "низший", "простейший"],
    "начальствовав": ["начальствовавши"],
    "начальствовавши": ["начальствовав"],
    "начар": ["яман", "алама"],
    "начать": ["положить начало", "приступить", "стартовать", "повести речь"],
    "начаться": ["наступить", "настать", "возникнуть"],
    "начеканив": ["начеканивши"],
    "начеканивав": ["начеканивавши"],
    "начеканивавши": ["начеканивав"],
    "начеканивши": ["начеканив"],
    "начеку": ["настороже", "наготове", "на стрёме"],
    "наченка": ["зачатък", "зародиш", "начало"],
    "начередив": ["начередивши"],
    "начередивши": ["начередив"],
    "начеркав": ["начеркавши"],
    "начеркавши": ["начеркав"],
    "начернив": ["начернивши"],
    "начернивши": ["начернив"],
    "начерняв": ["начернявши"],
    "начернявши": ["начерняв"],
    "начерпав": ["начерпавши"],
    "начерпавши": ["начерпав"],
    "начерпывав": ["начерпывавши"],
    "начерпывавши": ["начерпывав"],
    "начертав": ["начертавши"],
    "начертавши": ["начертав"],
    "начертанье": ["начертание"],
    "начертать": ["написать", "нарисовать", "указать", "определить"],
    "начертив": ["начертивши"],
    "начертивши": ["начертив"],
    "начертывав": ["начертывавши"],
    "начертывавши": ["начертывав"],
    "начерчивав": ["начерчивавши"],
    "начерчивавши": ["начерчивав"],
    "начесав": ["начесавши"],
    "начесавши": ["начесав"],
    "начетеност": ["грамотност", "образованост", "книжовност"],
    "начин": ["зачин", "начало"],
    "начинав": ["начинавши"],
    "начинавши": ["начинав"],
    "начинание": ["начало"],
    "начинанье": ["начинание"],
    "начинатель": ["зачинатель", "первопроходец", "пионер", "инициатор", "основатель"],
    "начинаться": ["возникать"],
    "начинаясь": ["возникаясь"],
    "начинив": ["начинивши"],
    "начинивав": ["начинивавши"],
    "начинивавши": ["начинивав"],
    "начинивши": ["начинив"],
    "начинка": ["припёк", "припёка"],
    "начинщик": ["начинатель", "заводиловец", "закопёрщик", "затейщик"],
    "начиняв": ["начинявши"],
    "начинявши": ["начиняв"],
    "начиркав": ["начиркавши"],
    "начиркавши": ["начиркав"],
    "начислив": ["начисливши"],
    "начисливши": ["начислив"],
    "начисляв": ["начислявши"],
    "начислявши": ["начисляв"],
    "начистив": ["начистивши"],
    "начистивши": ["начистив"],
    "начистить носопырку": ["поколотить", "исколотить", "отколотить", "поколошматить", "исколошматить", "отколошматить"],
    "начисто": ["набело", "полностью", "совсем", "совершенно"],
    "начистоту": ["откровенно", "открыто", "искренно"],
    "начитав": ["начитавши"],
    "начитавши": ["начитав"],
    "начитанность": ["эрудиция"],
    "начитанный": ["эрудированный"],
    "начитывав": ["начитывавши"],
    "начитывавши": ["начитывав"],
    "начитывать": ["прочитывать", "перечитывать", "вычитывать"],
    "начихав": ["начихавши"],
    "начихавши": ["начихав"],
    "начищав": ["начищавши"],
    "начищавши": ["начищав"],
    "начка": ["летьке"],
    "начо": ["игнасио"],
    "начпо": ["замполит"],
    "начудачив": ["начудачивши"],
    "начудачивши": ["начудачив"],
    "начудесив": ["начудесивши"],
    "начудесивши": ["начудесив"],
    "начудив": ["начудивши"],
    "начудивши": ["начудив"],
    "начутися": ["наслухатися"],
    "начхав": ["начхавши"],
    "начхавши": ["начхав"],
    "начхать": ["наплевать"],
    "начёркав": ["начёркавши"],
    "начёркавши": ["начёркав"],
    "начёркивав": ["начёркивавши"],
    "начёркивавши": ["начёркивав"],
    "начёсывав": ["начёсывавши"],
    "начёсывавши": ["начёсывав"],
    "начёт": ["взыскание", "компенсация"],
    "начётисто": ["убыточно", "невыгодно"],
    "начётничество": ["схоластика"],
    "наш общий друг": ["четвёрка"],
    "наша": ["кенаф", "каноп"],
    "нашагав": ["нашагавши"],
    "нашагавши": ["нашагав"],
    "нашалив": ["нашаливши"],
    "нашаливши": ["нашалив"],
    "нашарив": ["нашаривши"],
    "нашаривав": ["нашаривавши"],
    "нашаривавши": ["нашаривав"],
    "нашаривать": ["нащупывать"],
    "нашаривши": ["нашарив"],
    "нашарить": ["нащупать"],
    "нашаркав": ["нашаркавши"],
    "нашаркавши": ["нашаркав"],
    "нашаркивав": ["нашаркивавши"],
    "нашаркивавши": ["нашаркивав"],
    "нашарлатанив": ["нашарлатанивши"],
    "нашарлатанивши": ["нашарлатанив"],
    "нашармака": ["нашармачка", "нашарамыжку"],
    "нашатырь": ["хлорид аммония", "хлористый аммоний", "нашатырный спирт"],
    "нашвыривав": ["нашвыривавши"],
    "нашвыривавши": ["нашвыривав"],
    "нашвыряв": ["нашвырявши"],
    "нашвырявши": ["нашвыряв"],
    "нашего полку прибыло": ["в нашем полку прибыло"],
    "нашед": ["найдя", "нашедши"],
    "нашелушив": ["нашелушивши"],
    "нашелушивав": ["нашелушивавши"],
    "нашелушивавши": ["нашелушивав"],
    "нашелушивши": ["нашелушив"],
    "нашему забору двоюродный плетень": ["нашему забору двоюродный яков", "седьмая вода на киселе"],
    "нашему забору двоюродный яков": ["нашему забору двоюродный плетень", "седьмая вода на киселе"],
    "нашенец": ["земляк", "съотечественик"],
    "нашептав": ["нашептавши"],
    "нашептавши": ["нашептав"],
    "нашептать": ["прошептать", "насплетничать", "наколдовать"],
    "нашественик": ["завоевател", "окупатор", "агресор", "нападател", "империалист"],
    "нашибав": ["нашибавши"],
    "нашибавши": ["нашибав"],
    "нашибив": ["нашибивши"],
    "нашибивши": ["нашибив"],
    "нашив": ["нашивши"],
    "нашивав": ["нашивавши"],
    "нашивавши": ["нашивав"],
    "нашивать": ["носить"],
    "нашивши": ["нашив"],
    "нашинковав": ["нашинковавши"],
    "нашинковавши": ["нашинковав"],
    "нашинковывав": ["нашинковывавши"],
    "нашинковывавши": ["нашинковывав"],
    "нашить": ["надшить", "пришить", "понашить", "сшить"],
    "нашкодив": ["нашкодивши"],
    "нашкодивши": ["нашкодив"],
    "нашкодить": ["набедокурить", "напакостничать", "нахулиганить"],
    "нашколив": ["нашколивши"],
    "нашколивав": ["нашколивавши"],
    "нашколивавши": ["нашколивав"],
    "нашколивать": ["муштровать"],
    "нашколивши": ["нашколив"],
    "нашла коса на камень": ["попала коса на камень", "наскочила кость на кость", "наскочила подковка на булыжник"],
    "нашлёпав": ["нашлёпавши"],
    "нашлёпавши": ["нашлёпав"],
    "нашлёпнув": ["нашлёпнувши"],
    "нашлёпнувши": ["нашлёпнув"],
    "нашлёпывав": ["нашлёпывавши"],
    "нашлёпывавши": ["нашлёпывав"],
    "нашмыгав": ["нашмыгавши"],
    "нашмыгавши": ["нашмыгав"],
    "нашпарив": ["нашпаривши"],
    "нашпаривав": ["нашпаривавши"],
    "нашпаривавши": ["нашпаривав"],
    "нашпаривши": ["нашпарив"],
    "нашпиговав": ["нашпиговавши"],
    "нашпиговавши": ["нашпиговав"],
    "нашпиговывав": ["нашпиговывавши"],
    "нашпиговывавши": ["нашпиговывав"],
    "нашпиговывать": ["шпиговать"],
    "нашпиковав": ["нашпиковавши"],
    "нашпиковавши": ["нашпиковав"],
    "нашпиковывав": ["нашпиковывавши"],
    "нашпиковывавши": ["нашпиковывав"],
    "нашпилив": ["нашпиливши"],
    "нашпиливав": ["нашпиливавши"],
    "нашпиливавши": ["нашпиливав"],
    "нашпиливши": ["нашпилив"],
    "нашпионив": ["нашпионивши"],
    "нашпионивши": ["нашпионив"],
    "наштаарм": ["наштарм"],
    "наштамповав": ["наштамповавши"],
    "наштамповавши": ["наштамповав"],
    "наштамповывав": ["наштамповывавши"],
    "наштамповывавши": ["наштамповывав"],
    "наштарм": ["наштаарм"],
    "наштаюз": ["начальник штаба юго-западного фронта"],
    "наштопав": ["наштопавши"],
    "наштопавши": ["наштопав"],
    "наштопывав": ["наштопывавши"],
    "наштопывавши": ["наштопывав"],
    "наштукатурив": ["наштукатуривши"],
    "наштукатуривав": ["наштукатуривавши"],
    "наштукатуривавши": ["наштукатуривав"],
    "наштукатуривши": ["наштукатурив"],
    "нашумев": ["нашумевши"],
    "нашумевши": ["нашумев"],
    "нашумевший": ["сенсационный", "громкий", "знаменитый", "известный"],
    "нашутив": ["нашутивши"],
    "нашутивши": ["нашутив"],
    "нашчадак": ["патомак"],
    "нашъа": ["банг", "бангдона"],
    "нашёл дурака": ["разбежаться", "раскатать губу"],
    "нашёптывав": ["нашёптывавши"],
    "нашёптывавши": ["нашёптывав"],
    "нащеголяв": ["нащеголявши"],
    "нащеголявши": ["нащеголяв"],
    "нащеголять": ["нащеголяться"],
    "нащепав": ["нащепавши"],
    "нащепавши": ["нащепав"],
    "нащепив": ["нащепивши"],
    "нащепивши": ["нащепив"],
    "нащипав": ["нащипавши"],
    "нащипавши": ["нащипав"],
    "нащипывав": ["нащипывавши"],
    "нащипывавши": ["нащипывав"],
    "нащупав": ["нащупавши"],
    "нащупавши": ["нащупав"],
    "нащупывав": ["нащупывавши"],
    "нащупывавши": ["нащупывав"],
    "нащупывать": ["нашаривать"],
    "нащёлкав": ["нащёлкавши"],
    "нащёлкавши": ["нащёлкав"],
    "нащёлкивав": ["нащёлкивавши"],
    "нащёлкивавши": ["нащёлкивав"],
    "наэкономив": ["наэкономивши"],
    "наэкономивши": ["наэкономив"],
    "наэкспериментировав": ["наэкспериментировавши"],
    "наэкспериментировавши": ["наэкспериментировав"],
    "наэкспериментировать": ["наэкспериментироваться"],
    "наэкспериментироваться": ["наэкспериментировать"],
    "наэлектризовав": ["наэлектризовавши"],
    "наэлектризовавши": ["наэлектризовав"],
    "наэлектризовывав": ["наэлектризовывавши"],
    "наэлектризовывавши": ["наэлектризовывав"],
    "наябедничав": ["наябедничавши"],
    "наябедничавши": ["наябедничав"],
    "наяву": ["взаправду"],
    "наяда": ["русалка", "никса"],
    "наяривав": ["наяривавши"],
    "наяривавши": ["наяривав"],
    "наяривать": ["жать", "жарить", "чесать", "шпарить"],
    "наёб": ["надувательство", "наебаловка", "наебалово", "наебательство", "наёбка", "наебон", "наёбочка"],
    "наёбка": ["наебательство", "наёб", "наебаловка", "наебалово", "наебон", "наёбочка", "наебончик"],
    "наёбывав": ["наёбывавши"],
    "наёбывавши": ["наёбывав"],
    "наёбывать": ["наябывать"],
    "наём": ["найм", "аренда", "наёмка"],
    "наёмник": ["солдат удачи", "батрак", "арендатор"],
    "наёмничав": ["наёмничавши"],
    "наёмничавши": ["наёмничав"],
    "наёмничий": ["наёмный"],
    "наёмный рабочий": ["пролетарий", "наёмный работник", "наймит"],
    "наёмный убийца": ["киллер"],
    "нбамр": ["бамр"],
    "нвп": ["допризывный", "подготовка"],
    "нг": ["независимая газета", "новый год"],
    "нгала": ["лингала"],
    "нго": ["находкинский городской округ", "новоуральский городской округ"],
    "нгони": ["ангони", "мазиту", "мгвангара"],
    "ндфл": ["подоходный налог"],
    "не ахти": ["так себе", "не айс"],
    "не ахти как": ["так себе"],
    "не без основания": ["обоснованно"],
    "не благим матом": ["неистово", "исступлённо", "истошно", "благим матом", "лихим матом", "на лихой мат"],
    "не будь дурак": ["не промах", "парень не промах", "малый не промах"],
    "не в капусте найден": ["не лыком шит", "не в капусте подобран", "не пальцем делан", "не пальцем деланный"],
    "не в капусте подобран": ["не лыком шит", "не в капусте найден", "не пальцем делан", "не пальцем деланный"],
    "не в кассу": ["не к месту", "неуместно", "невпопад", "не ко времени"],
    "не в кипиш": ["тихо", "незаметно"],
    "не в пример": ["в отличие от"],
    "не в своей тарелке": ["неуютно", "некомфортно", "дискомфортно", "не в духе", "не в себе"],
    "не весть что": ["невесть что"],
    "не вовремя": ["несвоевременно"],
    "не вопрос": ["да", "конечно", "ещё бы", "согласный", "разумеется", "само собой", "легко", "хуйня вопрос", "просто", "пустяки", "пара пустяков", "раз плюнуть", "легче лёгкого", "запросто", "действительно"],
    "не все дома": ["ненормальный"],
    "не въебаться": ["не ебаться"],
    "не вязать лыка": ["лыка не вязать"],
    "не говоря худого слова": ["вдруг", "с бухты-барахты"],
    "не давать в обиду": ["заступаться", "защищать"],
    "не давать ходу": ["препятствовать", "мешать"],
    "не дай бог": ["не дай боже", "сохрани господи", "не приведи боже", "не приведи бог", "не дай господи", "сохрани боже", "не приведи господи", "сохрани бог", "упаси боже", "избави боже", "упаси бог", "упаси господи", "избави господи", "избави бог"],
    "не для чего": ["незачем", "не стоит"],
    "не ебаться": ["не въебаться"],
    "не за горами": ["скоро", "вскорости", "поблизости", "недалеко"],
    "не за что": ["не стоит благодарности", "пожалуйста", "на здоровье", "нет причины"],
    "не идёт в сравнение": ["не идёт ни в какое сравнение"],
    "не идёт ни в какое сравнение": ["не идёт в сравнение"],
    "не из чего": ["неоткуда", "незачем"],
    "не к спеху": ["время терпит", "не срочно", "успеется"],
    "не каплет": ["моя хата с краю"],
    "не климат": ["не климатит"],
    "не ко двору": ["не по двору"],
    "не лыком шит": ["не в капусте найден", "не в капусте подобран", "не пальцем делан", "не пальцем деланный"],
    "не находить себе места": ["маяться"],
    "не о чем": ["нечего"],
    "не одна я в поле кувыркалась": ["не одна я в сене кувыркалась", "я упала с сеновала"],
    "не одна я в сене кувыркалась": ["не одна я в поле кувыркалась"],
    "не пальцем делан": ["не лыком шит", "не в капусте найден", "не в капусте подобран", "не пальцем деланный"],
    "не пальцем деланный": ["не лыком шит", "не в капусте найден", "не в капусте подобран", "не пальцем делан"],
    "не по зубам": ["кишка тонка", "не в подъём", "не в силу", "не по плечу", "не под силу", "невпотяг", "свыше сил", "не по силам"],
    "не по себе": ["неуютно", "некомфортно"],
    "не по хуйне": ["нешуточно", "нешутейно", "не на шутку", "не по-детски"],
    "не по-детски": ["по-взрослому"],
    "не подлежит сомнению": ["несомненно"],
    "не покладая рук": ["без устали", "в поте лица"],
    "не помнить себя": ["едва помнить себя", "не в себе"],
    "не при чем": ["ни с чем", "с пустыми руками", "ни при чём"],
    "не пристало": ["негоже", "не дело"],
    "не пришей к пизде рукав": ["не пришей кобыле хвост", "ни к селу ни к городу"],
    "не пришей кобыле хвост": ["пришей кобыле хвост", "ни пришей ни пристегни", "не пришей рукав", "пришей пизде рукав", "пришей к пизде рукав", "не пришей пизде рукав", "не пришей к пизде рукав", "пришей пизде бубенчик", "пришей к пизде бубенчик", "не пришей пизде бубенчик", "не пришей к пизде бубенчик", "пришей пизде ушей", "пришей к пизде ушей", "не пришей пизде ушей", "не пришей к пизде ушей"],
    "не просто": ["непросто", "нелегко", "сложно"],
    "не прочь": ["не против", "согласен"],
    "не ровён час": ["неравно", "вдруг", "не дай бог", "не приведи боже", "мало ли что"],
    "не с руки": ["несподручно", "негоже", "не рука"],
    "не сегодня завтра": ["скоро", "сегодня-завтра"],
    "не сносить головы": ["не снести головы"],
    "не спеша": ["медленно", "неторопливо"],
    "не ставить ни в хуй": ["ни в хуй не ставить", "в хуй не ставить"],
    "не стоит": ["бессмысленно", "овчинка выделки не стоит", "нецелесообразно", "игра не стоит свеч", "неразумно"],
    "не стоит благодарности": ["не за что", "пожалуйста"],
    "не стоит труда": ["игра не стоит свеч"],
    "не стоять на месте": ["развиваться", "совершенствоваться"],
    "не суть": ["не суть важно"],
    "не суть важно": ["не суть"],
    "не считать хуй за мясо": ["хуй за мясо не считать"],
    "не тем будь помянут": ["не к ночи будь помянут"],
    "не терпеться": ["хотеться", "подмывать", "тянуть"],
    "не то пальто": ["невпопад", "не в склад", "не в тему"],
    "не то чтобы": ["не то чтоб"],
    "не тронь меня": ["недотрога", "стыдливая мимоза", "не-тронь-меня"],
    "не тут-то было": ["как бы не так", "ничуть не бывало"],
    "не уже ли": ["не уж то", "неужто", "в самом деле", "неужели"],
    "не учи учёного": ["яйца курицу не учат", "яйца задницу не учат"],
    "не фигура": ["не", "проблема", "легко"],
    "не фонтан": ["неважный", "неважнецкий", "второразрядный", "второсортный", "второстепенный", "не бог весть какой", "средней руки", "так себе", "не очень", "не ах", "не айс"],
    "не хуй": ["не хрен", "не хрена", "не хер", "не хера", "не хуя"],
    "не хуй делать": ["просто", "как нечего делать", "раз плюнуть", "проще пареной репы", "как дважды два", "как два пальца об асфальт", "как два байта переслать", "как два пальца обоссать", "что два пальца обоссать", "нехуй ссать", "как нехуй ссать", "как нахуй-нехуй", "как не хуй делать", "за не хуй делать"],
    "не хуй собачий": ["не хухры-мухры"],
    "не хухры-мухры": ["не", "абы", "что", "не кось-мось", "не хухлы-мухлы"],
    "не хуя": ["не хуй"],
    "не шутя": ["не на шутку", "без дураков", "по большому счёту", "на серьёз", "на полном серьёзе"],
    "не-а": ["нет", "отнюдь"],
    "не-тронь-меня": ["недотрога", "чертополох"],
    "неабелев": ["неабелевский"],
    "неадекват": ["сумасшедший", "умалишённый", "душевнобольной", "псих", "чудак"],
    "неадекватность": ["инадекватность", "несоответствие", "ненормальность"],
    "неадекватный": ["неподходящий", "неподобающий", "невменяемый", "ненормальный"],
    "неадкладна": ["спешна"],
    "неаккуратно": ["небрежно", "неопрятно", "грязно"],
    "неактуально": ["малоинтересно", "несовременно"],
    "неандерталец": ["палеоантроп", "человек неандертальский", "троглодит"],
    "неаристократический": ["неаристократичный", "плебейский"],
    "неаристократичный": ["плебейский"],
    "неатомный": ["неядерный"],
    "небанковская кредитная организация": ["нко"],
    "небаскроб": ["хмарачос"],
    "небат": ["осюмлик"],
    "небез-": ["небес-"],
    "небезкорисний": ["корисний"],
    "небезопасный": ["опасный"],
    "небезосновательный": ["небеспричинный", "небеспочвенный", "обоснованный"],
    "небезразлично": ["заинтересованно", "важно", "интересно"],
    "небезызвестный": ["пресловутый"],
    "небезынтересно": ["замечательно"],
    "небезынтересный": ["замечательный"],
    "небел": ["невель", "арфа"],
    "небережливый": ["неэкономный", "расточительный"],
    "небес-": ["небез-"],
    "небесное тело": ["астрономический объект", "космический объект"],
    "небесный": ["астрономический", "светло-голубой", "прекрасный", "восхитительный", "возвышенный", "чистый"],
    "небесплатный": ["платный"],
    "небесспорный": ["спорный", "сомнительный"],
    "небетхет": ["нефтида"],
    "небивалица": ["измислица", "басня"],
    "неблагожелательство": ["недоброжелательство", "неблагожелательность", "враждебность"],
    "неблагозвучие": ["неблагозвучность"],
    "неблагонадёжный": ["ненадёжный"],
    "неблагопристойно": ["неприлично"],
    "неблагоразумие": ["необдуманность"],
    "неближний": ["дальний", "далёкий"],
    "неблизкий": ["далёкий", "дальний"],
    "неблизко": ["далеко"],
    "небо": ["небеса", "небосвод", "небосклон", "поднебесье", "рай"],
    "небо коптить": ["прозябать"],
    "небогатый": ["бедный", "неимущий", "малоимущий", "нищий", "нуждающийся", "малообеспеченный", "необеспеченный", "скромный", "скудный", "ограниченный", "бедняк"],
    "небоеготовный": ["небоеспособный"],
    "небоеспособный": ["небоеготовный"],
    "небожитель": ["божество", "элита", "сливки", "аристократ"],
    "небожительница": ["богиня"],
    "небокрай": ["горизонт"],
    "небольшой": ["малый", "маленький", "незначительный"],
    "небосвод": ["небо", "небеса", "небосклон", "поднебесье"],
    "небосклон": ["небо", "небеса", "небосвод", "поднебесье"],
    "небоскрёб": ["многоэтажка", "высотка"],
    "небось": ["авось", "поди", "наверное", "пожалуй", "вероятно", "должно быть", "чай"],
    "небосяг": ["хмарочос"],
    "небрат": ["враг"],
    "небрежение": ["небрежность", "манкирование", "невнимание", "пренебрежение"],
    "небреженье": ["небрежение"],
    "небрежничав": ["небрежничавши"],
    "небрежничавши": ["небрежничав"],
    "небрежно": ["пренебрежительно", "беззаботно", "неряшливо", "неаккуратно", "халтурно"],
    "небрежность": ["неаккуратность"],
    "небрежный": ["нерадивый", "пренебрежительный", "неряшливый", "неаккуратный"],
    "небритость": ["щетина"],
    "неброский": ["неприметный"],
    "небывалый": ["невиданный", "неслыханный", "беспрецедентный", "беспримерный", "вымышленный", "фантастический"],
    "небывальщина": ["чудеса", "невероятный случай", "небылица", "небывальщинка"],
    "небывальщинка": ["небывальщина"],
    "небыдло": ["сноб"],
    "небылица": ["выдумка", "вымысел", "домысел", "враньё", "сказка"],
    "небыль": ["небылица", "сказка", "вымысел", "сплетня", "небытие"],
    "небыстрый": ["медленный"],
    "небытие": ["несуществование", "ничто"],
    "небытьё": ["небытие"],
    "невада": ["серебряный штат"],
    "неважнецки": ["неважно", "хреновато"],
    "неважный": ["незначительный", "несущественный"],
    "невалидност": ["недействителност"],
    "невалидный": ["недостоверный", "недопустимый", "неприемлемый", "недействительный", "неправильный", "ошибочный"],
    "неваляшка": ["ванька-встанька"],
    "невблагальний": ["невблаганний"],
    "невблаганний": ["невблагальний"],
    "невдалеке": ["неподалёку", "вблизи", "поблизости", "близко", "недалеко"],
    "невдоволення": ["незадоволення"],
    "невдогад": ["невдомёк"],
    "невдолге": ["вскорости", "вскоре", "скоро"],
    "невдомёк": ["невдогад"],
    "невеглас": ["невежда", "неуч"],
    "неведение": ["незнание", "неосведомлённость"],
    "неведомая ёбаная хуйня": ["нёх"],
    "неведомо": ["невесть", "незнамо", "неизвестно"],
    "неведомый": ["неизвестный", "таинственный", "непостижимый"],
    "невежа": ["грубиян", "мужлан", "плебей", "шариков", "обормот", "охламон", "скотина", "хам", "хамло", "лапоть", "простец", "троглодит", "невоспитанный", "некультурный", "неотёсанный"],
    "невежда": ["неуч", "недоучка", "профан"],
    "невежественность": ["некомпетентность", "необразованность", "неграмотность", "неотёсанность"],
    "невежественный": ["безграмотный", "дремучий", "лапотный", "малограмотный", "малознающий", "малокомпетентный", "малокультурный", "малообразованный", "малосведущий", "неграмотный", "некомпетентный", "необразованный", "непросвещённый", "неразвитой", "неразвитый"],
    "невежество": ["необразованность", "темнота", "невежливость", "бескультурье"],
    "невежливость": ["грубость", "неучтивость"],
    "невежливый": ["грубый", "неучтивый"],
    "невежничав": ["невежничавши"],
    "невежничавши": ["невежничав"],
    "невезение": ["невезуха", "непруха", "неудача"],
    "невезучесть": ["неудачливость"],
    "невезучий": ["неудачливый"],
    "невелика премудрость": ["эка невидаль"],
    "невеликий": ["малый"],
    "неверие": ["неуверенность", "атеизм", "безверие"],
    "неверно": ["неправильно", "ошибочно", "нетвёрдо", "неуверенно", "неровно"],
    "неверность": ["неправильность", "ошибочность", "вероломность", "нетвёрдость", "неуверенность"],
    "неверный": ["ложный", "ошибочный", "вероломный", "нетвёрдый", "неуверенный", "неустойчивый", "слабый", "неровный", "колеблющийся", "сомнительный", "обманчивый", "ненадёжный", "неверующий", "иноверец"],
    "невероподобный": ["недостоверный", "неправдоподобный"],
    "невероятный": ["неправдоподобный", "чрезвычайный", "поразительный"],
    "неверующая": ["атеистка"],
    "неверье": ["неверие"],
    "неверяще": ["недоверчиво"],
    "невесело": ["грустно"],
    "невеста": ["девушка"],
    "невестка": ["невестушка", "жена сына", "сноха", "сыновка", "сыноха", "жена брата", "братова", "золовка", "свояченица", "молодуха", "невеса"],
    "невесть": ["неведомо", "не", "ведать"],
    "невесть что": ["не весть что"],
    "невесёлый": ["грустный", "печальный"],
    "невечный": ["преходящий", "тленный", "недолговечный", "бренный", "неокончательный"],
    "невещественный": ["нематериальный", "духовный"],
    "невзаимность": ["безответность"],
    "невзаправдашний": ["ненастоящий", "неподлинный", "поддельный"],
    "невзвидев": ["невзвидевши"],
    "невзвидевши": ["невзвидев"],
    "невзгода": ["беда", "горесть", "терние"],
    "невзирая на": ["несмотря на", "независимо от"],
    "невзлюбив": ["невзлюбивши"],
    "невзлюбивши": ["невзлюбив"],
    "невзначай": ["ненароком", "случайно", "неумышленно"],
    "невзрачный": ["некрасивый", "невзорный", "невзглядный", "неказистый"],
    "невзыскательно": ["снисходительно"],
    "невзыскательность": ["снисхождение"],
    "невзыскательный": ["нетребовательный"],
    "невидаль": ["невидальщина"],
    "невиданный": ["неслыханный", "небывалый"],
    "невидимый": ["незримый"],
    "невидный": ["видимый", "знатный"],
    "невинный": ["невиновный", "безвинный", "безобидный", "наивный", "простодушный"],
    "невитое сено": ["неповитое сено"],
    "невкусно": ["безвкусно", "несъедобно", "малосъедобно", "неаппетитно"],
    "невкусный": ["неаппетитный"],
    "невловимий": ["неуловний"],
    "невменоз": ["коматоз", "невменяемость"],
    "невместно": ["негоже", "не дело", "неуместно", "неприлично"],
    "невмоготу": ["невмочь", "нестерпимо", "невтерпёж"],
    "невмочь": ["невмоготу"],
    "невнимание": ["невнимательность", "рассеянность", "равнодушие", "пренебрежение"],
    "невнимательно": ["рассеянно"],
    "невнимательность": ["рассеянность", "невнимание"],
    "невнимательный": ["рассеянный"],
    "невнятность": ["неопределённость"],
    "невнятный": ["неясный", "непонятный", "невразумительный"],
    "невовремя": ["несвоевременно", "некстати"],
    "невод": ["аламан", "лампара", "скипасть", "частик", "кловня", "жак", "илым", "ильменка", "приволочка", "ставник", "тагас", "тоня", "харва"],
    "неводив": ["неводивши"],
    "неводивши": ["неводив"],
    "невозбранно": ["беспрепятственно", "свободно"],
    "невозвратимый": ["невозвратный"],
    "невозвратный": ["безвозвратный"],
    "невозвращенец": ["перебежчик"],
    "невозвращенчество": ["невозвращение"],
    "невозвращенье": ["невозвращение"],
    "невоздержание": ["неумеренность", "невоздержанность", "несдержанность"],
    "невоздержанный": ["невоздержный"],
    "невозможно": ["недопустимо", "исключено", "невыносимо", "нельзя"],
    "невозможность": ["неосуществимость", "невыполнимость"],
    "невозмутимо": ["спокойно"],
    "невозмутимость": ["спокойствие"],
    "невознаградимый": ["невосполнимый", "невозместимый"],
    "неволив": ["неволивши"],
    "неволивши": ["неволив"],
    "неволить": ["заставлять", "принуждать", "вынуждать"],
    "невольник": ["раб", "пленник", "заключённый", "арестант", "узник"],
    "невольница": ["раба", "рабыня", "илотка", "пленница", "яремница"],
    "невольнический": ["невольничий"],
    "невольничий": ["невольнический"],
    "невольно": ["непреднамеренно", "нечаянно", "случайно", "непроизвольно", "бессознательно", "неумышленно", "без умысла", "противувольно"],
    "невольный": ["случайный", "вынужденный", "непроизвольный"],
    "неволя": ["несвобода", "кабала", "рабство", "плен", "полон", "необходимость", "нужда"],
    "невообразимо": ["немыслимо"],
    "невообразимость": ["немыслимость"],
    "невообразимый": ["немыслимый", "непредставимый", "несусветный"],
    "невооружённый": ["безоружный"],
    "невоплотимость": ["неисполнимость"],
    "невоспитанность": ["бескультурье", "необразованность", "неотёсанность", "дикарство", "невежливость"],
    "невоспитанный": ["некультурный", "неотёсанный"],
    "невоспроизводимый": ["невосстановимый", "невозобновляемый", "неповторимый"],
    "невоссоздаваемый": ["невозобновляемый", "невоспроизводимый"],
    "невостребованность": ["ненужность"],
    "невпинний": ["неупинний"],
    "невпроворот": ["много", "куча", "полно"],
    "невпротык": ["невпроворот"],
    "невр": ["нёвр"],
    "невразумительный": ["непонятный", "неясный"],
    "неврастения": ["астенический невроз", "нервная слабость"],
    "невредимый": ["целый"],
    "невредный": ["безвредный", "безопасный", "безобидный", "незлобивый", "сносный", "неплохой", "нормальный"],
    "невринома": ["шваннома", "шванноглиома", "неврилеммома", "нейринома", "леммобластома"],
    "невроз": ["психоневроз"],
    "невролиз": ["нейролиз"],
    "невролог": ["невропатолог"],
    "неврология": ["нейрология"],
    "невропат": ["нейропат"],
    "невропатия": ["нейропатия"],
    "невропатка": ["нейропатка"],
    "невропатолог": ["нейропатолог", "невролог"],
    "невропатологический": ["нейропатологический"],
    "невропатология": ["нейропатология"],
    "невротизировав": ["невротизировавши"],
    "невротизировавши": ["невротизировав"],
    "невротизировать": ["нервировать"],
    "невротизм": ["нейротизм"],
    "невротик": ["невропат", "нервнобольной", "ненормальный", "псих"],
    "невская губа": ["маркизова лужа"],
    "невский": ["невский проспект"],
    "невтерпёж": ["невмоготу", "невыносимо"],
    "невус": ["невоидная опухоль", "родинка"],
    "невчкн": ["невчк"],
    "невшатель": ["нёшатель"],
    "невъебенность": ["замечательность", "великолепность", "восхитительность", "изумительность", "офигительность", "офигенность", "охренительность", "охеренность", "охуительность", "охуетительность", "охуенность", "пиздатость", "опизденительность"],
    "невъебенный": ["охуительный", "охуенный", "невзъебенный"],
    "невыгодно": ["разорительно", "проигрышно"],
    "невыдуманный": ["невымышленный"],
    "невыездной": ["отказник"],
    "невыживание": ["гибель", "смерть"],
    "невымышленный": ["невыдуманный"],
    "невыносимо": ["непереносимо"],
    "невыносимый": ["непереносимый", "нестерпимый"],
    "невыплаканный": ["непролитый", "неизлитый"],
    "невыполнимый": ["неисполнимый"],
    "невыпущенный": ["невышедший"],
    "невырабатываемый": ["недоступный"],
    "невыраженность": ["невысказанность"],
    "невыразимо": ["неописуемо"],
    "невыразимый": ["неизъяснимый", "неописуемый", "непередаваемый", "несказанный", "неизреченный"],
    "невыразительность": ["бесцетность"],
    "невыразительный": ["тусклый", "серый"],
    "невысказанный": ["невыраженный", "неизглаголанный"],
    "невысокий": ["низкий", "небольшой", "низкорослый"],
    "невысоконравственный": ["низконравственный", "невысокоморальный"],
    "невысокообразованный": ["недоученный"],
    "невысокооплачиваемый": ["низкооплачиваемый", "малооплачиваемый"],
    "невышедший": ["невыпущенный"],
    "невязка": ["неувязка"],
    "невяра": ["съмнение", "колебание"],
    "нега": ["довольство", "беззаботность", "сладкая жизнь", "удовольствие", "нежность", "мягкость", "ласковость", "деликатность", "сентиментальность", "тонкость", "добросердечность"],
    "негабаритчик": ["водитель"],
    "негада": ["нубт", "омбос"],
    "негаданно": ["нежданно"],
    "негаснущий": ["неугасимый", "светящий"],
    "негатив": ["раздражение"],
    "негатрон": ["электрон"],
    "негашёная известь": ["оксид кальция"],
    "негде пробу ставить": ["пробы негде ставить", "пробу ставить некуда", "прожжённый"],
    "негерметический": ["проницаемый"],
    "негидалец": ["орочон"],
    "негласно": ["тайно", "конфиденциально", "неофициально"],
    "неглиже": ["дезабилье"],
    "неглижировав": ["неглижировавши"],
    "неглижировавши": ["неглижировав"],
    "неглижировать": ["пренебрегать", "пренебречь"],
    "неглинка": ["неглинная"],
    "неглинная": ["неглинка", "неглинна", "неглимна", "самотёка"],
    "неглубокий": ["мелкий", "поверхностный"],
    "неглубоко": ["мелко"],
    "неглубокость": ["мелкость"],
    "неглупый": ["умный"],
    "негнущийся": ["несгибаемый", "несгибающийся", "негибкий"],
    "негодник": ["проказник", "паршивец", "плут"],
    "негодный": ["старый", "ненужный", "некачественный", "гадкий", "дрянной"],
    "негодовав": ["негодовавши"],
    "негодовавши": ["негодовав"],
    "негодование": ["возмущение", "злость", "ярость"],
    "негодованье": ["негодование"],
    "негодовать": ["возмущаться"],
    "негодующе": ["возмущенно", "раздражённо"],
    "негодующий": ["возмущённый"],
    "негодяй": ["мерзавец", "подлец"],
    "негодящий": ["непригодный", "негодный", "неподходящий"],
    "негоже": ["плохо", "дурно", "неподходяще", "неприемлемо", "не след"],
    "негомогенный": ["неоднородный", "разнородный"],
    "негордий": ["негордовитий", "доступний"],
    "негорячий": ["прохладный"],
    "негостеприимный": ["неприветливый", "нерадушный", "враждебный"],
    "негосударственный": ["частный"],
    "неготовый": ["неподготовленный", "незрелый", "недоделанный"],
    "негоциант": ["купец"],
    "негр": ["негроид", "чернокожий", "темнокожий", "арап", "черномазый", "негритос", "ниггер", "черножопый", "раб"],
    "негражданин": ["негр"],
    "неграмотно": ["безграмотно"],
    "неграмотный": ["безграмотный", "малограмотный", "полуграмотный"],
    "негритос": ["ниггер", "негр"],
    "негритянка": ["чернокожая"],
    "негроид": ["негр", "мавр", "африканец", "афроамериканец"],
    "негромкий": ["тихий"],
    "негромко": ["тихо"],
    "негропонт": ["эвбея"],
    "негрофобия": ["афрофобия"],
    "негуманно": ["жестоко"],
    "недавний": ["новый", "поздний", "последний"],
    "недалеко": ["неподалёку", "вблизи", "поблизости", "близко", "невдалеке"],
    "недалечко": ["недалече", "близёхонько"],
    "недальний": ["недалёкий", "близкий", "близлежащий", "недавний", "короткий", "быстрый", "недолгий", "глупый"],
    "недальновидный": ["непредусмотрительный"],
    "недалёкий": ["близкий", "ближний", "близлежащий", "окрестный", "глуповатый", "простоватый"],
    "недаровым матом": ["благим матом", "божьим матом", "дурным матом", "лихим матом", "непутным матом"],
    "недаром": ["обоснованно", "неслучайно", "с умыслом", "небезрезультатно", "не зря"],
    "недвига": ["недвижимость"],
    "недвижимо": ["неподвижно"],
    "недвижимое имущество": ["недвижимость"],
    "недвижимость": ["недвижимое имущество", "недвижка", "недвига"],
    "недвижимый": ["неподвижный"],
    "недвижка": ["недвижимое имущество", "недвижимость", "недвига"],
    "недвоичность": ["небинарность"],
    "недвойственный": ["непротиворечивый", "недвоякий"],
    "недвоякий": ["недвойной", "недвойственный"],
    "недвусмысленно": ["однозначно"],
    "недвусмысленный": ["однозначный"],
    "недействительный": ["неэффективный"],
    "неделанье": ["неделание"],
    "недельный": ["семидневный", "однонедельный"],
    "неделя": ["седмица"],
    "неденежный": ["немонетарный"],
    "недержанье": ["недержание"],
    "недешевий": ["дорогий"],
    "недешёвый": ["дорогой", "ценный"],
    "недеяние": ["бездействие", "ничегонеделание"],
    "недеянье": ["недеяние"],
    "недлинный": ["короткий", "коротковатый"],
    "недобдев": ["недобдевши"],
    "недобдевши": ["недобдев"],
    "недобдеть": ["недосмотреть"],
    "недобив": ["недобивши"],
    "недобивав": ["недобивавши"],
    "недобивавши": ["недобивав"],
    "недобивши": ["недобив"],
    "недобирав": ["недобиравши"],
    "недобиравши": ["недобирав"],
    "недобор": ["недоимка"],
    "недоборщить": ["недоделать"],
    "недобрав": ["недобравши"],
    "недобравши": ["недобрав"],
    "недобрасывав": ["недобрасывавши"],
    "недобрасывавши": ["недобрасывав"],
    "недобрив": ["недобривши"],
    "недобривав": ["недобривавши"],
    "недобривавши": ["недобривав"],
    "недобривши": ["недобрив"],
    "недобро": ["неласково", "неприветливо"],
    "недоброжелательность": ["недоброжелательство", "недружелюбность", "враждебность"],
    "недоброжелательство": ["враждебность", "недоброжелательность", "неприязнь", "ненависть", "недружелюбие"],
    "недоброжелательствовав": ["недоброжелательствовавши"],
    "недоброжелательствовавши": ["недоброжелательствовав"],
    "недоброжелательствовать": ["недоброхотствовать"],
    "недобросив": ["недобросивши"],
    "недобросивши": ["недобросив"],
    "недобросовестность": ["нерадивость", "халатность"],
    "недоброхотствовав": ["недоброхотствовавши"],
    "недоброхотствовавши": ["недоброхотствовав"],
    "недоброхотствовать": ["недоброжелательствовать"],
    "недобрый": ["злой", "недоброжелательный"],
    "недоваливав": ["недоваливавши"],
    "недоваливавши": ["недоваливав"],
    "недоварив": ["недоваривши"],
    "недоваривав": ["недоваривавши"],
    "недоваривавши": ["недоваривав"],
    "недоваривши": ["недоварив"],
    "недовезя": ["недовёзши"],
    "недоверие": ["сомнение", "подозрение"],
    "недовернув": ["недовернувши"],
    "недовернувши": ["недовернув"],
    "недоверстав": ["недоверставши"],
    "недоверставши": ["недоверстав"],
    "недоверчиво": ["подозрительно"],
    "недоверчивый": ["подозрительный"],
    "недоверье": ["недоверие"],
    "недовесив": ["недовесивши"],
    "недовесивши": ["недовесив"],
    "недовешивав": ["недовешивавши"],
    "недовешивавши": ["недовешивав"],
    "недовешивать": ["обвешивать"],
    "недовзыскав": ["недовзыскавши"],
    "недовзыскавши": ["недовзыскав"],
    "недовзыскивав": ["недовзыскивавши"],
    "недовзыскивавши": ["недовзыскивав"],
    "недовидев": ["недовидевши"],
    "недовидевши": ["недовидев"],
    "недовложение": ["недозакладка"],
    "недовложив": ["недовложивши"],
    "недовложивши": ["недовложив"],
    "недовозив": ["недовозивши"],
    "недовозивши": ["недовозив"],
    "недовольно": ["сердито", "неудовлетворённо", "неохотно", "озлобленно"],
    "недовольный": ["неудовлетворённый"],
    "недовольство": ["неудовольствие", "неудовлетворение", "неудовлетворённость"],
    "недовоспитав": ["недовоспитавши"],
    "недовоспитавши": ["недовоспитав"],
    "недовоспитывав": ["недовоспитывавши"],
    "недовоспитывавши": ["недовоспитывав"],
    "недовыделив": ["недовыделивши"],
    "недовыделивши": ["недовыделив"],
    "недовынув": ["недовынувши"],
    "недовынувши": ["недовынув"],
    "недовыполнив": ["недовыполнивши"],
    "недовыполнивши": ["недовыполнив"],
    "недовыполняв": ["недовыполнявши"],
    "недовыполнявши": ["недовыполняв"],
    "недовыпускав": ["недовыпускавши"],
    "недовыпускавши": ["недовыпускав"],
    "недовыпустив": ["недовыпустивши"],
    "недовыпустивши": ["недовыпустив"],
    "недовырабатывав": ["недовырабатывавши"],
    "недовырабатывавши": ["недовырабатывав"],
    "недовыработав": ["недовыработавши"],
    "недовыработавши": ["недовыработав"],
    "недовыработка": ["недоделка"],
    "недовыручав": ["недовыручавши"],
    "недовыручавши": ["недовыручав"],
    "недовыручив": ["недовыручивши"],
    "недовыручивши": ["недовыручив"],
    "недовязав": ["недовязавши"],
    "недовязавши": ["недовязав"],
    "недовязывав": ["недовязывавши"],
    "недовязывавши": ["недовязывав"],
    "недовёзши": ["недовезя"],
    "недовёрстывав": ["недовёрстывавши"],
    "недовёрстывавши": ["недовёрстывав"],
    "недовёртывав": ["недовёртывавши"],
    "недовёртывавши": ["недовёртывав"],
    "недовёртываемый": ["недокручиваемый"],
    "недоглушив": ["недоглушивши"],
    "недоглушивши": ["недоглушив"],
    "недоглядев": ["недоглядевши"],
    "недоглядевши": ["недоглядев"],
    "недоглядеть": ["пропустить", "недосмотреть"],
    "недоглядывав": ["недоглядывавши"],
    "недоглядывавши": ["недоглядывав"],
    "недоговаривав": ["недоговаривавши"],
    "недоговаривавши": ["недоговаривав"],
    "недоговаривание": ["умалчивание"],
    "недоговорив": ["недоговоривши"],
    "недоговоривши": ["недоговорив"],
    "недоговорка": ["недомолвка", "недосказанность"],
    "недоговорённость": ["недосказанность"],
    "недогружав": ["недогружавши"],
    "недогружавши": ["недогружав"],
    "недогруз": ["недогрузка"],
    "недогрузив": ["недогрузивши"],
    "недогрузивши": ["недогрузив"],
    "недогрузка": ["недогруз"],
    "недодав": ["недодавши"],
    "недодавав": ["недодававши"],
    "недодававши": ["недодавав"],
    "недодавать": ["удерживать", "недовыпускать", "недопроизводить"],
    "недодавив": ["недодавивши"],
    "недодавивши": ["недодавив"],
    "недодавши": ["недодав"],
    "недодать": ["удержать", "недовыпустить", "недопроизвести"],
    "недоделав": ["недоделавши"],
    "недоделавши": ["недоделав"],
    "недоделанный": ["незаконченный", "растяпа", "разгильдяй", "глупец", "тупица", "этакий", "чёртов", "хренов", "хуев", "неполноценный"],
    "недоделка": ["недодел"],
    "недоделок": ["незаконнорожденный", "нагулянный", "недоделыш", "выблядок"],
    "недоделывав": ["недоделывавши"],
    "недоделывавши": ["недоделывав"],
    "недодержав": ["недодержавши"],
    "недодержавши": ["недодержав"],
    "недодержание": ["недодержка", "несоблюдение", "нарушение"],
    "недодержання": ["недотримання"],
    "недодерживав": ["недодерживавши"],
    "недодерживавши": ["недодерживав"],
    "недодумав": ["недодумавши"],
    "недодумавши": ["недодумав"],
    "недодумывав": ["недодумывавши"],
    "недодумывавши": ["недодумывав"],
    "недоедав": ["недоедавши"],
    "недоедавши": ["недоедав"],
    "недоеданье": ["недоедание"],
    "недоедать": ["голодать"],
    "недожав": ["недожавши"],
    "недожавши": ["недожав"],
    "недожарив": ["недожаривши"],
    "недожаривав": ["недожаривавши"],
    "недожаривавши": ["недожаривав"],
    "недожаривши": ["недожарив"],
    "недожать": ["недодавить"],
    "недожигав": ["недожигавши"],
    "недожигавши": ["недожигав"],
    "недожимав": ["недожимавши"],
    "недожимавши": ["недожимав"],
    "недожинав": ["недожинавши"],
    "недожинавши": ["недожинав"],
    "недозагрузка": ["недозагруженность"],
    "недозакладка": ["недовложение"],
    "недозарядив": ["недозарядивши"],
    "недозарядивши": ["недозарядив"],
    "недозволенный": ["незаконный", "противозаконный", "неправомерный", "противоправный", "преступный", "запрещённый", "нелегальный", "запретный", "воспрещённый"],
    "недозволительный": ["непозволительный", "недопустимый"],
    "недозрев": ["недозревши"],
    "недозревав": ["недозревавши"],
    "недозревавши": ["недозревав"],
    "недозревши": ["недозрев"],
    "недоиграв": ["недоигравши"],
    "недоигравши": ["недоиграв"],
    "недоигрывав": ["недоигрывавши"],
    "недоигрывавши": ["недоигрывав"],
    "недоиспользовав": ["недоиспользовавши"],
    "недоиспользовавши": ["недоиспользовав"],
    "недоиспользование": ["недопотребление"],
    "недоказанный": ["неподтверждённый"],
    "недокалив": ["недокаливши"],
    "недокаливав": ["недокаливавши"],
    "недокаливавши": ["недокаливав"],
    "недокаливши": ["недокалив"],
    "недокармливав": ["недокармливавши"],
    "недокармливавши": ["недокармливав"],
    "недоквасив": ["недоквасивши"],
    "недоквасивши": ["недоквасив"],
    "недоквашивав": ["недоквашивавши"],
    "недоквашивавши": ["недоквашивав"],
    "недокидывав": ["недокидывавши"],
    "недокидывавши": ["недокидывав"],
    "недокинув": ["недокинувши"],
    "недокинувши": ["недокинув"],
    "недокись": ["субоксид", "недоокись", "подокись", "второкись"],
    "недокопав": ["недокопавши"],
    "недокопавши": ["недокопав"],
    "недокорм": ["недокормка"],
    "недокормив": ["недокормивши"],
    "недокормивши": ["недокормив"],
    "недокосив": ["недокосивши"],
    "недокосивши": ["недокосив"],
    "недокрут": ["недокручивание"],
    "недокручивать": ["недовёртывать"],
    "недолавливав": ["недолавливавши"],
    "недолавливавши": ["недолавливав"],
    "недолга": ["всё", "конец"],
    "недолговременно": ["кратковременно"],
    "недолежав": ["недолежавши"],
    "недолежавши": ["недолежав"],
    "недолепив": ["недолепивши"],
    "недолепивши": ["недолепив"],
    "недолечив": ["недолечивши"],
    "недолечивав": ["недолечивавши"],
    "недолечивавши": ["недолечивав"],
    "недолечивши": ["недолечив"],
    "недоливав": ["недоливавши"],
    "недоливавши": ["недоливав"],
    "недоливши": ["недолив"],
    "недоловив": ["недоловивши"],
    "недоловивши": ["недоловив"],
    "недолюбливав": ["недолюбливавши"],
    "недолюбливавши": ["недолюбливав"],
    "недолюд": ["недолюдок"],
    "недолюдок": ["недолюд"],
    "недоля": ["недолюшка"],
    "недолёживав": ["недолёживавши"],
    "недолёживавши": ["недолёживав"],
    "недомачивав": ["недомачивавши"],
    "недомачивавши": ["недомачивав"],
    "недомерив": ["недомеривши"],
    "недомеривав": ["недомеривавши"],
    "недомеривавши": ["недомеривав"],
    "недомеривши": ["недомерив"],
    "недомеряв": ["недомерявши"],
    "недомерявши": ["недомеряв"],
    "недомогав": ["недомогавши"],
    "недомогавши": ["недомогав"],
    "недомогание": ["нездоровье", "плохое самочувствие"],
    "недомоганье": ["недомогание"],
    "недомогать": ["хворать", "болеть"],
    "недомолвив": ["недомолвивши"],
    "недомолвивши": ["недомолвив"],
    "недомолвить": ["недосказать", "недоговорить"],
    "недомолвка": ["недосказанность", "недоговорка", "недоговорённость"],
    "недомыв": ["недомывши"],
    "недомывав": ["недомывавши"],
    "недомывавши": ["недомывав"],
    "недомывши": ["недомыв"],
    "недонашивав": ["недонашивавши"],
    "недонашивавши": ["недонашивав"],
    "недоносив": ["недоносивши"],
    "недоносивши": ["недоносив"],
    "недоносок": ["недоношенный ребёнок", "недоношенец"],
    "недооблагав": ["недооблагавши"],
    "недооблагавши": ["недооблагав"],
    "недообложив": ["недообложивши"],
    "недообложивши": ["недообложив"],
    "недооборудовав": ["недооборудовавши"],
    "недооборудовавши": ["недооборудовав"],
    "недообследовав": ["недообследовавши"],
    "недообследовавши": ["недообследовав"],
    "недоосвоив": ["недоосвоивши"],
    "недоосвоивши": ["недоосвоив"],
    "недооформив": ["недооформивши"],
    "недооформивши": ["недооформив"],
    "недооценив": ["недооценивши"],
    "недооценивав": ["недооценивавши"],
    "недооценивавши": ["недооценивав"],
    "недооценивать": ["преуменьшать"],
    "недооценивши": ["недооценив"],
    "недооценённость": ["недооценка"],
    "недоочистив": ["недоочистивши"],
    "недоочистивши": ["недоочистив"],
    "недопаивав": ["недопаивавши"],
    "недопаивавши": ["недопаивав"],
    "недопарив": ["недопаривши"],
    "недопаривши": ["недопарив"],
    "недопахав": ["недопахавши"],
    "недопахавши": ["недопахав"],
    "недопахивав": ["недопахивавши"],
    "недопахивавши": ["недопахивав"],
    "недопаяв": ["недопаявши"],
    "недопаявши": ["недопаяв"],
    "недопекав": ["недопекавши"],
    "недопекавши": ["недопекав"],
    "недоперепив": ["недоперепивши"],
    "недоперепивши": ["недоперепив"],
    "недопив": ["недопивши"],
    "недопивав": ["недопивавши"],
    "недопивавши": ["недопивав"],
    "недопивать": ["допивать"],
    "недопивши": ["недопив"],
    "недописав": ["недописавши"],
    "недописавши": ["недописав"],
    "недописывав": ["недописывавши"],
    "недописывавши": ["недописывав"],
    "недоплатив": ["недоплативши"],
    "недоплативши": ["недоплатив"],
    "недоплатить": ["недовыплатить"],
    "недоплачивав": ["недоплачивавши"],
    "недоплачивавши": ["недоплачивав"],
    "недопоив": ["недопоивши"],
    "недопоивши": ["недопоив"],
    "недополучав": ["недополучавши"],
    "недополучавши": ["недополучав"],
    "недополучив": ["недополучивши"],
    "недополучивши": ["недополучив"],
    "недопонимав": ["недопонимавши"],
    "недопонимавши": ["недопонимав"],
    "недопонимание": ["недоразумение"],
    "недопоняв": ["недопонявши"],
    "недопонявши": ["недопоняв"],
    "недопоставив": ["недопоставивши"],
    "недопоставивши": ["недопоставив"],
    "недопоставляв": ["недопоставлявши"],
    "недопоставлявши": ["недопоставляв"],
    "недопродав": ["недопродавши"],
    "недопродавав": ["недопродававши"],
    "недопродававши": ["недопродавав"],
    "недопродавши": ["недопродав"],
    "недопуск": ["недопущение"],
    "недопустимий": ["недопустний"],
    "недопустимость": ["непозволительность", "неприемлемость"],
    "недопустимый": ["непозволительный"],
    "недопёсок": ["недопесь", "недокунь", "недолисок"],
    "недорабатывав": ["недорабатывавши"],
    "недорабатывавши": ["недорабатывав"],
    "недоработав": ["недоработавши"],
    "недоработавши": ["недоработав"],
    "недоразведав": ["недоразведавши"],
    "недоразведавши": ["недоразведав"],
    "недоразвив": ["недоразвивши"],
    "недоразвивав": ["недоразвивавши"],
    "недоразвивавши": ["недоразвивав"],
    "недоразвивши": ["недоразвив"],
    "недоразвитие": ["дисгенезия", "дисплазия"],
    "недоразвитый": ["недоразвившийся"],
    "недоразрушив": ["недоразрушивши"],
    "недоразрушивши": ["недоразрушив"],
    "недоразрядив": ["недоразрядивши"],
    "недоразрядивши": ["недоразрядив"],
    "недоразумев": ["недоразумевши"],
    "недоразумевав": ["недоразумевавши"],
    "недоразумевавши": ["недоразумевав"],
    "недоразумевши": ["недоразумев"],
    "недоразумение": ["недопонимание", "путаница", "ошибка"],
    "недоразуменье": ["недоразумение"],
    "недорезав": ["недорезавши"],
    "недорезавши": ["недорезав"],
    "недореформировав": ["недореформировавши"],
    "недореформировавши": ["недореформировав"],
    "недорисовав": ["недорисовавши"],
    "недорисовавши": ["недорисовав"],
    "недорисовывав": ["недорисовывавши"],
    "недорисовывавши": ["недорисовывав"],
    "недорого": ["дёшево"],
    "недорогой": ["дешёвый"],
    "недород": ["неурожай"],
    "недородный": ["неурожайный"],
    "недоросток": ["подросток"],
    "недорубив": ["недорубивши"],
    "недорубивши": ["недорубив"],
    "недосаливав": ["недосаливавши"],
    "недосаливавши": ["недосаливав"],
    "недосевав": ["недосевавши"],
    "недосевавши": ["недосевав"],
    "недосеивав": ["недосеивавши"],
    "недосеивавши": ["недосеивав"],
    "недосеяв": ["недосеявши"],
    "недосеявши": ["недосеяв"],
    "недосидев": ["недосидевши"],
    "недосидевши": ["недосидев"],
    "недосиживав": ["недосиживавши"],
    "недосиживавши": ["недосиживав"],
    "недосказав": ["недосказавши"],
    "недосказавши": ["недосказав"],
    "недосказанность": ["недомолвка", "недоговорка", "недоговорённость"],
    "недосказывав": ["недосказывавши"],
    "недосказывавши": ["недосказывав"],
    "недосказывать": ["недоговаривать", "умалчивать"],
    "недослав": ["недославши"],
    "недославши": ["недослав"],
    "недослушав": ["недослушавши"],
    "недослушавши": ["недослушав"],
    "недослушивав": ["недослушивавши"],
    "недослушивавши": ["недослушивав"],
    "недослышав": ["недослышавши"],
    "недослышавши": ["недослышав"],
    "недосматривав": ["недосматривавши"],
    "недосматривавши": ["недосматривав"],
    "недосматривать": ["недоглядывать"],
    "недосмотрев": ["недосмотревши"],
    "недосмотревши": ["недосмотрев"],
    "недосмотреть": ["недоглядеть"],
    "недособрав": ["недособравши"],
    "недособравши": ["недособрав"],
    "недосоленный": ["недосолённый"],
    "недосолив": ["недосоливши"],
    "недосоливши": ["недосолив"],
    "недосолённый": ["недосоленный"],
    "недоспав": ["недоспавши"],
    "недоспавши": ["недоспав"],
    "недоспев": ["недоспевши"],
    "недоспевав": ["недоспевавши"],
    "недоспевавши": ["недоспевав"],
    "недоспевши": ["недоспев"],
    "недоспорив": ["недоспоривши"],
    "недоспоривши": ["недоспорив"],
    "недостав": ["недоставши"],
    "недоставав": ["недостававши"],
    "недостававши": ["недоставав"],
    "недоставши": ["недостав"],
    "недостаток": ["дефект", "изъян", "недочёт", "порок", "нехватка", "отсутствие"],
    "недостаточность": ["недостаток", "дефицит"],
    "недостаточный": ["неполный", "ущербный", "неудовлетворительный", "неосновательный"],
    "недостача": ["нехватка", "растрата"],
    "недостающий": ["отсутствующий"],
    "недостижимый": ["недоступный", "недосягаемый", "непревзойдённый"],
    "недостраивав": ["недостраивавши"],
    "недостраивавши": ["недостраивав"],
    "недостреливав": ["недостреливавши"],
    "недостреливавши": ["недостреливав"],
    "недостроив": ["недостроивши"],
    "недостроивши": ["недостроив"],
    "недоступный": ["недостижимый", "непроходимый", "непонятный", "неясный", "непостижимый", "заумный", "тёмный", "невразумительный", "запретный"],
    "недосужный": ["занятой"],
    "недосушив": ["недосушивши"],
    "недосушивав": ["недосушивавши"],
    "недосушивавши": ["недосушивав"],
    "недосушивши": ["недосушив"],
    "недосчитав": ["недосчитавши"],
    "недосчитавши": ["недосчитав"],
    "недосчитывав": ["недосчитывавши"],
    "недосчитывавши": ["недосчитывав"],
    "недосылав": ["недосылавши"],
    "недосылавши": ["недосылав"],
    "недосып": ["недосыпание", "недосыпанье", "недосыпка"],
    "недосыпав": ["недосыпавши"],
    "недосыпавши": ["недосыпав"],
    "недосыпанье": ["недосыпание"],
    "недосягаемый": ["недостижимый", "непревзойденный", "несравненный"],
    "недотерпев": ["недотерпевши"],
    "недотерпевши": ["недотерпев"],
    "недотратить": ["недорасходовать"],
    "недотрах": ["недоёб"],
    "недотрога": ["стыдливая мимоза"],
    "недотягивав": ["недотягивавши"],
    "недотягивавши": ["недотягивав"],
    "недотянув": ["недотянувши"],
    "недотянувши": ["недотянув"],
    "недотянуть": ["недожать"],
    "недотёпа": ["кулёма", "неумеха"],
    "недоузнав": ["недоузнавши"],
    "недоузнавши": ["недоузнав"],
    "недоукомплектовав": ["недоукомплектовавши"],
    "недоукомплектовавши": ["недоукомплектовав"],
    "недоукомплектовывав": ["недоукомплектовывавши"],
    "недоукомплектовывавши": ["недоукомплектовывав"],
    "недоумевав": ["недоумевавши"],
    "недоумевавши": ["недоумевав"],
    "недоумевать": ["колебаться"],
    "недоумение": ["растерянность", "затруднение", "сомнение", "колебание", "оторопь", "недоуменье"],
    "недоуменно": ["недоумённо"],
    "недоуменный": ["недоумённый", "недоумевающий"],
    "недоуменье": ["недоумение"],
    "недоумок": ["дурак", "дурачок", "тупица"],
    "недоумённо": ["недоуменно"],
    "недоученный": ["недоученый"],
    "недоученый": ["недоученный"],
    "недоучив": ["недоучивши"],
    "недоучивав": ["недоучивавши"],
    "недоучивавши": ["недоучивав"],
    "недоучивши": ["недоучив"],
    "недоучитывав": ["недоучитывавши"],
    "недоучитывавши": ["недоучитывав"],
    "недоучка": ["невежда", "круглый невежда", "неуч", "недоучь", "недоученка", "верхогляд", "верхоглядка", "простец", "профан", "полузнайка", "лапоть", "лапотник", "митрофанушка", "валенок", "сибирский валенок"],
    "недофинансировав": ["недофинансировавши"],
    "недофинансировавши": ["недофинансировав"],
    "недофорсив": ["недофорсивши"],
    "недофорсивши": ["недофорсив"],
    "недочеловек": ["унтерменш", "урод", "выродок", "нечисть"],
    "недочитывав": ["недочитывавши"],
    "недочитывавши": ["недочитывав"],
    "недочёт": ["недостача", "недостаток"],
    "недошибав": ["недошибавши"],
    "недошибавши": ["недошибав"],
    "недошив": ["недошивши"],
    "недошивав": ["недошивавши"],
    "недошивавши": ["недошивав"],
    "недошивши": ["недошив"],
    "недоёб": ["недотрах"],
    "недреманный": ["недремлющий", "всевидящий"],
    "недробный": ["нераздельный"],
    "недруг": ["враг", "неприятель"],
    "недружелюбно": ["враждебно", "неприязненно"],
    "недружелюбный": ["враждебный", "неприязненный", "недоброжелательный"],
    "недружественный": ["недружеский", "неблагожелательный"],
    "недружный": ["недружественный"],
    "недуг": ["болезнь", "хворь"],
    "недуговав": ["недуговавши"],
    "недуговавши": ["недуговав"],
    "недужав": ["недужавши"],
    "недужавши": ["недужав"],
    "недужать": ["недужить"],
    "недужив": ["недуживши"],
    "недуживши": ["недужив"],
    "недужить": ["недужать", "хворать"],
    "недужность": ["болезненность"],
    "недужный": ["слабый", "больной", "немощный", "болезненный", "хворый"],
    "недурно": ["неплохо", "недурственно"],
    "недурной": ["хороший", "неплохой"],
    "недуховность": ["бессодержательность", "безыдейность", "бездуховность"],
    "недълготрайност": ["краткотрайност", "кратковременност"],
    "недюжинный": ["выдающийся", "незаурядный", "необыкновенный"],
    "неебический": ["ебический"],
    "неевклидов": ["неэвклидов"],
    "нееврей": ["гой"],
    "неединственный": ["неуникальный", "неоднозначный"],
    "неемия": ["нехемия", "нехемья", "неэмия", "негемя"],
    "неестественный": ["деланный", "ненатуральный", "сверхъестественный"],
    "нежданно": ["вдруг"],
    "нежданно-негаданно": ["неожиданно", "вдруг", "внезапно"],
    "нежданный": ["неожиданный"],
    "нежданчик": ["неожиданность", "сюрприз"],
    "нежелание": ["неохота", "нехотение"],
    "нежеланье": ["нежелание"],
    "нежели": ["чем"],
    "неженатый": ["холостой", "холостяцкий"],
    "неженский": ["мужской"],
    "неженье": ["нежение"],
    "нежив": ["неживши"],
    "неживой": ["мёртвый", "умерший", "вялый", "безжизненный", "мертвенный", "неестественный", "ненатуральный", "неорганический"],
    "неживописный": ["невыразительный"],
    "неживши": ["нежив"],
    "нежизненный": ["неправдоподобный", "неестественный", "нежизнеспособный"],
    "нежизнерадостный": ["неулыбчивый", "угрюмый", "невеселый", "мрачный", "унылый", "хмурый"],
    "нежилой": ["необитаемый", "пустой", "незаселённый", "ненаселённый"],
    "нежирный": ["постный", "маложирный"],
    "нежить": ["ласкать", "холить", "ублажать", "баловать", "лелеять", "пестовать"],
    "нежнев": ["нежневши"],
    "нежневши": ["нежнев"],
    "нежничав": ["нежничавши"],
    "нежничавши": ["нежничав"],
    "нежничать": ["сентиментальничать", "миловаться", "любезничать"],
    "нежно": ["ласково", "любовно", "мягко", "тонко", "легко", "изящно", "приятно", "осторожно", "аккуратно"],
    "нежно-жёлтый": ["светло-жёлтый", "бледно-жёлтый", "слабо-жёлтый"],
    "нежность": ["мягкость", "ласковость", "деликатность", "сентиментальность", "тонкость", "глупость", "ласка", "изнеженность"],
    "нежный пол": ["женский пол", "слабый пол", "прекрасный пол"],
    "незабвенный": ["незабываемый", "приснопамятный", "памятный"],
    "незабудка": ["миозотис"],
    "незабываемый": ["памятный", "незабвенный"],
    "незаверенный": ["незавизированный", "неутверждённый"],
    "незавершённый": ["незаконченный"],
    "независимое государство хорватия": ["нгх"],
    "независимость": ["свобода", "самостоятельность", "автономность"],
    "незаданность": ["неповторимость", "импровизированность"],
    "незаданный": ["пропущенный", "неопределенный"],
    "незадача": ["неудача"],
    "незадоволення": ["невдоволення"],
    "незадолго": ["недавно"],
    "незаинтересованный": ["безразличный", "индифферентный", "непредвзятый"],
    "незакавыченный": ["неотквоченный", "раскавыченный"],
    "незаконнорожденный": ["незаконнорождённый", "внебрачный"],
    "незаконнорождённый": ["незаконный", "внебрачный", "побочный", "нагульный", "пригульный", "приблудный", "прелюбодейный", "прижитый"],
    "незаконный": ["противозаконный", "неправомерный", "противоправный", "недозволенный", "нелегальный", "преступный"],
    "незаконченный": ["незавершённый", "недоконченный", "неоконченный", "недовершённый", "недоделанный"],
    "незамедлительно": ["немедленно", "безотлагательно"],
    "незамедлительность": ["безотлагательность", "немедленность", "неотложность", "срочность", "экстренность"],
    "незамедлительный": ["безотлагательный", "немедленный", "неотложный", "срочный", "экстренный"],
    "незамерзайка": ["стеклоомыватель", "омывайка"],
    "незаметно": ["скрытно", "неприметно", "украдкой", "неощутимо", "неосязаемо", "малозаметно", "нечувствительно", "не видно"],
    "незаметный": ["неприметный", "неброский"],
    "незамкнутый": ["незапертый", "разомкнутый"],
    "незамужница": ["незамужняя", "холостячка"],
    "незамысловато": ["незатейливо"],
    "незамысловатость": ["простота"],
    "незамысловатый": ["безыскусный", "бесхитростный", "незатейливый", "простой"],
    "незанимательный": ["неинтересный"],
    "незаносистый": ["незаносчивый"],
    "незаносчивый": ["незаносистый", "незаносливый"],
    "незанудливый": ["нескучный", "ненадоедливый"],
    "незанятость": ["безделье", "бездельничание", "пустование", "безработица"],
    "незапно": ["внезапно"],
    "незапрограммированный": ["запрограммированный"],
    "незапятнанный": ["безукоризненный", "безупречный"],
    "незаселённый": ["необитаемый", "нежилой", "пустой", "ненаселённый"],
    "незаслуженно": ["несправедливо"],
    "незаслуживающий": ["нестоящий"],
    "незатруднительный": ["беспроблемный", "лёгкий"],
    "незаурядность": ["необыкновенность", "необычность", "недюжинность", "экстраординарность", "исключительность", "феноменальность", "яркость", "редкостность", "замечательность", "видность"],
    "незаурядный": ["выдающийся", "неординарный", "яркий", "редкий", "необычный", "недюжинный", "необыкновенный", "исключительный", "редкостный"],
    "незачем": ["не нужно", "бесполезно", "бессмысленно"],
    "незашоренный": ["нестандартный"],
    "незащищённый": ["беззащитный", "уязвимый"],
    "незборний": ["незборимий"],
    "незваный": ["непрошеный"],
    "незвиклий": ["незвичний", "незвичайний"],
    "нездешний": ["неместный"],
    "нездешность": ["чуждость", "пришлость", "посторонность", "потусторонность", "сверхъестественность"],
    "нездоровиться": ["хвораться"],
    "нездорово": ["болезненно"],
    "нездоровые отношения": ["абьюзивные отношения"],
    "нездоровый": ["больной", "болезненный", "хворый"],
    "нездоровье": ["недомогание", "болезнь", "хворь"],
    "незеркальный": ["беззеркальный"],
    "незимостойкий": ["незимоустойчивый"],
    "незимоустойчивый": ["незимостойкий"],
    "незлобиво": ["незлобно", "незлостно"],
    "незлобивый": ["кроткий", "добродушный", "беззлобный", "незлобный"],
    "незлой": ["добрый"],
    "незлопамятный": ["отходчивый"],
    "незнаемо": ["неизвестно", "незнамо", "незнакомо", "неведомо", "непонятно"],
    "незнакомец": ["чёрт с виру"],
    "незнакомый": ["неизвестный", "неведомый", "неосведомлённый", "незнакомец"],
    "незнаменательный": ["неполнозначный", "служебный"],
    "незнамо": ["неизвестно", "неведомо"],
    "незнание": ["неведение", "неосведомлённость"],
    "незнанье": ["незнание"],
    "незначащий": ["незначительный", "незначимый"],
    "незначимый": ["незначащий", "незначительный"],
    "незначительный": ["малый", "маленький", "неважный", "несущественный", "пустяковый"],
    "незомь": ["пусть", "пускай", "не замай"],
    "незрелый": ["неспелый", "несозревший", "непродуманный"],
    "незримо": ["невидимо", "незаметно", "ненаблюдаемо", "скрыто", "тайно"],
    "незримый": ["невидимый"],
    "незрячий": ["слепой"],
    "незыблемо": ["прочно", "неколебимо", "надёжно", "твёрдо", "устойчиво", "стойко"],
    "незыблемость": ["непоколебимость", "неколебимость", "несокрушимость"],
    "незыблемый": ["неколебимый", "непоколебимый", "надёжный", "устойчивый", "прочный", "твёрдый", "неизменный"],
    "неидеально": ["несовершенно", "небезупречно", "небезукоризненно"],
    "неидеальность": ["несовершенство", "дефектность", "ущербность"],
    "неизбежно": ["обязательно", "непременно", "неминуемо", "неотвратимо", "непредотвратимо"],
    "неизбежность": ["неотвратимость"],
    "неизбежный": ["неминуемый", "неотвратимый", "неотменный", "непременный", "неотразимый", "роковой", "фатальный", "провиденциальный", "постоянный", "обычный"],
    "неизбывно": ["постоянно", "вечно", "непреходяще"],
    "неизбывность": ["неистребимость", "неизбежность"],
    "неизбывный": ["неистребимый", "неизбежный"],
    "неизвестно": ["неведомо"],
    "неизвестное": ["неведомое", "незнаемое", "незнакомое"],
    "неизвестность": ["непознанность", "неосведомлённость", "безвестность"],
    "неизвестный": ["незнаемый", "незнакомый", "безвестный", "незнакомец"],
    "неизглаголанный": ["невыраженный"],
    "неизлечимый": ["неисцелимый"],
    "неизменный": ["постоянный", "неизменяемый", "всегдашний", "обычный", "одинаковый", "преданный", "верный", "надёжный"],
    "неизменяемый": ["неизменный"],
    "неизмеримость": ["неизмеряемость"],
    "неизмеримый": ["безмерный"],
    "неизмолимо": ["неизбежно", "неминуемо", "неотвратимо"],
    "неизъяснимость": ["необъяснимость"],
    "неизъяснимый": ["невыразимый"],
    "неиллюзорный": ["реальный"],
    "неимав": ["неимавши"],
    "неимавши": ["неимав"],
    "неимение": ["отсутствие"],
    "неименье": ["неимение"],
    "неимеющийся": ["несуществующий"],
    "неимоверно": ["невероятно", "чрезвычайно"],
    "неимущественный": ["нематериальный", "духовный"],
    "неимущество": ["скудость", "бедность"],
    "неимущий": ["бедный", "малоимущий", "нищий", "небогатый", "нуждающийся", "малообеспеченный", "необеспеченный"],
    "неинвазивный": ["бескровный", "атравматичный", "бесконтактный"],
    "неиндуктивный": ["безындукционный"],
    "неинициативность": ["пассивность"],
    "неинкорпорированный": ["невключённый"],
    "неинтеллигентный": ["некультурный", "необразованный"],
    "неинтересно": ["скучно"],
    "неинтересный": ["скучный"],
    "неискоренимый": ["закоренелый", "неисправимый"],
    "неискусно": ["неумело"],
    "неискусный": ["неумелый"],
    "неискусомужная": ["дева", "девственница"],
    "неискусомужный": ["девственный"],
    "неисповедимо": ["непостижимо"],
    "неисповедимый": ["непостижимый"],
    "неисполненье": ["неисполнение"],
    "неисполнимый": ["неоуществимый"],
    "неиспользованность": ["неисчерпанность", "неизрасходованность"],
    "неисправимо": ["непоправимо"],
    "неисправимый": ["непоправимый", "застарелый", "закоснелый", "матёрый", "заматерелый", "отпетый", "закоренелый", "пропащий", "неискоренимый", "нераскаянный"],
    "неисправность": ["дефект", "изъян", "неполадка", "повреждение", "поломка"],
    "неисправный": ["испорченный", "неработоспособный", "неисполнительный", "нерадивый"],
    "неиссякаемый": ["неиссякающий", "неисчерпаемый", "неистощимый", "безграничный", "бесконечный"],
    "неиссякающий": ["неиссякаемый", "неисчерпаемый", "неистощимый", "бесконечный"],
    "неистово": ["безудержно", "необузданно", "бешено", "исступлённо", "буйно", "яростно", "яро"],
    "неистовость": ["буйность", "буйство"],
    "неистовство": ["неистовость", "бешенство", "ярость"],
    "неистовствовав": ["неистовствовавши"],
    "неистовствовавши": ["неистовствовав"],
    "неистовствовать": ["бесноваться", "буйствовать"],
    "неистовый": ["исступлённый", "бешеный"],
    "неисторичный": ["неисторический"],
    "неистощимый": ["неиссякаемый", "неисчерпаемый"],
    "неистребимый": ["неискоренимый"],
    "неисчислимый": ["бесчисленный", "бессчётный"],
    "ней": ["ей", "нею", "ею"],
    "нейзильбер": ["аргентан", "альфенид"],
    "неймеген": ["нимвеген"],
    "нейпьидо": ["найпьидо"],
    "нейраминидаза": ["сиалидаза"],
    "нейрит": ["неврит", "аксон"],
    "нейро-": ["нервно-", "нейронный", "нейросетевой"],
    "нейроглия": ["невроглия", "глия"],
    "нейродермит": ["невродермит"],
    "нейроимплант": ["нейропротез", "нейроимплантат"],
    "нейроимплантат": ["нейропротез", "нейроимплант"],
    "нейролейкоз": ["нейролейкемия"],
    "нейролептик": ["нейроплегик", "антипсихотик"],
    "нейромезодерматодистрофия": ["нейрофиброматоз"],
    "нейрон": ["неврон", "нервная клетка", "нейроцит"],
    "нейронка": ["нейросетка", "нейросеть", "нейронная сеть", "инс"],
    "нейронная сеть": ["нейросеть", "нейросетка", "нейронка"],
    "нейропатия": ["невропатия"],
    "нейропатологический": ["невропатологический"],
    "нейропиль": ["невропиль"],
    "нейропсихологическая коррекция": ["нейропсихокоррекция"],
    "нейросекрет": ["нейрогормон"],
    "нейросетка": ["нейронка", "нейросеть", "нейронная сеть", "инс"],
    "нейросеть": ["нейронная сеть", "инс", "нейронка", "нейросетка"],
    "нейростимулятор": ["нейротропное средство"],
    "нейротизм": ["невротизм"],
    "нейротомия": ["нейрэктомия", "невротомия"],
    "нейрофиброматоз": ["нейромезодерматодистрофия"],
    "нейтас": ["чёрное море", "азовское море"],
    "нейтрализировав": ["нейтрализировавши"],
    "нейтрализировавши": ["нейтрализировав"],
    "нейтрализовав": ["нейтрализовавши"],
    "нейтрализовавши": ["нейтрализовав"],
    "нейтрализовать": ["нейтрализировать", "нейтрализовывать"],
    "нейтралитет": ["нейтральность", "неучастие", "невмешательство"],
    "нейтральный": ["ничейный"],
    "нейтронография": ["нейтронная радиография"],
    "некав": ["некавши"],
    "некавши": ["некав"],
    "неказистый": ["некрасивый", "невзрачный"],
    "неканоничный": ["неканонический"],
    "некачественный": ["плохой", "скверный", "низкосортный"],
    "неквалифицированный": ["неумелый", "неопытный"],
    "некий": ["какой-то", "кое-какой", "какой-нибудь", "некоторый", "известный", "определённый"],
    "нековидный": ["некоронавирусный"],
    "некогда": ["бывало", "бывалоча", "когда-то", "в своё время"],
    "неколебимый": ["непоколебимый", "устойчивый", "стойкий"],
    "некомбатант": ["нонкомбатант"],
    "некоммерческая организация": ["нко"],
    "некоммерческий": ["неторговый"],
    "некоммуникабельность": ["малообщительность", "неконтактность", "необщительность", "замкнутость", "скрытность", "нелюдимость"],
    "некоммуникабельный": ["замкнутый"],
    "некомпетентность": ["безграмотность", "незнание"],
    "некомпланарность": ["некопланарность"],
    "некомфортно": ["не в своей тарелке"],
    "некомфортный": ["неудобный"],
    "неконвенциональный": ["нонконвенциональный"],
    "некондиция": ["брак"],
    "неконкретный": ["абстрактный", "общий", "неопределённый"],
    "неконкурентноспособный": ["неконкурентоспособный"],
    "неконкурентный": ["неконкурентноспособный"],
    "неконкурентоспособный": ["неконкурентный"],
    "неконтролируемость": ["бесконтрольность"],
    "некопланарность": ["некомпланарность"],
    "некоронавирусный": ["нековидный"],
    "некорректный": ["невежливый", "грубый", "ошибочный", "неправильный", "неверный"],
    "некорыстный": ["бедный", "небогатый", "бескорыстный"],
    "некоторый": ["какой-то", "кое-какой", "незначительный", "часть"],
    "некрасивый": ["невзрачный", "уродливый", "неблагозвучный", "нечестный", "непорядочный", "предосудительный"],
    "некредитоспособност": ["неплатежоспособност"],
    "некредитоспособность": ["неплатёжеспособность"],
    "некрепкий": ["слабозаваренный", "разбавленный", "слабоалкогольный"],
    "некрепко": ["несильно", "непрочно", "слабо"],
    "некресть": ["неверный", "безбожник"],
    "некристаллический": ["аморфный"],
    "некробактериоз": ["некробациллёз"],
    "некробациллёз": ["некробактериоз"],
    "некроз": ["омертвение"],
    "некрология": ["некролог"],
    "некромант": ["медиум"],
    "некромантия": ["спиритизм"],
    "некрополь": ["толос", "пантеон", "усыпальница", "гробница"],
    "некропсия": ["аутопсия", "вскрытие", "секция", "анатомирование"],
    "некросадизм": ["бертранизм"],
    "некротизировав": ["некротизировавши"],
    "некротизировавши": ["некротизировав"],
    "некротический": ["омертвевший"],
    "некрофагия": ["каннибализм"],
    "некрофилия": ["труположство", "труположество"],
    "некрофильство": ["труположство"],
    "некрофобия": ["танатофобия"],
    "некрут": ["рекрут"],
    "некрутский": ["рекрутский"],
    "некстати": ["несвоевременно", "неуместно"],
    "нектароподобный": ["нектарообразный"],
    "некто": ["кто-то", "некий"],
    "некузяво": ["не комильфо"],
    "некузявый": ["нехороший"],
    "некультяпистый": ["неловкий", "неуклюжий", "мешковатый"],
    "некхеб": ["эйлейтия"],
    "неласковый": ["суровый"],
    "нелегал": ["нелегальный", "мигрант", "резидент"],
    "нелегальный": ["незаконный", "противозаконный", "неправомерный", "противоправный", "недозволенный", "преступный", "запрещённый", "запретный", "воспрещённый"],
    "нелегитимный": ["неправомочный", "незаконный"],
    "нелегко": ["трудно", "тяжко"],
    "нелекарственный": ["немедикаментозный"],
    "нелепица": ["нелепость", "абсурд", "ахинея", "бессмыслица", "белиберда", "вздор", "галиматья", "дребедень", "ерунда", "несообразность", "околесица", "чепуха", "чушь"],
    "нелепо": ["глупо", "анекдотично", "несуразно"],
    "нелепое": ["курьёз", "нелепость"],
    "нелепость": ["абсурд", "бессмыслица", "глупость", "вздор", "ерунда", "несуразность", "несообразность"],
    "нелепый": ["чудной", "дурацкий", "несуразный", "неуклюжий", "неуместный", "несообразный"],
    "нелестно": ["неодобрительно", "малоприятно"],
    "нелетальный": ["несмертельный"],
    "неликвид": ["балласт", "некондиция", "отходы"],
    "нелитературный": ["просторечный"],
    "нелицензированный": ["нелицензионный"],
    "нелицеприятно": ["объективно", "непредубеждённо", "непредвзято", "беспристрастно", "резко", "справедливо", "невзирая на лица", "необлыжно"],
    "нелицеприятность": ["беспристрастность", "непредвзятость", "непредубеждённость", "объективность"],
    "нелицеприятный": ["беспристрастный", "объективный", "справедливый", "непредвзятый", "непредубеждённый", "правдивый", "праведный", "правосудный", "нелицеприимный", "необлыжный", "неумытный", "честной", "неприятный", "резкий", "грубый"],
    "нелишний": ["небесполезный", "нужный"],
    "неловкий": ["неуклюжий", "неповоротливый", "нескладный"],
    "неловко": ["неуклюже", "неудобно", "некомфортно"],
    "неловкость": ["неповоротливость", "неуклюжесть"],
    "нелогический": ["внелогический"],
    "нелогично": ["алогично"],
    "нелогичность": ["алогичность"],
    "нелогичный": ["алогичный", "иллогичный", "непоследовательный", "абсурдный"],
    "нельзя": ["невозможно", "запрещено", "недопустимо"],
    "нельзя быть наполовину беременной": ["нельзя быть немножко беременной", "нельзя быть немножечко беременной"],
    "нелюбезно": ["непредупредительно", "неприветливо", "неучтиво"],
    "нелюбезный": ["неприветливый", "невежливый"],
    "нелюбопытный": ["нелюбознательный"],
    "нелюбье": ["нелюбие"],
    "нелюдим": ["анахорет", "бирюк", "мизантроп"],
    "нелюдимый": ["необщительный", "некоммуникабельный", "бирюковатый", "замкнутый", "затворнический", "отшельнический", "смурной", "смурый", "угрюмый", "хмурый", "пустынный", "безлюдный", "нежилой", "глухой", "дикий"],
    "нелюдь": ["мерзавец", "негодяй", "выродок", "мразь", "отморозок", "подонок", "враг", "гад", "гадина", "зверь", "зверьё", "нечисть", "отребье", "нелюдим", "бирюк"],
    "нелёгкий": ["тяжёлый", "увесистый", "массивный", "непростой", "трудный", "сложный"],
    "нелёжкий": ["нелёжкоспособный"],
    "немало": ["много"],
    "немаловажно": ["важно"],
    "немаловажный": ["важный", "значительный", "существенный"],
    "немалооплачиваемый": ["высокооплачиваемый", "достойнооплачиваемый"],
    "нематериальный": ["немонетарный", "нефизический", "абстрактный", "духовный", "невещественный", "несуществующий"],
    "нематода": ["круглый червь"],
    "немачка": ["савезна република немачка"],
    "немев": ["немевши"],
    "немевши": ["немев"],
    "немед": ["нехмед"],
    "немедикаментозный": ["нелекарственный"],
    "немедленно": ["сию секунду", "сию минуту", "сразу", "сейчас же", "сейчас"],
    "немедленный": ["безотлагательный", "незамедлительный", "неотложный", "срочный", "экстренный"],
    "немедля": ["немедленно", "незамедлительно", "безотлагательно", "сейчас", "тотчас", "без замедления", "без промедления", "вборзе", "вскоре", "спешно", "не откладывая в долгий ящик"],
    "немезида": ["немесида"],
    "немерено": ["много", "видимо-невидимо", "неограниченно"],
    "немереный": ["неизмеримый", "необъятный", "неограниченный"],
    "немереча": ["чащоба"],
    "неместный": ["пришлый", "иногородний", "иноземный", "заезжий", "нетипичный", "приезжий", "чужак"],
    "неметалл": ["металлоид"],
    "неметчина": ["германия"],
    "неметь": ["онемевать"],
    "немец": ["германец", "немчура", "немчик", "фриц", "колбасник", "немецкая овчарка", "иностранец", "иноземец", "гувернёр"],
    "немецкий": ["германский", "немецкий язык"],
    "немецкий язык": ["немецкий"],
    "немецкоговорящий": ["немецкоязычный"],
    "немецкоязычный": ["немецкоговорящий"],
    "немилосердно": ["бесчеловечно"],
    "немилосердный": ["жестокосердный"],
    "немилостивый": ["немилосердный"],
    "неминуемый": ["неизбежный", "неотвратимый", "неминучий"],
    "неминучий": ["неминуемый", "неизбежный"],
    "немис": ["мектеп"],
    "немкиня": ["немцойка"],
    "немногий": ["малочисленный", "немногочисленный"],
    "немного": ["несколько", "слегка", "чуть-чуть", "чуток", "недолго"],
    "немноголюдно": ["малолюдно"],
    "немногословный": ["краткий", "сжатый", "лаконичный", "неразговорчивый", "несловоохотливый"],
    "немножечко": ["чуток"],
    "немножко": ["немного", "немножечко", "чуть-чуть", "слегка", "маленько"],
    "немогота": ["немочь", "хворь", "недуг", "бессилие", "немощность"],
    "неможется": ["нездоровиться", "хвораться", "недужиться"],
    "неможно": ["невозможно", "нельзя"],
    "немолкнущий": ["несмолкающий", "неумолкающий", "неумолчный"],
    "немолчно": ["безумолчно", "несмолкаемо", "неугомонно", "неумолкаемо", "неумолчно"],
    "немолчный": ["безумолкный", "безумолчный", "незамолкающий", "немолкнущий", "несмолкаемый", "несмолкающий", "неугомонный", "неумолкаемый", "неумолчный"],
    "неморозостойкий": ["неморозоустойчивый"],
    "неморозоустойчивый": ["неморозостойкий"],
    "немота": ["дислалия", "мутизм", "молчание", "бессловесность", "безмолвие", "тишина"],
    "немотия": ["нямане", "оскъдица", "бедност", "беднотия", "сиромашия"],
    "немотствовав": ["немотствовавши"],
    "немотствовавши": ["немотствовав"],
    "немотствование": ["немота", "молчание"],
    "немотствовать": ["безмолвствовать", "молчать"],
    "немочь": ["немощь"],
    "немощность": ["слабость"],
    "немощный": ["слабый", "хилый", "бессильный", "больной"],
    "немощь": ["слабость", "немочь", "истощение", "дряхлость", "немощность", "слабосилие", "дряблость", "хилость", "вялость", "хворь", "болезнь", "хвороба", "болячка", "недуг", "расстройство"],
    "немреспублика": ["асср немцев поволжья", "асср нп"],
    "немти": ["анти"],
    "немудрено": ["несложно", "нетрудно", "неудивительно", "нехитро", "незамысловато"],
    "немужской": ["женский"],
    "немузыка": ["антимузыка", "псевдомузыка"],
    "немцойка": ["немкиня"],
    "немчура": ["немец", "немка", "тевтон", "фриц", "ганс", "ганц", "колбасник"],
    "немыслимо": ["невообразимо", "уму непостижимо"],
    "немыслимость": ["невообразимость"],
    "немыслимый": ["невероятный", "невозможный"],
    "немытое рыло": ["неумытое рыло"],
    "ненавидев": ["ненавидевши"],
    "ненавидевши": ["ненавидев"],
    "ненавидимый": ["ненавистный", "невыносимый"],
    "ненавистник": ["ненавидящий", "злюка", "ненавидимый", "изгой", "антагонист", "гонитель", "злоумышленник", "лиходей", "недоброжелатель", "недруг", "неприятель", "обидчик", "преследователь"],
    "ненавистничав": ["ненавистничавши"],
    "ненавистничавши": ["ненавистничав"],
    "ненавистный": ["одиозный"],
    "ненависть": ["неприязнь"],
    "ненавязчиво": ["неназойливо"],
    "ненавязчивый": ["неназойливый", "деликатный", "тактичный"],
    "ненадёванный": ["новый", "неношеный"],
    "ненадёжный": ["сомнительный", "подозрительный"],
    "ненажера": ["бревкало", "захланник", "ненажеря", "ненаситець", "пажера", "пожерач", "хавкун"],
    "неназойливо": ["ненавязчиво"],
    "неназойливый": ["ненавязчивый", "ненадоедливый", "деликатный", "тактичный"],
    "ненамеренно": ["случайно", "непроизвольно"],
    "ненамеса": ["невмешателство"],
    "ненамного": ["немного", "незначительно"],
    "ненаправленный": ["всенаправленный"],
    "ненароком": ["ненамеренно", "непреднамеренно", "случайно", "невзначай", "неумышленно", "невольно", "часом", "нечаянно", "по невнимательности", "по недосмотру", "по оплошности", "по неосторожности", "неосторожно", "небрежно"],
    "ненарочный": ["неумышленный", "ненамеренный", "нечаянный"],
    "ненаселённый": ["необитаемый", "нежилой", "пустой", "незаселённый"],
    "ненасилие": ["ахимса", "пацифизм"],
    "ненастие": ["ненастье"],
    "ненастный": ["непогожий"],
    "ненастоящий": ["фальшивый", "поддельный", "искусственный"],
    "ненастье": ["непогода"],
    "ненасытность": ["жадность"],
    "ненатуральность": ["искусственность"],
    "ненаука": ["лженаука", "квазинаука", "псевдонаука", "паранаука"],
    "ненаучно": ["антинаучно"],
    "ненаучность": ["квазинаучность", "лженаучность", "паранаучность", "псевдонаучность"],
    "ненаучный": ["квазинаучный", "лженаучный", "паранаучный", "псевдонаучный"],
    "ненец": ["самоед", "юрак"],
    "ненецкий автономный округ": ["нао"],
    "ненормальный": ["аномальный", "сумасшедший", "псих"],
    "неношеный": ["ненадёванный"],
    "ненужный": ["бесполезный"],
    "ненька": ["неня", "мати"],
    "неньютоновский": ["неньютонов"],
    "неня": ["ненька"],
    "неняв": ["ненявши"],
    "ненявши": ["неняв"],
    "ненять": ["неимать"],
    "нео-": ["ново-"],
    "неоандроповщина": ["андроповщина"],
    "необеспеченный": ["бедный", "неимущий", "малоимущий", "нищий", "небогатый", "нуждающийся", "малообеспеченный"],
    "необжитой": ["необжитый"],
    "необжитый": ["необжитой"],
    "необитаемый": ["нежилой", "пустой", "незаселённый", "ненаселённый"],
    "необманный": ["несомненный", "настоящий", "действительный"],
    "необозримый": ["неоглядный"],
    "необоримо": ["неодолимо"],
    "необоснованно": ["неоправданно"],
    "необоснованный": ["неосновательный", "безосновательный"],
    "необосновательно": ["необоснованно"],
    "необосновательный": ["необоснованный"],
    "необразованность": ["нахватанность", "невежественность", "неграмотность"],
    "необразованный": ["безграмотный", "невежественный"],
    "необратимый": ["неповторимый", "невозвратимый", "невозвратный", "неконвертируемый", "непоколебимый", "неотвратимый", "неизменный"],
    "необременительный": ["нетрудный"],
    "необузданно": ["неистово", "буйно", "безудержно", "неукротимо"],
    "необходимейший": ["нужнейший"],
    "необходимо": ["надо", "нужно"],
    "необходимость": ["долженствование", "надобность", "потребность", "нужда"],
    "необходимый": ["насущный", "незаменимый", "потребный", "требуемый", "неизбежный", "неотложный"],
    "необширно": ["немного"],
    "необщительный": ["замкнутый"],
    "необъективно": ["лицеприятно", "тенденциозно", "пристрастно", "субъективно", "предубежденно", "предвзято", "небеспристрастно"],
    "необъективность": ["предвзятость", "пристрастность"],
    "необъяснимый": ["неизъяснимый"],
    "необъятность": ["безмерность", "беспредельность", "безграничность"],
    "необъятный": ["безграничный", "беспредельный", "необозримый", "неохватный", "чрезвычайный", "необыкновенный"],
    "необыкновенно": ["чрезмерно", "чрезвычайно", "очень", "необычайно"],
    "необыкновенный": ["необычный", "необычайный", "редкостный", "уникальный"],
    "необычайно": ["необычно", "исключительно", "чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми"],
    "необычайный": ["необыкновенный", "исключительный", "чрезвычайный", "необычный"],
    "необычно": ["непривычно", "странно"],
    "необычность": ["необычайность", "необыкновенность"],
    "необычный": ["необычайный", "необыкновенный", "непривычный", "странный", "удивительный"],
    "необязательный": ["опциональный", "факультативный"],
    "неоген": ["неогеновый период", "неогеновая система", "неохрон"],
    "неогенный": ["неогеновый"],
    "неогеновый": ["неогенный"],
    "неоглядность": ["необозримость", "безбрежность", "безграничность"],
    "неограниченность": ["безграничность", "беспредельность"],
    "неодарвинизм": ["вейсманизм"],
    "неодарённый": ["бездарный", "неталантливый", "бесталанный", "малоодарённый"],
    "неодетый": ["голый", "нагой", "в чём мать родила", "неприкрытый", "в исподнем"],
    "неодинаково": ["по-разному"],
    "неоднозначный": ["многозначный", "неопределённый", "спорный", "двусмысленный", "противоречивый", "смешанный"],
    "неоднократно": ["многажды"],
    "неодобренье": ["неодобрение"],
    "неодобрительно": ["осуждающе"],
    "неодобрительный": ["осуждающий"],
    "неодолимый": ["непреодолимый", "непобедимый"],
    "неодушевлённый": ["мёртвый", "неживой"],
    "неожиданно": ["внезапно", "нежданно", "непредвиденно"],
    "неожиданный": ["непредвиденный", "внезапный", "нежданный"],
    "неозой": ["постнеогей"],
    "неоколониалист": ["неоколонизатор"],
    "неоколонизатор": ["неоколониалист"],
    "неокон": ["неоконсерватор"],
    "неоконсерватор": ["неокон"],
    "неокоричневый": ["неонацистский", "неофашистский"],
    "неокортекс": ["изокортекс"],
    "неокрашенный": ["некрашеный"],
    "неомрачённость": ["безмятежность"],
    "неон": ["неонка"],
    "неопаганизм": ["неоязычество"],
    "неопасно": ["безопасно"],
    "неопентан": ["диметилпропан"],
    "неоперативность": ["медлительность", "неповоротливость"],
    "неоплазма": ["опухоль"],
    "неоплата": ["просрочка"],
    "неопознанный летающий объект": ["нло"],
    "неопохмелённый": ["непохмелённый"],
    "неоправданно": ["необоснованно"],
    "неопределённость": ["неопределительность", "смутность", "нечёткость", "неотчётливость", "туманность", "неявность", "неустановленность", "неясность", "уклончивость", "неконкретность", "недостоверность", "ненадёжность", "неточность", "сомнение", "расплывчатость"],
    "неопровержимо": ["неоспоримо"],
    "неопровержимый": ["неоспоримый"],
    "неопрятно": ["неаккуратно", "неряшливо"],
    "неопрятность": ["неряшливость", "неаккуратность", "неряшество"],
    "неопрятный": ["неряшливый"],
    "неорганизованно": ["неупорядоченно", "стихийно"],
    "неорганический": ["минеральный"],
    "неординарность": ["необычность", "незаурядность"],
    "неординарный": ["необычный", "незаурядный", "выдающийся"],
    "неориентированный": ["ненаправленный"],
    "неортодоксальный": ["еретический", "нестандартный"],
    "неосведомлённость": ["неведение", "некомпетентность"],
    "неосведомлённый": ["несведущий", "неинформированный"],
    "неосвещённый": ["тёмный", "сумрачный"],
    "неослабный": ["неумолимый"],
    "неосмотрительно": ["легкомысленно", "необдуманно", "неосторожно", "нерасчётливо"],
    "неосновательность": ["безосновательность", "необоснованность", "непредусмотрительность"],
    "неосновательный": ["необоснованный", "безосновательный", "бездоказательный"],
    "неосновной": ["второстепенный"],
    "неособенный": ["обычный"],
    "неосознанно": ["машинально"],
    "неосознанный": ["бессознательный", "безотчётный"],
    "неоспоримый": ["бесспорный"],
    "неосторожно": ["неосмотрительно", "опрометчиво", "безрассудно"],
    "неостроумный": ["туповатый"],
    "неосуществимый": ["неисполнимый"],
    "неосуществлённый": ["несовершённый", "нереализованный", "невыполненный"],
    "неотапливаемый": ["необогреваемый"],
    "неотвратимость": ["неизбежность"],
    "неотвратимый": ["неизбежный", "неминуемый"],
    "неотвязчиво": ["неотвязно", "неотступно"],
    "неотзывный": ["безотзывный"],
    "неотзывчивый": ["нечуткий", "бездушный", "чёрствый"],
    "неоткровенный": ["скрытный", "неискренний"],
    "неотлагательно": ["безотлагательно", "неотложно", "срочно"],
    "неотличимо": ["как две капли воды"],
    "неотличимый": ["неразличимый"],
    "неотложка": ["скорая"],
    "неотложный": ["безотлагательный", "незамедлительный", "немедленный", "срочный", "экстренный"],
    "неотменяемый": ["неотменный"],
    "неотрывно": ["непрерывно"],
    "неотслеживаемый": ["неуловимый"],
    "неотступный": ["неотвязный"],
    "неотстъпчивост": ["твърдост", "упорство", "непреклонност"],
    "неотчётливость": ["нечёткость"],
    "неотчётливый": ["нечёткий", "неясный", "расплывчатый"],
    "неотшлифованность": ["отшлифованность"],
    "неотъемлемый": ["неотделимый", "имманентный"],
    "неотёсанность": ["необтёсанность"],
    "неотёсанный": ["невоспитанный", "некультурный", "невежа"],
    "неофит": ["новообращённый", "прозелит", "новичок"],
    "неофутуризм": ["нео-футуризм"],
    "неохота": ["не хочется"],
    "неохотно": ["нехотя"],
    "неохочий": ["непадкий", "равнодушный"],
    "неохрон": ["неоген"],
    "неоценимый": ["бесценный", "сверхценный"],
    "неочевидный": ["неявный", "невидимый", "сомнительный", "спорный"],
    "неоязычество": ["неопаганизм"],
    "непальский": ["непали"],
    "непарнокопытные": ["непарнопалые"],
    "непарнокопытный": ["непарнопалый", "конь", "лошадь"],
    "непахнущий": ["непахучий"],
    "непереводимая игра слов": ["идиома", "бессмыслица"],
    "непереносимый": ["невыносимый"],
    "неперерабатываемый": ["неутилизируемый"],
    "непереходимый": ["непреодолимый"],
    "непечатно": ["нецензурно"],
    "непилотируемый": ["беспилотный"],
    "непитьевой": ["технический"],
    "непланомерность": ["бесплановость", "беспорядочность"],
    "неплатежоспособност": ["некредитоспособност"],
    "неплатёж": ["неоплата", "неплата", "неуплата"],
    "неплатёжеспособность": ["несостоятельность", "банкротство"],
    "неплодовитость": ["абортивность"],
    "неплохо": ["недурно", "ладом"],
    "неплохой": ["недурной"],
    "непобедимый": ["необоримый", "неодолимый", "непоборимый", "непреоборимый", "непреодолимый"],
    "неповиновение": ["непослушание", "непослушанье", "неповиновенье"],
    "неповиновенье": ["неповиновение"],
    "неповитое сено": ["невитое сено"],
    "неповоротливый": ["неловкий", "неуклюжий", "нерасторопный"],
    "неповторение": ["неповторенье"],
    "неповторимый": ["непревзойдённый", "несравненный", "уникальный"],
    "неповторяемый": ["исключительный", "неповторимый", "неподражаемый", "уникальный"],
    "неповторяющийся": ["уникальный"],
    "непогода": ["ненастье", "непогодица", "непогодь", "непогодье"],
    "непогодив": ["непогодивши"],
    "непогодивши": ["непогодив"],
    "непогодный": ["ненастливый", "ненастный", "непогожий"],
    "непогодь": ["непогода"],
    "непогожий": ["ненастный"],
    "непогрешимый": ["безгрешный", "безошибочный"],
    "неподалёку": ["близко", "вблизи", "невдалеке", "недалеко", "поблизости", "рядом"],
    "неподатной": ["неналогооблагаемый"],
    "неподвижно": ["недвижимо"],
    "неподготвеност": ["неопитност", "неумелост", "неумение"],
    "неподдельный": ["настоящий", "оригинальный", "искренний", "неприкрытый"],
    "неподконтрольность": ["независимость", "неуправляемость"],
    "неподкупность": ["честность"],
    "неподлинный": ["ненастоящий"],
    "неподобающий": ["неприличный"],
    "неподражаемый": ["бесподобный", "беспримерный", "неповторимый", "несравненный", "особенный", "уникальный"],
    "неподходящий": ["непригодный", "неудачный", "неуместный"],
    "неподымный": ["неподъёмный"],
    "непознаваемый": ["непостижимый"],
    "непоклатимост": ["непоколебимост"],
    "непокой": ["беспокойство"],
    "непоколебимо": ["неколебимо", "устойчиво", "непреклонно", "стойко"],
    "непоколебимость": ["неколебимость", "незыблемость", "несокрушимость", "непреклонность"],
    "непоколебимый": ["стабильный"],
    "непокорный": ["непослушный", "строптивый", "непокорливый", "своевольный"],
    "непокрытый": ["голый", "обнажённый", "оголённый", "нагой", "неприкрытый", "декольтированный", "открытый"],
    "неполадка": ["расстройство"],
    "неполивной": ["богарный", "засухоустойчивый"],
    "неполиткорректный": ["политнекорректный"],
    "неполнозначный": ["незнаменательный", "служебный"],
    "неполнота": ["недостаточность", "недостача"],
    "неполноценный": ["ущербный"],
    "неполный": ["ненаполненный", "незаполненный", "незаконченный", "поджарый", "сухопарый", "сухощавый", "худощавый"],
    "неположенный": ["запрещённый", "неподобающий"],
    "непомерно": ["сверх всякой меры", "сверх меры", "безмерно", "излишне", "не в меру", "неумеренно", "преувеличенно", "через меру", "чересчур", "чрезмерно"],
    "непомерный": ["чрезмерный"],
    "непомнящий": ["беспамятный"],
    "непонимание": ["неразумение"],
    "непоносимост": ["нетърпимост"],
    "непонятливый": ["несообразительный", "несмышлёный", "бестолковый"],
    "непонятно": ["неясно"],
    "непонятность": ["непонятка"],
    "непонятный": ["неясный", "непостижимый", "недоступный", "заумный", "тёмный", "невразумительный", "загадочный", "странный", "необъяснимый", "энигматический"],
    "непонятый": ["неясный", "невразумительный"],
    "непоправимый": ["неисправимый"],
    "непорочность": ["безгрешность", "безукоризненность", "безупречность", "праведность", "совершенство", "девственность", "невинность", "целомудрие"],
    "непорядок": ["нарушение", "неустройство", "беспорядок", "неправильность"],
    "непорядочный": ["нечестный"],
    "непосвящённый": ["наивный"],
    "непоседа": ["непосед", "непоседка", "егоза", "вертун", "юла"],
    "непоседливый": ["непоседный"],
    "непосидючий": ["метушливий"],
    "непосильный": ["неподъёмный"],
    "непослушание": ["неповиновение", "непокорность", "непослушность", "ослушание"],
    "непослушанье": ["непослушание"],
    "непослушный": ["непокорный"],
    "непоспешание": ["неспешительность", "медлительность", "неторопливость"],
    "непосредственно": ["напрямую"],
    "непосредственность": ["бесхитростность", "простодушие", "наивность", "прямота"],
    "непосредственный": ["личный", "прямой", "непринуждённый", "откровенный", "естественный", "бесхитростный", "прямолинейный"],
    "непоставка": ["недоставка"],
    "непостижимый": ["непонятный", "неясный", "недоступный", "заумный", "тёмный", "невразумительный"],
    "непостоянность": ["непостоянство", "изменчивость"],
    "непостоянство": ["изменчивость"],
    "непотачливый": ["неповадный", "неуступчивый", "суровый", "строгий", "жестокий", "рачительный"],
    "непотенциальный": ["неконсервативный"],
    "непотизм": ["семейственность", "кумовство", "протекционизм"],
    "непотребный": ["гнусный", "неприличный", "развратный", "ненужный", "непригодный", "лишний", "бесполезный"],
    "непотребство": ["непотребность", "безнравственность", "неблагопристойность", "неприличие", "неприличность", "непристойность", "разнузданность", "распутство", "распущенность", "непотребщина"],
    "непотребщина": ["непотребство"],
    "непохвальний": ["несхвальний"],
    "непохмелённый": ["неопохмелённый"],
    "непохожесть": ["несхожесть", "несходство", "отличие"],
    "непохожий": ["несхожий", "несходный"],
    "непочатый": ["непочатой", "нетронутый"],
    "непочатый угол": ["непочатый край", "непочатой край"],
    "непочтенье": ["непочтение"],
    "непочтительность": ["дерзость", "неуважение", "неуважительность", "непочтение"],
    "непочтительный": ["невежливый", "наглый", "бесцеремонный", "неуважительный"],
    "непоэзия": ["псевдопоэзия"],
    "неправда": ["ложь", "лживость", "кривда", "враньё", "враки", "брехня", "несправедливость", "неправедность", "обман", "мошенничество"],
    "неправдоподобие": ["неправдоподобье", "неправдоподобность"],
    "неправдоподобный": ["невероятный"],
    "неправильно": ["неверно", "ошибочно", "ложно", "некорректно"],
    "неправильный": ["нестандартный", "неверный", "ошибочный", "непропорциональный", "несимметричный", "исключительный"],
    "неправомерный": ["незаконный", "противозаконный", "противоправный", "недозволенный", "преступный", "нелегальный", "запрещённый", "запретный", "воспрещённый"],
    "неправосудие": ["шемякин суд", "беззаконие"],
    "неправосудно": ["незаконно", "противозаконно"],
    "неправота": ["несостоятельность", "ошибочность", "несправедливость"],
    "неправый": ["ошибочный", "неправильный", "несправедливый", "неправедный"],
    "непредвзято": ["объективно"],
    "непредвзятость": ["непредубеждённость"],
    "непредвзятый": ["объективный"],
    "непредвиденный": ["неожиданный", "непредсказуемый", "непредусмотренный", "нежданный"],
    "непреднамеренный": ["неумышленный"],
    "непредотвратимо": ["неизбежно", "неминуемо", "неотвратимо", "непременно", "обязательно", "фатально"],
    "непредотвратимый": ["неизбежный"],
    "непредсказуемость": ["непрогнозируемость", "внезапность"],
    "непредубеденост": ["безпристрастие", "незаинтересованост"],
    "непредубеждённо": ["объективно", "нелицеприятно", "непредвзято", "беспристрастно", "невзирая на лица", "независимо"],
    "непредубеждённость": ["непредвзятость", "беспристрастие"],
    "непредубеждённый": ["беспристрастный", "непредвзятый"],
    "непредумышленно": ["неумышленно"],
    "непредумышленный": ["непреднамеренный", "ненамеренный", "неумышленный"],
    "непредусмотрительно": ["недальновидно", "неосторожно"],
    "непредусмотрительность": ["недальновидность"],
    "непрезентабельный": ["невзрачный", "неказистый", "непредставительный"],
    "непреклонно": ["непоколебимо", "твёрдо"],
    "непреклонность": ["несгибаемость", "стойкость", "непоколебимость"],
    "непреклонный": ["стойкий", "твёрдый", "несгибаемый", "непоколебимый"],
    "непрекословие": ["беспрекословие", "послушание", "смиренномудрие"],
    "непрекословный": ["безоговорочный", "безотговорочный", "беспрекословный"],
    "непреложный": ["нерушимый", "непреклонный"],
    "непременно": ["в любом случае", "обязательно", "определённо", "несомненно", "всенепременно", "непременнейше", "всенепременнейше"],
    "непременный": ["обязательный", "непреложный"],
    "непреодолимо": ["неодолимо"],
    "непреодолимый": ["неодолимый", "необоримый"],
    "непререкаемый": ["неоспоримый", "бесспорный", "безоговорочный", "беспрекословный"],
    "непрерывно": ["беспрестанно", "непрестанно", "постоянно"],
    "непрерывность": ["недискретность"],
    "непрерывный": ["беспрерывный", "непрестанный", "постоянный"],
    "непрестанно": ["неустанно", "постоянно"],
    "непрестанность": ["беспрерывность", "беспрестанность", "непрерывность"],
    "непрестанный": ["беспрерывный", "беспрестанный", "безостановочный", "непрерывный", "неустанный", "постоянный"],
    "непреходящий": ["вечный"],
    "неприветливость": ["недружелюбие", "нерадушие"],
    "неприветливый": ["нерадушный"],
    "непривитый": ["невакцинированный"],
    "неприводимость": ["приводимость"],
    "непривычный": ["необычный", "незнакомый", "непривыкший"],
    "неприглядный": ["малопривлекательный", "непривлекательный", "уродливый", "невзрачный", "безнравственный", "предосудительный", "некрасивый", "аморальный", "неэтичный"],
    "непригодный": ["негодный"],
    "неприемлемо": ["недопустимо", "неподходяще", "негоже", "неакцептабельно"],
    "неприемлемый": ["недопустимый"],
    "неприетин": ["врэжмаш", "душман", "потривник"],
    "непризнанье": ["непризнание"],
    "неприкасаемый": ["пария", "изгой", "неприкосновенный"],
    "неприкаянность": ["одиночество", "неустроенность"],
    "неприкаянный": ["неустроенный", "бесприютный"],
    "неприкосновенность": ["целость", "целостность"],
    "неприкосновенный": ["заветный", "сокровенный", "священный", "святой", "дорогой", "задушевный", "тайный", "заповедный"],
    "неприкосновенный запас": ["нз"],
    "неприлежно": ["халатно", "спустя рукава"],
    "неприлично": ["неподобающе", "непристойно"],
    "неприличный": ["интимный"],
    "неприличье": ["неприличие"],
    "неприметный": ["незаметный", "заурядный", "рядовой"],
    "непримечательный": ["неприметный", "малозаметный", "малоприметный", "заурядный", "скромный"],
    "непринуждённо": ["естественно"],
    "непринуждённость": ["безыскусственность", "раскованность", "непосредственность", "натуральность", "нескованность"],
    "непринципиальный": ["беспринципный", "маловажный", "незначительный"],
    "неприручённый": ["дикий"],
    "непристойность": ["неприличность", "неприличие", "неприличье"],
    "непристойный": ["бесстыдный", "непотребный", "неприличный"],
    "неприступнее": ["неприступней"],
    "неприступней": ["неприступнее"],
    "непритязательный": ["неприхотливый"],
    "неприхотливость": ["непритязательность", "нетребовательность", "простота", "незатейливость"],
    "неприхотливый": ["непритязательный"],
    "непричёсанный": ["нечёсаный", "растрёпанный", "беспорядочный", "неупорядоченный"],
    "неприязненно": ["враждебно", "недобро"],
    "неприязненность": ["недружелюбность", "враждебность"],
    "неприязнь": ["нелюбовь", "нерасположение", "недоброхотство", "неприязненность", "неприятство", "отвращение", "антагонизм"],
    "неприятель": ["противник", "ворог", "враг", "супостат", "супротивник", "недоброжелатель", "недоброхот", "недруг"],
    "неприятельский": ["вражеский"],
    "неприятие": ["несогласие", "неприязнь"],
    "неприятно": ["отталкивающе"],
    "неприятность": ["отвратительность", "огорчение", "затруднение"],
    "неприятный": ["противный", "нежелательный"],
    "неприятье": ["неприятие"],
    "непробудно": ["беспробудно", "без задних ног"],
    "непроверенный": ["неапробированный", "неподтверждённый", "недостоверный", "сомнительный"],
    "непроглядный": ["беспроглядный", "кромешный", "безрадостный", "безотрадный", "безнадежный", "беспросветный"],
    "непрогредиентный": ["неусугубляющийся"],
    "непродолжительный": ["кратковременный", "недолгий", "краткий", "короткий"],
    "непродуманно": ["необдуманно"],
    "непродуманный": ["необдуманный", "опрометчивый", "безрассудный", "маразматический", "нерассудительный", "малообдуманный", "авантюристичный", "невзвешенный", "малопродуманный", "скороспелый", "неосторожный"],
    "непроезжий": ["непроходимый"],
    "непрожорливый": ["крепкий к корму"],
    "непрозорливый": ["непроницательный"],
    "непрозрачный": ["сплошной"],
    "непроизвольно": ["невольно", "автоматически"],
    "непроизвольный": ["невольный"],
    "непроизносимый": ["труднопроизносимый", "немой"],
    "непролазный": ["непроходимый"],
    "непроливайка": ["чернильница-непроливайка", "непроливашка", "чернильница-невыливайка", "чернилка-непроливайка"],
    "непромокаемый": ["водонепроницаемый", "водоотталкивающий"],
    "непропай": ["неспай"],
    "непропорциональный": ["негармоничный"],
    "непросто": ["не просто", "сложно"],
    "непростой": ["сложный"],
    "непротивленье": ["непротивление"],
    "непротиворечивый": ["однозначный"],
    "непроторённый": ["неизвестный", "новый"],
    "непрофессионал": ["дилетант", "любитель", "неспециалист", "профан", "аматор"],
    "непрофессионализм": ["непрофессиональность"],
    "непрофессионально": ["кустарно", "любительски"],
    "непроходимый": ["полный", "совершенный", "абсолютный", "безнадёжный"],
    "непрошеный": ["незваный"],
    "непрояснённость": ["неясность", "неопределённость"],
    "непрояснённый": ["неясный"],
    "непрямо": ["косвенно"],
    "непрямой": ["кривой", "обходной", "окольный", "кружный", "неоткровенный", "неискренний", "уклончивый", "косвенный", "побочный"],
    "непрямолинейный": ["прямой"],
    "нептун": ["посейдон"],
    "нептунист": ["вернерианец"],
    "непутный": ["непутёвый"],
    "непутным матом": ["благим матом", "божьим матом", "дурным матом", "лихим матом", "недаровым матом"],
    "непутёвый": ["бестолковый", "безалаберный"],
    "непьющий": ["трезвенник"],
    "непьяный": ["трезвый"],
    "неработающий": ["безработный", "нетрудящийся", "нерабочий", "недействующий", "нефункционирующий"],
    "нерабочий": ["сломанный", "сломавшийся", "непригодный"],
    "неравнозначный": ["неравноценный", "неэквивалентный"],
    "неравномернозернистый": ["неравномерно-зернистый"],
    "неравномерный": ["нерегулярный"],
    "неравноценный": ["несоизмеримый", "несравнимый", "несопоставимый"],
    "нерадение": ["нерадивость", "небрежение"],
    "нераденье": ["нерадение"],
    "нерадивость": ["недобросовестность", "халатность", "небрежность", "леность", "ленивость", "неряшливость", "нерадение", "невнимательность", "неаккуратность", "неохотность", "лень", "ленца"],
    "нерадивый": ["недобросовестный", "нерачительный", "халатный"],
    "нерадостный": ["грустный"],
    "неразбериха": ["куролесица", "бестолковщина", "беспорядок"],
    "неразбория": ["безредие", "безредица", "безпорядък"],
    "неразборчиво": ["нечётко", "неразличимо"],
    "неразборчивый": ["невнятный", "непонятный", "нечёткий", "нетребовательный", "невзыскательный", "беспринципный"],
    "неразведённый": ["неразбавленный"],
    "неразговорчиво": ["молчаливо", "немногословно"],
    "неразговорчивый": ["несловоохотливый", "немногословный"],
    "неразделимый": ["неделимый", "нераздельный", "неотделимый"],
    "нераздельный": ["безраздельный"],
    "неразделённый": ["неподелённый", "безответный"],
    "неразрушенный": ["целый"],
    "неразуменье": ["неразумение"],
    "неразумность": ["неразумие", "неразумье"],
    "неразумье": ["неразумие"],
    "нерасположение": ["неприязнь", "антипатия", "недружелюбность", "недоброжелательство", "недоброжелательность", "недоброхотство"],
    "нерасположенье": ["нерасположение"],
    "нерасторопный": ["медлительный", "неповоротливый", "копучий"],
    "нерациональность": ["бессмысленность", "нецелесообразность", "иррациональность"],
    "нерачительный": ["нерадивый"],
    "нервация": ["нерватура"],
    "нервив": ["нервивши"],
    "нервивши": ["нервив"],
    "нервировав": ["нервировавши"],
    "нервировавши": ["нервировав"],
    "нервировать": ["раздражать", "действовать на нервы"],
    "нервишки": ["нервы"],
    "нервничав": ["нервничавши"],
    "нервничавши": ["нервничав"],
    "нервничанье": ["нервничание"],
    "нервничать": ["волноваться", "беспокоиться"],
    "нервнобольной": ["невротический"],
    "нервность": ["нервозность"],
    "нервы": ["нервишки"],
    "нервяк": ["нервозность", "тревожность"],
    "нереалистический": ["нереалистичный"],
    "нереально": ["ирреально", "обманчиво", "иллюзорно", "фантастично", "невозможно", "невыполнимо", "недостижимо", "несбыточно", "утопично"],
    "нереальность": ["фантастичность", "сказочность", "невыполнимость", "неосуществимость"],
    "нереальный": ["воображаемый"],
    "нерегулируемый": ["неконтролируемый"],
    "нерегулярный": ["иррегулярный"],
    "нередкий": ["частый", "обычный"],
    "нередко": ["зачастую", "часто"],
    "нерейтинговый": ["низкорейтинговый"],
    "нерелевантный": ["иррелевантный", "незначимый"],
    "нерелигиозность": ["иррелигиозность"],
    "нерелигиозный": ["безрелигиозный", "светский", "неверующий"],
    "неремонтируемый": ["неремонтопригодный", "неисправляемый"],
    "неремонтопригодный": ["изношенный", "сломанный"],
    "нерентабельно": ["невыгодно", "убыточно"],
    "нерентабельный": ["бесприбыльный", "невыгодный"],
    "нерестовав": ["нерестовавши"],
    "нерестовавши": ["нерестовав"],
    "нереферентный": ["неиндивидуализированный", "обобщённый", "безличный", "чуждый"],
    "нерешимость": ["нерешительность"],
    "нерешительно": ["несмело", "робко", "неуверенно"],
    "нерешительный": ["несмелый", "робкий"],
    "нержавейка": ["нержавеющая сталь", "нержавсталь", "нержавка"],
    "неритмичный": ["аритмичный"],
    "нерка": ["красная", "красница"],
    "нероба": ["нероб", "ледар", "гультяй"],
    "неробкий": ["безбоязненный", "бесстрашный", "героический", "геройский", "дерзновенный", "лишенный боязни", "мужественный", "не знающий страха", "не робкого десятка", "не трусливого десятка", "небоязливый", "неустрашимый", "отважный", "рисковый", "смелый"],
    "неровно": ["негладко", "шероховато", "криво", "непрямо", "неодинаково", "сбивчиво", "неравномерно", "вдруг", "чем чёрт не шутит", "чего доброго", "не дай бог"],
    "неровность": ["извилистость", "ухабистость", "пересечённость", "бугристость"],
    "неровный": ["негладкий", "шероховатый"],
    "неродимый": ["чужой", "неродной"],
    "неродной": ["чужой", "далёкий"],
    "неродовитый": ["незнатный"],
    "неролиевое масло": ["флердоранжевое масло"],
    "нероссийский": ["иностранный"],
    "нерпий": ["нерпичий", "нерповый"],
    "нерпичий": ["нерпий", "нерповый"],
    "нерукопожатность": ["нерукоподатность"],
    "нерукопожатный": ["нерукоподатный", "нерукоподаваемый"],
    "нерукотворный": ["нерукотворенный"],
    "нерусь": ["инородец", "русофоб"],
    "нерушимый": ["несокрушимый", "незыблемый"],
    "нерфить": ["нёрфить"],
    "неряшливо": ["небрежно", "неаккуратно"],
    "неряшливость": ["неаккуратность", "неопрятность"],
    "неряшливый": ["неопрятный", "неаккуратный", "небрежный"],
    "несамородный": ["неестественный", "искуственный", "несамостоятельный"],
    "несамостоятельность": ["зависимость"],
    "несбыточный": ["неисполнимый", "неосуществимый"],
    "несварение": ["диспепсия"],
    "несваренье": ["несварение"],
    "несвобода": ["неволя", "зависимость", "рабство"],
    "несвободный": ["женатый", "замужняя"],
    "несвоевременно": ["не вовремя"],
    "несвойственно": ["нехарактерно"],
    "несвяст": ["безсъзнание", "шемет", "безчувственост", "припадък"],
    "несгибаемый": ["непреклонный", "твёрдый", "стойкий"],
    "несговорчивость": ["неуступчивость"],
    "несговорчивый": ["неуступчивый"],
    "несгода": ["трудност", "неудобство"],
    "несграбный": ["неуклюжий", "нескладный", "неловкий", "нелепый"],
    "несдержанность": ["невыдержанность", "невыдержка", "нетерпение", "нетерпенье", "невоздержанность"],
    "несдержанный": ["необузданный", "непроизвольный"],
    "несдобровав": ["несдобровавши"],
    "несдобровавши": ["несдобровав"],
    "несдобровать": ["поздоровиться"],
    "неседален": ["акафист"],
    "несезон": ["мёртвый сезон"],
    "несейсмический": ["несейсмичный"],
    "несейсмичный": ["несейсмический"],
    "несерийный": ["штучный"],
    "несерьёзно": ["в шутку"],
    "несерьёзный": ["легкомысленный", "беспечный", "ветреный", "неосновательный", "неважный", "незначительный"],
    "несильно": ["слабо"],
    "несимпатичный": ["малосимпатичный", "неприятный"],
    "несинхрон": ["асинхрон"],
    "несинхронный": ["асинхронный"],
    "несистематический": ["несистематичный"],
    "несистематичный": ["несистематический"],
    "несказанно": ["невыразимо", "в высшей степени"],
    "несказанный": ["неописуемый", "чрезвычайный"],
    "нескладно": ["неуклюже", "вразлад"],
    "нескладёха": ["бестолочь"],
    "несклонность": ["нежелание", "нелюбовь"],
    "несклоняемый": ["беспадежный", "непреклонный"],
    "несколько": ["немного", "сколько-то"],
    "нескошенный": ["несрезанный"],
    "нескучно": ["интересно"],
    "нескучный": ["интересный", "занимательный", "увлекательный"],
    "неслабый": ["яркий", "впечатляющий", "отличный"],
    "неславити": ["ганьбити"],
    "несладко": ["трудно"],
    "неслиянность": ["отдельность"],
    "несловесный": ["невербальный"],
    "несловоохотливый": ["неразговорчивый", "немногословный"],
    "неслогообразующий": ["неслоговой"],
    "несложно": ["легко", "незатейливо", "просто"],
    "несложность": ["лёгкость", "простота"],
    "несложный": ["простой", "лёгкий", "нетрудный"],
    "неслух": ["ослушник"],
    "неслыханный": ["небывалый", "беспрецедентный", "беспримерный", "поразительный"],
    "неслышно": ["тихо", "бесшумно", "беззвучно", "незаметно"],
    "несмекалистый": ["несообразительный"],
    "несмело": ["робко", "боязливо", "трусливо"],
    "несмелый": ["робкий", "нерешительный"],
    "несмертельный": ["нелетальный"],
    "несметный": ["бесчисленный", "бессчётный", "несчётный", "неисчислимый", "огромный", "немереный"],
    "несмеющийся": ["неулыбчивый"],
    "несмолкаемо": ["неумолкаемо"],
    "несмолкающий": ["неумолкающий", "неумолчный"],
    "несмотря": ["вопреки", "невзирая на"],
    "несмотря на": ["невзирая на", "хоть", "хотя"],
    "несмотря ни на что": ["и никаких гвоздей"],
    "несмышлёный": ["несмысленный"],
    "несмышлёныш": ["глупыш"],
    "несносно": ["мучительно", "тошно"],
    "несносность": ["невыносимость"],
    "несносный": ["невыносимый", "неприятный", "надоедливый"],
    "несовершеннолетие": ["малолетство"],
    "несовершеннолетний": ["неполнолетний"],
    "несовершеннолетняя": ["невзрослая"],
    "несовершенный": ["небезупречный"],
    "несовместимо": ["несочетаемо"],
    "несовместимость": ["несовместность", "противоречивость", "противоречие", "несоответствие"],
    "несовместимый": ["несовместный", "противоречивый", "несоответствующий", "несочетающийся", "противообразный"],
    "несовпадение": ["расхождение", "отклонение"],
    "несовпаденье": ["несовпадение"],
    "несогласие": ["разногласие", "раздор", "разлад", "ссора", "несогласица", "отказ"],
    "несогласованно": ["недружно", "нескладно", "неслаженно", "нестройно", "разрозненно"],
    "несогласье": ["несогласие"],
    "несозвучность": ["диссонанс"],
    "несозвучный": ["диссонирующий"],
    "несозревший": ["неспелый", "незрелый"],
    "несоизмеримость": ["несопоставимость"],
    "несокрушимый": ["незыблемый", "неколебимый", "непоколебимый", "стойкий", "непобедимый", "неуязвимый"],
    "несолидность": ["несерьёзность"],
    "несолоно хлебавши": ["безрезультатно"],
    "несомненно": ["без сомнения", "бесспорно"],
    "несомненный": ["бесспорный", "очевидный"],
    "несоответствие": ["несоответственность", "несогласованность", "противоречие"],
    "несопоставимый": ["несравнимый"],
    "несоставной": ["цельный", "монолитный", "сплошной", "неразделимый"],
    "несостыковка": ["несогласованность", "неувязка"],
    "несостыковочка": ["неувязочка"],
    "несочетаемый": ["несочетающийся", "противообразный"],
    "неспелый": ["недоспелый", "недозрелый", "зелёный"],
    "неспециалист": ["любитель", "аутсайдер", "профан", "дилетант"],
    "неспецифический": ["неособенный"],
    "неспешно": ["не спеша", "медленно", "потихоньку"],
    "неспешность": ["неторопливость"],
    "неспешный": ["неторопливый", "размеренный"],
    "несподручно": ["неудобно", "не с руки"],
    "неспокойность": ["подвижность", "динамичность", "нестабильность", "неустойчивость", "беспокойства"],
    "неспокойный": ["беспокойный"],
    "несполука": ["неудача", "неуспех"],
    "неспорный": ["бесспорный"],
    "несправедливость": ["неправедность", "незаслуженность"],
    "неспроста": ["не просто так", "недаром"],
    "несравненный": ["несравнимый", "бесподобный", "неподражаемый", "непревзойдённый", "неповторимый"],
    "несравнимый": ["несравненный"],
    "несрета": ["нерадост", "нещастие", "злощастие", "злочестина", "беда"],
    "несретник": ["бездомник", "бедняк", "голтак", "босяк", "скитник", "неудачник", "непрокопсаник"],
    "нестабильный": ["изменчивый", "непостоянный"],
    "нестандартка": ["некондиционка"],
    "нестандартный": ["своеобразный"],
    "нестарый": ["молодой", "младой"],
    "нестатный": ["некрасивый", "неказистый"],
    "нестаточный": ["неподобающий"],
    "нестационарность": ["изменчивость", "переменность"],
    "нестерпимость": ["невыносимость", "непереносимость"],
    "нестерпимый": ["невыносимый", "непереносимый"],
    "нестеснённость": ["вольность", "свобода"],
    "нестеснённый": ["неограниченный"],
    "нести": ["транспортировать", "увлекать", "держать", "удерживать", "подпирать", "доносить", "давать", "переживать", "испытывать", "терпеть", "тянуть", "сквозить", "молоть", "городить", "вякать"],
    "нести ахинею": ["нести чушь", "молоть чушь", "пороть чушь", "нести пургу", "ахинею нести", "чушь нести", "чушь молоть", "чушь пороть", "пургу нести"],
    "нести околесицу": ["нести чушь"],
    "нести пургу": ["гнать пургу"],
    "нестись": ["мчаться", "мчать", "распространяться", "разноситься", "доноситься"],
    "нестомчивость": ["неутомимость"],
    "нестомчивый": ["неутомимый"],
    "нестратегический": ["тактический"],
    "нестрашно": ["неопасно"],
    "нестрогий": ["мягкий", "добродушный", "неточный"],
    "нестроенье": ["нестроение"],
    "нестыковочка": ["неувязочка", "ошибочка"],
    "несть": ["нет", "нету"],
    "нестяжание": ["бескорыстие", "бескорыстность", "нестяжательство"],
    "несуразица": ["нелепица", "бессмыслица"],
    "несуразно": ["нелепо", "глупо", "несообразно", "неуместно", "неадекватно"],
    "несуразность": ["нелепость", "несуразица"],
    "несуразный": ["нелепый", "несообразный", "нескладный", "нестатный", "безобразный", "неуклюжий"],
    "несусветица": ["нелепость", "глупость", "бессмыслица", "несуразица", "несусветность"],
    "несусветное": ["нелепость", "нелепица", "несуразица", "несусветица", "несуразность", "несусветность"],
    "несусветный": ["невероятный", "невообразимый", "немыслимый", "неимоверный", "необычайный", "неправдоподобный", "вздорный", "нелепый", "несосветимый", "экстремальный", "безумный"],
    "несущественный": ["второстепенный"],
    "несуществование": ["небытие"],
    "несуществованье": ["несуществование"],
    "несхожесть": ["непохожесть"],
    "несхожий": ["несходный", "различный"],
    "несчастие": ["несчастье"],
    "несчастливец": ["бедняга", "бедолага", "горемыка"],
    "несчастливица": ["бедняга", "бедолага", "горемыка"],
    "несчастливо": ["несчастно"],
    "несчастливый": ["несчастный", "неудачливый"],
    "несчастная любовь": ["неразделённая любовь"],
    "несчастно": ["несчастливо"],
    "несчастный": ["бедный", "горький", "злосчастный", "жалостливый", "злополучный", "бедолага"],
    "несчастный случай": ["трагедия"],
    "несчастье": ["беда", "бедствие", "горе", "горесть", "драма", "злоключение", "злополучие", "невзгода", "трагедия", "удар", "зарез", "злоключенье", "злосчастье", "бездолье", "злосчастие"],
    "несчётный": ["бессчётный", "неисчислимый", "бесчисленный"],
    "несъёжившийся": ["несморщенный"],
    "несытый": ["голодный"],
    "нет": ["не-а", "нету", "нема"],
    "нет дыма без огня": ["неспроста"],
    "нет-арт": ["интернет-арт"],
    "нет-нет": ["нет"],
    "нетактичный": ["бестактный"],
    "нетакусик": ["нетакуся"],
    "нетакуся": ["нетакусик"],
    "неталантливый": ["бездарный"],
    "нетаниягу": ["нетаньяху"],
    "нетаньяху": ["нетаниягу"],
    "нетапыр": ["лятучая мыш", "кажан"],
    "нетбук": ["субноутбук"],
    "нетвойнист": ["пацифист", "нетвойняшка"],
    "нетвойняшка": ["нетвойнист"],
    "нетвёрдо": ["неустойчиво"],
    "нетель": ["яловка", "яловица"],
    "нетерпение": ["нетерпенье"],
    "нетерпенье": ["нетерпение"],
    "нетерпимость": ["нестерпимость", "ненависть", "непримиримость"],
    "нетерпимый": ["недопустимый", "неприемлемый"],
    "нетерпёж": ["нетерпение"],
    "нетипично": ["малохарактерно"],
    "нетипичный": ["атипичный", "нехарактерный"],
    "нетленный": ["вечный", "бессмертный"],
    "нетленье": ["нетление"],
    "нетоварный": ["непривлекательный", "неприглядный"],
    "нетовец": ["спасовец"],
    "нетоксичный": ["невредный"],
    "нетолерантность": ["интолерантность"],
    "нетолерантный": ["интолерантный"],
    "нетолстый": ["нежирный", "худой"],
    "неторный": ["непроторённый"],
    "неторопкий": ["неторопливый", "неспешный", "несуетливый", "спокойный"],
    "неторопливо": ["медленно"],
    "неторопливый": ["медлительный", "неспешный"],
    "неточно": ["некорректно", "неясно", "неправильно"],
    "неточность": ["погрешность", "приблизительность", "нестрогость", "несоответствие", "ошибка"],
    "неточный": ["приблизительный"],
    "нетрадиционалист": ["нетрадиционник"],
    "нетрадиционная медицина": ["альтернативная медицина"],
    "нетрадиционник": ["нетрадиционалист"],
    "нетрадиционно": ["необычно", "по-новому"],
    "нетрезвый": ["пьяный"],
    "нетривиально": ["нестандартно", "своеобразно", "оригинально", "неповторимо", "своеобычно", "нетрадиционно", "самобытно", "неординарно"],
    "нетривиальный": ["неочевидный", "сложный", "оригинальный", "необычный"],
    "нетронутый": ["целый"],
    "нетрудный": ["несложный", "лёгкий", "простой"],
    "нету": ["нет", "не", "иметься", "отсутствовать"],
    "нетусовочный": ["некомпанейский"],
    "нетушки": ["фигушки", "нет"],
    "нетяжёлый": ["лёгкий", "необременительный", "нетрудный", "неопасный"],
    "неубедительный": ["малоубедительный", "несостоятельный"],
    "неубиенный": ["бессмертный"],
    "неубыточность": ["прибыльность", "эффективность затрат"],
    "неуважаемый": ["неавторитетный", "малопочтенный"],
    "неуважение": ["непочтительность", "непочтение"],
    "неуваженье": ["неуважение"],
    "неуверенно": ["робко", "скованно"],
    "неувязка": ["нестыковка"],
    "неувязочка": ["несостыковочка"],
    "неугнетённый": ["неподавленный", "неразбитый"],
    "неугодный": ["нежелательный", "ненужный"],
    "неугомонный": ["говорливый", "неуспокаивающийся", "беспокойный"],
    "неуд": ["неудовлетворительно", "двойка"],
    "неудавшийся": ["неполучившийся", "неудачный", "несостоявшийся"],
    "неудачливость": ["невезучесть"],
    "неудачливый": ["невезучий", "незадачливый"],
    "неудачник": ["аутсайдер", "лузер", "несчастливец"],
    "неудачница": ["несчастливица", "страдалица", "лузерша"],
    "неудачно": ["безуспешно", "вотще", "неблагоприятно", "неуспешно", "провально", "безрезультатно"],
    "неудачность": ["безуспешность"],
    "неудачный": ["безуспешный", "провальный", "неудовлетворительный"],
    "неудержимый": ["неукротимый"],
    "неудобица": ["неудобь", "неудобье"],
    "неудобно": ["неловко", "некомфортно", "дискомфортно", "неуместно", "неприлично"],
    "неудобный": ["несподручный", "дискомфортный", "неприятный", "неуместный"],
    "неудобоваримый": ["невразумительный", "непонятный"],
    "неудобь": ["невозможно"],
    "неудовлетворительно": ["неуд", "плохо"],
    "неужели": ["неужто", "разве", "не уже ли"],
    "неужто": ["неужели"],
    "неузкий": ["широкий", "просторный"],
    "неуклонно": ["неотступно"],
    "неуклонный": ["стабильный", "постоянный", "непрестанный", "твёрдый"],
    "неуклюже": ["неловко", "неповоротливо"],
    "неуклюжесть": ["неповоротливость", "неловкость"],
    "неуклюжий": ["неловкий", "нескладный", "неповоротливый"],
    "неукоснительно": ["строго", "в точности"],
    "неукоснительность": ["строгость"],
    "неукоснительный": ["безусловный", "обязательный"],
    "неукротимый": ["неодолимый", "неудержимый"],
    "неуловимий": ["невловимий", "неуловний"],
    "неуловимо": ["незаметно", "неощутимо"],
    "неуловимый": ["неощутимый", "незаметный"],
    "неулыба": ["несмеяна"],
    "неумейка": ["недотёпа"],
    "неумело": ["непривычно", "неловко"],
    "неумелый": ["неловкий", "неопытный"],
    "неуменье": ["неумение"],
    "неумеренный": ["невоздержанный"],
    "неуместно": ["некстати", "неподходяще", "неприемлемо"],
    "неуместный": ["неподобающий", "неудачный"],
    "неумеха": ["недотёпа"],
    "неумирающий": ["бессмертный"],
    "неумирущий": ["невмирущий", "немрущий"],
    "неумный": ["глупый"],
    "неумойка": ["грязнуля", "неряха", "неумыва", "неумывака", "неумыха", "неумытик", "неумой", "чумичка", "грязнушка", "замарашка"],
    "неумолимо": ["безжалостно", "непреклонно", "непреложно", "неотвратимо"],
    "неумолимый": ["безжалостный", "непреклонный", "неотвратимый", "непреложный"],
    "неумолчно": ["без умолку"],
    "неумытое рыло": ["немытое рыло"],
    "неумытый": ["невымытый"],
    "неумышленно": ["нечаянно"],
    "неумышленный": ["непреднамеренный"],
    "неумёха": ["недотёпа", "кулёма"],
    "неуничтожаемый": ["неуничтожимый"],
    "неуничтожимый": ["неуничтожаемый"],
    "неунывающий": ["беззаботный", "веселый", "жизнерадостный", "бодрый"],
    "неупотребление": ["неиспользование"],
    "неуравновешенный": ["несбалансированный", "взбалмошный"],
    "неурезанный": ["полный", "целый", "цельный", "несокращённый", "неукороченный"],
    "неурожай": ["недород"],
    "неурочность": ["несвоевременность"],
    "неурядица": ["дисгармония", "беспорядок", "неустройство", "разлад", "ссора"],
    "неуспешность": ["неудачность", "безуспешность"],
    "неуспешный": ["неудачный", "безуспешный"],
    "неуставные отношения": ["дедовство", "дедовщина", "стариковство", "стариковщина"],
    "неуставняк": ["неуставуха", "дедовщина", "годковщина"],
    "неуставуха": ["дедовщина", "неуставняк"],
    "неустанно": ["постоянно", "непрестанно", "без устали", "неутомимо", "непрерывно"],
    "неустановленный": ["неопределённый"],
    "неустойчиво": ["шатко"],
    "неустойчивый": ["нестабильный", "непостоянный", "переменный", "изменчивый", "шаткий", "переменчивый", "непрочный"],
    "неустрашимый": ["смелый", "бесстрашный"],
    "неуступчивый": ["несговорчивый"],
    "неусыпно": ["неослабно"],
    "неусыпный": ["неутомимый", "непрестанный", "беспрестанный", "недремлющий", "бдительный"],
    "неутешительный": ["огорчительный"],
    "неутешный": ["безутешный"],
    "неутилизируемый": ["неперерабатываемый"],
    "неутомимый": ["неутрудимый"],
    "неутрудимый": ["неутомимый"],
    "неухоженность": ["неопрятность", "запущенность"],
    "неуч": ["невежда"],
    "неученье": ["необразованность", "невежество"],
    "неучтивость": ["невежливость", "непочтительность"],
    "неучтивый": ["невежливый", "непочтительный"],
    "неучтёнка": ["левак"],
    "неуютно": ["некомфортно", "неудобно"],
    "неуютный": ["дискомфортный"],
    "неуязвимость": ["живучесть", "невосприимчивость", "несокрушимость"],
    "неуязвимый": ["недосягаемый", "безупречный"],
    "неуёмность": ["неудержимость", "неукротимость", "безудержность"],
    "неуёмный": ["неудержимый"],
    "нефелин": ["элеолит"],
    "неферментативное гликозилирование": ["гликирование"],
    "нефиксированный": ["незакреплённый", "шаткий", "плавающий", "нестабильный"],
    "нефилим": ["исполин", "наблюдатель", "гигант", "титан", "рефаим", "эймим", "гиборим", "замзумим", "анаким", "авим"],
    "нефинитный": ["неличный"],
    "нефор": ["неформал"],
    "неформал": ["нефор"],
    "неформально": ["неофициально"],
    "нефролитиаз": ["почечнокаменная болезнь"],
    "нефромегалический": ["гепатонефромегальный"],
    "нефтебарон": ["нефтегенерал", "нефтекороль", "нефтемагнат", "нефтеолигарх"],
    "нефтебизнесмен": ["нефтеделец"],
    "нефтегазонакопление": ["газонефтенакопление"],
    "нефтегенерал": ["нефтебарон", "нефтекороль", "нефтемагнат", "нефтеолигарх"],
    "нефтеделец": ["нефтебизнесмен"],
    "нефтекороль": ["нефтебарон", "нефтегенерал", "нефтемагнат", "нефтеолигарх"],
    "нефтеловушка": ["нефтеуловитель"],
    "нефтемагнат": ["нефтебарон", "нефтегенерал", "нефтекороль", "нефтеолигарх"],
    "нефтеолигарх": ["нефтебарон", "нефтегенерал", "нефтекороль", "нефтемагнат"],
    "нефтестроевец": ["нефтестроитель"],
    "нефтестроитель": ["нефтестроевец"],
    "нефтетрейдерство": ["нефтетрейдинг"],
    "нефтетрейдинг": ["нефтетрейдерство"],
    "нефтехранилище": ["нефтебаза", "нефтетерминал"],
    "нефтида": ["небетхет"],
    "нефтис": ["нефтида", "небетхет"],
    "нефть": ["чёрное золото"],
    "нефункциональный": ["неделовой", "непрактичный"],
    "нехай": ["пусть", "пускай", "пущай", "ладно"],
    "нехайност": ["нехайство", "немарливост", "небрежност"],
    "нехбет": ["нехебт"],
    "нехватав": ["нехватавши"],
    "нехватавши": ["нехватав"],
    "нехватив": ["нехвативши"],
    "нехвативши": ["нехватив"],
    "нехватка": ["недостаток"],
    "нехебт": ["нехбет"],
    "нехитрый": ["простодушный", "простой", "незамысловатый", "несложный", "немудрёный"],
    "нехлебородный": ["неурожайный", "бесплодный"],
    "нехмед": ["немед"],
    "нехороший": ["плохой"],
    "нехорошо": ["плохо", "дурно", "худо"],
    "нехотенье": ["нехотение"],
    "нехотя": ["неохотно"],
    "нехристь": ["неверный", "безбожник", "злодей"],
    "нехуй": ["нех", "нехуя", "незачем", "нечего", "кончать", "прекращать", "не следует"],
    "нехуйный": ["неплохой", "отличный", "нехуёвый", "значительный", "впечатляющий", "потрясающий"],
    "нехуя": ["нечего"],
    "нехуёвый": ["неплохой", "отличный", "нехуйный", "значительный", "впечатляющий", "потрясающий"],
    "нецелесообразность": ["неразумность", "нерациональность", "бессмысленность", "неуместность", "неблагоразумность"],
    "нецелесообразный": ["неоправданный"],
    "нецелованный": ["чистый", "целомудренный"],
    "нецельный": ["составной", "раздробленный"],
    "нецензурно": ["непечатно"],
    "нецензурно выражаться": ["материться"],
    "нецентральный": ["периферийный"],
    "нецеремонный": ["бесцеремонный", "невежливый", "неделикатный", "беззастенчивый", "развязный"],
    "неча": ["нечего"],
    "нечасто": ["редко"],
    "нечастый": ["редкий"],
    "нечаянно": ["ненароком", "непреднамеренно", "невольно", "случайно"],
    "нечаянный": ["неожиданный", "внезапный", "нежданный", "неожидавшийся", "нечаемый", "случайный", "ненамеренный", "неумышленный"],
    "нечего говорить": ["понятно"],
    "нечего греха таить": ["что греха таить", "чего греха таить"],
    "нечепура": ["нечепуруха"],
    "нечернозёмка": ["нечерноземье"],
    "нечестивый": ["безбожник"],
    "нечестный": ["бесчестный"],
    "нечесть": ["нечестие", "бесчестие"],
    "нечестье": ["нечестие"],
    "нечистая сила": ["нечисть"],
    "нечистоты": ["отбросы", "помои"],
    "нечистый": ["грязный", "загрязнённый", "неаккуратный", "топорный", "мошеннический", "обманный", "потусторонний", "дьявольский", "дьявол", "чёрт", "бес"],
    "нечистый на руку": ["нечестный", "вороватый"],
    "нечисть": ["нечистая сила", "нелюдь", "дрянь"],
    "нечитабельность": ["нечитаемость"],
    "нечитабельный": ["нечитаемый", "неудобочитаемый"],
    "нечитаемость": ["нечитабельность"],
    "нечитаемый": ["нечитабельный"],
    "нечленораздельно": ["невнятно", "неразборчиво"],
    "нечто": ["что-то", "кое-что"],
    "нечувствительно": ["неосязаемо", "неощутимо"],
    "нечя": ["неча"],
    "нечёрный": ["нетёмный", "светлый"],
    "нечёсаный": ["непричёсанный", "растрёпанный"],
    "нечёткий": ["размытый"],
    "нечётко": ["неразборчиво", "неясно", "неточно"],
    "нешаблонный": ["оригинальный", "небанальный", "неизбитый", "своеобразный", "остроумный"],
    "неширокий": ["узкий", "незначительный"],
    "нештатный": ["внештатный", "сверхштатный", "экстренный", "экстраординарный"],
    "нешто": ["неужели", "разве"],
    "нещадно": ["беспощадно", "безжалостно", "отчаянно", "сильно", "яростно"],
    "нещадный": ["безжалостный", "беспощадный"],
    "нещепетильный": ["бессовестный", "беспринципный", "неразборчивый"],
    "нещечко": ["нечто", "кое-что"],
    "неэвклидов": ["неевклидов"],
    "неэквивалентный": ["неравнозначный", "неравноценный"],
    "неэлитарно": ["общедоступно"],
    "неэтичность": ["аморальность"],
    "неяв": ["неявши"],
    "неявно": ["имплицитно"],
    "неявный": ["имплицитный", "скрытый", "подразумеваемый"],
    "неявши": ["неяв"],
    "неяркий": ["тусклый"],
    "неярко": ["тускло"],
    "неясно": ["пасмурно", "смутно", "неочевидно", "непонятно"],
    "неясность": ["неопределённость", "недостоверность", "сомнительность"],
    "неясный": ["нечёткий", "неразборчивый", "невнятный", "неопределённый", "смутный", "путанный", "непонятный", "непостижимый", "недоступный", "заумный", "тёмный", "невразумительный", "противоречивый"],
    "ни абаза": ["ни гроша", "ни копейки"],
    "ни богу свечка ни чёрту кочерга": ["непутёвый", "ни рыба ни мясо", "ни то ни сё", "ни два ни полтора"],
    "ни в городе богдан ни в селе селифан": ["ни рыба ни мясо", "ни то ни сё", "ни два ни полтора", "ни богу свечка ни чёрту кочерга"],
    "ни в зуб": ["ни в зуб ногой", "ни в зуб ногой толкнуть", "ни в зуб галошей"],
    "ни в коем случае": ["любой ценой", "ни за что", "никоим образом"],
    "ни в одном глазу": ["как стёклышко", "бодрый"],
    "ни в хуй не ставить": ["не ставить ни в хуй", "в хуй не ставить"],
    "ни дай ни вынеси": ["ни за что ни про что", "за здорово живёшь", "просто так"],
    "ни два ни полтора": ["ни то ни сё", "ни да ни нет", "ни тпру ни ну", "ни богу свечка ни чёрту кочерга", "ни пава ни ворона", "ни пришей ни пристегни", "ни рыба ни мясо", "середина на половину", "серединка на половинку", "серёдка на половину"],
    "ни душой ни телом": ["ни сном ни духом"],
    "ни за какие коврижки": ["ни за что", "дудки"],
    "ни за понюх табаку": ["напрасно", "зазря", "зря", "безрезультатно", "бесполезно", "бессмысленно", "без толку", "впустую", "попусту", "понапрасну", "даром"],
    "ни за хуй": ["ни за что", "ни за что ни про что", "ни за хуй собачий"],
    "ни за что": ["никогда", "ни в коем случае", "ни при каких условиях", "просто так"],
    "ни зги не видно": ["хоть глаз выколи"],
    "ни к селу ни к городу": ["некстати", "невпопад", "неуместно", "не пришей кобыле хвост"],
    "ни к чему": ["без надобности", "бесполезный", "излишний", "лишний", "незачем", "ненадобный", "ненужный"],
    "ни ладу ни складу": ["ни складу ни ладу"],
    "ни на мизинец": ["ни в какой мере", "ни в какой степени", "ни в малейшей мере", "ни в малейшей степени", "совсем", "ничуть"],
    "ни о чём": ["ничего", "ни что", "обо всём"],
    "ни при чём": ["невинный", "невиноватый", "невиновный", "неповинный", "непричастный", "ни с чем", "с пустыми руками", "не при чем"],
    "ни пришей ни пристегни": ["не пришей кобыле хвост", "пришей кобыле хвост", "не пришей рукав", "ни богу свечка ни чёрту кочерга", "ни к селу ни к городу"],
    "ни разу": ["никогда", "так и не", "нисколько", "ничуть", "ни в коей мере", "ни в коей степени"],
    "ни рыба ни мясо": ["ни богу свечка ни чёрту кочерга", "ни то ни сё", "ни два ни полтора", "серединка на половинку", "серёдка на половинку", "божеский", "второй сорт", "не ах", "не ахти", "не бог весть какой", "не особенно", "не фонтан", "неважнецкий", "неважный", "так себе"],
    "ни с того ни с сего": ["беспричинно", "внезапно", "неожиданно", "ни с чёрта", "ни с хера", "ни с херов", "ни с хуя", "ни с хуёв"],
    "ни с хуя": ["беспричинно", "внезапно", "неожиданно", "ни с чёрта", "ни с хера", "ни с херов", "ни с хуёв"],
    "ни свет ни заря": ["до света", "до свету", "до рассвета", "спозаранку", "спозаранок", "до росы"],
    "ни складу ни ладу": ["ни ладу ни складу"],
    "ни сном ни духом": ["совершенно", "абсолютно"],
    "ни то ни сё": ["ни рыба ни мясо"],
    "ни фига себе": ["фигасе"],
    "ни хера": ["ни хрена", "ни фига", "ничего", "пусто"],
    "ни хрена": ["ни рожна"],
    "ни хуя себе": ["ну и ну", "ничего себе", "вот это да", "ни хрена себе", "ни хера себе", "ни хуя", "хуя себе", "хуясе", "нихуясе", "хуяссе", "ни хуя себе уха"],
    "ни хуя себе уха": ["ничего себе", "ну и ну", "вот это да", "вот это номер", "вот так номер", "ни хрена себе", "ни хера себе", "ни хуя", "ни хуя себе", "ни хуя уха"],
    "ни хуя уха": ["ничего себе", "ну и ну", "вот это да", "вот это номер", "вот так номер", "ни хрена себе", "ни хера себе", "ни хуя", "ни хуя себе", "ни хуя себе уха"],
    "ни шатко ни валко": ["средне", "средне-сдельно", "средней паршивости", "так себе", "не очень", "кое-как", "не ахти как", "не бог весть как", "не бог знает как", "ни хорошо ни плохо"],
    "ни-ни": ["ни-ни-ни"],
    "ниббана": ["нирвана"],
    "нибиру": ["неберу"],
    "ниблер": ["фидер"],
    "нива": ["нивушка"],
    "нивелировав": ["нивелировавши"],
    "нивелировавши": ["нивелировав"],
    "нивелирование": ["нивелировка"],
    "нивелировать": ["сглаживать"],
    "нивелировка": ["нивелирование", "нивелированье", "уравнивание", "уравниловка"],
    "нивелирующий": ["выравнивающий"],
    "нивеллятор": ["радикал", "коммунист", "коллективист", "социалист", "утопист", "революционер", "нигилист"],
    "нивесть": ["невесть"],
    "нивхка": ["нивхинка"],
    "нивяник": ["нивянка"],
    "нигга": ["негритос", "черномазый", "черножопый", "нигра", "уголёк", "шоколадка", "сникерс"],
    "ниггер": ["негритос", "черномазый", "черножопый", "нигра", "уголёк"],
    "нигелла": ["чёрный тмин", "чернушка", "чернушка посевная", "римский кориандр"],
    "нигер": ["республика нигер"],
    "нигерия": ["федеративная республика нигерия"],
    "нигири": ["нигиридзуси"],
    "нигиридзуси": ["нигири"],
    "нигоранда": ["адиб", "нависанда"],
    "нигростриарный": ["нигростриатный", "нигростриальный"],
    "нидерландец": ["голландец"],
    "нидерландка": ["голландка"],
    "нидерландский": ["голландский", "фламандский"],
    "нидерландский язык": ["нидерландский", "голландский язык"],
    "нидерландтар": ["нидерланд короллеге"],
    "нидерланды": ["голландия", "королевство нидерландов"],
    "ниеншанц": ["ниешанц", "шлотбург", "канец", "канцы"],
    "нижайший": ["наинизший"],
    "ниже": ["далее"],
    "нижегородская область": ["нижегородчина"],
    "нижеперечисленный": ["ниженазванный", "нижеозначенный", "нижеприведённый", "нижеследующий", "нижеуказанный", "нижеупомянутый", "следующий"],
    "нижеследующий": ["ниженазванный", "нижеуказанный", "нижеупомянутый"],
    "нижеуказанный": ["нижеупомянутый"],
    "нижеупомянутый": ["нижеуказанный"],
    "нижнее бельё": ["бельё", "исподнее"],
    "нижнелужицкий": ["нижнесорбский"],
    "нижнесаксонский": ["нижненемецкий язык", "нижнесаксонский язык"],
    "нижний": ["исподний", "низовой", "боттом"],
    "нижний египет": ["дельта", "та-меху"],
    "нижний новгород": ["нижний", "нино", "горький"],
    "нижняя": ["линтулан-йоки", "подгорная", "юля-йоки"],
    "нижняя грань": ["нижняя грань числового множества"],
    "нижняя грань числового множества": ["нижняя грань"],
    "низ-": ["нис-"],
    "низав": ["низавши"],
    "низавши": ["низав"],
    "низвергав": ["низвергавши"],
    "низвергавши": ["низвергав"],
    "низвергать": ["сбрасывать", "ниспровергать", "свергать", "развенчивать", "опровергать"],
    "низвергаться": ["падать", "валиться", "ниспровергаться"],
    "низвергнув": ["низвергнувши"],
    "низвергнувши": ["низвергнув"],
    "низвергнуть": ["скинуть", "сбросить", "свергнуть"],
    "низвергнуться": ["упасть", "свалиться"],
    "низверженье": ["низвержение"],
    "низвести": ["спустить", "понизить", "ниспослать", "унизить"],
    "низводив": ["низводивши"],
    "низводивши": ["низводив"],
    "низив": ["низивши"],
    "низивши": ["низив"],
    "низина": ["низы", "чернь"],
    "низить": ["снижать", "снижаться"],
    "низка": ["снизка"],
    "низкий": ["невысокий", "пониженный", "недостаточный", "неудовлетворительный", "подлый", "грубый", "басовый", "басистый"],
    "низко": ["невысоко", "низменно", "подло", "недостойно", "мало", "немного"],
    "низкобюджетный": ["малобюджетный"],
    "низкодисперсный": ["грубодисперсный", "крупнодисперсный"],
    "низкое": ["низменное"],
    "низкоинтенсивный": ["малоинтенсивный"],
    "низкой пробы": ["низкопробный"],
    "низкоквалифицированный": ["малоквалифицированный", "неквалифицированный"],
    "низкоконтрастный": ["малоконтрастный"],
    "низкооплачиваемый": ["невысокооплачиваемый"],
    "низкопоклонник": ["подхалим"],
    "низкопоклонничав": ["низкопоклонничавши"],
    "низкопоклонничавши": ["низкопоклонничав"],
    "низкопоклонничать": ["низкопоклонствовать"],
    "низкопоклонничество": ["низкопоклонство", "раболепие"],
    "низкопоклонство": ["низкопоклонничество"],
    "низкопоклонствовав": ["низкопоклонствовавши"],
    "низкопоклонствовавши": ["низкопоклонствовав"],
    "низкопоклонствовать": ["низкопоклонничать"],
    "низкопробный": ["низкий", "пошиб"],
    "низкорейтинговый": ["нерейтинговый"],
    "низкорослый": ["невысокий"],
    "низкоскоростной": ["малоскоростной"],
    "низкотоксичный": ["малотоксичный"],
    "низкоуровневый": ["простой", "примитивный"],
    "низкоэтажность": ["малоэтажность"],
    "низкоэтажный": ["малоэтажный"],
    "низлагав": ["низлагавши"],
    "низлагавши": ["низлагав"],
    "низлагать": ["скидывать", "повергать", "низвергать", "низводить", "ниспровергать", "свергать", "развенчивать", "опровергать"],
    "низлетав": ["низлетавши"],
    "низлетавши": ["низлетав"],
    "низлетев": ["низлетевши"],
    "низлетевши": ["низлетев"],
    "низложение": ["свержение"],
    "низложив": ["низложивши"],
    "низложивши": ["низложив"],
    "низо-": ["низ-", "нис-"],
    "низость": ["подлость", "бесчестность", "гнусность"],
    "низринув": ["низринувши"],
    "низринувши": ["низринув"],
    "низринуть": ["низвергнуть", "сбросить", "свергнуть"],
    "низывав": ["низывавши"],
    "низывавши": ["низывав"],
    "низь": ["низина"],
    "низя": ["нельзя", "запрещено", "недопустимо"],
    "нийога": ["левират"],
    "ник": ["никнейм"],
    "никак": ["никоим образом", "кажется", "похоже"],
    "никак нет": ["нет"],
    "никаквец": ["негодник", "мизерник", "подлец"],
    "никакой": ["ни один", "вовсе не", "отнюдь", "никакущий", "никакусенький"],
    "никакущий": ["никудышный", "вдрабадан"],
    "никелевый": ["никельсодержащий"],
    "никелировав": ["никелировавши"],
    "никелировавши": ["никелировав"],
    "никелировка": ["никелирование"],
    "никель-мурманский": ["никель"],
    "никельскуттерудит": ["хлоантит"],
    "никея": ["изник", "исник"],
    "никитовна": ["никитична"],
    "никифор": ["никифорка"],
    "никифорович": ["никифорыч"],
    "никнейм": ["ник"],
    "никнув": ["никнувши"],
    "никнувши": ["никнув"],
    "никнуть": ["поникать", "вянуть", "ослабевать"],
    "никогда": ["ни разу", "так и не", "николи", "отродясь", "отроду"],
    "никого": ["никогошенько"],
    "никогошеньки": ["никогошенько"],
    "никой": ["никакой"],
    "никола": ["николай"],
    "николаевич": ["николаич"],
    "николаевская область": ["николаевщина"],
    "николай": ["коля", "колян", "колёк", "николка", "колясик"],
    "николетта": ["николетт"],
    "николи": ["никогда"],
    "николь": ["ника"],
    "никольское": ["уссурийск"],
    "никонианец": ["никонианин"],
    "никонианин": ["никонианец"],
    "никотинамидадениндинуклеотид": ["дифосфопиридиннуклеотид", "дпн", "над"],
    "никотинамидадениндинуклеотидфосфат": ["кодегидраза", "надф"],
    "никотинный": ["никотиновый"],
    "никотиновая кислота": ["ниацин"],
    "никотиновый": ["никотинный", "ниациновый"],
    "никто": ["никтошеньки", "ничтожество", "незнакомец"],
    "никтофилия": ["скотофилия"],
    "никтошеньки": ["никто"],
    "никуда": ["ни к чёрту", "хуже некуда"],
    "никудышний": ["никудышный"],
    "никудышный": ["никчёмный", "никудышний"],
    "никчёмность": ["ничтожность", "негодность"],
    "никчёмный": ["негодный", "никудышный", "бестолковый", "бесполезный"],
    "нил": ["ниль"],
    "нилашист": ["салашист"],
    "нилка": ["лампея"],
    "нильсборий": ["дубний"],
    "нимало": ["нисколько", "ничуть"],
    "нимб": ["окружок", "венец", "венчик", "сияние", "аура"],
    "нимвеген": ["неймеген"],
    "нимкат": ["харак"],
    "нимнгадеми": ["сэвэнчэдеми"],
    "нимулид": ["нимесулид"],
    "нимфа": ["корелла", "муза"],
    "нимфея": ["кувшинка"],
    "нимфомания": ["метромания", "андромания", "эротомания", "аноргазмия"],
    "нимфоманка": ["проститутка", "шлюха", "блядь"],
    "нина": ["ниночка", "нинка", "нино"],
    "ниндзя": ["синоби"],
    "нинди": ["кай", "ни"],
    "нино": ["нижний новгород", "нижний"],
    "нинту": ["нинтур", "нинхурсаг"],
    "нинтур": ["нинту"],
    "нинхурсаг": ["ки", "нинту", "нинмах"],
    "ниня": ["неня"],
    "ниобий": ["колумбий"],
    "ниос": ["ньос"],
    "ниочёмный": ["ни о чём"],
    "нипочём": ["ни за что", "ни в коем случае", "ни за что на свете", "ни за какие коврижки", "даром", "задаром", "задёшево", "за бесценок", "за копейки", "за гроши", "за так", "за просто так", "за здорово живёшь", "за спасибо", "по дешёвке"],
    "нирвана": ["ниббана", "экстаз"],
    "нис-": ["низ-"],
    "нисбис": ["нусайбин"],
    "нисколечко": ["нисколько", "ничуть"],
    "нисколько": ["ничуть", "ни капельки", "ни на йоту", "ни на волос"],
    "ниспадав": ["ниспадавши"],
    "ниспадавши": ["ниспадав"],
    "ниспадать": ["свешиваться"],
    "ниспадать до степени": ["ниспасть на уровень"],
    "ниспасть": ["упасть", "пасть"],
    "ниспасть на уровень": ["ниспадать до степени"],
    "нисповергав": ["нисповергавши"],
    "нисповергавши": ["нисповергав"],
    "нисповергать": ["ниспровергать", "низвергать", "свергать", "развенчивать"],
    "нисповергнув": ["нисповергнувши"],
    "нисповергнувши": ["нисповергнув"],
    "нисповергнуть": ["ниспровергнуть"],
    "ниспослав": ["ниспославши"],
    "ниспославши": ["ниспослав"],
    "ниспослать": ["послать", "даровать"],
    "ниспосылав": ["ниспосылавши"],
    "ниспосылавши": ["ниспосылав"],
    "ниспровергав": ["ниспровергавши"],
    "ниспровергавши": ["ниспровергав"],
    "ниспровергать": ["низвергать", "сбрасывать", "низлагать"],
    "ниспровергнув": ["ниспровергнувши"],
    "ниспровергнувши": ["ниспровергнув"],
    "ниспровергнуть": ["низвергнуть", "повергнуть", "сбросить", "низринуть", "свергнуть", "низложить", "опровергнуть", "разоблачить"],
    "ниспровержение": ["низвержение", "свержение"],
    "ниспроверженье": ["ниспровержение"],
    "ниспускав": ["ниспускавши"],
    "ниспускавши": ["ниспускав"],
    "ниспустив": ["ниспустивши"],
    "ниспустивши": ["ниспустив"],
    "ниспуститься": ["опуститься", "снизойти"],
    "нисф": ["ним"],
    "нисходив": ["нисходивши"],
    "нисходивши": ["нисходив"],
    "нисходить": ["спускаться"],
    "нисходящий": ["убывающий", "понижающийся", "спускающийся", "сходящий"],
    "нисхожденье": ["нисхождение"],
    "нит": ["кандела на квадратный метр", "нт"],
    "нитевой": ["ниточный", "нитевидный"],
    "нитиджела": ["законодательное собрание"],
    "нитка": ["нить"],
    "нитрамин": ["нитроамин"],
    "нитрат": ["селитра", "азотокислая соль"],
    "нитрат аммония": ["аммонийная селитра", "аммиачная селитра"],
    "нитрат бария": ["бариевая селитра", "нитробарит"],
    "нитрил": ["цианид"],
    "нитрировав": ["нитрировавши"],
    "нитрировавши": ["нитрировав"],
    "нитрифицировав": ["нитрифицировавши"],
    "нитрифицировавши": ["нитрифицировав"],
    "нитроаммофоска": ["азофоска"],
    "нитровав": ["нитровавши"],
    "нитровавши": ["нитровав"],
    "нитроискожа": ["дерматин"],
    "нитроклетчатка": ["нитроцеллюлоза"],
    "нитрон": ["акрил"],
    "нитроцеллюлоза": ["нитроклетчатка"],
    "нитчатый": ["нитяной", "нитяный", "нитевидный"],
    "нить": ["нитка", "струна", "поток"],
    "нить ариадны": ["ариаднина нить"],
    "нихоний": ["унунтрий", "эка-таллий"],
    "ниц": ["ничком"],
    "ницшеанский": ["ницшевский"],
    "ницшевский": ["ницшеанский"],
    "ничего": ["более-менее", "неплохо", "нормально", "сносно", "удовлетворительно", "всё равно", "ладно", "ну что ж", "пускай"],
    "ничего не попишешь": ["ничего не поделаешь"],
    "ничегонеделание": ["бездельничание", "безделье", "праздношатание", "бездельничанье", "праздношатанье", "безделие"],
    "ничегонеделанье": ["ничегонеделание"],
    "ничегошеньки": ["ничегошенько"],
    "ничегошенько": ["ничегошеньки"],
    "ничегошный": ["ничёшный"],
    "ничей": ["ничейный", "бесхозный"],
    "ничек": ["ни"],
    "ничком": ["ниц", "вничь"],
    "ничоси": ["ничёси", "ничёсе"],
    "ничто": ["ничего", "ничтожество", "ноль", "нуль", "пустое место", "ерунда", "мусор", "пустяк", "безделица", "мелочь", "пустота", "вакуум", "небытие"],
    "ничтожество": ["ничтожность", "ноль", "нуль"],
    "ничтожив": ["ничтоживши"],
    "ничтоживши": ["ничтожив"],
    "ничтожно": ["пренебрежимо"],
    "ничтожность": ["ничтожество"],
    "ничтожный": ["мизерный", "незначительный", "жалкий", "недействительный"],
    "ничуточки": ["ничуть", "нисколько"],
    "ничуть": ["нисколько", "ни капли"],
    "ничья": ["ничейный результат", "ничейный исход", "мирный исход", "мир", "ничейный матч", "ничейная партия"],
    "ничёшный": ["ничегошный"],
    "нишкнув": ["нишкнувши"],
    "нишкнувши": ["нишкнув"],
    "нишкнуть": ["замолчать", "притихнуть"],
    "ништяк": ["хорошее", "клёвое", "хавчик", "хрючево"],
    "нищав": ["нищавши"],
    "нищавши": ["нищав"],
    "нищание": ["обнищание"],
    "нищать": ["беднеть", "разоряться"],
    "нищая": ["нищенка"],
    "нищеброд": ["побирушка", "попрошайка", "нищеёб"],
    "нищенство": ["попрошайничество", "нищета"],
    "нищенствовав": ["нищенствовавши"],
    "нищенствовавши": ["нищенствовав"],
    "нищенствовать": ["побираться", "христарадничать", "попрошайничать", "ходить по миру", "просить подаяния", "просить милостыни", "просить христа ради", "протягивать руку"],
    "нищета": ["беднота", "убожество", "убогость"],
    "нищий": ["неимущий", "бедный", "бедствующий", "нуждающийся", "малоимущий", "небогатый", "малообеспеченный", "необеспеченный", "побирушка", "попрошайка", "паупер", "скудный", "недостаточный"],
    "нквд": ["народный комиссариат внутренних дел", "наркомвнудел"],
    "нкрекп": ["нкрэку"],
    "нкрэку": ["нкрекп"],
    "нло": ["летающая тарелка"],
    "но": ["ро"],
    "ноак": ["народно-освободительная армия китая"],
    "нобелевка": ["нобелевская премия", "нобель"],
    "нобелевская премия": ["нобель", "нобелевка"],
    "нобелиат": ["нобелевский лауреат"],
    "новатор": ["рационализатор", "изобретатель"],
    "новаторский": ["первопроходческий", "передовой", "смелый"],
    "новаторство": ["нововведение", "новшество", "инновационность"],
    "новаторствовав": ["новаторствовавши"],
    "новаторствовавши": ["новаторствовав"],
    "новация": ["новшество"],
    "новая": ["новая звезда"],
    "новая волна": ["нью-вейв"],
    "новая земля": ["матка"],
    "новая москва": ["тинао"],
    "новгород": ["город на волхове"],
    "новгородская область": ["новгородчина"],
    "новев": ["новевши"],
    "новевши": ["новев"],
    "новейший": ["наиновейший"],
    "новелла": ["рассказ", "дополнение", "новшество"],
    "новеллический": ["новеллистический"],
    "новенький": ["новый", "новёхонький", "с иголочки", "новичок"],
    "новив": ["новивши"],
    "новивши": ["новив"],
    "новизна": ["свежесть", "новшество"],
    "новик": ["новичок", "новак", "новобранец", "салага", "новенький"],
    "новинка": ["новость", "новшество"],
    "новичок": ["свежак", "свежачок"],
    "ново-грудинино": ["новогрудинина", "новогрудинино"],
    "новоазовск": ["новониколаевская", "будённовская"],
    "новобранец": ["салага", "дух", "салабон"],
    "новобрачная": ["невеста", "молодая"],
    "новобрачный": ["молодожён"],
    "нововведение": ["новшество"],
    "нововведенье": ["нововведение"],
    "нововыстроенный": ["новопостроенный"],
    "новогодняя ёлка": ["рождественская ёлка"],
    "новогодье": ["новогодие"],
    "новогродовка": ["гродовка"],
    "новогрудинина": ["новогрудинино", "ново-грудинино"],
    "новогрудинино": ["новогрудинина", "ново-грудинино"],
    "новоиспечённый": ["новоявленный", "свежеиспечённый"],
    "новокузнецк": ["сталинск"],
    "новокупленный": ["новоприобретённый"],
    "новолетие": ["новый год"],
    "новолетье": ["новолетие"],
    "новолукомлец": ["новолукомчанин"],
    "новолукомчанин": ["новолукомлец"],
    "новолуние": ["новолунье"],
    "новомировский": ["новомирский"],
    "новомирский": ["новомировский"],
    "новомосковский административный округ": ["нао"],
    "новоназначенный": ["новый", "новоутверждённый"],
    "новонорвежский язык": ["новонорвежский", "нюнорск", "нюношк", "ландсмол"],
    "новообразование": ["неологизм", "образование", "опухоль"],
    "новооткрытый": ["открытый", "обнаруженный"],
    "новопостроенный": ["нововыстроенный"],
    "новопреставленный": ["преставившийся"],
    "новорождённый": ["младенец", "именинник"],
    "новороссийск": ["днепр", "днепропетровск", "екатеринослав", "касымбек"],
    "новороссия": ["конфедеративная республика новороссия", "крн", "союз народных республик", "снр", "лднр"],
    "новоселие": ["новоселье"],
    "новоселье": ["новоселие", "вселение", "вселины"],
    "новосиб": ["новосибирск"],
    "новосибирец": ["новониколаевец"],
    "новосибирск": ["сибирская столица", "столица сибири", "новониколаевск", "новосиб", "нск"],
    "новосибирский": ["новониколаевский"],
    "новостийщик": ["новостник"],
    "новостник": ["новостийщик"],
    "новость": ["известие", "новинка", "новшество", "новизна"],
    "новосёл": ["новоселец"],
    "новотор": ["новоторжец", "торжанин", "торжокец", "торжковец"],
    "новоторжец": ["новотор", "торжанин", "торжокец", "торжковец"],
    "новоукраинка": ["павловск", "новопавловск", "посад павловский"],
    "новоцианин": ["кафар", "новотианин"],
    "новоцианство": ["новотианство"],
    "новруз": ["новый год"],
    "новшество": ["нововведение"],
    "новые регионы": ["исторические территории"],
    "новый": ["нетрадиционный", "незнакомый", "недавний", "свежий"],
    "новый год": ["новолетие"],
    "новый свет": ["америка"],
    "новый уренгой": ["столица газовиков"],
    "новь": ["новизна", "новшество", "новьё", "целина"],
    "новьё": ["каноль"],
    "новёхонький": ["новенький"],
    "нога": ["копыто", "ходуля", "лапа", "щупальце", "протез"],
    "ногавка": ["повязка"],
    "ногай тили": ["ногайша"],
    "ногайский язык": ["ногайский"],
    "ногастый": ["большеногий", "длинноногий", "ногатый"],
    "ноггано": ["баста"],
    "ноготь": ["нокоть"],
    "ногохвостка": ["коллембола"],
    "ногощупальце": ["педипальпа"],
    "нод": ["наибольший общий делитель", "народное ополчение донбасса"],
    "нода": ["узел"],
    "нодозный": ["нодулярный", "узелковый", "узловатый"],
    "нодулярный": ["нодозный", "узелковый"],
    "нож": ["режик"],
    "нож в сердце": ["разбитое сердце"],
    "ножеклюв": ["водорез"],
    "ножка": ["лапка", "нога", "вывод", "цветоножка", "стебель", "черенок"],
    "ножками": ["сам"],
    "ножни": ["ножницы"],
    "ножница": ["калъф", "кания"],
    "ножовщина": ["поножовщина"],
    "ножонка": ["ножка"],
    "ноздреватый": ["пористый", "ноздристый", "ноздрястый"],
    "ноздревина": ["пора"],
    "нозография": ["носография"],
    "нозофобия": ["патофобия"],
    "нозпарвард": ["эрка"],
    "нозук": ["латиф"],
    "ной": ["нух"],
    "нок": ["наименьшее общее кратное"],
    "нокав": ["нокавши"],
    "нокавши": ["нокав"],
    "нокаутировав": ["нокаутировавши"],
    "нокаутировавши": ["нокаутировав"],
    "нокаутировать": ["вырубать", "вырубить"],
    "нокдаун": ["шок", "ошеломление", "аут", "ступор"],
    "ноктамбулизм": ["лунатизм", "сомнамбулизм", "снохождение"],
    "нолдамс вайме кожф": ["таргамс вайме", "панемс кожф тевлавста"],
    "нолдамс ункст": ["нолдамс юрхт"],
    "нолдамс юрхт": ["нолдамс ункст"],
    "нолевой": ["нулевой"],
    "нолик": ["однёрка"],
    "ноль": ["нуль", "ничто", "пустота", "ничтожество", "пустое место", "профан", "лузер", "зеро"],
    "ноль внимания": ["ухом не ведёт", "ноль внимания и фунт презрения"],
    "номабар": ["хаткашон", "хатбар"],
    "номад": ["кочевник"],
    "номадизм": ["кочевничество"],
    "номадный": ["кочевнический", "кочевой"],
    "номахон": ["мактубхон"],
    "номенклатура изделий": ["номенклатура продукции", "товарная номенклатура"],
    "номенклатурно-административный": ["административно-номенклатурный"],
    "номенклатурщик": ["назначенец", "ответработник"],
    "номер": ["число", "порядок", "маршрут"],
    "номерация": ["нумерация", "нумерование"],
    "номеровав": ["номеровавши"],
    "номеровавши": ["номеровав"],
    "номерование": ["нумерование"],
    "номеровать": ["нумеровать"],
    "номерок": ["талон", "явочка"],
    "номеронабиратель": ["тастатура"],
    "номзад": ["келин"],
    "номинализовав": ["номинализовавши"],
    "номинализовавши": ["номинализовав"],
    "номинально": ["формально"],
    "номинатив": ["именительный падеж"],
    "номинативный": ["назывательный"],
    "номинировав": ["номинировавши"],
    "номинировавши": ["номинировав"],
    "номинирование": ["номинация"],
    "номисма": ["солид", "номизма"],
    "номографировав": ["номографировавши"],
    "номографировавши": ["номографировав"],
    "номоканон": ["законоправильник", "кормчая книга"],
    "номос": ["ном"],
    "номофилак": ["эндек"],
    "нон-фикшен": ["документалистика"],
    "нон-фикшн": ["документалистика"],
    "нонановая кислота": ["пеларгоновая кислота"],
    "нонановый": ["пеларгоновый"],
    "нонво": ["хаббоз"],
    "ноне": ["нынче", "сегодня", "теперь"],
    "нонеча": ["теперь", "сейчас", "ныне", "нынче", "нонче"],
    "нонешний": ["нынешний", "теперешний"],
    "нониллион": ["септендециллион"],
    "нониус": ["верньер"],
    "нонкомбатант": ["некомбатант"],
    "нонконформизм": ["фрондёрство"],
    "нонсенс": ["чушь", "абсурд", "нелепость", "вздор", "ерунда", "чепуха", "абракадабра"],
    "нонче": ["ныне", "нынче", "нонеча", "теперь", "теперича", "сейчас", "сегодня"],
    "ноократия": ["меритократия", "технократия"],
    "нора": ["норка", "норочка", "норушка", "норища"],
    "норадреналин": ["норэпинефрин"],
    "норвег": ["норвежец", "норг", "норвежки", "бегаши", "ножи"],
    "норвегия": ["королевство норвегия"],
    "норвежец": ["норг"],
    "норвежки": ["норвеги", "ножи", "бегаши"],
    "норвежский": ["норвежский язык"],
    "норвежский язык": ["норвежский"],
    "норвежско-мурманский": ["мурманско-норвежский"],
    "норвежско-российский": ["российско-норвежский"],
    "норг": ["норвежец", "норвег"],
    "норд": ["север", "сивер", "сиверко"],
    "норд-вест": ["северо-запад"],
    "норд-ост": ["северо-восток"],
    "нордический": ["скандинавский"],
    "нори": ["ким"],
    "норильск": ["заполярная столица"],
    "норм": ["нормально", "сойдёт", "сносно"],
    "норма": ["правило", "квота", "хватит", "довольно"],
    "нормализировав": ["нормализировавши"],
    "нормализировавши": ["нормализировав"],
    "нормализироваться": ["нормализоваться"],
    "нормализовав": ["нормализовавши"],
    "нормализовавши": ["нормализовав"],
    "нормализоваться": ["нормализироваться"],
    "нормальность": ["обычность", "правильность", "норма", "вменяемость", "перпендикулярность"],
    "нормальный": ["обычный", "адекватный", "ортогональный"],
    "нормалёк": ["нормально"],
    "нормандская четвёрка": ["нормандский формат"],
    "нормандский формат": ["нормандская четвёрка"],
    "норманн": ["нормандец", "нурман", "викинг"],
    "нормас": ["норм", "нормал", "нормалёк", "нормуль"],
    "нормативный": ["позитивный", "ненормативный"],
    "нормировав": ["нормировавши"],
    "нормировавши": ["нормировав"],
    "нормис": ["обыватель", "конформист", "цивил", "аутсайдер", "чужак", "посредственность", "середнячок"],
    "нормич": ["норм", "нормалёк"],
    "нормобласт": ["эритробласт"],
    "нормозооспермия": ["нормоспермия"],
    "нормостеник": ["мезоморф"],
    "нормуль": ["нормально", "норм", "нормал", "нормалёк", "нормас", "нормальды", "канать"],
    "норов": ["характер", "нрав", "обычай", "привычка", "привычки", "своенравие"],
    "норовив": ["норовивши"],
    "норовивши": ["норовив"],
    "норовисто": ["своенравно"],
    "норовистый": ["упрямый", "своенравный"],
    "норовить": ["намереваться", "стараться", "метить"],
    "норочий": ["норковый"],
    "норуот": ["дьон"],
    "норушка": ["нора"],
    "норчёпинг": ["норкепинг"],
    "норэпинефрин": ["норадреналин"],
    "нос": ["клюв", "носок", "носик"],
    "носак": ["грузчик", "носильщик"],
    "носар": ["йорж донський"],
    "носарь": ["бобырь", "бирючок", "донской ёрш"],
    "носастый": ["носатый", "большеносый", "крупноносый"],
    "носатик": ["носач"],
    "носатый": ["носастый", "большеносый", "крупноносый"],
    "носач": ["кахау"],
    "носив": ["носивши"],
    "носивши": ["носив"],
    "носик": ["носишка", "носишко", "носок"],
    "носильный": ["ношебный", "повседневный", "рабочий"],
    "носипос": ["ношукр"],
    "носить": ["таскать"],
    "носить камень за пазухой": ["держать камень за пазухой", "иметь зуб"],
    "носить под сердцем": ["быть тяжёлой", "ходить с брюхом"],
    "носиться": ["метаться"],
    "носишко": ["носишка"],
    "носия": ["облекло", "дрехи", "костюм"],
    "носка": ["ношение"],
    "носовожденье": ["обман", "обещание", "заблуждение"],
    "носовой платок": ["платок"],
    "носоглоточный": ["назофарингеальный"],
    "носопыра": ["носопырка", "нюхалка", "рубильник", "шнобель"],
    "носопырка": ["носопыра", "нюхалка", "рубильник", "шнобель"],
    "носопырло": ["носопырла", "носопырка", "носяра", "носище", "шнобель", "нюхалка", "рубильник", "клюв"],
    "носороговый": ["носорожий"],
    "носорожий": ["носороговый"],
    "ностальгировав": ["ностальгировавши"],
    "ностальгировавши": ["ностальгировав"],
    "ностальгически": ["тоскливо"],
    "ностальгический": ["ностальгичный"],
    "ностальгия": ["пассеизм"],
    "ностратический язык": ["бореальные языки", "гиперборальные языки"],
    "носяра": ["нос", "шнобель", "рубильник", "носопырка"],
    "нота": ["тон", "интонация"],
    "нотабене": ["нотабена", "важно"],
    "нотарикон": ["рашей тевот"],
    "нотебург": ["орешек", "шлиссельбург"],
    "нотировав": ["нотировавши"],
    "нотировавши": ["нотировав"],
    "нотирование": ["нотировка"],
    "нотировка": ["нотирование"],
    "нотификация": ["уведомление", "оповещение"],
    "нотифицировав": ["нотифицировавши"],
    "нотифицировавши": ["нотифицировав"],
    "нотный стан": ["нотоносец"],
    "нотоносец": ["нотный стан"],
    "нотоптерус": ["нож-читала", "спинопер"],
    "нототрема": ["сумчатая лягушка"],
    "ноумен": ["нумен"],
    "ноуменальный": ["непостигаемый"],
    "ноунейм": ["барахло", "никто", "ноль без палочки"],
    "ноутбук": ["ноут", "лэптоп", "блокнот", "блокнотный компьютер"],
    "ноутбуковский": ["ноутбучный"],
    "ноутбучный": ["ноутбуковский"],
    "нохчи": ["чечен", "чеченец", "нохчий"],
    "нохчий": ["нохчи", "чечен"],
    "нохчийн мотт": ["нохчийн"],
    "нохчийчоь": ["нохчийн республика"],
    "ноцирецептор": ["ноцицептор"],
    "ноцицептор": ["болевой рецептор", "ноцирецептор"],
    "ноцицепция": ["ноциперцепция"],
    "ночевав": ["ночевавши"],
    "ночевавши": ["ночевав"],
    "ночевать": ["спать"],
    "ночер": ["ночерок"],
    "ночерок": ["ночер"],
    "ночесветка": ["ноктилука"],
    "ночию": ["ноченькой", "ночером"],
    "ночлег": ["ночёвка"],
    "ночлежничав": ["ночлежничавши"],
    "ночлежничавши": ["ночлежничав"],
    "ночлежный дом": ["ночлежка", "дом ночного пребывания", "дом ночлега"],
    "ночная бабочка": ["мотылёк", "проститутка", "путана", "жрица любви"],
    "ночная ваза": ["горшок", "ночной горшок", "урильник", "урыльник"],
    "ночнушка": ["ночная рубашка"],
    "ночь": ["ночное время", "вечер"],
    "ночёвывав": ["ночёвывавши"],
    "ночёвывавши": ["ночёвывав"],
    "ношебный": ["носильный", "повседневный", "рабочий", "нательный"],
    "ношенье": ["ношение"],
    "ношпа": ["дротаверин"],
    "ношукр": ["носипос"],
    "нощь": ["ночь"],
    "ноэль": ["сказка"],
    "нрав": ["характер", "темперамент", "норов", "уклад", "обычай"],
    "нравить": ["угождать"],
    "нравиться": ["привлекать", "импонировать"],
    "нравный": ["своевольный", "своенравный", "ндравный"],
    "нравоучав": ["нравоучавши"],
    "нравоучавши": ["нравоучав"],
    "нравоучение": ["поучение", "наставление", "назидание", "проповедь", "нотация", "морализирование", "нравоученье", "поученье", "наставленье", "назиданье", "морализированье"],
    "нравоученье": ["поучение", "наставление", "нравоучение", "назидание", "проповедь", "нотация", "морализирование", "поученье", "наставленье", "назиданье", "морализированье"],
    "нравоучительный": ["дидактический", "поучительный", "наставительный", "назидательный", "менторский", "учительный"],
    "нравственно": ["морально", "этически", "этично"],
    "нравственность": ["мораль", "этика", "моральность", "этичность"],
    "нрб": ["народная республика болгария"],
    "нсдап": ["нснрп", "нсрпг"],
    "ну": ["но", "пошёл", "пошла", "давай"],
    "ну вот": ["вот видишь"],
    "ну как": ["вдруг", "что если"],
    "ну ладно": ["хорошо"],
    "ну что ж": ["ну что же"],
    "ну что же": ["ну что ж"],
    "ну-ка": ["а ну-ка", "ну-ко", "ну-кась", "ну-кася"],
    "ну-кась": ["ну-ка", "ну-ко", "а ну-ка", "ну-кася"],
    "ну-кася": ["ну-ка", "ну-ко", "ну-кась", "а ну-ка"],
    "ну-ко": ["ну-ка", "а ну-ка", "ну-кась", "ну-кася"],
    "ну-с": ["итак", "следовательно", "таким образом", "ась"],
    "нуар": ["крутой детектив"],
    "нуб": ["чайник", "ламер", "нюб", "нубас", "нубасик", "наб", "краб"],
    "нубас": ["нуб", "нубасик"],
    "нубасик": ["нуб", "нубас"],
    "нувориш": ["парвеню", "скоробогач"],
    "нуда": ["зануда"],
    "нудев": ["нудевши"],
    "нудевши": ["нудев"],
    "нудеть": ["нудить"],
    "нудив": ["нудивши"],
    "нудивши": ["нудив"],
    "нудизм": ["натуризм"],
    "нудила": ["зануда"],
    "нудило": ["зануда", "нудила"],
    "нудист": ["натурист", "нюдист"],
    "нудистика": ["нудность", "нудятина", "нудь"],
    "нудистка": ["натуристка", "нюдистка"],
    "нудить": ["принуждать", "заставлять", "неволить", "приневоливать", "утомлять", "изнурять", "переутомлять", "выматывать", "изматывать", "измытаривать", "мучить", "тошнить", "мутить"],
    "нудно": ["занудно", "надоедливо"],
    "нудность": ["нудятина", "нудистика", "нудь"],
    "нудный": ["занудный", "докучливый", "надоедливый", "скучный", "тоскливый"],
    "нудь": ["нудность", "нудятина", "нудистика"],
    "нудятина": ["нудистика", "нудь", "нудность"],
    "нужа": ["нужда"],
    "нужда": ["потребность", "необходимость", "надобность", "нехватка", "нищета", "бедность"],
    "нуждающийся": ["бедный", "неимущий", "малоимущий", "нищий", "небогатый", "малообеспеченный", "необеспеченный"],
    "нужен": ["потребен"],
    "нужнейший": ["необходимейший"],
    "нужник": ["уборная", "отхожее место", "толчок", "туалет", "сортир", "сральник"],
    "нужно": ["не грех", "необходимо", "следует", "надо", "требуется", "потребно"],
    "нужность": ["необходимость", "потребность"],
    "нужный": ["необходимый"],
    "нузурух": ["мунзурух"],
    "нукав": ["нукавши"],
    "нукавши": ["нукав"],
    "нукание": ["нуканье"],
    "нуканье": ["нукание"],
    "нуклеарный": ["ядерный"],
    "нуклеация": ["зародышеобразование"],
    "нуклеид": ["нуклид"],
    "нуклеин": ["днк"],
    "нуклеиновая кислота": ["полинуклеотид"],
    "нуклеоид": ["нуклеоплазма"],
    "нуклеокапсид": ["вирион"],
    "нуклеоль": ["ядрышко"],
    "нуклеотид": ["нуклеозидфосфат"],
    "нуклеофозмин": ["нуматрин"],
    "нуклид": ["нуклеид"],
    "нуклон": ["нуклеон"],
    "нукнув": ["нукнувши"],
    "нукнувши": ["нукнув"],
    "нулевая флексия": ["нулевое окончание"],
    "нулевая энергия": ["нулевые колебания"],
    "нулевое окончание": ["нулевая флексия"],
    "нулевой": ["нолевой"],
    "нуллифицировав": ["нуллифицировавши"],
    "нуллифицировавши": ["нуллифицировав"],
    "нуллифицировать": ["аннулировать"],
    "нуль": ["ноль", "ничто", "пустота", "пустое место", "ничтожество", "профан", "лузер"],
    "нуль-матрица": ["нуль"],
    "нульмерный": ["точечный"],
    "нулёвка": ["нулевая отчётность", "нулевой отчёт", "нулевой баланс"],
    "нулёвый": ["новый", "свежий", "девственный", "с иголочки", "канолевый", "нулевой", "ничтожный", "никчемный"],
    "нумен": ["ноумен"],
    "нумер": ["номер"],
    "нумерация": ["нумерование", "номерация", "система счисления"],
    "нумерический": ["численный", "числовой"],
    "нумеровав": ["нумеровавши"],
    "нумеровавши": ["нумеровав"],
    "нумерование": ["номерование", "нумерация"],
    "нумеровщик": ["брошюровщик"],
    "нумол": ["шумбаз"],
    "нун": ["птах", "мемфис", "амон", "хива", "океан", "греция"],
    "нуна": ["тян"],
    "нунциатура": ["посольство"],
    "нунций": ["апокрисиарий", "посол", "представитель"],
    "нунчаки": ["нунчаку", "эр цзе гунь"],
    "нунчаку": ["нунчак", "эр цзе гунь"],
    "нур-султан": ["астана", "акмолинск", "целиноград", "акмола"],
    "нураг": ["нурага"],
    "нуротановец": ["аманатовец"],
    "нуртувати": ["вирувати"],
    "нусайрит": ["алавит"],
    "нусантара": ["индонезия", "республика индонезия", "маджапахит"],
    "нусратбахш": ["нусратовар"],
    "нут": ["ну", "нуит"],
    "нутрия": ["водяная крыса"],
    "нутро": ["утроба", "живот", "потроха", "внутренность", "внутренний мир", "душа", "интуиция", "чутьё"],
    "нутромер": ["штихмас"],
    "нутрометр": ["нутромер"],
    "нутромо": ["нутрома", "нутрово"],
    "нутряной": ["утробный", "внутренний", "внутриутробный", "глухой", "глубинный", "душевный", "врождённый", "чувственный", "эмоциональный", "вдохновленный"],
    "нуук": ["нук", "готхоб"],
    "нуха": ["шеки"],
    "нухрив": ["нухривши"],
    "нухривши": ["нухрив"],
    "нывши": ["ныв"],
    "нык": ["рывок", "толчок", "прыжок"],
    "ныкав": ["ныкавши"],
    "ныкавши": ["ныкав"],
    "ныкаться": ["прятаться", "скрываться", "скрытничать", "таиться", "шифроваться", "косить"],
    "ныл": ["нылыт"],
    "ныне": ["теперь", "сейчас", "нынче", "нонче", "нонеча", "по сей день"],
    "нынече": ["нынче", "ныне", "нонче", "нонече", "нонеча", "нонечи"],
    "нынешний": ["сегодняшний", "текущий", "теперешний", "современный"],
    "нынлу": ["ынлу"],
    "нынче": ["теперь", "сейчас", "ныне", "нонче", "нонеча", "нынече", "сегодня"],
    "нырнув": ["нырнувши"],
    "нырнувши": ["нырнув"],
    "нырнуть": ["занырнуть", "окунуться", "шмыгнуть"],
    "нырок": ["яма", "выбоина", "ухаб"],
    "ныряв": ["нырявши"],
    "нырявши": ["ныряв"],
    "нырянье": ["ныряние"],
    "ныть": ["выть", "скулить", "мычать", "причитать", "жаловаться", "сетовать", "роптать", "плакаться", "хныкать", "ломить", "мозжить"],
    "ныхас": ["дзырд", "сыбыртт"],
    "нычка": ["тайник", "загашник", "заначка", "галинник", "зажальник", "запичужник", "курок", "качка", "фартыцор", "ховыра", "шурша"],
    "нью-вейв": ["новая волна"],
    "нью-дели": ["новый дели"],
    "нью-йорк": ["большое яблоко", "город большого яблока", "столица мира", "город на гудзоне", "новгородское"],
    "ньюслеттер": ["вестник"],
    "ньюсмейкер": ["знаменитость"],
    "ньютонов": ["ньютоновский"],
    "ньютоновский": ["ньютонский"],
    "ньяса": ["малави"],
    "ньясалендец": ["малавиец"],
    "нэкъокъон": ["енэкъокъун"],
    "нэпмановский": ["нэпманский"],
    "нэпманский": ["нэпмановский"],
    "нэт": ["нат"],
    "нэфнэ": ["нэфын"],
    "нэфын": ["нэфнэ"],
    "нэшвилл": ["нашвилл"],
    "ню": ["неглиже"],
    "нюансировав": ["нюансировавши"],
    "нюансировавши": ["нюансировав"],
    "нюансировка": ["нюансирование"],
    "нюдист": ["нудист", "натурист"],
    "нюдистка": ["натуристка", "нудистка"],
    "нюдс": ["обнажёнка"],
    "нюни": ["нытьё", "хныкание"],
    "нюнив": ["нюнивши"],
    "нюнивши": ["нюнив"],
    "нюнорск": ["новонорвежский язык", "ланнсмол", "нюношк"],
    "нюня": ["размазня", "рохля"],
    "нюра": ["нюрка"],
    "нюрнберг": ["нюрнбергский процесс", "нюрнбергский трибунал"],
    "нюх": ["обоняние", "интуиция", "чутьё", "шестое чувство"],
    "нюхав": ["нюхавши"],
    "нюхавши": ["нюхав"],
    "нюхай бебру": ["отстать", "отвалить", "отвянуть"],
    "нюхалка": ["нос"],
    "нюхание": ["нюханье"],
    "нюханье": ["нюхание"],
    "нюхать": ["обонять", "вынюхивать", "совать нос"],
    "нюхач": ["нос", "нюхальщик"],
    "нюхивав": ["нюхивавши"],
    "нюхивавши": ["нюхивав"],
    "нюхнув": ["нюхнувши"],
    "нюхнувши": ["нюхнув"],
    "нюхнуть": ["понюхать"],
    "нюша": ["анюта"],
    "ня": ["вау", "ух ты"],
    "нява": ["вага", "вов"],
    "нявкання": ["явкання"],
    "нявкати": ["явкати"],
    "няемс": ["мумс ванфса", "мумс сельмоса"],
    "няемс-кулемс": ["марямс"],
    "нямка": ["вкусняшка"],
    "нянин": ["нянькин"],
    "нянченье": ["пестование", "ухаживание"],
    "нянчив": ["нянчивши"],
    "нянчивши": ["нянчив"],
    "нянчиться": ["нянькаться", "нянчить", "цацкаться"],
    "нянька": ["няня"],
    "нянькав": ["нянькавши"],
    "нянькавши": ["нянькав"],
    "нянькаться": ["нянчиться"],
    "нянькин": ["нянин"],
    "нянько": ["батько", "тато"],
    "няньо": ["тато"],
    "няньчив": ["няньчивши"],
    "няньчивши": ["няньчив"],
    "няня": ["сиделка", "нянька", "гувернантка"],
    "няфный": ["кавайный"],
    "няфтемс": ["шаркодьфтемс"],
    "няша": ["ил", "тина", "лайда", "ватты"],
    "няшив": ["няшивши"],
    "няшивши": ["няшив"],
    "няшить": ["ласкать", "тискать"],
    "няшка": ["милашечка", "анимешник"],
    "няшный": ["кавайный", "милый", "хорошенький", "прелестный"],
    "нёрд": ["ботаник", "ботан"],
    "нёрфить": ["нерфить"],
    "нёх": ["неведомая ёбаная хуйня"],
    "о вкусах не спорят": ["на вкус и цвет товарищей нет"],
    "о как": ["вот как", "вот оно как", "вон как", "эвано как"],
    "о пизде ни слова": ["про пизду ни слова"],
    "о чём разговор": ["а как же", "а то как же", "конечно", "разумеется"],
    "о-го-го": ["ого", "ух ты"],
    "о-образный": ["округлый"],
    "оазис": ["уголок", "островок"],
    "оаэ": ["объединённые арабские эмираты"],
    "об": ["обо"],
    "оба": ["двое"],
    "оба два": ["оба трое", "оба четверо", "оба пятеро", "оба шестеро", "оба семеро"],
    "оба семеро": ["оба два", "оба трое", "оба четверо", "оба пятеро", "оба шестеро"],
    "оба-на": ["оп-па", "вот те на", "вот тебе на", "опаньки", "во как"],
    "обабив": ["обабивши"],
    "обабивши": ["обабив"],
    "обабок": ["лекцинум"],
    "обагрив": ["обагривши"],
    "обагривав": ["обагривавши"],
    "обагривавши": ["обагривав"],
    "обагривать": ["обагрять"],
    "обагривши": ["обагрив"],
    "обагряв": ["обагрявши"],
    "обагрявши": ["обагряв"],
    "обагрянив": ["обагрянивши"],
    "обагрянивши": ["обагрянив"],
    "обагрять": ["обагривать"],
    "обаивав": ["обаивавши"],
    "обаивавши": ["обаивав"],
    "обаке": ["бакемоно"],
    "обакэ": ["бакэмоно"],
    "обалдев": ["обалдевши"],
    "обалдевав": ["обалдевавши"],
    "обалдевавши": ["обалдевав"],
    "обалдевать": ["офигевать", "охреневать"],
    "обалдевши": ["обалдев"],
    "обалдевший": ["одуревший", "ошалелый"],
    "обалденно": ["офигенно"],
    "обалденный": ["офигенный", "охрененный", "пердатый"],
    "обалденье": ["обалдение"],
    "обалдуй": ["балбес", "балда", "болван", "раздолбай"],
    "обалтывав": ["обалтывавши"],
    "обалтывавши": ["обалтывав"],
    "обандеролив": ["обандероливши"],
    "обандероливав": ["обандероливавши"],
    "обандероливавши": ["обандероливав"],
    "обандероливши": ["обандеролив"],
    "обанкротив": ["обанкротивши"],
    "обанкротивши": ["обанкротив"],
    "обанкрочивав": ["обанкрочивавши"],
    "обанкрочивавши": ["обанкрочивав"],
    "обанкрочивать": ["банкротить"],
    "обасурманив": ["обасурманивши"],
    "обасурманивав": ["обасурманивавши"],
    "обасурманивавши": ["обасурманивав"],
    "обасурманивши": ["обасурманив"],
    "обацда": ["обацтер"],
    "обацтер": ["обацда"],
    "обаче": ["однако", "вместе с тем", "тем не менее", "ведь", "же"],
    "обачний": ["обачливий"],
    "обаяв": ["обаявши"],
    "обаявши": ["обаяв"],
    "обаяние": ["очарование", "прелесть", "привлекательность", "притягательность", "шарм"],
    "обаянный": ["очарованный", "околдованный"],
    "обаянье": ["обаяние"],
    "обаятельность": ["обаяние", "шарм", "очаровательность", "харизма"],
    "обаятельный": ["очаровательный", "волшебный"],
    "обаять": ["очаровать", "очаровывать", "покорять", "покорить", "околдовать", "околдовывать", "пленять"],
    "оббегав": ["оббегавши"],
    "оббегавши": ["оббегав"],
    "оббегать": ["обегать"],
    "оббежав": ["оббежавши"],
    "оббежавши": ["оббежав"],
    "оббежать": ["обежать"],
    "оббив": ["оббивши"],
    "оббивав": ["оббивавши"],
    "оббивавши": ["оббивав"],
    "оббивши": ["оббив"],
    "оббрызгав": ["оббрызгавши"],
    "оббрызгавши": ["оббрызгав"],
    "оббрызгивав": ["оббрызгивавши"],
    "оббрызгивавши": ["оббрызгивав"],
    "обвал": ["обрушение"],
    "обвалив": ["обваливши"],
    "обваливав": ["обваливавши"],
    "обваливавши": ["обваливав"],
    "обваливать": ["рушить", "обрушивать"],
    "обваливши": ["обвалив"],
    "обвалить": ["обрушить"],
    "обвалиться": ["распасться", "развалиться"],
    "обваловав": ["обваловавши"],
    "обваловавши": ["обваловав"],
    "обваловывав": ["обваловывавши"],
    "обваловывавши": ["обваловывав"],
    "обвальный": ["тотальный", "масштабный"],
    "обваляв": ["обвалявши"],
    "обвалявши": ["обваляв"],
    "обварганив": ["обварганивши"],
    "обварганивши": ["обварганив"],
    "обварганить": ["сварганить"],
    "обварив": ["обваривши"],
    "обваривав": ["обваривавши"],
    "обваривавши": ["обваривав"],
    "обваривши": ["обварив"],
    "обвариться": ["ошпариться"],
    "обващивав": ["обващивавши"],
    "обващивавши": ["обващивав"],
    "обвевав": ["обвевавши"],
    "обвевавши": ["обвевав"],
    "обвезя": ["обвёзши"],
    "обвеивав": ["обвеивавши"],
    "обвеивавши": ["обвеивав"],
    "обвеивать": ["обвевать"],
    "обвенчав": ["обвенчавши"],
    "обвенчавши": ["обвенчав"],
    "обвенчанный": ["повенчанный"],
    "обвенчаться": ["вступить в брак", "пожениться"],
    "обвернув": ["обвернувши"],
    "обвернувши": ["обвернув"],
    "обвертев": ["обвертевши"],
    "обвертевши": ["обвертев"],
    "обверчивав": ["обверчивавши"],
    "обверчивавши": ["обверчивав"],
    "обвершив": ["обвершивши"],
    "обвершивав": ["обвершивавши"],
    "обвершивавши": ["обвершивав"],
    "обвершивши": ["обвершив"],
    "обвес": ["обвешивание"],
    "обвесив": ["обвесивши"],
    "обвесивши": ["обвесив"],
    "обвести вокруг пальца": ["обмануть", "перехитрить"],
    "обвестив": ["обвестивши"],
    "обвестивши": ["обвестив"],
    "обветрев": ["обветревши"],
    "обветревши": ["обветрев"],
    "обветрив": ["обветривши"],
    "обветривав": ["обветривавши"],
    "обветривавши": ["обветривав"],
    "обветривши": ["обветрив"],
    "обветшав": ["обветшавши"],
    "обветшавши": ["обветшав"],
    "обветшалый": ["ветхий", "старомодный", "старый"],
    "обветшание": ["обветшанье", "обветшалость"],
    "обвешав": ["обвешавши"],
    "обвешавши": ["обвешав"],
    "обвешив": ["обвешивши"],
    "обвешивав": ["обвешивавши"],
    "обвешивавши": ["обвешивав"],
    "обвешивши": ["обвешив"],
    "обвещав": ["обвещавши"],
    "обвещавши": ["обвещав"],
    "обвеяв": ["обвеявши"],
    "обвеявши": ["обвеяв"],
    "обвеяться": ["овеяться"],
    "обвив": ["обвивши"],
    "обвивав": ["обвивавши"],
    "обвивавши": ["обвивав"],
    "обвивши": ["обвив"],
    "обвинение": ["осуждение", "осужденье", "обвиненье", "иск", "истец", "прокурор"],
    "обвиненье": ["обвинение"],
    "обвинивши": ["обвинив"],
    "обвинитель": ["критик", "порицатель", "прокурор"],
    "обвиноватив": ["обвиновативши"],
    "обвиновативши": ["обвиноватив"],
    "обвиняв": ["обвинявши"],
    "обвинявши": ["обвиняв"],
    "обвиняемый": ["ответчи"],
    "обвинять": ["винить"],
    "обвисав": ["обвисавши"],
    "обвисавши": ["обвисав"],
    "обвисание": ["провисание", "свисание"],
    "обвиснув": ["обвиснувши"],
    "обвиснувши": ["обвиснув"],
    "обводив": ["обводивши"],
    "обводивши": ["обводив"],
    "обводнение": ["орошение"],
    "обводнив": ["обводнивши"],
    "обводнивши": ["обводнив"],
    "обводнить": ["оросить", "ирригировать"],
    "обводной": ["обводный"],
    "обводный": ["обводной"],
    "обводняв": ["обводнявши"],
    "обводнявши": ["обводняв"],
    "обвозив": ["обвозивши"],
    "обвозивши": ["обвозив"],
    "обволакивав": ["обволакивавши"],
    "обволакивавши": ["обволакивав"],
    "обволосатев": ["обволосатевши"],
    "обволосатевши": ["обволосатев"],
    "обвораживав": ["обвораживавши"],
    "обвораживавши": ["обвораживав"],
    "обвораживать": ["очаровывать", "пленять", "покорять"],
    "обворачивав": ["обворачивавши"],
    "обворачивавши": ["обворачивав"],
    "обворовав": ["обворовавши"],
    "обворовавши": ["обворовав"],
    "обворовать": ["обокрасть", "ограбить"],
    "обворовывав": ["обворовывавши"],
    "обворовывавши": ["обворовывав"],
    "обворовывать": ["обкрадывать", "обирать"],
    "обворожав": ["обворожавши"],
    "обворожавши": ["обворожав"],
    "обворожив": ["обвороживши"],
    "обвороживши": ["обворожив"],
    "обворожительный": ["очаровательный", "пленительный"],
    "обворожить": ["очаровать", "пленить", "покорить"],
    "обворотив": ["обворотивши"],
    "обворотивши": ["обворотив"],
    "обвощив": ["обвощивши"],
    "обвощивши": ["обвощив"],
    "обвыкав": ["обвыкавши"],
    "обвыкавши": ["обвыкав"],
    "обвыкать": ["обыкать", "привыкать"],
    "обвыкаться": ["обвыкать"],
    "обвыкнув": ["обвыкнувши"],
    "обвыкнувши": ["обвыкнув"],
    "обвыкнуть": ["привыкнуть", "пообвыкнуть", "свыкнуться"],
    "обвысив": ["обвысивши"],
    "обвысивши": ["обвысив"],
    "обвядав": ["обвядавши"],
    "обвядавши": ["обвядав"],
    "обвязав": ["обвязавши"],
    "обвязавши": ["обвязав"],
    "обвязать": ["обкрутить", "обметать", "обвесить"],
    "обвязка": ["обвеска"],
    "обвязывав": ["обвязывавши"],
    "обвязывавши": ["обвязывав"],
    "обвязываться": ["обматываться"],
    "обвялив": ["обвяливши"],
    "обвяливав": ["обвяливавши"],
    "обвяливавши": ["обвяливав"],
    "обвяливши": ["обвялив"],
    "обвянув": ["обвянувши"],
    "обвянувши": ["обвянув"],
    "обвёзши": ["обвезя"],
    "обвёртка": ["оборачивание", "обёртка"],
    "обвёртывав": ["обвёртывавши"],
    "обвёртывавши": ["обвёртывав"],
    "обгадив": ["обгадивши"],
    "обгадивши": ["обгадив"],
    "обгадить": ["изгадить"],
    "обгаживав": ["обгаживавши"],
    "обгаживавши": ["обгаживав"],
    "обгибав": ["обгибавши"],
    "обгибавши": ["обгибав"],
    "обгладив": ["обгладивши"],
    "обгладивши": ["обгладив"],
    "обгладывав": ["обгладывавши"],
    "обгладывавши": ["обгладывав"],
    "обглаживав": ["обглаживавши"],
    "обглаживавши": ["обглаживав"],
    "обглодав": ["обглодавши"],
    "обглодавши": ["обглодав"],
    "обглодать": ["обгрызть", "измучить"],
    "обглядев": ["обглядевши"],
    "обглядевши": ["обглядев"],
    "обглядывав": ["обглядывавши"],
    "обглядывавши": ["обглядывав"],
    "обгнив": ["обгнивши"],
    "обгнивав": ["обгнивавши"],
    "обгнивавши": ["обгнивав"],
    "обгнивши": ["обгнив"],
    "обговаривав": ["обговаривавши"],
    "обговаривавши": ["обговаривав"],
    "обговаривать": ["оговаривать"],
    "обговорив": ["обговоривши"],
    "обговоривши": ["обговорив"],
    "обголодав": ["обголодавши"],
    "обголодавши": ["обголодав"],
    "обгоняв": ["обгонявши"],
    "обгонявши": ["обгоняв"],
    "обгорав": ["обгоравши"],
    "обгоравши": ["обгорав"],
    "обгораживав": ["обгораживавши"],
    "обгораживавши": ["обгораживав"],
    "обгорання": ["обгоряння"],
    "обгорати": ["обгоряти"],
    "обгорать": ["обугливаться"],
    "обгорев": ["обгоревши"],
    "обгоревши": ["обгорев"],
    "обгореть": ["обуглиться"],
    "обгородив": ["обгородивши"],
    "обгородивши": ["обгородив"],
    "обгрызав": ["обгрызавши"],
    "обгрызавши": ["обгрызав"],
    "обгрызок": ["огрызок"],
    "обгрызывав": ["обгрызывавши"],
    "обгрызывавши": ["обгрызывав"],
    "обгуляться": ["нагуляться"],
    "обдав": ["обдавши"],
    "обдавав": ["обдававши"],
    "обдававши": ["обдавав"],
    "обдавать": ["окатывать", "обливать", "овевать", "обдувать"],
    "обдаваться": ["обливаться"],
    "обдавив": ["обдавивши"],
    "обдавивши": ["обдавив"],
    "обдавливав": ["обдавливавши"],
    "обдавливавши": ["обдавливав"],
    "обдавши": ["обдав"],
    "обдарив": ["обдаривши"],
    "обдаривав": ["обдаривавши"],
    "обдаривавши": ["обдаривав"],
    "обдаривши": ["обдарив"],
    "обдарування": ["обдаровання", "талант"],
    "обдать": ["окатить", "обвеять", "охватить", "опахнуть", "пронизать"],
    "обделав": ["обделавши"],
    "обделавши": ["обделав"],
    "обделаться": ["провернуться", "устроиться", "обосраться", "обкакаться", "наложить в штаны"],
    "обделив": ["обделивши"],
    "обделивав": ["обделивавши"],
    "обделивавши": ["обделивав"],
    "обделивши": ["обделив"],
    "обделывав": ["обделывавши"],
    "обделывавши": ["обделывав"],
    "обделяв": ["обделявши"],
    "обделявши": ["обделяв"],
    "обдержав": ["обдержавши"],
    "обдержавши": ["обдержав"],
    "обдерживав": ["обдерживавши"],
    "обдерживавши": ["обдерживав"],
    "обдернив": ["обдернивши"],
    "обдернивши": ["обдернив"],
    "обдернить": ["обдерновать"],
    "обдерновав": ["обдерновавши"],
    "обдерновавши": ["обдерновав"],
    "обдерновать": ["обдернить"],
    "обдерновывав": ["обдерновывавши"],
    "обдерновывавши": ["обдерновывав"],
    "обдерновывать": ["дерновать", "обдернять"],
    "обдерняв": ["обдернявши"],
    "обдернявши": ["обдерняв"],
    "обдернять": ["дерновать", "обдерновывать"],
    "обдимати": ["обдувати"],
    "обдир": ["обдирка", "обдирание", "обдёр", "обдор"],
    "обдирав": ["обдиравши"],
    "обдиравши": ["обдирав"],
    "обдирала": ["обирала"],
    "обдирной": ["обдирочный", "зачистный"],
    "обдолбав": ["обдолбавши"],
    "обдолбавши": ["обдолбав"],
    "обдолбанный": ["одурманенный", "опьянённый", "убитый", "ушатанный"],
    "обдолбаться": ["обсадиться"],
    "обдолбив": ["обдолбивши"],
    "обдолбивши": ["обдолбив"],
    "обдолбос": ["обдолбыш"],
    "обдолбыш": ["обдолбос"],
    "обдував": ["обдувавши"],
    "обдувавши": ["обдував"],
    "обдувши": ["обдув"],
    "обдумав": ["обдумавши"],
    "обдумавши": ["обдумав"],
    "обдуманно": ["продуманно"],
    "обдуманность": ["продуманность", "расчётливость"],
    "обдуманный": ["расчётливый", "продуманный", "серьёзный", "меркантильный", "корыстный"],
    "обдумать": ["вникнуть", "обмозговать", "поразмыслить", "продумать", "взвесить"],
    "обдумывав": ["обдумывавши"],
    "обдумывавши": ["обдумывав"],
    "обдумывание": ["обдумыванье"],
    "обдумыванье": ["обдумывание"],
    "обдумывать": ["взвешивать", "продумывать", "рассчитывать", "вынашивать", "лелеять", "обмозговывать"],
    "обдунув": ["обдунувши"],
    "обдунувши": ["обдунув"],
    "обдурачив": ["обдурачивши"],
    "обдурачивав": ["обдурачивавши"],
    "обдурачивавши": ["обдурачивав"],
    "обдурачивши": ["обдурачив"],
    "обдурив": ["обдуривши"],
    "обдуривав": ["обдуривавши"],
    "обдуривавши": ["обдуривав"],
    "обдуривши": ["обдурив"],
    "обдурить": ["обмануть", "одурачить", "объегорить", "провести", "развести", "облапошить", "обмишурить", "наколоть", "обвести вокруг пальца"],
    "обдуряв": ["обдурявши"],
    "обдурявши": ["обдуряв"],
    "обдёргав": ["обдёргавши"],
    "обдёргавши": ["обдёргав"],
    "обдёргивав": ["обдёргивавши"],
    "обдёргивавши": ["обдёргивав"],
    "обдёрнув": ["обдёрнувши"],
    "обдёрнувши": ["обдёрнув"],
    "обдёрнуть": ["одёрнуть", "оправить"],
    "обегав": ["обегавши"],
    "обегавши": ["обегав"],
    "обегать": ["обежать"],
    "обедав": ["обедавши"],
    "обедавши": ["обедав"],
    "обедать": ["ланчевать", "ланчеваться"],
    "обеднев": ["обедневши"],
    "обедневши": ["обеднев"],
    "обеднение": ["бедность", "доизвлечение"],
    "обеднив": ["обеднивши"],
    "обеднивши": ["обеднив"],
    "обедник": ["зюйд-ост"],
    "обедня": ["литургия", "месса"],
    "обедняв": ["обеднявши"],
    "обеднявши": ["обедняв"],
    "обедывав": ["обедывавши"],
    "обедывавши": ["обедывав"],
    "обежав": ["обежавши"],
    "обежавши": ["обежав"],
    "обез-": ["обес-"],
    "обезбаливающее": ["обезболивающее", "анальгетик"],
    "обезбашенный": ["безбашенный", "безголовый", "отчаянный", "сумасшедший", "ненормальный", "сумасбродный"],
    "обезболив": ["обезболивши"],
    "обезболивав": ["обезболивавши"],
    "обезболивавши": ["обезболивав"],
    "обезболивание": ["обезболиванье", "обезбол"],
    "обезболивающее": ["анальгетик", "обезбаливающее"],
    "обезболивающий": ["болеутоляющий", "противоболевой"],
    "обезболивши": ["обезболив"],
    "обезболить": ["анестезировать"],
    "обезветрив": ["обезветривши"],
    "обезветривав": ["обезветривавши"],
    "обезветривавши": ["обезветривав"],
    "обезветривши": ["обезветрив"],
    "обезводев": ["обезводевши"],
    "обезводевши": ["обезводев"],
    "обезводив": ["обезводивши"],
    "обезводивши": ["обезводив"],
    "обезводить": ["высушить", "осушить", "дегидратировать"],
    "обезвожение": ["обезвоживание"],
    "обезвоженность": ["пересушенность"],
    "обезвоженный": ["высохший", "иссохший", "пересохший", "дегидратированный"],
    "обезвоживав": ["обезвоживавши"],
    "обезвоживавши": ["обезвоживав"],
    "обезвоживание": ["обезвоживанье", "дегидрация"],
    "обезвоживанье": ["обезвоживание", "дегидрация"],
    "обезволашивав": ["обезволашивавши"],
    "обезволашивавши": ["обезволашивав"],
    "обезволашивание": ["обезволошение", "эпиляция"],
    "обезволев": ["обезволевши"],
    "обезволевши": ["обезволев"],
    "обезволив": ["обезволивши"],
    "обезволивав": ["обезволивавши"],
    "обезволивавши": ["обезволивав"],
    "обезволивши": ["обезволив"],
    "обезволосив": ["обезволосивши"],
    "обезволосивши": ["обезволосив"],
    "обезвредив": ["обезвредивши"],
    "обезвредивши": ["обезвредив"],
    "обезвреживав": ["обезвреживавши"],
    "обезвреживавши": ["обезвреживав"],
    "обезгаживав": ["обезгаживавши"],
    "обезгаживавши": ["обезгаживав"],
    "обезгаживание": ["дегазация", "дегазирование"],
    "обезгаживать": ["дегазировать"],
    "обезгазив": ["обезгазивши"],
    "обезгазивши": ["обезгазив"],
    "обезглавев": ["обезглавевши"],
    "обезглавевши": ["обезглавев"],
    "обезглавив": ["обезглавивши"],
    "обезглавивши": ["обезглавив"],
    "обезглавление": ["обезглавливание", "декапитация"],
    "обезглавливав": ["обезглавливавши"],
    "обезглавливавши": ["обезглавливав"],
    "обезглавливание": ["обезглавление", "обезглавливанье", "декапитация"],
    "обезголосев": ["обезголосевши"],
    "обезголосевши": ["обезголосев"],
    "обездвижев": ["обездвижевши"],
    "обездвижевши": ["обездвижев"],
    "обездвижив": ["обездвиживши"],
    "обездвиживав": ["обездвиживавши"],
    "обездвиживавши": ["обездвиживав"],
    "обездвиживши": ["обездвижив"],
    "обездвижиться": ["обездвижеть"],
    "обезденежев": ["обезденежевши"],
    "обезденежевши": ["обезденежев"],
    "обезденежив": ["обезденеживши"],
    "обезденеживши": ["обезденежив"],
    "обездоленный": ["гонимый", "несчастный"],
    "обездолив": ["обездоливши"],
    "обездоливав": ["обездоливавши"],
    "обездоливавши": ["обездоливав"],
    "обездоливши": ["обездолив"],
    "обездолить": ["разорить", "ограбить", "пустить по миру", "обобрать до нитки", "расстроить"],
    "обездомев": ["обездомевши"],
    "обездомевши": ["обездомев"],
    "обездомив": ["обездомивши"],
    "обездомивши": ["обездомив"],
    "обездушев": ["обездушевши"],
    "обездушевши": ["обездушев"],
    "обездушив": ["обездушивши"],
    "обездушивав": ["обездушивавши"],
    "обездушивавши": ["обездушивав"],
    "обездушивши": ["обездушив"],
    "обезжелезив": ["обезжелезивши"],
    "обезжелезивав": ["обезжелезивавши"],
    "обезжелезивавши": ["обезжелезивав"],
    "обезжелезивши": ["обезжелезив"],
    "обезживотев": ["обезживотевши"],
    "обезживотевши": ["обезживотев"],
    "обезживотив": ["обезживотивши"],
    "обезживотивши": ["обезживотив"],
    "обезживотить": ["разорить"],
    "обезжизнив": ["обезжизнивши"],
    "обезжизнивши": ["обезжизнив"],
    "обезжиренный": ["безжирный"],
    "обезжирив": ["обезжиривши"],
    "обезжиривав": ["обезжиривавши"],
    "обезжиривавши": ["обезжиривав"],
    "обезжиривши": ["обезжирив"],
    "обеззараживав": ["обеззараживавши"],
    "обеззараживавши": ["обеззараживав"],
    "обеззараживание": ["дезинфекция", "обеззараживанье"],
    "обеззараживать": ["дезинфицировать"],
    "обеззаразив": ["обеззаразивши"],
    "обеззаразивши": ["обеззаразив"],
    "обеззаразити": ["знезаразити"],
    "обеззаразить": ["дезинфицировать", "продезинфицировать"],
    "обеззвучив": ["обеззвучивши"],
    "обеззвучивав": ["обеззвучивавши"],
    "обеззвучивавши": ["обеззвучивав"],
    "обеззвучивши": ["обеззвучив"],
    "обезземелев": ["обезземелевши"],
    "обезземелевши": ["обезземелев"],
    "обезземелив": ["обезземеливши"],
    "обезземеливав": ["обезземеливавши"],
    "обезземеливавши": ["обезземеливав"],
    "обезземеливши": ["обезземелив"],
    "обеззолив": ["обеззоливши"],
    "обеззоливав": ["обеззоливавши"],
    "обеззоливавши": ["обеззоливав"],
    "обеззоливши": ["обеззолив"],
    "обеззубев": ["обеззубевши"],
    "обеззубевши": ["обеззубев"],
    "обезлесев": ["обезлесевши"],
    "обезлесевши": ["обезлесев"],
    "обезлесив": ["обезлесивши"],
    "обезлесивав": ["обезлесивавши"],
    "обезлесивавши": ["обезлесивав"],
    "обезлесивши": ["обезлесив"],
    "обезлиствев": ["обезлиствевши"],
    "обезлиствевши": ["обезлиствев"],
    "обезлиствив": ["обезлиствивши"],
    "обезлиствивши": ["обезлиствив"],
    "обезличенность": ["безликость"],
    "обезличенье": ["обезличение"],
    "обезличив": ["обезличивши"],
    "обезличивав": ["обезличивавши"],
    "обезличивавши": ["обезличивав"],
    "обезличивание": ["обезличение", "нивелирование", "нивелировка"],
    "обезличивание паровозов": ["обезличка"],
    "обезличивши": ["обезличив"],
    "обезлошадев": ["обезлошадевши"],
    "обезлошадевши": ["обезлошадев"],
    "обезлошадив": ["обезлошадивши"],
    "обезлошадивши": ["обезлошадив"],
    "обезлюдев": ["обезлюдевши"],
    "обезлюдевши": ["обезлюдев"],
    "обезлюдеть": ["вымереть"],
    "обезлюдив": ["обезлюдивши"],
    "обезлюдивши": ["обезлюдив"],
    "обезлюживав": ["обезлюживавши"],
    "обезлюживавши": ["обезлюживав"],
    "обезматочев": ["обезматочевши"],
    "обезматочевши": ["обезматочев"],
    "обезмолвев": ["обезмолвевши"],
    "обезмолвевши": ["обезмолвев"],
    "обезмолвив": ["обезмолвивши"],
    "обезмолвивши": ["обезмолвив"],
    "обезмолвить": ["обезречить", "обезъязычить"],
    "обезмужичив": ["обезмужичивши"],
    "обезмужичивав": ["обезмужичивавши"],
    "обезмужичивавши": ["обезмужичивав"],
    "обезмужичивши": ["обезмужичив"],
    "обезмячив": ["обезмячивши"],
    "обезмячивши": ["обезмячив"],
    "обезмячить": ["отобрать", "мяч"],
    "обезнадёжив": ["обезнадёживши"],
    "обезнадёживав": ["обезнадёживавши"],
    "обезнадёживавши": ["обезнадёживав"],
    "обезнадёживши": ["обезнадёжив"],
    "обезналичив": ["обезналичивши"],
    "обезналичивав": ["обезналичивавши"],
    "обезналичивавши": ["обезналичивав"],
    "обезналичивши": ["обезналичив"],
    "обезнародив": ["обезнародивши"],
    "обезнародивши": ["обезнародив"],
    "обезножев": ["обезножевши"],
    "обезножевши": ["обезножев"],
    "обезножив": ["обезноживши"],
    "обезноживши": ["обезножив"],
    "обезображивав": ["обезображивавши"],
    "обезображивавши": ["обезображивав"],
    "обезображивать": ["уродовать"],
    "обезобразив": ["обезобразивши"],
    "обезобразивши": ["обезобразив"],
    "обезобразить": ["изуродовать"],
    "обезопасенный": ["обезопашенный"],
    "обезопасив": ["обезопасивши"],
    "обезопасивши": ["обезопасив"],
    "обезопашенный": ["обезопасенный"],
    "обезопашивав": ["обезопашивавши"],
    "обезопашивавши": ["обезопашивав"],
    "обезоружив": ["обезоруживши"],
    "обезоруживав": ["обезоруживавши"],
    "обезоруживавши": ["обезоруживав"],
    "обезоруживать": ["разоружать"],
    "обезоруживающий": ["подкупающий"],
    "обезоруживши": ["обезоружив"],
    "обезоружить": ["разоружить"],
    "обезрассудив": ["обезрассудивши"],
    "обезрассудивши": ["обезрассудив"],
    "обезрожив": ["обезроживши"],
    "обезроживав": ["обезроживавши"],
    "обезроживавши": ["обезроживав"],
    "обезроживши": ["обезрожив"],
    "обезручев": ["обезручевши"],
    "обезручевши": ["обезручев"],
    "обезручив": ["обезручивши"],
    "обезручивши": ["обезручив"],
    "обезрыбев": ["обезрыбевши"],
    "обезрыбевши": ["обезрыбев"],
    "обезрыбеть": ["обезрыбиться"],
    "обезрыбив": ["обезрыбивши"],
    "обезрыбивши": ["обезрыбив"],
    "обезрыбиться": ["обезрыбеть"],
    "обезрыбливав": ["обезрыбливавши"],
    "обезрыбливавши": ["обезрыбливав"],
    "обезуглеродив": ["обезуглеродивши"],
    "обезуглеродивши": ["обезуглеродив"],
    "обезуглероживав": ["обезуглероживавши"],
    "обезуглероживавши": ["обезуглероживав"],
    "обезуглероживание": ["декарбюризация"],
    "обезумев": ["обезумевши"],
    "обезумевав": ["обезумевавши"],
    "обезумевавши": ["обезумевав"],
    "обезумевши": ["обезумев"],
    "обезумив": ["обезумивши"],
    "обезумивши": ["обезумив"],
    "обезызвествив": ["обезызвествивши"],
    "обезызвествивши": ["обезызвествив"],
    "обезызвествляв": ["обезызвествлявши"],
    "обезызвествлявши": ["обезызвествляв"],
    "обезьяна": ["кривляка", "имитатор", "негроид", "собака", "собачка"],
    "обезьянив": ["обезьянивши"],
    "обезьянивши": ["обезьянив"],
    "обезьянник": ["приматник", "стакан", "камера предварительного заключения", "кпз"],
    "обезьянничав": ["обезьянничавши"],
    "обезьянничавши": ["обезьянничав"],
    "обезьянничание": ["обезьянничанье"],
    "обезьянничанье": ["обезьянничание"],
    "обезьянничать": ["подражать"],
    "обезьянство": ["обезьянничание", "обезьянничество", "попугайничество", "попугайство"],
    "обезьянствовав": ["обезьянствовавши"],
    "обезьянствовавши": ["обезьянствовав"],
    "обелив": ["обеливши"],
    "обеливав": ["обеливавши"],
    "обеливавши": ["обеливав"],
    "обеливать": ["обелять"],
    "обеливши": ["обелив"],
    "обелить": ["оправдать"],
    "обелюс": ["обел"],
    "обеляв": ["обелявши"],
    "обелявши": ["обеляв"],
    "обер-палач": ["обер-убийца"],
    "обер-убийца": ["обер-палач"],
    "оберег": ["талисман", "амулет", "апотропей", "обережь"],
    "оберегав": ["оберегавши"],
    "оберегавши": ["оберегав"],
    "обереганье": ["оберегание"],
    "оберегать": ["беречь", "охранять", "защищать", "ограждать", "сберегать", "сохранять", "сторожить", "стеречь"],
    "оберегающий": ["охраняющий"],
    "оберегг": ["оберэгг"],
    "обережь": ["оберег"],
    "обернув": ["обернувши"],
    "обернувши": ["обернув"],
    "обертовий": ["обертальний"],
    "обес-": ["обез-"],
    "обескислородив": ["обескислородивши"],
    "обескислородивши": ["обескислородив"],
    "обескислороживав": ["обескислороживавши"],
    "обескислороживавши": ["обескислороживав"],
    "обесклеивав": ["обесклеивавши"],
    "обесклеивавши": ["обесклеивав"],
    "обескровев": ["обескровевши"],
    "обескровевши": ["обескровев"],
    "обескровив": ["обескровивши"],
    "обескровивши": ["обескровив"],
    "обескровливав": ["обескровливавши"],
    "обескровливавши": ["обескровливав"],
    "обескрылив": ["обескрыливши"],
    "обескрыливав": ["обескрыливавши"],
    "обескрыливавши": ["обескрыливав"],
    "обескрыливши": ["обескрылив"],
    "обескураженность": ["озадаченность", "недоумение", "сконфуженность"],
    "обескуражив": ["обескураживши"],
    "обескураживав": ["обескураживавши"],
    "обескураживавши": ["обескураживав"],
    "обескураживать": ["обезнадёживать"],
    "обескураживши": ["обескуражив"],
    "обеспамятев": ["обеспамятевши"],
    "обеспамятевши": ["обеспамятев"],
    "обеспамятеть": ["обеспамятовал"],
    "обеспамятовав": ["обеспамятовавши"],
    "обеспамятовавши": ["обеспамятовав"],
    "обеспенивав": ["обеспенивавши"],
    "обеспенивавши": ["обеспенивав"],
    "обесперивав": ["обесперивавши"],
    "обесперивавши": ["обесперивав"],
    "обеспечив": ["обеспечивши"],
    "обеспечивав": ["обеспечивавши"],
    "обеспечивавши": ["обеспечивав"],
    "обеспечивши": ["обеспечив"],
    "обесплодев": ["обесплодевши"],
    "обесплодевши": ["обесплодев"],
    "обесплодив": ["обесплодивши"],
    "обесплодивши": ["обесплодив"],
    "обеспложивав": ["обеспложивавши"],
    "обеспложивавши": ["обеспложивав"],
    "обеспокоенность": ["беспокойство", "озабоченность", "тревога", "встревоженность"],
    "обеспокоенный": ["встревоженный"],
    "обеспокоив": ["обеспокоивши"],
    "обеспокоивав": ["обеспокоивавши"],
    "обеспокоивавши": ["обеспокоивав"],
    "обеспокоивши": ["обеспокоив"],
    "обеспокоить": ["встревожить"],
    "обеспылив": ["обеспыливши"],
    "обеспыливав": ["обеспыливавши"],
    "обеспыливавши": ["обеспыливав"],
    "обеспыливши": ["обеспылив"],
    "обессахарив": ["обессахаривши"],
    "обессахаривав": ["обессахаривавши"],
    "обессахаривавши": ["обессахаривав"],
    "обессахаривши": ["обессахарив"],
    "обессерив": ["обессеривши"],
    "обессеривав": ["обессеривавши"],
    "обессеривавши": ["обессеривав"],
    "обессеривание": ["десульфуризация"],
    "обессеривши": ["обессерив"],
    "обессилев": ["обессилевши"],
    "обессилевав": ["обессилевавши"],
    "обессилевавши": ["обессилевав"],
    "обессилевать": ["слабеть", "ослабевать"],
    "обессилевши": ["обессилев"],
    "обессиленный": ["истощённый", "изнурённый"],
    "обессилеть": ["ослабеть"],
    "обессилив": ["обессиливши"],
    "обессиливав": ["обессиливавши"],
    "обессиливавши": ["обессиливав"],
    "обессиливать": ["изнемождать", "изнурять"],
    "обессиливши": ["обессилив"],
    "обесславив": ["обесславивши"],
    "обесславивши": ["обесславив"],
    "обесславить": ["опорочить", "опозорить", "осквернить", "очернить"],
    "обесславливав": ["обесславливавши"],
    "обесславливавши": ["обесславливав"],
    "обесславливать": ["позорить", "порочить"],
    "обессмертив": ["обессмертивши"],
    "обессмертивши": ["обессмертив"],
    "обессмертить": ["увековечить"],
    "обессмерчивание": ["увековечение", "увековечивание"],
    "обессмолив": ["обессмоливши"],
    "обессмоливав": ["обессмоливавши"],
    "обессмоливавши": ["обессмоливав"],
    "обессмоливши": ["обессмолив"],
    "обессмыслев": ["обессмыслевши"],
    "обессмыслевши": ["обессмыслев"],
    "обессмыслив": ["обессмысливши"],
    "обессмысливав": ["обессмысливавши"],
    "обессмысливавши": ["обессмысливав"],
    "обессмысливши": ["обессмыслив"],
    "обессолив": ["обессоливши"],
    "обессоливав": ["обессоливавши"],
    "обессоливавши": ["обессоливав"],
    "обессоливши": ["обессолив"],
    "обессроченный": ["бессрочник"],
    "обессудив": ["обессудивши"],
    "обессудивши": ["обессудив"],
    "обессудить": ["осудить"],
    "обестолковев": ["обестолковевши"],
    "обестолковевши": ["обестолковев"],
    "обесточение": ["обесточивание", "отключение"],
    "обесточив": ["обесточивши"],
    "обесточивав": ["обесточивавши"],
    "обесточивавши": ["обесточивав"],
    "обесточивание": ["обесточение", "отключение"],
    "обесточивать": ["выключать", "отключать"],
    "обесточивши": ["обесточив"],
    "обесточить": ["выключить", "отключить"],
    "обесточка": ["блэкаут"],
    "обесформив": ["обесформивши"],
    "обесформивши": ["обесформив"],
    "обесфосфорив": ["обесфосфоривши"],
    "обесфосфоривав": ["обесфосфоривавши"],
    "обесфосфоривавши": ["обесфосфоривав"],
    "обесфосфоривши": ["обесфосфорив"],
    "обесфторив": ["обесфторивши"],
    "обесфторивав": ["обесфторивавши"],
    "обесфторивавши": ["обесфторивав"],
    "обесфторивши": ["обесфторив"],
    "обесцветив": ["обесцветивши"],
    "обесцветивши": ["обесцветив"],
    "обесцвечивав": ["обесцвечивавши"],
    "обесцвечивавши": ["обесцвечивав"],
    "обесценение": ["обесценивание"],
    "обесценив": ["обесценивши"],
    "обесценивав": ["обесценивавши"],
    "обесценивавши": ["обесценивав"],
    "обесценивание": ["обесценение"],
    "обесценивши": ["обесценив"],
    "обесчеловечив": ["обесчеловечивши"],
    "обесчеловечивав": ["обесчеловечивавши"],
    "обесчеловечивавши": ["обесчеловечивав"],
    "обесчеловечивание": ["дегуманизация"],
    "обесчеловечивши": ["обесчеловечив"],
    "обесчестив": ["обесчестивши"],
    "обесчестивши": ["обесчестив"],
    "обесчестить": ["опозорить"],
    "обесчещивав": ["обесчещивавши"],
    "обесчещивавши": ["обесчещивав"],
    "обесчещивать": ["позорить"],
    "обет": ["зарок", "клятва"],
    "обетованье": ["обетование"],
    "обетонировав": ["обетонировавши"],
    "обетонировавши": ["обетонировав"],
    "обещав": ["обещавши"],
    "обещавши": ["обещав"],
    "обещание": ["обет", "обязательство", "клятва"],
    "обещанье": ["обещание"],
    "обещать": ["давать обещание", "обещаться", "предвещать"],
    "обещник": ["сообщник"],
    "обж": ["основы безопасности жизнедеятельности", "обэжэшка", "обжшка"],
    "обжав": ["обжавши"],
    "обжавши": ["обжав"],
    "обжаднев": ["обжадневши"],
    "обжадневши": ["обжаднев"],
    "обжаловав": ["обжаловавши"],
    "обжаловавши": ["обжаловав"],
    "обжалованье": ["обжалование"],
    "обжаловать": ["апеллировать", "опротестовывать", "опротестовать", "оспаривать"],
    "обжарив": ["обжаривши"],
    "обжаривав": ["обжаривавши"],
    "обжаривавши": ["обжаривав"],
    "обжаривание": ["обжарка"],
    "обжаривши": ["обжарив"],
    "обжевав": ["обжевавши"],
    "обжевавши": ["обжевав"],
    "обженив": ["обженивши"],
    "обженивши": ["обженив"],
    "обженить": ["оженить"],
    "обжечь": ["обгореть", "опалить", "ожечь"],
    "обжив": ["обживши"],
    "обживав": ["обживавши"],
    "обживавши": ["обживав"],
    "обживши": ["обжив"],
    "обжигав": ["обжигавши"],
    "обжигавши": ["обжигав"],
    "обжигать": ["опалять"],
    "обжигаться": ["жечься"],
    "обжим": ["обжимка", "обжимание", "обжатие"],
    "обжимав": ["обжимавши"],
    "обжимавши": ["обжимав"],
    "обжиманье": ["обжимание"],
    "обжимка": ["обжатие", "обжим", "обжимание"],
    "обжинав": ["обжинавши"],
    "обжинавши": ["обжинав"],
    "обжинок": ["ожинок"],
    "обжирав": ["обжиравши"],
    "обжиравши": ["обжирав"],
    "обжираловка": ["объедание", "переедание"],
    "обжирать": ["объедать"],
    "обжираться": ["объедаться"],
    "обжитой": ["жилой"],
    "обжорствовав": ["обжорствовавши"],
    "обжорствовавши": ["обжорствовав"],
    "обжулив": ["обжуливши"],
    "обжуливав": ["обжуливавши"],
    "обжуливавши": ["обжуливав"],
    "обжуливши": ["обжулив"],
    "обжулить": ["облапошить"],
    "обжёвывав": ["обжёвывавши"],
    "обжёвывавши": ["обжёвывав"],
    "обзаведенье": ["обзаведение"],
    "обзаводив": ["обзаводивши"],
    "обзаводивши": ["обзаводив"],
    "обзадив": ["обзадивши"],
    "обзадивши": ["обзадив"],
    "обзаконив": ["обзаконивши"],
    "обзаконивав": ["обзаконивавши"],
    "обзаконивавши": ["обзаконивав"],
    "обзакониваться": ["узакониваться"],
    "обзаконивши": ["обзаконив"],
    "обзатыливав": ["обзатыливавши"],
    "обзатыливавши": ["обзатыливав"],
    "обзванивав": ["обзванивавши"],
    "обзванивавши": ["обзванивав"],
    "обзвон": ["обзванивание"],
    "обзвонив": ["обзвонивши"],
    "обзвонивши": ["обзвонив"],
    "обзеленев": ["обзеленевши"],
    "обзеленевши": ["обзеленев"],
    "обзеленив": ["обзеленивши"],
    "обзеленивши": ["обзеленив"],
    "обзеленить": ["позеленить", "озеленить"],
    "обзирав": ["обзиравши"],
    "обзиравши": ["обзирав"],
    "обзирать": ["обозревать", "озирать"],
    "обзнакомив": ["обзнакомивши"],
    "обзнакомивши": ["обзнакомив"],
    "обзолотив": ["обзолотивши"],
    "обзолотивши": ["обзолотив"],
    "обзорщик": ["обозреватель"],
    "обзорщица": ["обозревательница"],
    "обзывав": ["обзывавши"],
    "обзывавши": ["обзывав"],
    "обив": ["обивши"],
    "обивав": ["обивавши"],
    "обивавши": ["обивав"],
    "обивши": ["обив"],
    "обигорив": ["обигоривши"],
    "обигоривав": ["обигоривавши"],
    "обигоривавши": ["обигоривав"],
    "обигоривши": ["обигорив"],
    "обида": ["огорчение", "обижда", "досада", "горечь"],
    "обидев": ["обидевши"],
    "обидевши": ["обидев"],
    "обидеть": ["огорчить", "оскорбить", "раздосадовать", "недодать", "обделить"],
    "обидеться": ["разобитеться", "изобидеться"],
    "обидно": ["оскорбительно"],
    "обидный": ["оскорбительный", "досадный", "неприятный"],
    "обижавши": ["обижав"],
    "обижать": ["огорчать", "задевать", "оскорблять"],
    "обижаться": ["оскорбляться", "огорчаться"],
    "обиженный": ["уязвлённый", "оскорблённый", "разобиженный", "расстроенный", "обойдённый", "обделённый", "ущемлённый", "надутый", "изобиженный", "задетый"],
    "обилетив": ["обилетивши"],
    "обилетивши": ["обилетив"],
    "обилечивав": ["обилечивавши"],
    "обилечивавши": ["обилечивав"],
    "обилие": ["изобилие", "множество", "обилье", "достаток", "довольство", "богатство"],
    "обиловав": ["обиловавши"],
    "обиловавши": ["обиловав"],
    "обилье": ["обилие"],
    "обильно": ["в изобилии"],
    "обильный": ["многочисленный", "богатый", "щедрый"],
    "обиняк": ["намёк", "недоговоренность", "экивок"],
    "обир": ["грабеж", "обирничество", "обсебване", "плячкосване"],
    "обирав": ["обиравши"],
    "обиравши": ["обирав"],
    "обираловка": ["лохотрон", "разводилово", "обиралово"],
    "обиралово": ["лохотрон", "разводилово"],
    "обирник": ["разбойник", "грабител", "крадец", "шайкаджия"],
    "обистан": ["бордор"],
    "обитав": ["обитавши"],
    "обитавши": ["обитав"],
    "обитание": ["проживание"],
    "обитатель": ["житель"],
    "обитательница": ["квартирантка"],
    "обитать": ["водиться", "жить", "проживать", "населять"],
    "обитель": ["монастырь", "жилище", "пристанище", "приют", "угол", "обиталище", "кров", "крыша над головой"],
    "обихаживав": ["обихаживавши"],
    "обихаживавши": ["обихаживав"],
    "обихаживать": ["заботиться", "ухаживать", "охаживать"],
    "обиходив": ["обиходивши"],
    "обиходивши": ["обиходив"],
    "обич": ["любов"],
    "обичам": ["любя"],
    "обкакав": ["обкакавши"],
    "обкакавши": ["обкакав"],
    "обкакаться": ["обосраться", "обделаться", "обдристаться", "наделать под себя", "наделать в штаны", "обоссаться", "ошибиться", "промахнуться", "облажаться"],
    "обкакивав": ["обкакивавши"],
    "обкакивавши": ["обкакивав"],
    "обкалив": ["обкаливши"],
    "обкаливав": ["обкаливавши"],
    "обкаливавши": ["обкаливав"],
    "обкаливать": ["окаливать"],
    "обкаливши": ["обкалив"],
    "обкалить": ["окалить"],
    "обкалывав": ["обкалывавши"],
    "обкалывавши": ["обкалывав"],
    "обкапав": ["обкапавши"],
    "обкапавши": ["обкапав"],
    "обкапывав": ["обкапывавши"],
    "обкапывавши": ["обкапывав"],
    "обкарикатурив": ["обкарикатуривши"],
    "обкарикатуривав": ["обкарикатуривавши"],
    "обкарикатуривавши": ["обкарикатуривав"],
    "обкарикатуривши": ["обкарикатурив"],
    "обкаркав": ["обкаркавши"],
    "обкаркавши": ["обкаркав"],
    "обкармливав": ["обкармливавши"],
    "обкармливавши": ["обкармливав"],
    "обкармливать": ["перекармливать"],
    "обкарнывав": ["обкарнывавши"],
    "обкарнывавши": ["обкарнывав"],
    "обкатав": ["обкатавши"],
    "обкатавши": ["обкатав"],
    "обкатив": ["обкативши"],
    "обкативши": ["обкатив"],
    "обкатывав": ["обкатывавши"],
    "обкатывавши": ["обкатывав"],
    "обкатывать": ["окатывать"],
    "обкачивав": ["обкачивавши"],
    "обкачивавши": ["обкачивав"],
    "обкашивав": ["обкашивавши"],
    "обкашивавши": ["обкашивав"],
    "обкидав": ["обкидавши"],
    "обкидавши": ["обкидав"],
    "обкидывав": ["обкидывавши"],
    "обкидывавши": ["обкидывав"],
    "обкинув": ["обкинувши"],
    "обкинувши": ["обкинув"],
    "обкладочный": ["облицовочный", "обмуровочный"],
    "обкладывав": ["обкладывавши"],
    "обкладывавши": ["обкладывав"],
    "обклевав": ["обклевавши"],
    "обклевавши": ["обклевав"],
    "обклеив": ["обклеивши"],
    "обклеивав": ["обклеивавши"],
    "обклеивавши": ["обклеивав"],
    "обклеивать": ["оклеивать"],
    "обклеивши": ["обклеив"],
    "обклеить": ["оклеить"],
    "обклёвывав": ["обклёвывавши"],
    "обклёвывавши": ["обклёвывав"],
    "обковав": ["обковавши"],
    "обковавши": ["обковав"],
    "обковывав": ["обковывавши"],
    "обковывавши": ["обковывав"],
    "обковыривав": ["обковыривавши"],
    "обковыривавши": ["обковыривав"],
    "обковыряв": ["обковырявши"],
    "обковырявши": ["обковыряв"],
    "обколачивав": ["обколачивавши"],
    "обколачивавши": ["обколачивав"],
    "обколов": ["обколовши"],
    "обколовши": ["обколов"],
    "обколотив": ["обколотивши"],
    "обколотивши": ["обколотив"],
    "обком": ["областной комитет"],
    "обконопатив": ["обконопативши"],
    "обконопативши": ["обконопатив"],
    "обконопачивав": ["обконопачивавши"],
    "обконопачивавши": ["обконопачивав"],
    "обконопачивать": ["оконопачивать"],
    "обконопачиваться": ["оконопачиваться"],
    "обкончав": ["обкончавши"],
    "обкончавши": ["обкончав"],
    "обкопав": ["обкопавши"],
    "обкопавши": ["обкопав"],
    "обкопать": ["окопать"],
    "обкорачивав": ["обкорачивавши"],
    "обкорачивавши": ["обкорачивав"],
    "обкормив": ["обкормивши"],
    "обкормивши": ["обкормив"],
    "обкорнав": ["обкорнавши"],
    "обкорнавши": ["обкорнав"],
    "обкорнать": ["обкарнать", "окорнать"],
    "обкоротив": ["обкоротивши"],
    "обкоротивши": ["обкоротив"],
    "обкосив": ["обкосивши"],
    "обкосивши": ["обкосив"],
    "обкостерив": ["обкостеривши"],
    "обкостеривши": ["обкостерив"],
    "обкрадывав": ["обкрадывавши"],
    "обкрадывавши": ["обкрадывав"],
    "обкрадывать": ["обворовывать"],
    "обкраивав": ["обкраивавши"],
    "обкраивавши": ["обкраивав"],
    "обкрасив": ["обкрасивши"],
    "обкрасивши": ["обкрасив"],
    "обкраситься": ["окраситься"],
    "обкрашивав": ["обкрашивавши"],
    "обкрашивавши": ["обкрашивав"],
    "обкроив": ["обкроивши"],
    "обкроивши": ["обкроив"],
    "обкромсав": ["обкромсавши"],
    "обкромсавши": ["обкромсав"],
    "обкрошив": ["обкрошивши"],
    "обкрошивши": ["обкрошив"],
    "обкрошившийся": ["обсыпавшийся", "рассыпавшийся"],
    "обкрошить": ["окрошить"],
    "обкрутив": ["обкрутивши"],
    "обкрутивши": ["обкрутив"],
    "обкручивав": ["обкручивавши"],
    "обкручивавши": ["обкручивав"],
    "обкургузив": ["обкургузивши"],
    "обкургузивши": ["обкургузив"],
    "обкургузиться": ["окургузиться"],
    "обкурив": ["обкуривши"],
    "обкуривав": ["обкуривавши"],
    "обкуривавши": ["обкуривав"],
    "обкуривши": ["обкурив"],
    "обкусав": ["обкусавши"],
    "обкусавши": ["обкусав"],
    "обкусив": ["обкусивши"],
    "обкусивши": ["обкусив"],
    "обкусывав": ["обкусывавши"],
    "обкусывавши": ["обкусывав"],
    "обкутав": ["обкутавши"],
    "обкутавши": ["обкутав"],
    "обкутывав": ["обкутывавши"],
    "обкутывавши": ["обкутывав"],
    "обкушав": ["обкушавши"],
    "обкушавши": ["обкушав"],
    "обкушивав": ["обкушивавши"],
    "обкушивавши": ["обкушивав"],
    "облавливав": ["облавливавши"],
    "облавливавши": ["облавливав"],
    "облага": ["полза", "изгода", "придобивка", "печалба"],
    "облагав": ["облагавши"],
    "облагавши": ["облагав"],
    "облагодетельствовав": ["облагодетельствовавши"],
    "облагодетельствовавши": ["облагодетельствовав"],
    "облагозвучив": ["облагозвучивши"],
    "облагозвучивав": ["облагозвучивавши"],
    "облагозвучивавши": ["облагозвучивав"],
    "облагозвучивши": ["облагозвучив"],
    "облагоображивав": ["облагоображивавши"],
    "облагоображивавши": ["облагоображивав"],
    "облагообразив": ["облагообразивши"],
    "облагообразивши": ["облагообразив"],
    "облагораживав": ["облагораживавши"],
    "облагораживавши": ["облагораживав"],
    "облагоразумив": ["облагоразумивши"],
    "облагоразумивши": ["облагоразумив"],
    "облагородив": ["облагородивши"],
    "облагородивши": ["облагородив"],
    "облаготворив": ["облаготворивши"],
    "облаготворивши": ["облаготворив"],
    "обладав": ["обладавши"],
    "обладавши": ["обладав"],
    "обладание": ["обладательство", "обладанье"],
    "обладанье": ["обладание"],
    "обладатель": ["владелец", "владетель", "собственник", "хозяин"],
    "обладать": ["владеть", "распоряжаться", "располагать", "владычествовать", "властвовать", "хозяйничать", "иметь"],
    "обладив": ["обладивши"],
    "обладивши": ["обладив"],
    "облажав": ["облажавши"],
    "облажавши": ["облажав"],
    "облажаться": ["лажануться"],
    "облаживав": ["облаживавши"],
    "облаживавши": ["облаживав"],
    "облазав": ["облазавши"],
    "облазавши": ["облазав"],
    "облазив": ["облазивши"],
    "облазивши": ["облазив"],
    "облаивав": ["облаивавши"],
    "облаивавши": ["облаивав"],
    "облак": ["облако", "туча", "клуб"],
    "обламывав": ["обламывавши"],
    "обламывавши": ["обламывав"],
    "обламывать": ["огорчать", "удручать", "расстраивать", "разочаровывать", "срывать"],
    "обламывать рога": ["обламывать уши", "обламывать клешни"],
    "облапав": ["облапавши"],
    "облапавши": ["облапав"],
    "облапив": ["облапивши"],
    "облапивши": ["облапив"],
    "облапливав": ["облапливавши"],
    "облапливавши": ["облапливав"],
    "облапошенный": ["обманутый", "одураченный", "объегоренный"],
    "облапошив": ["облапошивши"],
    "облапошивав": ["облапошивавши"],
    "облапошивавши": ["облапошивав"],
    "облапошивать": ["надувать", "одурачивать", "разводить"],
    "облапошиваться": ["одурачиваться", "объегориваться", "оболваниваться"],
    "облапошивши": ["облапошив"],
    "облапошить": ["обвести вокруг пальца", "одурачить", "обдурить", "объегорить", "развести", "надуть", "наколоть"],
    "обласкав": ["обласкавши"],
    "обласкавши": ["обласкав"],
    "обласкивав": ["обласкивавши"],
    "обласкивавши": ["обласкивав"],
    "областной": ["региональный", "местный"],
    "область": ["район", "регион", "участок", "местность", "губерния", "окрестность", "отрасль", "раздел", "сфера", "областной центр"],
    "облатав": ["облатавши"],
    "облатавши": ["облатав"],
    "облатка": ["капсула", "таблетка", "блистер", "гостия"],
    "облачав": ["облачавши"],
    "облачавши": ["облачав"],
    "облачение": ["облаченье", "одеяние", "одеянье"],
    "облаченье": ["облачение"],
    "облачив": ["облачивши"],
    "облачивши": ["облачив"],
    "облачко": ["тучка"],
    "облачность": ["пасмурность"],
    "облачный": ["пасмурный"],
    "облаяв": ["облаявши"],
    "облаявши": ["облаяв"],
    "облевав": ["облевавши"],
    "облевавши": ["облевав"],
    "облевать": ["заблевать"],
    "облегав": ["облегавши"],
    "облегавши": ["облегав"],
    "облегчав": ["облегчавши"],
    "облегчавши": ["облегчав"],
    "облегчать": ["упрощать"],
    "облегченье": ["облегчение"],
    "облегчив": ["облегчивши"],
    "облегчивши": ["облегчив"],
    "облегчить": ["упростить"],
    "облегчиться": ["упроститься", "скраситься", "притупиться", "сделать по-большому", "сходить по-большому", "сходить за нуждой", "опроститься", "сходить по нужде", "сходить на двор", "оправиться", "покакать", "сходить до ветру", "испражниться", "посрать", "поссать"],
    "облегчённо": ["с облегчением"],
    "обледенев": ["обледеневши"],
    "обледеневав": ["обледеневавши"],
    "обледеневавши": ["обледеневав"],
    "обледеневши": ["обледенев"],
    "обледенение": ["оледенение"],
    "обледенеть": ["заледенеть", "оледенеть", "закоченеть", "окоченеть"],
    "обледенив": ["обледенивши"],
    "обледенивши": ["обледенив"],
    "обледеняв": ["обледенявши"],
    "обледенявши": ["обледеняв"],
    "облежав": ["облежавши"],
    "облежавши": ["облежав"],
    "облезав": ["облезавши"],
    "облезавши": ["облезав"],
    "облезлый": ["лысый", "плешивый", "безволосый", "голый", "оголённый"],
    "облекав": ["облекавши"],
    "облекавши": ["облекав"],
    "обленив": ["обленивши"],
    "обленивав": ["обленивавши"],
    "обленивавши": ["обленивав"],
    "обленивши": ["обленив"],
    "облепив": ["облепивши"],
    "облепивши": ["облепив"],
    "облепиховый": ["облепишный"],
    "облепливав": ["облепливавши"],
    "облепливавши": ["облепливав"],
    "облепливать": ["облеплять"],
    "облепливаться": ["облепляться"],
    "облепляв": ["облеплявши"],
    "облеплявши": ["облепляв"],
    "облесив": ["облесивши"],
    "облесивши": ["облесив"],
    "облеснув": ["облеснувши"],
    "облеснувши": ["облеснув"],
    "облесяв": ["облесявши"],
    "облесявши": ["облесяв"],
    "облетав": ["облетавши"],
    "облетавши": ["облетав"],
    "облетев": ["облетевши"],
    "облетевши": ["облетев"],
    "облечение": ["обволакивание", "облачение", "одевание", "окутывание", "ряжение"],
    "облив": ["обливание"],
    "обливав": ["обливавши"],
    "обливавши": ["обливав"],
    "обливанье": ["обливание"],
    "обливать грязью": ["чернить", "порочить", "бесчестить", "сплетничать", "клеветать"],
    "обливаться": ["окатываться", "охватываться", "покрываться"],
    "обливши": ["облив"],
    "облигатный": ["необходимый", "непременный", "обязательный"],
    "облигация": ["облига"],
    "облизав": ["облизавши"],
    "облизавши": ["облизав"],
    "облизнув": ["облизнувши"],
    "облизнувши": ["облизнув"],
    "облизывав": ["облизывавши"],
    "облизывавши": ["облизывав"],
    "облизыванье": ["облизывание"],
    "облизывать": ["лизать"],
    "облик": ["обличье"],
    "облиняв": ["облинявши"],
    "облинявши": ["облиняв"],
    "облипав": ["облипавши"],
    "облипавши": ["облипав"],
    "облипнув": ["облипнувши"],
    "облипнувши": ["облипнув"],
    "облисполком": ["областной исполнительный комитет"],
    "облиствев": ["облиствевши"],
    "облиствевши": ["облиствев"],
    "облиственев": ["облиственевши"],
    "облиственевши": ["облиственев"],
    "облиствив": ["облиствивши"],
    "облиствивши": ["облиствив"],
    "облитературив": ["облитературивши"],
    "облитературивав": ["облитературивавши"],
    "облитературивавши": ["облитературивав"],
    "облитературивши": ["облитературив"],
    "облитерация": ["заращение", "атрезия"],
    "облитерировав": ["облитерировавши"],
    "облитерировавши": ["облитерировав"],
    "облицевав": ["облицевавши"],
    "облицевавши": ["облицевав"],
    "облицовывав": ["облицовывавши"],
    "облицовывавши": ["облицовывав"],
    "облицовывать": ["выкладывать", "лицевать"],
    "облицьовувальний": ["облицювальний"],
    "обличав": ["обличавши"],
    "обличавши": ["обличав"],
    "обличать": ["изобличать", "разоблачать", "уличать", "обвинять"],
    "обличенье": ["обличение"],
    "обличив": ["обличивши"],
    "обличивши": ["обличив"],
    "обличие": ["облик", "обличье"],
    "обличитель": ["обвинитель"],
    "обличительный": ["обличающий", "изобличающий", "осуждающий"],
    "обличить": ["изобличить", "разоблачить", "уличить", "обвинить", "раскрыть"],
    "обличье": ["лицо", "облик"],
    "облобызав": ["облобызавши"],
    "облобызавши": ["облобызав"],
    "облобызать": ["расцеловать"],
    "обловив": ["обловивши"],
    "обловивши": ["обловив"],
    "обложенье": ["обложение"],
    "обложив": ["обложивши"],
    "обложивши": ["обложив"],
    "обложка": ["корочка", "переплётная крышка", "шапка"],
    "обложной": ["окладной"],
    "облой": ["заусеница", "заусенец", "облец", "сляча"],
    "облокачивав": ["облокачивавши"],
    "облокачивавши": ["облокачивав"],
    "облокотив": ["облокотивши"],
    "облокотивши": ["облокотив"],
    "облом": ["отлом", "разлом", "досада", "расстройство", "разочарование", "горечь", "неприятность", "фрустрация", "бруствер", "заборол", "облам"],
    "обломав": ["обломавши"],
    "обломавши": ["обломав"],
    "обломать": ["отломать", "отломить", "расстроить", "разочаровать", "сорвать"],
    "обломив": ["обломивши"],
    "обломивши": ["обломив"],
    "обломинго": ["птица обломинго"],
    "обломлення": ["обломлювання"],
    "обломок": ["осколок", "пережиток"],
    "облудив": ["облудивши"],
    "облудивши": ["облудив"],
    "облуживав": ["облуживавши"],
    "облуживавши": ["облуживав"],
    "облупив": ["облупивши"],
    "облупивши": ["облупив"],
    "облупиться": ["осыпаться"],
    "облупленный": ["очищенный", "облезлый"],
    "облупливав": ["облупливавши"],
    "облупливавши": ["облупливав"],
    "облупляв": ["облуплявши"],
    "облуплявши": ["облупляв"],
    "облучав": ["облучавши"],
    "облучавши": ["облучав"],
    "облучив": ["облучивши"],
    "облучивши": ["облучив"],
    "облучок": ["деревина", "деревенина", "боковой", "край"],
    "облущив": ["облущивши"],
    "облущивав": ["облущивавши"],
    "облущивавши": ["облущивав"],
    "облущивать": ["лущить"],
    "облущивши": ["облущив"],
    "облыгав": ["облыгавши"],
    "облыгавши": ["облыгав"],
    "облыгать": ["лгать", "обманывать"],
    "облыжно": ["ложно", "обманно", "поддельно", "несправедливо", "клеветнически", "лживо", "напрасно", "незаслуженно"],
    "облыжность": ["лживость", "лицемерие", "лукавство", "двоедушие", "криводушие"],
    "облыжный": ["ложный", "обманный", "поддельный", "несправедливый"],
    "облый": ["круглый", "округлый", "кругловатый", "закруглённый", "выпуклый", "рельефный", "полный", "плотный", "толстый", "тучный"],
    "облысев": ["облысевши"],
    "облысевши": ["облысев"],
    "облысение": ["плешивость", "алопеция"],
    "облысенье": ["облысение"],
    "облюбив": ["облюбивши"],
    "облюбивши": ["облюбив"],
    "облюбить": ["облюбовать"],
    "облюбовав": ["облюбовавши"],
    "облюбовавши": ["облюбовав"],
    "облюбовать": ["предпочесть", "положить глаз"],
    "облюбовывав": ["облюбовывавши"],
    "облюбовывавши": ["облюбовывав"],
    "облюмовка": ["облимовка"],
    "обляпав": ["обляпавши"],
    "обляпавши": ["обляпав"],
    "обляпывав": ["обляпывавши"],
    "обляпывавши": ["обляпывав"],
    "облёвывав": ["облёвывавши"],
    "облёвывавши": ["облёвывав"],
    "облёживав": ["облёживавши"],
    "облёживавши": ["облёживав"],
    "облёскивав": ["облёскивавши"],
    "облёскивавши": ["облёскивав"],
    "облётывав": ["облётывавши"],
    "облётывавши": ["облётывав"],
    "обмазав": ["обмазавши"],
    "обмазавши": ["обмазав"],
    "обмазать": ["намазать", "обмарать"],
    "обмазывав": ["обмазывавши"],
    "обмазывавши": ["обмазывав"],
    "обмазывать": ["намазывать", "обмарывать"],
    "обмакивав": ["обмакивавши"],
    "обмакивавши": ["обмакивав"],
    "обмакивание": ["макание", "окунание"],
    "обмакивая": ["макая"],
    "обмакнув": ["обмакнувши"],
    "обмакнувши": ["обмакнув"],
    "обмалевав": ["обмалевавши"],
    "обмалевавши": ["обмалевав"],
    "обмалывав": ["обмалывавши"],
    "обмалывавши": ["обмалывав"],
    "обмалёвывав": ["обмалёвывавши"],
    "обмалёвывавши": ["обмалёвывав"],
    "обман": ["ложь", "враньё", "мистификация", "заблуждение"],
    "обманити": ["обманути"],
    "обманность": ["ложность", "лживость"],
    "обманный": ["ложный", "лживый", "жульнический", "притворный"],
    "обманув": ["обманувши"],
    "обманувши": ["обманув"],
    "обмануться": ["ошибиться", "просчитаться"],
    "обманщица": ["лгунья"],
    "обманывав": ["обманывавши"],
    "обманывавши": ["обманывав"],
    "обманывать": ["врать", "лгать", "вводить в заблуждение", "мошенничать", "предавать"],
    "обманываться": ["ошибаться", "заблуждаться", "просчитаться"],
    "обмарав": ["обмаравши"],
    "обмаравши": ["обмарав"],
    "обмарывав": ["обмарывавши"],
    "обмарывавши": ["обмарывав"],
    "обмаслив": ["обмасливши"],
    "обмасливав": ["обмасливавши"],
    "обмасливавши": ["обмасливав"],
    "обмасливши": ["обмаслив"],
    "обматерев": ["обматеревши"],
    "обматеревши": ["обматерев"],
    "обматерив": ["обматеривши"],
    "обматеривши": ["обматерив"],
    "обматывав": ["обматывавши"],
    "обматывавши": ["обматывав"],
    "обматывать": ["обвязывать", "обвивать", "опутывать", "обкручивать", "заматывать", "окутывать"],
    "обматюгав": ["обматюгавши"],
    "обматюгавши": ["обматюгав"],
    "обматюгать": ["обматерить", "покрыть матом"],
    "обматюкав": ["обматюкавши"],
    "обматюкавши": ["обматюкав"],
    "обмахав": ["обмахавши"],
    "обмахавши": ["обмахав"],
    "обмахивав": ["обмахивавши"],
    "обмахивавши": ["обмахивав"],
    "обмахнув": ["обмахнувши"],
    "обмахнувши": ["обмахнув"],
    "обмачивав": ["обмачивавши"],
    "обмачивавши": ["обмачивав"],
    "обмеблировав": ["обмеблировавши"],
    "обмеблировавши": ["обмеблировав"],
    "обмеблировывав": ["обмеблировывавши"],
    "обмеблировывавши": ["обмеблировывав"],
    "обмеблировывать": ["омеблировывать"],
    "обмежевав": ["обмежевавши"],
    "обмежевавши": ["обмежевав"],
    "обмежёвывав": ["обмежёвывавши"],
    "обмежёвывавши": ["обмежёвывав"],
    "обмелев": ["обмелевши"],
    "обмелевав": ["обмелевавши"],
    "обмелевавши": ["обмелевав"],
    "обмелевши": ["обмелев"],
    "обмелив": ["обмеливши"],
    "обмеливав": ["обмеливавши"],
    "обмеливавши": ["обмеливав"],
    "обмеливши": ["обмелив"],
    "обмельчав": ["обмельчавши"],
    "обмельчавши": ["обмельчав"],
    "обмеляв": ["обмелявши"],
    "обмелявши": ["обмеляв"],
    "обмен": ["обмена", "мена"],
    "обмен веществ": ["метаболизм"],
    "обменив": ["обменивши"],
    "обменивав": ["обменивавши"],
    "обменивавши": ["обменивав"],
    "обменивать": ["менять"],
    "обмениваться": ["меняться"],
    "обменивши": ["обменив"],
    "обменка": ["обменник"],
    "обменник": ["обменка"],
    "обменщик": ["меняла"],
    "обменяв": ["обменявши"],
    "обменявши": ["обменяв"],
    "обмер": ["измерение", "обмерка"],
    "обмерев": ["обмерши"],
    "обмереть": ["оцепенеть", "остолбенеть", "обомлеть"],
    "обмерзав": ["обмерзавши"],
    "обмерзавши": ["обмерзав"],
    "обмерив": ["обмеривши"],
    "обмеривав": ["обмеривавши"],
    "обмеривавши": ["обмеривав"],
    "обмеривать": ["обмерять", "обмишуливать"],
    "обмеривши": ["обмерив"],
    "обмерный": ["обмерочный"],
    "обмерши": ["обмерев"],
    "обмеряв": ["обмерявши"],
    "обмерявши": ["обмеряв"],
    "обмерять": ["обмеривать"],
    "обмеряющий": ["обмеривающий"],
    "обметав": ["обметавши"],
    "обметавши": ["обметав"],
    "обметив": ["обметивши"],
    "обметивши": ["обметив"],
    "обмечав": ["обмечавши"],
    "обмечавши": ["обмечав"],
    "обмещанив": ["обмещанивши"],
    "обмещанивав": ["обмещанивавши"],
    "обмещанивавши": ["обмещанивав"],
    "обмещанивши": ["обмещанив"],
    "обмещаниться": ["омещаниться"],
    "обмизерив": ["обмизеривши"],
    "обмизеривши": ["обмизерив"],
    "обмин": ["обминание", "обмятие"],
    "обминав": ["обминавши"],
    "обминавши": ["обминав"],
    "обмирав": ["обмиравши"],
    "обмиравши": ["обмирав"],
    "обмирщав": ["обмирщавши"],
    "обмирщавши": ["обмирщав"],
    "обмирщение": ["осквернение"],
    "обмирщив": ["обмирщивши"],
    "обмирщивши": ["обмирщив"],
    "обмишулив": ["обмишуливши"],
    "обмишуливав": ["обмишуливавши"],
    "обмишуливавши": ["обмишуливав"],
    "обмишуливать": ["обмишуривать", "облапошивать", "одурачивать"],
    "обмишуливши": ["обмишулив"],
    "обмишулить": ["обмишурить"],
    "обмишурив": ["обмишуривши"],
    "обмишуривав": ["обмишуривавши"],
    "обмишуривавши": ["обмишуривав"],
    "обмишуривать": ["обмишуливать"],
    "обмишуривши": ["обмишурив"],
    "обмишурить": ["обмишулить"],
    "обмишуриться": ["обмануться"],
    "обмозговав": ["обмозговавши"],
    "обмозговавши": ["обмозговав"],
    "обмозговывав": ["обмозговывавши"],
    "обмозговывавши": ["обмозговывав"],
    "обмозговывать": ["обдумывать"],
    "обмозолив": ["обмозоливши"],
    "обмозоливав": ["обмозоливавши"],
    "обмозоливавши": ["обмозоливав"],
    "обмозоливши": ["обмозолив"],
    "обмокав": ["обмокавши"],
    "обмокавши": ["обмокав"],
    "обмокнув": ["обмокнувши"],
    "обмокнувши": ["обмокнув"],
    "обмолачивав": ["обмолачивавши"],
    "обмолачивавши": ["обмолачивав"],
    "обмолвив": ["обмолвивши"],
    "обмолвивши": ["обмолвив"],
    "обмолвка": ["оговорка"],
    "обмолвливав": ["обмолвливавши"],
    "обмолвливавши": ["обмолвливав"],
    "обмолвливаться": ["оговариваться", "проговариваться", "пробалтываться"],
    "обмолвляв": ["обмолвлявши"],
    "обмолвлявши": ["обмолвляв"],
    "обмолвлять": ["обмолвливать"],
    "обмолив": ["обмоливши"],
    "обмоливши": ["обмолив"],
    "обмолов": ["обмоловши"],
    "обмоловши": ["обмолов"],
    "обмолот": ["обмолачивание", "молотьба"],
    "обмолотив": ["обмолотивши"],
    "обмолотивши": ["обмолотив"],
    "обмонолитив": ["обмонолитивши"],
    "обмонолитивши": ["обмонолитив"],
    "обмоноличивав": ["обмоноличивавши"],
    "обмоноличивавши": ["обмоноличивав"],
    "обмораживав": ["обмораживавши"],
    "обмораживавши": ["обмораживав"],
    "обмораживать": ["морозить"],
    "обморачивав": ["обморачивавши"],
    "обморачивавши": ["обморачивав"],
    "обморожение": ["обмораживание"],
    "обмороження": ["обморожування"],
    "обморозив": ["обморозивши"],
    "обморозивши": ["обморозив"],
    "обморозить": ["отморозить"],
    "обморок": ["синкопа", "беспамятство"],
    "обморочив": ["обморочивши"],
    "обморочивав": ["обморочивавши"],
    "обморочивавши": ["обморочивав"],
    "обморочивши": ["обморочив"],
    "обморочить": ["заворожить", "околдовать", "заморочить", "обмануть", "одурачить"],
    "обмотав": ["обмотавши"],
    "обмотавши": ["обмотав"],
    "обмотка": ["обматывание"],
    "обмохнатев": ["обмохнатевши"],
    "обмохнатевши": ["обмохнатев"],
    "обмочив": ["обмочивши"],
    "обмочивши": ["обмочив"],
    "обмочиться": ["облиться", "намочиться", "описаться"],
    "обмошенничав": ["обмошенничавши"],
    "обмошенничавши": ["обмошенничав"],
    "обмошенничивав": ["обмошенничивавши"],
    "обмошенничивавши": ["обмошенничивав"],
    "обмундировав": ["обмундировавши"],
    "обмундировавши": ["обмундировав"],
    "обмундирование": ["обмундировка", "экипировка", "форменная одежда", "униформа"],
    "обмундированье": ["обмундирование"],
    "обмундировка": ["обмундирование"],
    "обмундировывав": ["обмундировывавши"],
    "обмундировывавши": ["обмундировывав"],
    "обмундштучив": ["обмундштучивши"],
    "обмундштучивши": ["обмундштучив"],
    "обмуровав": ["обмуровавши"],
    "обмуровавши": ["обмуровав"],
    "обмуровочный": ["обкладочный", "облицовочный"],
    "обмуровывав": ["обмуровывавши"],
    "обмуровывавши": ["обмуровывав"],
    "обмуслив": ["обмусливши"],
    "обмусливав": ["обмусливавши"],
    "обмусливавши": ["обмусливав"],
    "обмусливши": ["обмуслив"],
    "обмуслить": ["обмусолить"],
    "обмусолив": ["обмусоливши"],
    "обмусоливав": ["обмусоливавши"],
    "обмусоливавши": ["обмусоливав"],
    "обмусоливши": ["обмусолив"],
    "обмусолить": ["обмуслить"],
    "обмывав": ["обмывавши"],
    "обмывавши": ["обмывав"],
    "обмывание": ["омовение", "смывание", "ополаскивание", "омывание"],
    "обмывать": ["омыть", "обмыть", "вымыть", "обстирывать", "отмечать"],
    "обмывать ножки": ["обмывать пяточки", "обмывать копытца"],
    "обмывши": ["обмыв"],
    "обмызгав": ["обмызгавши"],
    "обмызгавши": ["обмызгав"],
    "обмызгивав": ["обмызгивавши"],
    "обмызгивавши": ["обмызгивав"],
    "обмылив": ["обмыливши"],
    "обмыливав": ["обмыливавши"],
    "обмыливавши": ["обмыливав"],
    "обмыливши": ["обмылив"],
    "обмыслив": ["обмысливши"],
    "обмысливав": ["обмысливавши"],
    "обмысливавши": ["обмысливав"],
    "обмысливши": ["обмыслив"],
    "обмыть": ["омыть", "вымыть", "обстирать", "отметить"],
    "обмяв": ["обмявши"],
    "обмявши": ["обмяв"],
    "обмякав": ["обмякавши"],
    "обмякавши": ["обмякав"],
    "обмякать": ["увядать", "расслабляться", "раскрепощаться"],
    "обмякнув": ["обмякнувши"],
    "обмякнувши": ["обмякнув"],
    "обмякнуть": ["размякнуть"],
    "обмяна": ["обмен"],
    "обмёрзнув": ["обмёрзнувши"],
    "обмёрзнувши": ["обмёрзнув"],
    "обмётывав": ["обмётывавши"],
    "обмётывавши": ["обмётывав"],
    "обнаглев": ["обнаглевши"],
    "обнаглевши": ["обнаглев"],
    "обнаглив": ["обнагливши"],
    "обнагливши": ["обнаглив"],
    "обнаготив": ["обнаготивши"],
    "обнаготивши": ["обнаготив"],
    "обнадёжив": ["обнадёживши"],
    "обнадёживав": ["обнадёживавши"],
    "обнадёживавши": ["обнадёживав"],
    "обнадёживающе": ["многообещающе"],
    "обнадёживши": ["обнадёжив"],
    "обнажав": ["обнажавши"],
    "обнажавши": ["обнажав"],
    "обнажаться": ["оголяться", "раздеваться"],
    "обнаженье": ["обнажение"],
    "обнажив": ["обнаживши"],
    "обнаживши": ["обнажив"],
    "обнажить": ["оголить"],
    "обнажёнка": ["ню"],
    "обнажённость": ["нагота"],
    "обнажённый": ["голый", "нагой", "оголённый", "неприкрытый", "декольтированный", "открытый", "непокрытый"],
    "обнайтовив": ["обнайтовивши"],
    "обнайтовивши": ["обнайтовив"],
    "обналичив": ["обналичивши"],
    "обналичивав": ["обналичивавши"],
    "обналичивавши": ["обналичивав"],
    "обналичивание": ["обнал", "обналичка"],
    "обналичивши": ["обналичив"],
    "обнародовав": ["обнародовавши"],
    "обнародовавши": ["обнародовав"],
    "обнародование": ["опубликование", "публикация"],
    "обнаружение": ["нахождение"],
    "обнаруженный": ["найденный"],
    "обнаружив": ["обнаруживши"],
    "обнаруживав": ["обнаруживавши"],
    "обнаруживавши": ["обнаруживав"],
    "обнаруживание": ["обнаружение"],
    "обнаруживать": ["находить", "отыскивать", "разыскивать", "выяснять", "открывать", "узнавать", "проявлять", "показывать"],
    "обнаруживающий": ["выявляющий", "проявляющий"],
    "обнаруживши": ["обнаружив"],
    "обнаружить": ["найти", "отыскать", "разыскать", "выяснить", "открыть", "узнать", "проявить", "показать"],
    "обнашивав": ["обнашивавши"],
    "обнашивавши": ["обнашивав"],
    "обнемечив": ["обнемечивши"],
    "обнемечивав": ["обнемечивавши"],
    "обнемечивавши": ["обнемечивав"],
    "обнемечивать": ["онемечивать"],
    "обнемечивши": ["обнемечив"],
    "обнижав": ["обнижавши"],
    "обнижавши": ["обнижав"],
    "обнизав": ["обнизавши"],
    "обнизавши": ["обнизав"],
    "обнизив": ["обнизивши"],
    "обнизивши": ["обнизив"],
    "обнизить": ["окоротить"],
    "обнизывав": ["обнизывавши"],
    "обнизывавши": ["обнизывав"],
    "обнимав": ["обнимавши"],
    "обнимавши": ["обнимав"],
    "обнимание": ["обниманье"],
    "обнимать": ["заключать в объятия", "охватывать"],
    "обнимка": ["объятье", "обниманье", "обнимашка"],
    "обнищав": ["обнищавши"],
    "обнищавши": ["обнищав"],
    "обнищанье": ["обнищание"],
    "обнова": ["обновка", "обновление", "апдейт"],
    "обновив": ["обновивши"],
    "обновивши": ["обновив"],
    "обновка": ["обнова"],
    "обновленец": ["модернист"],
    "обновление": ["модернизация", "актуализация", "реновация", "апгрейд", "преображение", "возрождение", "апдейт", "обнова"],
    "обновленье": ["обновление"],
    "обновляв": ["обновлявши"],
    "обновлявши": ["обновляв"],
    "обножка": ["обножь"],
    "обножь": ["взяток", "колошка", "обножка", "поноска"],
    "обносив": ["обносивши"],
    "обносивши": ["обносив"],
    "обноска": ["разнашивание", "обнашивание"],
    "обнуление": ["обнуленье", "сброс", "уничтожение", "обнуляж"],
    "обнулив": ["обнуливши"],
    "обнуливши": ["обнулив"],
    "обнулиться": ["бухнуть", "проставиться", "обмыть"],
    "обнуляв": ["обнулявши"],
    "обнулявши": ["обнуляв"],
    "обнюхав": ["обнюхавши"],
    "обнюхавши": ["обнюхав"],
    "обнюхивав": ["обнюхивавши"],
    "обнюхивавши": ["обнюхивав"],
    "обнюхиванье": ["обнюхивание"],
    "обнюхиваться": ["принюхиваться"],
    "обняв": ["обнявши"],
    "обнявши": ["обняв"],
    "обнять": ["обхватить", "объять"],
    "обо": ["об", "про"],
    "обобрав": ["обобравши"],
    "обобравши": ["обобрав"],
    "обобщав": ["обобщавши"],
    "обобщавши": ["обобщав"],
    "обобщать": ["объединять"],
    "обобщение": ["генерализация", "генерализирование", "суммирование", "синтезирование"],
    "обобщенье": ["обобщение"],
    "обобществив": ["обобществивши"],
    "обобществивши": ["обобществив"],
    "обобществляв": ["обобществлявши"],
    "обобществлявши": ["обобществляв"],
    "обобщив": ["обобщивши"],
    "обобщивши": ["обобщив"],
    "обобщить": ["суммировать", "подытожить"],
    "обовшивев": ["обовшивевши"],
    "обовшивевши": ["обовшивев"],
    "обовшивевший": ["овшивевший"],
    "обовшиветь": ["овшиветь"],
    "обогатев": ["обогатевши"],
    "обогатевши": ["обогатев"],
    "обогатив": ["обогативши"],
    "обогативши": ["обогатив"],
    "обогатительно-агломерационный": ["агломерационно-обогатительный"],
    "обогатиться": ["разбогатеть", "развиться", "увеличиться", "научиться", "сконцентрироваться"],
    "обогащав": ["обогащавши"],
    "обогащавши": ["обогащав"],
    "обогащаться": ["богатеть"],
    "обогащение": ["обогащенье", "богатение"],
    "обогнав": ["обогнавши"],
    "обогнавши": ["обогнав"],
    "обогнать": ["опередить"],
    "обогнув": ["обогнувши"],
    "обогнувши": ["обогнув"],
    "обоготворение": ["обоготворенье"],
    "обоготворив": ["обоготворивши"],
    "обоготворивши": ["обоготворив"],
    "обоготворяв": ["обоготворявши"],
    "обоготворявши": ["обоготворяв"],
    "обогрев": ["обогревание", "подогрев", "подогревание", "согрев", "согревание"],
    "обогревав": ["обогревавши"],
    "обогревавши": ["обогревав"],
    "обогревши": ["обогрев"],
    "ободневав": ["ободневавши"],
    "ободневавши": ["ободневав"],
    "ободняв": ["ободнявши"],
    "ободнявши": ["ободняв"],
    "ободнять": ["рассвести", "развиднеть"],
    "ободок": ["каёмка", "окантовка", "обрамление", "обводка"],
    "ободрав": ["ободравши"],
    "ободравши": ["ободрав"],
    "ободренье": ["ободрение"],
    "ободрив": ["ободривши"],
    "ободривши": ["ободрив"],
    "ободрительно": ["ободряюще"],
    "ободрительный": ["ободряющий", "подбадривающий"],
    "ободрить": ["приободрить", "подбодрить"],
    "ободряв": ["ободрявши"],
    "ободрявши": ["ободряв"],
    "ободрять": ["подбадривать"],
    "ободряюще": ["ободрительно"],
    "ободряющий": ["ободрительный"],
    "обоеполость": ["андрогиния", "гермафродитизм"],
    "обожав": ["обожавши"],
    "обожавши": ["обожав"],
    "обожаемый": ["боготворимый"],
    "обожанье": ["обожание"],
    "обожатель": ["поклонник", "почитатель", "любитель", "кавалер", "воздыхатель", "ухажёр", "ухаживатель", "хахаль", "адоратер", "адоратёр", "адоратор"],
    "обожать": ["боготворить", "преклоняться"],
    "обождав": ["обождавши"],
    "обождавши": ["обождав"],
    "обожение": ["теозис"],
    "обожествив": ["обожествивши"],
    "обожествивши": ["обожествив"],
    "обожествляв": ["обожествлявши"],
    "обожествлявши": ["обожествляв"],
    "обожить": ["обожествить"],
    "обожнювати": ["обожувати"],
    "обожрав": ["обожравши"],
    "обожравши": ["обожрав"],
    "обожраться": ["объесться"],
    "обоз": ["караван"],
    "обозвав": ["обозвавши"],
    "обозвавши": ["обозвав"],
    "обозлив": ["обозливши"],
    "обозливши": ["обозлив"],
    "обозлиться": ["разозлиться"],
    "обознав": ["обознавши"],
    "обознавши": ["обознав"],
    "обознаться": ["перепутать", "спутать"],
    "обозначав": ["обозначавши"],
    "обозначавши": ["обозначав"],
    "обозначенье": ["обозначение"],
    "обозначив": ["обозначивши"],
    "обозначивши": ["обозначив"],
    "обозник": ["обозчик"],
    "обозничав": ["обозничавши"],
    "обозничавши": ["обозничав"],
    "обозрев": ["обозревши"],
    "обозревав": ["обозревавши"],
    "обозревавши": ["обозревав"],
    "обозреватель": ["наблюдатель", "обзорщик", "браузер"],
    "обозревательница": ["обзорщица"],
    "обозревши": ["обозрев"],
    "обозренье": ["обозрение"],
    "обозримый": ["осматриваемый", "просматриваемый"],
    "обойти": ["обогнуть", "миновать", "обходить", "посетить", "обогнать", "опередить", "перегнать", "обхитрить", "обмануть", "перехитрить"],
    "обокраденный": ["обкраденный"],
    "обокрасть": ["обворовать", "обчистить"],
    "оболванев": ["оболваневши"],
    "оболваневши": ["оболванев"],
    "оболванив": ["оболванивши"],
    "оболванивав": ["оболванивавши"],
    "оболванивавши": ["оболванивав"],
    "оболванивши": ["оболванив"],
    "оболгав": ["оболгавши"],
    "оболгавши": ["оболгав"],
    "оболокав": ["оболокавши"],
    "оболокавши": ["оболокав"],
    "оболонь": ["заболонь", "подкорье"],
    "оболочка": ["покрытие"],
    "оболочник": ["туниката"],
    "оболтав": ["оболтавши"],
    "оболтавши": ["оболтав"],
    "обольнув": ["обольнувши"],
    "обольнувши": ["обольнув"],
    "обольстив": ["обольстивши"],
    "обольстивши": ["обольстив"],
    "обольстительница": ["соблазнительница"],
    "обольстительный": ["соблазнительный"],
    "обольшевичив": ["обольшевичивши"],
    "обольшевичивав": ["обольшевичивавши"],
    "обольшевичивавши": ["обольшевичивав"],
    "обольшевичивши": ["обольшевичив"],
    "обольщав": ["обольщавши"],
    "обольщавши": ["обольщав"],
    "обольщенье": ["обольщение"],
    "обомлев": ["обомлевши"],
    "обомлевав": ["обомлевавши"],
    "обомлевавши": ["обомлевав"],
    "обомлевши": ["обомлев"],
    "обомлеть": ["оцепенеть", "оторопеть"],
    "обомшав": ["обомшавши"],
    "обомшавши": ["обомшав"],
    "обомшев": ["обомшевши"],
    "обомшевши": ["обомшев"],
    "обоняв": ["обонявши"],
    "обонявши": ["обоняв"],
    "обоняние": ["нюх"],
    "обонянье": ["обоняние"],
    "обонять": ["нюхать", "чуять"],
    "обопрев": ["обопревши"],
    "обопревав": ["обопревавши"],
    "обопревавши": ["обопревав"],
    "обопревши": ["обопрев"],
    "оборав": ["оборавши"],
    "оборавши": ["оборав"],
    "оборачивав": ["оборачивавши"],
    "оборачивавши": ["оборачивав"],
    "оборачивать": ["обёртывать", "обматывать", "заворачивать", "повёртывать", "поворачивать"],
    "оборвав": ["оборвавши"],
    "оборвавши": ["оборвав"],
    "оборванец": ["оборвыш", "нищий", "бомж"],
    "оборвашка": ["оборвыш", "оборванец", "босяк"],
    "оборвыш": ["оборванец"],
    "оборжав": ["оборжавши"],
    "оборжавев": ["оборжавевши"],
    "оборжавевши": ["оборжавев"],
    "оборжавши": ["оборжав"],
    "оборзев": ["оборзевши"],
    "оборзевши": ["оборзев"],
    "оборзевший": ["обнаглевший"],
    "обормот": ["бестолочь", "болван", "разгильдяй"],
    "оборов": ["оборовши"],
    "оборовши": ["оборов"],
    "обородатев": ["обородатевши"],
    "обородатевши": ["обородатев"],
    "оборона": ["защита"],
    "оборонив": ["оборонивши"],
    "оборонивши": ["оборонив"],
    "оборонитель": ["защитник", "обороняющийся"],
    "оборонить": ["защитить"],
    "оборонный": ["защитный", "оборонительный"],
    "обороняв": ["оборонявши"],
    "оборонявши": ["обороняв"],
    "оборонять": ["защищать"],
    "оборот": ["вращение", "виток", "цикл", "скорость вращения", "употребление", "использование", "хождение", "мах", "объём продаж"],
    "оборотив": ["оборотивши"],
    "оборотивши": ["оборотив"],
    "обороть": ["побороть"],
    "оборудовав": ["оборудовавши"],
    "оборудовавши": ["оборудовав"],
    "оборудование": ["оснащение", "аппаратура", "инструментарий", "инвентарь"],
    "оборудованье": ["оборудование"],
    "оборудовать": ["оснащать"],
    "обосабливав": ["обосабливавши"],
    "обосабливавши": ["обосабливав"],
    "обосабливание": ["обособление"],
    "обосабливать": ["обособлять"],
    "обосновав": ["обосновавши"],
    "обосновавши": ["обосновав"],
    "обоснованность": ["аргументированность", "вескость", "доказанность", "мотивированность", "убедительность"],
    "обоснованье": ["обоснование"],
    "обосновка": ["доводи", "доказателства"],
    "обосновывав": ["обосновывавши"],
    "обосновывавши": ["обосновывав"],
    "обосновывать": ["подкреплять", "доказывать"],
    "обособеност": ["самостоятелност", "обобщеност"],
    "обособив": ["обособивши"],
    "обособивши": ["обособив"],
    "обособление": ["обосабливание", "изоляция", "выделение", "отделение"],
    "обособленно": ["отдельно", "раздельно", "порознь"],
    "обособленность": ["отдельность"],
    "обособленье": ["обособление"],
    "обособляв": ["обособлявши"],
    "обособлявши": ["обособляв"],
    "обособлять": ["обосабливать", "отделять"],
    "обосрав": ["обосравши"],
    "обосравши": ["обосрав"],
    "обосрать": ["засрать", "опорочить", "испортить", "отравить"],
    "обосраться": ["обгадиться", "нагадить", "накатать в пелёнки", "накатать в штаны", "обкакаться", "обхезаться", "обсериться", "усраться", "сделать под себя", "обделаться", "наложить", "навалить", "опозориться", "осрамиться", "облажаться"],
    "обоссав": ["обоссавши"],
    "обоссавши": ["обоссав"],
    "обоссать": ["описать", "обмочить"],
    "обоссаться": ["обмочиться", "описаться", "зассать", "перессать"],
    "обостренье": ["обострение"],
    "обострив": ["обостривши"],
    "обостривши": ["обострив"],
    "обостриться": ["заостриться"],
    "обостряв": ["обострявши"],
    "обострявши": ["обостряв"],
    "обостряться": ["заостряться"],
    "обосцав": ["обосцавши"],
    "обосцавши": ["обосцав"],
    "обочечник": ["обочник", "обочинщик"],
    "обоюдно": ["взаимно", "между собой"],
    "обоюдность": ["взаимность"],
    "обоюдный": ["взаимный"],
    "обоюдовыгодный": ["взаимовыгодный"],
    "обоюдоострый": ["двуострый"],
    "обпачкав": ["обпачкавши"],
    "обпачкавши": ["обпачкав"],
    "обпив": ["обпивши"],
    "обпивав": ["обпивавши"],
    "обпивавши": ["обпивав"],
    "обпивши": ["обпив"],
    "обпиться": ["опиться"],
    "обползав": ["обползавши"],
    "обползавши": ["обползав"],
    "обр": ["авар"],
    "обрабатывав": ["обрабатывавши"],
    "обрабатывавши": ["обрабатывав"],
    "обрабатывать": ["обделывать", "возделывать", "доводить", "совершенствовать", "воздействовать", "склонять", "внушать", "обтяпывать", "устраивать", "проворачивать"],
    "обработав": ["обработавши"],
    "обработавши": ["обработав"],
    "обработать": ["обтяпать", "состряпать"],
    "обработка": ["обрабатывание", "выделка", "отделка", "подготовка", "ремикс", "аранжировка"],
    "обрав": ["обравши"],
    "обравнивав": ["обравнивавши"],
    "обравнивавши": ["обравнивав"],
    "обравши": ["обрав"],
    "обрадовав": ["обрадовавши"],
    "обрадовавши": ["обрадовав"],
    "обрадовать": ["порадовать"],
    "образ": ["облик", "изображение", "имидж", "образец", "метод", "способ", "путь", "склад", "уклад"],
    "образ мыслей": ["мировоззрение", "миросозерцание", "идеология", "философия", "взгляд", "миропонимание", "кредо", "убеждения", "воззрение", "принцип", "правило", "видение"],
    "образец": ["экземпляр", "проба", "эталон", "идеал", "шаблон"],
    "образив": ["образивши"],
    "образивши": ["образив"],
    "образина": ["харя", "рожа", "обличье", "урод", "уродина", "бука", "бабайка", "чудовище", "чудище", "страшилище", "монстр"],
    "образить": ["привести", "порядок", "надлежащий", "вид", "преобразить"],
    "образник": ["божница", "киот", "образница"],
    "образно": ["художественно", "ярко", "красочно"],
    "образовав": ["образовавши"],
    "образовавши": ["образовав"],
    "образованец": ["образованщина"],
    "образование": ["возникновение", "формирование", "просвещение", "наружность"],
    "образованный": ["полученный", "созданный", "сформированный", "учреждённый"],
    "образовательное учреждение": ["учебное заведение"],
    "образовать": ["сделать", "составить", "сформировать", "представить", "учредить", "организовать"],
    "образовывав": ["образовывавши"],
    "образовывавши": ["образовывав"],
    "образовывать": ["формировать", "составлять", "создавать", "организовывать"],
    "образок": ["икона", "образ"],
    "образумив": ["образумивши"],
    "образумивши": ["образумив"],
    "образумиться": ["одуматься", "опомниться", "прийти в себя"],
    "образумливав": ["образумливавши"],
    "образумливавши": ["образумливав"],
    "образумляв": ["образумлявши"],
    "образумлявши": ["образумляв"],
    "образумлять": ["образумливать"],
    "образчик": ["образец"],
    "обраковав": ["обраковавши"],
    "обраковавши": ["обраковав"],
    "обрамив": ["обрамивши"],
    "обрамивши": ["обрамив"],
    "обрамить": ["окружить", "окаймить"],
    "обрамлення": ["облямування", "обрамляння", "обрамка"],
    "обрамленье": ["обрамление"],
    "обрамливав": ["обрамливавши"],
    "обрамливавши": ["обрамливав"],
    "обрамляв": ["обрамлявши"],
    "обрамлявши": ["обрамляв"],
    "обрамляти": ["обрамлювати"],
    "обрантовав": ["обрантовавши"],
    "обрантовавши": ["обрантовав"],
    "обрасопив": ["обрасопивши"],
    "обрасопивши": ["обрасопив"],
    "обрастав": ["обраставши"],
    "обраставши": ["обрастав"],
    "обрастать": ["зарастать", "покрываться"],
    "обрасти": ["зарасти", "покрыться"],
    "обратив": ["обративши"],
    "обративши": ["обратив"],
    "обратимо": ["восстановимо"],
    "обратить": ["направить", "уделить"],
    "обратиться": ["обернуться", "повернуться", "адресоваться", "превратиться", "перевоплотиться", "воспользоваться"],
    "обратная тяга": ["опрокидывание тяги"],
    "обратно": ["назад", "взад", "вспять", "наоборот", "с другой стороны", "противоположно", "наперекор", "вопреки", "напротив", "снова", "тому назад"],
    "обратный": ["противоположный", "противный", "негативный", "изнаночный", "оборотный", "тыльный"],
    "обратный порядок слов": ["инверсия"],
    "обратный слеш": ["бэкслеш"],
    "обратный словарь": ["инверсарий"],
    "обратывав": ["обратывавши"],
    "обратывавши": ["обратывав"],
    "обращав": ["обращавши"],
    "обращавши": ["обращав"],
    "обращаться": ["вращаться", "вертеться", "оборачиваться", "кружиться", "поворачиваться", "направляться", "устремляться", "адресоваться"],
    "обращённость": ["устремлённость", "направленность", "адресуемость", "нацеленность"],
    "обращённый": ["повёрнутый"],
    "обревизовав": ["обревизовавши"],
    "обревизовавши": ["обревизовав"],
    "обревизовать": ["ревизовать"],
    "обрез": ["кромка", "срез"],
    "обрезав": ["обрезавши"],
    "обрезавши": ["обрезав"],
    "обрезание": ["циркумцизия", "мужское обрезание", "женское обрезание"],
    "обрезинив": ["обрезинивши"],
    "обрезинивав": ["обрезинивавши"],
    "обрезинивавши": ["обрезинивав"],
    "обрезинивши": ["обрезинив"],
    "обрезок": ["отрезок"],
    "обрезонив": ["обрезонивши"],
    "обрезонивав": ["обрезонивавши"],
    "обрезонивавши": ["обрезонивав"],
    "обрезонивши": ["обрезонив"],
    "обрезочный": ["обрезковый"],
    "обрезывав": ["обрезывавши"],
    "обрезывавши": ["обрезывав"],
    "обрекав": ["обрекавши"],
    "обрекавши": ["обрекав"],
    "обременив": ["обременивши"],
    "обременивши": ["обременив"],
    "обременительно": ["изнурительно", "тягостно", "затруднительно", "трудно"],
    "обременительный": ["хлопотный", "томительный", "отягощающий", "затруднительный", "проблемный", "сложный", "трудный", "тяжёлый", "тяжкий", "трудоёмкий", "мучительный"],
    "обременяв": ["обременявши"],
    "обременявши": ["обременяв"],
    "обременять": ["отягощать", "затруднять"],
    "обременённый": ["отягощённый", "отяжелённый", "загруженный"],
    "обремизив": ["обремизивши"],
    "обремизивав": ["обремизивавши"],
    "обремизивавши": ["обремизивав"],
    "обремизивать": ["ремизить"],
    "обремизивши": ["обремизив"],
    "обрести": ["найти", "получить"],
    "обретав": ["обретавши"],
    "обретавши": ["обретав"],
    "обретать": ["находить", "отыскивать", "получать"],
    "обретаться": ["находиться", "пребывать", "отыскиваться"],
    "обретенье": ["обретение"],
    "обретши": ["обретя"],
    "обретя": ["обретши"],
    "обретённый": ["найденный"],
    "обрехав": ["обрехавши"],
    "обрехавши": ["обрехав"],
    "обреченье": ["обречение"],
    "обречённый": ["приговорённый"],
    "обрешетив": ["обрешетивши"],
    "обрешетивши": ["обрешетив"],
    "обрешечивав": ["обрешечивавши"],
    "обрешечивавши": ["обрешечивав"],
    "обривав": ["обривавши"],
    "обривавши": ["обривав"],
    "обривши": ["обрив"],
    "обрисовав": ["обрисовавши"],
    "обрисовавши": ["обрисовав"],
    "обрисовывав": ["обрисовывавши"],
    "обрисовывавши": ["обрисовывав"],
    "обробев": ["обробевши"],
    "обробевши": ["обробев"],
    "обровняв": ["обровнявши"],
    "обровнявши": ["обровняв"],
    "оброк": ["подать", "зарок"],
    "оброненный": ["выпавший", "произнесённый", "потерянный"],
    "обронив": ["обронивши"],
    "обронивши": ["обронив"],
    "обросив": ["обросивши"],
    "обросивши": ["обросив"],
    "обротав": ["обротавши"],
    "обротавши": ["обротав"],
    "обротать": ["взнуздать"],
    "оброть": ["недоуздок", "обороть", "обротка"],
    "оброшюровав": ["оброшюровавши"],
    "оброшюровавши": ["оброшюровав"],
    "оброшюровать": ["сброшюровать"],
    "обрубав": ["обрубавши"],
    "обрубавши": ["обрубав"],
    "обрубив": ["обрубивши"],
    "обрубивши": ["обрубив"],
    "обрубить": ["отсечь", "прервать", "подрубить"],
    "обрубка": ["обруб", "обрубание"],
    "обрубочный": ["обрубной"],
    "обругав": ["обругавши"],
    "обругавши": ["обругав"],
    "обругивав": ["обругивавши"],
    "обругивавши": ["обругивав"],
    "обрумянив": ["обрумянивши"],
    "обрумянивав": ["обрумянивавши"],
    "обрумянивавши": ["обрумянивав"],
    "обрумянивать": ["подрумянивать"],
    "обрумянивши": ["обрумянив"],
    "обрумянить": ["подрумянить"],
    "обрусев": ["обрусевши"],
    "обрусевши": ["обрусев"],
    "обруселый": ["обрусевший"],
    "обрусив": ["обрусивши"],
    "обрусивши": ["обрусив"],
    "обрусяв": ["обрусявши"],
    "обрусявши": ["обрусяв"],
    "обруч": ["обод"],
    "обручав": ["обручавши"],
    "обручавши": ["обручав"],
    "обручалка": ["обручальное кольцо"],
    "обручальное кольцо": ["обручалка"],
    "обручение": ["обрученье"],
    "обрученье": ["обручение"],
    "обручив": ["обручивши"],
    "обручивши": ["обручив"],
    "обрушав": ["обрушавши"],
    "обрушавши": ["обрушав"],
    "обрушать": ["обрушивать"],
    "обрушив": ["обрушивши"],
    "обрушивав": ["обрушивавши"],
    "обрушивавши": ["обрушивав"],
    "обрушивши": ["обрушив"],
    "обрушить": ["порушить", "сбросить"],
    "обрыв": ["обрывание", "разрыв", "разрывание", "круча"],
    "обрывав": ["обрывавши"],
    "обрывавши": ["обрывав"],
    "обрывать": ["отрывать", "срывать", "прерывать"],
    "обрываться": ["отрываться", "разрываться", "срываться"],
    "обрывок": ["ошмёток"],
    "обрывши": ["обрыв"],
    "обрыдлый": ["скучный", "нудный", "надоевший"],
    "обрыднув": ["обрыднувши"],
    "обрыднувши": ["обрыднув", "обрыдши"],
    "обрыднувший": ["обрыдший", "опротивевший", "опостылевший"],
    "обрыднуть": ["опротиветь", "опостылеть", "осточертеть"],
    "обрыдши": ["обрыднув", "обрыднувши"],
    "обрыдший": ["обрыднувший", "опротивевший", "опостылевший"],
    "обрызгав": ["обрызгавши"],
    "обрызгавши": ["обрызгав"],
    "обрызгивав": ["обрызгивавши"],
    "обрызгивавши": ["обрызгивав"],
    "обрызгивать": ["опрыскивать"],
    "обрызнув": ["обрызнувши"],
    "обрызнувши": ["обрызнув"],
    "обрыскав": ["обрыскавши"],
    "обрыскавши": ["обрыскав"],
    "обрыскивав": ["обрыскивавши"],
    "обрыскивавши": ["обрыскивав"],
    "обрыскивать": ["шарить", "шариться"],
    "обрыться": ["окопаться"],
    "обрыхлев": ["обрыхлевши"],
    "обрыхлевши": ["обрыхлев"],
    "обрюзглый": ["обрюзгший"],
    "обрюзгнув": ["обрюзгнувши"],
    "обрюзгнувши": ["обрюзгнув"],
    "обрюзгнуть": ["растолстеть", "ожиреть"],
    "обрюхатев": ["обрюхатевши"],
    "обрюхатевши": ["обрюхатев"],
    "обрюхатив": ["обрюхативши"],
    "обрюхативши": ["обрюхатив"],
    "обрюхатить": ["сделать брюхо"],
    "обряд": ["ритуал", "церемония"],
    "обрядив": ["обрядивши"],
    "обрядивши": ["обрядив"],
    "обрядиться": ["приодеться"],
    "обрядный": ["обрядовый"],
    "обрядоверие": ["магизм", "фундаментализм"],
    "обрядовый": ["обрядный", "ритуальный"],
    "обряжав": ["обряжавши"],
    "обряжавши": ["обряжав"],
    "обряжаться": ["наряжаться"],
    "обряженье": ["обряжение"],
    "обрящив": ["обрящивши"],
    "обрящивши": ["обрящив"],
    "обрящить": ["найти", "отыскать", "обрести"],
    "обсада": ["блокада", "обграждане"],
    "обсадив": ["обсадивши"],
    "обсадивши": ["обсадив"],
    "обсадиться": ["обдолбаться"],
    "обсаживав": ["обсаживавши"],
    "обсаживавши": ["обсаживав"],
    "обсалив": ["обсаливши"],
    "обсаливав": ["обсаливавши"],
    "обсаливавши": ["обсаливав"],
    "обсаливши": ["обсалив"],
    "обсасывав": ["обсасывавши"],
    "обсасывавши": ["обсасывав"],
    "обсасывать": ["облизывать"],
    "обсахарив": ["обсахаривши"],
    "обсахаривав": ["обсахаривавши"],
    "обсахаривавши": ["обсахаривав"],
    "обсахаривши": ["обсахарив"],
    "обсвистав": ["обсвиставши"],
    "обсвиставши": ["обсвистав"],
    "обсвистывав": ["обсвистывавши"],
    "обсвистывавши": ["обсвистывав"],
    "обсдача": ["накладка", "сбой", "залёт", "косяк", "ляпсус", "оплошность"],
    "обсевав": ["обсевавши"],
    "обсевавши": ["обсевав"],
    "обсевок": ["высевки", "высевка"],
    "обсег": ["обхват", "обем"],
    "обседав": ["обседавши"],
    "обседавши": ["обседав"],
    "обсекав": ["обсекавши"],
    "обсекавши": ["обсекав"],
    "обселив": ["обселивши"],
    "обселивши": ["обселив"],
    "обсеменив": ["обсеменивши"],
    "обсеменивши": ["обсеменив"],
    "обсеменяв": ["обсеменявши"],
    "обсеменявши": ["обсеменяв"],
    "обсервировав": ["обсервировавши"],
    "обсервировавши": ["обсервировав"],
    "обсерив": ["обсеривши"],
    "обсеривши": ["обсерив"],
    "обсессивнофобический": ["обсессивно-фобический"],
    "обсессивный": ["обсессионный", "навязчивый"],
    "обсессионный": ["обсессивный"],
    "обсессия": ["ананказм", "компульсивность"],
    "обсеяв": ["обсеявши"],
    "обсеявши": ["обсеяв"],
    "обсидев": ["обсидевши"],
    "обсидевши": ["обсидев"],
    "обсиживав": ["обсиживавши"],
    "обсиживавши": ["обсиживав"],
    "обсикав": ["обсикавши"],
    "обсикавши": ["обсикав"],
    "обсикать": ["описать", "обоссать"],
    "обсирав": ["обсиравши"],
    "обсиравши": ["обсирав"],
    "обсирать": ["загрязнять", "обкакивать", "засирать", "ругать", "охаивать", "хаять", "поносить"],
    "обскабливав": ["обскабливавши"],
    "обскабливавши": ["обскабливав"],
    "обсказав": ["обсказавши"],
    "обсказавши": ["обсказав"],
    "обсказывав": ["обсказывавши"],
    "обсказывавши": ["обсказывав"],
    "обскакав": ["обскакавши"],
    "обскакавши": ["обскакав"],
    "обскакать": ["обогнать", "опередить", "превзойти", "обойти", "объехать"],
    "обскакивав": ["обскакивавши"],
    "обскакивавши": ["обскакивав"],
    "обскоблив": ["обскобливши"],
    "обскобливши": ["обскоблив"],
    "обскочив": ["обскочивши"],
    "обскочивши": ["обскочив"],
    "обскребав": ["обскребавши"],
    "обскребавши": ["обскребав"],
    "обскурант": ["мракобес", "обскурантист", "реакционер", "ретроград"],
    "обскурантизм": ["мракобесие"],
    "обскурантист": ["обскурант", "мракобес"],
    "обследовав": ["обследовавши"],
    "обследовавши": ["обследовав"],
    "обследовать": ["изучать", "изучить", "ревизовать", "ознакомляться", "ознакомиться", "заглядывать", "заглянуть", "оглядывать", "оглянуть"],
    "обслужив": ["обслуживши"],
    "обслуживав": ["обслуживавши"],
    "обслуживавши": ["обслуживав"],
    "обслуживание": ["сервис", "уход", "обслуга", "патронаж"],
    "обслуживанье": ["обслуживание"],
    "обслуживать": ["судить"],
    "обслуживши": ["обслужив"],
    "обслюнив": ["обслюнивши"],
    "обслюнивав": ["обслюнивавши"],
    "обслюнивавши": ["обслюнивав"],
    "обслюнивши": ["обслюнив"],
    "обслюнявив": ["обслюнявивши"],
    "обслюнявивши": ["обслюнявив"],
    "обслюнявливав": ["обслюнявливавши"],
    "обслюнявливавши": ["обслюнявливав"],
    "обсмаковав": ["обсмаковавши"],
    "обсмаковавши": ["обсмаковав"],
    "обсмаковывав": ["обсмаковывавши"],
    "обсмаковывавши": ["обсмаковывав"],
    "обсмаливав": ["обсмаливавши"],
    "обсмаливавши": ["обсмаливав"],
    "обсматривав": ["обсматривавши"],
    "обсматривавши": ["обсматривав"],
    "обсмеивав": ["обсмеивавши"],
    "обсмеивавши": ["обсмеивав"],
    "обсмеяв": ["обсмеявши"],
    "обсмеявши": ["обсмеяв"],
    "обсмеять": ["осмеять"],
    "обсмеяться": ["насмеяться", "осмеяться"],
    "обсмол": ["обсмолення"],
    "обсмолив": ["обсмоливши"],
    "обсмоливши": ["обсмолив"],
    "обсмотрев": ["обсмотревши"],
    "обсмотревши": ["обсмотрев"],
    "обсолив": ["обсоливши"],
    "обсоливши": ["обсолив"],
    "обсолонь": ["противосолонь", "противусолонь"],
    "обсос": ["обсосник", "обсосина"],
    "обсосав": ["обсосавши"],
    "обсосавши": ["обсосав"],
    "обсохнув": ["обсохнувши"],
    "обсохнувши": ["обсохнув"],
    "обсоюзив": ["обсоюзивши"],
    "обсоюзивши": ["обсоюзив"],
    "обсоюзить": ["осоюзить"],
    "обстав": ["обставши"],
    "обставав": ["обстававши"],
    "обстававши": ["обставав"],
    "обставив": ["обставивши"],
    "обставивши": ["обставив"],
    "обставляв": ["обставлявши"],
    "обставлявши": ["обставляв"],
    "обставши": ["обстав"],
    "обстанавливав": ["обстанавливавши"],
    "обстанавливавши": ["обстанавливав"],
    "обстановив": ["обстановивши"],
    "обстановивши": ["обстановив"],
    "обстановка": ["меблировка", "декорация"],
    "обстать": ["окружить", "обступить"],
    "обстирав": ["обстиравши"],
    "обстиравши": ["обстирав"],
    "обстирывав": ["обстирывавши"],
    "обстирывавши": ["обстирывав"],
    "обстояв": ["обстоявши"],
    "обстоявши": ["обстояв"],
    "обстоятельнее": ["обстоятельней", "подробнее"],
    "обстоятельней": ["обстоятельнее", "подробнее"],
    "обстоятельно": ["детально", "досконально", "исчерпывающе", "основательно"],
    "обстоятельство": ["обстановка", "ситуация", "условие"],
    "обстрагивав": ["обстрагивавши"],
    "обстрагивавши": ["обстрагивав"],
    "обстрагивание": ["обстругивание", "строгание"],
    "обстраивав": ["обстраивавши"],
    "обстраивавши": ["обстраивав"],
    "обстрачивав": ["обстрачивавши"],
    "обстрачивавши": ["обстрачивав"],
    "обстрекав": ["обстрекавши"],
    "обстрекавши": ["обстрекав"],
    "обстрел": ["обстреливание"],
    "обстреливав": ["обстреливавши"],
    "обстреливавши": ["обстреливав"],
    "обстреляв": ["обстрелявши"],
    "обстрелявши": ["обстреляв"],
    "обстрелянный": ["подстреленный"],
    "обстригав": ["обстригавши"],
    "обстригавши": ["обстригав"],
    "обстрогав": ["обстрогавши"],
    "обстрогавши": ["обстрогав"],
    "обстрогать": ["обстругать", "острогать", "остругать"],
    "обстроив": ["обстроивши"],
    "обстроивши": ["обстроив"],
    "обстрочив": ["обстрочивши"],
    "обстрочивши": ["обстрочив"],
    "обстругав": ["обстругавши"],
    "обстругавши": ["обстругав"],
    "обстругать": ["обстрогать"],
    "обстругивав": ["обстругивавши"],
    "обстругивавши": ["обстругивав"],
    "обстругивание": ["обстрагивание"],
    "обстругивать": ["обстрагивать"],
    "обструктивный": ["обтурационный"],
    "обструкция": ["травля", "закупорка", "непроходимость"],
    "обстряпав": ["обстряпавши"],
    "обстряпавши": ["обстряпав"],
    "обстряпывав": ["обстряпывавши"],
    "обстряпывавши": ["обстряпывав"],
    "обстряпывать": ["обделывать"],
    "обстукав": ["обстукавши"],
    "обстукавши": ["обстукав"],
    "обстукивав": ["обстукивавши"],
    "обстукивавши": ["обстукивав"],
    "обступав": ["обступавши"],
    "обступавши": ["обступав"],
    "обступать": ["окутывать", "обволакивать"],
    "обступив": ["обступивши"],
    "обступивши": ["обступив"],
    "обстучав": ["обстучавши"],
    "обстучавши": ["обстучав"],
    "обсудив": ["обсудивши"],
    "обсудивши": ["обсудив"],
    "обсуждав": ["обсуждавши"],
    "обсуждавши": ["обсуждав"],
    "обсуждать": ["дискутировать"],
    "обсуждение": ["дискутирование", "диспут", "обсужденье"],
    "обсужденье": ["обсуждение", "дискуссия", "дискурс"],
    "обсуживав": ["обсуживавши"],
    "обсуживавши": ["обсуживав"],
    "обсуслив": ["обсусливши"],
    "обсусливав": ["обсусливавши"],
    "обсусливавши": ["обсусливав"],
    "обсусливши": ["обсуслив"],
    "обсусолив": ["обсусоливши"],
    "обсусоливав": ["обсусоливавши"],
    "обсусоливавши": ["обсусоливав"],
    "обсусоливши": ["обсусолив"],
    "обсушив": ["обсушивши"],
    "обсушивав": ["обсушивавши"],
    "обсушивавши": ["обсушивав"],
    "обсушивши": ["обсушив"],
    "обсценная лексика": ["мат", "обсценизм", "ненормативная лексика", "лая матерна", "запрещённые госдурой слова"],
    "обсценное выражение": ["обсценизм"],
    "обсценный": ["скабрёзный", "непристойный", "неприличный", "недопустимый", "ненормативный", "нецензурный", "матерный"],
    "обсчитав": ["обсчитавши"],
    "обсчитавши": ["обсчитав"],
    "обсчитаться": ["обчесться"],
    "обсчитывав": ["обсчитывавши"],
    "обсчитывавши": ["обсчитывав"],
    "обсыпав": ["обсыпавши"],
    "обсыпавши": ["обсыпав"],
    "обсыхав": ["обсыхавши"],
    "обсыхавши": ["обсыхав"],
    "обсявкав": ["обсявкавши"],
    "обсявкавши": ["обсявкав"],
    "обтаивав": ["обтаивавши"],
    "обтаивавши": ["обтаивав"],
    "обтапливав": ["обтапливавши"],
    "обтапливавши": ["обтапливав"],
    "обтаптывав": ["обтаптывавши"],
    "обтаптывавши": ["обтаптывав"],
    "обтаскав": ["обтаскавши"],
    "обтаскавши": ["обтаскав"],
    "обтаскивав": ["обтаскивавши"],
    "обтаскивавши": ["обтаскивав"],
    "обтачав": ["обтачавши"],
    "обтачавши": ["обтачав"],
    "обтачивав": ["обтачивавши"],
    "обтачивавши": ["обтачивав"],
    "обтащив": ["обтащивши"],
    "обтащивши": ["обтащив"],
    "обтаяв": ["обтаявши"],
    "обтаявши": ["обтаяв"],
    "обтекав": ["обтекавши"],
    "обтекавши": ["обтекав"],
    "обтеребив": ["обтеребивши"],
    "обтеребивши": ["обтеребив"],
    "обтерев": ["обтёрши"],
    "обтерхав": ["обтерхавши"],
    "обтерхавши": ["обтерхав"],
    "обтесав": ["обтесавши"],
    "обтесавши": ["обтесав"],
    "обтесаться": ["обшлифоваться"],
    "обтирав": ["обтиравши"],
    "обтиравши": ["обтирав"],
    "обтирание": ["обтирка"],
    "обтирать": ["отирать", "утирать"],
    "обтирка": ["обтирание"],
    "обтискав": ["обтискавши"],
    "обтискавши": ["обтискав"],
    "обтискивав": ["обтискивавши"],
    "обтискивавши": ["обтискивав"],
    "обтиснув": ["обтиснувши"],
    "обтиснувши": ["обтиснув"],
    "обтолковав": ["обтолковавши"],
    "обтолковавши": ["обтолковав"],
    "обтолковывав": ["обтолковывавши"],
    "обтолковывавши": ["обтолковывав"],
    "обтопив": ["обтопивши"],
    "обтопивши": ["обтопив"],
    "обтоптав": ["обтоптавши"],
    "обтоптавши": ["обтоптав"],
    "обточив": ["обточивши"],
    "обточивши": ["обточив"],
    "обтравив": ["обтравивши"],
    "обтравивши": ["обтравив"],
    "обтравливав": ["обтравливавши"],
    "обтравливавши": ["обтравливав"],
    "обтрепав": ["обтрепавши"],
    "обтрепавши": ["обтрепав"],
    "обтрусив": ["обтрусивши"],
    "обтрусивши": ["обтрусив"],
    "обтрусить": ["стряхнуть", "стрясти"],
    "обтрясав": ["обтрясавши"],
    "обтрясавши": ["обтрясав"],
    "обтряхав": ["обтряхавши"],
    "обтряхавши": ["обтряхав"],
    "обтряхивав": ["обтряхивавши"],
    "обтряхивавши": ["обтряхивав"],
    "обтряхнув": ["обтряхнувши"],
    "обтряхнувши": ["обтряхнув"],
    "обтрёпывав": ["обтрёпывавши"],
    "обтрёпывавши": ["обтрёпывав"],
    "обтрёпываемый": ["изнашиваемый", "истаскиваемый"],
    "обтуратор": ["обтюратор"],
    "обтурационный": ["обструктивный"],
    "обтурация": ["обтюрация", "закупоривание", "закупорка"],
    "обтурировав": ["обтурировавши"],
    "обтурировавши": ["обтурировав"],
    "обтурированный": ["закупоренный"],
    "обтурировать": ["обтюрировать"],
    "обтыкав": ["обтыкавши"],
    "обтыкавши": ["обтыкав"],
    "обтюратор": ["обтуратор"],
    "обтюрация": ["обтурация"],
    "обтюрировав": ["обтюрировавши"],
    "обтюрировавши": ["обтюрировав"],
    "обтягивав": ["обтягивавши"],
    "обтягивавши": ["обтягивав"],
    "обтягиваться": ["оборачиваться"],
    "обтягувати": ["обтягати"],
    "обтяження": ["завантаження"],
    "обтяжечный": ["обтяжной"],
    "обтянув": ["обтянувши"],
    "обтянувши": ["обтянув"],
    "обтяпав": ["обтяпавши"],
    "обтяпавши": ["обтяпав"],
    "обтяпывав": ["обтяпывавши"],
    "обтяпывавши": ["обтяпывав"],
    "обтёрши": ["обтерев"],
    "обтёсывав": ["обтёсывавши"],
    "обтёсывавши": ["обтёсывав"],
    "обув": ["обувши"],
    "обував": ["обувавши"],
    "обувавши": ["обував"],
    "обуванье": ["обувание"],
    "обувать": ["надевать", "надувать", "обманывать", "облапошивать"],
    "обувница": ["галошница"],
    "обувши": ["обув"],
    "обувщик": ["сапожник", "обувник", "башмачник", "чеботарь"],
    "обувь": ["обувка"],
    "обуглев": ["обуглевши"],
    "обуглевши": ["обуглев"],
    "обугленный": ["сожжённый", "обгорелый", "опалённый", "обожжённый", "закалённый"],
    "обуглеродив": ["обуглеродивши"],
    "обуглеродивши": ["обуглеродив"],
    "обуглероживав": ["обуглероживавши"],
    "обуглероживавши": ["обуглероживав"],
    "обуглив": ["обугливши"],
    "обугливав": ["обугливавши"],
    "обугливавши": ["обугливав"],
    "обугливаться": ["обгорать"],
    "обугливши": ["обуглив"],
    "обуглиться": ["обгореть"],
    "обуевав": ["обуевавши"],
    "обуевавши": ["обуевав"],
    "обуживав": ["обуживавши"],
    "обуживавши": ["обуживав"],
    "обуза": ["балласт", "бремя", "ноша", "нагрузка", "тягота", "тягость", "гнёт"],
    "обуздав": ["обуздавши"],
    "обуздавши": ["обуздав"],
    "обузданье": ["обуздание"],
    "обуздать": ["взнуздать", "укротить"],
    "обуздывав": ["обуздывавши"],
    "обуздывавши": ["обуздывав"],
    "обузив": ["обузивши"],
    "обузивши": ["обузив"],
    "обукрасив": ["обукрасивши"],
    "обукрасивши": ["обукрасив"],
    "обуревав": ["обуревавши"],
    "обуревавши": ["обуревав"],
    "обуреваемый": ["охваченный", "захваченный", "пожираемый", "снедаемый"],
    "обурення": ["роздратування"],
    "обуржуазив": ["обуржуазивши"],
    "обуржуазивав": ["обуржуазивавши"],
    "обуржуазивавши": ["обуржуазивав"],
    "обуржуазивши": ["обуржуазив"],
    "обурив": ["обуривши"],
    "обуривав": ["обуривавши"],
    "обуривавши": ["обуривав"],
    "обуривши": ["обурив"],
    "обуславливав": ["обуславливавши"],
    "обуславливавши": ["обуславливав"],
    "обуславливать": ["обусловливать"],
    "обусловив": ["обусловивши"],
    "обусловивши": ["обусловив"],
    "обусловить": ["оговорить"],
    "обусловленность": ["зависимость"],
    "обусловленный": ["детерминированный", "предопределённый"],
    "обусловливав": ["обусловливавши"],
    "обусловливавши": ["обусловливав"],
    "обусловливать": ["определять", "нагонять", "вселять", "рождать", "обуславливать", "возбуждать", "зажигать", "сеять", "провоцировать", "предопределять", "создавать", "детерминировать", "поселять", "порождать", "зарождать"],
    "обустраивав": ["обустраивавши"],
    "обустраивавши": ["обустраивав"],
    "обустраиваться": ["обосновываться", "устраиваться"],
    "обустроив": ["обустроивши"],
    "обустроивши": ["обустроив"],
    "обустроиться": ["обосноваться", "устроиться", "наладиться"],
    "обутрев": ["обутревши"],
    "обутревши": ["обутрев"],
    "обутреть": ["рассвести"],
    "обуть": ["надеть"],
    "обуховый": ["обушный"],
    "обучав": ["обучавши"],
    "обучавши": ["обучав"],
    "обучать": ["учить"],
    "обучаться": ["научаться", "учиться"],
    "обучающаяся": ["учащаяся", "ученица"],
    "обучение": ["изучение"],
    "обучив": ["обучивши"],
    "обучивши": ["обучив"],
    "обучить": ["научить"],
    "обучиться": ["научиться"],
    "обуяв": ["обуявши"],
    "обуявши": ["обуяв"],
    "обфусцировать": ["запутывать", "запутать"],
    "обхаживав": ["обхаживавши"],
    "обхаживавши": ["обхаживав"],
    "обхаживать": ["обходить", "охаживать", "ухаживать"],
    "обхаивав": ["обхаивавши"],
    "обхаивавши": ["обхаивав"],
    "обхаивать": ["охаивать"],
    "обхайрав": ["обхайравши"],
    "обхайравши": ["обхайрав"],
    "обхамив": ["обхамивши"],
    "обхамивши": ["обхамив"],
    "обхаркав": ["обхаркавши"],
    "обхаркавши": ["обхаркав"],
    "обхаркати": ["обплювати"],
    "обхаркивав": ["обхаркивавши"],
    "обхаркивавши": ["обхаркивав"],
    "обхаяв": ["обхаявши"],
    "обхаявши": ["обхаяв"],
    "обхаять": ["охаять", "отругать", "выбранить", "обкостерить"],
    "обхватав": ["обхватавши"],
    "обхватавши": ["обхватав"],
    "обхватив": ["обхвативши"],
    "обхвативши": ["обхватив"],
    "обхватить": ["обнять", "охватить", "объять"],
    "обхватывав": ["обхватывавши"],
    "обхватывавши": ["обхватывав"],
    "обхватывание": ["обхват"],
    "обхезав": ["обхезавши"],
    "обхезавши": ["обхезав"],
    "обхезать": ["обгадить", "испортить", "нарушить", "оболгать", "оклеветать", "обругать", "изругать"],
    "обхезаться": ["обделаться", "обгадиться", "обосраться", "испугаться", "потерпеть неудачу", "потерпеть фиаско", "осрамиться", "провалиться", "жидко обделаться", "обделаться по-крупному"],
    "обхитрив": ["обхитривши"],
    "обхитривши": ["обхитрив"],
    "обхитряв": ["обхитрявши"],
    "обхитрявши": ["обхитряв"],
    "обхлестав": ["обхлеставши"],
    "обхлеставши": ["обхлестав"],
    "обхлопав": ["обхлопавши"],
    "обхлопавши": ["обхлопав"],
    "обхлопатывав": ["обхлопатывавши"],
    "обхлопатывавши": ["обхлопатывав"],
    "обхлопотав": ["обхлопотавши"],
    "обхлопотавши": ["обхлопотав"],
    "обхлопывав": ["обхлопывавши"],
    "обхлопывавши": ["обхлопывав"],
    "обхлёстывав": ["обхлёстывавши"],
    "обхлёстывавши": ["обхлёстывав"],
    "обходив": ["обходивши"],
    "обходивши": ["обходив"],
    "обходительность": ["вежливость", "учтивость"],
    "обходительный": ["вежливый", "учтивый", "приветливый"],
    "обходить стороной": ["сторониться"],
    "обхождение": ["циркумамбуляция"],
    "обхожденье": ["обхождение"],
    "обцарапав": ["обцарапавши"],
    "обцарапавши": ["обцарапав"],
    "обцарапывав": ["обцарапывавши"],
    "обцарапывавши": ["обцарапывав"],
    "обцеловав": ["обцеловавши"],
    "обцеловавши": ["обцеловав"],
    "обцеловывав": ["обцеловывавши"],
    "обцеловывавши": ["обцеловывав"],
    "обчекрыжив": ["обчекрыживши"],
    "обчекрыживав": ["обчекрыживавши"],
    "обчекрыживавши": ["обчекрыживав"],
    "обчекрыживши": ["обчекрыжив"],
    "обчесав": ["обчесавши"],
    "обчесавши": ["обчесав"],
    "обчинив": ["обчинивши"],
    "обчинивав": ["обчинивавши"],
    "обчинивавши": ["обчинивав"],
    "обчинивши": ["обчинив"],
    "обчистив": ["обчистивши"],
    "обчистивши": ["обчистив"],
    "обчищав": ["обчищавши"],
    "обчищавши": ["обчищав"],
    "обчёсывав": ["обчёсывавши"],
    "обчёсывавши": ["обчёсывав"],
    "обшарив": ["обшаривши"],
    "обшаривав": ["обшаривавши"],
    "обшаривавши": ["обшаривав"],
    "обшаривши": ["обшарив"],
    "обшаркав": ["обшаркавши"],
    "обшаркавши": ["обшаркав"],
    "обшаркивав": ["обшаркивавши"],
    "обшаркивавши": ["обшаркивав"],
    "обшарпав": ["обшарпавши"],
    "обшарпавши": ["обшарпав"],
    "обшарпанность": ["потёртость", "обветшалость"],
    "обшарпанный": ["потёртый", "использованный"],
    "обшарпывав": ["обшарпывавши"],
    "обшарпывавши": ["обшарпывав"],
    "обшастав": ["обшаставши"],
    "обшаставши": ["обшастав"],
    "обшевни": ["пошевни"],
    "обшелушив": ["обшелушивши"],
    "обшелушивав": ["обшелушивавши"],
    "обшелушивавши": ["обшелушивав"],
    "обшелушивши": ["обшелушив"],
    "обшельмовав": ["обшельмовавши"],
    "обшельмовавши": ["обшельмовав"],
    "обшибав": ["обшибавши"],
    "обшибавши": ["обшибав"],
    "обшибив": ["обшибивши"],
    "обшибивши": ["обшибив"],
    "обшив": ["обшивши"],
    "обшивав": ["обшивавши"],
    "обшивавши": ["обшивав"],
    "обшивка": ["обшивание"],
    "обшивши": ["обшив"],
    "обшикав": ["обшикавши"],
    "обшикавши": ["обшикав"],
    "обшикать": ["ошикать"],
    "обшикивав": ["обшикивавши"],
    "обшикивавши": ["обшикивав"],
    "обширный": ["широкий"],
    "обшлаг": ["отворот"],
    "обшлифовав": ["обшлифовавши"],
    "обшлифовавши": ["обшлифовав"],
    "обшлифовывав": ["обшлифовывавши"],
    "обшлифовывавши": ["обшлифовывав"],
    "обшлифовывать": ["ошлифовывать"],
    "обшлёпав": ["обшлёпавши"],
    "обшлёпавши": ["обшлёпав"],
    "обшлёпывав": ["обшлёпывавши"],
    "обшлёпывавши": ["обшлёпывав"],
    "обшмаляв": ["обшмалявши"],
    "обшмалявши": ["обшмаляв"],
    "обшмыгав": ["обшмыгавши"],
    "обшмыгавши": ["обшмыгав"],
    "обшмыгивав": ["обшмыгивавши"],
    "обшмыгивавши": ["обшмыгивав"],
    "обшнырив": ["обшныривши"],
    "обшныривав": ["обшныривавши"],
    "обшныривавши": ["обшныривав"],
    "обшныривши": ["обшнырив"],
    "обшныряв": ["обшнырявши"],
    "обшнырявши": ["обшныряв"],
    "обшнырять": ["обшнырить"],
    "обшор": ["шалола", "шаршара"],
    "обштопав": ["обштопавши"],
    "обштопавши": ["обштопав"],
    "обштопывав": ["обштопывавши"],
    "обштопывавши": ["обштопывав"],
    "общага": ["общежитие"],
    "общаться": ["водить", "знакомство", "знаться", "водиться", "встречаться", "разговаривать"],
    "общая теория относительности": ["ото"],
    "общая тетрадь": ["амбарная книга"],
    "обще": ["в целом", "вместе", "совместно", "сообща"],
    "общее место": ["топос", "избитое выражение", "клише", "штамп"],
    "общее образование": ["оо"],
    "общежитье": ["общежитие"],
    "общекомбинатский": ["общекомбинатовский"],
    "общенародно": ["всенародно", "прилюдно"],
    "общение": ["сношение", "контакт", "диалог", "полилог", "общенье", "сношенье"],
    "общенье": ["общение", "сношение", "контакт", "диалог", "полилог", "сношенье"],
    "общепризнанный": ["признанный"],
    "общепринятый": ["общеупотребительный", "общепризнанный"],
    "общераспространённый": ["распространённый", "общепринятый", "повсеместный"],
    "общероссийский": ["всероссийский"],
    "общесословный": ["всесословный"],
    "общественная организация": ["оо"],
    "общественно": ["социально"],
    "общественность": ["общество"],
    "общественный": ["социальный", "коллективный", "общий", "общительный", "открытый"],
    "общественный строй": ["общественно-экономическая формация"],
    "общество": ["общественность", "класс", "союз", "организация", "компания", "фирма", "предприятие", "товарищество", "обществознание"],
    "общество с ограниченной ответственностью": ["ооо"],
    "обществоведение": ["обществознание", "общество"],
    "обществознание": ["обществоведение", "общество"],
    "общеупотребимый": ["общеупотребительный", "широкоупотребимый"],
    "общецерковный": ["вселенский"],
    "общечеловеческий": ["всечеловеческий"],
    "общий": ["совместный", "коллективный", "совокупный", "суммарный", "отвлечённый", "неконкретный", "расхожий", "свойственный", "относящийся", "касающийся"],
    "община": ["коммуна", "сообщество"],
    "общинник": ["общинник-земледелец", "крестьянин-общинник", "феодальный", "дагестан", "уздень", "англосаксонский", "королевство", "керл", "кэрл", "кёрл", "англия", "йомен", "йоменри", "согласник"],
    "общинно-родовой строй": ["первобытно-общинный строй", "родовой строй", "первобытный строй"],
    "общипав": ["общипавши"],
    "общипавши": ["общипав"],
    "общипывав": ["общипывавши"],
    "общипывавши": ["общипывав"],
    "общипывать": ["ощипывать", "обкрадывать", "обирать"],
    "общительность": ["коммуникабельность"],
    "общительный": ["коммуникабельный", "контактный"],
    "общность": ["единство", "сходство", "схожесть", "соединение", "совокупность", "союз"],
    "общо": ["обобщённо"],
    "общупав": ["общупавши"],
    "общупавши": ["общупав"],
    "общупывав": ["общупывавши"],
    "общупывавши": ["общупывав"],
    "общёлкав": ["общёлкавши"],
    "общёлкавши": ["общёлкав"],
    "общёлкивав": ["общёлкивавши"],
    "общёлкивавши": ["общёлкивав"],
    "общёлкнув": ["общёлкнувши"],
    "общёлкнувши": ["общёлкнув"],
    "объебав": ["объебавши"],
    "объебавши": ["объебав"],
    "объебаться": ["обломаться", "обдолбаться", "обдолбиться", "дозняк"],
    "объебашив": ["объебашивши"],
    "объебашивав": ["объебашивавши"],
    "объебашивавши": ["объебашивав"],
    "объебашивши": ["объебашив"],
    "объебон": ["обвинительное заключение", "ложь", "обман", "объёбка", "наёбка", "наебалово", "наебаловка"],
    "объебошив": ["объебошивши"],
    "объебошивав": ["объебошивавши"],
    "объебошивавши": ["объебошивав"],
    "объебошивши": ["объебошив"],
    "объегоренный": ["обманутый"],
    "объегорив": ["объегоривши"],
    "объегоривав": ["объегоривавши"],
    "объегоривавши": ["объегоривав"],
    "объегоривать": ["облапошивать", "обводить вокруг пальца"],
    "объегоривши": ["объегорив"],
    "объегорить": ["облапошить", "провести", "обхитрить", "перехитрить", "обвести вокруг пальца"],
    "объедав": ["объедавши"],
    "объедавши": ["объедав"],
    "объедала": ["обжора"],
    "объедаться": ["чревоугодничать", "обжираться"],
    "объедение": ["пальчики оближешь", "обжорство", "чревоугодие"],
    "объеденье": ["объедение"],
    "объединение": ["соединение", "слияние", "составление", "интеграция", "агрегация", "кооперация", "союз", "альянс", "ассоциация", "объединение множеств"],
    "объединенье": ["объединение"],
    "объединив": ["объединивши"],
    "объединивши": ["объединив"],
    "объединиться": ["соединиться", "соединиться вновь", "стабуниться", "скопниться", "интегрироваться", "консолидироваться", "организоваться", "сконсолидироваться", "солидаризироваться", "спаяться", "сплотиться"],
    "объединяв": ["объединявши"],
    "объединявши": ["объединяв"],
    "объединять": ["соединять", "сливать", "роднить", "сближать", "сплачивать", "спаивать"],
    "объединяться": ["соединяться"],
    "объединённые арабские эмираты": ["оаэ", "эмираты", "арабские эмираты"],
    "объединённый": ["соединённый", "союзный"],
    "объедок": ["опивка"],
    "объедья": ["объедки"],
    "объездив": ["объездивши"],
    "объездивши": ["объездив"],
    "объезжав": ["объезжавши"],
    "объезжавши": ["объезжав"],
    "объезживав": ["объезживавши"],
    "объезживавши": ["объезживав"],
    "объект науки": ["объект исследования"],
    "объективация": ["объективизация"],
    "объективизация": ["объективация"],
    "объективизировав": ["объективизировавши"],
    "объективизировавши": ["объективизировав"],
    "объективизироваться": ["объективироваться"],
    "объективировав": ["объективировавши"],
    "объективировавши": ["объективировав"],
    "объективка": ["справка-объективка", "справка об объективных сведениях"],
    "объективно": ["действительно", "реально", "непредвзято", "беспристрастно", "нелицеприятно", "справедливо", "непредубеждённо"],
    "объективное право": ["право", "закон"],
    "объективность": ["реальность", "беспристрастность", "непредвзятость"],
    "объектировав": ["объектировавши"],
    "объектировавши": ["объектировав"],
    "объектировать": ["объективировать", "объективизировать"],
    "объектно-ориентированный подход": ["ооп"],
    "объектосексуал": ["объектофил"],
    "объектофил": ["объектосексуал"],
    "объемлев": ["объемлевши"],
    "объемлевши": ["объемлев"],
    "объесться": ["обожраться"],
    "объехав": ["объехавши"],
    "объехавши": ["объехав"],
    "объяв": ["объявши"],
    "объява": ["объявление"],
    "объявив": ["объявивши"],
    "объявивши": ["объявив"],
    "объявиться": ["обнаружиться", "объявить"],
    "объявление": ["провозглашение", "разглашение", "оглашение", "декларация", "сообщение", "извещение", "объява"],
    "объявленье": ["объявление"],
    "объявляв": ["объявлявши"],
    "объявлявши": ["объявляв"],
    "объявлять": ["декларировать", "извещать", "сообщать", "информировать", "уведомлять", "осведомлять", "докладывать", "доносить", "заявлять", "оповещать", "предупреждать", "называть"],
    "объявши": ["объяв"],
    "объягниться": ["оягниться"],
    "объяснение": ["разъяснение", "растолковывание"],
    "объяснив": ["объяснивши"],
    "объяснивши": ["объяснив"],
    "объяснимый": ["необъяснимый"],
    "объяснительная": ["объяснительная записка"],
    "объяснить": ["разъяснить", "изъяснить", "пояснить", "истолковать", "растолковать"],
    "объясниться": ["обнаружиться", "оказаться", "переговорить", "оправдаться"],
    "объясняв": ["объяснявши"],
    "объяснявши": ["объясняв"],
    "объяснять": ["растолковывать", "втолковывать", "прояснять", "разжёвывать"],
    "объёб": ["объёбка", "объебон", "объебос"],
    "объёбывав": ["объёбывавши"],
    "объёбывавши": ["объёбывав"],
    "объёбывать": ["наёбывать", "обманывать", "одурачивать"],
    "объём": ["кубатура", "вместимость", "ёмкость", "поместительность", "тело"],
    "объёмистый": ["крупный", "большой", "вместительный", "ёмкий"],
    "объёмно-детонирующий боеприпас": ["одб"],
    "объёмный": ["ёмкостной", "ёмкий", "объёмистый", "вместительный", "трёхмерный", "стереоскопический"],
    "объёрзав": ["объёрзавши"],
    "объёрзавши": ["объёрзав"],
    "обывав": ["обывавши"],
    "обывавши": ["обывав"],
    "обыватель": ["мещанин"],
    "обывательски": ["по-обывательски"],
    "обывательский": ["мещанский", "банальный", "отсталый", "мелкобуржуазный", "претенциозно-пошлый", "не высокого достоинства", "простонародный", "вульгарный", "не принятый в высшем обществе", "недалёкий"],
    "обывательщина": ["узость взглядов", "узость интересов", "узость кругозора", "филистерство", "мещанство"],
    "обывать": ["обитать", "проживать"],
    "обыграв": ["обыгравши"],
    "обыгравши": ["обыграв"],
    "обыграть": ["победить"],
    "обыгрывав": ["обыгрывавши"],
    "обыгрывавши": ["обыгрывав"],
    "обыгрывать": ["выигрывать", "побеждать", "одерживать верх"],
    "обыденно": ["скучно", "однообразно", "обычно", "заурядно"],
    "обыденность": ["будничность", "повседневность"],
    "обыденный": ["повседневный", "обыкновенный", "заурядный", "однодневный", "суточный"],
    "обыдление": ["обыдленье"],
    "обызвествив": ["обызвествивши"],
    "обызвествивши": ["обызвествив"],
    "обызвествление": ["обызвесткование", "объизвествление", "кальциноз"],
    "обызвествляв": ["обызвествлявши"],
    "обызвествлявши": ["обызвествляв"],
    "обыкав": ["обыкавши"],
    "обыкавши": ["обыкав"],
    "обыкать": ["обвыкать", "привыкать"],
    "обыкновение": ["обычай", "привычка"],
    "обыкновенная дробь": ["арифметическая дробь", "простая дробь"],
    "обыкновенно": ["обычно", "как правило", "заурядно"],
    "обыкновенный": ["обычный", "заурядный", "привычный"],
    "обыкновенный японский школьник": ["обычный японский школьник", "ояш"],
    "обыкновенье": ["обыкновение"],
    "обыкнув": ["обыкнувши"],
    "обыкнувши": ["обыкнув"],
    "обыкнуть": ["привыкнуть"],
    "обыкший": ["привычный", "привыкший", "обыклый"],
    "обымав": ["обымавши"],
    "обымавши": ["обымав"],
    "обындевев": ["обындевевши"],
    "обындевевши": ["обындевев"],
    "обындеветь": ["заиндеветь"],
    "обыск": ["шмон", "свидетельство"],
    "обыскав": ["обыскавши"],
    "обыскавши": ["обыскав"],
    "обыскать": ["обшмонать"],
    "обыскивав": ["обыскивавши"],
    "обыскивавши": ["обыскивав"],
    "обыскивание": ["обыск", "шмон"],
    "обыскивать": ["досматривать", "шмонать"],
    "обытовив": ["обытовивши"],
    "обытовивши": ["обытовив"],
    "обытовляв": ["обытовлявши"],
    "обытовлявши": ["обытовляв"],
    "обычай": ["обыкновение", "традиция", "ритуал"],
    "обычливый": ["благонравный"],
    "обычно": ["заурядно", "привычно", "чаще всего", "как правило"],
    "обычное явление": ["обычное дело"],
    "обычность": ["обыкновенность", "обыденность", "нормальность"],
    "обычный": ["нормальный", "обыденный", "привычный"],
    "обычный японский школьник": ["обыкновенный японский школьник", "ояш"],
    "обюрократив": ["обюрокративши"],
    "обюрокративши": ["обюрократив"],
    "обюрокрачивав": ["обюрокрачивавши"],
    "обюрокрачивавши": ["обюрокрачивав"],
    "обява": ["обявление", "разгласа", "публикация", "известие", "съобщение", "обнародване"],
    "обязав": ["обязавши"],
    "обязавши": ["обязав"],
    "обязаловка": ["принудиловка"],
    "обязанность": ["долг", "повинность", "обязательство", "необходимость", "служба", "работа", "дело", "должность"],
    "обязанный": ["вынужденный", "признательный", "благодарный"],
    "обязательно": ["непременно", "безусловно", "конечно же", "требуется", "необходимо", "любезно", "услужливо"],
    "обязательный": ["необходимый", "неукоснительный", "непреложный", "преюдициальный", "облигатный", "непременный"],
    "обязательство": ["обет", "облигация", "финансовое обязательство"],
    "обязывав": ["обязывавши"],
    "обязывавши": ["обязывав"],
    "обёртка": ["обвёртка", "фантик"],
    "обёртывав": ["обёртывавши"],
    "обёртывавши": ["обёртывав"],
    "обёртывать": ["оборачивать"],
    "обёртываться": ["поворачиваться", "повёртываться", "оборачиваться"],
    "овал": ["эллипс"],
    "овалогубцы": ["круглогубцы"],
    "овалоцитоз": ["эллиптоцитоз"],
    "овариальный": ["яичниковый"],
    "овдовев": ["овдовевши"],
    "овдовевши": ["овдовев"],
    "овевав": ["овевавши"],
    "овевавши": ["овевав"],
    "овевать": ["овеивать", "обдувать"],
    "овеивав": ["овеивавши"],
    "овеивавши": ["овеивав"],
    "овеивание": ["овевание", "обдувание"],
    "овеивать": ["овевать", "обдувать"],
    "овен": ["баран"],
    "овердоз": ["передозировка", "передоз"],
    "овердофига": ["множество"],
    "овердрафтный": ["овердрафтовый"],
    "овердрафтовый": ["овердрафтный"],
    "оверкиль": ["опрокидывание"],
    "овертайм": ["тай-брейк"],
    "овечий": ["овчий", "бараний", "безропотный"],
    "овечья смерть": ["ковыл", "кипер", "иголка", "шелкова трава"],
    "овеществив": ["овеществивши"],
    "овеществивши": ["овеществив"],
    "овеществиться": ["реализоваться", "материализоваться", "воплотиться"],
    "овеществляв": ["овеществлявши"],
    "овеществлявши": ["овеществляв"],
    "овеяв": ["овеявши"],
    "овеявши": ["овеяв"],
    "овзросляв": ["овзрослявши"],
    "овзрослявши": ["овзросляв"],
    "овив": ["овивши"],
    "овивав": ["овивавши"],
    "овивавши": ["овивав"],
    "овивши": ["овив"],
    "овин": ["рига"],
    "овладев": ["овладевши"],
    "овладевав": ["овладевавши"],
    "овладевавши": ["овладевав"],
    "овладевать": ["захватывать"],
    "овладевши": ["овладев"],
    "овладенье": ["овладение"],
    "овладеть": ["завладеть", "взять", "подчинить", "выучить", "изучить", "освоить", "усвоить"],
    "овлажняв": ["овлажнявши"],
    "овлажнявши": ["овлажняв"],
    "овлажнять": ["увлажнять"],
    "овогенез": ["оогенез"],
    "овоид": ["овал", "эллипсоид", "оолит"],
    "овощ": ["овощь", "обощи", "билье", "слетье", "огородина", "овощие", "пикули"],
    "овощерезальный": ["овощерезательный", "овощерезный"],
    "овощерезательный": ["овощерезальный", "овощерезный"],
    "овощерезный": ["овощерезальный", "овощерезательный"],
    "овощехранилище": ["склад"],
    "овощной": ["вегетарианский"],
    "овсюг": ["овёс пустой", "овёс дикий"],
    "овсяная каша": ["овсянка", "геркулесовая каша"],
    "овсянка": ["овёс", "геркулес", "овсяная каша"],
    "овсяные хлопья": ["геркулес"],
    "овсяный": ["овсяной"],
    "овуляшка": ["овуляция"],
    "овца": ["баран", "овен", "барануха", "дура", "идиотка", "лохушка"],
    "овцеград": ["овцекомплекс"],
    "овцекомплекс": ["овцеград"],
    "овцеёб": ["овцелюб", "дурак", "кретин", "идиот", "дебил", "скотина", "свинья", "пёс", "пёс смердячий", "псина", "сука", "сучонок", "сучёныш", "сучара", "сволочь"],
    "овчар": ["чабан", "овчарка"],
    "овчарня": ["кошара", "овчарник"],
    "овчина": ["каракуль", "мутон", "руно"],
    "овчинка": ["овчина"],
    "овчинка выделки не стоит": ["игра не стоит свеч"],
    "овшивев": ["овшивевши"],
    "овшивевши": ["овшивев"],
    "овшиветь": ["обовшиветь"],
    "овый": ["один", "некий", "этот", "некоторый"],
    "овёс": ["овсяная крупа"],
    "огадив": ["огадивши"],
    "огадивши": ["огадив"],
    "огаживав": ["огаживавши"],
    "огаживавши": ["огаживав"],
    "огайо": ["штат конского каштана", "штат янки", "охайо"],
    "оганесон": ["унуноктий", "эка-радон"],
    "огар": ["огарь", "загар"],
    "огарок": ["сорванец"],
    "огарь": ["красная утка", "пеганка"],
    "огибав": ["огибавши"],
    "огибавши": ["огибав"],
    "огибающая": ["контур"],
    "огидливий": ["огидний", "гидкий", "бридкий"],
    "оглавление": ["содержание"],
    "оглавленье": ["оглавление"],
    "оглаголивание": ["вербализация"],
    "огладив": ["огладивши"],
    "огладивши": ["огладив"],
    "огладывав": ["огладывавши"],
    "огладывавши": ["огладывав"],
    "оглаживав": ["оглаживавши"],
    "оглаживавши": ["оглаживав"],
    "огласив": ["огласивши"],
    "огласивши": ["огласив"],
    "огласить": ["объявить", "провозгласить", "зачитать", "оповестить", "разгласить", "выдать", "озвучить"],
    "огласка": ["разглашение", "известность"],
    "оглашав": ["оглашавши"],
    "оглашавши": ["оглашав"],
    "оглашать": ["объявлять", "провозглашать", "зачитывать", "оповещать", "разглашать", "выдавать", "озвучивать"],
    "оглашение": ["оглашенье"],
    "оглашенье": ["оглашение"],
    "оглед": ["оглеждане", "проверка", "ревизия", "разглеждане"],
    "оглобля": ["оглобень", "оглоблина", "бастрык", "дужка"],
    "оглодав": ["оглодавши"],
    "оглодавши": ["оглодав"],
    "оглоед": ["бездельник", "нахал", "наглец", "дармоед"],
    "оглоедка": ["дармоедка", "тунеядка"],
    "оглонассив": ["оглонассивши"],
    "оглонассивши": ["оглонассив"],
    "оглонашивав": ["оглонашивавши"],
    "оглонашивавши": ["оглонашивав"],
    "оглоушив": ["оглоушивши"],
    "оглоушивав": ["оглоушивавши"],
    "оглоушивавши": ["оглоушивав"],
    "оглоушивши": ["оглоушив"],
    "оглоушить": ["оглушить", "поразить", "сразить", "ошеломить", "обескуражить", "огорошить"],
    "оглохнув": ["оглохнувши"],
    "оглохнувши": ["оглохнув"],
    "оглупев": ["оглупевши"],
    "оглупевши": ["оглупев"],
    "оглупив": ["оглупивши"],
    "оглупивши": ["оглупив"],
    "оглупить": ["дебилизовать"],
    "оглупляв": ["оглуплявши"],
    "оглуплявши": ["оглупляв"],
    "оглушав": ["оглушавши"],
    "оглушавши": ["оглушав"],
    "оглушение": ["оглушенье", "оглушённость", "синдром оглушения сознания"],
    "оглушенье": ["оглушение"],
    "оглушив": ["оглушивши"],
    "оглушивши": ["оглушив"],
    "оглушить": ["оглоушить", "ошеломить"],
    "оглядев": ["оглядевши"],
    "оглядевши": ["оглядев"],
    "оглядеться": ["осмотреться", "оглянуться"],
    "оглядывав": ["оглядывавши"],
    "оглядывавши": ["оглядывав"],
    "оглядыванье": ["оглядывание"],
    "оглядывать": ["осматривать", "обозревать"],
    "оглядываться": ["осматриваться", "осваиваться"],
    "оглянув": ["оглянувши"],
    "оглянувши": ["оглянув"],
    "огнеборец": ["пожарник", "пожарный"],
    "огневая позиция": ["огневой рубеж"],
    "огневев": ["огневевши"],
    "огневевши": ["огневев"],
    "огневой рубеж": ["огневая позиция"],
    "огнемётный": ["огнеметательный", "ошеломительный"],
    "огненная вода": ["алкоголь"],
    "огненно-красный": ["пламенно-красный", "пламенно-рыжий", "огненно-рыжий", "ярко-рыжий"],
    "огненный": ["огневой", "огняный", "пламенный", "зажигательный"],
    "огненосец": ["факелоносец"],
    "огнеопасный": ["легковоспламеняющийся"],
    "огнепоклонничество": ["огнепоклонство"],
    "огнепоклонство": ["огнепоклонничество"],
    "огнестойкий": ["огнезащитный", "огнеупорный"],
    "огнестрел": ["огнестрельное оружие", "огнестрельное ранение"],
    "огнестрельное оружие": ["огнестрел"],
    "огнестрельное ранение": ["огнестрел"],
    "огнестрельный": ["стрелковый"],
    "огнеупорный": ["несгораемый"],
    "огнецвет": ["иван-да-марья"],
    "огниво": ["кресало"],
    "огнищанин": ["житой человек"],
    "огнище": ["кострище", "костёр"],
    "огнь": ["огонь"],
    "ого": ["ух ты", "ничего себе", "вот это да"],
    "оговаривав": ["оговаривавши"],
    "оговаривавши": ["оговаривав"],
    "оговариваться": ["оговаривать", "предупреждать"],
    "оговор": ["наговаривание", "клевета", "наговор", "напраслина", "поклёп"],
    "оговорив": ["оговоривши"],
    "оговоривши": ["оговорив"],
    "оговорить": ["оболгать", "оклеветать", "условиться", "отметить"],
    "оговорка": ["обмолвка"],
    "оговорка по фрейду": ["оговорочка по фрейду"],
    "оговорщик": ["клеветник"],
    "огогокав": ["огогокавши"],
    "огогокавши": ["огогокав"],
    "оголев": ["оголевши"],
    "оголевши": ["оголев"],
    "оголец": ["озорник", "сорванец"],
    "оголив": ["оголивши"],
    "оголивши": ["оголив"],
    "оголить": ["обнажить"],
    "оголовушив": ["оголовушивши"],
    "оголовушивши": ["оголовушив"],
    "оголовушить": ["оглушить", "оголоушить"],
    "оголодав": ["оголодавши"],
    "оголодавши": ["оголодав"],
    "оголодив": ["оголодивши"],
    "оголодивши": ["оголодив"],
    "оголтев": ["оголтевши"],
    "оголтевши": ["оголтев"],
    "оголтелость": ["необузданность", "несдержанность", "разнузданность", "безудержность"],
    "оголтелый": ["бесстыдный", "одурелый", "отъявленный", "заклятый", "дикий", "шальной", "бесшабашный", "беспредельный", "бешеный", "оголченный"],
    "оголяв": ["оголявши"],
    "оголявши": ["оголяв"],
    "оголяться": ["обнажаться", "раздеваться"],
    "оголённый": ["обнажённый", "голый", "нагой", "неприкрытый", "декольтированный", "открытый", "непокрытый", "лысый", "плешивый", "облезлый", "безволосый"],
    "огонь": ["пли"],
    "огонь по своим": ["фратрицид", "дружественный огонь"],
    "огонёк": ["огонь", "искра", "искорка"],
    "огораживав": ["огораживавши"],
    "огораживавши": ["огораживав"],
    "огораживание": ["ограждение", "выгораживание", "обведение", "обвод", "обгораживание", "загораживание"],
    "огораживать": ["ограждать"],
    "огорашивав": ["огорашивавши"],
    "огорашивавши": ["огорашивав"],
    "огорашивать": ["огорошивать", "ошеломлять"],
    "огородив": ["огородивши"],
    "огородивши": ["огородив"],
    "огородик": ["огородчик"],
    "огородничав": ["огородничавши"],
    "огородничавши": ["огородничав"],
    "огорошенный": ["оглушённый", "озадаченный", "ошарашенный", "ошеломлённый", "потрясённый", "растерянный", "смущённый"],
    "огорошив": ["огорошивши"],
    "огорошивав": ["огорошивавши"],
    "огорошивавши": ["огорошивав"],
    "огорошивать": ["огорашивать", "ошеломлять"],
    "огорошивши": ["огорошив"],
    "огорошить": ["поставить в тупик"],
    "огорчав": ["огорчавши"],
    "огорчавши": ["огорчав"],
    "огорчать": ["расстраивать", "печалить"],
    "огорчение": ["расстройство"],
    "огорчив": ["огорчивши"],
    "огорчивши": ["огорчив"],
    "огорчительно": ["прискорбно", "жалко", "жаль", "обидно", "досадно"],
    "огорчить": ["опечалить", "расстроить"],
    "огорчиться": ["расстроиться"],
    "огосударствив": ["огосударствивши"],
    "огосударствивши": ["огосударствив"],
    "огосударствливав": ["огосударствливавши"],
    "огосударствливавши": ["огосударствливав"],
    "огосударствляв": ["огосударствлявши"],
    "огосударствлявши": ["огосударствляв"],
    "огпу": ["огпу при снк ссср"],
    "ограбив": ["ограбивши"],
    "ограбивши": ["ограбив"],
    "ограбление": ["грабёж"],
    "ограбленье": ["ограбление"],
    "ограбляв": ["ограблявши"],
    "ограблявши": ["ограбляв"],
    "ограблять": ["грабить"],
    "ограда": ["ограждение", "изгородь", "забор", "охрана", "защита"],
    "оградив": ["оградивши"],
    "оградивши": ["оградив"],
    "оградить": ["огородить", "защитить"],
    "ограждав": ["ограждавши"],
    "ограждавши": ["ограждав"],
    "ограждать": ["огораживать", "защищать", "оберегать"],
    "ограждение": ["загораживание", "заграждение", "ограда"],
    "огражденье": ["ограждение"],
    "огранив": ["огранивши"],
    "огранивав": ["огранивавши"],
    "огранивавши": ["огранивав"],
    "огранивать": ["огранять"],
    "ограниваться": ["ограняться", "граниться"],
    "огранивши": ["огранив"],
    "ограничение": ["лимитирование", "ограниченье"],
    "ограниченье": ["ограничение"],
    "ограничив": ["ограничивши"],
    "ограничивав": ["ограничивавши"],
    "ограничивавши": ["ограничивав"],
    "ограничивши": ["ограничив"],
    "ограночный": ["гранильный"],
    "ограняв": ["огранявши"],
    "огранявши": ["ограняв"],
    "огранять": ["огранивать", "гранить"],
    "ограняться": ["ограниваться", "граниться"],
    "огребав": ["огребавши"],
    "огребавши": ["огребав"],
    "огрев": ["огревши"],
    "огревав": ["огревавши"],
    "огревавши": ["огревав"],
    "огревши": ["огрев"],
    "огреть": ["ударить", "задать жару", "побить"],
    "огрех": ["недостаток", "ошибка", "промашка", "погрешность"],
    "огрже": ["эгер"],
    "огромадный": ["громадный", "огромистый", "огромнеющий"],
    "огромив": ["огромивши"],
    "огромивши": ["огромив"],
    "огромный": ["гигантский", "грандиозный", "громадный", "колоссальный", "обширный"],
    "огрубев": ["огрубевши"],
    "огрубевав": ["огрубевавши"],
    "огрубевавши": ["огрубевав"],
    "огрубевши": ["огрубев"],
    "огрубив": ["огрубивши"],
    "огрубивши": ["огрубив"],
    "огрубляв": ["огрублявши"],
    "огрублявши": ["огрубляв"],
    "огрублять": ["загрублять"],
    "огружав": ["огружавши"],
    "огружавши": ["огружав"],
    "огрузав": ["огрузавши"],
    "огрузавши": ["огрузав"],
    "огрузив": ["огрузивши"],
    "огрузивши": ["огрузив"],
    "огрузнев": ["огрузневши"],
    "огрузневши": ["огрузнев"],
    "огрузнув": ["огрузнувши"],
    "огрузнувши": ["огрузнув"],
    "огрузнуть": ["огрузнеть"],
    "огрунтовав": ["огрунтовавши"],
    "огрунтовавши": ["огрунтовав"],
    "огрунтовывав": ["огрунтовывавши"],
    "огрунтовывавши": ["огрунтовывав"],
    "огрыз": ["огрызание"],
    "огрызав": ["огрызавши"],
    "огрызавши": ["огрызав"],
    "огрызок": ["обрывок", "кусок"],
    "огрызться": ["обгрызться"],
    "огрядний": ["дебелий"],
    "огрёбки": ["огребье"],
    "огубив": ["огубивши"],
    "огубивши": ["огубив"],
    "огубить": ["лабиализовать"],
    "огубление": ["лабиализация"],
    "огубляв": ["огублявши"],
    "огублявши": ["огубляв"],
    "огублять": ["лабиализовать"],
    "огуз": ["варташен"],
    "огуливав": ["огуливавши"],
    "огуливавши": ["огуливав"],
    "огульно": ["огулом", "безосновательно", "гуртом", "сообща", "оптом"],
    "огульность": ["необоснованность", "неосновательность"],
    "огульный": ["общий", "гуртовой", "поголовный", "необоснованный", "поверхностный", "бездоказательный", "безосновательный", "беспочвенный", "взятый с потолка", "голословный", "малодоказательный", "малосостоятельный", "неаргументированный", "недоказательный", "неоправданный"],
    "огуменник": ["гуменник", "гумно", "ток"],
    "огурец": ["трезвый", "бодрый"],
    "огуречик": ["огурчик"],
    "огурчик": ["трезвый"],
    "огустев": ["огустевши"],
    "огустевав": ["огустевавши"],
    "огустевавши": ["огустевав"],
    "огустевши": ["огустев"],
    "огъри": ["огъры"],
    "огърлица": ["гердан", "наниз", "гиздило", "накит", "колие"],
    "огэ": ["государственная итоговая аттестация"],
    "одал": ["отал", "отила"],
    "одалживав": ["одалживавши"],
    "одалживавши": ["одалживав"],
    "одаль": ["вдалеке", "поодаль"],
    "одарив": ["одаривши"],
    "одаривав": ["одаривавши"],
    "одаривавши": ["одаривав"],
    "одаривать": ["одарять", "дарить"],
    "одаривши": ["одарив"],
    "одарить": ["наделить"],
    "одаряв": ["одарявши"],
    "одарявши": ["одаряв"],
    "одарять": ["одаривать", "дарить"],
    "одарённейший": ["талантливейший"],
    "одарённость": ["талант", "дар", "дарование", "талантливость", "даровитость", "способность", "задатки"],
    "одарённый": ["талантливый"],
    "одб": ["бов"],
    "одвуконь": ["одвуконно", "двуконно", "двоеконно"],
    "одвухсотив": ["одвухсотивши"],
    "одвухсотивши": ["одвухсотив"],
    "одвухсотить": ["задвухсотить", "замочить", "завалить"],
    "одвухсочивав": ["одвухсочивавши"],
    "одвухсочивавши": ["одвухсочивав"],
    "одвухсочивать": ["двухсотить", "мочить", "валить"],
    "одебелев": ["одебелевши"],
    "одебелевши": ["одебелев"],
    "одебелеть": ["ожиреть", "потучнеть", "огрубеть"],
    "одебилив": ["одебиливши"],
    "одебиливав": ["одебиливавши"],
    "одебиливавши": ["одебиливав"],
    "одебиливать": ["дебилизировать"],
    "одебиливши": ["одебилив"],
    "одебилить": ["дебилизировать"],
    "одев": ["одевши"],
    "одевав": ["одевавши"],
    "одевавши": ["одевав"],
    "одевание": ["одеванье"],
    "одеванье": ["одевание"],
    "одевать": ["облачать"],
    "одеваться": ["облачаться"],
    "одевши": ["одев"],
    "одежда": ["одеяние", "одёжа", "шмотки", "костюм", "наряд", "туалет", "убранство", "облачение", "платье"],
    "одеколон": ["туалетная вода"],
    "одеколонив": ["одеколонивши"],
    "одеколонивши": ["одеколонив"],
    "оделив": ["оделивши"],
    "оделивши": ["оделив"],
    "оделить": ["одарить", "наделить"],
    "оделяв": ["оделявши"],
    "оделявши": ["оделяв"],
    "одембелев": ["одембелевши"],
    "одембелевши": ["одембелев"],
    "одеревенев": ["одеревеневши"],
    "одеревеневши": ["одеревенев"],
    "одеревенелый": ["задубелый", "одеревеневший", "закостенелый", "онемевший", "закоченевший", "равнодушный"],
    "одержав": ["одержавши"],
    "одержавши": ["одержав"],
    "одержать": ["завоевать"],
    "одержать верх": ["взять верх", "одержать победу"],
    "одерживав": ["одерживавши"],
    "одерживавши": ["одерживав"],
    "одерживать": ["одолевать", "осиливать", "побеждать"],
    "одерживать верх": ["брать верх", "одерживать победу"],
    "одержимость": ["влекомость", "увлечённость", "фанатизм", "сумасшествие", "безумие"],
    "одержимый": ["обуянный", "охваченный"],
    "одержувач": ["адресат", "отримувач"],
    "одесную": ["справа"],
    "одесса": ["город-мама", "жемчужина черноморья"],
    "одесская область": ["одесщина"],
    "одеть": ["облачить"],
    "одещина": ["одеська область"],
    "одеяние": ["наряд", "одеянье"],
    "одеянье": ["одеяние"],
    "оджак": ["комин", "огнище", "баджа"],
    "оджибва": ["оджибве", "очипве", "чиппева", "анишшинапе"],
    "одигитрия": ["путеводительница"],
    "один": ["вотан"],
    "один за другим": ["вереницей", "цепью", "цепочкой", "чередой", "цугом", "гуськом", "друг за другом", "друг за дружкой", "затылок в затылок", "паровозом", "паровозиком", "один за одним", "гусем", "чредой"],
    "один как перст": ["один-одинёшенек"],
    "один на один": ["с глазу на глаз"],
    "один раз": ["единожды"],
    "один хрен": ["без разницы", "один фиг", "всё равно", "монопенисуально", "эквипенисуально"],
    "один-одинёшенек": ["одинёшенек", "один-одинёхонек"],
    "одинак": ["одинець"],
    "одинакий": ["одинаковый"],
    "одинаково": ["равно", "равным образом", "в равной мере", "в равной степени", "точь-в-точь"],
    "одинаковый": ["такой же", "идентичный", "равный", "симметричный"],
    "одинець": ["одинак"],
    "одинизм": ["вотанизм"],
    "одиннадцатиугольник": ["гендекагон"],
    "одиннадцать": ["барабанные палочки"],
    "одиножды": ["единожды"],
    "одинокий": ["уединённый"],
    "одинокость": ["одиночество"],
    "одиночество": ["уединение", "изоляция", "изолированность"],
    "одиночествовав": ["одиночествовавши"],
    "одиночествовавши": ["одиночествовав"],
    "одиночный": ["единичный", "индивидуальный", "одноместный"],
    "одиозно": ["отвратительно"],
    "одиозность": ["отвратительность"],
    "одиозный": ["ненавистный", "противный"],
    "одирав": ["одиравши"],
    "одиравши": ["одирав"],
    "одиссей": ["улисс"],
    "одичав": ["одичавши"],
    "одичавши": ["одичав"],
    "одичалый": ["одичавший"],
    "одичанье": ["одичание"],
    "одиши": ["акапа"],
    "одна ласточка весны не делает": ["один в поле не воин"],
    "однажды": ["единожды", "однаво", "как-то раз", "когда-то", "когда-нибудь"],
    "однако": ["но", "тем не менее", "всё же", "всё-таки", "вместе с тем", "ну и ну", "вот это да"],
    "однако же": ["тем не менее", "но"],
    "одни глаза не сыты": ["глаза одни не сыты", "одне глаза не сыты"],
    "одним духом": ["быстро", "миг", "стремительно", "раз"],
    "одним миром мазаны": ["два сапога пара", "одного поля ягоды", "из одного теста сделаны"],
    "одно и то же": ["то же самое", "все равно", "одинаково", "без разницы", "одна малина"],
    "однобайтовый": ["восьмибитный", "восьмибитовый"],
    "однобоко": ["односторонне"],
    "однова": ["однажды", "один раз", "некогда", "когда-то", "единожды"],
    "одновалентный": ["моновалентный"],
    "одновременно": ["параллельно", "синхронно", "единовременно", "в равной мере"],
    "одновременность": ["синхронность"],
    "одновременный": ["синхронный"],
    "одноглазый": ["кривоглазый", "кривой", "одноокий"],
    "одного поля ягоды": ["одним миром мазаны", "два сапога пара", "одна шайка-лейка"],
    "одногодичный": ["однолетний"],
    "одногодка": ["один", "возраст", "ровесница", "сверстница"],
    "одногодовалый": ["годовалый", "летошний"],
    "одногодок": ["один", "возраст", "ровесник", "сверстник", "годок"],
    "одноголосий": ["одноголосний"],
    "одноголосица": ["одноголосие"],
    "одноголосно": ["одноголосо"],
    "одноголосье": ["одноголосие"],
    "однодворец": ["сосед"],
    "однодентатный": ["монодентатный"],
    "однодневка": ["подёнка", "фирма-однодневка", "летун"],
    "однодольный": ["односеменодольный", "односемядольный"],
    "одноеровый": ["одноеревый"],
    "однозвучно": ["однотонно", "монотонно"],
    "однозвучность": ["монотонность"],
    "однозвёздный": ["однозвёздочный"],
    "однозвёздочный": ["однозвёздный"],
    "однозначно": ["недвусмысленно", "определённо", "точно", "конечно", "несомненно", "разумеется", "без сомнения", "да"],
    "однозначность": ["определённость", "недвусмысленность"],
    "одноимённый": ["соименный", "тезоименитый", "тождеименный"],
    "одной левой": ["запросто", "плёвое дело"],
    "одноклассник": ["однокашник", "соклассник"],
    "одноклассница": ["однокашница"],
    "одноклетный": ["одноклеточный"],
    "одноклеточное": ["амёба", "примитив"],
    "одноклеточный": ["простейший", "примитивный", "одноклетный"],
    "одноклиномерный": ["моносимметрический"],
    "однокомпонентный": ["монокомпонентный"],
    "однокоренной": ["однокорневой"],
    "однокорытница": ["сотрапезница"],
    "однокристальный": ["одночиповый", "одночипный"],
    "однокур": ["однокурсник"],
    "однокурсник": ["сокурсник"],
    "однокурсница": ["сокурсница"],
    "однолетка": ["один", "возраст", "ровесник", "ровесница", "сверстник", "сверстница", "годок"],
    "однолетний": ["одногодичный"],
    "однолеток": ["один", "возраст", "ровесник", "сверстник", "годок"],
    "однолюб": ["однолюбец"],
    "одномандатник": ["одноманда"],
    "одномандатный": ["одноимённый", "униноминальный"],
    "одномастий": ["одномасний"],
    "одноминутный": ["минутный", "шестидесятисекундный", "пятиминутный"],
    "одномоментный": ["единовременный", "одновременный"],
    "однонедельный": ["недельный", "семидневный"],
    "однообразив": ["однообразивши"],
    "однообразивши": ["однообразив"],
    "однообразить": ["уоднообразить", "унифицировать", "единообразить"],
    "однообразно": ["монотонно"],
    "однообразный": ["монотонный", "единообразный"],
    "однообразье": ["однообразие"],
    "одноокись": ["моноокись", "монооксид", "моноксид"],
    "однопалатник": ["сопалатник"],
    "однопарный": ["бигеминальный"],
    "однопартийный": ["монопартийный"],
    "одноплечий": ["одним", "плечом", "одноплечный", "одноплечевой"],
    "одноплёкий": ["одноплечный", "одноплечевой", "одноплечий", "одним", "плечом"],
    "однополчанин": ["сослуживец"],
    "однополый": ["раздельнополый"],
    "однопользовательский": ["персональный"],
    "однополярный": ["монополярный", "однополюсный", "однобокий"],
    "однопутный": ["односторонний"],
    "одноразовость": ["однократность"],
    "одноразовый": ["однократный"],
    "однорельсовый": ["монорельсовый"],
    "однородность": ["гомогенность"],
    "однородный": ["однотипный", "гомогенный"],
    "однорукий бандит": ["игровой автомат", "лохотрон"],
    "односемядольный": ["однодольный"],
    "односемянный": ["моноспермический", "моноспермный"],
    "однослоговой": ["моносиллабический", "односложный"],
    "однослоговый": ["однослоговой", "односложный"],
    "односложный": ["однослоговый", "однослоговой", "моносиллабический"],
    "однослойный": ["послойный"],
    "одностадийный": ["одноступенчатый"],
    "одностишие": ["моностих"],
    "одностраничник": ["лендинг", "лэндинг"],
    "одноступенчатый": ["одностадийный", "одноступенный"],
    "односум": ["собрат", "однополчанин", "сослуживец"],
    "однотипный": ["стандартный"],
    "однотонный": ["однозвучный", "монотонный", "одноцветный", "монохроматический"],
    "однофунтовый": ["фунтовый"],
    "однохуйственно": ["одинаково", "так же"],
    "одноцветный": ["монохромный", "монохроматический"],
    "одночасовой": ["часовой", "шестидесятиминутный"],
    "одночлен": ["моном"],
    "одноязычие": ["монолингвизм"],
    "однояйцовый": ["монозиготный"],
    "однёрка": ["единица", "однёшка", "однушка"],
    "одобрение": ["похвала"],
    "одобренье": ["одобрение"],
    "одобрив": ["одобривши"],
    "одобривши": ["одобрив"],
    "одобряв": ["одобрявши"],
    "одобрявши": ["одобряв"],
    "одограф": ["курсограф", "автопрокладчик"],
    "одолбив": ["одолбивши"],
    "одолбивши": ["одолбив"],
    "одолбить": ["сдолбить"],
    "одолевав": ["одолевавши"],
    "одолевавши": ["одолевав"],
    "одолевать": ["побеждать", "осиливать", "пересиливать"],
    "одолевши": ["одолев"],
    "одолень-трава": ["белая кувшинка"],
    "одоленье": ["одоление"],
    "одолеть": ["победить", "осилить", "пересилить", "превозмочь"],
    "одолжав": ["одолжавши"],
    "одолжавши": ["одолжав"],
    "одолженье": ["одолжение"],
    "одолжив": ["одолживши"],
    "одолживши": ["одолжив"],
    "одолжить": ["дать в долг", "дать взаймы", "ссудить", "обязать", "занять"],
    "одолив": ["одоливши"],
    "одоливши": ["одолив"],
    "одоляв": ["одолявши"],
    "одолявши": ["одоляв"],
    "одомашнение": ["одомашнивание"],
    "одомашненный": ["прирученный", "ручной", "домашний", "доместицированный"],
    "одомашнив": ["одомашнивши"],
    "одомашнивав": ["одомашнивавши"],
    "одомашнивавши": ["одомашнивав"],
    "одомашнивание": ["одомашнение", "доместикация", "одомашниванье"],
    "одомашниванье": ["одомашнение", "одомашнивание", "доместикация"],
    "одомашнивать": ["приручать"],
    "одомашнивши": ["одомашнив"],
    "одомашнить": ["приручить"],
    "одонтеризм": ["бруксизм"],
    "одонтолит": ["костяная бирюза", "зубной камень"],
    "одонье": ["сноп", "скирда"],
    "одоратор": ["ароматизатор"],
    "одоризация": ["одорирование"],
    "одоризировав": ["одоризировавши"],
    "одоризировавши": ["одоризировав"],
    "одоризировать": ["одоризовать"],
    "одоризовав": ["одоризовавши"],
    "одоризовавши": ["одоризовав"],
    "одоризовать": ["одоризировать"],
    "одориметрия": ["ольфактометрия"],
    "одорировав": ["одорировавши"],
    "одорировавши": ["одорировав"],
    "одорировать": ["ароматизировать", "одоризировать"],
    "одох": ["явах"],
    "одр": ["постель", "ложе", "повозка", "носилки"],
    "одрав": ["одравши"],
    "одравши": ["одрав"],
    "одревеснев": ["одревесневши"],
    "одревесневав": ["одревесневавши"],
    "одревесневавши": ["одревесневав"],
    "одревесневши": ["одревеснев"],
    "одревеснение": ["лигнификация"],
    "одринлия": ["одринец"],
    "одряблев": ["одряблевши"],
    "одряблевши": ["одряблев"],
    "одряблеть": ["одрябнуть"],
    "одрябнув": ["одрябнувши"],
    "одрябнувши": ["одрябнув"],
    "одрябнуть": ["одряблеть"],
    "одряхлев": ["одряхлевши"],
    "одряхлевши": ["одряхлев"],
    "одряхление": ["состаривание", "старение", "обветшание"],
    "одряхнув": ["одряхнувши"],
    "одряхнувши": ["одряхнув"],
    "одряхнуть": ["одряхлеть"],
    "одсто": ["посто"],
    "оду-васу": ["мековасу", "омбоцеда"],
    "одубев": ["одубевши"],
    "одубевши": ["одубев"],
    "одув": ["одувши"],
    "одувши": ["одув"],
    "одумав": ["одумавши"],
    "одумавши": ["одумав"],
    "одуматься": ["передумать"],
    "одумывав": ["одумывавши"],
    "одумывавши": ["одумывав"],
    "одурачив": ["одурачивши"],
    "одурачивав": ["одурачивавши"],
    "одурачивавши": ["одурачивав"],
    "одурачивать": ["оставлять в дураках", "облапошивать"],
    "одурачивши": ["одурачив"],
    "одурачить": ["провести", "обвести вокруг пальца"],
    "одурев": ["одуревши"],
    "одуревав": ["одуревавши"],
    "одуревавши": ["одуревав"],
    "одуревши": ["одурев"],
    "одуревший": ["обалдевший", "ошалелый"],
    "одурив": ["одуривши"],
    "одуривши": ["одурив"],
    "одурить": ["одурачить"],
    "одурманив": ["одурманивши"],
    "одурманивав": ["одурманивавши"],
    "одурманивавши": ["одурманивав"],
    "одурманивать": ["опьянять"],
    "одурманивши": ["одурманив"],
    "одуряв": ["одурявши"],
    "одурявши": ["одуряв"],
    "одутловатость": ["припухлость"],
    "одутловатый": ["обрюзгший"],
    "одухотворив": ["одухотворивши"],
    "одухотворивши": ["одухотворив"],
    "одухотворяв": ["одухотворявши"],
    "одухотворявши": ["одухотворяв"],
    "одухотворённость": ["благородность", "возвышенность"],
    "одухотворённый": ["пассионарный"],
    "одушевив": ["одушевивши"],
    "одушевивши": ["одушевив"],
    "одушевить": ["одухотворить", "воодушевить"],
    "одушевление": ["олицетворение"],
    "одушевленье": ["одушевление"],
    "одушевляв": ["одушевлявши"],
    "одушевлявши": ["одушевляв"],
    "одушевлять": ["одухотворять", "воодушевлять"],
    "одушевлённый": ["живой"],
    "одышливый": ["задыхающийся"],
    "одяг": ["одежа"],
    "одёжка": ["одежда"],
    "одёр": ["кляча"],
    "одёргивав": ["одёргивавши"],
    "одёргивавши": ["одёргивав"],
    "одёрнув": ["одёрнувши"],
    "одёрнувши": ["одёрнув"],
    "оевропеив": ["оевропеивши"],
    "оевропеивав": ["оевропеивавши"],
    "оевропеивавши": ["оевропеивав"],
    "оевропеивание": ["европеизация"],
    "оевропеивши": ["оевропеив"],
    "ожарив": ["ожаривши"],
    "ожаривав": ["ожаривавши"],
    "ожаривавши": ["ожаривав"],
    "ожаривши": ["ожарив"],
    "ожарить": ["обжарить"],
    "ожеледь": ["гололёд"],
    "оженив": ["оженивши"],
    "оженивши": ["оженив"],
    "оженить": ["поженить", "обженить"],
    "ожениться": ["обжениться", "вступить в брак", "жениться"],
    "ожеребив": ["ожеребивши"],
    "ожеребивши": ["ожеребив"],
    "ожерёб": ["выжереб"],
    "ожесточав": ["ожесточавши"],
    "ожесточавши": ["ожесточав"],
    "ожесточаться": ["озлобляться", "разъяряться"],
    "ожесточенье": ["ожесточение"],
    "ожесточив": ["ожесточивши"],
    "ожесточивши": ["ожесточив"],
    "ожечь": ["обжечь"],
    "ожив": ["оживши"],
    "оживав": ["оживавши"],
    "оживавши": ["оживав"],
    "оживать": ["воскресать", "воодушевляться"],
    "оживев": ["оживевши"],
    "оживевши": ["оживев"],
    "оживив": ["ожививши"],
    "ожививши": ["оживив"],
    "оживление": ["активность", "подъём", "оживлённость", "бурление"],
    "оживленье": ["оживление"],
    "оживляв": ["оживлявши"],
    "оживлявши": ["оживляв"],
    "оживляж": ["оживление"],
    "оживлять": ["воскрешать"],
    "оживлённый": ["весёлый", "взбудораженный", "воскрешённый", "восставший", "людный"],
    "оживотворив": ["оживотворивши"],
    "оживотворивши": ["оживотворив"],
    "оживотвориться": ["оживиться", "обновиться"],
    "оживотворяв": ["оживотворявши"],
    "оживотворявши": ["оживотворяв"],
    "оживотворяться": ["оживляться", "обновляться"],
    "оживши": ["ожив"],
    "ожигав": ["ожигавши"],
    "ожигавши": ["ожигав"],
    "ожигать": ["обжигать"],
    "ожидав": ["ожидавши"],
    "ожидавши": ["ожидав"],
    "ожидаемость": ["предсказуемость"],
    "ожидалка": ["приёмная", "ожидальня"],
    "ожидальня": ["приёмная"],
    "ожидание": ["выжидание", "надежда", "упование"],
    "ожиданье": ["ожидание"],
    "ожидать": ["ждать", "поджидать", "дожидаться"],
    "ожидаться": ["предвидеться", "предстоять"],
    "ожижав": ["ожижавши"],
    "ожижавши": ["ожижав"],
    "ожижать": ["сжижать"],
    "ожина": ["ежевика"],
    "ожинник": ["ежевика", "ежевичник"],
    "ожирев": ["ожиревши"],
    "ожиревав": ["ожиревавши"],
    "ожиревавши": ["ожиревав"],
    "ожиревать": ["жиреть", "толстеть", "тучнеть"],
    "ожиревши": ["ожирев"],
    "ожирелость": ["полнота", "тучность"],
    "ожирелый": ["дебелый", "жирный", "ожиревший"],
    "ожирение": ["ожиренье"],
    "ожиренье": ["ожирение"],
    "ожиреть": ["разжиреть", "погрузнеть", "раскормиться"],
    "ожить": ["воскреснуть", "возродиться", "оживиться"],
    "ожог": ["ожога"],
    "ожоговая медицина": ["комбустиология"],
    "ожу": ["ащемс", "повелительное наклонение"],
    "ожуда": ["ащемс", "повелительное наклонение"],
    "оз": ["друмлин", "эскер"],
    "озабот": ["озабоченный"],
    "озаботив": ["озаботивши"],
    "озаботивши": ["озаботив"],
    "озабоченно": ["обеспокоенно", "встревоженно"],
    "озабоченность": ["обеспокоенность", "тревога", "встревоженность", "беспокойство"],
    "озабочивав": ["озабочивавши"],
    "озабочивавши": ["озабочивав"],
    "озаглавив": ["озаглавивши"],
    "озаглавивши": ["озаглавив"],
    "озаглавливав": ["озаглавливавши"],
    "озаглавливавши": ["озаглавливав"],
    "озаглавливать": ["называть"],
    "озадачив": ["озадачивши"],
    "озадачивав": ["озадачивавши"],
    "озадачивавши": ["озадачивав"],
    "озадачивать": ["обескураживать", "загружать"],
    "озадачивши": ["озадачив"],
    "озак": ["озын", "акрын"],
    "озакламый": ["озакламыйча", "тиз"],
    "озамс": ["ландямс", "матрамс", "валгомс", "тумс", "юронзамс"],
    "озарение": ["озаренье", "освещение", "наитие", "прояснение", "инсайт"],
    "озаренье": ["озарение"],
    "озарив": ["озаривши"],
    "озаривши": ["озарив"],
    "озаряв": ["озарявши"],
    "озарявши": ["озаряв"],
    "озверев": ["озверевши"],
    "озверевши": ["озверев"],
    "озверелость": ["озверение", "бешенство"],
    "озвереть": ["рассвирепеть", "вскипеть"],
    "озвучание": ["озвучение", "озвучка"],
    "озвучение": ["озвучание", "озвучивание", "озвучка"],
    "озвучив": ["озвучивши"],
    "озвучивав": ["озвучивавши"],
    "озвучивавши": ["озвучивав"],
    "озвучивание": ["озвучание", "озвучение", "озвучка"],
    "озвучивши": ["озвучив"],
    "озвучка": ["озвучание", "озвучение"],
    "оздоба": ["прикраса"],
    "оздоравливав": ["оздоравливавши"],
    "оздоравливавши": ["оздоравливав"],
    "оздоровев": ["оздоровевши"],
    "оздоровевши": ["оздоровев"],
    "оздоровив": ["оздоровивши"],
    "оздоровивши": ["оздоровив"],
    "оздоровить": ["поправить", "нормализовать", "привести в порядок"],
    "оздоровляв": ["оздоровлявши"],
    "оздоровлявши": ["оздоровляв"],
    "озеленив": ["озеленивши"],
    "озеленивши": ["озеленив"],
    "озеленяв": ["озеленявши"],
    "озеленявши": ["озеленяв"],
    "озенковав": ["озенковавши"],
    "озенковавши": ["озенковав"],
    "озерко": ["озерцо"],
    "озернив": ["озернивши"],
    "озернивши": ["озернив"],
    "озерняв": ["озернявши"],
    "озернявши": ["озерняв"],
    "озеровед": ["лимнолог"],
    "озероведение": ["лимнология"],
    "озерцо": ["озерко"],
    "озимизировав": ["озимизировавши"],
    "озимизировавши": ["озимизировав"],
    "озимые": ["озимь"],
    "озимь": ["озимка"],
    "озирав": ["озиравши"],
    "озиравши": ["озирав"],
    "озираться": ["оглядываться"],
    "озирис": ["осирис"],
    "озлатив": ["озлативши"],
    "озлативши": ["озлатив"],
    "озлащав": ["озлащавши"],
    "озлащавши": ["озлащав"],
    "озлев": ["озлевши"],
    "озлевши": ["озлев"],
    "озлив": ["озливши"],
    "озливши": ["озлив"],
    "озлить": ["обозлить"],
    "озлобив": ["озлобивши"],
    "озлобивши": ["озлобив"],
    "озлобить": ["ожесточить", "рассердить"],
    "озлобленье": ["озлобление"],
    "озлобляв": ["озлоблявши"],
    "озлоблявши": ["озлобляв"],
    "озлоблять": ["ожесточать", "сердить"],
    "ознакомив": ["ознакомивши"],
    "ознакомивши": ["ознакомив"],
    "ознакомление": ["знакомство"],
    "ознакомляв": ["ознакомлявши"],
    "ознакомлявши": ["ознакомляв"],
    "ознакомлять": ["знакомить"],
    "ознакомляться": ["знакомиться"],
    "ознаменовав": ["ознаменовавши"],
    "ознаменовавши": ["ознаменовав"],
    "ознаменованье": ["ознаменование"],
    "ознаменовывав": ["ознаменовывавши"],
    "ознаменовывавши": ["ознаменовывав"],
    "ознаменовывать": ["отмечать"],
    "означав": ["означавши"],
    "означавши": ["означав"],
    "означаемое": ["денотат"],
    "означать": ["помечать", "обозначать", "отмечать"],
    "означающее": ["обозначающее"],
    "означение": ["обозначение"],
    "означенный": ["вышеозначенный"],
    "означенье": ["означение"],
    "означив": ["означивши"],
    "означивши": ["означив"],
    "озноб": ["дрожь", "зноб", "колотун"],
    "ознобив": ["ознобивши"],
    "ознобивши": ["ознобив"],
    "ознобляв": ["озноблявши"],
    "озноблявши": ["ознобляв"],
    "озодшуда": ["растагор"],
    "озокерит": ["горный воск", "гумбед"],
    "озолагния": ["ренифлекс", "осфрезиофилия"],
    "озолотев": ["озолотевши"],
    "озолотевши": ["озолотев"],
    "озолотеть": ["озолотиться"],
    "озолотив": ["озолотивши"],
    "озолотивши": ["озолотив"],
    "озон": ["трикислород"],
    "озонизация": ["озонация", "озонирование"],
    "озонировав": ["озонировавши"],
    "озонировавши": ["озонировав"],
    "озонная дыра": ["озоновая дыра"],
    "озонный": ["озоновый"],
    "озоновая дыра": ["озонная дыра"],
    "озоновый": ["озонный"],
    "озоносфера": ["озоновый слой"],
    "озорник": ["шалун", "баловник", "бандит", "бедокур", "проказник", "сорванец"],
    "озорничав": ["озорничавши"],
    "озорничавши": ["озорничав"],
    "озорничание": ["озорство"],
    "озорничанье": ["озорничание"],
    "озорничать": ["шалить", "баловаться", "куролесить", "проказничать", "шкодить", "колобродить"],
    "озорно": ["шаловливо"],
    "озорной": ["скандальный", "буйный"],
    "озоровав": ["озоровавши"],
    "озоровавши": ["озоровав"],
    "озоровать": ["озорничать", "баловаться"],
    "озород": ["зарод"],
    "озорство": ["шалость", "баловство", "бесчинство", "хулиганство", "беспорядок"],
    "озрев": ["озревши"],
    "озревши": ["озрев"],
    "озу": ["мозги", "оператива", "оперативка", "память"],
    "озын": ["озак"],
    "озын бармак": ["урта бармак"],
    "озынборын": ["черки"],
    "озябав": ["озябавши"],
    "озябавши": ["озябав"],
    "озябать": ["зябнуть"],
    "озябнув": ["озябнувши"],
    "озябнувши": ["озябнув"],
    "озябнуть": ["замёрзнуть", "продрогнуть"],
    "озям": ["азям"],
    "ои": ["олимпийские игры", "олимпиада"],
    "оидий": ["оидиум"],
    "оидиум": ["мучнистая роса", "оидий"],
    "оила": ["хонавода"],
    "ой": ["ай", "мамочки", "ух"],
    "ой-йо": ["ё-моё", "ничего себе", "офигеть", "опупеть"],
    "ойкав": ["ойкавши"],
    "ойкавши": ["ойкав"],
    "ойкать": ["охать"],
    "ойкнув": ["ойкнувши"],
    "ойкнувши": ["ойкнув"],
    "ойконимикон": ["ойконимика", "ойконимия"],
    "ойконимия": ["ойконимика", "ойконимикон"],
    "ойкумена": ["экумена", "эйкумена"],
    "ойкуменический": ["эйкуменический", "экуменический"],
    "ойленшпигель": ["уленшпигель"],
    "ойрот": ["алтаец"],
    "ойтландер": ["уитлендер"],
    "ок": ["окей"],
    "ока": ["аха"],
    "окав": ["окавши"],
    "окавши": ["окав"],
    "оказав": ["оказавши"],
    "оказавши": ["оказав"],
    "оказать": ["произвести"],
    "оказаться": ["очутиться", "обнаружиться", "найтись", "проявиться"],
    "оказион": ["случай", "съвпадение"],
    "оказионализм": ["окказионализм"],
    "оказия": ["неожиданность", "случай", "происшествие", "неприятность", "несчастие", "беда"],
    "оказывав": ["оказывавши"],
    "оказывавши": ["оказывав"],
    "оказывать": ["осуществлять"],
    "оказываться": ["проявлять себя", "показывать себя", "попадать", "обнаруживаться", "находиться"],
    "оказёнив": ["оказёнивши"],
    "оказёнивав": ["оказёнивавши"],
    "оказёнивавши": ["оказёнивав"],
    "оказёнивши": ["оказёнив"],
    "окаймив": ["окаймивши"],
    "окаймивши": ["окаймив"],
    "окаймление": ["обрамление", "кайма", "окаёмка", "окантовка"],
    "окаймляв": ["окаймлявши"],
    "окаймлявши": ["окаймляв"],
    "окаймлять": ["окантовывать", "обводить", "каймить", "обрамлять"],
    "окалечив": ["окалечивши"],
    "окалечивши": ["окалечив"],
    "окалив": ["окаливши"],
    "окаливав": ["окаливавши"],
    "окаливавши": ["окаливав"],
    "окаливать": ["обкаливать"],
    "окаливши": ["окалив"],
    "окалить": ["обкалить"],
    "окалывав": ["окалывавши"],
    "окалывавши": ["окалывав"],
    "окаменев": ["окаменевши"],
    "окаменевав": ["окаменевавши"],
    "окаменевавши": ["окаменевав"],
    "окаменевать": ["каменеть"],
    "окаменевши": ["окаменев"],
    "окаменелый": ["неподвижный", "безжизненный", "окаменевший"],
    "окамененье": ["окаменение"],
    "окаменеть": ["закаменеть", "затвердеть", "одеревенеть", "отвердеть", "задеревенеть", "задубеть", "задубенеть", "замереть", "застыть", "остолбенеть", "оцепенеть", "затаить", "дыхание", "обмереть", "остановиться"],
    "окаменив": ["окаменивши"],
    "окаменивши": ["окаменив"],
    "окантовав": ["окантовавши"],
    "окантовавши": ["окантовав"],
    "окантовка": ["обрамление"],
    "окантовывав": ["окантовывавши"],
    "окантовывавши": ["окантовывав"],
    "оканчивав": ["оканчивавши"],
    "оканчивавши": ["оканчивав"],
    "оканчивать": ["завершать", "заканчивать", "кончать"],
    "оканчиваться": ["заканчиваться"],
    "оканчиваясь": ["завершаясь"],
    "окапав": ["окапавши"],
    "окапавши": ["окапав"],
    "окапать": ["обкапать"],
    "окапывав": ["окапывавши"],
    "окапывавши": ["окапывав"],
    "окапываться": ["обкапываться"],
    "окара": ["пульпа", "жмых"],
    "окараулив": ["окарауливши"],
    "окарауливав": ["окарауливавши"],
    "окарауливавши": ["окарауливав"],
    "окарауливши": ["окараулив"],
    "окарачь": ["на карачках", "на четвереньках"],
    "окарикатурив": ["окарикатуривши"],
    "окарикатуривав": ["окарикатуривавши"],
    "окарикатуривавши": ["окарикатуривав"],
    "окарикатуривши": ["окарикатурив"],
    "окармливав": ["окармливавши"],
    "окармливавши": ["окармливав"],
    "окатав": ["окатавши"],
    "окатавши": ["окатав"],
    "окатив": ["окативши"],
    "окативши": ["окатив"],
    "окатоличив": ["окатоличивши"],
    "окатоличивав": ["окатоличивавши"],
    "окатоличивавши": ["окатоличивав"],
    "окатоличивши": ["окатоличив"],
    "окатывав": ["окатывавши"],
    "окатывавши": ["окатывав"],
    "окатышевоз": ["вагон-хоппер"],
    "окачалка": ["закачалка"],
    "окачествив": ["окачествивши"],
    "окачествивши": ["окачествив"],
    "окачествляв": ["окачествлявши"],
    "окачествлявши": ["окачествляв"],
    "окачивав": ["окачивавши"],
    "окачивавши": ["окачивав"],
    "окашивав": ["окашивавши"],
    "окашивавши": ["окашивав"],
    "окаянний": ["безбожний"],
    "окаянный": ["проклятый", "безбожный", "греховный", "нечестивый", "нечистая сила", "бес", "чёрт"],
    "окаянствовав": ["окаянствовавши"],
    "окаянствовавши": ["окаянствовав"],
    "оквадратив": ["оквадративши"],
    "оквадративши": ["оквадратив"],
    "океан": ["нун", "египет", "океанес"],
    "океанавт": ["гидронавт", "акванавт"],
    "океанарий": ["океанариум"],
    "океанический": ["океанский"],
    "океания": ["австралия и океания"],
    "океановед": ["моревед", "океанолог", "океанограф"],
    "океанография": ["океанология"],
    "океанолог": ["моревед", "океановед", "океанограф"],
    "океанология": ["океанография"],
    "океанский": ["океанический"],
    "окенит": ["бордит", "дисклазит"],
    "океюшки": ["окей"],
    "окидав": ["окидавши"],
    "окидавши": ["окидав"],
    "окидывав": ["окидывавши"],
    "окидывавши": ["окидывав"],
    "окинув": ["окинувши"],
    "окинувши": ["окинув"],
    "окирковав": ["окирковавши"],
    "окирковавши": ["окирковав"],
    "окирковывав": ["окирковывавши"],
    "окирковывавши": ["окирковывав"],
    "окирпичивать": ["кирпичить", "убивать"],
    "окирпичить": ["убить"],
    "окисав": ["окисавши"],
    "окисавши": ["окисав"],
    "окисел": ["окись", "оксид"],
    "окисленный": ["оксидированный"],
    "окислив": ["окисливши"],
    "окисливши": ["окислив"],
    "окислитель": ["оксидант"],
    "окислительно-восстановительная реакция": ["редокс"],
    "окисляв": ["окислявши"],
    "окислявши": ["окисляв"],
    "окиснув": ["окиснувши"],
    "окиснувши": ["окиснув"],
    "окись": ["окисел", "оксид"],
    "окказионализм": ["окказиональное слово"],
    "окклюдировав": ["окклюдировавши"],
    "окклюдировавши": ["окклюдировав"],
    "окклюзировав": ["окклюзировавши"],
    "окклюзировавши": ["окклюзировав"],
    "оккультизм": ["эзотерика"],
    "оккультический": ["оккультистский"],
    "оккультный": ["сверхъестественный", "тайный", "мистический"],
    "оккупант": ["захватчик"],
    "оккупировав": ["оккупировавши"],
    "оккупировавши": ["оккупировав"],
    "оккупированный": ["захваченный"],
    "оклад": ["жалованье", "зарплата"],
    "окладчик": ["обкладчик"],
    "окладывав": ["окладывавши"],
    "окладывавши": ["окладывав"],
    "оклевав": ["оклевавши"],
    "оклевавши": ["оклевав"],
    "оклеветав": ["оклеветавши"],
    "оклеветавши": ["оклеветав"],
    "оклеив": ["оклеивши"],
    "оклеивав": ["оклеивавши"],
    "оклеивавши": ["оклеивав"],
    "оклеивать": ["обклеивать"],
    "оклеивши": ["оклеив"],
    "оклеить": ["обклеить"],
    "оклеймив": ["оклеймивши"],
    "оклеймивши": ["оклеймив"],
    "оклематься": ["выздороветь", "поправиться", "отудобеть", "очнуться", "очухаться", "выкрутиться", "выпутаться"],
    "оклик": ["окрик"],
    "окликав": ["окликавши"],
    "окликавши": ["окликав"],
    "окликнув": ["окликнувши"],
    "окликнувши": ["окликнув"],
    "окликнуть": ["позвать"],
    "оклёвывав": ["оклёвывавши"],
    "оклёвывавши": ["оклёвывав"],
    "окно": ["окошко", "касса", "вадья", "водья", "чаруса"],
    "око": ["глаз"],
    "оковав": ["оковавши"],
    "оковавши": ["оковав"],
    "оковувати": ["обковувати"],
    "оковы": ["кандалы", "цепи"],
    "оковывав": ["оковывавши"],
    "оковывавши": ["оковывав"],
    "околачивав": ["околачивавши"],
    "околачивавши": ["околачивав"],
    "околачивать": ["обивать", "оббивать", "повреждать", "ушибать", "портить", "трепаться", "почём зря", "трындеть", "обворовывать", "обкрадывать"],
    "околачиваться": ["ошиваться", "слоняться"],
    "околашиваться": ["выколашиваться", "околоситься"],
    "околдовав": ["околдовавши"],
    "околдовавши": ["околдовав"],
    "околдовать": ["заколдовать", "пленить", "очаровать"],
    "околдовывав": ["околдовывавши"],
    "околдовывавши": ["околдовывав"],
    "околдовывание": ["очарование"],
    "околдовывать": ["зачаровывать", "очаровывать", "обвораживать"],
    "околев": ["околевши"],
    "околевав": ["околевавши"],
    "околевавши": ["околевав"],
    "околевши": ["околев"],
    "околесив": ["околесивши"],
    "околесивши": ["околесив"],
    "околеть": ["умереть", "издохнуть", "сдохнуть", "замёрзнуть", "озябнуть", "застыть"],
    "околеть на смерть": ["околеть насмерть"],
    "околеть насмерть": ["околеть на смерть"],
    "околиця": ["край"],
    "околичность": ["околичнословие"],
    "околка": ["окалывание", "обкалывание", "обколка"],
    "около": ["при", "рядом с", "возле", "близко", "близ", "подле", "недалеко", "порядка", "приблизительно", "где-то"],
    "около-": ["при-", "квази-"],
    "околов": ["околовши"],
    "околоводный": ["прибрежный", "приморский"],
    "околовши": ["околов"],
    "окологлазничный": ["окологлазной"],
    "околодок": ["околоток"],
    "околоземной": ["околоземный"],
    "околомурманский": ["подмурманский", "примурманский"],
    "околонаучный": ["квазинаучный", "псевдонаучный"],
    "околонулевой": ["крошечный", "минимальный"],
    "околоплодник": ["перикарпий"],
    "околоплодный": ["амниотический"],
    "околополярный": ["циркумполярный"],
    "околопочечный": ["периренальный"],
    "околопрямокишечный": ["аноректальный"],
    "околоротовой": ["периоральный"],
    "околосветовой": ["субсветовой"],
    "околосердие": ["перикард"],
    "околоситься": ["околашиваться", "выколоситься"],
    "околот": ["околотина"],
    "околотив": ["околотивши"],
    "околотивши": ["околотив"],
    "околоток": ["местность", "окрестность", "округ", "округа", "сторона", "уголок", "район", "окраина", "околица", "пригород"],
    "околпачив": ["околпачивши"],
    "околпачивав": ["околпачивавши"],
    "околпачивавши": ["околпачивав"],
    "околпачивать": ["одурачивать", "обдуривать", "обводить вокруг пальца"],
    "околпачивши": ["околпачив"],
    "околпачить": ["одурачить"],
    "окольный": ["окрестный"],
    "окольцевав": ["окольцевавши"],
    "окольцевавши": ["окольцевав"],
    "окольцевать": ["опоясать", "обручить", "охомутать"],
    "окольцованный": ["окружённый", "охомутанный"],
    "окольцовывав": ["окольцовывавши"],
    "окольцовывавши": ["окольцовывав"],
    "окомпрометировав": ["окомпрометировавши"],
    "окомпрометировавши": ["окомпрометировав"],
    "оконечность": ["конец", "край", "конечность"],
    "оконечный": ["концевой"],
    "оконник": ["подоконник"],
    "оконопатив": ["оконопативши"],
    "оконопативши": ["оконопатив"],
    "оконопачивав": ["оконопачивавши"],
    "оконопачивавши": ["оконопачивав"],
    "оконопачивать": ["обконопачивать"],
    "оконтузив": ["оконтузивши"],
    "оконтузивши": ["оконтузив"],
    "оконтузить": ["контузить"],
    "оконтурив": ["оконтуривши"],
    "оконтуривав": ["оконтуривавши"],
    "оконтуривавши": ["оконтуривав"],
    "оконтуривши": ["оконтурив"],
    "оконфузив": ["оконфузивши"],
    "оконфузивши": ["оконфузив"],
    "оконцовка": ["окончание", "финал", "конец", "финиш", "эпилог", "оконцевание"],
    "окончанье": ["окончание"],
    "окончательно": ["окончательно и бесповоротно", "совсем", "совершенно", "полностью", "целиком и полностью", "в пух", "в пух и прах"],
    "окончательный": ["завершающий", "конечный", "финальный", "бесповоротный"],
    "окончать": ["подвести", "поставить", "точку", "заключить", "прекратить", "бросить", "кончить", "оставить", "покончить", "перестать", "завязать", "закрыть", "лавочку"],
    "окончив": ["окончивши"],
    "окончивши": ["окончив"],
    "окончить": ["закончить", "кончить", "завершить", "перестать", "прекратить", "выпуститься"],
    "окончиться": ["завершиться", "закончиться", "кончиться", "прийти к концу"],
    "окоп": ["траншея", "шанец"],
    "окопав": ["окопавши"],
    "окопавши": ["окопав"],
    "окопник": ["костолом", "виз-трава", "сальный корень", "живокост"],
    "окопница": ["окопщица"],
    "окоптев": ["окоптевши"],
    "окоптевши": ["окоптев"],
    "окоптеть": ["закоптеть"],
    "окопщица": ["окопница"],
    "окорачивав": ["окорачивавши"],
    "окорачивавши": ["окорачивав"],
    "окорачивать": ["урезонивать", "укрощать", "успокаивать"],
    "окорив": ["окоривши"],
    "окоривши": ["окорив"],
    "окорить": ["ошкурить"],
    "окормив": ["окормивши"],
    "окормивши": ["окормив"],
    "окормляв": ["окормлявши"],
    "окормлявши": ["окормляв"],
    "окорнав": ["окорнавши"],
    "окорнавши": ["окорнав"],
    "окороковый": ["окорочный"],
    "окоротив": ["окоротивши"],
    "окоротивши": ["окоротив"],
    "окорочок": ["окорок"],
    "окорябав": ["окорябавши"],
    "окорябавши": ["окорябав"],
    "окоряв": ["окорявши"],
    "окорявши": ["окоряв"],
    "окорёнок": ["кадка", "лоханка", "таз"],
    "окосев": ["окосевши"],
    "окосевши": ["окосев"],
    "окосив": ["окосивши"],
    "окосивши": ["окосив"],
    "окосматев": ["окосматевши"],
    "окосматевши": ["окосматев"],
    "окостенев": ["окостеневши"],
    "окостеневав": ["окостеневавши"],
    "окостеневавши": ["окостеневав"],
    "окостеневать": ["костенеть"],
    "окостеневши": ["окостенев"],
    "окостеневший": ["окостенелый"],
    "окостенение": ["остеогенез", "оссификация", "окостенелость"],
    "окостенеть": ["окоченеть", "закоченеть", "застыть"],
    "окостенив": ["окостенивши"],
    "окостенивши": ["окостенив"],
    "окосье": ["косовище"],
    "окотив": ["окотивши"],
    "окотивши": ["окотив"],
    "окотиться": ["принести"],
    "окоченев": ["окоченевши"],
    "окоченевав": ["окоченевавши"],
    "окоченевавши": ["окоченевав"],
    "окоченевши": ["окоченев"],
    "окочененье": ["окоченение"],
    "окоченеть": ["замёрзнуть", "закоченеть", "продрогнуть", "замереть", "оцепенеть", "окостенеть"],
    "окошечко": ["окошко"],
    "окошечный": ["оконный"],
    "окошко": ["окно", "оконце", "перерывчик"],
    "окоём": ["горизонт"],
    "окр": ["обсессивно-компульсивное расстройство", "невроз навязчивых состояний", "олимпийский комитет россии"],
    "окра": ["бамия", "гомбо", "дамские пальчики", "гибискус съедобный"],
    "окраина": ["край", "периферия"],
    "окраинный": ["периферийный"],
    "окрайка": ["крайка"],
    "окрас": ["окраска"],
    "окрасив": ["окрасивши"],
    "окрасивши": ["окрасив"],
    "окрасить": ["выкрасить"],
    "окраска": ["раскраска", "окрас", "расцветка", "покраска"],
    "окрашивав": ["окрашивавши"],
    "окрашивавши": ["окрашивав"],
    "окрашивать": ["красить"],
    "окрашивающий": ["красящий"],
    "окрепнув": ["окрепнувши"],
    "окрепнувши": ["окрепнув"],
    "окрест": ["вокруг", "поблизости"],
    "окрестив": ["окрестивши"],
    "окрестивши": ["окрестив"],
    "окрестить": ["назвать"],
    "окрестность": ["округа", "район"],
    "окрестный": ["близкий", "ближний", "недалёкий", "близлежащий"],
    "окривев": ["окривевши"],
    "окривевши": ["окривев"],
    "окривив": ["окрививши"],
    "окрививши": ["окривив"],
    "окрик": ["оклик"],
    "окрикивав": ["окрикивавши"],
    "окрикивавши": ["окрикивав"],
    "окрикнув": ["окрикнувши"],
    "окрикнувши": ["окрикнув"],
    "окрикнуть": ["окликнуть"],
    "окристаллизовав": ["окристаллизовавши"],
    "окристаллизовавши": ["окристаллизовав"],
    "окристаллизовывав": ["окристаллизовывавши"],
    "окристаллизовывавши": ["окристаллизовывав"],
    "окритиковав": ["окритиковавши"],
    "окритиковавши": ["окритиковав"],
    "окровавив": ["окровавивши"],
    "окровавивши": ["окровавив"],
    "окровавленный": ["обагрённый", "кровавый", "кровяной", "искровавленный"],
    "окровавливав": ["окровавливавши"],
    "окровавливавши": ["окровавливав"],
    "окровавляв": ["окровавлявши"],
    "окровавлявши": ["окровавляв"],
    "окровенев": ["окровеневши"],
    "окровеневши": ["окровенев"],
    "окровенив": ["окровенивши"],
    "окровенивши": ["окровенив"],
    "окрол": ["окот"],
    "окроме": ["окромя"],
    "окромсав": ["окромсавши"],
    "окромсавши": ["окромсав"],
    "окромя": ["кроме"],
    "окропив": ["окропивши"],
    "окропивши": ["окропив"],
    "окропить": ["сбрызнуть", "обрызгать"],
    "окропляв": ["окроплявши"],
    "окроплявши": ["окропляв"],
    "окроплять": ["кропить"],
    "окрошечка": ["окрошка"],
    "окрошив": ["окрошивши"],
    "окрошивши": ["окрошив"],
    "окрошить": ["обкрошить"],
    "окрошка": ["эклектика", "солянка"],
    "округа": ["окрестность"],
    "округлев": ["округлевши"],
    "округлевши": ["округлев"],
    "округление": ["закругление", "скругление", "округлость"],
    "округлив": ["округливши"],
    "округливши": ["округлив"],
    "округлить": ["скруглить"],
    "округлый": ["круглый", "плавный", "размеренный"],
    "округляв": ["округлявши"],
    "округлявши": ["округляв"],
    "округлённость": ["округлость"],
    "окружав": ["окружавши"],
    "окружавши": ["окружав"],
    "окружение": ["приближённые", "котёл", "кольцо", "осада", "антураж"],
    "окруженье": ["окружение"],
    "окружив": ["окруживши"],
    "окруживши": ["окружив"],
    "окружить": ["обступить", "обставить", "обнести"],
    "окружность": ["пирибола", "обхват", "периметр", "округа", "окрестность"],
    "окружье": ["окружие"],
    "окрутив": ["окрутивши"],
    "окрутивши": ["окрутив"],
    "окрутить": ["обмотать", "обвить", "обкрутить", "скрутить", "загнуть", "обхитрить", "окольцевать"],
    "окручивав": ["окручивавши"],
    "окручивавши": ["окручивав"],
    "окръг": ["област", "край", "район"],
    "окрылив": ["окрыливши"],
    "окрыливши": ["окрылив"],
    "окрылить": ["воодушевить", "вдохновить"],
    "окрыляв": ["окрылявши"],
    "окрылявши": ["окрыляв"],
    "окрылять": ["воодушевлять"],
    "оксамитовий": ["оксамитний"],
    "оксана": ["оксанка", "ксения"],
    "оксанка": ["оксана", "хохлушка"],
    "оксиальдегид": ["альдегидоспирт", "гидроксиальдегид"],
    "оксигемограф": ["оксиграф", "фотооксигемограф"],
    "оксигемометр": ["оксиметр", "фотооксигемометр"],
    "оксигемометрия": ["пульсоксиметрия"],
    "оксиген": ["кислотвор"],
    "оксигенотерапия": ["кислородотерапия"],
    "оксид никеля": ["окись никеля"],
    "оксид углерода": ["угарный газ", "углекислый газ"],
    "оксидант": ["окислитель"],
    "оксидация": ["окисление", "оксидирование"],
    "оксидировав": ["оксидировавши"],
    "оксидировавши": ["оксидировав"],
    "оксим": ["изонитрозосоединение"],
    "оксиметилен": ["формальдегид"],
    "оксиметр": ["термооксиметр"],
    "оксиморон": ["оксюморон"],
    "оксиморонный": ["оксюморонный"],
    "оксиморончик": ["оксюморончик"],
    "оксинон": ["антифлюс"],
    "окситанский": ["провансальский"],
    "окситональный": ["ямбический"],
    "окситонический": ["окситонный"],
    "окситоцин": ["питоцин", "гормон удовольствия", "гормон любви", "гормон счастья", "гормон привязанности"],
    "оксиуроз": ["энтеробиоз"],
    "оксия": ["акут", "острое ударение", "аксантегю"],
    "окснар": ["окончательно снаряжённый", "окснаренный"],
    "окснарив": ["окснаривши"],
    "окснаривав": ["окснаривавши"],
    "окснаривавши": ["окснаривав"],
    "окснаривши": ["окснарив"],
    "оксоний": ["гидроксоний", "гидроний"],
    "окстив": ["окстивши"],
    "окстивши": ["окстив"],
    "окстить": ["перекрестить", "окрестить"],
    "окститься": ["перекреститься", "опомниться", "одуматься", "успокоиться"],
    "оксюморон": ["оксиморон"],
    "оксюморонный": ["оксиморонный"],
    "оксюморончик": ["оксиморончик"],
    "окта-": ["восьми-"],
    "октавия": ["шкода-октавия"],
    "октагон": ["восьмиугольник"],
    "октаграмма": ["крестострел"],
    "октада": ["восьмёрка"],
    "октадный": ["восьмерной"],
    "октаедр": ["восьмигранник"],
    "октаконта-": ["восьмидесяти-"],
    "октален": ["альдрин"],
    "октант": ["октан", "квадрант хэдли", "гадлеев квадрант"],
    "октаэдр": ["восьмигранник"],
    "октаэдральный": ["октаэдрический"],
    "октаэдрит": ["сидерит"],
    "октеракт": ["гексадеказеттон"],
    "октоих": ["осмогласник", "осмогласие", "осьмогласие"],
    "октоторп": ["решётка", "хеш", "шарп"],
    "октроировав": ["октроировавши"],
    "октроировавши": ["октроировав"],
    "октябрины": ["красные крестины"],
    "октябрьская революция": ["октябрьский переворот"],
    "окул": ["мектеп"],
    "окулачив": ["окулачивши"],
    "окулачивши": ["окулачив"],
    "окулировав": ["окулировавши"],
    "окулировавши": ["окулировав"],
    "окулирование": ["окулировка"],
    "окулировка": ["окулирование"],
    "окулист": ["глазник", "офтальмолог"],
    "окулография": ["айтрекинг"],
    "окультивировав": ["окультивировавши"],
    "окультивировавши": ["окультивировав"],
    "окультурив": ["окультуривши"],
    "окультуривав": ["окультуривавши"],
    "окультуривавши": ["окультуривав"],
    "окультуривать": ["цивилизовывать"],
    "окультуривши": ["окультурив"],
    "окультурить": ["культивировать", "цивилизовать"],
    "окуляр": ["очки"],
    "окумал": ["сабаттуу", "зыялы", "интеллигент"],
    "окунав": ["окунавши"],
    "окунавши": ["окунав"],
    "окунать": ["макать"],
    "окуневый": ["окунёвый"],
    "окунув": ["окунувши"],
    "окунувши": ["окунув"],
    "окунь": ["речной окунь", "морской окунь"],
    "окунёвка": ["тарпанчи", "беши"],
    "окупав": ["окупавши"],
    "окупавши": ["окупав"],
    "окупив": ["окупивши"],
    "окупивши": ["окупив"],
    "окупиться": ["возместиться", "дать плоды"],
    "окупывав": ["окупывавши"],
    "окупывавши": ["окупывав"],
    "окургузив": ["окургузивши"],
    "окургузивши": ["окургузив"],
    "окургузить": ["обкургузить"],
    "окургузиться": ["обкургузиться"],
    "окурив": ["окуривши"],
    "окуривав": ["окуривавши"],
    "окуривавши": ["окуривав"],
    "окуривши": ["окурив"],
    "окурочек": ["недокурочек"],
    "окутав": ["окутавши"],
    "окутавши": ["окутав"],
    "окутуучу": ["мугалим"],
    "окутывав": ["окутывавши"],
    "окутывавши": ["окутывав"],
    "окутывать": ["кутать", "обволакивать", "обступать"],
    "окучив": ["окучивши"],
    "окучивав": ["окучивавши"],
    "окучивавши": ["окучивав"],
    "окучивать": ["обхаживать"],
    "окучивать капусту": ["варить капусту", "много", "рубить капусту"],
    "окучивши": ["окучив"],
    "окциденталь": ["оксиденталь", "интерлингве"],
    "окципитальный": ["затылочный"],
    "окъ": ["ок"],
    "олаберный": ["бестолковый", "косноязычный", "своеобразный"],
    "оладий": ["оладья"],
    "оладушек": ["оладушка"],
    "оладушка": ["оладушек"],
    "олаф": ["олуф", "олав", "улав", "улуф", "улаф", "улоф"],
    "олдовый": ["старый"],
    "олдскульный": ["стародавний", "устарелый", "старомодный", "ветхозаветный"],
    "олдтаймер": ["старинный", "автомобиль", "классический"],
    "олеандр": ["лавророза"],
    "оледенев": ["оледеневши"],
    "оледеневав": ["оледеневавши"],
    "оледеневавши": ["оледеневав"],
    "оледеневать": ["леденеть"],
    "оледеневши": ["оледенев"],
    "оледенелость": ["оледенение"],
    "оледенение": ["оледенелость", "обледенение"],
    "оледененье": ["оледенение"],
    "оледенеть": ["оледянеть"],
    "оледенив": ["оледенивши"],
    "оледенивши": ["оледенив"],
    "оледеняв": ["оледенявши"],
    "оледенявши": ["оледеняв"],
    "оледянев": ["оледяневши"],
    "оледяневать": ["оледеневать"],
    "оледяневши": ["оледянев"],
    "оледянеть": ["оледенеть"],
    "оледянив": ["оледянивши"],
    "оледянивши": ["оледянив"],
    "олей": ["олея"],
    "олелия": ["шум", "глъч", "врява", "писък", "гюрултия"],
    "оленегонка": ["ненецкая лайка", "оленегонная лайка"],
    "олениха": ["ланка"],
    "оленуха": ["олениха"],
    "олень": ["лопух", "простак"],
    "олеографичный": ["приукрашенный"],
    "олеография": ["лубок"],
    "олеофильный": ["гидрофобный"],
    "олеофобный": ["жироотталкивающий", "маслоотталкивающий", "гидрофильный"],
    "олефин": ["алкен"],
    "олечка": ["оленька"],
    "олешник": ["олешняк", "ольшаник", "ольшатник"],
    "олея": ["олей"],
    "олива": ["оливка"],
    "оливин": ["перидот"],
    "оливка": ["олива", "маслина"],
    "оливье": ["зимний салат", "русский салат"],
    "олигарх": ["магнат", "олигархер"],
    "олигархат": ["олигархия"],
    "олигархия": ["плутократия", "плутократ"],
    "олигемия": ["гиповолемия"],
    "олиголецитальный": ["алецитальный"],
    "олигоспермия": ["гипоспермия", "гиповолюмия"],
    "олигоурия": ["олигурия"],
    "олигофрен": ["дурак", "тупица", "недоумок", "недоразвитый"],
    "олигофрения": ["малоумие"],
    "олигоцитемия": ["олигоцитоз"],
    "олигошизофрения": ["пфропфшизофрения"],
    "олигурия": ["олигоурия"],
    "олимпиада": ["олимпийские игры", "соревнование", "состязание"],
    "олимпийские игры": ["олимпиада"],
    "олитературив": ["олитературивши"],
    "олитературивав": ["олитературивавши"],
    "олитературивавши": ["олитературивав"],
    "олитературивши": ["олитературив"],
    "олифив": ["олифивши"],
    "олифивши": ["олифив"],
    "олифный": ["олифовый"],
    "олифовый": ["олифный"],
    "олицетворение": ["воплощение", "персонификация", "прозопопея"],
    "олицетворив": ["олицетворивши"],
    "олицетворивши": ["олицетворив"],
    "олицетворяв": ["олицетворявши"],
    "олицетворявши": ["олицетворяв"],
    "олл-ин": ["ва-банк", "пуш"],
    "оловоносный": ["оловосодержащий"],
    "ологичивав": ["ологичивавши"],
    "ологичивавши": ["ологичивав"],
    "олорифма": ["панторифма", "панторим"],
    "олуболу": ["караз"],
    "олух": ["балбес", "балда", "болван", "глупец", "дурак", "дуралей", "дурачина", "дурень", "идиот", "остолоп", "простак", "простофиля", "разиня", "растяпа", "ротозей"],
    "олька": ["оля"],
    "ольстер": ["северная ирландия"],
    "ольфакторный": ["обонятельный"],
    "ольха": ["ёлха"],
    "ольховник": ["ольшаник", "ольшняк"],
    "ольшаник": ["ольховник", "ольшняк"],
    "ольшняк": ["ольшаник", "ольховник"],
    "олютор": ["коряк", "олюторец"],
    "олютора": ["уйулен"],
    "оляпав": ["оляпавши"],
    "оляпавши": ["оляпав"],
    "оляпка": ["водяной воробей"],
    "олёна": ["елена"],
    "омагнитив": ["омагнитивши"],
    "омагнитивши": ["омагнитив"],
    "омагничивав": ["омагничивавши"],
    "омагничивавши": ["омагничивав"],
    "омайница": ["чародейка", "вълшебница", "магьосница", "хубавица", "красавица"],
    "оман": ["султанат оман"],
    "омар": ["лобстер"],
    "омахивав": ["омахивавши"],
    "омахивавши": ["омахивав"],
    "омахнув": ["омахнувши"],
    "омахнувши": ["омахнув"],
    "омачивав": ["омачивавши"],
    "омачивавши": ["омачивав"],
    "омачивать": ["обмачивать"],
    "омба": ["омбоце"],
    "омба масторс": ["лия масторс"],
    "омба масторса": ["лия масторса"],
    "омбоце": ["омба"],
    "омбоцеда": ["оду-васу"],
    "омбраж": ["сомнение", "подозрение", "недоверие", "суспиция"],
    "омбрела": ["чадър"],
    "омеблировав": ["омеблировавши"],
    "омеблировавши": ["омеблировав"],
    "омеблировывав": ["омеблировывавши"],
    "омеблировывавши": ["омеблировывав"],
    "омеблировывать": ["обмеблировывать"],
    "омег": ["болиголов", "омежник"],
    "омеднив": ["омеднивши"],
    "омеднивши": ["омеднив"],
    "омедняв": ["омеднявши"],
    "омеднявши": ["омедняв"],
    "омелев": ["омелевши"],
    "омелевши": ["омелев"],
    "омерзев": ["омерзевши"],
    "омерзевши": ["омерзев"],
    "омерзение": ["отвращение", "гадливость"],
    "омерзив": ["омерзивши"],
    "омерзивши": ["омерзив"],
    "омерзительно": ["мерзко", "отвратительно"],
    "омерзительный": ["отвратительный", "мерзкий", "гнусный"],
    "омерзить": ["изгадить", "опаскудить"],
    "омерта": ["кодекс молчания", "закон молчания", "обет молчания", "круговая порука"],
    "омертвев": ["омертвевши"],
    "омертвевав": ["омертвевавши"],
    "омертвевавши": ["омертвевав"],
    "омертвевши": ["омертвев"],
    "омертвение": ["омертвенье", "некроз"],
    "омертвенье": ["омертвение", "некроз"],
    "омертветь": ["отмереть"],
    "омертвив": ["омертвивши"],
    "омертвивши": ["омертвив"],
    "омертвляв": ["омертвлявши"],
    "омертвлявши": ["омертвляв"],
    "омехта": ["халит"],
    "омехтан": ["шебидан"],
    "омещанив": ["омещанивши"],
    "омещанивав": ["омещанивавши"],
    "омещанивавши": ["омещанивав"],
    "омещанивши": ["омещанив"],
    "омещаниться": ["обмещаниться"],
    "омикрон-вариант": ["омикрон-штамм"],
    "омикрон-штамм": ["омикрон-вариант"],
    "оминав": ["оминавши"],
    "оминавши": ["оминав"],
    "омич": ["омец", "омчанин"],
    "омлет": ["минет"],
    "оммаж": ["гоминиум", "коммендация", "вассальство"],
    "омнипотентность": ["всемогущество", "универсальность"],
    "омнипотенциальный": ["омнипотентный", "всемогущий"],
    "омовение": ["умывание", "обмывание", "мытьё"],
    "омовенье": ["омовение"],
    "омографический": ["омографичный"],
    "омографичный": ["омографический"],
    "омозолев": ["омозолевши"],
    "омозолевши": ["омозолев"],
    "омолаживав": ["омолаживавши"],
    "омолаживавши": ["омолаживав"],
    "омолаживаться": ["молодеть"],
    "омологировав": ["омологировавши"],
    "омологировавши": ["омологировав"],
    "омолодив": ["омолодивши"],
    "омолодивши": ["омолодив"],
    "омолодиться": ["помолодеть"],
    "омоложав": ["омоложавши"],
    "омоложавши": ["омоложав"],
    "омон": ["собр"],
    "оморгар": ["оморшинос"],
    "оморочка": ["омороча"],
    "оморшинос": ["оморгар"],
    "оморячив": ["оморячивши"],
    "оморячивши": ["оморячив"],
    "омофор": ["нараменник", "нарамник", "омофорий", "амофор"],
    "омочив": ["омочивши"],
    "омочивши": ["омочив"],
    "омп": ["оружие массового поражения", "оружие массового уничтожения"],
    "омрачав": ["омрачавши"],
    "омрачавши": ["омрачав"],
    "омрачать": ["застить", "затенять"],
    "омраченье": ["омрачение"],
    "омрачив": ["омрачивши"],
    "омрачивши": ["омрачив"],
    "омрачнев": ["омрачневши"],
    "омрачневши": ["омрачнев"],
    "омс": ["обязательное медицинское страхование"],
    "омузыкалив": ["омузыкаливши"],
    "омузыкаливав": ["омузыкаливавши"],
    "омузыкаливавши": ["омузыкаливав"],
    "омузыкаливши": ["омузыкалив"],
    "омуль": ["арктический омуль"],
    "омут": ["водоворот", "быстрина", "трясина"],
    "омутина": ["омутище"],
    "омутище": ["омутина"],
    "омшаник": ["зимовник", "половень"],
    "омыв": ["омывши"],
    "омывав": ["омывавши"],
    "омывавши": ["омывав"],
    "омывши": ["омыв"],
    "омыление": ["омыливание", "сапонификация", "омыленье"],
    "омылив": ["омыливши"],
    "омыливание": ["омыление", "сапонификация"],
    "омыливши": ["омылив"],
    "омылить": ["обмылить"],
    "омыляв": ["омылявши"],
    "омылявши": ["омыляв"],
    "омэт": ["нинсоаре"],
    "омяв": ["омявши"],
    "омявши": ["омяв"],
    "омёт": ["стог", "кайма", "кант"],
    "онанировав": ["онанировавши"],
    "онанировавши": ["онанировав"],
    "онанист": ["мастурбатор", "дрочун", "дрочер", "дон-дрочила", "зодрыч"],
    "онаучив": ["онаучивши"],
    "онаучивши": ["онаучив"],
    "ондатра": ["мускусная крыса"],
    "ондюляция": ["изгиб", "укладка", "завивка"],
    "онега": ["онег", "онежское озеро", "онего"],
    "онего": ["онежское озеро"],
    "онежское озеро": ["онега", "онего"],
    "онемев": ["онемевши"],
    "онемевав": ["онемевавши"],
    "онемевавши": ["онемевав"],
    "онемевать": ["неметь"],
    "онемевши": ["онемев"],
    "онеменье": ["онемение"],
    "онемечение": ["онемечивание"],
    "онемечив": ["онемечивши"],
    "онемечивав": ["онемечивавши"],
    "онемечивавши": ["онемечивав"],
    "онемечивание": ["онемечение"],
    "онемечивши": ["онемечив"],
    "оник": ["он", "кружок", "кругляшок", "колечко", "нолик", "нулик", "ноль", "нуль", "ук"],
    "оним": ["имя собственное"],
    "онимизация": ["ономастическая конверсия"],
    "онихия": ["онихоз"],
    "онкогенез": ["бластомогенез", "канцерогенез"],
    "онкогенность": ["канцерогенность"],
    "онкогенный": ["канцерогенный"],
    "онкология": ["рак"],
    "онлайн-бизнес": ["интернет-бизнес"],
    "онлайн-брокер": ["интернет-брокер"],
    "онлайн-версия": ["веб-версия", "интернет-версия"],
    "онлайн-видео": ["интернет-видео"],
    "онлайн-издание": ["веб-издание", "интернет-издание"],
    "онлайн-казино": ["интернет-казино"],
    "онлайн-коммерция": ["интернет-коммерция"],
    "онлайн-конференция": ["веб-конференция", "интернет-конференция"],
    "онлайн-магазин": ["интернет-магазин"],
    "онлайн-опрос": ["интернет-опрос"],
    "онлайн-порно": ["стриминговое порно"],
    "онлайн-приложение": ["веб-приложение"],
    "онлайн-проект": ["веб-проект", "интернет-проект"],
    "онлайн-реклама": ["интернет-реклама"],
    "онлайн-ресурс": ["веб-ресурс", "интернет-ресурс"],
    "онлайн-ретейлер": ["интернет-ретейлер"],
    "онлайн-система": ["веб-система", "интернет-система"],
    "онлайн-служба": ["веб-служба"],
    "онлайн-торговля": ["интернет-торговля"],
    "онлайн-травля": ["интернет-травля", "кибербуллинг", "кибертравля"],
    "онлайн-услуга": ["интернет-услуга"],
    "онмёдзи": ["оммёдзи"],
    "оногдысь": ["недавно", "днями", "на днях", "давеча", "намедни", "надысь", "давыча", "намеднись", "ономедни", "ономнясь"],
    "ономастика": ["ономатология", "ономастикон"],
    "ономатодоксия": ["имяславие", "имябожничество", "имябожие"],
    "ономатология": ["ономастика"],
    "ономатопеический": ["звукоподражательный", "ономатопоэтический"],
    "ономатопея": ["звукоподражание"],
    "ономнясь": ["недавно", "на днях", "намедни", "давеча", "надысь", "ономедни"],
    "онтогенез": ["развитие", "путь", "жизнь"],
    "онтогенезис": ["онтогенез"],
    "онтогенезный": ["онтогенетический"],
    "онтогенетический": ["онтогенезный"],
    "онтологизация": ["онтологизирование"],
    "онтологизировав": ["онтологизировавши"],
    "онтологизировавши": ["онтологизировав"],
    "онтологизировать": ["объективировать"],
    "онурис": ["анхур", "анхар", "инхар"],
    "онуча": ["портянка", "чулок", "носок"],
    "оный": ["тот", "другой", "противоположный", "потусторонний", "загробный", "отдалённый", "незапамятный"],
    "оогенез": ["овогенез"],
    "оолонг": ["улун"],
    "ооо": ["общество с ограниченной ответственностью"],
    "оп": ["общественная палата", "общественная палатка", "отрасль права", "офис президента"],
    "опа": ["ба", "оп"],
    "опадав": ["опадавши"],
    "опадавши": ["опадав"],
    "опаданье": ["опадание"],
    "опадыш": ["паданец", "паданка", "падалица"],
    "опаздывав": ["опаздывавши"],
    "опаздывавши": ["опаздывав"],
    "опаздывать": ["запаздывать", "задерживаться", "отставать"],
    "опаивав": ["опаивавши"],
    "опаивавши": ["опаивав"],
    "опала": ["немилость", "репрессия", "гонение", "нерасположение", "нелюбовь"],
    "опалесцировав": ["опалесцировавши"],
    "опалесцировавши": ["опалесцировав"],
    "опалив": ["опаливши"],
    "опаливав": ["опаливавши"],
    "опаливавши": ["опаливав"],
    "опаливши": ["опалив"],
    "опаловый": ["молочно-голубой"],
    "опалубив": ["опалубивши"],
    "опалубивши": ["опалубив"],
    "опалывав": ["опалывавши"],
    "опалывавши": ["опалывав"],
    "опалый": ["похудевший", "осунувшийся", "опавший"],
    "опаляв": ["опалявши"],
    "опалявши": ["опаляв"],
    "опамятоваться": ["опомниться", "прийти в чувство", "прийти в себя"],
    "опаньки": ["оба-на", "оп-па", "вот те на", "вот те раз", "вот тебе на", "вот тебе раз", "во как", "мать честная", "поди ж ты"],
    "опарив": ["опаривши"],
    "опаривав": ["опаривавши"],
    "опаривавши": ["опаривав"],
    "опаривши": ["опарив"],
    "опарка": ["опара"],
    "опарник": ["опарница"],
    "опарница": ["опарник", "квашня"],
    "опаршивев": ["опаршивевши"],
    "опаршивевши": ["опаршивев"],
    "опаршивив": ["опаршививши"],
    "опаршививши": ["опаршивив"],
    "опарывав": ["опарывавши"],
    "опарывавши": ["опарывав"],
    "опарыш": ["живчик", "трефы", "ничтожество", "негодяй", "подонок", "крыса"],
    "опас": ["охрана", "опека", "заступничество", "покровительство"],
    "опасаться": ["бояться", "пугаться", "страшиться", "трусить", "дрейфить", "робеть"],
    "опасение": ["подозрение", "беспокойство", "страх", "опаска"],
    "опасенье": ["опасение"],
    "опаскудев": ["опаскудевши"],
    "опаскудевши": ["опаскудев"],
    "опаскудив": ["опаскудивши"],
    "опаскудивши": ["опаскудив"],
    "опасливо": ["с опасением", "боязливо", "несмело", "осторожно", "робко"],
    "опасная бритва": ["опаска"],
    "опасно": ["рискованно"],
    "опасное химическое вещество": ["охв"],
    "опасность": ["угроза"],
    "опатия": ["аббация"],
    "опахав": ["опахавши"],
    "опахавши": ["опахав"],
    "опахало": ["веер", "рипида"],
    "опахать": ["обпахать", "оборать"],
    "опахивав": ["опахивавши"],
    "опахивавши": ["опахивав"],
    "опахиванье": ["опахивание"],
    "опахнув": ["опахнувши"],
    "опахнувши": ["опахнув"],
    "опачкав": ["опачкавши"],
    "опачкавши": ["опачкав"],
    "опаяв": ["опаявши"],
    "опаявши": ["опаяв"],
    "опев": ["опевши"],
    "опевав": ["опевавши"],
    "опевавши": ["опевав"],
    "опевши": ["опев"],
    "опездал": ["разгильдяй", "придурок", "дурак", "дебил", "апездал", "глупиздень", "опездолочь", "распездал", "размазня", "нытик", "бестолочь"],
    "опездол": ["мудень", "опездл", "остопездол"],
    "опека": ["опекание", "присмотр", "попечительство", "шефство", "опекун", "покровительство"],
    "опекав": ["опекавши"],
    "опекавши": ["опекав"],
    "опекун": ["попечитель"],
    "опекунствовав": ["опекунствовавши"],
    "опекунствовавши": ["опекунствовав"],
    "опеленав": ["опеленавши"],
    "опеленавши": ["опеленав"],
    "опен": ["открытый", "чемпионат", "турнир"],
    "опенив": ["опенивши"],
    "опенивши": ["опенив"],
    "опенинг": ["интро"],
    "опенспейс": ["опен-офис"],
    "опеняв": ["опенявши"],
    "опенявши": ["опеняв"],
    "опер": ["оперативник"],
    "оперативник": ["опер"],
    "оперативно-разыскной": ["оперативно-розыскной"],
    "оперативно-розыскной": ["оперативно-разыскной"],
    "оперативно-тактический ракетный комплекс": ["отрк"],
    "оперативный": ["операционный", "непосредственный", "быстрый", "своевременный"],
    "оператор": ["хирург"],
    "операционка": ["ось"],
    "операционная система": ["ос", "операционка", "ось"],
    "опердень": ["операционный день"],
    "оперев": ["опёрши"],
    "опередивши": ["опередив"],
    "опережав": ["опережавши"],
    "опережавши": ["опережав"],
    "опережать": ["обгонять"],
    "опереженье": ["опережение"],
    "опереживав": ["опереживавши"],
    "опереживавши": ["опереживав"],
    "оперение": ["оперенье"],
    "опереточный": ["шутовской"],
    "опереться": ["положиться"],
    "оперив": ["оперивши"],
    "оперивши": ["оперив"],
    "оперировав": ["оперировавши"],
    "оперировавши": ["оперировав"],
    "оперяв": ["оперявши"],
    "оперявши": ["оперяв"],
    "опечаленный": ["огорчённый"],
    "опечалив": ["опечаливши"],
    "опечаливав": ["опечаливавши"],
    "опечаливавши": ["опечаливав"],
    "опечаливши": ["опечалив"],
    "опечалить": ["огорчить", "расстроить", "разочаровать"],
    "опечатав": ["опечатавши"],
    "опечатавши": ["опечатав"],
    "опечатывав": ["опечатывавши"],
    "опечатывавши": ["опечатывав"],
    "опешив": ["опешивши"],
    "опешивши": ["опешив"],
    "опешить": ["оторопеть"],
    "опи": ["упи"],
    "опив": ["опивши"],
    "опивав": ["опивавши"],
    "опивавши": ["опивав"],
    "опивши": ["опив"],
    "опидорасив": ["опидорасивши"],
    "опидорасивши": ["опидорасив"],
    "опидорев": ["опидоревши"],
    "опидоревши": ["опидорев"],
    "опидореть": ["обнаглеть", "офигеть", "охуеть"],
    "опизденев": ["опизденевши"],
    "опизденевав": ["опизденевавши"],
    "опизденевавши": ["опизденевав"],
    "опизденевать": ["офигевать", "обалдевать"],
    "опизденевши": ["опизденев"],
    "опизденеть": ["офигеть", "охуеть"],
    "опизденительность": ["замечательность", "великолепность", "восхитительность", "изумительность", "офигительность", "офигенность", "охренительность", "охеренность", "невъебенность", "охуительность", "охуетительность", "охуенность", "пиздатость"],
    "опиздохуительный": ["охуенный", "охуительный", "пиздатый"],
    "опиздюлив": ["опиздюливши"],
    "опиздюливав": ["опиздюливавши"],
    "опиздюливавши": ["опиздюливав"],
    "опиздюливаемый": ["избиваемый"],
    "опиздюливши": ["опиздюлив"],
    "опиздюлиться": ["отхватить пиздюлей", "получить пиздюлей", "отпиздиться"],
    "опий": ["опиум"],
    "опий-сырец": ["ханка"],
    "опилив": ["опиливши"],
    "опиливав": ["опиливавши"],
    "опиливавши": ["опиливав"],
    "опиливши": ["опилив"],
    "опиния": ["мнение", "суждение"],
    "опирав": ["опиравши"],
    "опиравши": ["опирав"],
    "опираться": ["упираться", "базироваться", "основываться"],
    "опираясь": ["облокачиваясь"],
    "описав": ["описавши"],
    "описавши": ["описав"],
    "описанный": ["упомянутый", "рассказанный", "рассмотренный", "представленный"],
    "описать": ["изобразить", "обрисовать"],
    "описаться": ["обмочиться", "обоссаться"],
    "описка": ["опечатка"],
    "опистодом": ["опистодомос", "описфодом"],
    "опистоконт": ["заднежгутиковый"],
    "опистосома": ["брюшко"],
    "описывав": ["описывавши"],
    "описывавши": ["описывав"],
    "опись": ["инвентаризация"],
    "опиться": ["обпиться"],
    "опиум": ["опий", "опиуха"],
    "опиумный": ["опийный"],
    "оплавив": ["оплавивши"],
    "оплавивши": ["оплавив"],
    "оплавливав": ["оплавливавши"],
    "оплавливавши": ["оплавливав"],
    "оплавляв": ["оплавлявши"],
    "оплавлявши": ["оплавляв"],
    "оплакав": ["оплакавши"],
    "оплакавши": ["оплакав"],
    "оплакивав": ["оплакивавши"],
    "оплакивавши": ["оплакивав"],
    "оплакиванье": ["оплакивание"],
    "оплакивать": ["плакать", "сожалеть", "кручиниться"],
    "оплата": ["платёж", "уплата", "плата"],
    "оплатив": ["оплативши"],
    "оплативши": ["оплатив"],
    "оплатить": ["заплатить", "уплатить", "расплатиться"],
    "оплачивав": ["оплачивавши"],
    "оплачивавши": ["оплачивав"],
    "оплевав": ["оплевавши"],
    "оплевавши": ["оплевав"],
    "оплескав": ["оплескавши"],
    "оплескавши": ["оплескав"],
    "оплески": ["аплодисменти"],
    "оплеснув": ["оплеснувши"],
    "оплеснувши": ["оплеснув"],
    "оплетав": ["оплетавши"],
    "оплетавши": ["оплетав"],
    "оплеуха": ["пощёчина", "затрещина"],
    "оплечье": ["бармы"],
    "оплешивев": ["оплешивевши"],
    "оплешивевши": ["оплешивев"],
    "оплешивив": ["оплешививши"],
    "оплешививши": ["оплешивив"],
    "оплодотворение": ["амфимиксис", "сингамия"],
    "оплодотворенье": ["оплодотворение"],
    "оплодотворив": ["оплодотворивши"],
    "оплодотворивши": ["оплодотворив"],
    "оплодотворяв": ["оплодотворявши"],
    "оплодотворявши": ["оплодотворяв"],
    "опломбировав": ["опломбировавши"],
    "опломбировавши": ["опломбировав"],
    "опломбировывав": ["опломбировывавши"],
    "опломбировывавши": ["опломбировывав"],
    "оплот": ["цитадель", "крепость", "опора", "прибежище"],
    "оплотнев": ["оплотневши"],
    "оплотневши": ["оплотнев"],
    "оплошав": ["оплошавши"],
    "оплошавши": ["оплошав"],
    "оплошность": ["ошибочность", "ошибка", "промах", "промашка", "просчёт", "недосмотр", "упущение"],
    "оплывав": ["оплывавши"],
    "оплывавши": ["оплывав"],
    "оплывши": ["оплыв"],
    "опля": ["гопля"],
    "оплёвывав": ["оплёвывавши"],
    "оплёвывавши": ["оплёвывав"],
    "оплёскивав": ["оплёскивавши"],
    "оплёскивавши": ["оплёскивав"],
    "оповестив": ["оповестивши"],
    "оповестивши": ["оповестив"],
    "оповестить": ["известить", "уведомить"],
    "оповещав": ["оповещавши"],
    "оповещавши": ["оповещав"],
    "оповещатель": ["извещатель"],
    "оповещать": ["сообщать", "извещать", "уведомлять", "осведомлять", "заявлять", "объявлять"],
    "оповещение": ["оповещенье"],
    "оповещенье": ["оповещение"],
    "опоганив": ["опоганивши"],
    "опоганивав": ["опоганивавши"],
    "опоганивавши": ["опоганивав"],
    "опоганивши": ["опоганив"],
    "оподзолив": ["оподзоливши"],
    "оподзоливав": ["оподзоливавши"],
    "оподзоливавши": ["оподзоливав"],
    "оподзоливание": ["подзолообразование"],
    "оподзоливши": ["оподзолив"],
    "оподлев": ["оподлевши"],
    "оподлевши": ["оподлев"],
    "оподлив": ["оподливши"],
    "оподливав": ["оподливавши"],
    "оподливавши": ["оподливав"],
    "оподливши": ["оподлив"],
    "оподляв": ["оподлявши"],
    "оподлявши": ["оподляв"],
    "опоек": ["сосунок"],
    "опоздав": ["опоздавши"],
    "опоздавши": ["опоздав"],
    "опозданье": ["опоздание"],
    "опоздать": ["запоздать", "задержаться", "припоздниться", "проспать"],
    "опоздун": ["опоздавший", "опозданец"],
    "опознав": ["опознавши"],
    "опознавав": ["опознававши"],
    "опознававши": ["опознавав"],
    "опознавание": ["распознавание", "аутентификация", "опознание"],
    "опознавши": ["опознав"],
    "опознание": ["узнавание", "распознавание", "опознавание", "установление"],
    "опознать": ["распознать", "узнать", "идентифицировать", "установить"],
    "опозоренный": ["опороченный", "обесчещенный"],
    "опозорив": ["опозоривши"],
    "опозоривши": ["опозорив"],
    "опозорить": ["опорочить", "обесчестить", "скомпрометировать"],
    "опоив": ["опоивши"],
    "опоивши": ["опоив"],
    "опоковый": ["опочный"],
    "ополаскивав": ["ополаскивавши"],
    "ополаскивавши": ["ополаскивав"],
    "ополаскивать": ["оплёскивать", "всполаскивать", "споласкивать"],
    "оползав": ["оползавши"],
    "оползавши": ["оползав"],
    "ополов": ["ополовши"],
    "ополовиненный": ["уполовиненный", "отполовиненный", "переполовиненный"],
    "ополовинив": ["ополовинивши"],
    "ополовинивав": ["ополовинивавши"],
    "ополовинивавши": ["ополовинивав"],
    "ополовинивши": ["ополовинив"],
    "ополовник": ["длиннохвостая синица"],
    "ополовши": ["ополов"],
    "ополонив": ["ополонивши"],
    "ополонивши": ["ополонив"],
    "ополоник": ["черпак", "полоник", "пуголовок"],
    "ополоскав": ["ополоскавши"],
    "ополоскавши": ["ополоскав"],
    "ополоснув": ["ополоснувши"],
    "ополоснувши": ["ополоснув"],
    "ополоумев": ["ополоумевши"],
    "ополоумевши": ["ополоумев"],
    "ополоуметь": ["обезуметь"],
    "ополчав": ["ополчавши"],
    "ополчавши": ["ополчав"],
    "ополченье": ["ополчение"],
    "ополчив": ["ополчивши"],
    "ополчивши": ["ополчив"],
    "ополячив": ["ополячивши"],
    "ополячивав": ["ополячивавши"],
    "ополячивавши": ["ополячивав"],
    "ополячивши": ["ополячив"],
    "опомниться": ["очнуться", "прийти в сознание", "прийти в себя", "собраться с мыслями", "оправиться", "одуматься", "образумиться"],
    "опопсев": ["опопсевши"],
    "опопсевши": ["опопсев"],
    "опоражнивав": ["опоражнивавши"],
    "опоражнивавши": ["опоражнивав"],
    "опоражнивание": ["опорожнение"],
    "опоражнивать": ["опорожнять", "опустошать"],
    "опорачивав": ["опорачивавши"],
    "опорачивавши": ["опорачивав"],
    "опоров": ["опоровши"],
    "опоровши": ["опоров"],
    "опорожнение": ["опоражнивание", "опустошение"],
    "опорожнив": ["опорожнивши"],
    "опорожнивши": ["опорожнив"],
    "опорожнить": ["опустошить"],
    "опорожняв": ["опорожнявши"],
    "опорожнявши": ["опорожняв"],
    "опорожнять": ["опоражнивать", "опустошать"],
    "опорожняться": ["опоражниваться"],
    "опорок": ["опорка"],
    "опоросив": ["опоросивши"],
    "опоросивши": ["опоросив"],
    "опорочив": ["опорочивши"],
    "опорочивав": ["опорочивавши"],
    "опорочивавши": ["опорочивав"],
    "опорочивание": ["опорочение"],
    "опорочивши": ["опорочив"],
    "опорочить": ["очернить", "опозорить"],
    "опорошив": ["опорошивши"],
    "опорошивши": ["опорошив"],
    "опосля": ["после", "потом"],
    "опосредовав": ["опосредовавши"],
    "опосредовавши": ["опосредовав"],
    "опосредование": ["опосредствование"],
    "опосредованно": ["косвенно"],
    "опосредованность": ["опосредствование"],
    "опосредованный": ["непрямой", "косвенный"],
    "опосредовать": ["опосредствовать"],
    "опосредствовав": ["опосредствовавши"],
    "опосредствовавши": ["опосредствовав"],
    "опоссум": ["двуутробка"],
    "опостыв": ["опостывши"],
    "опостывши": ["опостыв"],
    "опостылев": ["опостылевши"],
    "опостылевав": ["опостылевавши"],
    "опостылевавши": ["опостылевав"],
    "опостылевши": ["опостылев"],
    "опостылевший": ["надоевший"],
    "опостылеть": ["осточертеть", "приесться", "набить оскомину", "опротиветь"],
    "опостынув": ["опостынувши"],
    "опостынувши": ["опостынув"],
    "опотев": ["опотевши"],
    "опотевши": ["опотев"],
    "опотерапия": ["органотерапия"],
    "опохабив": ["опохабивши"],
    "опохабивши": ["опохабив"],
    "опохмелив": ["опохмеливши"],
    "опохмеливши": ["опохмелив"],
    "опохмеляв": ["опохмелявши"],
    "опохмелявши": ["опохмеляв"],
    "опочив": ["опочивши"],
    "опочивав": ["опочивавши"],
    "опочивавши": ["опочивав"],
    "опочивальня": ["спальня", "спаленка", "дортуар"],
    "опочивши": ["опочив"],
    "опочивший": ["заснувший", "уснувший", "умерший", "скончавшийся"],
    "опочить": ["заснуть", "уснуть"],
    "опошлев": ["опошлевши"],
    "опошлевши": ["опошлев"],
    "опошлив": ["опошливши"],
    "опошливав": ["опошливавши"],
    "опошливавши": ["опошливав"],
    "опошливши": ["опошлив"],
    "опошляв": ["опошлявши"],
    "опошлявши": ["опошляв"],
    "опоэтизировав": ["опоэтизировавши"],
    "опоэтизировавши": ["опоэтизировав"],
    "опоясав": ["опоясавши"],
    "опоясавши": ["опоясав"],
    "опоясать": ["подпоясать"],
    "опоясаться": ["подпоясаться"],
    "опояска": ["пояс", "опоясок"],
    "опоясок": ["опояска", "пояс"],
    "опоясывав": ["опоясывавши"],
    "опоясывавши": ["опоясывав"],
    "опоясывать": ["подпоясывать"],
    "опоясывающий лишай": ["опоясывающий герпес"],
    "оппоблок": ["оппозиционный блок"],
    "оппозиционный блок": ["об", "оппоблок"],
    "оппозиция": ["возражение", "несогласие", "противоборство"],
    "оппонент": ["противник"],
    "оппонировав": ["оппонировавши"],
    "оппонировавши": ["оппонировав"],
    "оппортунизм": ["беспринципность", "соглашательство", "приспособленчество"],
    "оппортунист": ["конъюнктурщик", "приспособленец", "соглашатель"],
    "оппортунистический": ["беспринципный", "конъюнктурный"],
    "оппортунистский": ["оппортунистический"],
    "оправа": ["рамка", "обрамление"],
    "оправдав": ["оправдавши"],
    "оправдавши": ["оправдав"],
    "оправдание": ["оправданье"],
    "оправданье": ["оправдание"],
    "оправдательный приговор": ["оправдание"],
    "оправив": ["оправивши"],
    "оправивши": ["оправив"],
    "оправление": ["одёргивание"],
    "оправляв": ["оправлявши"],
    "оправлявши": ["оправляв"],
    "опрастывав": ["опрастывавши"],
    "опрастывавши": ["опрастывав"],
    "опрастывать": ["опорожнять"],
    "опрашивав": ["опрашивавши"],
    "опрашивавши": ["опрашивав"],
    "опрашивальщик": ["опрашиватель"],
    "опрев": ["опревши"],
    "опревав": ["опревавши"],
    "опревавши": ["опревав"],
    "опревши": ["опрев"],
    "определенье": ["определение"],
    "определив": ["определивши"],
    "определивши": ["определив"],
    "определитель": ["детерминант"],
    "определить": ["идентифицировать", "обнаружить", "выявить", "дать определение", "установить", "назначить", "обусловить", "задать", "детерминировать", "устроить", "пристроить"],
    "определяв": ["определявши"],
    "определявши": ["определяв"],
    "определять": ["идентифицировать", "обнаруживать", "выявлять", "давать определение", "устанавливать", "назначать", "обуславливать", "задавать", "детерминировать", "устраивать", "пристраивать"],
    "определённость": ["точность", "ясность"],
    "определённый": ["установленный", "конкретный"],
    "опредметив": ["опредметивши"],
    "опредметивши": ["опредметив"],
    "опредметить": ["объективировать"],
    "опредмечивав": ["опредмечивавши"],
    "опредмечивавши": ["опредмечивав"],
    "опредмечивание": ["объективация"],
    "опредмечивать": ["объективировать"],
    "опреснение": ["обессоливание"],
    "опреснив": ["опреснивши"],
    "опреснивши": ["опреснив"],
    "опреснок": ["маца"],
    "опресняв": ["опреснявши"],
    "опреснявши": ["опресняв"],
    "опрессовав": ["опрессовавши"],
    "опрессовавши": ["опрессовав"],
    "опрессовка": ["опрессовывание"],
    "опрессовывав": ["опрессовывавши"],
    "опрессовывавши": ["опрессовывав"],
    "опрессовывание": ["опрессовка"],
    "опрессовывать": ["обжимать"],
    "оприходовав": ["оприходовавши"],
    "оприходовавши": ["оприходовав"],
    "опричнина": ["опричина"],
    "опричь": ["кроме", "помимо"],
    "опробкование": ["опробковение"],
    "опробковев": ["опробковевши"],
    "опробковевав": ["опробковевавши"],
    "опробковевавши": ["опробковевав"],
    "опробковевши": ["опробковев"],
    "опробовав": ["опробовавши"],
    "опробовавши": ["опробовав"],
    "опробование": ["опробованье"],
    "опробовать": ["испытывать", "испытать", "отведывать", "отведать"],
    "опровергав": ["опровергавши"],
    "опровергавши": ["опровергав"],
    "опровергнув": ["опровергнувши", "опровергши"],
    "опровергнувши": ["опровергнув"],
    "опровергши": ["опровергнув", "опровергнувши"],
    "опроверженье": ["опровержение"],
    "опрозрачнев": ["опрозрачневши"],
    "опрозрачневши": ["опрозрачнев"],
    "опрозрачнивав": ["опрозрачнивавши"],
    "опрозрачнивавши": ["опрозрачнивав"],
    "опрокидывав": ["опрокидывавши"],
    "опрокидывавши": ["опрокидывав"],
    "опрокидывать": ["переворачивать"],
    "опрокинув": ["опрокинувши"],
    "опрокинувши": ["опрокинув"],
    "опрокинуться": ["перевернуться", "повалиться", "вывалиться"],
    "опрометчиво": ["поспешно", "необдуманно", "неосмотрительно"],
    "опрометчивый": ["неосмотрительный", "неосторожный"],
    "опрометью": ["поспешно", "стремительно", "стремглав", "опрометком"],
    "опрос": ["анкетирование"],
    "опросив": ["опросивши"],
    "опросивши": ["опросив"],
    "опросить": ["спросить", "проанкетировать", "допросить"],
    "опросник": ["анкета"],
    "опростав": ["опроставши"],
    "опроставши": ["опростав"],
    "опростать": ["опустошить", "выпростать"],
    "опростев": ["опростевши"],
    "опростевши": ["опростев"],
    "опростив": ["опростивши"],
    "опростивши": ["опростив"],
    "опростить": ["упростить", "адаптировать"],
    "опротестовав": ["опротестовавши"],
    "опротестовавши": ["опротестовав"],
    "опротестователь": ["протестующий"],
    "опротестовать": ["обжаловать"],
    "опротестовывав": ["опротестовывавши"],
    "опротестовывавши": ["опротестовывав"],
    "опротестовывать": ["оспаривать", "обжаловать"],
    "опротивев": ["опротивевши"],
    "опротивевши": ["опротивев"],
    "опротиветь": ["омерзеть", "опостылеть", "осточертеть", "обрыднуть", "достать", "наскучить"],
    "опрощав": ["опрощавши"],
    "опрощавши": ["опрощав"],
    "опрощение": ["деэтимологизация"],
    "опрыскав": ["опрыскавши"],
    "опрыскавши": ["опрыскав"],
    "опрыскивав": ["опрыскивавши"],
    "опрыскивавши": ["опрыскивав"],
    "опрыснув": ["опрыснувши"],
    "опрыснувши": ["опрыснув"],
    "опрыснуть": ["опрыскать"],
    "опрыщавев": ["опрыщавевши"],
    "опрыщавевши": ["опрыщавев"],
    "опрятный": ["аккуратный", "чистоплотный", "чистюля"],
    "опсовев": ["опсовевши"],
    "опсовевши": ["опсовев"],
    "оптативный": ["желательный"],
    "оптация": ["выбор гражданства", "выбор"],
    "оптико-волоконный": ["оптоволоконный"],
    "оптимализировав": ["оптимализировавши"],
    "оптимализировавши": ["оптимализировав"],
    "оптимальный": ["наилучший"],
    "оптимизация": ["улучшение", "совершенствование"],
    "оптимизировав": ["оптимизировавши"],
    "оптимизировавши": ["оптимизировав"],
    "оптимизм": ["жизнерадостность"],
    "оптимист": ["жизнелюб", "жизнелюбец"],
    "оптимистический": ["жизнерадостный", "оптимистичный"],
    "оптимистично": ["оптимистически"],
    "оптимистичность": ["оптимизм", "жизнерадостность", "гипомания"],
    "оптимистичный": ["оптимистический"],
    "оптировав": ["оптировавши"],
    "оптировавши": ["оптировав"],
    "оптически": ["зрительно"],
    "оптическое волокно": ["оптоволокно"],
    "оптово-торговый": ["оптовый"],
    "оптоволоконный": ["оптико-волоконный"],
    "оптоизоляция": ["изоляция"],
    "оптом": ["валом", "гуртом", "огулом", "сплошь", "подряд", "без разбора", "без исключения"],
    "оптопара": ["оптрон"],
    "оптрон": ["оптопара"],
    "опубликовав": ["опубликовавши"],
    "опубликовавши": ["опубликовав"],
    "опубликование": ["печать"],
    "опубликовать": ["издать"],
    "опубликоваться": ["издаться"],
    "опубликовывав": ["опубликовывавши"],
    "опубликовывавши": ["опубликовывав"],
    "опубликовывать": ["публиковать", "издавать"],
    "опубликовываться": ["издаваться"],
    "опудрив": ["опудривши"],
    "опудривав": ["опудривавши"],
    "опудривавши": ["опудривав"],
    "опудривши": ["опудрив"],
    "опупев": ["опупевши"],
    "опупевав": ["опупевавши"],
    "опупевавши": ["опупевав"],
    "опупевши": ["опупев"],
    "опупеть": ["охренеть", "одуреть"],
    "опус": ["сочинение"],
    "опускав": ["опускавши"],
    "опускавши": ["опускав"],
    "опускание": ["опущение"],
    "опусканье": ["опускание"],
    "опускать": ["снижать", "принижать", "понижать", "уменьшать", "приземлять"],
    "опускать руки": ["вешать голову", "вешать нос", "падать духом", "опускать крылья", "опускать крылышки"],
    "опускаться": ["снижаться", "спускаться", "уменьшаться"],
    "опустев": ["опустевши"],
    "опустевав": ["опустевавши"],
    "опустевавши": ["опустевав"],
    "опустевать": ["пустеть"],
    "опустевши": ["опустев"],
    "опустелый": ["пустой", "пустующий", "опустевший", "порожний"],
    "опустеть": ["опорожниться"],
    "опустив": ["опустивши"],
    "опустивши": ["опустив"],
    "опустить": ["спустить", "потупить", "склонить", "откинуть", "пропустить", "исключить", "дискредитировать"],
    "опустить руки": ["повесить голову", "повесить нос", "пасть духом", "опустить крылья", "опустить крылышки"],
    "опуститься": ["снизиться"],
    "опустошав": ["опустошавши"],
    "опустошавши": ["опустошав"],
    "опустошение": ["разорение", "опустошённость"],
    "опустошив": ["опустошивши"],
    "опустошивши": ["опустошив"],
    "опустошить": ["опорожнить", "разорить"],
    "опустынив": ["опустынивши"],
    "опустынивав": ["опустынивавши"],
    "опустынивавши": ["опустынивав"],
    "опустынивание": ["дезертификация"],
    "опустынивши": ["опустынив"],
    "опутав": ["опутавши"],
    "опутавши": ["опутав"],
    "опутывав": ["опутывавши"],
    "опутывавши": ["опутывав"],
    "опухав": ["опухавши"],
    "опухавши": ["опухав"],
    "опуханье": ["опухание"],
    "опухлый": ["опухший", "отёчный"],
    "опухнув": ["опухнувши"],
    "опухнувши": ["опухнув"],
    "опухнуть": ["вздуться", "разбухнуть", "оборзеть"],
    "опухолеродный": ["онкогенный"],
    "опухоль": ["новообразование", "неоплазия", "неоплазма", "опух"],
    "опушав": ["опушавши"],
    "опушавши": ["опушав"],
    "опушив": ["опушивши"],
    "опушивши": ["опушив"],
    "опущение": ["опускание"],
    "опущенье": ["опущение"],
    "опционально": ["необязательно", "факультативно"],
    "опция": ["возможность", "вариант", "факультатив"],
    "опърничавост": ["упоритост", "непослушание", "непокорство"],
    "опылив": ["опыливши"],
    "опыливав": ["опыливавши"],
    "опыливавши": ["опыливав"],
    "опыливши": ["опылив"],
    "опыляв": ["опылявши"],
    "опылявши": ["опыляв"],
    "опыт": ["практика", "искушённость", "опытность", "навык", "мастерство", "проверка", "поверка", "испытание", "эксперимент"],
    "опытничав": ["опытничавши"],
    "опытничавши": ["опытничав"],
    "опытный": ["умудрённый", "бывалый", "искушённый", "матёрый", "тёртый", "экспериментальный", "тестовый", "пробный", "практический"],
    "опьянев": ["опьяневши"],
    "опьяневши": ["опьянев"],
    "опьянелый": ["пьяный", "опьяневший", "захмелевший", "возбуждённый", "воодушевлённый"],
    "опьяненье": ["опьянение"],
    "опьянеть": ["запьянеть", "захмелеть", "охмелеть", "окосеть", "напиться"],
    "опьянив": ["опьянивши"],
    "опьянивши": ["опьянив"],
    "опьяняв": ["опьянявши"],
    "опьянявши": ["опьяняв"],
    "опьянять": ["пьянить", "хмелить", "одурманивать"],
    "опьянённость": ["опьянелость", "опьянение"],
    "опять": ["ещё", "ещё раз", "вновь", "заново", "снова", "сызнова", "повторно"],
    "опять двадцать пять": ["опять за рыбу деньги", "снова-здорово"],
    "опять за рыбу деньги": ["снова здорово", "снова да ладом", "опять двадцать пять", "опять за рыбу гроши"],
    "опять-таки": ["опять", "снова", "вновь"],
    "опёрши": ["оперев"],
    "ор": ["вопль", "галдёж", "гам", "гвалт", "гомон", "крик", "орание", "оранье"],
    "ора": ["райчиха", "гора"],
    "орабочив": ["орабочивши"],
    "орабочивав": ["орабочивавши"],
    "орабочивавши": ["орабочивав"],
    "орабочивши": ["орабочив"],
    "оравнодушев": ["оравнодушевши"],
    "оравнодушевши": ["оравнодушев"],
    "оравши": ["орав"],
    "орала": ["горлан", "крикун", "крикунья"],
    "орало": ["рало", "плуг", "соха"],
    "орально": ["устно"],
    "оральный": ["ротовой"],
    "оранг": ["орангутан", "орангутанг"],
    "оранг-утан": ["орангутан"],
    "орангутан": ["оранг", "орангутанг"],
    "орангутанг": ["орангутан", "оранг"],
    "оранжевая революция": ["майдан", "цветная революция"],
    "оранжевев": ["оранжевевши"],
    "оранжевевши": ["оранжевев"],
    "оранжево-жёлтый": ["шафранный", "шафрановый"],
    "оранжево-тыквенный": ["тыквенно-оранжевый"],
    "оранжевое свободное государство": ["оранское свободное государство", "оранжевая республика"],
    "оранжевый": ["апельсиновый", "апельсинный", "морковный", "густо-жёлтый", "рудо-жёлтый", "рыжий", "оранжевенький", "померанцевый", "помаранчевый", "ранжевый", "жаркой", "красножёлтый"],
    "оранжерейно-тепличный": ["теплично-оранжерейный"],
    "оранжерея": ["парник", "теплица"],
    "оранжист": ["помаранчевый"],
    "оранье": ["орание"],
    "орарь": ["орарий"],
    "оратай": ["землепашец", "пахарь", "оратель", "ратай"],
    "оратор": ["спикер", "говорящий", "вития"],
    "ораторствовав": ["ораторствовавши"],
    "ораторствовавши": ["ораторствовав"],
    "орать": ["кричать", "вопить", "голосить", "галдеть", "горлопанить", "драть горло", "бранить", "ржать", "угорать"],
    "орашул-сталин": ["сталин", "брашов"],
    "орбиобразие": ["орбифолд"],
    "орбита": ["сфера", "глазница", "глазная орбита"],
    "орви": ["острая респираторная вирусная инфекция", "орз"],
    "оргазм": ["восторг"],
    "орган": ["часть тела", "организация", "ведомство"],
    "орган вебера": ["предстательная маточка", "простатическая маточка"],
    "органайзер": ["ежедневник", "бизнес-блокнот", "бизнес-организатор"],
    "органелла": ["орган"],
    "организатор": ["устроитель"],
    "организация": ["организовывание", "упорядочение", "слаженность", "дисциплинированность", "организованность", "структура"],
    "организация варшавского договора": ["варшавский договор", "овд"],
    "организация объединённых наций": ["оон"],
    "организовав": ["организовавши"],
    "организовавши": ["организовав"],
    "организовать": ["создать", "основать", "образовать", "сформировать", "учредить"],
    "организоваться": ["организовываться"],
    "организовывав": ["организовывавши"],
    "организовывавши": ["организовывав"],
    "организовывать": ["образовывать", "основывать", "учреждать", "налаживать", "отлаживать", "сплачивать", "упорядочивать"],
    "организъм": ["тяло"],
    "органиструм": ["колёсная лира"],
    "органическая химия": ["органика"],
    "органическое вещество": ["органическое соединение", "органика"],
    "органическое соединение": ["органическое вещество", "органика"],
    "органично": ["естественно"],
    "органичный": ["присущий", "неотделимый", "неотъемлемый", "естественный", "органический"],
    "органосохраняющий": ["органосохранный"],
    "органотроф": ["гетеротроф"],
    "органщик": ["органист"],
    "органы внутренних дел": ["овд", "полиция", "милиция"],
    "оргвзнос": ["организационный взнос"],
    "оргия": ["вакханалия", "пьянка", "групповуха"],
    "орговик": ["орготделец"],
    "орготделец": ["орговик"],
    "оргстекло": ["органическое стекло", "плексиглас"],
    "оргтехника": ["организационная техника"],
    "орден ленина": ["ол"],
    "орден святого владимира": ["владимир"],
    "орден святого станислава": ["станислав"],
    "орден святой анны": ["анна"],
    "ордер": ["архитектурный ордер"],
    "ординарец": ["адъютант", "денщик", "вестовой", "посыльный"],
    "ординарность": ["обыкновенность", "заурядность", "посредственность"],
    "ординарный": ["обыкновенный", "заурядный", "штатный"],
    "ординатор": ["клинический ординатор"],
    "ордовик": ["ордовикский период"],
    "ордовикский": ["ордовик", "ордовикский период"],
    "оре": ["бале"],
    "ореада": ["орестиада"],
    "оребрив": ["оребривши"],
    "оребривши": ["оребрив"],
    "оребряв": ["оребрявши"],
    "оребрявши": ["оребряв"],
    "оренбург": ["чкалов", "орен"],
    "оренбургская область": ["оренбуржье"],
    "оренбургский": ["оренбуржский"],
    "оренбуржский": ["оренбургский"],
    "ореол": ["гало", "сияние", "нимб"],
    "орестиада": ["касторское", "адрианополь", "орестида", "орестия"],
    "орех": ["орешник"],
    "ореховка": ["кедровка"],
    "ореховопромысловый": ["орехопромысловый"],
    "орехопромысловый": ["ореховопромысловый"],
    "орешек": ["нотебург"],
    "орешник": ["лещина"],
    "орешничав": ["орешничавши"],
    "орешничавши": ["орешничав"],
    "орз": ["острое респираторное заболевание"],
    "орзотто": ["перлотто"],
    "орзу": ["майл"],
    "оригенист": ["оригенианин", "оригений"],
    "оригинал": ["подлинник", "чудак", "эксцентрик"],
    "оригинальничав": ["оригинальничавши"],
    "оригинальничавши": ["оригинальничав"],
    "оригинально": ["своеобразно", "незаурядно", "необычно", "своеобычно", "самобытно", "нетривиально"],
    "оригинальность": ["самобытность", "своеобразие"],
    "ориенталист": ["востоковед", "восточник"],
    "ориенталистика": ["востоковедение"],
    "ориенталистский": ["востоковедческий"],
    "ориентация": ["ориентирование", "направленность"],
    "ориентировав": ["ориентировавши"],
    "ориентировавши": ["ориентировав"],
    "ориентироваться": ["разбираться", "оглядываться"],
    "ориентировочно": ["оценочно", "приблизительно", "примерно"],
    "ориентолог": ["ориенталист", "востоковед", "восточник"],
    "орис": ["съдба", "орисница", "орисия", "участ", "предопределение", "жребий"],
    "орисия": ["орис", "съдба", "орисница", "участ", "предопределение", "жребий"],
    "орисница": ["орис", "съдба", "орисия", "участ", "предопределение", "жребий"],
    "орисс": ["оригинальное исследование"],
    "орисса": ["одиша"],
    "орития": ["орифия"],
    "орифия": ["орития"],
    "орихалк": ["орихальк", "аврихальк"],
    "орк": ["оркус", "плутон", "аид"],
    "оркан": ["ураган", "буря", "тропический", "циклон", "орканбо"],
    "оркестр": ["оркестровая яма", "вагнер", "вагнеровец", "музыкант", "любитель немецкой музыки", "оркестрант", "пригожинец"],
    "оркестральный": ["оркестровый"],
    "оркестрировав": ["оркестрировавши"],
    "оркестрировавши": ["оркестрировав"],
    "оркестровав": ["оркестровавши"],
    "оркестровавши": ["оркестровав"],
    "орловская область": ["орловщина"],
    "ормазд": ["ахурамазда"],
    "ормузд": ["ахурамазда"],
    "орнаменталист": ["орнаментист", "орнаментщик"],
    "орнаментальный": ["узорчатый"],
    "орнаментировав": ["орнаментировавши"],
    "орнаментировавши": ["орнаментировав"],
    "орнаментирование": ["орнаментация", "орнамент"],
    "орнаментовав": ["орнаментовавши"],
    "орнаментовавши": ["орнаментовав"],
    "орнат": ["казула"],
    "орнитин": ["диаминовалериановая кислота"],
    "орнитолог": ["птицевед"],
    "орнитолог-любитель": ["бердвотчер", "бёрдвочер"],
    "орнитоптер": ["прицелёт", "махолёт"],
    "орнитофауна": ["авифауна"],
    "орнув": ["орнувши"],
    "орнувши": ["орнув"],
    "оробев": ["оробевши"],
    "оробевши": ["оробев"],
    "орогенез": ["горообразование"],
    "орогенезис": ["орогения", "горообразование"],
    "орогенитальный": ["орально-генитальный"],
    "орогения": ["диастрофизм"],
    "ороговев": ["ороговевши"],
    "ороговевав": ["ороговевавши"],
    "ороговевавши": ["ороговевав"],
    "ороговевши": ["ороговев"],
    "ороговевший": ["ороговелый"],
    "ороговелый": ["ороговевший"],
    "оромо": ["галла"],
    "оронт": ["эль-аси"],
    "оросив": ["оросивши"],
    "оросивши": ["оросив"],
    "ороситель": ["разбрызгиватель", "поливалка"],
    "оросительный": ["ирригационный"],
    "оросить": ["полить"],
    "оростан": ["перостан"],
    "ороч": ["орочон"],
    "орочий": ["оркский"],
    "орочон": ["орочен", "ороч", "негидалец", "удэгеец"],
    "орошав": ["орошавши"],
    "орошавши": ["орошав"],
    "орошаемый": ["поливаемый"],
    "орошать": ["поливать"],
    "орошение": ["поливание", "ирригация", "затопление", "заводнение", "обводнение"],
    "орошенье": ["орошение"],
    "орстхоец": ["карабулак"],
    "орт": ["единичный вектор"],
    "ортак": ["съдружник", "съучастник", "помагач"],
    "ортакин": ["ортакюнь"],
    "ортакюнь": ["ортакин"],
    "ортогональный": ["прямоугольный"],
    "ортодокс": ["правоверный", "консерватор", "традиционалист", "православный"],
    "ортодоксальность": ["убеждённость"],
    "ортодоксальный": ["правоверный"],
    "ортодоксия": ["ортодоксальность", "убеждённость", "приверженность", "правоверие", "правоверность"],
    "ортодромия": ["геодезическая кривая"],
    "ортоклаз": ["калиевый полевой шпат"],
    "ортонормальный": ["взаимноперпендикулярный"],
    "ортопантограф": ["ортопантомограф"],
    "ортопед": ["ортопедист"],
    "ору": ["открытое распределительное устройство", "обще-развивающее упражнение", "отдельная рота управления"],
    "оруденев": ["оруденевши"],
    "оруденевши": ["оруденев"],
    "оруденелый": ["металлизированный", "металлизованный"],
    "орудие": ["пешка", "марионетка", "артиллерийское орудие"],
    "орудие преступления": ["орудие совершения преступления"],
    "орудовав": ["орудовавши"],
    "орудовавши": ["орудовав"],
    "орудование": ["манипулирование"],
    "орудовать": ["распоряжаться", "управлять", "командовать", "заправлять", "манипулировать", "оперировать", "управляться", "действовать"],
    "орудовец": ["гаишник"],
    "орудье": ["орудие"],
    "оружейка": ["оружейная"],
    "оружейная": ["оружейка"],
    "оружие": ["вооружение", "экипировка", "снаряжение"],
    "оружие массового поражения": ["оружие массового уничтожения"],
    "оружие массового уничтожения": ["оружие массового поражения"],
    "оружье": ["оружие"],
    "орумянив": ["орумянивши"],
    "орумянивав": ["орумянивавши"],
    "орумянивавши": ["орумянивав"],
    "орумянивши": ["орумянив"],
    "орун": ["крикун"],
    "орунья": ["крикунья"],
    "орусия федерациясы": ["орусия"],
    "оруэлльский": ["оруэлловский"],
    "орфографический": ["правописный"],
    "орфография": ["правописание"],
    "орфоэпический": ["произносительный"],
    "орхит": ["тестит"],
    "оръжар": ["оръжейник"],
    "орыжъ": ["темэн"],
    "орёл": ["царь-птица", "молодец", "казак", "казак лихой", "джигит", "мачо"],
    "ос": ["окружающая среда", "операционная система"],
    "осада": ["блокада", "окружение"],
    "осадив": ["осадивши"],
    "осадивши": ["осадив"],
    "осадки": ["атмосферные осадки"],
    "осадкомер": ["плювиометр", "плювиограф"],
    "осаднив": ["осаднивши"],
    "осаднивав": ["осаднивавши"],
    "осаднивавши": ["осаднивав"],
    "осаднивши": ["осаднив"],
    "осадок": ["отстой", "тяжесть", "горечь"],
    "осадочный цикл": ["седиментационный цикл"],
    "осаждав": ["осаждавши"],
    "осаждавши": ["осаждав"],
    "осаживав": ["осаживавши"],
    "осаживавши": ["осаживав"],
    "осака": ["город воды"],
    "осалив": ["осаливши"],
    "осаливав": ["осаливавши"],
    "осаливавши": ["осаливав"],
    "осаливши": ["осалив"],
    "осалить": ["просалить", "насалить", "засалить", "замарать", "запачкать", "испачкать"],
    "осанисто": ["важно", "внушительно", "солидно"],
    "осанистый": ["представительный"],
    "осанна": ["славословие", "похвала"],
    "осарсиф": ["озарсиф", "осарсеф"],
    "осатанев": ["осатаневши"],
    "осатаневав": ["осатаневавши"],
    "осатаневавши": ["осатаневав"],
    "осатаневши": ["осатанев"],
    "осатаневший": ["осатанелый", "озверевший"],
    "осатанело": ["остервенело"],
    "осатанеть": ["остервенеть"],
    "осахарив": ["осахаривши"],
    "осахаривав": ["осахаривавши"],
    "осахаривавши": ["осахаривав"],
    "осахаривши": ["осахарив"],
    "осбб": ["осмд"],
    "осваговский": ["осважный"],
    "осважный": ["осваговский"],
    "осваивав": ["осваивавши"],
    "осваивавши": ["осваивав"],
    "осваивать": ["овладевать", "изучать", "постигать"],
    "осведомив": ["осведомивши"],
    "осведомивши": ["осведомив"],
    "осведомитель": ["информант", "информатор", "разведчик", "доносчик", "изветчик", "предатель", "секретный сотрудник", "сексот", "соглядатай", "стукач", "провокатор", "шпион", "ябеда"],
    "осведомить": ["известить", "оповестить", "уведомить", "информировать"],
    "осведомление": ["сообщение", "оповещение", "извещение", "информирование", "уведомление"],
    "осведомляв": ["осведомлявши"],
    "осведомлявши": ["осведомляв"],
    "осведомлять": ["сообщать", "информировать", "извещать", "уведомлять", "докладывать", "доносить", "заявлять", "объявлять", "оповещать", "предупреждать"],
    "осведомляться": ["спрашивать", "справляться", "узнавать"],
    "осведомлённый": ["сведущий", "информированный", "компетентный", "подготовленный"],
    "освежав": ["освежавши"],
    "освежавши": ["освежав"],
    "освежевав": ["освежевавши"],
    "освежевавши": ["освежевав"],
    "освеженье": ["освежение"],
    "освежив": ["освеживши"],
    "освеживши": ["освежив"],
    "освежёвывав": ["освежёвывавши"],
    "освежёвывавши": ["освежёвывав"],
    "освенцим": ["аушвиц"],
    "осветив": ["осветивши"],
    "осветивши": ["осветив"],
    "осветитель": ["светотехник", "световик"],
    "осветление": ["блондирование"],
    "осветлив": ["осветливши"],
    "осветливши": ["осветлив"],
    "осветляв": ["осветлявши"],
    "осветлявши": ["осветляв"],
    "освещав": ["освещавши"],
    "освещавши": ["освещав"],
    "освещённость": ["освещение"],
    "освидетельствовав": ["освидетельствовавши"],
    "освидетельствовавши": ["освидетельствовав"],
    "освидетельствование": ["осматривание", "осмотр"],
    "освидетельствовать": ["осмотреть", "обследовать"],
    "освинцевав": ["освинцевавши"],
    "освинцевавши": ["освинцевав"],
    "освинцовывав": ["освинцовывавши"],
    "освинцовывавши": ["освинцовывав"],
    "освирепев": ["освирепевши"],
    "освирепевши": ["освирепев"],
    "освирепелый": ["рассвирепевший"],
    "освистав": ["освиставши"],
    "освиставши": ["освистав"],
    "освистывав": ["освистывавши"],
    "освистывавши": ["освистывав"],
    "освободив": ["освободивши"],
    "освободивши": ["освободив"],
    "освободитель": ["вызволитель", "избавитель", "спаситель"],
    "освободить": ["избавить", "спасти", "опустошить", "очистить"],
    "освобождав": ["освобождавши"],
    "освобождавши": ["освобождав"],
    "освобождать": ["увольнять"],
    "освобожденье": ["освобождение"],
    "освоив": ["освоивши"],
    "освоивши": ["освоив"],
    "освоить": ["научиться", "овладеть"],
    "освоиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться"],
    "освоялово": ["освоение"],
    "освятив": ["освятивши"],
    "освятивши": ["освятив"],
    "освящав": ["освящавши"],
    "освящавши": ["освящав"],
    "освященье": ["освящение"],
    "осевой": ["аксиальный"],
    "оседав": ["оседавши"],
    "оседавши": ["оседав"],
    "оседать": ["опускаться", "заваливаться", "валиться", "скапливаться", "селиться", "поселяться", "обосновываться"],
    "оседлав": ["оседлавши"],
    "оседлавши": ["оседлав"],
    "оседлать": ["заседлать", "сесть верхом"],
    "осекав": ["осекавши"],
    "осекавши": ["осекав"],
    "оселедец": ["айдар", "ардар", "чуб", "чуприна", "чупрына", "коса", "косма", "хохол"],
    "оселок": ["точило", "брусок", "осёлка", "пробирный камень", "пробный камень", "лидийский камень", "лидит"],
    "осеменение": ["осемененье"],
    "осеменив": ["осеменивши"],
    "осеменивши": ["осеменив"],
    "осеменить": ["оплодотворить"],
    "осеменяв": ["осеменявши"],
    "осеменявши": ["осеменяв"],
    "осемнадесет": ["осемнайсет"],
    "осемь": ["восемь"],
    "осенев": ["шарукань"],
    "осененье": ["осенение"],
    "осенив": ["осенивши"],
    "осенивши": ["осенив"],
    "осенить": ["увести в тень", "затенить", "озарить"],
    "осенний": ["осенный"],
    "осень": ["закат", "увядание", "год"],
    "осенью": ["по осени"],
    "осеняв": ["осенявши"],
    "осенявши": ["осеняв"],
    "осердив": ["осердивши"],
    "осердивши": ["осердив"],
    "осердье": ["осердие"],
    "осеребрив": ["осеребривши"],
    "осеребривши": ["осеребрив"],
    "осеребряв": ["осеребрявши"],
    "осеребрявши": ["осеребряв"],
    "осереднячив": ["осереднячивши"],
    "осереднячивши": ["осереднячив"],
    "осерчав": ["осерчавши"],
    "осерчавши": ["осерчав"],
    "осерчать": ["рассердиться", "разозлиться"],
    "осерёдыш": ["голец"],
    "осетив": ["осетивши"],
    "осетивши": ["осетив"],
    "осетинский язык": ["осетинский"],
    "осетия": ["иристон", "ир", "алания"],
    "осечка": ["ошибка", "промах", "промашка"],
    "осивев": ["осивевши"],
    "осивевши": ["осивев"],
    "осигуровка": ["застраховка"],
    "осика": ["осичина"],
    "осил": ["аркан"],
    "осилив": ["осиливши"],
    "осиливав": ["осиливавши"],
    "осиливавши": ["осиливав"],
    "осиливши": ["осилив"],
    "осилить": ["победить", "одержать верх", "перебороть"],
    "осилье": ["силок", "осилок"],
    "осинный": ["осиновый"],
    "осиновик": ["подосиновик"],
    "осипав": ["осипавши"],
    "осипавши": ["осипав"],
    "осипев": ["осипевши"],
    "осипевши": ["осипев"],
    "осипнув": ["осипнувши"],
    "осипнувши": ["осипнув"],
    "осипнуть": ["охрипнуть"],
    "осипший": ["охрипший", "осиплый", "сиплый"],
    "осирис": ["усир", "озирис"],
    "осиротев": ["осиротевши"],
    "осиротевши": ["осиротев"],
    "осиротело": ["сиротливо"],
    "осиротелый": ["обезлюдевший", "опустевший", "заброшенный"],
    "осиротив": ["осиротивши"],
    "осиротивши": ["осиротив"],
    "осификация": ["остеогенеза"],
    "осичина": ["осика"],
    "осияв": ["осиявши"],
    "осиявав": ["осиявавши"],
    "осиявавши": ["осиявав"],
    "осиявать": ["озарять"],
    "осиявши": ["осияв"],
    "оскабливав": ["оскабливавши"],
    "оскабливавши": ["оскабливав"],
    "оскаленный": ["ощеренный", "осклабившийся", "ухмыляющийся"],
    "оскалив": ["оскаливши"],
    "оскаливав": ["оскаливавши"],
    "оскаливавши": ["оскаливав"],
    "оскаливать": ["скалить"],
    "оскаливши": ["оскалив"],
    "оскалившийся": ["ощерившийся"],
    "оскалиться": ["ощериться"],
    "оскальпировав": ["оскальпировавши"],
    "оскальпировавши": ["оскальпировав"],
    "оскаляясь": ["оскаливаясь"],
    "оскандалив": ["оскандаливши"],
    "оскандаливав": ["оскандаливавши"],
    "оскандаливавши": ["оскандаливав"],
    "оскандаливши": ["оскандалив"],
    "оскандалиться": ["осрамиться"],
    "осквернение": ["опоганивание", "поругание", "профанация", "испоганивание", "загаживание", "профанирование", "надругательство", "святотатство"],
    "оскверненье": ["осквернение"],
    "осквернив": ["осквернивши"],
    "осквернивши": ["осквернив"],
    "осквернительница": ["омерзительница"],
    "оскверняв": ["осквернявши"],
    "осквернявши": ["оскверняв"],
    "осквернять": ["поганить", "испоганивать", "опоганивать", "надругаться"],
    "осклабив": ["осклабивши"],
    "осклабивши": ["осклабив"],
    "осклабить": ["оскалить"],
    "осклабиться": ["ухмыльнуться"],
    "осклабляв": ["осклаблявши"],
    "осклаблявши": ["осклабляв"],
    "осклабляться": ["склабиться"],
    "осклизлый": ["мокрый", "скользкий", "ослизлый", "осклизший", "склизкий"],
    "осклизнув": ["осклизнувши"],
    "осклизнувши": ["осклизнув"],
    "оскоблив": ["оскобливши"],
    "оскобливши": ["оскоблив"],
    "оскопив": ["оскопивши"],
    "оскопивши": ["оскопив"],
    "оскопить": ["кастрировать", "выхолостить"],
    "оскопление": ["кастрация"],
    "оскопляв": ["оскоплявши"],
    "оскоплявши": ["оскопляв"],
    "оскоплять": ["кастрировать", "холостить", "скопить", "подвергать цензуре", "выхолащивать", "изменять", "искажать", "редактировать", "сокращать"],
    "оскорбив": ["оскорбивши"],
    "оскорбивши": ["оскорбив"],
    "оскорбление": ["унижение"],
    "оскорбляв": ["оскорблявши"],
    "оскорблявши": ["оскорбляв"],
    "оскорблядство": ["оскорблённость"],
    "оскорблять": ["унижать", "гневить", "позорить"],
    "оскорблённо": ["уязвлённо", "обидчиво", "обиженно"],
    "оскоромив": ["оскоромивши"],
    "оскоромивши": ["оскоромив"],
    "оскотинев": ["оскотиневши"],
    "оскотиневши": ["оскотинев"],
    "оскотинив": ["оскотинивши"],
    "оскотинивав": ["оскотинивавши"],
    "оскотинивавши": ["оскотинивав"],
    "оскотинивши": ["оскотинив"],
    "оскребав": ["оскребавши"],
    "оскребавши": ["оскребав"],
    "оскрёбывав": ["оскрёбывавши"],
    "оскрёбывавши": ["оскрёбывав"],
    "оскрёбывать": ["оскребать"],
    "оскудев": ["оскудевши"],
    "оскудевав": ["оскудевавши"],
    "оскудевавши": ["оскудевав"],
    "оскудевать": ["скудеть"],
    "оскудевающий": ["скудеющий"],
    "оскудевши": ["оскудев"],
    "оскудение": ["оскуденье"],
    "оскуденье": ["оскудение"],
    "оскуднев": ["оскудневши"],
    "оскудневши": ["оскуднев"],
    "оскъдица": ["оскъдност", "недоимък", "лишение", "немотия", "нямане", "бедност", "беднота", "нужда"],
    "ослабев": ["ослабевши"],
    "ослабевав": ["ослабевавши"],
    "ослабевавши": ["ослабевав"],
    "ослабевать": ["слабеть"],
    "ослабевши": ["ослабев"],
    "ослабевший": ["ослабший"],
    "ослабеть": ["ослабнуть"],
    "ослабив": ["ослабивши"],
    "ослабивши": ["ослабив"],
    "ослабленье": ["ослабление"],
    "ослаблювач": ["атенюатор"],
    "ослабляв": ["ослаблявши"],
    "ослаблявши": ["ослабляв"],
    "ослабнув": ["ослабнувши"],
    "ослабнувши": ["ослабнув"],
    "ослабнуть": ["ослабеть"],
    "ослабший": ["ослабевший"],
    "ославив": ["ославивши"],
    "ославивши": ["ославив"],
    "ославить": ["опозорить", "оклеветать", "оболгать", "скомпрометировать", "очернить", "опорочить"],
    "ославляв": ["ославлявши"],
    "ославлявши": ["ославляв"],
    "ославянив": ["ославянивши"],
    "ославянивав": ["ославянивавши"],
    "ославянивавши": ["ославянивав"],
    "ославянивать": ["славянизировать"],
    "ославянивши": ["ославянив"],
    "ослепив": ["ослепивши"],
    "ослепивши": ["ослепив"],
    "ослепительно": ["ослепляюще"],
    "ослепительный": ["ослепляющий", "яркий", "блистательный"],
    "ослепленье": ["ослепление"],
    "ослепляв": ["ослеплявши"],
    "ослеплявши": ["ослепляв"],
    "ослепнув": ["ослепнувши"],
    "ослепнувши": ["ослепнув"],
    "ослив": ["осливши"],
    "осливши": ["ослив"],
    "ослизлый": ["мокрый", "скользкий", "осклизлый", "осклизший", "склизкий"],
    "ослизнув": ["ослизнувши"],
    "ослизнувши": ["ослизнув"],
    "ослизняв": ["ослизнявши"],
    "ослизнявши": ["ослизняв"],
    "ослинник": ["энотера"],
    "ослиха": ["ослица"],
    "ослица": ["ослиха"],
    "осло": ["христиания", "кристиания"],
    "ослобонив": ["ослобонивши"],
    "ослобонивши": ["ослобонив"],
    "ослобонить": ["отпустить"],
    "осложнение": ["затруднение", "запутывание", "трудность", "препятствие", "проблема"],
    "осложненье": ["осложнение"],
    "осложнив": ["осложнивши"],
    "осложнивши": ["осложнив"],
    "осложнить": ["усложнить"],
    "осложняв": ["осложнявши"],
    "осложнявши": ["осложняв"],
    "осложнять": ["усложнять", "обострять", "усугублять"],
    "ослушав": ["ослушавши"],
    "ослушавши": ["ослушав"],
    "ослушанье": ["ослушание"],
    "ослушивав": ["ослушивавши"],
    "ослушивавши": ["ослушивав"],
    "ослушник": ["неслух"],
    "ослышка": ["мондегрин"],
    "ослюнявив": ["ослюнявивши"],
    "ослюнявивши": ["ослюнявив"],
    "осмаливав": ["осмаливавши"],
    "осмаливавши": ["осмаливав"],
    "осман": ["оттоман"],
    "османец": ["осман", "турок"],
    "османская империя": ["оттоманская империя"],
    "османский": ["оттоманский", "турецкий"],
    "османский язык": ["османский", "османско-турецкий"],
    "осматривав": ["осматривавши"],
    "осматривавши": ["осматривав"],
    "осматривать": ["оглядывать"],
    "осмд": ["осбб"],
    "осмеивав": ["осмеивавши"],
    "осмеивавши": ["осмеивав"],
    "осмеивать": ["высмеивать"],
    "осмелев": ["осмелевши"],
    "осмелевши": ["осмелев"],
    "осмеливаться": ["отваживаться", "набираться смелости", "решаться"],
    "осмелиться": ["отважиться", "набраться смелости", "решиться"],
    "осмеркнув": ["осмеркнувши"],
    "осмеркнувши": ["осмеркнув"],
    "осмеяв": ["осмеявши"],
    "осмеявши": ["осмеяв"],
    "осмеянье": ["осмеяние"],
    "осмирнев": ["осмирневши"],
    "осмирневши": ["осмирнев"],
    "осмолив": ["осмоливши"],
    "осмоливши": ["осмолив"],
    "осмос": ["диффузия"],
    "осмотр": ["осматривание", "оглядывание"],
    "осмотрев": ["осмотревши"],
    "осмотревши": ["осмотрев"],
    "осмотреть": ["оглядеть", "произвести", "осмотр", "исследовать", "обследовать"],
    "осмуглив": ["осмугливши"],
    "осмугливши": ["осмуглив"],
    "осмыслив": ["осмысливши"],
    "осмысливав": ["осмысливавши"],
    "осмысливавши": ["осмысливав"],
    "осмысливать": ["осмыслять"],
    "осмысливши": ["осмыслив"],
    "осмысляв": ["осмыслявши"],
    "осмыслявши": ["осмысляв"],
    "осмыслять": ["осмысливать"],
    "оснастив": ["оснастивши"],
    "оснастивши": ["оснастив"],
    "оснащав": ["оснащавши"],
    "оснащавши": ["оснащав"],
    "оснащение": ["оснащенье", "оборудование"],
    "оснащенье": ["оснащение", "оборудование"],
    "оснащивав": ["оснащивавши"],
    "оснащивавши": ["оснащивав"],
    "оснежав": ["оснежавши"],
    "оснежавши": ["оснежав"],
    "оснежив": ["оснеживши"],
    "оснеживши": ["оснежив"],
    "основа": ["база", "базис", "основание", "остов", "опора", "сущность", "ость"],
    "основав": ["основавши"],
    "основавши": ["основав"],
    "основание": ["создание", "учреждение", "организация", "основа", "опора", "база", "базис", "обоснование", "оправдание", "резон", "причина", "повод", "основы", "начала", "щёлочь"],
    "основанный": ["обоснованный", "опирающийся"],
    "основанье": ["основание"],
    "основатель": ["основоположник", "учредитель", "родоначальник", "зачинатель"],
    "основательно": ["обстоятельно"],
    "основательный": ["обоснованный"],
    "основать": ["создать", "учредить"],
    "основаться": ["возникнуть", "образоваться", "учредиться", "обосноваться", "расположиться", "разместиться", "поселиться"],
    "основное": ["главное"],
    "основной": ["базовый", "фундаментальный", "главный", "ведущий", "важнейший"],
    "основоположник": ["родоначальник", "основатель", "зачинатель", "образователь", "отец", "инициатор", "патриарх"],
    "основоположница": ["основательница"],
    "основывав": ["основывавши"],
    "основывавши": ["основывав"],
    "основывать": ["создавать", "учреждать", "обосновывать", "базировать"],
    "основываться": ["возникать", "образовываться", "базироваться", "создаваться", "учреждаться"],
    "осноровив": ["осноровивши"],
    "осноровивши": ["осноровив"],
    "особа": ["лицо", "личность", "вельможа", "дама"],
    "особенно": ["особливо", "особо"],
    "особенность": ["особость", "своеобразие", "черта", "свойство", "отличие"],
    "особенный": ["необыкновенный", "особый"],
    "особист": ["контрразведчик"],
    "особиться": ["обособляться"],
    "особливый": ["отдельный", "особый", "своеобразный", "исключительный", "особенный"],
    "особняком": ["обособленно", "особенно", "наособицу", "особицей", "врозь", "по себе"],
    "особо": ["отдельно", "обособленно", "иначе", "по-своему", "особенно", "особливо", "очень"],
    "особоровав": ["особоровавши"],
    "особоровавши": ["особоровав"],
    "особый": ["особенный", "исключительный", "специальный", "экстраординарный"],
    "особь": ["индивид"],
    "осовев": ["осовевши"],
    "осовевши": ["осовев"],
    "осовелый": ["вялый", "опьянелый", "осовевший", "осоловелый", "полусонный", "посоловелый", "расслабленный"],
    "осовестив": ["осовестивши"],
    "осовестивши": ["осовестив"],
    "осоветь": ["осоловеть", "посоловеть"],
    "осовременив": ["осовременивши"],
    "осовременивав": ["осовременивавши"],
    "осовременивавши": ["осовременивав"],
    "осовременивание": ["обновление", "модернизация"],
    "осовременивши": ["осовременив"],
    "осознав": ["осознавши"],
    "осознавав": ["осознававши"],
    "осознававши": ["осознавав"],
    "осознавать": ["уяснять", "осмысливать", "давать себе отчёт"],
    "осознавши": ["осознав"],
    "осознание": ["осмысление", "понимание", "постижение"],
    "осознанно": ["сознательно"],
    "осознанность": ["осмысленность"],
    "осознанный": ["понятый"],
    "осознанье": ["осознание"],
    "осознать": ["понять", "уяснить"],
    "осоковые": ["сытевые"],
    "осокорь": ["чёрный тополь"],
    "осолаживав": ["осолаживавши"],
    "осолаживавши": ["осолаживав"],
    "осоловев": ["осоловевши"],
    "осоловевши": ["осоловев"],
    "осоловелый": ["осовелый"],
    "осоловеть": ["осоветь"],
    "осолодев": ["осолодевши"],
    "осолодевши": ["осолодев"],
    "осолодив": ["осолодивши"],
    "осолодивши": ["осолодив"],
    "осолонив": ["осолонивши"],
    "осолонивши": ["осолонив"],
    "осолонцевав": ["осолонцевавши"],
    "осолонцевавши": ["осолонцевав"],
    "осолоняв": ["осолонявши"],
    "осолонявши": ["осолоняв"],
    "осоння": ["осонь"],
    "осопев": ["осопевши"],
    "осопевши": ["осопев"],
    "осопливев": ["осопливевши"],
    "осопливевши": ["осопливев"],
    "осоружний": ["огидний", "поганий", "бридкий", "неприязний", "недоброзичливий"],
    "осотный": ["осотовый"],
    "осотовый": ["осотный"],
    "осохнув": ["осохнувши"],
    "осохнувши": ["осохнув"],
    "осоюзив": ["осоюзивши"],
    "осоюзивши": ["осоюзив"],
    "осоюзить": ["обсоюзить"],
    "оспа": ["воспа"],
    "оспаривав": ["оспаривавши"],
    "оспаривавши": ["оспаривав"],
    "оспаривать": ["обжаловать", "опровергать", "апеллировать", "возражать", "опротестовывать"],
    "оспинка": ["щербинка"],
    "оспорив": ["оспоривши"],
    "оспоривав": ["оспоривавши"],
    "оспоривавши": ["оспоривав"],
    "оспоривши": ["оспорив"],
    "осрамив": ["осрамивши"],
    "осрамивши": ["осрамив"],
    "осрамить": ["опозорить"],
    "осрамиться": ["опозориться"],
    "осрамляв": ["осрамлявши"],
    "осрамлявши": ["осрамляв"],
    "осребрив": ["осребривши"],
    "осребривши": ["осребрив"],
    "осребряв": ["осребрявши"],
    "осребрявши": ["осребряв"],
    "осребрять": ["осеребрять"],
    "осребряться": ["осеребряться"],
    "осреднив": ["осреднивши"],
    "осреднивши": ["осреднив"],
    "осредняв": ["осреднявши"],
    "осреднявши": ["осредняв"],
    "осреднять": ["усреднять"],
    "оссификация": ["остеогенез", "окостенение"],
    "оссифицировав": ["оссифицировавши"],
    "оссифицировавши": ["оссифицировав"],
    "оссифицироваться": ["костенеть", "окостеневать"],
    "оссуарий": ["костница"],
    "ост": ["восток"],
    "оставаться": ["сохраняться", "оказываться", "проигрывать"],
    "оставив": ["оставя"],
    "оставивши": ["оставив"],
    "оставить без порток": ["оставить без штанов"],
    "оставить в дураках": ["одурачить"],
    "оставление": ["покидание", "бросание", "оставленье", "сохранение", "хранение", "сохраненье", "храненье"],
    "оставляв": ["оставлявши"],
    "оставлявши": ["оставляв"],
    "оставлять": ["покидать", "сохранять"],
    "оставлять без порток": ["оставлять без штанов"],
    "оставя": ["оставив"],
    "осталив": ["осталивши"],
    "осталивав": ["осталивавши"],
    "осталивавши": ["осталивав"],
    "осталивши": ["осталив"],
    "остальной": ["прочий", "другой", "оставшийся"],
    "остан": ["провинция"],
    "останавливав": ["останавливавши"],
    "останавливавши": ["останавливав"],
    "останавливать": ["задерживать", "сдерживать", "стопорить", "застопоривать", "тормозить", "обездвиживать"],
    "останки": ["прах", "труп", "кости", "тело", "остатки"],
    "останный": ["последний"],
    "останов": ["остановка", "затворная задержка"],
    "остановив": ["остановивши"],
    "остановивши": ["остановив"],
    "остановить": ["задержать", "сдержать", "застопорить", "затормозить", "обездвижить", "стопануть"],
    "остановиться": ["встать"],
    "остановляв": ["остановлявши"],
    "остановлявши": ["остановляв"],
    "остап": ["остапка", "ося"],
    "остарев": ["остаревши"],
    "остаревши": ["остарев"],
    "остатний": ["последний", "крайний", "останний"],
    "остаток": ["излишек"],
    "остаточный": ["неизрасходованный"],
    "остаться в дураках": ["быть в дураках", "опростоволоситься"],
    "остаться в лицах": ["быть в лицах"],
    "остаться на бобах": ["остаться ни с чем", "остаться с пустыми руками"],
    "остаться с носом": ["остаться с хуем"],
    "остаться с хуем": ["остаться ни с чем", "остаться с пустыми руками", "остаться с носом"],
    "остгот": ["острогот", "грейтунг", "гревтунг"],
    "остеартроз": ["артроз"],
    "остеклев": ["остеклевши"],
    "остеклевши": ["остеклев"],
    "остекленев": ["остекленевши"],
    "остекленевши": ["остекленев"],
    "остекленевший": ["застывший"],
    "остекленелый": ["остекленевший", "остеклелый"],
    "остекленеть": ["остеклеть"],
    "остекление": ["остекленье"],
    "остеклив": ["остекливши"],
    "остекливши": ["остеклив"],
    "остекловав": ["остекловавши"],
    "остекловавши": ["остекловав"],
    "остекляв": ["остеклявши"],
    "остеклявши": ["остекляв"],
    "остеклянев": ["остекляневши"],
    "остекляневши": ["остеклянев"],
    "остеклять": ["застеклять"],
    "остенсивный": ["наглядный"],
    "остеогенез": ["костеобразование", "окостенение", "оссификация"],
    "остеогенный": ["костеобразующий"],
    "остеоцит": ["костная клетка"],
    "остепенев": ["остепеневши"],
    "остепеневши": ["остепенев"],
    "остепенив": ["остепенивши"],
    "остепенивши": ["остепенив"],
    "остепенить": ["образумить"],
    "остепеняв": ["остепенявши"],
    "остепенявши": ["остепеняв"],
    "остервенев": ["остервеневши"],
    "остервеневши": ["остервенев"],
    "остервенело": ["ожесточённо", "озверело", "исступлённо", "яростно"],
    "остервенелость": ["разъярённость", "озверелость", "разгневанность", "исступлённость", "неистовство", "взбешённость", "исступление", "бешенство", "осатанелость", "неистовость"],
    "остервенение": ["остервененье"],
    "остервененье": ["остервенение"],
    "остервенив": ["остервенивши"],
    "остервенивши": ["остервенив"],
    "остервеняв": ["остервенявши"],
    "остервенявши": ["остервеняв"],
    "остерегав": ["остерегавши"],
    "остерегавши": ["остерегав"],
    "остерегать": ["предостерегать"],
    "остереженье": ["остережение"],
    "остеречь": ["предостеречь"],
    "остзейский": ["прибалтийский"],
    "остинка": ["ость"],
    "остов": ["каркас", "опора", "рама", "костяк", "скелет", "схема", "план"],
    "остоебенив": ["остоебенивши"],
    "остоебенивши": ["остоебенив"],
    "остоебенить": ["опротиветь", "опостылеть", "осточертеть", "остохренеть", "остохуеть", "остопиздеть"],
    "остол": ["хорей"],
    "остолбенев": ["остолбеневши"],
    "остолбеневав": ["остолбеневавши"],
    "остолбеневавши": ["остолбеневав"],
    "остолбеневши": ["остолбенев"],
    "остолбенелость": ["остолбенение"],
    "остолбенелый": ["остолбеневший"],
    "остолбенеть": ["замереть", "застыть", "оцепенеть", "окаменеть"],
    "остолбив": ["остолбивши"],
    "остолбивши": ["остолбив"],
    "остолоп": ["бестолочь", "глупец", "недоумок", "тупица"],
    "остопиздев": ["остопиздевши"],
    "остопиздевши": ["остопиздев"],
    "остопиздеть": ["опротиветь", "осточертеть", "осточертенеть", "остохренеть", "остофигеть", "остохереть", "остоебенить", "остохуеть", "остохуенить", "настопиздеть"],
    "остопиздив": ["остопиздивши"],
    "остопиздивши": ["остопиздив"],
    "остопиздить": ["остоебать", "остоебенить", "осточертеть", "заебать", "надоесть", "достать"],
    "осторожничав": ["осторожничавши"],
    "осторожничавши": ["осторожничав"],
    "осторожно": ["осмотрительно", "аккуратно", "слабо", "нерешительно", "тихо", "сдержанно", "внимательно", "бережно", "деликатно", "внимание", "берегись"],
    "осторожность": ["осмотрительность", "опасливость"],
    "осторожный": ["осмотрительный", "сдержанный"],
    "остохренев": ["остохреневши"],
    "остохреневши": ["остохренев"],
    "остохренеть": ["остоебенить", "остопиздеть", "остохуеть"],
    "остохуев": ["остохуевши"],
    "остохуевши": ["остохуев"],
    "остохуеть": ["опротиветь", "опостылеть", "осточертеть", "остохренеть", "остохереть", "остоебенить", "остопиздеть"],
    "осточертев": ["осточертевши"],
    "осточертевав": ["осточертевавши"],
    "осточертевавши": ["осточертевав"],
    "осточертевши": ["осточертев"],
    "осточертевший": ["опротивевший", "опостылевший"],
    "осточертеть": ["опротиветь", "опостылеть", "очертеть"],
    "острагивав": ["острагивавши"],
    "острагивавши": ["острагивав"],
    "остракоды": ["ракушковые"],
    "остранив": ["остранивши"],
    "остранивши": ["остранив"],
    "остраняв": ["остранявши"],
    "остранявши": ["остраняв"],
    "острастка": ["запугивание"],
    "острая респираторная вирусная инфекция": ["орви"],
    "острекав": ["острекавши"],
    "острекавив": ["острекавивши"],
    "острекавивши": ["острекавив"],
    "острекавши": ["острекав"],
    "острив": ["остривши"],
    "остривши": ["острив"],
    "остригав": ["остригавши"],
    "остригавши": ["остригав"],
    "остриженный": ["постриженный", "состриженный", "обстриженный", "обчекрыженный", "оболваненный"],
    "острить": ["заострять"],
    "острица": ["асперуга"],
    "остричь": ["состричь"],
    "остриё": ["кончик", "лезвие", "сосредоточие", "средоточие"],
    "остро-дефицитный": ["остродефицитный"],
    "остров принца эдуарда": ["опэ", "сен-жан", "сент-джонс"],
    "остров свободы": ["куба"],
    "острова россиян": ["туамоту"],
    "островерхий": ["островершинный", "остроконечный"],
    "островной": ["йоканьгский погост", "йоканга", "гремиха"],
    "острог": ["крепость"],
    "острога": ["трезубец"],
    "острогав": ["острогавши"],
    "острогавши": ["острогав"],
    "остроглазый": ["зоркий", "глазастый", "востроглазый"],
    "остродефицитный": ["остро-дефицитный"],
    "острожив": ["остроживши"],
    "остроживши": ["острожив"],
    "острожничав": ["острожничавши"],
    "острожничавши": ["острожничав"],
    "острожок": ["острожек"],
    "остроконечность": ["остроугольность"],
    "остролистый": ["остролистный"],
    "остролодка": ["остролодочник"],
    "остролодочник": ["остролодка"],
    "остроносый": ["востроносый", "остроконечный"],
    "остропилив": ["остропиливши"],
    "остропиливав": ["остропиливавши"],
    "остропиливавши": ["остропиливав"],
    "остропиливши": ["остропилив"],
    "острослов": ["остряк", "шутник"],
    "острословив": ["острословивши"],
    "острословивши": ["острословив"],
    "острословить": ["острить"],
    "острословье": ["острословие"],
    "острота": ["шутка", "каламбур", "остроумие"],
    "остроумничав": ["остроумничавши"],
    "остроумничавши": ["остроумничав"],
    "остроумье": ["остроумие"],
    "остроязыкий": ["остроязычный"],
    "остругав": ["остругавши"],
    "остругавши": ["остругав"],
    "остругивав": ["остругивавши"],
    "остругивавши": ["остругивав"],
    "острый": ["вострый", "отточенный", "жгучий", "едкий", "критический", "высокотемпературный"],
    "остряк": ["острослов", "шутник"],
    "остряк-самоучка": ["клоун", "наглец"],
    "остудив": ["остудивши"],
    "остудивши": ["остудив"],
    "остудить": ["охладить"],
    "остужав": ["остужавши"],
    "остужавши": ["остужав"],
    "остужать": ["охлаждать"],
    "остужение": ["охлаждение"],
    "остуживав": ["остуживавши"],
    "остуживавши": ["остуживав"],
    "остукав": ["остукавши"],
    "остукавши": ["остукав"],
    "остукивав": ["остукивавши"],
    "остукивавши": ["остукивав"],
    "остыв": ["остывши"],
    "остывав": ["остывавши"],
    "остывавши": ["остывав"],
    "остывание": ["остыванье", "охлаждение"],
    "остыванье": ["остывание"],
    "остывать": ["охлаждаться", "успокаиваться"],
    "остывши": ["остыв"],
    "остынув": ["остынувши"],
    "остынувши": ["остынув"],
    "остынуть": ["остыть", "охладиться", "успокоиться"],
    "остыть": ["остынуть"],
    "остёгивав": ["остёгивавши"],
    "остёгивавши": ["остёгивав"],
    "осудив": ["осудивши"],
    "осудивши": ["осудив"],
    "осудить": ["приговорить", "обречь"],
    "осуждав": ["осуждавши"],
    "осуждавши": ["осуждав"],
    "осуждать": ["порицать"],
    "осуждающе": ["порицающе", "неодобрительно"],
    "осужденье": ["осуждение"],
    "осунув": ["осунувши"],
    "осунувши": ["осунув"],
    "осушав": ["осушавши"],
    "осушавши": ["осушав"],
    "осушать": ["дегидрировать"],
    "осушенье": ["осушение"],
    "осушив": ["осушивши"],
    "осушивши": ["осушив"],
    "осушить": ["дегидрировать", "испить", "опорожнить", "опустошить"],
    "осушка": ["осушение"],
    "осуществив": ["осуществивши"],
    "осуществивши": ["осуществив"],
    "осуществимость": ["исполнимость", "выполнимость", "сбыточность"],
    "осуществиться": ["исполниться", "свершиться", "сбыться"],
    "осуществленье": ["осуществление"],
    "осуществляв": ["осуществлявши"],
    "осуществлявши": ["осуществляв"],
    "осуществлять": ["воплощать", "реализовывать", "претворять в жизнь", "совершать", "делать", "выполнять", "вести"],
    "осфрезиофилия": ["озолагния", "ренифлекс"],
    "осциллировав": ["осциллировавши"],
    "осциллировавши": ["осциллировав"],
    "осциллировать": ["колебаться", "пульсировать"],
    "осцилляционный": ["колебательный"],
    "осцилляция": ["осциллирование", "колебание"],
    "осчастливив": ["осчастлививши"],
    "осчастлививши": ["осчастливив"],
    "осчастливливав": ["осчастливливавши"],
    "осчастливливавши": ["осчастливливав"],
    "осъществител": ["реализатор", "изпълнител"],
    "осыпав": ["осыпавши"],
    "осыпавши": ["осыпав"],
    "осыпанье": ["осыпание"],
    "осыпать": ["обсыпать", "усеять", "заполнить", "покрыть"],
    "осыхав": ["осыхавши"],
    "осыхавши": ["осыхав"],
    "ось": ["вал", "стержень", "втулка"],
    "осьмек": ["буюмек"],
    "осьмидесятилетний": ["восьмидесятилетний"],
    "осьмина": ["восьмина", "восьминка", "восьмушка", "осьминка", "осьмуха", "осьмушка", "получеть", "получетверть", "осьминник"],
    "осьминог": ["спрут"],
    "осьминогообразный": ["октопоидный", "спрутообразный"],
    "осьмнадцатый": ["восемнадцатый"],
    "осьмнадцать": ["восемнадцать"],
    "осьмой": ["восьмой"],
    "осьмуха": ["восьмина", "восьминка", "восьмушка", "осьмина", "осьминка", "осьмушка", "получеть", "получетверть"],
    "осьмушка": ["восьмина", "восьминка", "восьмушка", "осьмина", "осьминка", "осьмуха", "получеть", "получетверть"],
    "осюмлик": ["небат"],
    "ося": ["остапка"],
    "осязав": ["осязавши"],
    "осязавши": ["осязав"],
    "осязанье": ["осязание"],
    "осёдлывав": ["осёдлывавши"],
    "осёдлывавши": ["осёдлывав"],
    "осёдлывать": ["седлать", "садиться верхом", "подчинять"],
    "осёл": ["ишак", "дурак", "чурбан"],
    "от а до зет": ["от а до я"],
    "от а до я": ["от а до ижицы", "от а до ижицы включительно", "от альфы до омеги", "от а до зет"],
    "от балды": ["необоснованно", "навскидку", "необдуманно", "просто так", "наобум"],
    "от винта": ["приступить", "поехать", "двинуться"],
    "от всего сердца": ["от души"],
    "от греха подальше": ["на всякий пожарный"],
    "от добра добра не ищут": ["дарёному коню в зубы не смотрят", "работает - не трогай", "за добро не жди добра"],
    "от доски до доски": ["от корки до корки", "от а до я"],
    "от души": ["искренно"],
    "от искры сыр бор загорается": ["буря в стакане воды"],
    "от копеечной свечи москва загорелась": ["москва от копеечной свечки сгорала", "москва от копеечной свечки сгорела", "от искры москва загорелась"],
    "от корки до корки": ["от доски до доски", "от а до я"],
    "от кутюр": ["высокая мода"],
    "от мала до велика": ["стар и млад"],
    "от не хуй делать": ["от нечего делать"],
    "от нечего делать": ["от не хуй делать"],
    "от осины не родятся апельсины": ["от осинки не родятся апельсинки"],
    "от пуза": ["досыта", "вволю"],
    "от рождества христова": ["по рождестве христовом"],
    "от росы до росы": ["от утра до утра", "от зари до зари", "сутки напролёт", "без продыха", "без продыху"],
    "от слова до слова": ["целиком"],
    "от случая к случаю": ["иногда", "изредка", "порой", "порою", "временами", "по временам", "время от времени", "от времени до времени", "иной раз", "другой раз", "при случае", "в некоторых случаях", "в отдельных случаях", "часом", "иным часом"],
    "от фонаря": ["с потолка", "от балды", "сдуру"],
    "от хуя уши": ["недостаточно", "нет", "нету", "нема", "нетути", "там хуй ночевал", "там хуй плавал", "хуй там ночевал", "хуй там плавал"],
    "от чистого сердца": ["от души"],
    "от-": ["с-"],
    "от-кутюр": ["высокая мода"],
    "отабунив": ["отабунивши"],
    "отабунивши": ["отабунив"],
    "отава": ["отавушка", "трава", "мурава"],
    "отавушка": ["отава"],
    "отакелажив": ["отакелаживши"],
    "отакелаживав": ["отакелаживавши"],
    "отакелаживавши": ["отакелаживав"],
    "отакелаживши": ["отакелажив"],
    "отаку": ["анимешник"],
    "отандас": ["жерлес"],
    "отапливав": ["отапливавши"],
    "отапливавши": ["отапливав"],
    "отаптывав": ["отаптывавши"],
    "отаптывавши": ["отаптывав"],
    "отара": ["гурт"],
    "отарщик": ["атарщик"],
    "отац": ["бабо"],
    "отачивав": ["отачивавши"],
    "отачивавши": ["отачивав"],
    "оташдон": ["оташхона"],
    "оташхона": ["оташдон"],
    "отбавив": ["отбавивши"],
    "отбавивши": ["отбавив"],
    "отбавляв": ["отбавлявши"],
    "отбавлявши": ["отбавляв"],
    "отбалансировав": ["отбалансировавши"],
    "отбалансировавши": ["отбалансировав"],
    "отбаливав": ["отбаливавши"],
    "отбаливавши": ["отбаливав"],
    "отбарабанив": ["отбарабанивши"],
    "отбарабанивав": ["отбарабанивавши"],
    "отбарабанивавши": ["отбарабанивав"],
    "отбарабанивши": ["отбарабанив"],
    "отбарствовав": ["отбарствовавши"],
    "отбарствовавши": ["отбарствовав"],
    "отбегав": ["отбегавши"],
    "отбегавши": ["отбегав"],
    "отбегаться": ["отбегать"],
    "отбежав": ["отбежавши"],
    "отбежавши": ["отбежав"],
    "отбелив": ["отбеливши"],
    "отбеливав": ["отбеливавши"],
    "отбеливавши": ["отбеливав"],
    "отбеливши": ["отбелив"],
    "отбелка": ["отбеливание", "выбелка"],
    "отбензинив": ["отбензинивши"],
    "отбензинивав": ["отбензинивавши"],
    "отбензинивавши": ["отбензинивав"],
    "отбензинивши": ["отбензинив"],
    "отбеседовав": ["отбеседовавши"],
    "отбеседовавши": ["отбеседовав"],
    "отбивав": ["отбивавши"],
    "отбивавши": ["отбивав"],
    "отбиваться в горизонталь": ["отбиваться", "отбиваться в койку", "отбиваться харю мять"],
    "отбиваться в койку": ["отбиваться", "отбиваться в горизонталь", "отбиваться харю мять"],
    "отбиваться харю мять": ["отбиваться", "отбиваться в койку", "отбиваться в горизонталь"],
    "отбивка": ["джингл"],
    "отбивная": ["отбивная котлета"],
    "отбивши": ["отбив"],
    "отбирав": ["отбиравши"],
    "отбиравши": ["отбирав"],
    "отбирать": ["забирать", "отнимать", "производить отбор"],
    "отбитый": ["отвоёванный"],
    "отбить": ["отвратить", "отнять", "отвадить"],
    "отбить желание": ["отбить охоту"],
    "отблаговестив": ["отблаговестивши"],
    "отблаговестивши": ["отблаговестив"],
    "отблагодарив": ["отблагодаривши"],
    "отблагодаривши": ["отблагодарив"],
    "отблагодарить": ["поблагодарить", "всучить"],
    "отблажив": ["отблаживши"],
    "отблаживши": ["отблажив"],
    "отблажить": ["остепениться", "перебеситься", "отгулять"],
    "отблеск": ["блик", "отсвет"],
    "отблескивав": ["отблескивавши"],
    "отблескивавши": ["отблескивав"],
    "отблескивать": ["отблёскивать"],
    "отблестев": ["отблестевши"],
    "отблестевши": ["отблестев"],
    "отблистав": ["отблиставши"],
    "отблиставши": ["отблистав"],
    "отблёскивав": ["отблёскивавши"],
    "отблёскивавши": ["отблёскивав"],
    "отблёскивать": ["отблескивать", "отсвечивать"],
    "отбойник": ["ударник", "барьерное ограждение", "криволинейный брус"],
    "отболев": ["отболевши"],
    "отболевши": ["отболев"],
    "отболеть": ["переболеть"],
    "отбомбив": ["отбомбивши"],
    "отбомбивши": ["отбомбив"],
    "отборный": ["первосортный", "отличный", "изысканный", "грязный", "неприличный", "непристойный", "скверный"],
    "отборным матом крыть": ["крупным матом крыть", "трёхэтажным матом крыть", "семиэтажным матом крыть", "девятиэтажным матом крыть"],
    "отборонив": ["отборонивши"],
    "отборонивши": ["отборонив"],
    "отбортовав": ["отбортовавши"],
    "отбортовавши": ["отбортовав"],
    "отбортовывав": ["отбортовывавши"],
    "отбортовывавши": ["отбортовывав"],
    "отбоярив": ["отбояривши"],
    "отбояривав": ["отбояривавши"],
    "отбояривавши": ["отбояривав"],
    "отбояривши": ["отбоярив"],
    "отбоярить": ["отвадить"],
    "отбояриться": ["отбрыкаться", "отвязаться"],
    "отбраковав": ["отбраковавши"],
    "отбраковавши": ["отбраковав"],
    "отбраковывав": ["отбраковывавши"],
    "отбраковывавши": ["отбраковывав"],
    "отбрана": ["защита", "закрила", "охрана"],
    "отбранив": ["отбранивши"],
    "отбранивши": ["отбранив"],
    "отбрасывав": ["отбрасывавши"],
    "отбрасывавши": ["отбрасывав"],
    "отбрасывать": ["откидывать"],
    "отбредав": ["отбредавши"],
    "отбредавши": ["отбредав"],
    "отбренчав": ["отбренчавши"],
    "отбренчавши": ["отбренчав"],
    "отбрехаться": ["отбояриться"],
    "отбрив": ["отбривши"],
    "отбривав": ["отбривавши"],
    "отбривавши": ["отбривав"],
    "отбривши": ["отбрив"],
    "отбродив": ["отбродивши"],
    "отбродивши": ["отбродив"],
    "отброс": ["мусор", "дрянь", "отход", "помои", "отребье", "подонок"],
    "отбросав": ["отбросавши"],
    "отбросавши": ["отбросав"],
    "отбросаться": ["откидаться"],
    "отбросив": ["отбросивши"],
    "отбросивши": ["отбросив"],
    "отбросить": ["откинуть"],
    "отбросный": ["отбросовый"],
    "отбрызгивав": ["отбрызгивавши"],
    "отбрызгивавши": ["отбрызгивав"],
    "отбрызнув": ["отбрызнувши"],
    "отбрызнувши": ["отбрызнув"],
    "отбрякав": ["отбрякавши"],
    "отбрякавши": ["отбрякав"],
    "отбрякивав": ["отбрякивавши"],
    "отбрякивавши": ["отбрякивав"],
    "отбрякнув": ["отбрякнувши"],
    "отбрякнувши": ["отбрякнув"],
    "отбубнив": ["отбубнивши"],
    "отбубнивши": ["отбубнив"],
    "отбузовав": ["отбузовавши"],
    "отбузовавши": ["отбузовав"],
    "отбуйствовав": ["отбуйствовавши"],
    "отбуйствовавши": ["отбуйствовав"],
    "отбуксировав": ["отбуксировавши"],
    "отбуксировавши": ["отбуксировав"],
    "отбуксировывав": ["отбуксировывавши"],
    "отбуксировывавши": ["отбуксировывав"],
    "отбунтовав": ["отбунтовавши"],
    "отбунтовавши": ["отбунтовав"],
    "отбурив": ["отбуривши"],
    "отбуривав": ["отбуривавши"],
    "отбуривавши": ["отбуривав"],
    "отбуривши": ["отбурив"],
    "отбурлив": ["отбурливши"],
    "отбурливши": ["отбурлив"],
    "отбухав": ["отбухавши"],
    "отбухавши": ["отбухав"],
    "отбучив": ["отбучивши"],
    "отбучивав": ["отбучивавши"],
    "отбучивавши": ["отбучивав"],
    "отбучивши": ["отбучив"],
    "отбушевав": ["отбушевавши"],
    "отбушевавши": ["отбушевав"],
    "отбушевать": ["отшуметь"],
    "отбуянив": ["отбуянивши"],
    "отбуянивши": ["отбуянив"],
    "отбыв": ["отбывши"],
    "отбывав": ["отбывавши"],
    "отбывавши": ["отбывав"],
    "отбывши": ["отбыв"],
    "отбытье": ["отбытие"],
    "отвага": ["храбрость", "бесстрашие", "отважность", "мужество", "смелость", "доблесть"],
    "отвадив": ["отвадивши"],
    "отвадивши": ["отвадив"],
    "отвадить": ["отучить"],
    "отваживав": ["отваживавши"],
    "отваживавши": ["отваживав"],
    "отваживаться": ["осмеливаться"],
    "отважиться": ["осмелиться", "решиться"],
    "отважничав": ["отважничавши"],
    "отважничавши": ["отважничав"],
    "отважно": ["храбро", "смело", "мужественно", "доблестно", "бесстрашно"],
    "отважность": ["смелость", "бесстрашие"],
    "отважный": ["смелый", "бесстрашный"],
    "отвалив": ["отваливши"],
    "отваливав": ["отваливавши"],
    "отваливавши": ["отваливав"],
    "отваливаться": ["отпадать", "откидываться"],
    "отваливши": ["отвалив"],
    "отвалить": ["выложить", "отчалить", "отойти", "отхлынуть", "отвять", "свалить"],
    "отвалтузив": ["отвалтузивши"],
    "отвалтузивши": ["отвалтузив"],
    "отвалтузить": ["отдубасить"],
    "отвальная": ["на посошок"],
    "отваляв": ["отвалявши"],
    "отвалявши": ["отваляв"],
    "отвалять": ["свалять"],
    "отвар": ["отваривание", "бульон", "навар", "юшка"],
    "отвара": ["извара"],
    "отварив": ["отваривши"],
    "отваривав": ["отваривавши"],
    "отваривавши": ["отваривав"],
    "отваривши": ["отварив"],
    "отвевав": ["отвевавши"],
    "отвевавши": ["отвевав"],
    "отведав": ["отведавши"],
    "отведавши": ["отведав"],
    "отведывав": ["отведывавши"],
    "отведывавши": ["отведывав"],
    "отвезя": ["отвёзши"],
    "отвеивав": ["отвеивавши"],
    "отвеивавши": ["отвеивав"],
    "отвековав": ["отвековавши"],
    "отвековавши": ["отвековав"],
    "отвергав": ["отвергавши"],
    "отвергавши": ["отвергав"],
    "отвергать": ["отклонять", "отказываться", "отказывать", "отрицать"],
    "отвергающий": ["отказывающий", "отрицающий"],
    "отвергнув": ["отвергнувши"],
    "отвергнувши": ["отвергнув"],
    "отвергнуть": ["отклонить", "отказаться", "отказать"],
    "отвердев": ["отвердевши"],
    "отвердевав": ["отвердевавши"],
    "отвердевавши": ["отвердевав"],
    "отвердевать": ["твердеть", "отверждаться"],
    "отвердевши": ["отвердев"],
    "отвердив": ["отвердивши"],
    "отвердивши": ["отвердив"],
    "отвердиться": ["отвердеть"],
    "отверждав": ["отверждавши"],
    "отверждавши": ["отверждав"],
    "отверждаться": ["затвердевать", "твердеть"],
    "отверженец": ["отверженник"],
    "отверженье": ["отвержение"],
    "отверзав": ["отверзавши"],
    "отверзавши": ["отверзав"],
    "отверзать": ["открывать", "размыкать", "раскрывать"],
    "отверзаться": ["открываться"],
    "отверзнув": ["отверзнувши"],
    "отверзнувши": ["отверзнув"],
    "отверзнуть": ["отверзть", "открыть"],
    "отвернув": ["отвернувши"],
    "отвернувши": ["отвернув"],
    "отвернуло башню": ["сорвало башню", "свернуло башню", "снесло башню", "башню снесло", "башню сорвало", "башню свернуло", "башню отвернуло"],
    "отвернуться": ["отворотиться", "повернуться", "обернуться", "открыться", "отвинтиться", "открутиться", "загнуться", "отогнуться"],
    "отверстие": ["дыра", "дырка"],
    "отверстый": ["открытый"],
    "отверстье": ["отверстие"],
    "отвертев": ["отвертевши"],
    "отвертевши": ["отвертев"],
    "отвертеться": ["отвернуться", "открутиться", "уклониться"],
    "отверчивав": ["отверчивавши"],
    "отверчивавши": ["отверчивав"],
    "отвес": ["отвешивание", "обрыв", "весок", "весовой сертификат"],
    "отвесив": ["отвесивши"],
    "отвесивши": ["отвесив"],
    "отвесить": ["свесить", "оттопырить"],
    "отвесный": ["вертикальный"],
    "отвести": ["отодвинуть", "передвинуть", "провести"],
    "ответ": ["отклик", "отзыв", "реакция", "решение", "отгадка"],
    "ответвив": ["ответвивши"],
    "ответвивши": ["ответвив"],
    "ответвляв": ["ответвлявши"],
    "ответвлявши": ["ответвляв"],
    "ответив": ["ответивши"],
    "ответивши": ["ответив"],
    "ответить": ["откликнуться", "отозваться", "понести ответственность"],
    "ответка": ["отместка"],
    "ответочка": ["обраточка"],
    "ответственность": ["важность", "подотчётность", "долг"],
    "ответственный": ["подотчётный", "высокопоставленный", "полномочный", "добросовестный", "надёжный", "важный", "решающий", "критичный"],
    "ответствовав": ["ответствовавши"],
    "ответствовавши": ["ответствовав"],
    "ответствовать": ["отвечать", "ответить"],
    "ответчик": ["ответственный"],
    "отвечав": ["отвечавши"],
    "отвечавши": ["отвечав"],
    "отвечать": ["откликаться", "реагировать", "быть ответственным", "быть в ответе", "нести ответственность"],
    "отвечать за базар": ["держать ответ"],
    "отвешав": ["отвешавши"],
    "отвешавши": ["отвешав"],
    "отвешивав": ["отвешивавши"],
    "отвешивавши": ["отвешивав"],
    "отвешивание": ["взвешивание", "пондерация"],
    "отвеяв": ["отвеявши"],
    "отвеявши": ["отвеяв"],
    "отвив": ["отвивши"],
    "отвивав": ["отвивавши"],
    "отвивавши": ["отвивав"],
    "отвивши": ["отвив"],
    "отвиливав": ["отвиливавши"],
    "отвиливавши": ["отвиливав"],
    "отвиливать": ["увиливать"],
    "отвильнув": ["отвильнувши"],
    "отвильнувши": ["отвильнув"],
    "отвиляв": ["отвилявши"],
    "отвилявши": ["отвиляв"],
    "отвинтив": ["отвинтивши"],
    "отвинтивши": ["отвинтив"],
    "отвинтиться": ["развинтиться"],
    "отвинчивав": ["отвинчивавши"],
    "отвинчивавши": ["отвинчивав"],
    "отвинчиваться": ["развинчиваться"],
    "отвисав": ["отвисавши"],
    "отвисавши": ["отвисав"],
    "отвиснув": ["отвиснувши"],
    "отвиснувши": ["отвиснув"],
    "отвлекав": ["отвлекавши"],
    "отвлекавши": ["отвлекав"],
    "отвлекать": ["отклонять"],
    "отвлеченье": ["отвлечение"],
    "отвод": ["ворота"],
    "отводив": ["отводивши"],
    "отводивши": ["отводив"],
    "отводя": ["отвод"],
    "отвоевав": ["отвоевавши"],
    "отвоевавши": ["отвоевав"],
    "отвозив": ["отвозивши"],
    "отвозивши": ["отвозив"],
    "отвозить": ["привозить"],
    "отволаживав": ["отволаживавши"],
    "отволаживавши": ["отволаживав"],
    "отволакивав": ["отволакивавши"],
    "отволакивавши": ["отволакивав"],
    "отволгнув": ["отволгнувши"],
    "отволгнувши": ["отволгнув"],
    "отволожив": ["отволоживши"],
    "отволоживши": ["отволожив"],
    "отволочив": ["отволочивши"],
    "отволочивши": ["отволочив"],
    "отвораживав": ["отвораживавши"],
    "отвораживавши": ["отвораживав"],
    "отворачивав": ["отворачивавши"],
    "отворачивавши": ["отворачивав"],
    "отворачивать рыло": ["воротить рыло", "рыло воротить", "рыло отворачивать"],
    "отворив": ["отворивши"],
    "отворивши": ["отворив"],
    "отворить": ["открыть"],
    "отворожив": ["отвороживши"],
    "отвороживши": ["отворожив"],
    "отворотив": ["отворотивши"],
    "отворотивши": ["отворотив"],
    "отворотиться": ["отвернуться", "повернуться", "обернуться", "забить", "отвернуть", "повернуть", "обернуть"],
    "отворотка": ["отворот", "своротка", "свёрток"],
    "отворочав": ["отворочавши"],
    "отворочавши": ["отворочав"],
    "отворяв": ["отворявши"],
    "отворявши": ["отворяв"],
    "отворять": ["открывать"],
    "отвоёвывав": ["отвоёвывавши"],
    "отвоёвывавши": ["отвоёвывав"],
    "отвоёвывать": ["отбивать", "завоёвывать"],
    "отвратив": ["отвративши"],
    "отвративши": ["отвратив"],
    "отвратительный": ["отвратный", "омерзительный", "отталкивающий", "мерзкий", "хреновый", "дрянной"],
    "отвратный": ["отвратительный", "мерзкий", "поганый", "препоганый"],
    "отвращав": ["отвращавши"],
    "отвращавши": ["отвращав"],
    "отвращать": ["отворачивать", "поворачивать", "отталкивать", "внушать", "отвращение", "предотвращать", "отражать"],
    "отвращение": ["отваживание", "предотвращение", "устранение", "омерзение", "неприятие", "неприязнь"],
    "отвращенье": ["отвращение"],
    "отвулканизировав": ["отвулканизировавши"],
    "отвулканизировавши": ["отвулканизировав"],
    "отвыв": ["отвывши"],
    "отвывав": ["отвывавши"],
    "отвывавши": ["отвывав"],
    "отвывши": ["отвыв"],
    "отвыкав": ["отвыкавши"],
    "отвыкавши": ["отвыкав"],
    "отвыкнув": ["отвыкнувши"],
    "отвыкнувши": ["отвыкнув"],
    "отвыкнуть": ["дезадаптироваться", "отвадиться", "отучиться", "поотвыкнуть"],
    "отвязав": ["отвязавши"],
    "отвязавши": ["отвязав"],
    "отвязывав": ["отвязывавши"],
    "отвязывавши": ["отвязывав"],
    "отвянув": ["отвянувши"],
    "отвянувши": ["отвянув"],
    "отвёзши": ["отвезя"],
    "отвёрточка": ["отвёртка"],
    "отвёртывав": ["отвёртывавши"],
    "отвёртывавши": ["отвёртывав"],
    "отгадав": ["отгадавши"],
    "отгадавши": ["отгадав"],
    "отгадать": ["разгадать"],
    "отгадка": ["разгадка"],
    "отгадчик": ["провидец", "ясновидящий", "ясновидец", "прозорливец", "угадчик", "разгадчик", "предсказатель"],
    "отгадывав": ["отгадывавши"],
    "отгадывавши": ["отгадывав"],
    "отгащивав": ["отгащивавши"],
    "отгащивавши": ["отгащивав"],
    "отгектографировав": ["отгектографировавши"],
    "отгектографировавши": ["отгектографировав"],
    "отгибав": ["отгибавши"],
    "отгибавши": ["отгибав"],
    "отгибать": ["отгинать", "загинать"],
    "отглагольное существительное": ["девербатив"],
    "отгладив": ["отгладивши"],
    "отгладивши": ["отгладив"],
    "отгладывав": ["отгладывавши"],
    "отгладывавши": ["отгладывав"],
    "отглаженный": ["отутюженный", "выглаженный"],
    "отглаживав": ["отглаживавши"],
    "отглаживавши": ["отглаживав"],
    "отгламурив": ["отгламуривши"],
    "отгламуривши": ["отгламурив"],
    "отглатывав": ["отглатывавши"],
    "отглатывавши": ["отглатывав"],
    "отглодав": ["отглодавши"],
    "отглодавши": ["отглодав"],
    "отглотнув": ["отглотнувши"],
    "отглотнувши": ["отглотнув"],
    "отглядев": ["отглядевши"],
    "отглядевши": ["отглядев"],
    "отглянцевав": ["отглянцевавши"],
    "отглянцевавши": ["отглянцевав"],
    "отгнив": ["отгнивши"],
    "отгнивав": ["отгнивавши"],
    "отгнивавши": ["отгнивав"],
    "отгнивши": ["отгнив"],
    "отговаривав": ["отговаривавши"],
    "отговаривавши": ["отговаривав"],
    "отговев": ["отговевши"],
    "отговевши": ["отговев"],
    "отговорив": ["отговоривши"],
    "отговоривши": ["отговорив"],
    "отговорить": ["разубедить", "замолчать"],
    "отговориться": ["отвертеться"],
    "отговорност": ["ответственост"],
    "отговоры": ["просьба", "уговор"],
    "отголосив": ["отголосивши"],
    "отголосивши": ["отголосив"],
    "отголосок": ["отзвук", "эхо"],
    "отголубев": ["отголубевши"],
    "отголубевши": ["отголубев"],
    "отгоняв": ["отгонявши"],
    "отгонявши": ["отгоняв"],
    "отгорав": ["отгоравши"],
    "отгоравши": ["отгорав"],
    "отгораживав": ["отгораживавши"],
    "отгораживавши": ["отгораживав"],
    "отгораживаться": ["обособляться"],
    "отгорев": ["отгоревши"],
    "отгоревав": ["отгоревавши"],
    "отгоревавши": ["отгоревав"],
    "отгоревши": ["отгорев"],
    "отгородив": ["отгородивши"],
    "отгородивши": ["отгородив"],
    "отгостив": ["отгостивши"],
    "отгостивши": ["отгостив"],
    "отготовив": ["отготовивши"],
    "отготовивши": ["отготовив"],
    "отгравировав": ["отгравировавши"],
    "отгравировавши": ["отгравировав"],
    "отградуировав": ["отградуировавши"],
    "отградуировавши": ["отградуировав"],
    "отгранив": ["отгранивши"],
    "отгранивав": ["отгранивавши"],
    "отгранивавши": ["отгранивав"],
    "отгранивши": ["отгранив"],
    "отграничив": ["отграничивши"],
    "отграничивав": ["отграничивавши"],
    "отграничивавши": ["отграничивав"],
    "отграничивать": ["разграничивать"],
    "отграничивши": ["отграничив"],
    "отграфив": ["отграфивши"],
    "отграфивши": ["отграфив"],
    "отграфляв": ["отграфлявши"],
    "отграфлявши": ["отграфляв"],
    "отгребав": ["отгребавши"],
    "отгребавши": ["отгребав"],
    "отгрейдировав": ["отгрейдировавши"],
    "отгрейдировавши": ["отгрейдировав"],
    "отгремев": ["отгремевши"],
    "отгремевши": ["отгремев"],
    "отгромыхав": ["отгромыхавши"],
    "отгромыхавши": ["отгромыхав"],
    "отгрохав": ["отгрохавши"],
    "отгрохавши": ["отгрохав"],
    "отгрохотав": ["отгрохотавши"],
    "отгрохотавши": ["отгрохотав"],
    "отгружав": ["отгружавши"],
    "отгружавши": ["отгружав"],
    "отгрузив": ["отгрузивши"],
    "отгрузивши": ["отгрузив"],
    "отгрузка": ["поставка"],
    "отгрустив": ["отгрустивши"],
    "отгрустивши": ["отгрустив"],
    "отгрызав": ["отгрызавши"],
    "отгрызавши": ["отгрызав"],
    "отгрянув": ["отгрянувши"],
    "отгрянувши": ["отгрянув"],
    "отгудев": ["отгудевши"],
    "отгудевши": ["отгудев"],
    "отгуливав": ["отгуливавши"],
    "отгуливавши": ["отгуливав"],
    "отгуливать": ["прогуливать", "отлынивать", "увиливать"],
    "отгулье": ["отгул", "голк", "отголосок", "отголосье", "паголосье", "поголос", "паголос", "вторье", "зык", "позык", "пазык", "рай"],
    "отгуляв": ["отгулявши"],
    "отгулявши": ["отгуляв"],
    "отдавав": ["отдававши"],
    "отдававши": ["отдавав"],
    "отдавать предпочтение": ["предпочитать"],
    "отдавать себе отчёт": ["осознавать"],
    "отдавать честь": ["козырять", "брать под козырёк"],
    "отдавив": ["отдавивши"],
    "отдавивши": ["отдавив"],
    "отдавливав": ["отдавливавши"],
    "отдавливавши": ["отдавливав"],
    "отдавши": ["отдав"],
    "отдаивав": ["отдаивавши"],
    "отдаивавши": ["отдаивав"],
    "отдаленье": ["отдаление"],
    "отдалив": ["отдаливши"],
    "отдаливши": ["отдалив"],
    "отдалиться": ["удалиться"],
    "отдаляв": ["отдалявши"],
    "отдалявши": ["отдаляв"],
    "отдалённо": ["вдалеке", "косвенно", "слабо", "мало"],
    "отдалённый": ["удалённый"],
    "отданье": ["отдание"],
    "отдарив": ["отдаривши"],
    "отдаривав": ["отдаривавши"],
    "отдаривавши": ["отдаривав"],
    "отдаривши": ["отдарив"],
    "отдарок": ["дар"],
    "отдать": ["вернуть", "избавиться", "подарить", "продать", "выдать", "поместить", "переместить", "заплатить", "присудить", "посвятить", "откатиться", "отпустить", "потерять"],
    "отдать концы": ["отдать швартовы"],
    "отдача": ["закачка"],
    "отдающий": ["дающий"],
    "отдвигав": ["отдвигавши"],
    "отдвигавши": ["отдвигав"],
    "отдвинув": ["отдвинувши"],
    "отдвинувши": ["отдвинув"],
    "отдев": ["отдевши"],
    "отдевав": ["отдевавши"],
    "отдевавши": ["отдевав"],
    "отдевши": ["отдев"],
    "отдежурив": ["отдежуривши"],
    "отдежуривав": ["отдежуривавши"],
    "отдежуривавши": ["отдежуривав"],
    "отдежуривши": ["отдежурив"],
    "отдекатировав": ["отдекатировавши"],
    "отдекатировавши": ["отдекатировав"],
    "отдел": ["подразделение", "раздел", "секция"],
    "отдел народного образования": ["оно"],
    "отдел реализации": ["отдел продаж"],
    "отделав": ["отделавши"],
    "отделавши": ["отделав"],
    "отделение": ["обособление", "отдел", "департамент"],
    "отделив": ["отделивши"],
    "отделивши": ["отделив"],
    "отделка": ["ремонт"],
    "отделывав": ["отделывавши"],
    "отделывавши": ["отделывав"],
    "отдельно": ["обособленно", "индивидуально", "сепаратно", "изолированно", "раздельно", "порознь", "особо", "разрозненно"],
    "отдельный": ["обособленный", "изолированный", "специальный", "единичный", "некоторый"],
    "отдельский": ["отдельческий"],
    "отделяв": ["отделявши"],
    "отделявши": ["отделяв"],
    "отделять": ["отъединять"],
    "отделять зёрна от плевел": ["отделять мух от котлет"],
    "отдиктовав": ["отдиктовавши"],
    "отдиктовавши": ["отдиктовав"],
    "отдиктовывав": ["отдиктовывавши"],
    "отдиктовывавши": ["отдиктовывав"],
    "отдирав": ["отдиравши"],
    "отдиравши": ["отдирав"],
    "отдирижировав": ["отдирижировавши"],
    "отдирижировавши": ["отдирижировав"],
    "отдифференцировав": ["отдифференцировавши"],
    "отдифференцировавши": ["отдифференцировав"],
    "отдневав": ["отдневавши"],
    "отдневавши": ["отдневав"],
    "отдневалив": ["отдневаливши"],
    "отдневаливши": ["отдневалив"],
    "отдоив": ["отдоивши"],
    "отдоивши": ["отдоив"],
    "отдолдонив": ["отдолдонивши"],
    "отдолдонивши": ["отдолдонив"],
    "отдохновение": ["отдых"],
    "отдохновенье": ["отдохновение", "отдых"],
    "отдохновив": ["отдохновивши"],
    "отдохновивши": ["отдохновив"],
    "отдохновляв": ["отдохновлявши"],
    "отдохновлявши": ["отдохновляв"],
    "отдохнув": ["отдохнувши"],
    "отдохнувши": ["отдохнув"],
    "отдохнуть": ["передохнуть", "прийти в себя"],
    "отдраив": ["отдраивши"],
    "отдраивав": ["отдраивавши"],
    "отдраивавши": ["отдраивав"],
    "отдраивши": ["отдраив"],
    "отдрапаться": ["отбегаться"],
    "отдрейфовав": ["отдрейфовавши"],
    "отдрейфовавши": ["отдрейфовав"],
    "отдрессировав": ["отдрессировавши"],
    "отдрессировавши": ["отдрессировав"],
    "отдрюкав": ["отдрюкавши"],
    "отдрюкавши": ["отдрюкав"],
    "отдрючив": ["отдрючивши"],
    "отдрючивши": ["отдрючив"],
    "отдубасив": ["отдубасивши"],
    "отдубасивши": ["отдубасив"],
    "отдув": ["отдувши"],
    "отдував": ["отдувавши"],
    "отдувавши": ["отдував"],
    "отдувши": ["отдув"],
    "отдумав": ["отдумавши"],
    "отдумавши": ["отдумав"],
    "отдумать": ["передумать"],
    "отдумывав": ["отдумывавши"],
    "отдумывавши": ["отдумывав"],
    "отдуплить": ["вдуплить", "раздуплить"],
    "отдуплиться": ["раздуплиться", "разобраться", "вникнуть", "завершить", "закончить", "окончить", "выполнить", "развеяться"],
    "отдуться": ["оттопыриться", "отговориться", "отпереться", "отбрехаться"],
    "отдушивав": ["отдушивавши"],
    "отдушивавши": ["отдушивав"],
    "отдушивать": ["ароматизировать"],
    "отдушина": ["продушина", "отдушник", "душник"],
    "отдушник": ["душник", "отдушина"],
    "отдымив": ["отдымивши"],
    "отдымивши": ["отдымив"],
    "отдых": ["отдохновение"],
    "отдыхав": ["отдыхавши"],
    "отдыхавши": ["отдыхав"],
    "отдыхайка": ["отдыхающий"],
    "отдыхайль": ["отдых"],
    "отдышав": ["отдышавши"],
    "отдышавши": ["отдышав"],
    "отдёргав": ["отдёргавши"],
    "отдёргавши": ["отдёргав"],
    "отдёргивав": ["отдёргивавши"],
    "отдёргивавши": ["отдёргивав"],
    "отдёрнув": ["отдёрнувши"],
    "отдёрнувши": ["отдёрнув"],
    "отекав": ["отекавши"],
    "отекавши": ["отекав"],
    "отелив": ["отеливши"],
    "отеливши": ["отелив"],
    "отель": ["гостиница"],
    "отемнев": ["отемневши"],
    "отемневши": ["отемнев"],
    "отемнив": ["отемнивши"],
    "отемнивши": ["отемнив"],
    "отемняв": ["отемнявши"],
    "отемнявши": ["отемняв"],
    "отенив": ["отенивши"],
    "отенивши": ["отенив"],
    "отеняв": ["отенявши"],
    "отенявши": ["отеняв"],
    "отеплив": ["отепливши"],
    "отепливши": ["отеплив"],
    "отепляв": ["отеплявши"],
    "отеплявши": ["отепляв"],
    "отерев": ["отёрши"],
    "отереть": ["вытереть", "обтереть", "стереть", "утереть"],
    "отерпнув": ["отерпнувши"],
    "отерпнувши": ["отерпнув"],
    "отесав": ["отесавши"],
    "отесавши": ["отесав"],
    "отец": ["бог отец", "отец небесный"],
    "отець": ["батько", "тато"],
    "отеческий": ["отцовский", "отчий"],
    "отечество": ["отчизна", "родина"],
    "отечествоведение": ["россиеведение"],
    "отечь": ["затечь", "оплыть"],
    "отжав": ["отжавши"],
    "отжавши": ["отжав"],
    "отжарив": ["отжаривши"],
    "отжаривав": ["отжаривавши"],
    "отжаривавши": ["отжаривав"],
    "отжаривши": ["отжарив"],
    "отжать": ["выжать", "вскрыть", "отделить", "отпустить", "ослабить", "оттеснить", "оттереть", "отодвинуть", "отогнать", "забрать", "захватить", "отнять", "отобрать"],
    "отжевав": ["отжевавши"],
    "отжевавши": ["отжевав"],
    "отженив": ["отженивши"],
    "отженивши": ["отженив"],
    "отжечь": ["отчебучить", "отмочить"],
    "отжив": ["отживши"],
    "отживав": ["отживавши"],
    "отживавши": ["отживав"],
    "отживелица": ["отживялост", "преживелица", "архаизъм", "анахронизъм"],
    "отживив": ["отжививши"],
    "отжививши": ["отживив"],
    "отживляв": ["отживлявши"],
    "отживлявши": ["отживляв"],
    "отживши": ["отжив"],
    "отжигав": ["отжигавши"],
    "отжигавши": ["отжигав"],
    "отжилив": ["отжиливши"],
    "отжиливав": ["отжиливавши"],
    "отжиливавши": ["отжиливав"],
    "отжиливши": ["отжилив"],
    "отжилок": ["ответвление"],
    "отжимав": ["отжимавши"],
    "отжимавши": ["отжимав"],
    "отжимание": ["выжимание", "отжим", "отжимка", "толкание"],
    "отжимать": ["выжимать", "отпускать", "ослаблять", "оттеснять", "оттирать", "отодвигать", "отнимать", "отбирать", "присваивать", "захапывать"],
    "отжинав": ["отжинавши"],
    "отжинавши": ["отжинав"],
    "отжировав": ["отжировавши"],
    "отжировавши": ["отжировав"],
    "отжитие": ["отживание"],
    "отжужжав": ["отжужжавши"],
    "отжужжавши": ["отжужжав"],
    "отжурив": ["отжуривши"],
    "отжуривши": ["отжурив"],
    "отжучив": ["отжучивши"],
    "отжучивши": ["отжучив"],
    "отжёвывав": ["отжёвывавши"],
    "отжёвывавши": ["отжёвывав"],
    "отзавтракав": ["отзавтракавши"],
    "отзавтракавши": ["отзавтракав"],
    "отзаседав": ["отзаседавши"],
    "отзаседавши": ["отзаседав"],
    "отзванивав": ["отзванивавши"],
    "отзванивавши": ["отзванивав"],
    "отзвенев": ["отзвеневши"],
    "отзвеневши": ["отзвенев"],
    "отзвенеть": ["затихнуть", "прозвенеть"],
    "отзвонив": ["отзвонивши"],
    "отзвонивши": ["отзвонив"],
    "отзвук": ["эхо", "отклик", "отголосок", "отсвет"],
    "отзвучав": ["отзвучавши"],
    "отзвучавши": ["отзвучав"],
    "отзив": ["мнение", "преценка", "оценка"],
    "отзимовав": ["отзимовавши"],
    "отзимовавши": ["отзимовав"],
    "отзол": ["отзолка"],
    "отзолив": ["отзоливши"],
    "отзоливши": ["отзолив"],
    "отзубрив": ["отзубривши"],
    "отзубривши": ["отзубрив"],
    "отзыв": ["ответ", "отклик", "отзвук", "эхо", "ответное чувство", "суждение"],
    "отзывав": ["отзывавши"],
    "отзывавши": ["отзывав"],
    "отзывчивый": ["чуткий", "участливый", "заботливый", "внимательный"],
    "отиатр": ["отолог", "ушник"],
    "отиатрия": ["отология"],
    "отинуда": ["отинуде", "отинуду", "отинуды", "отинудь"],
    "отирав": ["отиравши"],
    "отиравши": ["отирав"],
    "отирать": ["обтирать"],
    "отиш": ["фейерверк"],
    "отйот": ["отийот"],
    "откаблучив": ["откаблучивши"],
    "откаблучивав": ["откаблучивавши"],
    "откаблучивавши": ["откаблучивав"],
    "откаблучивши": ["откаблучив"],
    "отказ": ["отрицание", "поломка", "порча", "сбой"],
    "отказав": ["отказавши"],
    "отказавши": ["отказав"],
    "отказать": ["сломаться"],
    "отказополучатель": ["легатарий"],
    "отказывав": ["отказывавши"],
    "отказывавши": ["отказывав"],
    "отказывать": ["возражать", "отрицать", "некать", "плохеть", "плошать", "лениться", "замирать"],
    "отказываться": ["не соглашаться", "отвергать"],
    "откалибровав": ["откалибровавши"],
    "откалибровавши": ["откалибровав"],
    "откалибровывав": ["откалибровывавши"],
    "откалибровывавши": ["откалибровывав"],
    "откалывав": ["откалывавши"],
    "откалывавши": ["откалывав"],
    "откапав": ["откапавши"],
    "откапавши": ["откапав"],
    "откапнув": ["откапнувши"],
    "откапнувши": ["откапнув"],
    "откапывав": ["откапывавши"],
    "откапывавши": ["откапывав"],
    "откапывать": ["выкапывать"],
    "откармливав": ["откармливавши"],
    "откармливавши": ["откармливав"],
    "откармливаться": ["отъедаться"],
    "откат": ["откатывание", "отдача", "отступление", "отмена", "возврат", "взятка", "скат", "склон", "уклон"],
    "откатав": ["откатавши"],
    "откатавши": ["откатав"],
    "откатив": ["откативши"],
    "откативши": ["откатив"],
    "откатывав": ["откатывавши"],
    "откатывавши": ["откатывав"],
    "откачав": ["откачавши"],
    "откачавши": ["откачав"],
    "откачать": ["выкачать", "реанимировать"],
    "откачивав": ["откачивавши"],
    "откачивавши": ["откачивав"],
    "откачивать": ["выкачивать"],
    "откачнув": ["откачнувши"],
    "откачнувши": ["откачнув"],
    "откашивав": ["откашивавши"],
    "откашивавши": ["откашивав"],
    "откашливав": ["откашливавши"],
    "откашливавши": ["откашливав"],
    "откашливанье": ["откашливание"],
    "откашляв": ["откашлявши"],
    "откашлявши": ["откашляв"],
    "откашлянув": ["откашлянувши"],
    "откашлянувши": ["откашлянув"],
    "отквасив": ["отквасивши"],
    "отквасивши": ["отквасив"],
    "отквитав": ["отквитавши"],
    "отквитавши": ["отквитав"],
    "отквитывав": ["отквитывавши"],
    "отквитывавши": ["отквитывав"],
    "откешиться": ["обналичить", "выйти в кеш"],
    "откидав": ["откидавши"],
    "откидавши": ["откидав"],
    "откидаться": ["отбросаться"],
    "откидной": ["откидывающийся", "отгибающийся"],
    "откидывав": ["откидывавши"],
    "откидывавши": ["откидывав"],
    "откинув": ["откинувши"],
    "откинувши": ["откинув"],
    "откинуть": ["отбросить", "запрокинуть", "сбросить со счетов"],
    "откипав": ["откипавши"],
    "откипавши": ["откипав"],
    "откипев": ["откипевши"],
    "откипевши": ["откипев"],
    "откисать": ["отмокать"],
    "откиснуть": ["отмокнуть"],
    "откладывав": ["откладывавши"],
    "откладывавши": ["откладывав"],
    "откладыванье": ["откладывание"],
    "откладывать": ["переносить", "класть"],
    "отклевав": ["отклевавши"],
    "отклевавши": ["отклевав"],
    "отклеив": ["отклеивши"],
    "отклеивав": ["отклеивавши"],
    "отклеивавши": ["отклеивав"],
    "отклеивать": ["отлеплять"],
    "отклеиваться": ["отлипать"],
    "отклеивши": ["отклеив"],
    "отклеиться": ["отлепиться"],
    "отклепав": ["отклепавши"],
    "отклепавши": ["отклепав"],
    "откликав": ["откликавши"],
    "откликавши": ["откликав"],
    "отклонение": ["несовпадение", "расхождение"],
    "отклоненье": ["отклонение"],
    "отклонив": ["отклонивши"],
    "отклонивши": ["отклонив"],
    "отклонировав": ["отклонировавши"],
    "отклонировавши": ["отклонировав"],
    "отклоняв": ["отклонявши"],
    "отклонявши": ["отклоняв"],
    "отключав": ["отключавши"],
    "отключавши": ["отключав"],
    "отключаться": ["выключаться", "отсоединяться"],
    "отключение": ["отсоединение"],
    "отключив": ["отключивши"],
    "отключивши": ["отключив"],
    "отключённость": ["выключенность", "отстраненность"],
    "отключённый": ["выключенный", "вырубленный", "обесточенный", "отсоединённый", "разъединённый"],
    "отклячив": ["отклячивши"],
    "отклячивав": ["отклячивавши"],
    "отклячивавши": ["отклячивав"],
    "отклячивши": ["отклячив"],
    "отклёвывав": ["отклёвывавши"],
    "отклёвывавши": ["отклёвывав"],
    "отклёпывав": ["отклёпывавши"],
    "отклёпывавши": ["отклёпывав"],
    "отковав": ["отковавши"],
    "отковавши": ["отковав"],
    "отковывав": ["отковывавши"],
    "отковывавши": ["отковывав"],
    "отковыляв": ["отковылявши"],
    "отковылявши": ["отковыляв"],
    "отковыривав": ["отковыривавши"],
    "отковыривавши": ["отковыривав"],
    "отковырнув": ["отковырнувши"],
    "отковырнувши": ["отковырнув"],
    "отковыряв": ["отковырявши"],
    "отковырявши": ["отковыряв"],
    "отковырять": ["выкопать"],
    "откозырнув": ["откозырнувши"],
    "откозырнувши": ["откозырнув"],
    "откозыряв": ["откозырявши"],
    "откозырявши": ["откозыряв"],
    "откокав": ["откокавши"],
    "откокавши": ["откокав"],
    "откокнув": ["откокнувши"],
    "откокнувши": ["откокнув"],
    "откол": ["откалывание", "отколка", "осколок"],
    "отколачивав": ["отколачивавши"],
    "отколачивавши": ["отколачивав"],
    "отколашиваться": ["отколоситься", "выколоситься"],
    "отколдовав": ["отколдовавши"],
    "отколдовавши": ["отколдовав"],
    "отколов": ["отколовши"],
    "отколовши": ["отколов"],
    "отколоситься": ["выколоситься"],
    "отколотив": ["отколотивши"],
    "отколотивши": ["отколотив"],
    "отколошматив": ["отколошмативши"],
    "отколошмативши": ["отколошматив"],
    "отколупав": ["отколупавши"],
    "отколупавши": ["отколупав"],
    "отколупнув": ["отколупнувши"],
    "отколупнувши": ["отколупнув"],
    "отколупывав": ["отколупывавши"],
    "отколупывавши": ["отколупывав"],
    "отколь": ["откуда", "откель", "откедова"],
    "откомандировав": ["откомандировавши"],
    "откомандировавши": ["откомандировав"],
    "откомандировать": ["командировать"],
    "откомандировывав": ["откомандировывавши"],
    "откомандировывавши": ["откомандировывав"],
    "откомандовав": ["откомандовавши"],
    "откомандовавши": ["откомандовав"],
    "откомиссовав": ["откомиссовавши"],
    "откомиссовавши": ["откомиссовав"],
    "откомиссовать": ["комиссовать"],
    "откомментировав": ["откомментировавши"],
    "откомментировавши": ["откомментировав"],
    "откомпилировать": ["скомпилировать"],
    "отконвертировав": ["отконвертировавши"],
    "отконвертировавши": ["отконвертировав"],
    "отконвоировав": ["отконвоировавши"],
    "отконвоировавши": ["отконвоировав"],
    "отконопатив": ["отконопативши"],
    "отконопативши": ["отконопатив"],
    "отконопачивав": ["отконопачивавши"],
    "отконопачивавши": ["отконопачивав"],
    "откопав": ["откопавши"],
    "откопавши": ["откопав"],
    "откопка": ["откапывание"],
    "откормив": ["откормивши"],
    "откормивши": ["откормив"],
    "откормочный": ["откармливаемый"],
    "откормыш": ["откормок"],
    "откорректировав": ["откорректировавши"],
    "откорректировавши": ["откорректировав"],
    "откос": ["склон", "уклон", "косогор", "покатость", "подкос"],
    "откосив": ["откосивши"],
    "откосивши": ["откосив"],
    "откосить": ["уклониться"],
    "откостыляв": ["откостылявши"],
    "откостылявши": ["откостыляв"],
    "откочевав": ["откочевавши"],
    "откочевавши": ["откочевав"],
    "откочёвывав": ["откочёвывавши"],
    "откочёвывавши": ["откочёвывав"],
    "откраивав": ["откраивавши"],
    "откраивавши": ["откраивав"],
    "открамсывав": ["открамсывавши"],
    "открамсывавши": ["открамсывав"],
    "открасив": ["открасивши"],
    "открасивши": ["открасив"],
    "открахмалив": ["открахмаливши"],
    "открахмаливав": ["открахмаливавши"],
    "открахмаливавши": ["открахмаливав"],
    "открахмаливши": ["открахмалив"],
    "открашивав": ["открашивавши"],
    "открашивавши": ["открашивав"],
    "открепивши": ["открепив"],
    "открепляв": ["откреплявши"],
    "откреплявши": ["открепляв"],
    "откристаллизовав": ["откристаллизовавши"],
    "откристаллизовавши": ["откристаллизовав"],
    "откристаллизовывав": ["откристаллизовывавши"],
    "откристаллизовывавши": ["откристаллизовывав"],
    "откричав": ["откричавши"],
    "откричавши": ["откричав"],
    "откровеннейший": ["искреннейший"],
    "откровенничав": ["откровенничавши"],
    "откровенничавши": ["откровенничав"],
    "откровенно": ["честно", "открыто", "искренне", "как на духу", "не таясь", "без утайки"],
    "откровенный": ["искренний", "очевидный", "раскованный"],
    "откровенье": ["откровение"],
    "откроив": ["откроивши"],
    "откроивши": ["откроив"],
    "откромсав": ["откромсавши"],
    "откромсавши": ["откромсав"],
    "откружив": ["откруживши"],
    "откруживши": ["откружив"],
    "открутив": ["открутивши"],
    "открутивши": ["открутив"],
    "открутиться": ["отвинтиться", "отвертеться", "уклониться", "отделаться"],
    "откручивав": ["откручивавши"],
    "откручивавши": ["откручивав"],
    "открыв": ["открывши"],
    "открывав": ["открывавши"],
    "открывавши": ["открывав"],
    "открывалка": ["открывашка"],
    "открывание": ["открытие"],
    "открываться": ["отворяться", "раскрываться", "разворачиваться", "разъясняться", "начинаться", "признаваться"],
    "открывашка": ["открывалка", "консервный нож", "пепельница"],
    "открывши": ["открыв"],
    "открыжив": ["открыживши"],
    "открыживши": ["открыжив"],
    "открытие": ["открытье", "раскрытие", "начало", "находка"],
    "открытое море": ["голомя", "голомень"],
    "открыточник": ["филокартист"],
    "открытым текстом": ["бесхитростно", "объективно", "честно", "без утайки", "прямым текстом"],
    "открыть": ["раскрыть", "распахнуть", "обнажить", "развернуть", "включить", "запустить", "начать", "обнаружить"],
    "открыть огонь": ["застрелять"],
    "открытье": ["открытие"],
    "отксерив": ["отксеривши"],
    "отксеривав": ["отксеривавши"],
    "отксеривавши": ["отксеривав"],
    "отксеривши": ["отксерив"],
    "отксерить": ["отксерокопировать", "отфотокопировать", "откопировать", "отканонить", "отэрить", "отсинить"],
    "отксерокопировав": ["отксерокопировавши"],
    "отксерокопировавши": ["отксерокопировав"],
    "отксерокопировать": ["отфотокопировать", "откопировать", "отксерить", "отканонить", "отэрить", "отсинить"],
    "отксерокопироваться": ["отфотокопироваться", "откопироваться", "отксериться"],
    "откуда": ["откедова", "откель", "отколь", "откудова", "отколе", "отколева", "откуль", "откулева", "откуля", "откуды", "откулича", "отколича", "откелича", "откулинька", "откелева"],
    "откуда ни возьмись": ["как из пизды на лыжах"],
    "откуда-либо": ["откуда-нибудь"],
    "откуда-нибудь": ["откуда-либо"],
    "откудова": ["откуда", "откедова", "откель", "отколь", "отколе", "отколева", "откуль", "откулева", "откуля", "откуды", "откулича", "отколича", "откелича", "откулинька", "откелева"],
    "откуковав": ["откуковавши"],
    "откуковавши": ["откуковав"],
    "откупав": ["откупавши"],
    "откупавши": ["откупав"],
    "откупив": ["откупивши"],
    "откупивши": ["откупив"],
    "откупорив": ["откупоривши"],
    "откупоривав": ["откупоривавши"],
    "откупоривавши": ["откупоривав"],
    "откупоривание": ["раскупоривание", "откупорка"],
    "откупориваться": ["раскупориваться"],
    "откупоривши": ["откупорив"],
    "откупорить": ["раскупорить"],
    "откупориться": ["раскупориться"],
    "откупорка": ["откупоривание", "раскупорка"],
    "откупщик": ["рантье"],
    "откусав": ["откусавши"],
    "откусавши": ["откусав"],
    "откусив": ["откусивши"],
    "откусивши": ["откусив"],
    "откусывав": ["откусывавши"],
    "откусывавши": ["откусывав"],
    "откутав": ["откутавши"],
    "откутавши": ["откутав"],
    "откутаться": ["раскутаться"],
    "откутывав": ["откутывавши"],
    "откутывавши": ["откутывав"],
    "откутываться": ["раскутываться"],
    "откушав": ["откушавши"],
    "откушавши": ["откушав"],
    "откъс": ["парче", "част", "отрязък", "фрагмент"],
    "откъслек": ["отломък", "парче", "откъс", "част", "къс", "фрагмент"],
    "отлавировав": ["отлавировавши"],
    "отлавировавши": ["отлавировав"],
    "отлавливав": ["отлавливавши"],
    "отлавливавши": ["отлавливав"],
    "отлагав": ["отлагавши"],
    "отлагавши": ["отлагав"],
    "отлагательство": ["отсрочка", "прокрастинация"],
    "отладив": ["отладивши"],
    "отладивши": ["отладив"],
    "отладчик": ["наладчик"],
    "отлаженность": ["отточенность", "налаженность", "настройка"],
    "отлаживав": ["отлаживавши"],
    "отлаживавши": ["отлаживав"],
    "отлазив": ["отлазивши"],
    "отлазивши": ["отлазив"],
    "отлаивав": ["отлаивавши"],
    "отлаивавши": ["отлаивав"],
    "отлакировав": ["отлакировавши"],
    "отлакировавши": ["отлакировав"],
    "отлакировывав": ["отлакировывавши"],
    "отлакировывавши": ["отлакировывав"],
    "отламывав": ["отламывавши"],
    "отламывавши": ["отламывав"],
    "отламывая": ["уламывая"],
    "отлаяв": ["отлаявши"],
    "отлаявши": ["отлаяв"],
    "отлегав": ["отлегавши"],
    "отлегавши": ["отлегав"],
    "отлегло от сердца": ["отлегло на душе"],
    "отлежав": ["отлежавши"],
    "отлежавши": ["отлежав"],
    "отлезав": ["отлезавши"],
    "отлезавши": ["отлезав"],
    "отлепив": ["отлепивши"],
    "отлепивши": ["отлепив"],
    "отлепка": ["отлепок"],
    "отлепливав": ["отлепливавши"],
    "отлепливавши": ["отлепливав"],
    "отлепливать": ["отлеплять"],
    "отлепляв": ["отлеплявши"],
    "отлеплявши": ["отлепляв"],
    "отлеплять": ["отлепливать"],
    "отлетав": ["отлетавши"],
    "отлетавши": ["отлетав"],
    "отлетев": ["отлетевши"],
    "отлетевши": ["отлетев"],
    "отлететь": ["улететь"],
    "отлив": ["отливание", "отток", "малая вода", "сухая вода", "убылая вода", "куйпога", "убывание", "отсвет", "отблеск", "оттенок", "литораль", "переток", "перетекание", "литьё", "отливка"],
    "отливав": ["отливавши"],
    "отливавши": ["отливав"],
    "отливанье": ["отливание"],
    "отливать пули": ["вешать лапшу на уши"],
    "отливши": ["отлив"],
    "отлизав": ["отлизавши"],
    "отлизавши": ["отлизав"],
    "отлизывав": ["отлизывавши"],
    "отлизывавши": ["отлизывав"],
    "отликовав": ["отликовавши"],
    "отликовавши": ["отликовав"],
    "отлиняв": ["отлинявши"],
    "отлинявши": ["отлиняв"],
    "отлипав": ["отлипавши"],
    "отлипавши": ["отлипав"],
    "отлипаться": ["отлипать", "отклеиваться"],
    "отлипнув": ["отлипнувши"],
    "отлипнувши": ["отлипнув"],
    "отлитографировав": ["отлитографировавши"],
    "отлитографировавши": ["отлитографировав"],
    "отлицензировав": ["отлицензировавши"],
    "отлицензировавши": ["отлицензировав"],
    "отличав": ["отличавши"],
    "отличавши": ["отличав"],
    "отличаться": ["выделяться", "характеризоваться"],
    "отличив": ["отличивши"],
    "отличивши": ["отличив"],
    "отличие": ["различие", "разница", "отличность"],
    "отличнейший": ["наилучший"],
    "отлично": ["великолепно", "превосходно", "прекрасно", "хорошо", "ладно", "окей", "иначе", "по-другому", "пять", "пятёрка"],
    "отличность": ["отличие"],
    "отличный": ["иной", "непохожий", "выделяющийся", "отличающийся"],
    "отличье": ["отличие"],
    "отловив": ["отловивши"],
    "отловивши": ["отловив"],
    "отлогий": ["пологий", "покатый"],
    "отлогость": ["пологость"],
    "отложенье": ["отложение"],
    "отложив": ["отложивши"],
    "отложивши": ["отложив"],
    "отложительный": ["аблатив"],
    "отложительный падеж": ["элатив", "элятив", "аблатив", "исходный падеж"],
    "отложить личинку": ["покакать", "посрать"],
    "отломав": ["отломавши"],
    "отломавши": ["отломав"],
    "отломаться": ["отломиться"],
    "отломив": ["отломивши"],
    "отломивши": ["отломив"],
    "отлудив": ["отлудивши"],
    "отлудивши": ["отлудив"],
    "отлуп": ["трещина", "отлупка"],
    "отлупив": ["отлупивши"],
    "отлупивши": ["отлупив"],
    "отлупить": ["отхлестать", "выпороть", "отшлёпать"],
    "отлупливав": ["отлупливавши"],
    "отлупливавши": ["отлупливав"],
    "отлупливать": ["отлуплять"],
    "отлупливаться": ["отлупляться"],
    "отлупляв": ["отлуплявши"],
    "отлуплявши": ["отлупляв"],
    "отлуплять": ["отлупливать"],
    "отлупляться": ["отлупливаться"],
    "отлупцевав": ["отлупцевавши"],
    "отлупцевавши": ["отлупцевав"],
    "отлучав": ["отлучавши"],
    "отлучавши": ["отлучав"],
    "отлученье": ["отлучение"],
    "отлучив": ["отлучивши"],
    "отлучивши": ["отлучив"],
    "отлучить": ["дать от ворот поворот", "отвергнуть", "отнять", "отстранить", "отторгнуть", "попереть", "указать на дверь", "выгнать", "выдворить", "выпереть", "вытеснить", "вышвырнуть", "отдалить", "отделить", "прогнать"],
    "отлынивав": ["отлынивавши"],
    "отлынивавши": ["отлынивав"],
    "отлынивать": ["уклоняться", "увиливать", "отвиливать", "вертеться", "вилять", "отбиваться", "отбояриваться", "филонить", "откручиваться", "отбрыкиваться", "придуриваться", "сачковать", "лынять", "лытать"],
    "отлынув": ["отлынувши"],
    "отлынувши": ["отлынув"],
    "отлыняв": ["отлынявши"],
    "отлынявши": ["отлыняв"],
    "отлытав": ["отлытавши"],
    "отлытавши": ["отлытав"],
    "отлюбив": ["отлюбивши"],
    "отлюбивши": ["отлюбив"],
    "отлютовав": ["отлютовавши"],
    "отлютовавши": ["отлютовав"],
    "отляпав": ["отляпавши"],
    "отляпавши": ["отляпав"],
    "отляпывав": ["отляпывавши"],
    "отляпывавши": ["отляпывав"],
    "отлёживав": ["отлёживавши"],
    "отлёживавши": ["отлёживав"],
    "отмазав": ["отмазавши"],
    "отмазавши": ["отмазав"],
    "отмазать": ["замазать", "промазать", "обмазать", "заштукатурить", "отштукатурить", "отклеить", "отшпаклевать", "обелить", "выгородить", "откупить", "откосить"],
    "отмазка": ["оправдание", "отговорка", "предлог", "отписка", "отмаза", "отмаз", "отмазон"],
    "отмазывав": ["отмазывавши"],
    "отмазывавши": ["отмазывав"],
    "отмазывать": ["выгораживать", "оправдывать", "обелять"],
    "отмазываться": ["оправдываться", "отмежёвываться", "отделываться"],
    "отмалевав": ["отмалевавши"],
    "отмалевавши": ["отмалевав"],
    "отмаливав": ["отмаливавши"],
    "отмаливавши": ["отмаливав"],
    "отмалывав": ["отмалывавши"],
    "отмалывавши": ["отмалывав"],
    "отмалёвывав": ["отмалёвывавши"],
    "отмалёвывавши": ["отмалёвывав"],
    "отманив": ["отманивши"],
    "отманивав": ["отманивавши"],
    "отманивавши": ["отманивав"],
    "отманивши": ["отманив"],
    "отмаркировав": ["отмаркировавши"],
    "отмаркировавши": ["отмаркировав"],
    "отмаршировав": ["отмаршировавши"],
    "отмаршировавши": ["отмаршировав"],
    "отматывав": ["отматывавши"],
    "отматывавши": ["отматывав"],
    "отматюгав": ["отматюгавши"],
    "отматюгавши": ["отматюгав"],
    "отмахав": ["отмахавши"],
    "отмахавши": ["отмахав"],
    "отмахивав": ["отмахивавши"],
    "отмахивавши": ["отмахивав"],
    "отмахнув": ["отмахнувши"],
    "отмахнувши": ["отмахнув"],
    "отмачивав": ["отмачивавши"],
    "отмачивавши": ["отмачивав"],
    "отмаяться": ["отмучиться"],
    "отмаячив": ["отмаячивши"],
    "отмаячивши": ["отмаячив"],
    "отмежевав": ["отмежевавши"],
    "отмежевавши": ["отмежевав"],
    "отмежёвывав": ["отмежёвывавши"],
    "отмежёвывавши": ["отмежёвывав"],
    "отмель": ["ёгра"],
    "отмелькав": ["отмелькавши"],
    "отмелькавши": ["отмелькав"],
    "отмена": ["упразднение"],
    "отменив": ["отменивши"],
    "отменивши": ["отменив"],
    "отменно": ["отлично", "превосходно", "очень", "в высшей степени", "весьма", "чрезвычайно", "иначе", "иным образом", "по-другому", "по-иному", "инако"],
    "отменный": ["превосходный"],
    "отменяв": ["отменявши"],
    "отменявши": ["отменяв"],
    "отмерев": ["отмерши"],
    "отмереть": ["омертветь", "умереть"],
    "отмерзав": ["отмерзавши"],
    "отмерзавши": ["отмерзав"],
    "отмерив": ["отмеривши"],
    "отмеривав": ["отмеривавши"],
    "отмеривавши": ["отмеривав"],
    "отмеривши": ["отмерив"],
    "отмерцав": ["отмерцавши"],
    "отмерцавши": ["отмерцав"],
    "отмерши": ["отмерев"],
    "отмеряв": ["отмерявши"],
    "отмерявши": ["отмеряв"],
    "отмесив": ["отмесивши"],
    "отмесивши": ["отмесив"],
    "отместка": ["отмщение", "отплата"],
    "отметав": ["отметавши"],
    "отметавши": ["отметав"],
    "отметелив": ["отметеливши"],
    "отметеливав": ["отметеливавши"],
    "отметеливавши": ["отметеливав"],
    "отметеливши": ["отметелив"],
    "отметив": ["отметивши"],
    "отметивши": ["отметив"],
    "отметить": ["пометить", "заметить", "подчеркнуть", "сказать", "отпраздновать"],
    "отметиться": ["зарегистрироваться", "выделиться"],
    "отмечав": ["отмечавши"],
    "отмечавши": ["отмечав"],
    "отмечаться": ["регистрироваться", "наблюдаться", "обнаруживаться"],
    "отмигав": ["отмигавши"],
    "отмигавши": ["отмигав"],
    "отминав": ["отминавши"],
    "отминавши": ["отминав"],
    "отминетить": ["отсосать", "отчмокать"],
    "отмирав": ["отмиравши"],
    "отмиравши": ["отмирав"],
    "отмирание": ["некроз"],
    "отмирать": ["омертвевать", "выветриваться", "уничтожаться", "исчезать", "исчезать без следа", "рассеиваться", "сходить на нет", "обращаться в ничто", "превращаться в ничто", "стираться", "утрачиваться", "исчезать бесследно", "развеиваться", "изглаживаться"],
    "отмитинговав": ["отмитинговавши"],
    "отмитинговавши": ["отмитинговав"],
    "отмобилизовав": ["отмобилизовавши"],
    "отмобилизовавши": ["отмобилизовав"],
    "отмобилизовывав": ["отмобилизовывавши"],
    "отмобилизовывавши": ["отмобилизовывав"],
    "отмока": ["обводнение"],
    "отмокав": ["отмокавши"],
    "отмокавши": ["отмокав"],
    "отмокнув": ["отмокнувши"],
    "отмокнувши": ["отмокнув"],
    "отмолачивав": ["отмолачивавши"],
    "отмолачивавши": ["отмолачивав"],
    "отмолвив": ["отмолвивши"],
    "отмолвивши": ["отмолвив"],
    "отмолив": ["отмоливши"],
    "отмоливши": ["отмолив"],
    "отмолов": ["отмоловши"],
    "отмоловши": ["отмолов"],
    "отмолотив": ["отмолотивши"],
    "отмолотивши": ["отмолотив"],
    "отмолчав": ["отмолчавши"],
    "отмолчавши": ["отмолчав"],
    "отмониторив": ["отмониторивши"],
    "отмониторивши": ["отмониторив"],
    "отмора": ["отдих", "почивка"],
    "отмораживав": ["отмораживавши"],
    "отмораживавши": ["отмораживав"],
    "отморозив": ["отморозивши"],
    "отморозивши": ["отморозив"],
    "отморозок": ["негодяй", "подонок", "выродок", "мерзавец", "подлец"],
    "отмостив": ["отмостивши"],
    "отмостивши": ["отмостив"],
    "отмотав": ["отмотавши"],
    "отмотавши": ["отмотав"],
    "отмочалив": ["отмочаливши"],
    "отмочаливав": ["отмочаливавши"],
    "отмочаливавши": ["отмочаливав"],
    "отмочаливши": ["отмочалив"],
    "отмочив": ["отмочивши"],
    "отмочивши": ["отмочив"],
    "отмочить": ["вымочить", "отчебучить", "отжечь"],
    "отмстив": ["отмстивши"],
    "отмстивши": ["отмстив"],
    "отмстить": ["отомстить"],
    "отмудохав": ["отмудохавши"],
    "отмудохавши": ["отмудохав"],
    "отмудохать": ["выкинуть", "выкинуть номер", "отчебучить"],
    "отмусолив": ["отмусоливши"],
    "отмусоливав": ["отмусоливавши"],
    "отмусоливавши": ["отмусоливав"],
    "отмусоливши": ["отмусолив"],
    "отмутив": ["отмутивши"],
    "отмутивши": ["отмутив"],
    "отмутузив": ["отмутузивши"],
    "отмутузивши": ["отмутузив"],
    "отмучив": ["отмучивши"],
    "отмучивав": ["отмучивавши"],
    "отмучивавши": ["отмучивав"],
    "отмучивши": ["отмучив"],
    "отмщав": ["отмщавши"],
    "отмщавши": ["отмщав"],
    "отмщать": ["отомщать", "мстить"],
    "отмщение": ["месть", "отместка", "мщение", "возмездие", "кара", "расплата"],
    "отмщенье": ["отмщение"],
    "отмывав": ["отмывавши"],
    "отмывавши": ["отмывав"],
    "отмывание": ["отмывалово"],
    "отмывши": ["отмыв"],
    "отмыкав": ["отмыкавши"],
    "отмыкавши": ["отмыкав"],
    "отмытарив": ["отмытаривши"],
    "отмытаривши": ["отмытарив"],
    "отмяв": ["отмявши"],
    "отмявши": ["отмяв"],
    "отмякав": ["отмякавши"],
    "отмякавши": ["отмякав"],
    "отмякнув": ["отмякнувши"],
    "отмякнувши": ["отмякнув"],
    "отмёрзнув": ["отмёрзнувши"],
    "отмёрзнувши": ["отмёрзнув"],
    "отначив": ["отначивши"],
    "отначивав": ["отначивавши"],
    "отначивавши": ["отначивав"],
    "отначивши": ["отначив"],
    "отнашивав": ["отнашивавши"],
    "отнашивавши": ["отнашивав"],
    "отнекиваться": ["отказываться", "отбрыкиваться", "ломаться"],
    "отнерестовав": ["отнерестовавши"],
    "отнерестовавши": ["отнерестовав"],
    "отнестись": ["воспринять", "оценить"],
    "отнизав": ["отнизавши"],
    "отнизавши": ["отнизав"],
    "отнизывав": ["отнизывавши"],
    "отнизывавши": ["отнизывав"],
    "отникелировав": ["отникелировавши"],
    "отникелировавши": ["отникелировав"],
    "отнимав": ["отнимавши"],
    "отнимавши": ["отнимав"],
    "отнимание": ["вычитание"],
    "отнимать": ["отбирать", "лишать", "занимать", "отводить", "отстранять", "отодвигать", "удалять", "ампутировать", "вычитать"],
    "относив": ["относивши"],
    "относивши": ["относив"],
    "относителност": ["релативност", "зависимост"],
    "относительно": ["сравнительно", "более или менее", "касательно", "что касается", "насчёт"],
    "относительность": ["условность", "неопределённость"],
    "относительный": ["сравнительный", "небольшой", "некоторый", "умеренный", "определённый", "условный"],
    "относиться": ["касаться", "иметь отношение", "иметь касательство", "принадлежать"],
    "относящийся": ["считающий", "думающий", "связанный", "касающийся", "затрагивающий", "входящий"],
    "отночевав": ["отночевавши"],
    "отночевавши": ["отночевав"],
    "отныне": ["впредь", "отселе", "отсель"],
    "отнюдь": ["вовсе", "совсем", "никоим образом"],
    "отняв": ["отнявши"],
    "отнявши": ["отняв"],
    "отнятый": ["лишённый", "отобранный"],
    "отнять": ["отобрать", "изъять", "отъять", "вычесть", "отдалить", "отвести", "ампутировать"],
    "отоантрит": ["антрит"],
    "отобедав": ["отобедавши"],
    "отобедавши": ["отобедав"],
    "отобедать": ["пообедать"],
    "отобравши": ["отобрав"],
    "отображав": ["отображавши"],
    "отображавши": ["отображав"],
    "отображение": ["функция"],
    "отображенье": ["отображение"],
    "отобразив": ["отобразивши"],
    "отобразивши": ["отобразив"],
    "отобрание": ["отбирание", "изъятие", "отбор"],
    "отобрать": ["отнять", "изъять", "конфисковать", "выбрать", "выделить", "избрать", "подобрать"],
    "отоварив": ["отоваривши"],
    "отоваривав": ["отоваривавши"],
    "отоваривавши": ["отоваривав"],
    "отоваривши": ["отоварив"],
    "отовариться": ["закупаться"],
    "отовладев": ["отовладевши"],
    "отовладевши": ["отовладев"],
    "отовсюду": ["изовсюду"],
    "отогнав": ["отогнавши"],
    "отогнавши": ["отогнав"],
    "отогнув": ["отогнувши"],
    "отогнувши": ["отогнув"],
    "отогревав": ["отогревавши"],
    "отогревавши": ["отогревав"],
    "отогревать": ["согревать", "греть"],
    "отогревши": ["отогрев"],
    "отогреть": ["согреть"],
    "отодвигав": ["отодвигавши"],
    "отодвигавши": ["отодвигав"],
    "отодвигать": ["отстранять"],
    "отодвигаться": ["отдвигаться"],
    "отодвинув": ["отодвинувши"],
    "отодвинувши": ["отодвинув"],
    "отодвинуть": ["отстранить", "открыть", "оттеснить", "отсрочить"],
    "отодрав": ["отодравши"],
    "отодравши": ["отодрав"],
    "отож": ["конечно"],
    "отождествив": ["отождествивши"],
    "отождествивши": ["отождествив"],
    "отождествление": ["сравнение", "сверка", "идентификация"],
    "отождествляв": ["отождествлявши"],
    "отождествлявши": ["отождествляв"],
    "отождествлять": ["идентифицировать"],
    "отожествив": ["отожествивши"],
    "отожествивши": ["отожествив"],
    "отожествить": ["отождествить"],
    "отожествление": ["отождествление"],
    "отожествляв": ["отожествлявши"],
    "отожествлявши": ["отожествляв"],
    "отожествлять": ["отождествлять"],
    "отожраться": ["отъесться"],
    "отозвав": ["отозвавши"],
    "отозвавши": ["отозвав"],
    "отозваться": ["ответить", "откликнуться", "высказаться", "дать отзыв", "повлиять", "сказаться", "распространиться", "почувствоваться"],
    "отойти": ["отвалить", "выскочить", "прийти в себя", "очухаться"],
    "отоларинголог": ["ухогорлонос", "оториноларинголог"],
    "отоларингология": ["оториноларингология"],
    "отолит": ["статолит"],
    "отологический": ["отиатрический"],
    "отология": ["отиатрия"],
    "отолстев": ["отолстевши"],
    "отолстевши": ["отолстев"],
    "отомкнув": ["отомкнувши"],
    "отомкнувши": ["отомкнув"],
    "отомстив": ["отомстивши"],
    "отомстивши": ["отомстив"],
    "отомстить": ["отмстить", "отплатить", "расквитаться", "поквитаться"],
    "отомчав": ["отомчавши"],
    "отомчавши": ["отомчав"],
    "отомщав": ["отомщавши"],
    "отомщавши": ["отомщав"],
    "отомщать": ["отмщать", "мстить"],
    "отоневрология": ["оториноларингоневрология"],
    "отонок": ["плёнка", "перепонка", "кожура"],
    "отономастический": ["отонимический"],
    "отопив": ["отопивши"],
    "отопивши": ["отопив"],
    "отопитель": ["нагреватель"],
    "отопляв": ["отоплявши"],
    "отоплявши": ["отопляв"],
    "отопрев": ["отопревши"],
    "отопревав": ["отопревавши"],
    "отопревавши": ["отопревав"],
    "отопревши": ["отопрев"],
    "отоптав": ["отоптавши"],
    "отоптавши": ["отоптав"],
    "отоптать": ["обтоптать"],
    "оторачивав": ["оторачивавши"],
    "оторачивавши": ["оторачивав"],
    "оторва": ["сорвиголова", "отчаюга", "оторвыш"],
    "оторвав": ["оторвавши"],
    "оторвавши": ["оторвав"],
    "оторванно": ["отвлечённо", "уединённо", "обособленно", "отделённо", "отстраненно"],
    "оторви да брось": ["оторви да выбрось", "оторви и выбрось"],
    "оторжавев": ["оторжавевши"],
    "оторжавевши": ["оторжавев"],
    "оториноларинголог": ["отоларинголог", "лор", "ухогорлонос"],
    "оторопев": ["оторопевши"],
    "оторопевши": ["оторопев"],
    "оторопеть": ["опешить", "обомлеть"],
    "оторопь": ["дрожь"],
    "отороченный": ["окантованный", "обмётанный", "опушённый"],
    "оторочив": ["оторочивши"],
    "оторочивши": ["оторочив"],
    "оторочить": ["окантовать"],
    "оторфенев": ["оторфеневши"],
    "оторфеневши": ["оторфенев"],
    "оторцевав": ["оторцевавши"],
    "оторцевавши": ["оторцевав"],
    "оторцовывав": ["оторцовывавши"],
    "оторцовывавши": ["оторцовывав"],
    "отосклероз": ["отоспонгиоз"],
    "отоскопировав": ["отоскопировавши"],
    "отоскопировавши": ["отоскопировав"],
    "отослав": ["отославши"],
    "отославши": ["отослав"],
    "отоспав": ["отоспавши"],
    "отоспавши": ["отоспав"],
    "ототкнув": ["ототкнувши"],
    "ототкнувши": ["ототкнув"],
    "ототкнуть": ["открыть", "откупорить", "вытащить"],
    "отофон": ["слуховой аппарат"],
    "отохотив": ["отохотивши"],
    "отохотивши": ["отохотив"],
    "оточив": ["оточивши"],
    "оточивши": ["оточив"],
    "отощав": ["отощавши"],
    "отощавши": ["отощав"],
    "отощалый": ["отощавший", "неплодородный", "истощённый"],
    "отощание": ["исхудание", "оскудение"],
    "отощать": ["исхудать", "истощиться", "оскудеть"],
    "отпад": ["отпадение"],
    "отпадав": ["отпадавши"],
    "отпадавши": ["отпадав"],
    "отпадение": ["отваливание", "отделение", "отлетание", "отпад", "отпадание", "отскакивание", "отскок", "отсыхание", "отлипание", "осыпание", "богоотступничество", "выход", "отмежёвывание"],
    "отпаденье": ["отпадение"],
    "отпадналост": ["изнемощялост", "изнемога", "слабост", "безсилие", "изнуреност", "умора"],
    "отпадный": ["сногсшибательный", "ошеломляющий", "впечатляющий", "потрясающий", "потрясный"],
    "отпадывав": ["отпадывавши"],
    "отпадывавши": ["отпадывав"],
    "отпадывать": ["отпадать", "отниматься"],
    "отпазаничав": ["отпазаничавши"],
    "отпазаничавши": ["отпазаничав"],
    "отпазаничать": ["отпазанчить"],
    "отпазанчив": ["отпазанчивши"],
    "отпазанчивши": ["отпазанчив"],
    "отпазанчить": ["отпазаничать"],
    "отпаивав": ["отпаивавши"],
    "отпаивавши": ["отпаивав"],
    "отпаиванье": ["отпаивание"],
    "отпал": ["отпалка", "выпал"],
    "отпалзывав": ["отпалзывавши"],
    "отпалзывавши": ["отпалзывав"],
    "отпалив": ["отпаливши"],
    "отпаливав": ["отпаливавши"],
    "отпаливавши": ["отпаливав"],
    "отпаливши": ["отпалив"],
    "отпалка": ["отпал"],
    "отпалывав": ["отпалывавши"],
    "отпалывавши": ["отпалывав"],
    "отпарив": ["отпаривши"],
    "отпаривав": ["отпаривавши"],
    "отпаривавши": ["отпаривав"],
    "отпаривши": ["отпарив"],
    "отпарировав": ["отпарировавши"],
    "отпарировавши": ["отпарировав"],
    "отпарировать": ["парировать"],
    "отпархивав": ["отпархивавши"],
    "отпархивавши": ["отпархивав"],
    "отпарывав": ["отпарывавши"],
    "отпарывавши": ["отпарывав"],
    "отпаснув": ["отпаснувши"],
    "отпаснувши": ["отпаснув"],
    "отпасовав": ["отпасовавши"],
    "отпасовавши": ["отпасовав"],
    "отпасовать": ["отпаснуть"],
    "отпасовывав": ["отпасовывавши"],
    "отпасовывавши": ["отпасовывав"],
    "отпахав": ["отпахавши"],
    "отпахавши": ["отпахав"],
    "отпахивав": ["отпахивавши"],
    "отпахивавши": ["отпахивав"],
    "отпахнув": ["отпахнувши"],
    "отпахнувши": ["отпахнув"],
    "отпаяв": ["отпаявши"],
    "отпаявши": ["отпаяв"],
    "отпев": ["отпевши"],
    "отпевав": ["отпевавши"],
    "отпевавши": ["отпевав"],
    "отпевание": ["заупокойная служба", "отпеванье", "чин погребения", "панихида"],
    "отпеванье": ["отпевание"],
    "отпевши": ["отпев"],
    "отпекав": ["отпекавши"],
    "отпекавши": ["отпекав"],
    "отпекать": ["выпекать"],
    "отпердолив": ["отпердоливши"],
    "отпердоливши": ["отпердолив"],
    "отперев": ["отперши"],
    "отпереть": ["отомкнуть", "отворить"],
    "отперши": ["отперев"],
    "отпетушив": ["отпетушивши"],
    "отпетушивши": ["отпетушив"],
    "отпетый": ["отъявленный", "закоренелый", "безнадёжный", "неисправимый", "погибший", "пропащий", "конченый", "отчаянный", "удалой"],
    "отпечатав": ["отпечатавши"],
    "отпечатавши": ["отпечатав"],
    "отпечатлев": ["отпечатлевши"],
    "отпечатлевав": ["отпечатлевавши"],
    "отпечатлевавши": ["отпечатлевав"],
    "отпечатлевши": ["отпечатлев"],
    "отпечаток": ["след", "оттиск", "печать"],
    "отпечатывав": ["отпечатывавши"],
    "отпечатывавши": ["отпечатывав"],
    "отпечатывать": ["печатать"],
    "отпиарив": ["отпиаривши"],
    "отпиаривши": ["отпиарив"],
    "отпив": ["отпивши"],
    "отпивав": ["отпивавши"],
    "отпивавши": ["отпивав"],
    "отпивание": ["отпитие"],
    "отпивши": ["отпив"],
    "отпидорасив": ["отпидорасивши"],
    "отпидорасивши": ["отпидорасив"],
    "отпиздеться": ["отбояриться", "отбрехаться"],
    "отпиздив": ["отпиздивши"],
    "отпиздивши": ["отпиздив"],
    "отпиздохав": ["отпиздохавши"],
    "отпиздохавши": ["отпиздохав"],
    "отпиздохать": ["отхуярить", "отхуячить", "отпиздячить", "отпиздякать"],
    "отпиздякав": ["отпиздякавши"],
    "отпиздякавши": ["отпиздякав"],
    "отпиздякать": ["отхуярить", "отхуячить", "отпиздячить", "отпиздохать"],
    "отпиздячив": ["отпиздячивши"],
    "отпиздячивши": ["отпиздячив"],
    "отпиздячить": ["отхуярить", "отхуячить", "отпиздякать", "отпиздохать"],
    "отпилив": ["отпиливши"],
    "отпиливав": ["отпиливавши"],
    "отпиливавши": ["отпиливав"],
    "отпиливши": ["отпилив"],
    "отпилотировав": ["отпилотировавши"],
    "отпилотировавши": ["отпилотировав"],
    "отпинав": ["отпинавши"],
    "отпинавши": ["отпинав"],
    "отпирав": ["отпиравши"],
    "отпиравши": ["отпирав"],
    "отпировав": ["отпировавши"],
    "отпировавши": ["отпировав"],
    "отпироваться": ["отпраздноваться"],
    "отписав": ["отписавши"],
    "отписавши": ["отписав"],
    "отписать": ["сообщить", "написать"],
    "отписаться": ["откреститься", "ограничиться", "отмахнуться", "отбрыкаться", "отстрочиться", "послать", "отписать", "написаться", "откалякаться", "ответить", "отчитаться", "уведомить", "сообщить", "доложить", "отрапортовать"],
    "отписка": ["отписывание"],
    "отписывав": ["отписывавши"],
    "отписывавши": ["отписывав"],
    "отпитие": ["отпивание"],
    "отпить": ["отхлебнуть", "спить"],
    "отпихивав": ["отпихивавши"],
    "отпихивавши": ["отпихивав"],
    "отпихнув": ["отпихнувши"],
    "отпихнувши": ["отпихнув"],
    "отплавав": ["отплававши"],
    "отплававши": ["отплавав"],
    "отплакав": ["отплакавши"],
    "отплакавши": ["отплакав"],
    "отплатив": ["отплативши"],
    "отплативши": ["отплатив"],
    "отплатить": ["воздать"],
    "отплачивав": ["отплачивавши"],
    "отплачивавши": ["отплачивав"],
    "отплачивать": ["платить", "воздавать"],
    "отплевав": ["отплевавши"],
    "отплевавши": ["отплевав"],
    "отплескав": ["отплескавши"],
    "отплескавши": ["отплескав"],
    "отплеснув": ["отплеснувши"],
    "отплеснувши": ["отплеснув"],
    "отплетав": ["отплетавши"],
    "отплетавши": ["отплетав"],
    "отплодоносив": ["отплодоносивши"],
    "отплодоносивши": ["отплодоносив"],
    "отплоив": ["отплоивши"],
    "отплоивши": ["отплоив"],
    "отплыв": ["отплывши"],
    "отплывав": ["отплывавши"],
    "отплывавши": ["отплывав"],
    "отплывши": ["отплыв"],
    "отплытье": ["отплытие"],
    "отплюнув": ["отплюнувши"],
    "отплюнувши": ["отплюнув"],
    "отплясав": ["отплясавши"],
    "отплясавши": ["отплясав"],
    "отплясать": ["оттанцевать", "проплясать", "протанцевать"],
    "отплясывав": ["отплясывавши"],
    "отплясывавши": ["отплясывав"],
    "отплёвывав": ["отплёвывавши"],
    "отплёвывавши": ["отплёвывав"],
    "отплёскивав": ["отплёскивавши"],
    "отплёскивавши": ["отплёскивав"],
    "отповедь": ["отпор"],
    "отпоив": ["отпоивши"],
    "отпоивши": ["отпоив"],
    "отполаскивав": ["отполаскивавши"],
    "отполаскивавши": ["отполаскивав"],
    "отполдничав": ["отполдничавши"],
    "отполдничавши": ["отполдничав"],
    "отползав": ["отползавши"],
    "отползавши": ["отползав"],
    "отполировав": ["отполировавши"],
    "отполировавши": ["отполировав"],
    "отполировывав": ["отполировывавши"],
    "отполировывавши": ["отполировывав"],
    "отполировывать": ["полировать"],
    "отполов": ["отполовши"],
    "отполовинив": ["отполовинивши"],
    "отполовинивав": ["отполовинивавши"],
    "отполовинивавши": ["отполовинивав"],
    "отполовинивши": ["отполовинив"],
    "отполовши": ["отполов"],
    "отполоскав": ["отполоскавши"],
    "отполоскавши": ["отполоскав"],
    "отполоскать": ["прополоскать"],
    "отполосовав": ["отполосовавши"],
    "отполосовавши": ["отполосовав"],
    "отполосовать": ["исполосовать"],
    "отполыхав": ["отполыхавши"],
    "отполыхавши": ["отполыхав"],
    "отпоров": ["отпоровши"],
    "отпоровши": ["отпоров"],
    "отпорхнув": ["отпорхнувши"],
    "отпорхнувши": ["отпорхнув"],
    "отпотев": ["отпотевши"],
    "отпотевав": ["отпотевавши"],
    "отпотевавши": ["отпотевав"],
    "отпотевши": ["отпотев"],
    "отпотчевав": ["отпотчевавши"],
    "отпотчевавши": ["отпотчевав"],
    "отправивши": ["отправив"],
    "отправитель": ["адресант"],
    "отправить": ["послать"],
    "отправка": ["отправление", "отъезд"],
    "отправление": ["отсылка", "отъезд", "уход", "исполнение", "деятельность", "работа", "функционирование"],
    "отправленье": ["отправление"],
    "отправляв": ["отправлявши"],
    "отправлявши": ["отправляв"],
    "отправлять": ["отсылать", "посылать", "слать", "препровождать", "засылать", "бросать", "гонять", "класть"],
    "отправлять естественные надобности": ["справлять нужду"],
    "отправная точка": ["исходная точка"],
    "отправочный": ["отправной"],
    "отпраздновав": ["отпраздновавши"],
    "отпраздновавши": ["отпраздновав"],
    "отпрашивав": ["отпрашивавши"],
    "отпрашивавши": ["отпрашивав"],
    "отпрепарировав": ["отпрепарировавши"],
    "отпрепарировавши": ["отпрепарировав"],
    "отпрессовав": ["отпрессовавши"],
    "отпрессовавши": ["отпрессовав"],
    "отприветствовав": ["отприветствовавши"],
    "отприветствовавши": ["отприветствовав"],
    "отпричитав": ["отпричитавши"],
    "отпричитавши": ["отпричитав"],
    "отпробовав": ["отпробовавши"],
    "отпробовавши": ["отпробовав"],
    "отпросив": ["отпросивши"],
    "отпросивши": ["отпросив"],
    "отпружинив": ["отпружинивши"],
    "отпружинивши": ["отпружинив"],
    "отпрукав": ["отпрукавши"],
    "отпрукавши": ["отпрукав"],
    "отпрукивав": ["отпрукивавши"],
    "отпрукивавши": ["отпрукивав"],
    "отпрукнув": ["отпрукнувши"],
    "отпрукнувши": ["отпрукнув"],
    "отпрыгав": ["отпрыгавши"],
    "отпрыгавши": ["отпрыгав"],
    "отпрыгивав": ["отпрыгивавши"],
    "отпрыгивавши": ["отпрыгивав"],
    "отпрыгивать": ["отскакивать"],
    "отпрыгнув": ["отпрыгнувши"],
    "отпрыгнувши": ["отпрыгнув"],
    "отпрыск": ["потомок"],
    "отпрягав": ["отпрягавши"],
    "отпрягавши": ["отпрягав"],
    "отпрядав": ["отпрядавши"],
    "отпрядавши": ["отпрядав"],
    "отпрядывав": ["отпрядывавши"],
    "отпрядывавши": ["отпрядывав"],
    "отпрянув": ["отпрянувши"],
    "отпрянувши": ["отпрянув"],
    "отпугав": ["отпугавши"],
    "отпугавши": ["отпугав"],
    "отпугивав": ["отпугивавши"],
    "отпугивавши": ["отпугивав"],
    "отпугивать": ["отгонять", "останавливать", "отвращать", "отталкивать"],
    "отпугнув": ["отпугнувши"],
    "отпугнувши": ["отпугнув"],
    "отпускав": ["отпускавши"],
    "отпускавши": ["отпускав"],
    "отпускать": ["выпускать", "пускать", "ослаблять", "распускать", "ослабевать", "продавать", "выдавать", "предоставлять", "давать", "отращивать"],
    "отпустив": ["отпустивши"],
    "отпустивши": ["отпустив"],
    "отпутав": ["отпутавши"],
    "отпутавши": ["отпутав"],
    "отпутешествовав": ["отпутешествовавши"],
    "отпутешествовавши": ["отпутешествовав"],
    "отпутывав": ["отпутывавши"],
    "отпутывавши": ["отпутывав"],
    "отпущав": ["отпущавши"],
    "отпущавши": ["отпущав"],
    "отпылав": ["отпылавши"],
    "отпылавши": ["отпылав"],
    "отпылив": ["отпыливши"],
    "отпыливши": ["отпылив"],
    "отпыхивав": ["отпыхивавши"],
    "отпыхивавши": ["отпыхивав"],
    "отпыхнув": ["отпыхнувши"],
    "отпыхнувши": ["отпыхнув"],
    "отпыхтев": ["отпыхтевши"],
    "отпыхтевши": ["отпыхтев"],
    "отпялив": ["отпяливши"],
    "отпяливав": ["отпяливавши"],
    "отпяливавши": ["отпяливав"],
    "отпяливши": ["отпялив"],
    "отпятив": ["отпятивши"],
    "отпятивши": ["отпятив"],
    "отпячивав": ["отпячивавши"],
    "отпячивавши": ["отпячивав"],
    "отрабатывав": ["отрабатывавши"],
    "отрабатывавши": ["отрабатывав"],
    "отрабатывание": ["отработка"],
    "отработав": ["отработавши"],
    "отработавши": ["отработав"],
    "отработывав": ["отработывавши"],
    "отработывавши": ["отработывав"],
    "отрава": ["яд", "отравление"],
    "отравив": ["отравивши"],
    "отравивши": ["отравив"],
    "отравитель": ["отравщик"],
    "отравление": ["отравленье", "интоксикация"],
    "отравленье": ["отравление"],
    "отравливав": ["отравливавши"],
    "отравливавши": ["отравливав"],
    "отравляв": ["отравлявши"],
    "отравлявши": ["отравляв"],
    "отравляющий": ["токсичный", "ядовитый"],
    "отрада": ["радость", "удовольствие"],
    "отрадно": ["радостно", "умиротворяюще", "приятно"],
    "отражав": ["отражавши"],
    "отражавши": ["отражав"],
    "отражаться": ["зеркалиться", "отзываться", "влиять", "обнаруживаться", "показываться", "отбиваться"],
    "отраженье": ["отражение"],
    "отразив": ["отразивши"],
    "отразивши": ["отразив"],
    "отразить": ["опровергнуть", "возразить", "показать", "отзеркалить", "изобразить"],
    "отразиться": ["обнаружиться", "показаться"],
    "отрапортовав": ["отрапортовавши"],
    "отрапортовавши": ["отрапортовав"],
    "отрапортовать": ["доложить", "донести"],
    "отрапортоваться": ["отчитаться", "доложиться", "представиться"],
    "отрапортовывав": ["отрапортовывавши"],
    "отрапортовывавши": ["отрапортовывав"],
    "отрасль": ["отросток"],
    "отрасль права": ["оп"],
    "отрастав": ["отраставши"],
    "отраставши": ["отрастав"],
    "отрастив": ["отрастивши"],
    "отрастивши": ["отрастив"],
    "отрач": ["отураш"],
    "отращивав": ["отращивавши"],
    "отращивавши": ["отращивав"],
    "отреагировав": ["отреагировавши"],
    "отреагировавши": ["отреагировав"],
    "отребье": ["отбросы", "помои", "шлак", "быдло", "быдломасса", "гопота", "плебс", "подонки", "сброд", "сволота", "скотобаза", "теребень", "чернь", "шпана"],
    "отревав": ["отревавши"],
    "отревавши": ["отревав"],
    "отревев": ["отревевши"],
    "отревевши": ["отревев"],
    "отревновав": ["отревновавши"],
    "отревновавши": ["отревновав"],
    "отрегулировав": ["отрегулировавши"],
    "отрегулировавши": ["отрегулировав"],
    "отрегулировать": ["настроить"],
    "отред": ["чета", "дружина", "група"],
    "отредактировав": ["отредактировавши"],
    "отредактировавши": ["отредактировав"],
    "отрежиссировав": ["отрежиссировавши"],
    "отрежиссировавши": ["отрежиссировав"],
    "отрез": ["отрезание", "отрезка"],
    "отрезав": ["отрезавши"],
    "отрезавши": ["отрезав"],
    "отрезвев": ["отрезвевши"],
    "отрезвевши": ["отрезвев"],
    "отрезвив": ["отрезвивши"],
    "отрезвивши": ["отрезвив"],
    "отрезвленье": ["отрезвление"],
    "отрезвляв": ["отрезвлявши"],
    "отрезвлявши": ["отрезвляв"],
    "отрезок": ["сегмент", "числовой отрезок", "замкнутый промежуток"],
    "отрезывав": ["отрезывавши"],
    "отрезывавши": ["отрезывав"],
    "отрекав": ["отрекавши"],
    "отрекавши": ["отрекав"],
    "отрекать": ["отревать", "отвергать"],
    "отрекламировав": ["отрекламировавши"],
    "отрекламировавши": ["отрекламировав"],
    "отрекомендовав": ["отрекомендовавши"],
    "отрекомендовавши": ["отрекомендовав"],
    "отрекомендовывав": ["отрекомендовывавши"],
    "отрекомендовывавши": ["отрекомендовывав"],
    "отреконструировав": ["отреконструировавши"],
    "отреконструировавши": ["отреконструировав"],
    "отремонтировав": ["отремонтировавши"],
    "отремонтировавши": ["отремонтировав"],
    "отремонтировать": ["восстановить"],
    "отрендерив": ["отрендеривши"],
    "отрендеривши": ["отрендерив"],
    "отреновировав": ["отреновировавши"],
    "отреновировавши": ["отреновировав"],
    "отрепав": ["отрепавши"],
    "отрепавши": ["отрепав"],
    "отрепетировав": ["отрепетировавши"],
    "отрепетировавши": ["отрепетировав"],
    "отрепетовав": ["отрепетовавши"],
    "отрепетовавши": ["отрепетовав"],
    "отрепье": ["отрёпки", "лохмотья", "отрепья"],
    "отреставрировав": ["отреставрировавши"],
    "отреставрировавши": ["отреставрировав"],
    "отретироваться": ["ретироваться", "убраться", "смыться"],
    "отретушировав": ["отретушировавши"],
    "отретушировавши": ["отретушировав"],
    "отреферировав": ["отреферировавши"],
    "отреферировавши": ["отреферировав"],
    "отрефлексировав": ["отрефлексировавши"],
    "отрефлексировавши": ["отрефлексировав"],
    "отрецензировав": ["отрецензировавши"],
    "отрецензировавши": ["отрецензировав"],
    "отречение": ["отказ", "отрицание"],
    "отреченный": ["апокрифический", "отвергнутый"],
    "отреченье": ["отречение"],
    "отрешав": ["отрешавши"],
    "отрешавши": ["отрешав"],
    "отрешать": ["освобождать", "отрывать", "исключать", "из", "увольнять", "отстранять"],
    "отрешив": ["отрешивши"],
    "отрешивши": ["отрешив"],
    "отрешить": ["освободить", "оторвать", "исключить", "уволить", "отстранить"],
    "отрешённо": ["безучастно"],
    "отрешённость": ["безучастность"],
    "отрикошетив": ["отрикошетивши"],
    "отрикошетивши": ["отрикошетив"],
    "отринув": ["отринувши"],
    "отринувши": ["отринув"],
    "отринуть": ["отвергнуть"],
    "отрисовав": ["отрисовавши"],
    "отрисовавши": ["отрисовав"],
    "отрисовка": ["отрисовывание"],
    "отрисовывав": ["отрисовывавши"],
    "отрисовывавши": ["отрисовывав"],
    "отрисовывать": ["прорисовывать"],
    "отрихтовав": ["отрихтовавши"],
    "отрихтовавши": ["отрихтовав"],
    "отрихтовать щи": ["настучать по щам"],
    "отрихтовывав": ["отрихтовывавши"],
    "отрихтовывавши": ["отрихтовывав"],
    "отрицав": ["отрицавши"],
    "отрицавши": ["отрицав"],
    "отрицание": ["инверсия", "негация"],
    "отрицанье": ["отрицание"],
    "отрицатель": ["отвергатель"],
    "отрицательница": ["противница"],
    "отрицательно": ["негативно", "неодобрительно", "неблагоприятно"],
    "отрицательность": ["негативность"],
    "отрицательный ион": ["анион"],
    "отрицающий": ["отвергающий", "опровергающий"],
    "отрк": ["оперативно-тактический ракетный комплекс"],
    "отрова": ["яд"],
    "отродив": ["отродивши"],
    "отродивши": ["отродив"],
    "отроду": ["отродясь"],
    "отродье": ["отребье", "потомок", "отпрыск"],
    "отродясь": ["отроду"],
    "отрожав": ["отрожавши"],
    "отрожавши": ["отрожав"],
    "отрождав": ["отрождавши"],
    "отрождавши": ["отрождав"],
    "отроив": ["отроивши"],
    "отроивши": ["отроив"],
    "отрок": ["подросток", "дружинник"],
    "отроковица": ["подросток", "отрочица"],
    "отрокотав": ["отрокотавши"],
    "отрокотавши": ["отрокотав"],
    "отроческий": ["подростковый"],
    "отрочица": ["отроковица"],
    "отрубав": ["отрубавши"],
    "отрубавши": ["отрубав"],
    "отрубив": ["отрубивши"],
    "отрубивши": ["отрубив"],
    "отрубить": ["отсечь", "отчекрыжить", "прекратить", "прервать", "пресечь", "обесточить", "отключить", "вырубить"],
    "отругав": ["отругавши"],
    "отругавши": ["отругав"],
    "отругать": ["выругать", "выбранить"],
    "отругивав": ["отругивавши"],
    "отругивавши": ["отругивав"],
    "отругивать": ["ругать"],
    "отрулив": ["отруливши"],
    "отруливав": ["отруливавши"],
    "отруливавши": ["отруливав"],
    "отруливши": ["отрулив"],
    "отрута": ["трунок"],
    "отрухлявев": ["отрухлявевши"],
    "отрухлявевши": ["отрухлявев"],
    "отрыбачив": ["отрыбачивши"],
    "отрыбачивши": ["отрыбачив"],
    "отрыв": ["отрывание"],
    "отрывав": ["отрывавши"],
    "отрывавши": ["отрывав"],
    "отрыванье": ["отрывание"],
    "отрывать глаза": ["отводить"],
    "отрываться": ["взлетать", "отвлекаться", "прерывать", "уходить", "отделяться", "кайфовать", "ловить кайф", "тащиться"],
    "отрываться от коллектива": ["обособляться"],
    "отрывисто": ["стаккато"],
    "отрывок": ["фрагмент", "пассаж", "кусок", "обрывок"],
    "отрывши": ["отрыв"],
    "отрыгав": ["отрыгавши"],
    "отрыгавши": ["отрыгав"],
    "отрыгивав": ["отрыгивавши"],
    "отрыгивавши": ["отрыгивав"],
    "отрыгивание": ["отрыжка"],
    "отрыгивать": ["отрыгать"],
    "отрыгнув": ["отрыгнувши"],
    "отрыгнувши": ["отрыгнув"],
    "отрыдав": ["отрыдавши"],
    "отрыдавши": ["отрыдав"],
    "отрыскав": ["отрыскавши"],
    "отрыскавши": ["отрыскав"],
    "отрыскивав": ["отрыскивавши"],
    "отрыскивавши": ["отрыскивав"],
    "отрыть": ["выкопать", "вырыть", "откопать"],
    "отряд": ["порядок"],
    "отряд милиции особого назначения": ["отряд мобильный особого назначения", "омон"],
    "отрядив": ["отрядивши"],
    "отрядивши": ["отрядив"],
    "отрядить": ["направить"],
    "отряжав": ["отряжавши"],
    "отряжавши": ["отряжав"],
    "отрясав": ["отрясавши"],
    "отрясавши": ["отрясав"],
    "отряхав": ["отряхавши"],
    "отряхавши": ["отряхав"],
    "отряхать": ["сбрасывать", "стряхивать"],
    "отряхивав": ["отряхивавши"],
    "отряхивавши": ["отряхивав"],
    "отряхиваться": ["отряхаться"],
    "отряхнув": ["отряхнувши"],
    "отряхнувши": ["отряхнув"],
    "отрёпывав": ["отрёпывавши"],
    "отрёпывавши": ["отрёпывав"],
    "отрёпывать": ["обтрёпывать"],
    "отсадив": ["отсадивши"],
    "отсадивши": ["отсадив"],
    "отсадок": ["отводок"],
    "отсаживав": ["отсаживавши"],
    "отсаживавши": ["отсаживав"],
    "отсалютовав": ["отсалютовавши"],
    "отсалютовавши": ["отсалютовав"],
    "отсасывав": ["отсасывавши"],
    "отсасывавши": ["отсасывав"],
    "отсасыватель": ["аспиратор"],
    "отсверкав": ["отсверкавши"],
    "отсверкавши": ["отсверкав"],
    "отсверкивав": ["отсверкивавши"],
    "отсверкивавши": ["отсверкивав"],
    "отсвет": ["отблеск"],
    "отсветив": ["отсветивши"],
    "отсветивши": ["отсветив"],
    "отсвечивав": ["отсвечивавши"],
    "отсвечивавши": ["отсвечивав"],
    "отсвистав": ["отсвиставши"],
    "отсвиставши": ["отсвистав"],
    "отсвистев": ["отсвистевши"],
    "отсвистевши": ["отсвистев"],
    "отсебятина": ["импровизация", "самодеятельность"],
    "отсев": ["отбор", "отсеивание"],
    "отсевав": ["отсевавши"],
    "отсевавши": ["отсевав"],
    "отсеваться": ["отсеиваться"],
    "отседав": ["отседавши"],
    "отседавши": ["отседав"],
    "отсеивав": ["отсеивавши"],
    "отсеивавши": ["отсеивав"],
    "отсеивать": ["отсевать"],
    "отсек": ["отделение", "кабина", "камера"],
    "отсекав": ["отсекавши"],
    "отсекавши": ["отсекав"],
    "отсекать": ["отрубать"],
    "отсекающий": ["отрубающий"],
    "отселе": ["отсель", "отсюда", "отсюдова", "отныне", "впредь"],
    "отселекционировав": ["отселекционировавши"],
    "отселекционировавши": ["отселекционировав"],
    "отселив": ["отселивши"],
    "отселивши": ["отселив"],
    "отсель": ["отселе", "отсюда", "отсюдова", "отседова", "отныне", "впредь"],
    "отселяв": ["отселявши"],
    "отселявши": ["отселяв"],
    "отсенка": ["отсянка", "нюанс", "оттенък"],
    "отсепарировав": ["отсепарировавши"],
    "отсепарировавши": ["отсепарировав"],
    "отсепаровав": ["отсепаровавши"],
    "отсепаровавши": ["отсепаровав"],
    "отсепаровывав": ["отсепаровывавши"],
    "отсепаровывавши": ["отсепаровывав"],
    "отсечение": ["усекновение", "отсеченье", "усекновенье"],
    "отсеченье": ["отсечение"],
    "отсечь": ["отрубить"],
    "отсеяв": ["отсеявши"],
    "отсеявши": ["отсеяв"],
    "отсигналив": ["отсигналивши"],
    "отсигналивши": ["отсигналив"],
    "отсидев": ["отсидевши"],
    "отсидевши": ["отсидев"],
    "отсиживав": ["отсиживавши"],
    "отсиживавши": ["отсиживав"],
    "отскабливав": ["отскабливавши"],
    "отскабливавши": ["отскабливав"],
    "отскакав": ["отскакавши"],
    "отскакавши": ["отскакав"],
    "отскакивав": ["отскакивавши"],
    "отскакивавши": ["отскакивав"],
    "отскакивание": ["отскок"],
    "отскакивать": ["отпрыгивать", "отлетать", "отрываться"],
    "отскакнув": ["отскакнувши"],
    "отскакнувши": ["отскакнув"],
    "отсканив": ["отсканивши"],
    "отсканивши": ["отсканив"],
    "отсканировав": ["отсканировавши"],
    "отсканировавши": ["отсканировав"],
    "отсканировать": ["отсканить"],
    "отсканить": ["отсканировать"],
    "отскоблив": ["отскобливши"],
    "отскобливши": ["отскоблив"],
    "отскочив": ["отскочивши"],
    "отскочивши": ["отскочив"],
    "отскребав": ["отскребавши"],
    "отскребавши": ["отскребав"],
    "отскрести": ["отскоблить"],
    "отскринив": ["отскринивши"],
    "отскринивши": ["отскринив"],
    "отскринить": ["заскринить", "отскриншотить", "заскриншотить"],
    "отскриншотить": ["заскриншотить", "заскринить", "отскринить"],
    "отскрёбывав": ["отскрёбывавши"],
    "отскрёбывавши": ["отскрёбывав"],
    "отслаивав": ["отслаивавши"],
    "отслаивавши": ["отслаивав"],
    "отследив": ["отследивши"],
    "отследивши": ["отследив"],
    "отслеживав": ["отслеживавши"],
    "отслеживавши": ["отслеживав"],
    "отслоение": ["отслойка"],
    "отслоив": ["отслоивши"],
    "отслоивши": ["отслоив"],
    "отслойка": ["отслоение"],
    "отслонив": ["отслонивши"],
    "отслонивши": ["отслонив"],
    "отслоняв": ["отслонявши"],
    "отслонявши": ["отслоняв"],
    "отслужив": ["отслуживши"],
    "отслуживав": ["отслуживавши"],
    "отслуживавши": ["отслуживав"],
    "отслуживши": ["отслужив"],
    "отслушав": ["отслушавши"],
    "отслушавши": ["отслушав"],
    "отслушать": ["прослушать", "дослушать"],
    "отслушивав": ["отслушивавши"],
    "отслушивавши": ["отслушивав"],
    "отслюнив": ["отслюнивши"],
    "отслюнивав": ["отслюнивавши"],
    "отслюнивавши": ["отслюнивав"],
    "отслюнивши": ["отслюнив"],
    "отслюнявив": ["отслюнявивши"],
    "отслюнявивши": ["отслюнявив"],
    "отслюнявить": ["отсчитать"],
    "отслюнявливав": ["отслюнявливавши"],
    "отслюнявливавши": ["отслюнявливав"],
    "отсматривав": ["отсматривавши"],
    "отсматривавши": ["отсматривав"],
    "отсмеяв": ["отсмеявши"],
    "отсмеявши": ["отсмеяв"],
    "отсмотрев": ["отсмотревши"],
    "отсмотревши": ["отсмотрев"],
    "отснимав": ["отснимавши"],
    "отснимавши": ["отснимав"],
    "отсняв": ["отснявши"],
    "отснявши": ["отсняв"],
    "отсоветовав": ["отсоветовавши"],
    "отсоветовавши": ["отсоветовав"],
    "отсоветовать": ["разубедить", "отговорить"],
    "отсовывав": ["отсовывавши"],
    "отсовывавши": ["отсовывав"],
    "отсоединив": ["отсоединивши"],
    "отсоединивши": ["отсоединив"],
    "отсоединить": ["рассоединить"],
    "отсоединяв": ["отсоединявши"],
    "отсоединявши": ["отсоединяв"],
    "отсортировав": ["отсортировавши"],
    "отсортировавши": ["отсортировав"],
    "отсортировывав": ["отсортировывавши"],
    "отсортировывавши": ["отсортировывав"],
    "отсос": ["отсасывание", "минет", "оральный секс"],
    "отсосав": ["отсосавши"],
    "отсосавши": ["отсосав"],
    "отсоси у тракториста": ["отсоси у пианиста", "отсоси у онаниста"],
    "отсосник": ["отсасыватель"],
    "отсохнув": ["отсохнувши"],
    "отсохнувши": ["отсохнув"],
    "отспаривав": ["отспаривавши"],
    "отспаривавши": ["отспаривав"],
    "отспорив": ["отспоривши"],
    "отспоривши": ["отспорив"],
    "отсрочив": ["отсрочивши"],
    "отсрочивав": ["отсрочивавши"],
    "отсрочивавши": ["отсрочивав"],
    "отсрочивать": ["откладывать", "переносить", "продлевать"],
    "отсрочивши": ["отсрочив"],
    "отсрочка": ["откладывание", "задержка", "мораторий"],
    "отстав": ["отставши"],
    "отставав": ["отстававши"],
    "отстававши": ["отставав"],
    "отставанье": ["отставание"],
    "отставать": ["опаздывать", "задерживаться"],
    "отставив": ["отставивши"],
    "отставивши": ["отставив"],
    "отставка": ["увольнение"],
    "отставляв": ["отставлявши"],
    "отставлявши": ["отставляв"],
    "отставник": ["ветеран"],
    "отставной": ["отставка"],
    "отставши": ["отстав"],
    "отстаивав": ["отстаивавши"],
    "отстаивавши": ["отстаивав"],
    "отстаиванье": ["отстаивание"],
    "отстаивать": ["защищать"],
    "отстегав": ["отстегавши"],
    "отстегавши": ["отстегав"],
    "отстегать": ["отхлестать"],
    "отстегнув": ["отстегнувши"],
    "отстегнувши": ["отстегнув"],
    "отстегнуть": ["расстегнуть"],
    "отстирав": ["отстиравши"],
    "отстиравши": ["отстирав"],
    "отстирывав": ["отстирывавши"],
    "отстирывавши": ["отстирывав"],
    "отстой": ["отстаивание", "осаждение", "осадок", "дрянь", "гавно", "стоянка"],
    "отстойный": ["плохой", "дрянной", "паршивый", "отвратительный", "ужасный"],
    "отсторонив": ["отсторонивши"],
    "отсторонивши": ["отсторонив"],
    "отстороняв": ["отсторонявши"],
    "отсторонявши": ["отстороняв"],
    "отстояв": ["отстоявши"],
    "отстоявши": ["отстояв"],
    "отстоять": ["защитить"],
    "отстрагивав": ["отстрагивавши"],
    "отстрагивавши": ["отстрагивав"],
    "отстрагивать": ["отстругивать", "выстрагивать"],
    "отстрадав": ["отстрадавши"],
    "отстрадавши": ["отстрадав"],
    "отстрадовав": ["отстрадовавши"],
    "отстрадовавши": ["отстрадовав"],
    "отстраивав": ["отстраивавши"],
    "отстраивавши": ["отстраивав"],
    "отстраивать": ["строить"],
    "отстраненье": ["отстранение"],
    "отстранив": ["отстранивши"],
    "отстранивши": ["отстранив"],
    "отстранить": ["отодвинуть", "уволить", "освободить", "сместить"],
    "отстраняв": ["отстранявши"],
    "отстранявши": ["отстраняв"],
    "отстранять": ["отодвигать", "увольнять", "освобождать", "смещать"],
    "отстранённо": ["безучастно"],
    "отстранённость": ["отрешённость", "отчуждённость", "отчуждение"],
    "отстранённый": ["отодвинутый", "отведённый", "отклонённый", "отлучённый", "отогнанный", "отслонённый", "отрешённый", "отчуждённый", "безучастный", "задумчивый"],
    "отстрачивав": ["отстрачивавши"],
    "отстрачивавши": ["отстрачивав"],
    "отстрачивать": ["выстрачивать"],
    "отстрекотав": ["отстрекотавши"],
    "отстрекотавши": ["отстрекотав"],
    "отстрелив": ["отстреливши"],
    "отстреливав": ["отстреливавши"],
    "отстреливавши": ["отстреливав"],
    "отстреливши": ["отстрелив"],
    "отстрелить": ["отстрелять"],
    "отстреляв": ["отстрелявши"],
    "отстрелявши": ["отстреляв"],
    "отстрелять": ["отстрелить", "расстрелять", "исстрелять"],
    "отстреляться": ["отстрелять"],
    "отстригав": ["отстригавши"],
    "отстригавши": ["отстригав"],
    "отстригнув": ["отстригнувши"],
    "отстригнувши": ["отстригнув"],
    "отстрогав": ["отстрогавши"],
    "отстрогавши": ["отстрогав"],
    "отстрогать": ["отстругать"],
    "отстроив": ["отстроивши"],
    "отстроивши": ["отстроив"],
    "отстройка": ["отстраивание"],
    "отстрочив": ["отстрочивши"],
    "отстрочивши": ["отстрочив"],
    "отстрочить": ["выстрочить"],
    "отстругав": ["отстругавши"],
    "отстругавши": ["отстругав"],
    "отстругивав": ["отстругивавши"],
    "отстругивавши": ["отстругивав"],
    "отстряпав": ["отстряпавши"],
    "отстряпавши": ["отстряпав"],
    "отстукав": ["отстукавши"],
    "отстукавши": ["отстукав"],
    "отстукивав": ["отстукивавши"],
    "отстукивавши": ["отстукивав"],
    "отступ": ["промежуток", "отступление", "сдвиг", "смещение", "рекурсия"],
    "отступав": ["отступавши"],
    "отступавши": ["отступав"],
    "отступать": ["отходить", "пятиться", "ретироваться", "совершать отход", "совершать отступление", "идти на попятный"],
    "отступив": ["отступивши"],
    "отступивши": ["отступив"],
    "отступленье": ["отступление"],
    "отступничество": ["ренегатство"],
    "отступное": ["компенсация", "возмещение", "вязка", "возмещенье"],
    "отстучав": ["отстучавши"],
    "отстучавши": ["отстучав"],
    "отстучать": ["отстукать"],
    "отстыковав": ["отстыковавши"],
    "отстыковавши": ["отстыковав"],
    "отстыковывав": ["отстыковывавши"],
    "отстыковывавши": ["отстыковывав"],
    "отстёгивав": ["отстёгивавши"],
    "отстёгивавши": ["отстёгивав"],
    "отстёгивать": ["выкладывать"],
    "отсудив": ["отсудивши"],
    "отсудивши": ["отсудив"],
    "отсуживав": ["отсуживавши"],
    "отсуживавши": ["отсуживав"],
    "отсунув": ["отсунувши"],
    "отсунувши": ["отсунув"],
    "отсутствие": ["нехватка"],
    "отсутствовав": ["отсутствовавши"],
    "отсутствовавши": ["отсутствовав"],
    "отсутяжив": ["отсутяживши"],
    "отсутяживши": ["отсутяжив"],
    "отсутяжить": ["отсутяжничать"],
    "отсутяжничав": ["отсутяжничавши"],
    "отсутяжничавши": ["отсутяжничав"],
    "отсучив": ["отсучивши"],
    "отсучивав": ["отсучивавши"],
    "отсучивавши": ["отсучивав"],
    "отсучивши": ["отсучив"],
    "отсчитав": ["отсчитавши"],
    "отсчитавши": ["отсчитав"],
    "отсчитывав": ["отсчитывавши"],
    "отсчитывавши": ["отсчитывав"],
    "отсчёт": ["отсчитывание"],
    "отсъствие": ["неналичие"],
    "отсылав": ["отсылавши"],
    "отсылавши": ["отсылав"],
    "отсып": ["отсыпание"],
    "отсыпав": ["отсыпавши"],
    "отсыпавши": ["отсыпав"],
    "отсырев": ["отсыревши"],
    "отсыревав": ["отсыревавши"],
    "отсыревавши": ["отсыревав"],
    "отсыревать": ["намокать", "сыреть"],
    "отсыревши": ["отсырев"],
    "отсыреть": ["намокнуть"],
    "отсыхав": ["отсыхавши"],
    "отсыхавши": ["отсыхав"],
    "отсюда": ["отсель", "отсюдова", "отсюду", "откуда", "оттуда", "следовательно"],
    "отсюдова": ["отсюда"],
    "отсюду": ["отсель", "отсюда", "отсюдова", "оттуда", "оттуду", "откуда"],
    "отсянка": ["оттенък", "нюанс"],
    "оттабанив": ["оттабанивши"],
    "оттабанивши": ["оттабанив"],
    "оттаивав": ["оттаивавши"],
    "оттаивавши": ["оттаивав"],
    "оттаивание": ["таяние"],
    "оттаивать": ["размораживаться", "размораживать", "растапливать", "отогревать", "согревать", "смягчаться"],
    "отталкивав": ["отталкивавши"],
    "отталкивавши": ["отталкивав"],
    "отталкиванье": ["отталкивание"],
    "отталкиваться": ["продвигаться", "проталкиваться", "отодвигаться", "основываться", "питать отвращение", "испытывать отвращение"],
    "оттанцевав": ["оттанцевавши"],
    "оттанцевавши": ["оттанцевав"],
    "оттанцовывав": ["оттанцовывавши"],
    "оттанцовывавши": ["оттанцовывав"],
    "оттапливав": ["оттапливавши"],
    "оттапливавши": ["оттапливав"],
    "оттаптывав": ["оттаптывавши"],
    "оттаптывавши": ["оттаптывав"],
    "оттарабанив": ["оттарабанивши"],
    "оттарабанивав": ["оттарабанивавши"],
    "оттарабанивавши": ["оттарабанивав"],
    "оттарабанивши": ["оттарабанив"],
    "оттарабанить": ["отгреметь", "отстучать"],
    "оттаскав": ["оттаскавши"],
    "оттаскавши": ["оттаскав"],
    "оттаскивав": ["оттаскивавши"],
    "оттаскивавши": ["оттаскивав"],
    "оттаскивавший": ["отволакивавший", "оттягивавший"],
    "оттачивав": ["оттачивавши"],
    "оттачивавши": ["оттачивав"],
    "оттащив": ["оттащивши"],
    "оттащивши": ["оттащив"],
    "оттаяв": ["оттаявши"],
    "оттаявши": ["оттаяв"],
    "оттаять": ["растаять", "растопить", "разморозить"],
    "оттеда": ["оттедова", "оттуда"],
    "оттекав": ["оттекавши"],
    "оттекавши": ["оттекав"],
    "оттекать": ["отливать"],
    "оттелева": ["оттуда", "оттеле", "оттель", "оттеля", "оттоль", "оттудова"],
    "оттель": ["оттуда", "оттеле", "оттелева", "оттеля", "оттоль", "оттудова"],
    "оттенив": ["оттенивши"],
    "оттенивав": ["оттенивавши"],
    "оттенивавши": ["оттенивав"],
    "оттенивши": ["оттенив"],
    "оттенок": ["оттень"],
    "оттеночный": ["нюансный", "тоновой"],
    "оттеняв": ["оттенявши"],
    "оттенявши": ["оттеняв"],
    "оттеплев": ["оттеплевши"],
    "оттеплевши": ["оттеплев"],
    "оттеребив": ["оттеребивши"],
    "оттеребивши": ["оттеребив"],
    "оттерев": ["оттёрши"],
    "оттесав": ["оттесавши"],
    "оттесавши": ["оттесав"],
    "оттеснив": ["оттеснивши"],
    "оттеснивши": ["оттеснив"],
    "оттесняв": ["оттеснявши"],
    "оттеснявши": ["оттесняв"],
    "оттестировав": ["оттестировавши"],
    "оттестировавши": ["оттестировав"],
    "оттестировать": ["протестировать"],
    "оттирав": ["оттиравши"],
    "оттиравши": ["оттирав"],
    "оттиражировав": ["оттиражировавши"],
    "оттиражировавши": ["оттиражировав"],
    "оттирание": ["очищение", "растирание", "отодвигание", "оттеснение"],
    "оттирать": ["отдраивать", "оттеснять"],
    "оттиск": ["отпечаток"],
    "оттискав": ["оттискавши"],
    "оттискавши": ["оттискав"],
    "оттискивав": ["оттискивавши"],
    "оттискивавши": ["оттискивав"],
    "оттискивать": ["отпечатывать", "оттеснять"],
    "оттиснув": ["оттиснувши"],
    "оттиснувши": ["оттиснув"],
    "оттитровав": ["оттитровавши"],
    "оттитровавши": ["оттитровав"],
    "оттитровывав": ["оттитровывавши"],
    "оттитровывавши": ["оттитровывав"],
    "оттого": ["поэтому", "потому что"],
    "оттоковав": ["оттоковавши"],
    "оттоковавши": ["оттоковав"],
    "оттоле": ["оттуда"],
    "оттолкав": ["оттолкавши"],
    "оттолкавши": ["оттолкав"],
    "оттолкнув": ["оттолкнувши"],
    "оттолкнувши": ["оттолкнув"],
    "оттолковав": ["оттолковавши"],
    "оттолковавши": ["оттолковав"],
    "оттоль": ["оттуда", "оттеле", "оттелева", "оттель", "оттеля", "оттудова"],
    "оттоман": ["осман", "оттоманка"],
    "оттоманка": ["оттоман", "тахта", "турчанка"],
    "оттоманский": ["османский"],
    "оттопав": ["оттопавши"],
    "оттопавши": ["оттопав"],
    "оттопив": ["оттопивши"],
    "оттопивши": ["оттопив"],
    "оттоптав": ["оттоптавши"],
    "оттоптавши": ["оттоптав"],
    "оттопывав": ["оттопывавши"],
    "оттопывавши": ["оттопывав"],
    "оттопырив": ["оттопыривши"],
    "оттопыривав": ["оттопыривавши"],
    "оттопыривавши": ["оттопыривав"],
    "оттопыривши": ["оттопырив"],
    "отторгав": ["отторгавши"],
    "отторгавши": ["отторгав"],
    "отторгать": ["отделять"],
    "отторгнув": ["отторгнувши"],
    "отторгнувши": ["отторгнув"],
    "отторговав": ["отторговавши"],
    "отторговавши": ["отторговав"],
    "отторговывав": ["отторговывавши"],
    "отторговывавши": ["отторговывав"],
    "отторжение": ["отвержение", "неприятие"],
    "отторженье": ["отторжение"],
    "оттормаживав": ["оттормаживавши"],
    "оттормаживавши": ["оттормаживав"],
    "оттормозив": ["оттормозивши"],
    "оттормозивши": ["оттормозив"],
    "отточенный": ["заточенный", "заострённый"],
    "отточив": ["отточивши"],
    "отточивши": ["отточив"],
    "отточие": ["многоточие"],
    "оттранслировав": ["оттранслировавши"],
    "оттранслировавши": ["оттранслировав"],
    "оттрассировав": ["оттрассировавши"],
    "оттрассировавши": ["оттрассировав"],
    "оттрахав": ["оттрахавши"],
    "оттрахавши": ["оттрахав"],
    "оттрахать": ["отыметь", "выебать", "трахнуть"],
    "оттрезвонив": ["оттрезвонивши"],
    "оттрезвонивши": ["оттрезвонив"],
    "оттренировав": ["оттренировавши"],
    "оттренировавши": ["оттренировав"],
    "оттренировывав": ["оттренировывавши"],
    "оттренировывавши": ["оттренировывав"],
    "оттрепав": ["оттрепавши"],
    "оттрепавши": ["оттрепав"],
    "оттрубив": ["оттрубивши"],
    "оттрубивши": ["оттрубив"],
    "оттрясав": ["оттрясавши"],
    "оттрясавши": ["оттрясав"],
    "оттряхивав": ["оттряхивавши"],
    "оттряхивавши": ["оттряхивав"],
    "оттряхнув": ["оттряхнувши"],
    "оттряхнувши": ["оттряхнув"],
    "оттрёпывав": ["оттрёпывавши"],
    "оттрёпывавши": ["оттрёпывав"],
    "оттуда": ["оттеле", "оттелева", "оттель", "оттеля", "оттоль", "оттудова"],
    "оттудова": ["оттуда", "оттеле", "оттелева", "оттель", "оттеля", "оттоль"],
    "оттужив": ["оттуживши"],
    "оттуживши": ["оттужив"],
    "оттузив": ["оттузивши"],
    "оттузивши": ["оттузив"],
    "оттузить": ["отмутузить", "отвалтузить"],
    "оттушевав": ["оттушевавши"],
    "оттушевавши": ["оттушевав"],
    "оттушёвывав": ["оттушёвывавши"],
    "оттушёвывавши": ["оттушёвывав"],
    "оттыкав": ["оттыкавши"],
    "оттыкавши": ["оттыкав"],
    "оттюкав": ["оттюкавши"],
    "оттюкавши": ["оттюкав"],
    "оттюкнув": ["оттюкнувши"],
    "оттюкнувши": ["оттюкнув"],
    "оттягав": ["оттягавши"],
    "оттягавши": ["оттягав"],
    "оттягивав": ["оттягивавши"],
    "оттягивавши": ["оттягивав"],
    "оттянув": ["оттянувши"],
    "оттянувши": ["оттянув"],
    "оттяпав": ["оттяпавши"],
    "оттяпавши": ["оттяпав"],
    "оттяпнув": ["оттяпнувши"],
    "оттяпнувши": ["оттяпнув"],
    "оттяпывав": ["оттяпывавши"],
    "оттяпывавши": ["оттяпывав"],
    "оттёк": ["сироп", "патока"],
    "оттёрши": ["оттерев"],
    "оттёсывав": ["оттёсывавши"],
    "оттёсывавши": ["оттёсывав"],
    "отудив": ["отудивши"],
    "отудивши": ["отудив"],
    "отудобев": ["отудобевши"],
    "отудобевши": ["отудобев"],
    "отудобеть": ["ожить", "отогреться", "отойти", "очнуться", "опомниться", "прийти в себя"],
    "отужинав": ["отужинавши", "поужинав"],
    "отужинавши": ["отужинав"],
    "отуманенный": ["обволоченный", "окутанный", "затянутый", "подёрнутый", "заволоченный", "застланный", "затуманенный", "обложенный", "повитый", "мутный", "одурманенный", "замороченный", "соблазнённый", "обольщённый", "ослеплённый"],
    "отуманив": ["отуманивши"],
    "отуманивав": ["отуманивавши"],
    "отуманивавши": ["отуманивав"],
    "отуманивши": ["отуманив"],
    "отупев": ["отупевши"],
    "отупевав": ["отупевавши"],
    "отупевавши": ["отупевав"],
    "отупевши": ["отупев"],
    "отупело": ["тупо"],
    "отупенье": ["отупение"],
    "отупеть": ["одуреть"],
    "отупив": ["отупивши"],
    "отупивши": ["отупив"],
    "отупляв": ["отуплявши"],
    "отуплявши": ["отупляв"],
    "отураш": ["отрач"],
    "отуречив": ["отуречивши"],
    "отуречивав": ["отуречивавши"],
    "отуречивавши": ["отуречивав"],
    "отуречивание": ["тюркизация"],
    "отуречивши": ["отуречив"],
    "отутюжив": ["отутюживши"],
    "отутюживав": ["отутюживавши"],
    "отутюживавши": ["отутюживав"],
    "отутюживши": ["отутюжив"],
    "отучав": ["отучавши"],
    "отучавши": ["отучав"],
    "отучив": ["отучивши"],
    "отучивав": ["отучивавши"],
    "отучивавши": ["отучивав"],
    "отучивать": ["отучать"],
    "отучивши": ["отучив"],
    "отучить": ["выучить", "доучить"],
    "отучнев": ["отучневши"],
    "отучневши": ["отучнев"],
    "отфактурировав": ["отфактурировавши"],
    "отфактурировавши": ["отфактурировав"],
    "отфактуровав": ["отфактуровавши"],
    "отфактуровавши": ["отфактуровав"],
    "отфанеровав": ["отфанеровавши"],
    "отфанеровавши": ["отфанеровав"],
    "отфиксировав": ["отфиксировавши"],
    "отфиксировавши": ["отфиксировав"],
    "отфильтровав": ["отфильтровавши"],
    "отфильтровавши": ["отфильтровав"],
    "отфильтровывав": ["отфильтровывавши"],
    "отфильтровывавши": ["отфильтровывав"],
    "отфорвардить": ["форварднуть"],
    "отформатировав": ["отформатировавши"],
    "отформатировавши": ["отформатировав"],
    "отформовав": ["отформовавши"],
    "отформовавши": ["отформовав"],
    "отформовывав": ["отформовывавши"],
    "отформовывавши": ["отформовывав"],
    "отфорсив": ["отфорсивши"],
    "отфорсивши": ["отфорсив"],
    "отфотожопив": ["отфотожопивши"],
    "отфотожопивши": ["отфотожопив"],
    "отфотожопить": ["отфотошопить"],
    "отфотошопив": ["отфотошопивши"],
    "отфотошопивши": ["отфотошопив"],
    "отфотошопить": ["отфотожопить"],
    "отфрезеровав": ["отфрезеровавши"],
    "отфрезеровавши": ["отфрезеровав"],
    "отфрезеровывав": ["отфрезеровывавши"],
    "отфрезеровывавши": ["отфрезеровывав"],
    "отфрендив": ["отфрендивши"],
    "отфрендивши": ["отфрендив"],
    "отфрендить": ["расфрендить", "разойтись", "раздружиться"],
    "отфутболив": ["отфутболивши"],
    "отфутболивав": ["отфутболивавши"],
    "отфутболивавши": ["отфутболивав"],
    "отфутболивши": ["отфутболив"],
    "отфыркав": ["отфыркавши"],
    "отфыркавши": ["отфыркав"],
    "отфыркивав": ["отфыркивавши"],
    "отфыркивавши": ["отфыркивав"],
    "отхаживав": ["отхаживавши"],
    "отхаживавши": ["отхаживав"],
    "отхаркав": ["отхаркавши"],
    "отхаркавши": ["отхаркав"],
    "отхаркивав": ["отхаркивавши"],
    "отхаркивавши": ["отхаркивав"],
    "отхаркиванье": ["отхаркивание"],
    "отхаркнув": ["отхаркнувши"],
    "отхаркнувши": ["отхаркнув"],
    "отхватав": ["отхватавши"],
    "отхватавши": ["отхватав"],
    "отхватив": ["отхвативши"],
    "отхвативши": ["отхватив"],
    "отхватить пиздюлей": ["отхватить люлей", "выхватить люлей", "огрести люлей", "люлей отхватить", "люлей выхватить", "люлей огрести", "выхватить пиздюлей", "огрести пиздюлей", "пиздюлей отхватить", "пиздюлей выхватить", "пиздюлей огрести"],
    "отхватывав": ["отхватывавши"],
    "отхватывавши": ["отхватывав"],
    "отхворав": ["отхворавши"],
    "отхворавши": ["отхворав"],
    "отхлебав": ["отхлебавши"],
    "отхлебавши": ["отхлебав"],
    "отхлебнув": ["отхлебнувши"],
    "отхлебнувши": ["отхлебнув"],
    "отхлебнуть": ["отпить", "спить"],
    "отхлестав": ["отхлеставши"],
    "отхлеставши": ["отхлестав"],
    "отхлопав": ["отхлопавши"],
    "отхлопавши": ["отхлопав"],
    "отхлопатывав": ["отхлопатывавши"],
    "отхлопатывавши": ["отхлопатывав"],
    "отхлопнув": ["отхлопнувши"],
    "отхлопнувши": ["отхлопнув"],
    "отхлопотав": ["отхлопотавши"],
    "отхлопотавши": ["отхлопотав"],
    "отхлопотать": ["охлопотать"],
    "отхлопывав": ["отхлопывавши"],
    "отхлопывавши": ["отхлопывав"],
    "отхлынув": ["отхлынувши"],
    "отхлынувши": ["отхлынув"],
    "отхлыстав": ["отхлыставши"],
    "отхлыставши": ["отхлыстав"],
    "отхлыстать": ["отхлестать"],
    "отхлыстывав": ["отхлыстывавши"],
    "отхлыстывавши": ["отхлыстывав"],
    "отхлёбывав": ["отхлёбывавши"],
    "отхлёбывавши": ["отхлёбывав"],
    "отхлёстывав": ["отхлёстывавши"],
    "отхлёстывавши": ["отхлёстывав"],
    "отход": ["отступление", "отброс", "отхожий промысел"],
    "отходив": ["отходивши"],
    "отходивши": ["отходив"],
    "отходничав": ["отходничавши"],
    "отходничавши": ["отходничав"],
    "отходос": ["отходняк"],
    "отходчивый": ["незлопамятный"],
    "отхожее место": ["туалет"],
    "отхотев": ["отхотевши"],
    "отхотевши": ["отхотев"],
    "отхотеться": ["расхотеться"],
    "отхрапев": ["отхрапевши"],
    "отхрапевши": ["отхрапев"],
    "отхрапывав": ["отхрапывавши"],
    "отхрапывавши": ["отхрапывав"],
    "отхромировав": ["отхромировавши"],
    "отхромировавши": ["отхромировав"],
    "отхуесосив": ["отхуесосивши"],
    "отхуесосивши": ["отхуесосив"],
    "отхуесосить": ["отвафлить", "завафлить", "отминьетить", "отчмызать", "откифирить", "оттащить за щеку", "дать на клык", "дать сосюру отчитать болту", "сунуть за щеку", "стрельнуть в голову", "отматерить", "выматерить", "отвозить на матах", "на матах отвозить", "оттаскать на матерках"],
    "отхуякав": ["отхуякавши"],
    "отхуякавши": ["отхуякав"],
    "отхуярив": ["отхуяривши"],
    "отхуяривши": ["отхуярив"],
    "отхуяченный": ["отделанный", "отмудоханный", "измудоханный"],
    "отхуячив": ["отхуячивши"],
    "отхуячивав": ["отхуячивавши"],
    "отхуячивавши": ["отхуячивав"],
    "отхуячивши": ["отхуячив"],
    "отцарствовав": ["отцарствовавши"],
    "отцарствовавши": ["отцарствовав"],
    "отцветав": ["отцветавши"],
    "отцветавши": ["отцветав"],
    "отцветив": ["отцветивши"],
    "отцветивши": ["отцветив"],
    "отцвечивав": ["отцвечивавши"],
    "отцвечивавши": ["отцвечивав"],
    "отцедив": ["отцедивши"],
    "отцедивши": ["отцедив"],
    "отцедить": ["отфильтровать"],
    "отцеживав": ["отцеживавши"],
    "отцеживавши": ["отцеживав"],
    "отцеловав": ["отцеловавши"],
    "отцеловавши": ["отцеловав"],
    "отцентрировав": ["отцентрировавши"],
    "отцентрировавши": ["отцентрировав"],
    "отцентрифугировав": ["отцентрифугировавши"],
    "отцентрифугировавши": ["отцентрифугировав"],
    "отцентровав": ["отцентровавши"],
    "отцентровавши": ["отцентровав"],
    "отцепив": ["отцепивши"],
    "отцепивши": ["отцепив"],
    "отцепляв": ["отцеплявши"],
    "отцеплявши": ["отцепляв"],
    "отциклевав": ["отциклевавши"],
    "отциклевавши": ["отциклевав"],
    "отцифровав": ["отцифровавши"],
    "отцифровавши": ["отцифровав"],
    "отцов": ["папин", "тятин", "батюшкин", "отцовский"],
    "отцовский": ["отцов", "папин", "тятин", "батюшкин"],
    "отцокав": ["отцокавши"],
    "отцокавши": ["отцокав"],
    "отчаиваться": ["впадать в отчаяние"],
    "отчал": ["отчаливание"],
    "отчалив": ["отчаливши"],
    "отчаливав": ["отчаливавши"],
    "отчаливавши": ["отчаливав"],
    "отчаливши": ["отчалив"],
    "отчасти": ["частично"],
    "отчаяние": ["безнадёжность", "печаль", "уныние"],
    "отчаянный": ["отчаявшийся", "яростный", "буйный", "неистовый", "неугомонный"],
    "отчаянье": ["отчаяние", "безнадёжность", "печаль", "уныние"],
    "отчаёвничав": ["отчаёвничавши"],
    "отчаёвничавши": ["отчаёвничав"],
    "отчебучив": ["отчебучивши"],
    "отчебучивав": ["отчебучивавши"],
    "отчебучивавши": ["отчебучивав"],
    "отчебучивши": ["отчебучив"],
    "отчебучить": ["отчудить", "учудить", "отмочить", "выдать", "отжечь"],
    "отчего": ["почему", "вследствие чего", "поэтому"],
    "отчего-либо": ["отчего-нибудь", "отчего-то"],
    "отчего-нибудь": ["отчего-либо", "отчего-то"],
    "отчего-то": ["почему-то", "чего-то", "отчего-либо", "отчего-нибудь"],
    "отчеканив": ["отчеканивши"],
    "отчеканивав": ["отчеканивавши"],
    "отчеканивавши": ["отчеканивав"],
    "отчеканивши": ["отчеканив"],
    "отчекрыжив": ["отчекрыживши"],
    "отчекрыживав": ["отчекрыживавши"],
    "отчекрыживавши": ["отчекрыживав"],
    "отчекрыживши": ["отчекрыжив"],
    "отчекрыжить": ["оттяпать"],
    "отчеренковав": ["отчеренковавши"],
    "отчеренковавши": ["отчеренковав"],
    "отчеркнув": ["отчеркнувши"],
    "отчеркнувши": ["отчеркнув"],
    "отчерпав": ["отчерпавши"],
    "отчерпавши": ["отчерпав"],
    "отчерпнув": ["отчерпнувши"],
    "отчерпнувши": ["отчерпнув"],
    "отчерпывав": ["отчерпывавши"],
    "отчерпывавши": ["отчерпывав"],
    "отчертив": ["отчертивши"],
    "отчертивши": ["отчертив"],
    "отчерчивав": ["отчерчивавши"],
    "отчерчивавши": ["отчерчивав"],
    "отчесав": ["отчесавши"],
    "отчесавши": ["отчесав"],
    "отчество": ["патроним"],
    "отчехвостив": ["отчехвостивши"],
    "отчехвостивши": ["отчехвостив"],
    "отчизна": ["отечество", "родина"],
    "отчий": ["отцовский", "родительский", "родной"],
    "отчикав": ["отчикавши"],
    "отчикавши": ["отчикав"],
    "отчикнув": ["отчикнувши"],
    "отчикнувши": ["отчикнув"],
    "отчим": ["вотчим"],
    "отчинив": ["отчинивши"],
    "отчинивши": ["отчинив"],
    "отчиняв": ["отчинявши"],
    "отчинявши": ["отчиняв"],
    "отчирикав": ["отчирикавши"],
    "отчирикавши": ["отчирикав"],
    "отчиркав": ["отчиркавши"],
    "отчиркавши": ["отчиркав"],
    "отчислив": ["отчисливши"],
    "отчисливши": ["отчислив"],
    "отчисляв": ["отчислявши"],
    "отчислявши": ["отчисляв"],
    "отчистив": ["отчистивши"],
    "отчистивши": ["отчистив"],
    "отчистить": ["вычистить", "очистить", "почистить"],
    "отчитав": ["отчитавши"],
    "отчитавши": ["отчитав"],
    "отчитывав": ["отчитывавши"],
    "отчитывавши": ["отчитывав"],
    "отчитываться": ["давать отчёт"],
    "отчихав": ["отчихавши"],
    "отчихавши": ["отчихав"],
    "отчихвостив": ["отчихвостивши"],
    "отчихвостивши": ["отчихвостив"],
    "отчихвостить": ["отругать"],
    "отчищав": ["отчищавши"],
    "отчищавши": ["отчищав"],
    "отчленив": ["отчленивши"],
    "отчленивши": ["отчленив"],
    "отчленяв": ["отчленявши"],
    "отчленявши": ["отчленяв"],
    "отчпокав": ["отчпокавши"],
    "отчпокавши": ["отчпокав"],
    "отчпоканный": ["оттраханный"],
    "отчпокать": ["оттрахать"],
    "отчубучив": ["отчубучивши"],
    "отчубучивав": ["отчубучивавши"],
    "отчубучивавши": ["отчубучивав"],
    "отчубучивши": ["отчубучив"],
    "отчубучить": ["отчебучить", "учудить"],
    "отчудачив": ["отчудачивши"],
    "отчудачивши": ["отчудачив"],
    "отчудачить": ["отчудить", "учудить"],
    "отчудив": ["отчудивши"],
    "отчудивши": ["отчудив"],
    "отчуждав": ["отчуждавши"],
    "отчуждавши": ["отчуждав"],
    "отчуждение": ["экспроприация", "отстранённость", "отчуждённость"],
    "отчужденье": ["отчуждение"],
    "отчуждив": ["отчуждивши"],
    "отчуждивши": ["отчуждив"],
    "отчуждить": ["отчудить"],
    "отчуждённый": ["обособленный", "замкнутый", "отрешённый", "отстранённый"],
    "отчёркивав": ["отчёркивавши"],
    "отчёркивавши": ["отчёркивав"],
    "отчёсывав": ["отчёсывавши"],
    "отчёсывавши": ["отчёсывав"],
    "отчётливо": ["чётко", "явственно"],
    "отчётливый": ["чёткий"],
    "отшабашив": ["отшабашивши"],
    "отшабашивши": ["отшабашив"],
    "отшагав": ["отшагавши"],
    "отшагавши": ["отшагав"],
    "отшагивав": ["отшагивавши"],
    "отшагивавши": ["отшагивав"],
    "отшагнув": ["отшагнувши"],
    "отшагнувши": ["отшагнув"],
    "отшатнув": ["отшатнувши"],
    "отшатнувши": ["отшатнув"],
    "отшатнуться": ["отступить", "шатнуться", "отдалиться"],
    "отшатывав": ["отшатывавши"],
    "отшатывавши": ["отшатывав"],
    "отшвартовав": ["отшвартовавши"],
    "отшвартовавши": ["отшвартовав"],
    "отшвартоваться": ["отдать швартовы"],
    "отшвартовывав": ["отшвартовывавши"],
    "отшвартовывавши": ["отшвартовывав"],
    "отшвыривав": ["отшвыривавши"],
    "отшвыривавши": ["отшвыривав"],
    "отшвырнув": ["отшвырнувши"],
    "отшвырнувши": ["отшвырнув"],
    "отшвыряв": ["отшвырявши"],
    "отшвырявши": ["отшвыряв"],
    "отшелестев": ["отшелестевши"],
    "отшелестевши": ["отшелестев"],
    "отшелушив": ["отшелушивши"],
    "отшелушивав": ["отшелушивавши"],
    "отшелушивавши": ["отшелушивав"],
    "отшелушивание": ["эксфолиация", "пилинг"],
    "отшелушивши": ["отшелушив"],
    "отшельник": ["аскет", "пустынник", "анахорет", "затворник"],
    "отшельничав": ["отшельничавши"],
    "отшельничавши": ["отшельничав"],
    "отшельнический": ["пустыннический", "отшельничий"],
    "отшельничий": ["отшельнический"],
    "отшибав": ["отшибавши"],
    "отшибавши": ["отшибав"],
    "отшибив": ["отшибивши"],
    "отшибивши": ["отшибив"],
    "отшибнув": ["отшибнувши"],
    "отшибнувши": ["отшибнув"],
    "отшив": ["отшивши"],
    "отшивав": ["отшивавши"],
    "отшивавши": ["отшивав"],
    "отшивать": ["отбивать", "отваживать", "прогонять"],
    "отшивши": ["отшив"],
    "отшкурив": ["отшкуривши"],
    "отшкуривав": ["отшкуривавши"],
    "отшкуривавши": ["отшкуривав"],
    "отшкуривши": ["отшкурив"],
    "отшлифовав": ["отшлифовавши"],
    "отшлифовавши": ["отшлифовав"],
    "отшлифовывав": ["отшлифовывавши"],
    "отшлифовывавши": ["отшлифовывав"],
    "отшлёпав": ["отшлёпавши"],
    "отшлёпавши": ["отшлёпав"],
    "отшлёпывав": ["отшлёпывавши"],
    "отшлёпывавши": ["отшлёпывав"],
    "отшмыгать": ["отчистить", "отполировать", "отдраить"],
    "отшнуровывав": ["отшнуровывавши"],
    "отшнуровывавши": ["отшнуровывав"],
    "отшоферив": ["отшоферивши"],
    "отшоферивши": ["отшоферив"],
    "отшпандорив": ["отшпандоривши"],
    "отшпандоривав": ["отшпандоривавши"],
    "отшпандоривавши": ["отшпандоривав"],
    "отшпандоривши": ["отшпандорив"],
    "отшпилив": ["отшпиливши"],
    "отшпиливав": ["отшпиливавши"],
    "отшпиливавши": ["отшпиливав"],
    "отшпиливши": ["отшпилив"],
    "отштамповав": ["отштамповавши"],
    "отштамповавши": ["отштамповав"],
    "отштамповывав": ["отштамповывавши"],
    "отштамповывавши": ["отштамповывав"],
    "отштопав": ["отштопавши"],
    "отштопавши": ["отштопав"],
    "отштопывав": ["отштопывавши"],
    "отштопывавши": ["отштопывав"],
    "отштормив": ["отштормивши"],
    "отштормивши": ["отштормив"],
    "отштудировав": ["отштудировавши"],
    "отштудировавши": ["отштудировав"],
    "отштукатурив": ["отштукатуривши"],
    "отштукатуривав": ["отштукатуривавши"],
    "отштукатуривавши": ["отштукатуривав"],
    "отштукатуривать": ["штукатурить"],
    "отштукатуривши": ["отштукатурив"],
    "отштурмовав": ["отштурмовавши"],
    "отштурмовавши": ["отштурмовав"],
    "отшугивав": ["отшугивавши"],
    "отшугивавши": ["отшугивав"],
    "отшугнув": ["отшугнувши"],
    "отшугнувши": ["отшугнув"],
    "отшумев": ["отшумевши"],
    "отшумевши": ["отшумев"],
    "отшуметь": ["затихнуть", "отгреметь"],
    "отшуршав": ["отшуршавши"],
    "отшуршавши": ["отшуршав"],
    "отшутив": ["отшутивши"],
    "отшутивши": ["отшутив"],
    "отщебетав": ["отщебетавши"],
    "отщебетавши": ["отщебетав"],
    "отщеголяв": ["отщеголявши"],
    "отщеголявши": ["отщеголяв"],
    "отщелкнув": ["отщелкнувши"],
    "отщелкнувши": ["отщелкнув"],
    "отщемив": ["отщемивши"],
    "отщемивши": ["отщемив"],
    "отщемляв": ["отщемлявши"],
    "отщемлявши": ["отщемляв"],
    "отщепав": ["отщепавши"],
    "отщепавши": ["отщепав"],
    "отщепенец": ["изменник", "фракционер", "раскольник", "еретик"],
    "отщепив": ["отщепивши"],
    "отщепивши": ["отщепив"],
    "отщепляв": ["отщеплявши"],
    "отщеплявши": ["отщепляв"],
    "отщетив": ["отщетивши"],
    "отщетивши": ["отщетив"],
    "отщипав": ["отщипавши"],
    "отщипавши": ["отщипав"],
    "отщипнув": ["отщипнувши"],
    "отщипнувши": ["отщипнув"],
    "отщипывав": ["отщипывавши"],
    "отщипывавши": ["отщипывав"],
    "отщёлкав": ["отщёлкавши"],
    "отщёлкавши": ["отщёлкав"],
    "отщёлкивав": ["отщёлкивавши"],
    "отщёлкивавши": ["отщёлкивав"],
    "отщёлкнув": ["отщёлкнувши"],
    "отщёлкнувши": ["отщёлкнув"],
    "отъебав": ["отъебавши"],
    "отъебавши": ["отъебав"],
    "отъебать": ["оттаскать", "оттаскать по полной", "оттаскать по полной программе", "оттаскать на хуях", "отъябать"],
    "отъебаться": ["отвязаться", "отстать", "прекратиться", "исчезнуть", "сгинуть"],
    "отъебнуть": ["отъебёхать"],
    "отъебошив": ["отъебошивши"],
    "отъебошивши": ["отъебошив"],
    "отъебукав": ["отъебукавши"],
    "отъебукавши": ["отъебукав"],
    "отъебукать": ["выматерить", "изматерить", "отъебукентить"],
    "отъедав": ["отъедавши"],
    "отъедавши": ["отъедав"],
    "отъединив": ["отъединивши"],
    "отъединивши": ["отъединив"],
    "отъединить": ["разъединить", "отсоединить"],
    "отъединяв": ["отъединявши"],
    "отъединявши": ["отъединяв"],
    "отъединять": ["отсоединять"],
    "отъездив": ["отъездивши"],
    "отъездивши": ["отъездив"],
    "отъезжав": ["отъезжавши"],
    "отъезжавши": ["отъезжав"],
    "отъезжание": ["отъезд"],
    "отъесть": ["откусить", "наесть", "отожрать", "захватить", "отхватить", "отнять", "оттяпать", "отхапать", "захапать"],
    "отъесться": ["поправиться", "потолстеть", "растолстеть", "разжиреть", "отожраться"],
    "отъехав": ["отъехавши"],
    "отъехавши": ["отъехав"],
    "отъюлив": ["отъюливши"],
    "отъюливав": ["отъюливавши"],
    "отъюливавши": ["отъюливав"],
    "отъюливать": ["уклоняться", "избегать"],
    "отъюливши": ["отъюлив"],
    "отъюлить": ["уклониться", "избежать"],
    "отъюстировав": ["отъюстировавши"],
    "отъюстировавши": ["отъюстировав"],
    "отъяв": ["отъявши"],
    "отъявив": ["отъявивши"],
    "отъявивши": ["отъявив"],
    "отъявляв": ["отъявлявши"],
    "отъявлявши": ["отъявляв"],
    "отъявши": ["отъяв"],
    "отъёбываться": ["отвязываться", "отставать"],
    "отыграв": ["отыгравши"],
    "отыгравши": ["отыграв"],
    "отыгрывав": ["отыгрывавши"],
    "отыгрывавши": ["отыгрывав"],
    "отыгрыш": ["отыгрывание", "ритурнель", "пас"],
    "отылив": ["отыливши"],
    "отыливши": ["отылив"],
    "отыллюстрировав": ["отыллюстрировавши"],
    "отыллюстрировавши": ["отыллюстрировав"],
    "отыллюстрироваться": ["проиллюстрироваться"],
    "отымав": ["отымавши"],
    "отымавши": ["отымав"],
    "отымать": ["отнимать"],
    "отымев": ["отымевши"],
    "отымевши": ["отымев"],
    "отыметь": ["поиметь", "трахнуть", "вздрючить"],
    "отымённый": ["деноминативный"],
    "отынуда": ["отинуде", "отинуду", "отинуды", "отинудь"],
    "отыскав": ["отыскавши"],
    "отыскавши": ["отыскав"],
    "отыскивав": ["отыскивавши"],
    "отыскивавши": ["отыскивав"],
    "отыскиванье": ["отыскивание"],
    "отышачив": ["отышачивши"],
    "отышачивши": ["отышачив"],
    "отэкзаменовав": ["отэкзаменовавши"],
    "отэкзаменовавши": ["отэкзаменовав"],
    "отэкзаменовать": ["проэкзаменовать"],
    "отяготев": ["отяготевши"],
    "отяготевши": ["отяготев"],
    "отяготив": ["отяготивши"],
    "отяготивши": ["отяготив"],
    "отягощав": ["отягощавши"],
    "отягощавши": ["отягощав"],
    "отягощать": ["обременять"],
    "отягощение": ["утяжеление", "обременение"],
    "отягощённый": ["отяжелённый", "обременённый"],
    "отягчав": ["отягчавши"],
    "отягчавши": ["отягчав"],
    "отягчавшийся": ["усугублявшийся", "осложнявшийся", "усиливавшийся", "тяжелевший", "наливавшийся"],
    "отягчать": ["отягощать", "усугублять"],
    "отягчив": ["отягчивши"],
    "отягчивши": ["отягчив"],
    "отягчённый": ["отягощённый"],
    "отяжелев": ["отяжелевши"],
    "отяжелевав": ["отяжелевавши"],
    "отяжелевавши": ["отяжелевав"],
    "отяжелевши": ["отяжелев"],
    "отяжелеть": ["потяжелеть"],
    "отяжелив": ["отяжеливши"],
    "отяжеливши": ["отяжелив"],
    "отяжеляв": ["отяжелявши"],
    "отяжелявши": ["отяжеляв"],
    "отяжелённый": ["отягощённый"],
    "отёл": ["растёл"],
    "отёрши": ["отерев"],
    "отёсывав": ["отёсывавши"],
    "отёсывавши": ["отёсывав"],
    "оу": ["ох"],
    "оф": ["офс"],
    "офактурив": ["офактуривши"],
    "офактуривши": ["офактурив"],
    "офанзива": ["атака", "щурм", "пристъп", "настъпление"],
    "офарблення": ["пофарбування", "забарвлення"],
    "офаридгор": ["фотир"],
    "офаринанда": ["офаридгор"],
    "офариниш": ["таквин"],
    "офенский": ["коробейницкий", "афинский", "аламанский"],
    "офеня": ["коробейник", "ходебщик", "ходок", "мазыка", "масыга", "торгаш", "барышник", "промышленник", "скупщик", "перекупщик", "купец", "купчик", "купчина"],
    "оферта": ["оффер"],
    "офигев": ["офигевши"],
    "офигевав": ["офигевавши"],
    "офигевавши": ["офигевав"],
    "офигевать": ["охреневать", "обалдевать"],
    "офигевши": ["офигев"],
    "офигевший": ["охреневший", "обалдевший", "офонаревший", "очумевший"],
    "офигенно": ["классно", "обалденно", "офигительно", "потрясно"],
    "офигенный": ["офигительный", "обалденный", "пердатый", "клёвый", "потрясный", "классный", "потрясающий"],
    "офигеть": ["охренеть", "обалдеть", "офонареть", "очуметь", "ой-йо"],
    "офигительно": ["офигенно"],
    "офиолит": ["серпентинит"],
    "офиология": ["серпентология"],
    "офис": ["контора", "бюро", "канцелярия", "представительство", "штаб-квартира"],
    "офисное приложение": ["офисная программа"],
    "офисный планктон": ["канцелярская крыса", "белые воротнички"],
    "офит": ["благородный серпентин", "офианин", "наасен", "нахашен"],
    "офитовый": ["интерсертальный"],
    "офиура": ["змеехвостка"],
    "офицер": ["слон"],
    "офицерик": ["офицер"],
    "офицеришка": ["офицер", "офицерик"],
    "офицерня": ["офицерьё"],
    "офицеръ": ["слонъ"],
    "офицерьё": ["офицерня"],
    "официальничав": ["официальничавши"],
    "официальничавши": ["официальничав"],
    "официальничанье": ["чопорность", "официальность"],
    "официальный": ["строгий", "формальный"],
    "официальный язык": ["канцелярит"],
    "официальщина": ["официальность"],
    "официантка": ["подавальщица"],
    "офлюсовав": ["офлюсовавши"],
    "офлюсовавши": ["офлюсовав"],
    "офлюсовывав": ["офлюсовывавши"],
    "офлюсовывавши": ["офлюсовывав"],
    "офонарев": ["офонаревши"],
    "офонаревши": ["офонарев"],
    "офонаревший": ["обалдевший", "офигевший", "охреневший", "охеревший", "охуевший"],
    "офонареть": ["с ума сойти", "охренеть", "офигеть", "охуеть"],
    "оформив": ["оформивши"],
    "оформивши": ["оформив"],
    "оформитель": ["дизайнер"],
    "оформить": ["сформировать", "узаконить", "принять", "зачислить", "устроить"],
    "оформление": ["трудоустройство", "экстерьер"],
    "оформленность": ["сформированность"],
    "оформленье": ["оформление"],
    "оформливав": ["оформливавши"],
    "оформливавши": ["оформливав"],
    "оформляв": ["оформлявши"],
    "оформлявши": ["оформляв"],
    "оформлять": ["формулировать"],
    "офранцуживав": ["офранцуживавши"],
    "офранцуживавши": ["офранцуживав"],
    "офранцузив": ["офранцузивши"],
    "офранцузивши": ["офранцузив"],
    "офрирование": ["предложение"],
    "офрировать": ["предлагать"],
    "офс": ["оф"],
    "офсайд": ["вне игры"],
    "офсетная машина": ["офсетная печатная машина"],
    "офтальмолог": ["окулист", "глазник"],
    "офтальмология": ["глазное отделение"],
    "офтальмореография": ["реоофтальмография"],
    "офтоб": ["хуршед", "шамс"],
    "офтоббаро": ["ховар"],
    "офтопик": ["оффтопик", "офтоп", "оффтоп", "офф"],
    "офутеровав": ["офутеровавши"],
    "офутеровавши": ["офутеровав"],
    "оффер": ["оферта"],
    "охав": ["охавши"],
    "охаверничав": ["охаверничавши"],
    "охаверничавши": ["охаверничав"],
    "охавши": ["охав"],
    "охаживав": ["охаживавши"],
    "охаживавши": ["охаживав"],
    "охаживать": ["обхаживать", "ублажать", "стегать"],
    "охаивав": ["охаивавши"],
    "охаивавши": ["охаивав"],
    "охаивать": ["хаять"],
    "охайний": ["акуратний", "охайливий"],
    "охалпев": ["охалпевши"],
    "охалпевши": ["охалпев"],
    "охалпеть": ["обнаглеть", "охренеть"],
    "охальник": ["озорник", "нахал", "развратник"],
    "охальница": ["нахалка", "бесстыдница", "срамница"],
    "охальничав": ["охальничавши"],
    "охальничавши": ["охальничав"],
    "охальный": ["бесстыжий", "непристойный"],
    "охальство": ["охальничание"],
    "охамев": ["охамевши"],
    "охамевши": ["охамев"],
    "охарактеризовав": ["охарактеризовавши"],
    "охарактеризовавши": ["охарактеризовав"],
    "охарактеризовать": ["обрисовать", "назвать", "аттестовать", "отрекомендовать", "отнестись", "квалифицировать", "дать", "характеристику", "высказаться", "отозваться", "зарекомендовать", "рекомендовать"],
    "охарактеризовывав": ["охарактеризовывавши"],
    "охарактеризовывавши": ["охарактеризовывав"],
    "охаяв": ["охаявши"],
    "охаявши": ["охаяв"],
    "охаять": ["обхаять", "обругать", "изругать", "разругать", "опозорить", "опорочить", "очернить"],
    "охватив": ["охвативши"],
    "охвативши": ["охватив"],
    "охватить": ["обхватить"],
    "охватывав": ["охватывавши"],
    "охватывавши": ["охватывав"],
    "охватывать": ["обхватывать", "окружать"],
    "охвостье": ["ухвостье", "охоботье", "ухоботье", "ухоботь", "озадки", "хвостец"],
    "охерев": ["охеревши"],
    "охеревав": ["охеревавши"],
    "охеревавши": ["охеревав"],
    "охеревши": ["охерев"],
    "охеревший": ["офонаревший", "охуевший", "обалдевший"],
    "охеренно": ["охуенный", "офигенный"],
    "охереть": ["охуеть", "ахуеть", "обалдеть", "охренеть", "очуметь"],
    "охир": ["поён", "итмом", "тамом"],
    "охладев": ["охладевши"],
    "охладевав": ["охладевавши"],
    "охладевавши": ["охладевав"],
    "охладевать": ["остывать"],
    "охладевши": ["охладев"],
    "охладеть": ["остыть", "остынуть", "похолодать", "разлюбить"],
    "охладив": ["охладивши"],
    "охладивши": ["охладив"],
    "охладить": ["остудить"],
    "охлаждав": ["охлаждавши"],
    "охлаждавши": ["охлаждав"],
    "охлаждать": ["остужать"],
    "охлаждаться": ["остывать"],
    "охлажденье": ["охлаждение"],
    "охламон": ["болван", "чурбан"],
    "охламонка": ["полухвея", "простодырка"],
    "охлестав": ["охлеставши"],
    "охлеставши": ["охлестав"],
    "охлестнув": ["охлестнувши"],
    "охлестнувши": ["охлестнув"],
    "охломон": ["охламон"],
    "охлопав": ["охлопавши"],
    "охлопавши": ["охлопав"],
    "охлопатывав": ["охлопатывавши"],
    "охлопатывавши": ["охлопатывав"],
    "охлопать": ["рукоплескать", "аплодировать"],
    "охлопотав": ["охлопотавши"],
    "охлопотавши": ["охлопотав"],
    "охлопотать": ["отхлопотать"],
    "охлопывав": ["охлопывавши"],
    "охлопывавши": ["охлопывав"],
    "охлопье": ["хлопье"],
    "охлос": ["чернь", "плебс", "быдло"],
    "охлофобия": ["демофобия"],
    "охлупень": ["охлуп", "охлупь"],
    "охлюпкой": ["охлябь"],
    "охлябь": ["охлябью", "охлюпкой", "айдаком"],
    "охлябью": ["охлябь", "охлюпкой", "айдаком"],
    "охлёстывав": ["охлёстывавши"],
    "охлёстывавши": ["охлёстывав"],
    "охмелев": ["охмелевши"],
    "охмелевав": ["охмелевавши"],
    "охмелевавши": ["охмелевав"],
    "охмелевши": ["охмелев"],
    "охмелеть": ["опьянеть"],
    "охмелив": ["охмеливши"],
    "охмеливши": ["охмелив"],
    "охмеляв": ["охмелявши"],
    "охмелявши": ["охмеляв"],
    "охмурив": ["охмуривши"],
    "охмуривши": ["охмурив"],
    "охмурить": ["обольстить", "одурачить"],
    "охмуряв": ["охмурявши"],
    "охмурявши": ["охмуряв"],
    "охмурять": ["соблазнять"],
    "охмурёж": ["охмурение", "охмуренье", "охмуряж"],
    "охнув": ["охнувши"],
    "охнувши": ["охнув"],
    "охолаживав": ["охолаживавши"],
    "охолаживавши": ["охолаживав"],
    "охолащивав": ["охолащивавши"],
    "охолащивавши": ["охолащивав"],
    "охолащивание": ["кастрация"],
    "охолодав": ["охолодавши"],
    "охолодавши": ["охолодав"],
    "охолодев": ["охолодевши"],
    "охолодевши": ["охолодев"],
    "охолодив": ["охолодивши"],
    "охолодивши": ["охолодив"],
    "охолонив": ["охолонивши"],
    "охолонивши": ["охолонив"],
    "охолонув": ["охолонувши"],
    "охолонувши": ["охолонув"],
    "охолостив": ["охолостивши"],
    "охолостивши": ["охолостив"],
    "охомутав": ["охомутавши"],
    "охомутавши": ["охомутав"],
    "охорашивав": ["охорашивавши"],
    "охорашивавши": ["охорашивав"],
    "охорашивать": ["прихорашивать"],
    "охорашиваться": ["прихорашиваться"],
    "охота": ["ловля"],
    "охотбилет": ["охотничий билет"],
    "охотив": ["охотивши"],
    "охотивши": ["охотив"],
    "охотник-промысловик": ["промысловик-охотник"],
    "охотничав": ["охотничавши"],
    "охотничавши": ["охотничав"],
    "охотничать": ["охотиться"],
    "охотничий билет": ["охотбилет"],
    "охотно": ["с удовольствием", "с радостью"],
    "охотское море": ["ламское море", "камчатское море"],
    "охохоньки": ["охохонюшки", "охохошеньки"],
    "охохонюшки": ["охохоньки", "охохошеньки"],
    "охохохоньки": ["охохонюшки"],
    "охохошеньки": ["охохоньки", "охохонюшки"],
    "охочий": ["падкий"],
    "охрана": ["защита", "охранник"],
    "охраненье": ["охранение"],
    "охранив": ["охранивши"],
    "охранивши": ["охранив"],
    "охранительный": ["охранный"],
    "охранить": ["защитить", "уберечь"],
    "охранная грамота": ["охоронный лист"],
    "охранник": ["секьюрити", "сесуриту", "сторож"],
    "охраняв": ["охранявши"],
    "охранявши": ["охраняв"],
    "охранять": ["защищать"],
    "охренев": ["охреневши"],
    "охреневав": ["охреневавши"],
    "охреневавши": ["охреневав"],
    "охреневать": ["обалдевать", "обалденевать"],
    "охреневши": ["охренев"],
    "охреневший": ["офигевший"],
    "охренение": ["одурение"],
    "охренительно": ["поразительно"],
    "охренительный": ["изумительный"],
    "охрив": ["охривши"],
    "охривши": ["охрив"],
    "охрипнув": ["охрипнувши"],
    "охрипнувши": ["охрипнув"],
    "охровый": ["охряный"],
    "охромев": ["охромевши"],
    "охромевши": ["охромев"],
    "охрометь": ["захромать"],
    "охряной": ["охристый"],
    "охряный": ["охровый", "охряной", "охренный", "охристый"],
    "охтенка": ["охтинка"],
    "охтика": ["туберкулоза", "живеница"],
    "охтинка": ["охтенка"],
    "охуев": ["охуевши", "подохуев", "подохуевши", "приохуев", "приохуевши"],
    "охуевав": ["охуевавши"],
    "охуевавши": ["охуевав"],
    "охуевать": ["обалдевать", "опупевать", "одуревать", "охреневать", "офигевать", "фалломорфировать", "опизденевать"],
    "охуевши": ["охуев"],
    "охуевший": ["оборзевший"],
    "охуение": ["охуевание", "обалдение", "одурение", "отупение"],
    "охуенно": ["удивительно", "потрясающе", "слишком", "ишь ты", "как бы не так", "великолепно", "замечательно", "супер", "обалденно", "офигенно", "офигительно", "охуительно", "охуетительно", "охуевертительно", "охуеть"],
    "охуенность": ["великолепность", "невъебенность"],
    "охуенный": ["удивительный", "потрясающий", "великолепный", "опупенный", "охуительный", "охуетительный", "пиздатый", "пиздатейший", "охуенненький", "большой", "огромный"],
    "охуенский": ["удивительный", "потрясающий", "великолепный", "опупенный", "охуенный", "охуительный", "охуетительный", "пиздатый", "пиздатейший", "охуенненький"],
    "охуеть": ["обалдеть", "одуреть", "очуметь", "ошалеть", "охренеть", "офигеть", "фалломорфировать", "удивиться", "поразиться", "изумиться", "обомлеть", "оторопеть", "опешить", "с ума сойти", "обнаглеть"],
    "охуждав": ["охуждавши"],
    "охуждавши": ["охуждав"],
    "охуждать": ["осуждать", "порицать"],
    "охуительно": ["обалденно", "офигенно", "охуенно", "пиздато"],
    "охуительный": ["замечательный", "великолепный", "восхитительный", "изумительный", "охренительный", "офигенный", "офигительный", "пиздатый", "невъебенный", "охуенный", "охуетительный", "охуевертительный", "невообразимый", "непредставимый"],
    "охуй": ["оторопь", "ахуй"],
    "охулиард": ["дохулион"],
    "охулив": ["охуливши"],
    "охуливши": ["охулив"],
    "охулион": ["дохулион", "ахулиард"],
    "охулка": ["хула", "осуждение"],
    "охульник": ["хулитель"],
    "охульничав": ["охульничавши"],
    "охульничавши": ["охульничав"],
    "охуячив": ["охуячивши"],
    "охуячивав": ["охуячивавши"],
    "охуячивавши": ["охуячивав"],
    "охуячивши": ["охуячив"],
    "охымыш": ["охумуш"],
    "оцарапав": ["оцарапавши"],
    "оцарапавши": ["оцарапав"],
    "оцарапаться": ["пораниться"],
    "оцарапнув": ["оцарапнувши"],
    "оцарапнувши": ["оцарапнув"],
    "оцарапывав": ["оцарапывавши"],
    "оцарапывавши": ["оцарапывав"],
    "оцарапывать": ["царапать"],
    "оцветив": ["оцветивши"],
    "оцветивши": ["оцветив"],
    "оцедив": ["оцедивши"],
    "оцедивши": ["оцедив"],
    "оцедить": ["отцедить", "процедить"],
    "оцеживав": ["оцеживавши"],
    "оцеживавши": ["оцеживав"],
    "оцементировав": ["оцементировавши"],
    "оцементировавши": ["оцементировав"],
    "оценив": ["оценивши"],
    "оценивав": ["оценивавши"],
    "оценивавши": ["оценивав"],
    "оценивши": ["оценив"],
    "оценить": ["назначить цену"],
    "оценка": ["оценивание", "определение", "мнение", "суждение", "отзыв", "отметка", "балл"],
    "оценяв": ["оценявши"],
    "оценявши": ["оценяв"],
    "оцепенев": ["оцепеневши"],
    "оцепеневав": ["оцепеневавши"],
    "оцепеневавши": ["оцепеневав"],
    "оцепеневши": ["оцепенев"],
    "оцепенение": ["остолбенение", "ступор", "столбняк", "каталепсия", "оцепененье"],
    "оцепененье": ["оцепенение"],
    "оцепенеть": ["замереть", "застыть", "остолбенеть", "окаменеть", "онеметь"],
    "оцепенив": ["оцепенивши"],
    "оцепенивши": ["оцепенив"],
    "оцепеняв": ["оцепенявши"],
    "оцепенявши": ["оцепеняв"],
    "оцепив": ["оцепивши"],
    "оцепивши": ["оцепив"],
    "оцепленье": ["оцепление"],
    "оцепляв": ["оцеплявши"],
    "оцеплявши": ["оцепляв"],
    "оцилиндровав": ["оцилиндровавши"],
    "оцилиндровавши": ["оцилиндровав"],
    "оцинковав": ["оцинковавши"],
    "оцинковавши": ["оцинковав"],
    "оцинковка": ["оцинковывание"],
    "оцинковывав": ["оцинковывавши"],
    "оцинковывавши": ["оцинковывав"],
    "оцифровав": ["оцифровавши"],
    "оцифровавши": ["оцифровав"],
    "оцифровка": ["оцифровывание", "дигитализация"],
    "оцифровывав": ["оцифровывавши"],
    "оцифровывавши": ["оцифровывав"],
    "оцифровывание": ["оцифровка", "дигитализация", "диджитализация"],
    "очаг": ["источник", "эпицентр", "рассадник", "продлёнка"],
    "очапаться": ["очухаться", "оклематься", "прийти в себя", "очнуться", "опомниться"],
    "очапываться": ["очухиваться", "приходить в себя"],
    "очаровав": ["очаровавши"],
    "очаровавши": ["очаровав"],
    "очаровательница": ["обворожительница", "обольстительница", "чаровница", "обаятельница"],
    "очаровательно": ["прелестно", "прекрасно", "чудесно", "чарующе"],
    "очаровательный": ["обворожительный", "прелестный", "чарующий"],
    "очаровать": ["околдовать", "зачаровать", "заколдовать", "обворожить", "пленить"],
    "очаровашка": ["милашка"],
    "очаровывав": ["очаровывавши"],
    "очаровывавши": ["очаровывав"],
    "очебийност": ["очевидност", "нагледност", "яснота"],
    "очевидец": ["свидетель"],
    "очевидно": ["несомненно", "заметно", "ясно", "понятно", "безусловно", "бесспорно", "разумеется", "конечно", "наверное", "вероятно", "по-видимому", "видимо"],
    "очевидность": ["несомненность", "бесспорность", "понятность"],
    "очевидный": ["явный", "бесспорный", "наглядный"],
    "очеловеченье": ["очеловечение"],
    "очеловечив": ["очеловечивши"],
    "очеловечивав": ["очеловечивавши"],
    "очеловечивавши": ["очеловечивав"],
    "очеловечивание": ["очеловечение", "гуманизация"],
    "очеловечивши": ["очеловечив"],
    "очень": ["чересчур", "чрезмерно", "излишне", "слишком", "сильно", "весьма", "сверх меры", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно", "зело", "дюже"],
    "очепной": ["оцепной"],
    "очепятаться": ["опечататься"],
    "очепятка": ["опечатка"],
    "очервивев": ["очервивевши"],
    "очервивевши": ["очервивев"],
    "очередной": ["следующий", "последующий"],
    "очередь": ["череда", "хвост", "очерёдность", "порядок", "фаза", "этап", "период"],
    "очеретяный": ["очеретовый", "камышовый"],
    "очерк": ["контур", "очертание", "линия", "заметка"],
    "очеркнув": ["очеркнувши"],
    "очеркнувши": ["очеркнув"],
    "очернив": ["очернивши"],
    "очернивши": ["очернив"],
    "очернительство": ["очернение"],
    "очернить": ["опорочить"],
    "очерняв": ["очернявши"],
    "очернявши": ["очерняв"],
    "очернять": ["пятнать", "чернить", "марать", "порочить", "возводить напраслину", "позорить", "обесславливать", "обесчещивать", "ославлять", "замарывать"],
    "очерствев": ["очерствевши"],
    "очерствевав": ["очерствевавши"],
    "очерствевавши": ["очерствевав"],
    "очерствевать": ["черстветь"],
    "очерствевши": ["очерствев"],
    "очерстветь": ["зачерстветь"],
    "очерствив": ["очерствивши"],
    "очерствивши": ["очерствив"],
    "очерствляв": ["очерствлявши"],
    "очерствлявши": ["очерствляв"],
    "очерствляться": ["черстветь"],
    "очертав": ["очертавши"],
    "очертавши": ["очертав"],
    "очертание": ["контур", "абрис", "черты"],
    "очертанье": ["очертание"],
    "очертев": ["очертевши"],
    "очертевши": ["очертев"],
    "очертенев": ["очертеневши"],
    "очертеневши": ["очертенев"],
    "очертенело": ["хаотически", "без разбору"],
    "очертенеть": ["остервенеть", "опротиветь", "опостылеть", "осточертеть", "очертеть"],
    "очертив": ["очертивши"],
    "очертивши": ["очертив"],
    "очертка": ["рейсмас"],
    "очертывав": ["очертывавши"],
    "очертывавши": ["очертывав"],
    "очертя голову": ["стремительно", "поспешно", "стремглав", "опрометью", "сломя голову"],
    "очерчивав": ["очерчивавши"],
    "очерчивавши": ["очерчивав"],
    "очесав": ["очесавши"],
    "очесавши": ["очесав"],
    "очешник": ["очечник"],
    "очинив": ["очинивши"],
    "очинивав": ["очинивавши"],
    "очинивавши": ["очинивав"],
    "очинивать": ["очинять", "чинить", "заострять", "точить", "затачивать", "отачивать"],
    "очинивши": ["очинив"],
    "очиняв": ["очинявши"],
    "очинявши": ["очиняв"],
    "очинять": ["очинивать", "чинить", "заострять", "точить", "затачивать", "отачивать"],
    "очистив": ["очистивши"],
    "очистивши": ["очистив"],
    "очистить": ["вычистить", "отчистить", "почистить"],
    "очистка": ["чистка"],
    "очистной": ["очистный"],
    "очиток": ["седум", "заячья капуста"],
    "очищав": ["очищавши"],
    "очищавши": ["очищав"],
    "очищать": ["чистить", "отчищать", "вычищать", "удалять", "освобождать"],
    "очищаться": ["чиститься", "избавляться", "освобождаться", "вывобождаться"],
    "очищение": ["очистка"],
    "очканув": ["очканувши"],
    "очканувши": ["очканув"],
    "очкарик": ["очкарь", "четырёхглазый", "четырёхглазик"],
    "очкарь": ["очкарик"],
    "очко жим-жим": ["очко на минус"],
    "очко играет": ["очко жим-жим"],
    "очковав": ["очковавши"],
    "очковавши": ["очковав"],
    "очковать": ["колировать"],
    "очковая змея": ["кобра"],
    "очковтирательство": ["приписки", "блеф"],
    "очконавт": ["очкарь", "очкарик", "четырёхглазый", "четырёхглазик"],
    "очнуться": ["проснуться", "пробудиться", "оклематься", "очувствоваться", "опамятоваться", "опомниться", "образумиться"],
    "очочки": ["очёчки"],
    "очреватеть": ["забеременеть", "обрюхатеть"],
    "очувствить": ["сенсибилизировать"],
    "очувствление": ["сенсибилизация"],
    "очувствляв": ["очувствлявши"],
    "очувствлявши": ["очувствляв"],
    "очугунев": ["очугуневши"],
    "очугуневши": ["очугунев"],
    "очумев": ["очумевши"],
    "очумевши": ["очумев"],
    "очумело": ["обалдело", "ошалело"],
    "очумелый": ["одурелый"],
    "очуметь": ["обезуметь", "ошалеть", "офигеть", "обалдеть"],
    "очунев": ["очуневши"],
    "очуневши": ["очунев"],
    "очутиться": ["оказаться"],
    "очухаться": ["очнуться", "прийти в себя", "опомниться"],
    "очухиваться": ["приходить в себя", "опоминаться"],
    "очь": ["акътыман"],
    "очюнь": ["очень", "чересчур", "чрезмерно", "излишне", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "очёркивав": ["очёркивавши"],
    "очёркивавши": ["очёркивав"],
    "очёсывав": ["очёсывавши"],
    "очёсывавши": ["очёсывав"],
    "очёчки": ["очочки"],
    "ошагав": ["ошагавши"],
    "ошагавши": ["ошагав"],
    "ошагивав": ["ошагивавши"],
    "ошагивавши": ["ошагивав"],
    "ошалев": ["ошалевши"],
    "ошалевав": ["ошалевавши"],
    "ошалевавши": ["ошалевав"],
    "ошалевши": ["ошалев"],
    "ошалелый": ["одуревший", "обалдевший", "изумлённый"],
    "ошарашенно": ["недоуменно"],
    "ошарашив": ["ошарашивши"],
    "ошарашивав": ["ошарашивавши"],
    "ошарашивавши": ["ошарашивав"],
    "ошарашивать": ["бить", "огорошивать", "поражать"],
    "ошарашивши": ["ошарашив"],
    "ошарашить": ["огреть", "огорошить", "поразить"],
    "ошарив": ["ошаривши"],
    "ошаривав": ["ошаривавши"],
    "ошаривавши": ["ошаривав"],
    "ошаривши": ["ошарив"],
    "ошарить": ["обшарить"],
    "ошарпав": ["ошарпавши"],
    "ошарпавши": ["ошарпав"],
    "ошарпать": ["обшарпать"],
    "ошарпывав": ["ошарпывавши"],
    "ошарпывавши": ["ошарпывав"],
    "ошвартовав": ["ошвартовавши"],
    "ошвартовавши": ["ошвартовав"],
    "ошвартовив": ["ошвартовивши"],
    "ошвартовивши": ["ошвартовив"],
    "ошвартовить": ["ошвартовать"],
    "ошвартовывав": ["ошвартовывавши"],
    "ошвартовывавши": ["ошвартовывав"],
    "ошейник": ["нашейник"],
    "ошеломив": ["ошеломивши"],
    "ошеломивши": ["ошеломив"],
    "ошеломительный": ["ошеломляющий", "потрясающий", "сногсшибательный"],
    "ошеломить": ["поразить", "обескуражить", "огорошить"],
    "ошеломление": ["ошеломлённость"],
    "ошеломляв": ["ошеломлявши"],
    "ошеломлявши": ["ошеломляв"],
    "ошеломлять": ["поражать", "обескураживать", "огорошивать", "огорашивать"],
    "ошеломляющий": ["ошеломительный", "изумляющий", "потрясающий"],
    "ошеломлённо": ["ошарашенно"],
    "ошеломлённость": ["ошарашенность"],
    "ошеломлённый": ["шокированный"],
    "ошелудивев": ["ошелудивевши"],
    "ошелудивевши": ["ошелудивев"],
    "ошелудиветь": ["опаршиветь"],
    "ошелушив": ["ошелушивши"],
    "ошелушивав": ["ошелушивавши"],
    "ошелушивавши": ["ошелушивав"],
    "ошелушивши": ["ошелушив"],
    "ошельмовав": ["ошельмовавши"],
    "ошельмовавши": ["ошельмовав"],
    "ошельмовывав": ["ошельмовывавши"],
    "ошельмовывавши": ["ошельмовывав"],
    "ошепелявев": ["ошепелявевши"],
    "ошепелявевши": ["ошепелявев"],
    "ошиб": ["хвост"],
    "ошибав": ["ошибавши"],
    "ошибавши": ["ошибав"],
    "ошибаться": ["допускать ошибку", "совершать ошибку", "заблуждаться", "обманываться", "просчитаться"],
    "ошибив": ["ошибивши"],
    "ошибивши": ["ошибив"],
    "ошибиться": ["промахнуться"],
    "ошибка": ["погрешность", "неправильность"],
    "ошибка хайндсайта": ["я так и знал"],
    "ошибочно": ["неверно", "неправильно"],
    "ошибочность": ["неправильность"],
    "ошибочный": ["неверный", "неправильный", "ложный"],
    "ошиваться": ["болтаться", "околачиваться", "отираться"],
    "ошизев": ["ошизевши"],
    "ошизевши": ["ошизев"],
    "ошикав": ["ошикавши"],
    "ошикавши": ["ошикав"],
    "ошикать": ["обшикать"],
    "ошикивав": ["ошикивавши"],
    "ошикивавши": ["ошикивав"],
    "ошинив": ["ошинивши"],
    "ошинивши": ["ошинив"],
    "ошиновав": ["ошиновавши"],
    "ошиновавши": ["ошиновав"],
    "ошиновывав": ["ошиновывавши"],
    "ошиновывавши": ["ошиновывав"],
    "ошиповав": ["ошиповавши"],
    "ошиповавши": ["ошиповав"],
    "оширяв": ["оширявши"],
    "оширявши": ["оширяв"],
    "ошколярив": ["ошколяривши"],
    "ошколяривши": ["ошколярив"],
    "ошкор": ["фош"],
    "ошкуй": ["белый медведь", "умка"],
    "ошкурив": ["ошкуривши"],
    "ошкуривав": ["ошкуривавши"],
    "ошкуривавши": ["ошкуривав"],
    "ошкуривши": ["ошкурив"],
    "ошкурить": ["окорить", "освежевать", "снять шкуру", "содрать шкуру", "спустить шкуру", "обломать", "обобрать", "перевоспитать"],
    "ошлаковав": ["ошлаковавши"],
    "ошлаковавши": ["ошлаковав"],
    "ошлаковывав": ["ошлаковывавши"],
    "ошлаковывавши": ["ошлаковывав"],
    "ошлаковываться": ["шлаковаться"],
    "ошлифовав": ["ошлифовавши"],
    "ошлифовавши": ["ошлифовав"],
    "ошлифовывав": ["ошлифовывавши"],
    "ошлифовывавши": ["ошлифовывав"],
    "ошлихтовав": ["ошлихтовавши"],
    "ошлихтовавши": ["ошлихтовав"],
    "ошлихтовывав": ["ошлихтовывавши"],
    "ошлихтовывавши": ["ошлихтовывав"],
    "ошлюзовав": ["ошлюзовавши"],
    "ошлюзовавши": ["ошлюзовав"],
    "ошлюзовывав": ["ошлюзовывавши"],
    "ошлюзовывавши": ["ошлюзовывав"],
    "ошмурыгывав": ["ошмурыгывавши"],
    "ошмурыгывавши": ["ошмурыгывав"],
    "ошпазхона": ["матбах"],
    "ошпарив": ["ошпаривши"],
    "ошпаривав": ["ошпаривавши"],
    "ошпаривавши": ["ошпаривав"],
    "ошпаривать": ["шпарить", "обваривать"],
    "ошпаривши": ["ошпарив"],
    "ошпырок": ["веник", "пацан", "шкет", "окурок", "бычок"],
    "оштрафовав": ["оштрафовавши"],
    "оштрафовавши": ["оштрафовав"],
    "оштрафовывав": ["оштрафовывавши"],
    "оштрафовывавши": ["оштрафовывав"],
    "оштукатурив": ["оштукатуривши"],
    "оштукатуривав": ["оштукатуривавши"],
    "оштукатуривавши": ["оштукатуривав"],
    "оштукатуривать": ["штукатурить"],
    "оштукатуривши": ["оштукатурив"],
    "ошукувати": ["обдурювати"],
    "ошую": ["слева", "по левую руку", "с левой стороны"],
    "ошуюю": ["ошую", "слева", "по левую руку", "с левой стороны"],
    "ощелачивание": ["алкализация"],
    "ощеливав": ["ощеливавши"],
    "ощеливавши": ["ощеливав"],
    "ощенив": ["ощенивши"],
    "ощенивши": ["ощенив"],
    "ощенить": ["ощениться"],
    "ощерив": ["ощеривши"],
    "ощеривав": ["ощеривавши"],
    "ощеривавши": ["ощеривав"],
    "ощеривать": ["оскаливать", "щерить"],
    "ощериваться": ["скалить зубы", "скалиться", "ощеряться"],
    "ощеривши": ["ощерив"],
    "ощерившийся": ["оскалившийся"],
    "ощерить": ["оскалить"],
    "ощериться": ["оскалиться"],
    "ощеряв": ["ощерявши"],
    "ощерявши": ["ощеряв"],
    "ощерять": ["ощеривать", "оскаливать", "скалить", "щерить"],
    "ощеряться": ["скалить зубы", "скалиться", "щериться"],
    "ощетинив": ["ощетинивши"],
    "ощетинивав": ["ощетинивавши"],
    "ощетинивавши": ["ощетинивав"],
    "ощетинивши": ["ощетинив"],
    "ощетинить": ["встопорщить"],
    "ощипав": ["ощипавши"],
    "ощипавши": ["ощипав"],
    "ощипывав": ["ощипывавши"],
    "ощипывавши": ["ощипывав"],
    "ощипыванье": ["общипывание", "общипанье", "ощипанье", "ощипывание"],
    "ощипывать": ["общипывать", "отщипывать"],
    "ощиряти": ["вищиряти"],
    "ощупав": ["ощупавши"],
    "ощупавши": ["ощупав"],
    "ощупывав": ["ощупывавши"],
    "ощупывавши": ["ощупывав"],
    "ощупыванье": ["ощупывание"],
    "ощутив": ["ощутивши"],
    "ощутивши": ["ощутив"],
    "ощутимый": ["ощутительный"],
    "ощутить": ["почувствовать", "испытать"],
    "ощущав": ["ощущавши"],
    "ощущавши": ["ощущав"],
    "ощущать": ["чувствовать", "испытывать"],
    "ощущаться": ["чувствоваться"],
    "ощущение": ["чувство"],
    "ощущенье": ["ощущение"],
    "ощущеньице": ["ощущение"],
    "оьзен": ["къойсув"],
    "оьлик": ["суьек"],
    "оьтирик": ["ялган"],
    "оягнив": ["оягнивши"],
    "оягнивши": ["оягнив"],
    "оягниться": ["объягниться"],
    "оязыковлять": ["вербализовать"],
    "ояловев": ["ояловевши"],
    "ояловевши": ["ояловев"],
    "па-де-де": ["падеде", "танец"],
    "па-де-дё": ["па-де-де", "падеде"],
    "па-де-кале": ["дуврский пролив", "галльский пролив"],
    "паан": ["бетель"],
    "паб": ["пивная"],
    "паблисити": ["рекламирование", "продвижение"],
    "пава": ["павлиниха"],
    "павана": ["падована"],
    "паветвь": ["ответвление"],
    "павичка": ["пава"],
    "павлианец": ["павликианец", "павликанин"],
    "павлианство": ["павликианство"],
    "павликанин": ["павликианин", "тондракиец"],
    "павликанство": ["павликианство"],
    "павликианец": ["павликианин"],
    "павликианин": ["павликанин", "павлианец", "павлинист", "тондракиец", "катар", "альбигоец", "богомил"],
    "павликианство": ["павликанство"],
    "павлин": ["павлинка", "павлиня", "павля", "павла", "павлуня", "павлуся", "павлуха", "павлуша", "паша", "пава"],
    "павлинизм": ["паулинизм"],
    "павлиний": ["павлиновый", "павлинный", "павлиный"],
    "павлинист": ["павликианин"],
    "павлинный": ["павлиний", "павлиновый"],
    "павлиноглазка": ["сатурния"],
    "павлиный": ["павлиний", "павлиновый"],
    "павлович": ["павлыч", "палыч"],
    "павловск": ["мариуполь", "новоукраинка"],
    "павлёнок": ["павча"],
    "паводковый": ["паводочный"],
    "паводочный": ["паводковый"],
    "павозка": ["павозок"],
    "паволока": ["пелена", "покров"],
    "павутина": ["павутиння"],
    "павутиння": ["павутина"],
    "паганизм": ["идолопоклонство"],
    "пагинация": ["постраничный вывод"],
    "пагуба": ["гибель", "погибель"],
    "пагубный": ["гибельный", "катастрофический", "вредоносный"],
    "пад": ["по"],
    "падав": ["падавши"],
    "падавши": ["падав"],
    "падаль": ["мертвечина", "дохлятина", "стервятина", "стерва", "падла", "подонок", "подлец", "мерзавец", "падалица"],
    "падальщик": ["некрофаг", "трупоед"],
    "паданец": ["паданка"],
    "паданье": ["падание"],
    "падар": ["сарнасл", "аб", "волид"],
    "падаркалон": ["бобо"],
    "падать в цене": ["дешеветь"],
    "падающая звезда": ["метеорит"],
    "падбародак": ["падбароддзе"],
    "падводная лодка": ["падлодка", "субмарына"],
    "паддл": ["пэддл", "шлёпалка"],
    "падеде": ["па-де-де", "па-де-дё"],
    "падение": ["снижение", "уменьшение", "упадок", "разложение", "поражение", "сдача", "покорение", "свержение", "ниспровержение"],
    "падение редуцированных": ["падение еров"],
    "падик": ["подъезд", "парадная"],
    "падкий": ["охочий", "жадный"],
    "падла": ["падло", "падаль", "падел", "подонок"],
    "падлборд": ["сапборд"],
    "падло": ["падла", "сволочь"],
    "падуб": ["остролист"],
    "падун": ["айсберг", "торос"],
    "падучая": ["эпилепсия"],
    "падчерица": ["падчеруха", "падчерка"],
    "падший": ["павший"],
    "падший ангел": ["павший ангел"],
    "паерок": ["паерк", "паерчик", "ерок", "ерик"],
    "пажера": ["ненажера"],
    "пажитник": ["шамбала", "фенугрек", "хельба", "чаман", "донник синий", "донник голубой", "греческое сено", "уцхо-сунели", "грибная трава"],
    "пажитный": ["луговой", "луговинный", "лужковый", "выпасной", "выгонный", "выгоночный", "займищный"],
    "пажить": ["луг", "луговина", "поле", "пашня", "пахота", "нива", "выгон", "выгонка", "выпас", "поскотина", "алань", "елань", "левада", "летовка", "пасево"],
    "паз": ["павловский автомобильный завод"],
    "пазанчив": ["пазанчивши"],
    "пазанчивши": ["пазанчив"],
    "пазач": ["пазвант", "телохранител", "страж", "пазител"],
    "пазив": ["пазивши"],
    "пазивши": ["пазив"],
    "пазител": ["страж", "блюстител", "хранител", "пазач"],
    "пазл": ["мозаика"],
    "пазник": ["шпунтубель", "дорожник"],
    "паивав": ["паивавши"],
    "паивавши": ["паивав"],
    "паинька": ["тихоня"],
    "пай-девочка": ["паинька"],
    "пай-мальчик": ["паинька", "пай"],
    "пайп": ["хафпайп", "рампа", "вертикальная черта"],
    "пайплайн": ["разработка"],
    "пайта": ["батник", "джемпер"],
    "пайцза": ["пайза", "пайдза"],
    "пайщик": ["певщик"],
    "пак": ["самолет"],
    "пакараць": ["наказаць"],
    "пакарьста тиф": ["пакарень"],
    "пакетизация": ["пакетирование"],
    "пакетизировав": ["пакетизировавши"],
    "пакетизировавши": ["пакетизировав"],
    "пакетир-пресс": ["пакетировочный", "пресс"],
    "пакетировав": ["пакетировавши"],
    "пакетировавши": ["пакетировав"],
    "пакетирование": ["пакетизация"],
    "пакетировать": ["пакетизировать"],
    "пакетник": ["пакетный выключатель", "пакетный файл", "командный файл"],
    "паки": ["опять", "снова", "ещё"],
    "паки и паки": ["снова и снова"],
    "пакибытие": ["посмертие"],
    "паклады": ["залежы"],
    "паклив": ["пакливши"],
    "пакливши": ["паклив"],
    "паклитаксел": ["паклитаксель"],
    "паковав": ["паковавши"],
    "паковавши": ["паковав"],
    "паковать": ["задерживать", "арестовывать"],
    "паковый лёд": ["пак"],
    "пакостив": ["пакостивши"],
    "пакостивши": ["пакостив"],
    "пакостливо": ["изподтишка", "паскудно", "злорадно", "пакостно", "шкодно"],
    "пакостник": ["негодник", "проказник"],
    "пакостничав": ["пакостничавши"],
    "пакостничавши": ["пакостничав"],
    "пакостнический": ["каверзнический", "вредительский"],
    "пакостничество": ["пакостность"],
    "пакостный": ["дурной", "дрянной", "мерзкий", "отвратительный"],
    "пакость": ["гадость", "гнусность", "грязь", "мерзость", "гнусь", "свинство", "скверность", "паскудство", "скверна"],
    "пакт": ["договор"],
    "пакша": ["грабли"],
    "пал": ["пожар", "паль"],
    "паладин": ["вельможа"],
    "паланг": ["бабр"],
    "паланка": ["град", "градец", "селище", "поселище"],
    "паланкин": ["портшез", "седан"],
    "палас": ["ковер"],
    "палат": ["дворец", "замък"],
    "палата": ["хоромы", "дортуар"],
    "палата представителей": ["маджлиси намояндагон"],
    "палатализировав": ["палатализировавши"],
    "палатализировавши": ["палатализировав"],
    "палатализовав": ["палатализовавши"],
    "палатализовавши": ["палатализовав"],
    "палатальный": ["передненёбный"],
    "палатин": ["майордом"],
    "палатка": ["тент", "шатёр", "павильон", "киоск", "ларёк"],
    "палаточка": ["палатка"],
    "палау": ["республика палау"],
    "палауский": ["палау", "палауский язык", "белау", "белауский язык"],
    "палаццо": ["чертог"],
    "палач": ["экзекутор", "кат"],
    "палачествовав": ["палачествовавши"],
    "палачествовавши": ["палачествовав"],
    "палдиски": ["рогервик", "балтийский порт"],
    "палевно": ["заметно", "броско"],
    "палево": ["стукач", "ябеда", "ябедник"],
    "палевый": ["бледно-жёлтый", "изжелта-белый", "светло-жёлтый", "соломенно-жёлтый", "соломенный", "тускло-желтый", "глинистый", "изабелловый", "половый", "соловый"],
    "паленье": ["паление"],
    "палеоантроп": ["неандерталец", "человек неандертальский"],
    "палеоботаник": ["фитопалеонтолог"],
    "палеоботаника": ["палеофитология", "фитопалеонтология"],
    "палеоген": ["палеогеновый период"],
    "палеозой": ["палеозойская эра", "эокембрий"],
    "палеозойская эра": ["палеозой"],
    "палеозоология": ["архезоология"],
    "палеоистория": ["доистория", "предыстория"],
    "палеомагнетизм": ["палеомагнитология"],
    "палеонтология": ["петроматогнозия", "петрефактология", "палеобиология"],
    "палеопалинология": ["геопалинология"],
    "палеофитология": ["палеоботаника", "фитопалеонтология"],
    "палермец": ["палермитанец"],
    "палермо": ["столица мафии", "панормус"],
    "палессе": ["беларускае палессе"],
    "палестина": ["местность", "край"],
    "палета": ["паллет", "поддон"],
    "палетка": ["палета", "паллета"],
    "пали": ["пракрит", "среднеиндийский язык"],
    "паливав": ["паливавши"],
    "паливавши": ["паливав"],
    "паливши": ["палив"],
    "палий": ["накидка", "мантия"],
    "палингенез": ["палингенезис"],
    "палингенезис": ["палингенез"],
    "палиндром": ["перевёртыш"],
    "палиндромический": ["палиндромный"],
    "палинодия": ["непостоянство"],
    "палисандр": ["палисандровое дерево"],
    "палистин": ["валистин", "паттин"],
    "палить": ["жечь", "сжигать", "пулять", "шмалять"],
    "палить из пушки по воробьям": ["стрелять из пушки по воробьям", "за мухой угоняешься с обухом"],
    "палка": ["батог", "кнут", "батон", "котелка", "правонарушение", "жезл", "пачка сигарет"],
    "палка о двух концах": ["обоюдоострый меч", "у медали две стороны"],
    "палку кинуть": ["оттрахать", "трахнуть", "отыметь", "выебать", "отъебать"],
    "палладианизм": ["палладианство"],
    "палладианство": ["палладианизм", "палладиева архитектура", "палладианский стиль"],
    "палладиум": ["защита", "оплот", "опора", "палладион", "оберег", "талисман"],
    "паллета": ["подтоварник"],
    "паллиативный": ["смягчающий"],
    "паллий": ["омофор", "нарамник", "гимантий", "хламида", "тога"],
    "паллиум": ["плащ мозга", "мантиум", "паллий"],
    "палмтоп": ["наладонник"],
    "паломник": ["пилигрим"],
    "паломничав": ["паломничавши"],
    "паломничавши": ["паломничав"],
    "паломничество": ["богомолье"],
    "палочка": ["палочка для еды", "китайская палочка"],
    "палочковидный": ["палочкообразный"],
    "палочкообразный": ["палочковидный"],
    "палты": ["малты"],
    "палубив": ["палубивши"],
    "палубивши": ["палубив"],
    "палубная команда": ["боцманская команда"],
    "палубный": ["авианосный"],
    "палыгорскит": ["аттапульгит"],
    "паль": ["пал"],
    "пальба": ["стрельба", "канонада"],
    "пальма": ["пальма-де-майорка", "пальма-де-мальорка"],
    "пальмира": ["тадмор"],
    "пальмистрия": ["хиромантия"],
    "пальмит": ["пальмовая мука"],
    "пальмитин": ["трипальмитин"],
    "пальмитировав": ["пальмитировавши"],
    "пальмитировавши": ["пальмитировав"],
    "пальмовидный": ["пальмоподобный"],
    "пальнув": ["пальнувши"],
    "пальнувши": ["пальнув"],
    "пальпа": ["педипальпа"],
    "пальпировав": ["пальпировавши"],
    "пальпировавши": ["пальпировав"],
    "пальтишко": ["пальтишечко"],
    "пальтэсь": ["скуммьп"],
    "пальцевав": ["пальцевавши"],
    "пальцевавши": ["пальцевав"],
    "пальцевидный": ["пальцеобразный", "пальчатый"],
    "пальцевой": ["пальцевый"],
    "пальцевый": ["пальцевой"],
    "пальцеобразный": ["пальцевидный", "пальчатый"],
    "пальцовка": ["распальцовка"],
    "пальчато-лопастный": ["пальчатолопастный"],
    "пальчатолопастный": ["пальчато-лопастный"],
    "паляв": ["палявши"],
    "палявши": ["паляв"],
    "палячо": ["клоун", "шут", "смешник", "смешльо", "шегаджия"],
    "пама": ["ленточный крайт"],
    "памир": ["крыша мира"],
    "памис": ["памисос", "амаф"],
    "памисос": ["памис", "пирнадза"],
    "паморок": ["морось", "мжица"],
    "пампасный": ["пампасовый"],
    "пампасовый": ["пампасный"],
    "пампасы": ["пампа"],
    "памперс": ["одноразовый подгузник"],
    "пампушка": ["пышка", "толстушка"],
    "памфил": ["мистигри", "памфиль"],
    "памфиль": ["памфил"],
    "памфлетист": ["памфлетёр"],
    "памятник": ["монумент"],
    "памятный": ["запомнившийся", "незабываемый"],
    "памятовав": ["памятовавши"],
    "памятовавши": ["памятовав"],
    "памятовать": ["помнить"],
    "память": ["памятливость", "голова", "воспоминание", "запоминающее устройство"],
    "пан": ["господин", "помещик", "барин"],
    "пан или пропал": ["всё или ничего"],
    "пан-": ["все-"],
    "паназиатский": ["всеазиатский"],
    "панама": ["республика панама"],
    "панамагейт": ["панамский архив", "панамские документы", "панамское досье"],
    "панамка": ["панамочка"],
    "панариций": ["ногтоеда"],
    "панаш": ["султан", "плюмаж"],
    "панашировав": ["панашировавши"],
    "панашировавши": ["панашировав"],
    "пангенез": ["пангенезис"],
    "пангенезис": ["пангенез"],
    "панголин": ["ящер"],
    "панграмма": ["разнобуквица"],
    "панд": ["машварат"],
    "панда": ["большая панда", "бамбуковый медведь", "малая панда", "красная панда"],
    "пандан": ["пара", "чета"],
    "панданус": ["пандан"],
    "пандемониум": ["паноптикум", "паноптикон", "шабаш", "бордель", "вертеп", "кабак"],
    "панджаби": ["пенджабский язык", "пенджаби"],
    "панджабский": ["пенджабский"],
    "пандус": ["рампа"],
    "панегирик": ["дифирамб"],
    "панель": ["плита", "тротуар", "пульт", "щит", "матрица"],
    "паненка": ["барышня", "девица"],
    "панибратский": ["амикошонский", "бесцеремонный", "фамильярный", "развязный"],
    "панибратство": ["развязность", "фамильярность", "непочтительность"],
    "панибратствовав": ["панибратствовавши"],
    "панибратствовавши": ["панибратствовав"],
    "паника": ["страх", "боязнь", "испуг", "ужас"],
    "паникадило": ["паникандило"],
    "паниковав": ["паниковавши"],
    "паниковавши": ["паниковав"],
    "паниковать": ["паникёрствовать", "сходить с ума"],
    "паникёр": ["алармист"],
    "паникёрство": ["алармизм"],
    "паникёрствовав": ["паникёрствовавши"],
    "паникёрствовавши": ["паникёрствовав"],
    "панировав": ["панировавши"],
    "панировавши": ["панировав"],
    "панихида": ["отпевание"],
    "панк-ансамбль": ["панк-группа", "панк-банда", "панк-коллектив", "панк-команда", "панк-рок-группа", "панк-состав"],
    "панк-банда": ["панк-ансамбль", "панк-группа", "панк-коллектив", "панк-команда", "панк-рок-группа", "панк-состав"],
    "панк-группа": ["панк-ансамбль", "панк-банда", "панк-коллектив", "панк-команда", "панк-рок-группа", "панк-состав"],
    "панк-исполнитель": ["панк-музыкант", "панк-рокер"],
    "панк-коллектив": ["панк-ансамбль", "панк-группа", "панк-банда", "панк-команда", "панк-рок-группа", "панк-состав"],
    "панк-команда": ["панк-ансамбль", "панк-группа", "панк-банда", "панк-коллектив", "панк-рок-группа", "панк-состав"],
    "панк-музыкант": ["панк-исполнитель", "панк-рокер"],
    "панк-рок-группа": ["панк-ансамбль", "панк-группа", "панк-банда", "панк-коллектив", "панк-команда", "панк-состав"],
    "панк-рокер": ["панк-исполнитель", "панк-музыкант"],
    "панк-состав": ["панк-ансамбль", "панк-банда", "панк-группа", "панк-коллектив", "панк-команда", "панк-рок-группа"],
    "панк-стилистика": ["панк-стиль"],
    "панк-стиль": ["панк-стилистика"],
    "панкерский": ["панковский"],
    "панковав": ["панковавши"],
    "панковавши": ["панковав"],
    "панмиелофтиз": ["апластическая анемия"],
    "пановав": ["пановавши"],
    "пановавши": ["пановав"],
    "пановать": ["барствовать", "панствовать"],
    "паноплия": ["всеоружие"],
    "паноптес": ["аргус", "аргос", "арг"],
    "паноптикум": ["выставка", "коллекция", "музей", "паноптикон", "пандемониум"],
    "панорамировав": ["панорамировавши"],
    "панорамировавши": ["панорамировав"],
    "панорм": ["сус", "моханат", "палермо"],
    "панпроктоколэктомия": ["брюшнопромежностная резекция"],
    "пансексуальность": ["омнисексуальность"],
    "пансион": ["интернат", "школа-интернат"],
    "панславистский": ["панславянский"],
    "панствовав": ["панствовавши"],
    "панствовавши": ["панствовав"],
    "панствовать": ["пановать"],
    "панталони": ["панталон"],
    "панталык": ["пантелик"],
    "пантеон": ["усыпальница", "мавзолей", "гробница", "склеп"],
    "пантера": ["чёрная пантера"],
    "пантикапей": ["пантикапея"],
    "пантикапея": ["пантикапей"],
    "пантовав": ["пантовавши"],
    "пантовавши": ["пантовав"],
    "пантопод": ["морской паук"],
    "панторифма": ["олорифма", "панторим"],
    "пантофагия": ["всеядность", "эврифагия", "полифагия"],
    "пантофобия": ["панафобия"],
    "пантуфля": ["тапочка"],
    "пануры": ["замкнёны", "хмурны", "пахмурны"],
    "панфиловец": ["герой-панфиловец"],
    "панцер": ["панцир"],
    "панцир": ["панцер"],
    "панцирь": ["броня", "латы"],
    "панцырь": ["доспехи", "броня", "скорлупа"],
    "панчлайн": ["пуант"],
    "панъевропейский": ["общеевропейский"],
    "паны": ["рэка", "море"],
    "паныч": ["барич", "барчук", "господич"],
    "панье": ["фижма"],
    "панькаться": ["нянчиться", "цацкаться"],
    "панэллинский": ["всегреческий", "общегреческий"],
    "панявежис": ["паневежис", "поневеж"],
    "панёва": ["понёва", "понява"],
    "папа": ["отец", "папка", "папаша", "папаня", "папуля", "папан", "тятя", "тятька", "батя", "батяня", "батька", "батько"],
    "папа римский": ["папа"],
    "папайя": ["дынное дерево"],
    "папак": ["копито"],
    "папан": ["папаня"],
    "папаня": ["папаша"],
    "папарацци": ["фотошпион"],
    "папаха": ["папах"],
    "папахен": ["папка"],
    "папаша": ["отец", "папаня", "дядя"],
    "папашка": ["папаша"],
    "папежский": ["папский"],
    "папенька": ["папочка", "папуля", "папаша"],
    "паперть": ["внешний притвор", "преддверие", "порог"],
    "папик": ["папа", "пахан", "крыша"],
    "папиллосфинктеротомия": ["сфинктеротомия"],
    "папильотка": ["бигуди"],
    "папин": ["батин", "отцов", "отцовский", "папкин", "тятин"],
    "папиролог": ["папирусолог"],
    "папирология": ["папирусология"],
    "папироса на папиросу": ["папироса за папиросой", "курить папиросу за папиросой", "смолить папиросу за папиросой", "не выпускать папиросу изо рта", "дымить как паровоз"],
    "папиросница": ["папиросочница", "портсигар"],
    "папиросочница": ["портсигар", "папиросница"],
    "папирусология": ["папирология"],
    "папист": ["католик"],
    "папистский": ["католический", "римско-католический"],
    "папка": ["дело", "скоросшиватель", "файл", "каталог", "директория", "директорий"],
    "паплач": ["сбирщина", "сган", "орда"],
    "паплюхаць": ["паплёскаць"],
    "папокесаризм": ["папоцезаризм"],
    "папоротка": ["крыло", "перо"],
    "папороток": ["папоротка"],
    "папоцезаризм": ["папокесаризм"],
    "паппус": ["летучка", "парашютик", "хохолок"],
    "папуленька": ["папуля", "папулечка", "папочка"],
    "папулечка": ["папуля", "папуленька", "папочка"],
    "папулька": ["папочка"],
    "папуля": ["папочка"],
    "папушив": ["папушивши"],
    "папушивши": ["папушив"],
    "папьяменту": ["папьяменто"],
    "пар": ["испарения", "туман", "аэрозоль", "водяной пар"],
    "пара": ["чета", "два", "дополнение", "двойка", "двояк", "лента"],
    "пара ласковых": ["пара ласковых слов"],
    "пара мяльса": ["мяль вельде", "эсь мяльса"],
    "пара-аминобензойная кислота": ["пабк", "парааминобензойная кислота"],
    "парааминобензойный": ["пара-аминобензойный"],
    "парабаза": ["парабаса", "инвектива"],
    "парабаса": ["парабаза"],
    "парабеллум": ["люгер"],
    "параболизировав": ["параболизировавши"],
    "параболизировавши": ["параболизировав"],
    "параганглиома": ["гломерулоцитома"],
    "парагемофилия": ["гипоакцелеринемия"],
    "парагенез": ["парагенезис"],
    "парагенезис": ["парагенез"],
    "параглайдер": ["планер", "глайдер", "параглайд", "парапланерист"],
    "параглайдинг": ["парапланеризм"],
    "парагормон": ["гормоноид"],
    "параграф": ["раздел"],
    "парад": ["прохождение торжественным маршем", "парад-алле", "празднество", "торжество", "парадность", "помпезность", "показуха"],
    "парад-алле": ["парад"],
    "парадентит": ["пародонтоклазия", "периодонтоз", "периодонтолиз", "полиальвеолиз"],
    "параденциум": ["амфодонт"],
    "парадигма": ["модель", "образец", "схема"],
    "парадиз": ["рай", "петербург", "град петров", "северная пальмира", "раёк"],
    "парадизка": ["райская яблоня"],
    "парадировав": ["парадировавши"],
    "парадировавши": ["парадировав"],
    "парадная": ["подъезд"],
    "парадно-выходной": ["праздничный", "нарядный", "парадный", "торжественный", "официальный", "церемонный", "вечерний"],
    "парадное": ["парадная", "подъезд"],
    "парадокс": ["антиномия", "противоречие"],
    "паразит": ["чужеяд", "чужеядный", "трутень", "тунеядец", "дармоед"],
    "паразитивный": ["паразитический"],
    "паразитировав": ["паразитировавши"],
    "паразитировавши": ["паразитировав"],
    "паразитировать": ["паразитничать", "паразитствовать", "нахлебничать", "тунеядствовать"],
    "паразитничав": ["паразитничавши"],
    "паразитничавши": ["паразитничав"],
    "паразитный": ["паразитический", "паразитарный"],
    "паразитствовав": ["паразитствовавши"],
    "паразитствовавши": ["паразитствовав"],
    "паразитствовать": ["паразитировать"],
    "параклет": ["параклит"],
    "паракомпактный": ["бикомпактный"],
    "паракомплексный": ["двойной", "гиперболический"],
    "параламбдацизм": ["ламбдацизм"],
    "паралелка": ["клас"],
    "парализация": ["парализование", "паралич"],
    "парализировав": ["парализировавши"],
    "парализировавши": ["парализировав"],
    "парализировать": ["обездвиживать"],
    "парализовав": ["парализовавши"],
    "парализовавши": ["парализовав"],
    "паралитература": ["полулитература", "псевдолитература", "чтиво"],
    "паралитик": ["парализованный"],
    "параллелепипед": ["прямая призма"],
    "параллелизм": ["параллельность"],
    "параллелотоп": ["параллелогранник"],
    "параллель": ["параллельный класс"],
    "параллельно": ["одновременно"],
    "параман": ["параманд", "аналав"],
    "параманд": ["параман"],
    "парамезонефральный": ["парамезонефрический"],
    "парамезонефрический": ["парамезонефральный"],
    "парамезонефрический проток": ["парамезонефральный проток", "женский проток", "мюллеров канал", "мюллеров проток", "мюллеров ход"],
    "параметр": ["постоянная", "константа", "показатель"],
    "параметризировав": ["параметризировавши"],
    "параметризировавши": ["параметризировав"],
    "параметризовав": ["параметризовавши"],
    "параметризовавши": ["параметризовав"],
    "парамилитаристский": ["парамилитарный", "военизированный", "полувоенный"],
    "парамилитарный": ["парамилитаристский", "военизированный"],
    "парамнезия": ["ложные воспоминания"],
    "парамонарий": ["просмонарий"],
    "паранаука": ["лженаука", "квазинаука", "псевдонаука"],
    "паранаучный": ["ненаучный", "лженаучный", "псевдонаучный", "квазинаучный"],
    "паранафталин": ["антрацен"],
    "парангон": ["двойной боргес"],
    "паранджа": ["чадра"],
    "параноидальный": ["параноидный", "параноический"],
    "параноидный": ["параноидальный"],
    "параноический": ["паранойяльный"],
    "паранойя": ["психоз", "сумасшествие", "помешательство", "умопомешательство"],
    "паранойяльный": ["параноический"],
    "паранормальное явление": ["аномальное явление", "аномалия"],
    "паранормальный": ["сверхъестественный", "мистический"],
    "параолимпиада": ["параолимпийские игры"],
    "парапет": ["перила"],
    "параплазма": ["дейтоплазма"],
    "параплан": ["параглайдер"],
    "парапланеризм": ["параглайдинг"],
    "параположение": ["пара-положение"],
    "парапроктит": ["параректальный абсцесс"],
    "парапротеин": ["моноклональный иммуноглобулин"],
    "парапротеинемия": ["патопротеинемия"],
    "парарелигия": ["квазирелигия"],
    "параротацизм": ["ротацизм"],
    "парасанг": ["фарсах", "фарсаг", "фарсанг", "фарасанг", "парасанга", "санг", "таш", "йигач"],
    "параселена": ["ложная луна"],
    "парасимпатикотония": ["ваготония"],
    "парасинтез": ["конфиксация"],
    "парасистолия": ["аритмия"],
    "параскаведекатриафобия": ["фриггатрискаидекафобия"],
    "парасольный": ["зонтичный"],
    "парасхит": ["парасхист"],
    "парата": ["паранта"],
    "паратаксис": ["бессоюзие"],
    "паратгормон": ["паратирин"],
    "паратиреотоксический": ["гиперкальциемический"],
    "паратиреоэктомия": ["паратиреоидэктомия"],
    "паратирин": ["паратгормон", "паратиреоидный гормон"],
    "паратрахеальный": ["апотрахеальный"],
    "парафазия": ["парафемия", "парафразия"],
    "парафилия": ["параллелизм", "парафилетизм"],
    "парафинив": ["парафинивши"],
    "парафинивши": ["парафинив"],
    "парафинировав": ["парафинировавши"],
    "парафинировавши": ["парафинировав"],
    "парафировав": ["парафировавши"],
    "парафировавши": ["парафировав"],
    "парафия": ["приход"],
    "парафойл": ["парашют-крыло"],
    "параформальдегид": ["диоксиметилен"],
    "парафраз": ["пересказ", "изложение", "адаптация", "парафраза", "парафразис", "переложение"],
    "парафраза": ["парафраз"],
    "парафразировав": ["парафразировавши"],
    "парафразировавши": ["парафразировав"],
    "парафразировать": ["перифразировать"],
    "парафренический": ["парафренный"],
    "парафренный": ["парафренический"],
    "парацетамол": ["ацетаминофен"],
    "парацитный": ["параллельноклеточный"],
    "параша": ["нужник", "говно", "дерьмо", "херня", "сплетня", "чушь"],
    "парашечник": ["парашник", "золотарь"],
    "парашют-крыло": ["парафойл"],
    "парашютик": ["паппус", "хохолок"],
    "парашютировав": ["парашютировавши"],
    "парашютировавши": ["парашютировав"],
    "парвардан": ["парваридан", "парвариш додан"],
    "парваридан": ["парвардан"],
    "парвеню": ["выскочка"],
    "парвона": ["шабпарак"],
    "паргелий": ["лжесолнце", "ложное солнце"],
    "парда": ["пардача"],
    "пардон": ["прощение", "извинение", "простите", "извините", "прощу прощения", "пардоньте"],
    "парейдолия": ["парейдолическая иллюзия"],
    "паремейник": ["паремийник"],
    "паремия": ["нравоучение", "сентенция"],
    "парентеральный": ["парэнтеральный"],
    "парень": ["молодой человек", "юноша", "малый", "малой", "чувак", "кекс", "крендель", "хлопец", "паря", "парниша", "пацан", "бойфренд"],
    "паренёк": ["паренёчек"],
    "парешок": ["паренёк"],
    "парешон": ["парешонхотир"],
    "пари": ["заклад"],
    "парив": ["паривши"],
    "паривав": ["паривавши"],
    "паривавши": ["паривав"],
    "паривши": ["парив"],
    "париж": ["столица мировой моды", "мекка моды", "лютеция", "елисейский дворец"],
    "парижанин": ["парижец"],
    "паризий": ["лютеция"],
    "парикмахерская": ["цирюльня"],
    "парилка": ["парная", "парильня", "пыхалка", "подик", "вейп", "под", "вейпик", "ашка", "ашкудишка", "чарон", "чарончик", "аега", "аегис"],
    "парильня": ["парилка", "парная", "париленка", "парилочка"],
    "парировав": ["парировавши"],
    "парировавши": ["парировав"],
    "паритет": ["равнозначность", "равноценность", "консенсус", "курс"],
    "парить мозги": ["компостировать мозги"],
    "париться": ["потеть", "томиться", "мучиться", "беспокоиться", "тревожиться", "волноваться", "переживать", "стараться", "утруждаться"],
    "пария": ["неприкасаемый", "изгой", "отверженный"],
    "парк": ["сад", "сквер"],
    "парк культуры имени отдыха": ["крах культуры", "прах культуры"],
    "парка": ["парение"],
    "паркануться": ["припарковаться"],
    "паркет": ["мозаика"],
    "паркетина": ["клёпка"],
    "парковав": ["парковавши"],
    "парковавши": ["парковав"],
    "парковка": ["припарковывание", "стоянка", "автостоянка"],
    "парковочный радар": ["парктроник"],
    "парковщик": ["стоянщик", "стояночник"],
    "паркомат": ["паркометр"],
    "паркометр": ["паркомат"],
    "парктроник": ["парковочный радар"],
    "паркурив": ["паркуривши"],
    "паркуривши": ["паркурив"],
    "паркурист": ["паркурщик", "трейсер"],
    "паркурщик": ["паркурист", "трейсер"],
    "парламентаризм": ["политическая система"],
    "парламентско-правительственный": ["правительственно-парламентский"],
    "парламентско-президентский": ["президентско-парламентский"],
    "парламентёр": ["переговорщик"],
    "парная": ["парилка", "парильня", "парильная", "сауна"],
    "парниковый": ["оранжерейный"],
    "парнэ": ["вашо"],
    "парняга": ["парень", "паренёк", "парниша"],
    "паровав": ["паровавши"],
    "паровавши": ["паровав"],
    "пароварив": ["пароваривши"],
    "пароваривши": ["пароварив"],
    "паровая телега": ["пароходный дилижанец", "сухопутный пароход"],
    "паровоз": ["паровая телега", "паровой дилижанец", "сухопутный пароход", "паровозик"],
    "паровоздуходувка": ["паровоздуходувный", "станция"],
    "паровой дилижанец": ["паровоз", "сухопутный пароход"],
    "пародийный": ["пародический"],
    "пародировав": ["пародировавши"],
    "пародировавши": ["пародировав"],
    "пародирование": ["подражание", "имитирование", "имитация"],
    "пародия": ["карикатура"],
    "пародонтоз": ["пародонтит"],
    "пародонтопатия": ["парадентопатия", "приодонтопатия"],
    "парокомпрессионный": ["парокомпрессорный"],
    "парокомпрессорный": ["парокомпрессионный"],
    "пароконка": ["пара"],
    "пароль": ["код"],
    "парольный": ["паролевый"],
    "паромобиль": ["паровик"],
    "паромология": ["антанагога", "рекомпенсация"],
    "пароним": ["омофон", "омоним"],
    "паронимический": ["паронимичный"],
    "паронимия": ["сходство"],
    "паронихия": ["паронихий", "ногтоеда"],
    "парономазия": ["парономасия", "анноминация"],
    "пароотвод": ["сепарация пара", "пароотделитель", "сепаратор пара", "пароотводчик"],
    "пароотводный": ["пароотводящий"],
    "паропанк": ["стимпанк"],
    "пароподогревание": ["паровой", "отопление"],
    "пароход": ["пироскаф", "паровоз"],
    "пароходный дилижанец": ["паровая телега", "сухопутный пароход"],
    "парочка": ["влюблённые"],
    "парра": ["пар"],
    "парранда": ["тайр"],
    "парс": ["фарс"],
    "парсек": ["параллакс-секунда"],
    "парсер": ["синтаксический анализатор"],
    "парсив": ["парсивши"],
    "парсивши": ["парсив"],
    "парсизм": ["маздеизм", "зороастризм"],
    "парсить": ["анализировать", "разбирать"],
    "парсифаль": ["парцифаль"],
    "парста": ["лац", "цебярьста", "сатфксуста"],
    "партав": ["завъ"],
    "партак": ["партачка", "наколка"],
    "партгрупорг": ["партгруппорг"],
    "партгруппорг": ["партгрупорг"],
    "партдокумент": ["партийный билет", "партбилет"],
    "партейка": ["партийка"],
    "партесный": ["хоровой", "многоголосный"],
    "парти": ["пати"],
    "партиец": ["партийный", "большевик", "коммунист"],
    "партизанив": ["партизанивши"],
    "партизанивши": ["партизанив"],
    "партизанничав": ["партизанничавши"],
    "партизанничавши": ["партизанничав"],
    "партизанствовав": ["партизанствовавши"],
    "партизанствовавши": ["партизанствовав"],
    "партийка": ["кадетка", "коммунистка"],
    "партийно-номенклатурный": ["партноменклатурный"],
    "партийно-политическая работа": ["партполитработа"],
    "партийный": ["партиец", "член партии"],
    "партийный билет": ["партбилет"],
    "партикулярный": ["частный", "неофициальный", "штатский"],
    "партимен": ["тенсона"],
    "партионный": ["партийный", "отрядный", "оптовый"],
    "партитив": ["разделительный падеж", "второй родительный падеж", "количественно-отделительный падеж", "частичный"],
    "партитивный": ["частичный", "разделительный", "партитив"],
    "партиципативный": ["сопричастный"],
    "партия жуликов и воров": ["пжив"],
    "партноменклатурный": ["партийно-номенклатурный"],
    "партнёр": ["компаньон"],
    "партнёрство": ["товарищество"],
    "партократ": ["партноменклатурщик"],
    "партоним": ["мероним"],
    "парубок": ["юноша", "парень"],
    "парус": ["ветрило"],
    "парусив": ["парусивши"],
    "парусивши": ["парусив"],
    "парусинный": ["парусиновый"],
    "парусло": ["старица", "речища", "паруслина"],
    "парусная доска": ["виндсёрфер"],
    "парусник": ["парусное судно"],
    "паруш": ["поруш"],
    "парфетка": ["аккуратистка", "отличница", "прилежница"],
    "парфийский": ["парфянский"],
    "парфорс": ["строгий ошейник", "строгач"],
    "парфюмированный": ["ароматный"],
    "парфюмировать": ["ароматизировать"],
    "парфянская стрела": ["парфянский выстрел"],
    "парфянский": ["парфийский"],
    "пархатый": ["чёртов", "хренов"],
    "парцеллировав": ["парцеллировавши"],
    "парцеллировавши": ["парцеллировав"],
    "парциальный": ["частичный", "пристрастный", "несправедливый", "предвзятый"],
    "парцифаль": ["парсифаль"],
    "парча": ["аксамит", "персидская материя"],
    "парченце": ["късче", "хапка", "частица", "мъничко", "малко"],
    "парчис": ["лудо"],
    "парша": ["фавус"],
    "паршивая овца": ["отщепенец"],
    "паршивев": ["паршивевши"],
    "паршивевши": ["паршивев"],
    "паршивенький": ["плохонький"],
    "паршивец": ["негодник", "поганец"],
    "паршивив": ["паршививши"],
    "паршививши": ["паршивив"],
    "паршиво": ["мерзко"],
    "паршивый": ["гадкий", "дурной", "дрянной", "плохой", "скверный"],
    "парывав": ["парывавши"],
    "парывавши": ["парывав"],
    "паря": ["парень"],
    "пасандоз": ["захира"],
    "пасанув": ["пасанувши"],
    "пасанувши": ["пасанув"],
    "пасануть": ["отпасовать"],
    "пасека": ["пчельник"],
    "пасечник": ["пчеловод"],
    "пасибо": ["спасибо"],
    "пасик": ["ремешок"],
    "паска": ["пасха"],
    "пасквиль": ["пашквиль"],
    "пасквильный": ["клеветнический"],
    "пасквилянт": ["клеветник"],
    "пасквилянтствовав": ["пасквилянтствовавши"],
    "пасквилянтствовавши": ["пасквилянтствовав"],
    "паскуда": ["скверность", "гад", "гадость", "касть", "пакость", "мерзавец", "сволочь", "пакостник", "паскудник", "предатель"],
    "паскудив": ["паскудивши"],
    "паскудивши": ["паскудив"],
    "паскудить": ["гадить", "пачкать", "портить", "паскудничать", "паскудствовать"],
    "паскудник": ["пакостник", "паскуда"],
    "паскудница": ["безобразница", "мерзавка", "пакостница"],
    "паскудничав": ["паскудничавши"],
    "паскудничавши": ["паскудничав"],
    "паскудничать": ["паскудить", "пакостить", "пакостничать", "гадить"],
    "паскудный": ["мерзкий", "пакостный", "отвратительный", "подлый"],
    "паскудство": ["мерзость", "непорядочность"],
    "паскудствовав": ["паскудствовавши"],
    "паскудствовавши": ["паскудствовав"],
    "пасля": ["апасля"],
    "паслён": ["пасклён"],
    "пасма": ["пасмо"],
    "пасмо": ["пасма", "прядь"],
    "пасмурнев": ["пасмурневши"],
    "пасмурневши": ["пасмурнев"],
    "пасмурно": ["хмуро", "ненастно"],
    "пасмурный": ["хмурый", "облачный", "мрачный", "невесёлый"],
    "паснув": ["паснувши"],
    "паснувши": ["паснув"],
    "пасовав": ["пасовавши"],
    "пасовавши": ["пасовав"],
    "пасовать": ["объявлять пас", "сдаваться", "отступать", "давать пас", "отдавать пас", "сделать передачу", "делать передачу"],
    "пасок": ["передачка"],
    "пасол": ["пасылаць"],
    "паспорт": ["вид на жительство", "вид"],
    "паспортизировав": ["паспортизировавши"],
    "паспортизировавши": ["паспортизировав"],
    "паспортизовав": ["паспортизовавши"],
    "паспортизовавши": ["паспортизовав"],
    "пассагард": ["пасаргады"],
    "пассажирооборот": ["пассажиропоток"],
    "пассажирский автобус": ["автобус", "городской автобус", "маршрутный автобус"],
    "пассакалия": ["пассакалья"],
    "пассатижи": ["плоскогубцы"],
    "пассеровав": ["пассеровавши"],
    "пассеровавши": ["пассеровав"],
    "пассерование": ["пассеровка"],
    "пассеровка": ["пассерование"],
    "пассив": ["обязательства", "гомосексуалист"],
    "пассивация": ["пассивирование"],
    "пассивизм": ["пассивность"],
    "пассивировав": ["пассивировавши"],
    "пассивировавши": ["пассивировав"],
    "пассивирование": ["пассивация"],
    "пассивно": ["инертно", "бездеятельно", "заторможенно", "неактивно", "безучастно", "бездейственно", "инерционно", "созерцательно", "безынициативно"],
    "пассивность": ["бездеятельность", "инертность"],
    "пассивный": ["бездеятельный", "безынициативный", "инертный"],
    "пассивный залог": ["страдательный залог"],
    "пассивный словарь": ["пассивный словарный запас"],
    "пассионарность": ["одержимость", "энтелехия"],
    "пассионарный": ["самоотверженный", "страстный", "целеустремлённый", "одухотворённый", "действенный"],
    "пассировав": ["пассировавши"],
    "пассировавши": ["пассировав"],
    "пассировать": ["страховать", "подстраховывать"],
    "пассировка": ["страхование", "страховка"],
    "пассифлора": ["страстоцвет"],
    "пассия": ["возлюбленная", "любовь", "любовница", "дульцинея", "дроля"],
    "пассовав": ["пассовавши"],
    "пассовавши": ["пассовав"],
    "паст": ["пастак"],
    "паста": ["масса", "макароны", "стержень", "чернила"],
    "пастбище": ["выгон", "выпас", "пажить"],
    "паства": ["прихожане", "верующий"],
    "пастеризация": ["стерилизация"],
    "пастеризировав": ["пастеризировавши"],
    "пастеризировавши": ["пастеризировав"],
    "пастеризировать": ["пастеризовать"],
    "пастеризовав": ["пастеризовавши"],
    "пастеризовавши": ["пастеризовав"],
    "пастеризовать": ["пастеризировать"],
    "пасти": ["выпасать"],
    "пастик": ["стержень", "стерженёк", "ампулка", "ампула"],
    "пастилка": ["конфета", "конфетка", "таблетка"],
    "пастоизготовитель": ["пастоприготовитель"],
    "пастообразный": ["тестообразный"],
    "пастораль": ["буколика", "идиллия"],
    "пасторат": ["пасторство", "приход"],
    "пасторель": ["пастурель", "пастораль"],
    "пастриги": ["пастрижки"],
    "пастурель": ["пасторель"],
    "пастушачий": ["пастуший"],
    "пастушеский": ["пастушечий", "пастуший"],
    "пастушив": ["пастушивши"],
    "пастушивши": ["пастушив"],
    "пастушка": ["девочка", "девушка", "женщина"],
    "пастушонок": ["пастушок", "подпасок"],
    "пастырь": ["пастух"],
    "пасть": ["рот", "зев"],
    "пасть секельная": ["вульва", "вагина", "пасть однозубая", "пасть клиторная"],
    "пастьба": ["выпас", "паства", "попас"],
    "пасха": ["воскресение христово", "светлое христово воскресение", "песах"],
    "пасхалий": ["паскуале"],
    "пасхалка": ["пасхальное яйцо"],
    "пасхальное яйцо": ["пасхалка"],
    "пасынковав": ["пасынковавши"],
    "пасынковавши": ["пасынковав"],
    "пасынок": ["неродной сын"],
    "пасьют": ["персьют"],
    "пасюк": ["серая крыса"],
    "пасёлак": ["вёска"],
    "патанатом": ["патологоанатом"],
    "пате": ["паштет"],
    "пательня": ["сковорода"],
    "патент": ["застёжка-молния", "змейка", "молния"],
    "патентировав": ["патентировавши"],
    "патентировавши": ["патентировав"],
    "патентник": ["патентщик"],
    "патентовав": ["патентовавши"],
    "патентовавши": ["патентовав"],
    "патентовладелец": ["патентообладатель"],
    "патентообладатель": ["патентовладелец"],
    "патентоспособный": ["патентабильный"],
    "патентщик": ["патентник"],
    "патетика": ["пафос", "патетизм", "патетичность"],
    "патетически": ["страстно", "эмоционально"],
    "патетический": ["патетичный", "пафосный", "страстный"],
    "патетично": ["пафосно", "прочувствованно", "торжественно"],
    "патетичность": ["торжественность", "взволнованность", "пафосность"],
    "патетичный": ["патетический"],
    "патефон": ["граммофон"],
    "пати": ["парти"],
    "патиентность": ["толерантность"],
    "патика": ["патик", "палиця"],
    "патимейкер": ["заводила", "душа компании"],
    "патина": ["ржа", "ржавчина", "окисел"],
    "патинировав": ["патинировавши"],
    "патинировавши": ["патинировав"],
    "патинировать": ["старить", "чернить"],
    "патластый": ["патлатый"],
    "патлатый": ["косматый", "патластый"],
    "патлач": ["патлань"],
    "патовав": ["патовавши"],
    "патовавши": ["патовав"],
    "патовость": ["бесперспективность"],
    "патогистология": ["гистопатология"],
    "патогномический": ["патогностический"],
    "патогномонический": ["патогностический"],
    "патогномоничный": ["патогномический", "патогностический"],
    "патогностический": ["патогномический", "патогномонический"],
    "патока": ["декстринмальтоза", "мальтодекстрин"],
    "патологизировав": ["патологизировавши"],
    "патологизировавши": ["патологизировав"],
    "патологическая смерть": ["естественная смерть"],
    "патологический": ["патологичный", "болезненно-ненормальный", "уродливый"],
    "патологичный": ["патологический"],
    "патология": ["заболевание"],
    "патологоанатом": ["патанатом"],
    "патоморфоз": ["нозоморфоз"],
    "патофизиология": ["патологическая физиология"],
    "патриарх": ["старейшина", "основоположник"],
    "патриархальность": ["традиционность"],
    "патриархат": ["патриархия"],
    "патриархия": ["патриархат"],
    "патриаршествовав": ["патриаршествовавши"],
    "патриаршествовавши": ["патриаршествовав"],
    "патриаршествование": ["патриаршество"],
    "патриаршие пруды": ["патрики"],
    "патриарший": ["патриаршеский"],
    "патрики": ["патриаршие пруды"],
    "патримониальный": ["наследственный", "родовой"],
    "патримоний": ["вотчина"],
    "патриот": ["отечестволюбец"],
    "патриотизм": ["отечестволюбие"],
    "патриотически": ["патриотично"],
    "патриотично": ["патриотически"],
    "патриотичный": ["патриотический", "отечественный"],
    "патриотствовав": ["патриотствовавши"],
    "патриотствовавши": ["патриотствовав"],
    "патристика": ["патрология"],
    "патристический": ["патрологический"],
    "патроклинность": ["патроклиния"],
    "патрологический": ["патристический"],
    "патрология": ["патристика"],
    "патрон": ["держатель"],
    "патронаж": ["покровительство", "опека", "попечительство"],
    "патронесса": ["покровительница"],
    "патронировав": ["патронировавши"],
    "патронировавши": ["патронировав"],
    "патронировать": ["покровительствовать"],
    "патронная лента": ["пулемётная лента"],
    "патрулировав": ["патрулировавши"],
    "патрулировавши": ["патрулировав"],
    "патрулирование": ["дозор"],
    "патрульный": ["дозорный"],
    "паттерн проектирования": ["шаблон проектирования"],
    "паттинг-грин": ["грин"],
    "пату": ["дубинка", "палица"],
    "патч": ["заплатка"],
    "патърдия": ["олелия", "врява"],
    "паудер": ["пухляк"],
    "паужин": ["полдник", "паужина", "паужна", "паужник", "пауженье", "пауженки"],
    "паужинав": ["паужинавши"],
    "паужинавши": ["паужинав"],
    "паужнав": ["паужнавши"],
    "паужнавши": ["паужнав"],
    "пауза": ["перерыв"],
    "паузация": ["паузирование"],
    "паузив": ["паузивши"],
    "паузивши": ["паузив"],
    "паузник": ["дольник"],
    "паузнув": ["паузнувши"],
    "паузнувши": ["паузнув"],
    "паук": ["мизгирь", "муховор", "сетник", "кошель", "тенетник", "эксплуататор", "мироед"],
    "паукобоязнь": ["арахнофобия"],
    "пауковый": ["паучий", "паучиный"],
    "паумоту": ["туамоту"],
    "паупер": ["бедняк", "нищий"],
    "пауперизация": ["обнищание"],
    "пауперизм": ["нищета"],
    "пауперизовав": ["пауперизовавши"],
    "пауперизовавши": ["пауперизовав"],
    "паут": ["овод"],
    "паутинный": ["паутиновый"],
    "паутиновый": ["паутинный"],
    "пауч": ["дой-пак"],
    "паучара": ["паучище"],
    "паучий": ["паучиный"],
    "паучиный": ["паучий"],
    "паучище": ["паучара"],
    "паучник": ["клеоме", "клеома"],
    "паушальный": ["цельный", "целиком"],
    "пауэрлифтер": ["лифтер", "пауэрлифтингист"],
    "пауэрлифтингист": ["пауэрлифтер"],
    "пафос": ["патетика"],
    "пафосно": ["выспренно", "высокопарно", "напыщенно"],
    "пафосный": ["возвышенный", "величественный", "высокопарный", "напыщенный"],
    "паха": ["подмышка"],
    "пахав": ["пахавши"],
    "пахавши": ["пахав"],
    "паханье": ["пахание"],
    "пахарь": ["землепашец", "оратай", "плугарь", "земледелец", "крестьянин", "землероб", "труженик", "трудоголик", "трудяга", "работяга", "трудолюбец", "трудолюб"],
    "пахать": ["вкалывать", "впахивать"],
    "пахва": ["паха"],
    "пахивав": ["пахивавши"],
    "пахивавши": ["пахивав"],
    "пахидермия": ["толстокожесть"],
    "пахитена": ["пахинема"],
    "пахитоса": ["пахитоска", "папироса"],
    "пахитоска": ["пахитоса"],
    "пахлава": ["баклава"],
    "пахнув": ["пахнувши"],
    "пахнувши": ["пахнув"],
    "паховой": ["паховый"],
    "паховый": ["паховой", "ингвинальный"],
    "пахота": ["вспашка", "пашня"],
    "пахта": ["пахтанье", "юрага"],
    "пахтав": ["пахтавши"],
    "пахтавши": ["пахтав"],
    "пахтание": ["пахтанье"],
    "пахтанье": ["пахтание", "пахта", "юрага"],
    "пахтать": ["пехтать"],
    "пахучы": ["духмяны"],
    "пацан": ["мальчишка", "парнишка", "хлопец", "поц"],
    "пацанва": ["ребятня", "пацаньё", "ребятё"],
    "пацанка": ["сорванец"],
    "пацанский": ["пацанячий", "пацанюрский"],
    "пацаньё": ["пацанва"],
    "пацанёнок": ["пацан", "мальчик"],
    "пациенс": ["объект"],
    "пациент": ["больной"],
    "пациентка": ["больная"],
    "пацифизм": ["миролюбие"],
    "пацифик": ["знак мира", "символ мира"],
    "пацифист": ["нетвойнист"],
    "пацюк": ["щур"],
    "пачавра": ["парцал", "бърсалка", "изтривалка"],
    "пачатак": ["пачынак", "пачын", "аснова", "прынцып"],
    "паче": ["более", "больше"],
    "пачесав": ["пачесавши"],
    "пачесавши": ["пачесав"],
    "пачк": ["кафту"],
    "пачка": ["ряха", "харя", "толпа", "гурьба"],
    "пачкав": ["пачкавши"],
    "пачкавши": ["пачкав"],
    "пачкавшийся": ["загрязнявшийся", "маравшийся", "вымазывавшийся"],
    "пачкание": ["загрязнение", "пачканье", "загрязненье"],
    "пачканье": ["пачкание", "загрязнение"],
    "пачкать": ["марать", "грязнить", "загрязнять", "порочить", "чернить", "осквернять"],
    "пачкаться": ["загрязняться", "мараться"],
    "пачкотня": ["мазня"],
    "пачпорт": ["паспорт", "пашпорт"],
    "пашенка": ["кулижка"],
    "пашко": ["пашка"],
    "пашмак": ["парварда"],
    "пашмина": ["кашемир"],
    "пашпорт": ["пачпорт"],
    "пашша": ["магас", "паша"],
    "пащенок": ["молокосос", "малявка", "щенок", "сопляк", "сосунок", "салажонок"],
    "паюс": ["паюсная иркра"],
    "паяв": ["паявши"],
    "паявши": ["паяв"],
    "паяние": ["паянье"],
    "паясничав": ["паясничавши"],
    "паясничавши": ["паясничав"],
    "паясничать": ["скоморошничать", "кривляться", "ломаться", "комедию ломать"],
    "паять": ["шить"],
    "паяц": ["шут", "клоун", "скоморох", "арлекин", "кривляка", "фигляр"],
    "паёк": ["довольствие", "пай"],
    "пв": ["птв"],
    "пвм": ["эвм"],
    "пво": ["противовоздушная оборона"],
    "пг": ["петроград"],
    "пду": ["пульт дистанционного управления", "пульт", "лентяйка", "рулилка"],
    "пев": ["певши"],
    "певав": ["певавши"],
    "певавши": ["певав"],
    "певень": ["петух"],
    "певец": ["певун", "певунишка"],
    "певец быта": ["бытописатель", "бытописец", "бытовик"],
    "певица": ["певчиха"],
    "певунья": ["певица"],
    "певческие знамёна": ["крюки", "столбовые знаки"],
    "певчиха": ["певица"],
    "певши": ["пев"],
    "пега": ["пегия", "пи", "пегги", "маргарита"],
    "пеганка": ["атайка"],
    "пегий": ["пёстрый", "пятнистый"],
    "пегонький": ["пегенький"],
    "пед": ["педвуз", "пединститут", "педуниверситет"],
    "педагог": ["наставник", "учитель", "воспитатель", "преподаватель"],
    "педагогика": ["педагогия"],
    "педагогиня": ["воспитательница", "учительница", "училка", "учительша", "наставница", "репетиторша", "преподша"],
    "педагогический": ["воспитательный", "наставнический", "образовательный", "преподавательский", "учительский"],
    "педагогичный": ["педагогический"],
    "педагогия": ["педагогика"],
    "педализировав": ["педализировавши"],
    "педализировавши": ["педализировав"],
    "педалировав": ["педалировавши"],
    "педалировавши": ["педалировав"],
    "педалировать": ["педализировать"],
    "педант": ["учитель", "зануда", "формалист", "зазнайка"],
    "педантизм": ["педантство", "пунктуальность"],
    "педантично": ["педантически"],
    "педантичность": ["педантизм", "скрупулёзность"],
    "педантствовав": ["педантствовавши"],
    "педантствовавши": ["педантствовав"],
    "педер": ["хомосексуалац"],
    "педераст": ["пидорас", "пидарас"],
    "педиатр": ["детский врач", "врач-педиатр"],
    "педик": ["гей", "гомик", "гомосек", "гомосексуалист", "пидорас", "яойщик", "пидор", "педрилка", "ахтунг"],
    "педикулёз": ["вшивость"],
    "пединститут": ["пед", "педулька"],
    "педиосфера": ["педосфера"],
    "педипальпа": ["ногощупальце", "пальпа"],
    "педнаука": ["педагогика"],
    "педобир": ["педомедведь"],
    "педобраз": ["педагог дополнительного образования"],
    "педометр": ["шагомер"],
    "педоморфный": ["педоморфичный"],
    "педоскоп": ["флюороскоп"],
    "педофил": ["педофиляка", "детолюб", "чадолюб"],
    "педофилия": ["инфантосексуализм", "падерозия", "педосексуальность", "растление"],
    "педофилка": ["маньячка"],
    "педулище": ["педучилище", "педулька"],
    "педулька": ["пед"],
    "пеедькшнемс": ["мъзолдомс", "пеедемс", "рахсемс"],
    "пезфтамс": ["сялгомс", "озафтомс"],
    "пейджер": ["интернет-пейджер"],
    "пейзаж": ["ландшафт"],
    "пейзанка": ["крестьянка", "селянка"],
    "пейка": ["скамейка"],
    "пейнтбол-клуб": ["пейнтклуб"],
    "пейнтболист": ["пейнтбольщик"],
    "пейнтболистка": ["пейнтбольщица"],
    "пейнтбольщик": ["пейнтболист"],
    "пейнтбольщица": ["пейнтболистка"],
    "пейнтклуб": ["пейнтбол-клуб"],
    "пейнь пачк": ["пееньбачк"],
    "пейоратив": ["пежоратив"],
    "пейоративность": ["уничижительность", "неодобрительность"],
    "пейоративный": ["неодобрительный", "уничижительный", "умаляющий", "пренебрежительный", "презрительный"],
    "пейот": ["лофофора уильямса", "пейотль"],
    "пейринг": ["шиппинг"],
    "пейс": ["пеот"],
    "пейсли": ["бута"],
    "пейсмейкер": ["водитель ритма", "водитель ритма сердца"],
    "пекан": ["кария пекан", "орех пекана"],
    "пекарив": ["пекаривши"],
    "пекаривши": ["пекарив"],
    "пекарка": ["пекарша"],
    "пекарничав": ["пекарничавши"],
    "пекарничавши": ["пекарничав"],
    "пекарня": ["хлебопекарня", "писюк"],
    "пекарствовав": ["пекарствовавши"],
    "пекарствовавши": ["пекарствовав"],
    "пекарь": ["хлебопёк"],
    "пекельный": ["адский", "инфернальный", "дьявольский"],
    "пекин": ["бэйдзин", "бэйпин"],
    "пекинес": ["пекинская собака"],
    "пекинка": ["пекинская капуста"],
    "пекинская капуста": ["пекинка"],
    "пеклевав": ["пеклевавши"],
    "пеклевавши": ["пеклевав"],
    "пекло": ["пожар", "жара", "зной", "преисподняя", "побоище"],
    "пекот": ["пэко"],
    "пекулярный": ["неповторимый", "специфический", "особенный"],
    "пекуниарный": ["денежный"],
    "пекучка": ["пекло"],
    "пелагея": ["пелагия"],
    "пелагия": ["пелагея"],
    "пеламуши": ["татара"],
    "пеле": ["король футбола"],
    "пелемс": ["пелезевомс", "тандадомс", "эводемс"],
    "пелена": ["покрывало", "пелёнка", "пелёнки", "саван", "покров", "дымка"],
    "пеленав": ["пеленавши"],
    "пеленавши": ["пеленав"],
    "пеленг": ["азимут"],
    "пеленгация": ["пеленгование"],
    "пеленгировав": ["пеленгировавши"],
    "пеленгировавши": ["пеленгировав"],
    "пеленговав": ["пеленговавши"],
    "пеленговавши": ["пеленговав"],
    "пеленгование": ["пеленгация"],
    "пелеринаж": ["путешествие", "паломничество"],
    "пеликан": ["кликуша", "баба-птица"],
    "пеллопонес": ["пелопонес", "пелопоннес"],
    "пелопонес": ["пеллопонес", "пелопоннес"],
    "пелопоннес": ["пеллопонес", "пелопонес"],
    "пелотерапевтический": ["грязелечебный"],
    "пелпелек": ["пэльпэлэк"],
    "пелтва": ["полтва"],
    "пелузий": ["пелусий"],
    "пелузийский": ["пелусийский"],
    "пелусий": ["пелузий"],
    "пелусийский": ["пелузийский", "пилусийский"],
    "пельвеция": ["пельветия"],
    "пельменная": ["пельмешка"],
    "пельмень": ["дамплинг"],
    "пелюстка": ["пелюсток"],
    "пелядь": ["сырок", "пелять"],
    "пелять": ["пелядь"],
    "пелёнывав": ["пелёнывавши"],
    "пелёнывавши": ["пелёнывав"],
    "пемзовав": ["пемзовавши"],
    "пемзовавши": ["пемзовав"],
    "пемфигус": ["пузырчатка"],
    "пенал": ["футляр"],
    "пенальти": ["одиннадцатиметровый удар", "одиннадцатиметровый"],
    "пендаль": ["поджопник", "подсрачник", "пендель"],
    "пенделикон": ["пентеликон"],
    "пенджабский язык": ["панджаби"],
    "пендюрить": ["фигачить", "хреначить"],
    "пеней": ["пиньос"],
    "пензенец": ["пензяк"],
    "пензенская область": ["пензенский край", "сурский край"],
    "пензяк": ["пензенец"],
    "пенив": ["пенивши"],
    "пенивав": ["пенивавши"],
    "пенивавши": ["пенивав"],
    "пенивши": ["пенив"],
    "пение": ["вокал"],
    "пенис": ["орган копуляции", "орган мочеиспускания"],
    "пенитенциалий": ["покаянная книга"],
    "пенитенциарный": ["исправительный", "карательный", "тюремный"],
    "пенить": ["вспенивать"],
    "пения": ["паупертата", "эгеста"],
    "пенкосниматель": ["халявщик", "прихлебатель", "плагиатчик"],
    "пенни": ["пенс"],
    "пенник": ["пенное"],
    "пенное": ["пенник", "пиво"],
    "пенобетон": ["газобетон"],
    "пенообразование": ["вспенивание"],
    "пеночка-теньковка": ["пеночка", "теньковка"],
    "пенс": ["пенни"],
    "пенсе": ["пенсне"],
    "пенсионерив": ["пенсионеривши"],
    "пенсионеривши": ["пенсионерив"],
    "пенсионерить": ["пенсионерствовать"],
    "пенсионерствовав": ["пенсионерствовавши"],
    "пенсионерствовавши": ["пенсионерствовав"],
    "пенсионерствовать": ["пенсионерить"],
    "пенсия": ["пенсуха"],
    "пенсне": ["пенсе", "очки"],
    "пентагерон": ["пентаграмма", "пентальфа"],
    "пентагон": ["минобороны сша", "американская военщина"],
    "пентагон-додекаэдр": ["пентагондодекаэдр"],
    "пентагон-тритетраэдр": ["пентагонтритетраэдр"],
    "пентагональный": ["пятиугольный"],
    "пентагондодекаэдр": ["пентагон-додекаэдр", "пентагональный додекаэдр"],
    "пентагоновский": ["пентагонский"],
    "пентагонский": ["пентагоновский"],
    "пентагонтритетраэдр": ["пентагон-тритетраэдр"],
    "пентаграмма": ["пентальфа", "пентагерон", "пентакль"],
    "пентакампеон": ["селесао"],
    "пентакисдодекаэдр": ["шестидесятигранник"],
    "пентальфа": ["пентаграмма", "пентагерон"],
    "пентаналь": ["амиловый альдегид", "валериановый альдегид"],
    "пентасвинецгексалютеций": ["гексалютецийпентасвинец"],
    "пентатлон": ["пятиборье"],
    "пентатоп": ["пятивершинник", "гиперпирамида"],
    "пентаэдр": ["пятигранник"],
    "пентеликон": ["пенделикон"],
    "пентен": ["амилен"],
    "пентеракт": ["пентакуб", "декатерон"],
    "пентикостарион": ["пентикостарий"],
    "пентил": ["амил"],
    "пентиум": ["пентюх"],
    "пентод": ["пятиэлектродная лампа"],
    "пентюх": ["увалень", "недотёпа", "глупец", "дурак", "тупица", "остолоп", "бестолочь", "болван", "балбес", "балда", "обалдуй"],
    "пень": ["обрубок", "чурбан", "бестолочь"],
    "пеньюар": ["халат", "ночнушка"],
    "пеньё": ["пенье"],
    "пеня": ["неустойка", "упрёк", "сетование", "укор"],
    "пеняв": ["пенявши"],
    "пенявши": ["пеняв"],
    "пенязь": ["пенега", "пеннинг", "пфенниг", "денарий", "деньги", "монета"],
    "пенять": ["роптать", "винить"],
    "пепел": ["изгарь", "зола"],
    "пепелац": ["развалина", "развалюха", "рухлядь", "тарантас", "драндулет", "колымага", "джабахан"],
    "пепелив": ["пепеливши"],
    "пепеливши": ["пепелив"],
    "пепелище": ["гарь", "пожарище", "пенаты"],
    "пепельный": ["дымчатый", "светло-серый"],
    "пеплон": ["пеплум", "пеплос"],
    "пеплос": ["пеплон", "пеплум"],
    "пепси": ["пепси-кола"],
    "пепси-кола": ["пепси"],
    "пептидаза": ["протеаза", "протеиназа"],
    "пептидильный": ["пептидный"],
    "пептидная группа": ["амидная группа"],
    "пептидогликан": ["муреин"],
    "пералня": ["перална машина"],
    "первая мировая война": ["великая война", "германская", "германская война", "империалистическая война"],
    "первая речка": ["первореченский район", "первак"],
    "первая скрипка": ["заводила", "лидер", "прима"],
    "первая чеченская война": ["первая чеченская"],
    "первейший": ["наипервейший"],
    "первенственный": ["главный", "первенствующий", "первобытный"],
    "первенство": ["чемпионат"],
    "первенствовав": ["первенствовавши"],
    "первенствовавши": ["первенствовав"],
    "первенький": ["старшенький"],
    "перверт": ["извращенец"],
    "первичная": ["первичка"],
    "первичный": ["исходный", "первоначальный", "основной", "главный", "низовой"],
    "первичный транскрипт": ["гетерогенная рнк"],
    "перво-наперво": ["сначала", "в первую очередь", "во-первых", "прежде"],
    "первобытно-общинный строй": ["родовой строй", "общинно-родовой строй", "первобытный строй", "первобытное общество"],
    "первобытный": ["доисторический", "примитивный", "простейший", "дикий", "некультурный", "неразвитый", "девственный", "нетронутый", "первоначальный", "исходный", "исконный"],
    "первобытный бык": ["тур"],
    "первобытный коммунизм": ["примитивный коммунизм", "коммунализм"],
    "первое": ["первое блюдо"],
    "первое лицо": ["глава", "руководитель"],
    "первое мая": ["первомай"],
    "первозимье": ["первопуток"],
    "первоисточник": ["источник"],
    "первоклассник": ["первоклашка"],
    "первоклассничек": ["первоклассник", "первоклашка"],
    "первоклассно": ["благодать", "блеск", "в ажуре", "в лучшем виде", "важнецки", "восхитительно", "всё окей", "высококачественно", "добротно", "замечательно", "здорово", "знатно", "изрядно", "как нельзя лучше", "качественно"],
    "первоклассность": ["восхитительность", "высококачественность", "высокосортность", "доброкачественность", "добротность", "замечательность", "качественность", "классность", "клёвость", "обалденность", "отличность", "отменность", "первосортность", "первостатейность", "превосходность"],
    "первоклассный": ["отличный", "перворазрядный"],
    "первоклашка": ["первоклассник", "первоклассница"],
    "первомай": ["первое мая"],
    "первоначально": ["поначалу", "изначально"],
    "первооснова": ["основа"],
    "первооткрыватель": ["первопроходец"],
    "первоочередной": ["первоочерёдный"],
    "первоочерёдный": ["первоочередной"],
    "первопоселенец": ["поселенец"],
    "первоприсутствовав": ["первоприсутствовавши"],
    "первоприсутствовавши": ["первоприсутствовав"],
    "первопричина": ["корень"],
    "первопроходец": ["пионер", "первооткрыватель", "открыватель", "землепроходец", "первопроходчик", "новатор", "ранний последователь"],
    "первопут": ["первопуток", "первопутье"],
    "первопуток": ["первопутье"],
    "первопутье": ["первопут"],
    "перворазник": ["интродайвер"],
    "первородный": ["первозданный", "первосозданный", "нетронутый", "девственный"],
    "первородный грех": ["ошибка"],
    "первосвященник": ["архиерей"],
    "первостепенный": ["приоритетный"],
    "первоход": ["первоходок", "первоходка", "первоходочник"],
    "первоцвет": ["примула"],
    "первочеловек": ["адам"],
    "первый": ["начальный", "ранний", "древний", "лучший", "наилучший", "несравненный", "непревзойдённый"],
    "первый закон менделя": ["закон доминирования"],
    "первый закон ньютона": ["закон инерции"],
    "первый попавшийся": ["случайный", "чужой", "незнакомый"],
    "первый рейх": ["священная римская империя"],
    "первый экран": ["союзный экран"],
    "перга": ["хлебина"],
    "пергамен": ["пергамент"],
    "пергаменный": ["пергаментный"],
    "пергамин": ["рубероид"],
    "пердак": ["афедрон", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея"],
    "пердальник": ["жопа", "очко", "пердак", "срака"],
    "пердатый": ["отличный", "превосходный", "суперский", "обалденный", "охренительный"],
    "пердев": ["пердевши"],
    "пердевши": ["пердев"],
    "пердеть": ["пукать", "газовать", "пускать газы", "выпускать газы", "вонять"],
    "пердимонокль": ["пердюмонокль"],
    "пердолив": ["пердоливши"],
    "пердоливши": ["пердолив"],
    "пердолить": ["идти", "шагать"],
    "пердунья": ["бздунья", "пердючка", "пердушка", "пердушечка"],
    "пердь": ["глухомань", "глушь", "дыра", "захолустье", "медвежий угол", "тьмутаракань"],
    "пердюмонокль": ["пердимонокль"],
    "пердячим паром": ["пешкодралом", "на своих двоих"],
    "переадминистрировав": ["переадминистрировавши"],
    "переадминистрировавши": ["переадминистрировав"],
    "переадресация": ["переадресование", "переадресовка", "перенаправление"],
    "переадресовав": ["переадресовавши"],
    "переадресовавши": ["переадресовав"],
    "переадресовывав": ["переадресовывавши"],
    "переадресовывавши": ["переадресовывав"],
    "переаккредитовав": ["переаккредитовавши"],
    "переаккредитовавши": ["переаккредитовав"],
    "переаккредитовывав": ["переаккредитовывавши"],
    "переаккредитовывавши": ["переаккредитовывав"],
    "переакцентировав": ["переакцентировавши"],
    "переакцентировавши": ["переакцентировав"],
    "переакцентирование": ["переакцентировка"],
    "переакцентировка": ["переакцентирование"],
    "переаминирование": ["трансаминирование"],
    "переаранжировав": ["переаранжировавши"],
    "переаранжировавши": ["переаранжировав"],
    "переарендовав": ["переарендовавши"],
    "переарендовавши": ["переарендовав"],
    "переарендовывав": ["переарендовывавши"],
    "переарендовывавши": ["переарендовывав"],
    "переарестовав": ["переарестовавши"],
    "переарестовавши": ["переарестовав"],
    "переарестовывав": ["переарестовывавши"],
    "переарестовывавши": ["переарестовывав"],
    "переассигновав": ["переассигновавши"],
    "переассигновавши": ["переассигновав"],
    "переассигновывав": ["переассигновывавши"],
    "переассигновывавши": ["переассигновывав"],
    "переаттестовав": ["переаттестовавши"],
    "переаттестовавши": ["переаттестовав"],
    "переаттестовывав": ["переаттестовывавши"],
    "переаттестовывавши": ["переаттестовывав"],
    "перебазировав": ["перебазировавши"],
    "перебазировавши": ["перебазировав"],
    "перебаламутив": ["перебаламутивши"],
    "перебаламутивши": ["перебаламутив"],
    "перебаливав": ["перебаливавши"],
    "перебаливавши": ["перебаливав"],
    "перебалластировав": ["перебалластировавши"],
    "перебалластировавши": ["перебалластировав"],
    "перебаллотировав": ["перебаллотировавши"],
    "перебаллотировавши": ["перебаллотировав"],
    "перебаллотировывав": ["перебаллотировывавши"],
    "перебаллотировывавши": ["перебаллотировывав"],
    "перебаловав": ["перебаловавши"],
    "перебаловавши": ["перебаловав"],
    "перебаловывав": ["перебаловывавши"],
    "перебаловывавши": ["перебаловывав"],
    "перебалтывав": ["перебалтывавши"],
    "перебалтывавши": ["перебалтывав"],
    "перебалчивав": ["перебалчивавши"],
    "перебалчивавши": ["перебалчивав"],
    "перебарщивав": ["перебарщивавши"],
    "перебарщивавши": ["перебарщивав"],
    "перебарщивать": ["переусердствовать", "перестараться"],
    "перебарывав": ["перебарывавши"],
    "перебарывавши": ["перебарывав"],
    "перебачив": ["перебачивши"],
    "перебачивши": ["перебачив"],
    "перебачить": ["переборщить"],
    "перебдев": ["перебдевши"],
    "перебдевши": ["перебдев"],
    "перебегав": ["перебегавши"],
    "перебегавши": ["перебегав"],
    "перебедовав": ["перебедовавши"],
    "перебедовавши": ["перебедовав"],
    "перебежав": ["перебежавши"],
    "перебежавши": ["перебежав"],
    "перебежчик": ["ренегат"],
    "перебелив": ["перебеливши"],
    "перебеливав": ["перебеливавши"],
    "перебеливавши": ["перебеливав"],
    "перебеливши": ["перебелив"],
    "перебеляв": ["перебелявши"],
    "перебелявши": ["перебеляв"],
    "перебеседовав": ["перебеседовавши"],
    "перебеседовавши": ["перебеседовав"],
    "перебесив": ["перебесивши"],
    "перебесивши": ["перебесив"],
    "перебздев": ["перебздевши"],
    "перебздевши": ["перебздев"],
    "перебив": ["перебивши"],
    "перебивав": ["перебивавши"],
    "перебивавши": ["перебивав"],
    "перебиваться": ["обходиться", "перемежаться", "чередоваться"],
    "перебиваться с хлеба на воду": ["жить впроголодь", "перебиваться с хлеба на квас", "жить в большой крайности", "жить паром", "жить на кочерыжке"],
    "перебиваться с хлеба на квас": ["жить впроголодь", "перебиваться с хлеба на воду", "жить в большой крайности", "жить паром", "жить на кочерыжке"],
    "перебивочка": ["связка"],
    "перебивши": ["перебив"],
    "перебинтовав": ["перебинтовавши"],
    "перебинтовавши": ["перебинтовав"],
    "перебинтовка": ["перебинтовывание", "бинтование"],
    "перебинтовывав": ["перебинтовывавши"],
    "перебинтовывавши": ["перебинтовывав"],
    "перебинтовывание": ["перебинтовка", "бинтование"],
    "перебирав": ["перебиравши"],
    "перебиравши": ["перебирав"],
    "переблефовав": ["переблефовавши"],
    "переблефовавши": ["переблефовав"],
    "перебодав": ["перебодавши"],
    "перебодавши": ["перебодав"],
    "перебойно": ["прерывисто"],
    "переболев": ["переболевши"],
    "переболевав": ["переболевавши"],
    "переболевавши": ["переболевав"],
    "переболевши": ["переболев"],
    "переболтав": ["переболтавши"],
    "переболтавши": ["переболтав"],
    "переболтив": ["переболтивши"],
    "переболтивши": ["переболтив"],
    "переболчивав": ["переболчивавши"],
    "переболчивавши": ["переболчивав"],
    "перебор": ["последовательный поиск", "излишек", "избыток", "излишество", "лишек", "лишнее", "запредельное", "погребальный звон"],
    "переборанивав": ["переборанивавши"],
    "переборанивавши": ["переборанивав"],
    "переборка": ["перегородка", "стенка"],
    "переборовши": ["переборов"],
    "перебороздив": ["перебороздивши"],
    "перебороздивши": ["перебороздив"],
    "переборонив": ["переборонивши"],
    "переборонивши": ["переборонив"],
    "перебороновав": ["перебороновавши"],
    "перебороновавши": ["перебороновав"],
    "перебороновывав": ["перебороновывавши"],
    "перебороновывавши": ["перебороновывав"],
    "переборщив": ["переборщивши"],
    "переборщивши": ["переборщив"],
    "переборщить": ["перестараться", "переусердствовать"],
    "перебрав": ["перебравши"],
    "перебравши": ["перебрав"],
    "перебраковав": ["перебраковавши"],
    "перебраковавши": ["перебраковав"],
    "перебраковывав": ["перебраковывавши"],
    "перебраковывавши": ["перебраковывав"],
    "перебранив": ["перебранивши"],
    "перебранивши": ["перебранив"],
    "перебранка": ["переругивание", "перепалка", "свара"],
    "перебрасывав": ["перебрасывавши"],
    "перебрасывавши": ["перебрасывав"],
    "перебредав": ["перебредавши"],
    "перебредавши": ["перебредав"],
    "перебрив": ["перебривши"],
    "перебривав": ["перебривавши"],
    "перебривавши": ["перебривав"],
    "перебривши": ["перебрив"],
    "перебродив": ["перебродивши"],
    "перебродивши": ["перебродив"],
    "перебронировав": ["перебронировавши"],
    "перебронировавши": ["перебронировав"],
    "перебросав": ["перебросавши"],
    "перебросавши": ["перебросав"],
    "перебросать": ["перекидать"],
    "перебросив": ["перебросивши"],
    "перебросивши": ["перебросив"],
    "перебрызгав": ["перебрызгавши"],
    "перебрызгавши": ["перебрызгав"],
    "перебрызгивав": ["перебрызгивавши"],
    "перебрызгивавши": ["перебрызгивав"],
    "перебрызнув": ["перебрызнувши"],
    "перебрызнувши": ["перебрызнув"],
    "перебудив": ["перебудивши"],
    "перебудивши": ["перебудив"],
    "перебудоражив": ["перебудораживши"],
    "перебудораживши": ["перебудоражив"],
    "перебуживав": ["перебуживавши"],
    "перебуживавши": ["перебуживав"],
    "перебулгачив": ["перебулгачивши"],
    "перебулгачивши": ["перебулгачив"],
    "перебунтовав": ["перебунтовавши"],
    "перебунтовавши": ["перебунтовав"],
    "перебуторив": ["перебуторивши"],
    "перебуторивши": ["перебуторив"],
    "перебутырив": ["перебутыривши"],
    "перебутыривши": ["перебутырив"],
    "перебыв": ["перебывши"],
    "перебывав": ["перебывавши"],
    "перебывавши": ["перебывав"],
    "перебывши": ["перебыв"],
    "перевабив": ["перевабивши"],
    "перевабивши": ["перевабив"],
    "перевабливав": ["перевабливавши"],
    "перевабливавши": ["перевабливав"],
    "переваживав": ["переваживавши"],
    "переваживавши": ["переваживав"],
    "перевалив": ["переваливши"],
    "переваливав": ["переваливавши"],
    "переваливавши": ["переваливав"],
    "переваливши": ["перевалив"],
    "перевальный": ["перевалочный"],
    "переваляв": ["перевалявши"],
    "перевалявши": ["переваляв"],
    "переварив": ["переваривши"],
    "переваривав": ["переваривавши"],
    "переваривавши": ["переваривав"],
    "переваривши": ["переварив"],
    "перевбрасывав": ["перевбрасывавши"],
    "перевбрасывавши": ["перевбрасывав"],
    "перевбросив": ["перевбросивши"],
    "перевбросивши": ["перевбросив"],
    "перевевав": ["перевевавши"],
    "перевевавши": ["перевевав"],
    "перевезя": ["перевёзши"],
    "перевезясь": ["перевёзшись"],
    "перевеивав": ["перевеивавши"],
    "перевеивавши": ["перевеивав"],
    "перевенчав": ["перевенчавши"],
    "перевенчавши": ["перевенчав"],
    "перевербовав": ["перевербовавши"],
    "перевербовавши": ["перевербовав"],
    "перевербовывав": ["перевербовывавши"],
    "перевербовывавши": ["перевербовывав"],
    "переверив": ["переверивши"],
    "переверивши": ["переверив"],
    "перевернув": ["перевернувши"],
    "перевернувши": ["перевернув"],
    "перевернуться": ["перекатиться", "перекинуться", "опрокинуться", "перемениться"],
    "переверстав": ["переверставши"],
    "переверставши": ["переверстав"],
    "перевертев": ["перевертевши"],
    "перевертевши": ["перевертев"],
    "перевертень": ["палиндром"],
    "переверчивав": ["переверчивавши"],
    "переверчивавши": ["переверчивав"],
    "переверяв": ["переверявши"],
    "переверявши": ["переверяв"],
    "переверять": ["перепроверять"],
    "перевес": ["преимущество", "фора", "успех", "победа", "избыточный вес"],
    "перевесив": ["перевесивши"],
    "перевесивши": ["перевесив"],
    "перевет": ["измена"],
    "перевешав": ["перевешавши"],
    "перевешавши": ["перевешав"],
    "перевешивав": ["перевешивавши"],
    "перевешивавши": ["перевешивав"],
    "перевеяв": ["перевеявши"],
    "перевеявши": ["перевеяв"],
    "перевивав": ["перевивавши"],
    "перевивавши": ["перевивав"],
    "перевивши": ["перевив"],
    "перевидав": ["перевидавши"],
    "перевидавши": ["перевидав"],
    "перевидев": ["перевидевши"],
    "перевидевши": ["перевидев"],
    "перевинтив": ["перевинтивши"],
    "перевинтивши": ["перевинтив"],
    "перевинчивав": ["перевинчивавши"],
    "перевинчивавши": ["перевинчивав"],
    "перевирав": ["перевиравши"],
    "перевиравши": ["перевирав"],
    "перевирать": ["искажать"],
    "перевисав": ["перевисавши"],
    "перевисавши": ["перевисав"],
    "перевисев": ["перевисевши"],
    "перевисевши": ["перевисев"],
    "перевиснув": ["перевиснувши"],
    "перевиснувши": ["перевиснув"],
    "перевиснуть": ["перевеситься"],
    "перевитый": ["переплетённый", "обвитый", "завитый", "перепутанный"],
    "перевихрив": ["перевихривши"],
    "перевихривши": ["перевихрив"],
    "перевод": ["перенос", "преобразование", "переведение", "транспортация", "пересказывание", "передача", "переложение", "пересказ", "трансляция", "почтовый перевод", "банковский перевод"],
    "переводив": ["переводивши"],
    "переводивши": ["переводив"],
    "переводить": ["преобразовывать", "трансформировать", "переносить", "перекладывать", "транслировать", "перелагать", "передавать", "конвертировать", "расходовать", "уничтожать"],
    "переводчик": ["толмач", "преложитель", "драгоман", "переводяга"],
    "переводяга": ["переводчик"],
    "перевозбудив": ["перевозбудивши"],
    "перевозбудивши": ["перевозбудив"],
    "перевозбуждав": ["перевозбуждавши"],
    "перевозбуждавши": ["перевозбуждав"],
    "перевозив": ["перевозивши"],
    "перевозивши": ["перевозив"],
    "перевозка": ["перевоз", "транспортировка"],
    "перевозничав": ["перевозничавши"],
    "перевозничавши": ["перевозничав"],
    "перевозчицкий": ["перевозчичий"],
    "перевозчичий": ["перевозчицкий"],
    "переволакивав": ["переволакивавши"],
    "переволакивавши": ["переволакивав"],
    "переволакивать": ["перетаскивать"],
    "переволновав": ["переволновавши"],
    "переволновавши": ["переволновав"],
    "переволок": ["переволока", "волок"],
    "переволока": ["волок"],
    "переволочив": ["переволочивши"],
    "переволочивши": ["переволочив"],
    "переволочь": ["перетащить"],
    "перевооружав": ["перевооружавши"],
    "перевооружавши": ["перевооружав"],
    "перевооружив": ["перевооруживши"],
    "перевооруживши": ["перевооружив"],
    "перевоплотив": ["перевоплотивши"],
    "перевоплотивши": ["перевоплотив"],
    "перевоплощав": ["перевоплощавши"],
    "перевоплощавши": ["перевоплощав"],
    "перевоплощенье": ["перевоплощение"],
    "переворачивав": ["переворачивавши"],
    "переворачивавши": ["переворачивав"],
    "переворашивав": ["переворашивавши"],
    "переворашивавши": ["переворашивав"],
    "переворот": ["кувырок", "проворот", "перевёртывание", "перелом", "революция", "прорыв", "путч"],
    "переворотив": ["переворотивши"],
    "переворотивши": ["переворотив"],
    "переворочав": ["переворочавши"],
    "переворочавши": ["переворочав"],
    "переворошив": ["переворошивши"],
    "переворошивши": ["переворошив"],
    "перевоспитав": ["перевоспитавши"],
    "перевоспитавши": ["перевоспитав"],
    "перевоспитанье": ["перевоспитание"],
    "перевоспитывав": ["перевоспитывавши"],
    "перевоспитывавши": ["перевоспитывав"],
    "переврав": ["перевравши"],
    "перевравши": ["переврав"],
    "перевтома": ["перевтомлення"],
    "перевтомлення": ["перевтома"],
    "перевыбирав": ["перевыбиравши"],
    "перевыбиравши": ["перевыбирав"],
    "перевыбирать": ["переизбирать"],
    "перевыбрав": ["перевыбравши"],
    "перевыбравши": ["перевыбрав"],
    "перевыполнив": ["перевыполнивши"],
    "перевыполнивши": ["перевыполнив"],
    "перевыполняв": ["перевыполнявши"],
    "перевыполнявши": ["перевыполняв"],
    "перевыпуск": ["перепроизводство"],
    "перевыпускав": ["перевыпускавши"],
    "перевыпускавши": ["перевыпускав"],
    "перевыпустив": ["перевыпустивши"],
    "перевыпустивши": ["перевыпустив"],
    "перевысив": ["перевысивши"],
    "перевысивши": ["перевысив"],
    "перевьючив": ["перевьючивши"],
    "перевьючивав": ["перевьючивавши"],
    "перевьючивавши": ["перевьючивав"],
    "перевьючивши": ["перевьючив"],
    "перевядав": ["перевядавши"],
    "перевядавши": ["перевядав"],
    "перевязав": ["перевязавши"],
    "перевязавши": ["перевязав"],
    "перевязочная": ["перевязочный кабинет"],
    "перевязывав": ["перевязывавши"],
    "перевязывавши": ["перевязывав"],
    "перевязывать": ["обвязывать", "перетягивать", "перебинтовывать"],
    "перевялив": ["перевяливши"],
    "перевяливав": ["перевяливавши"],
    "перевяливавши": ["перевяливав"],
    "перевяливши": ["перевялив"],
    "перевянув": ["перевянувши"],
    "перевянувши": ["перевянув"],
    "перевясло": ["свясло"],
    "перевёзши": ["перевезя"],
    "перевёзшись": ["перевезясь"],
    "перевёрнутый": ["опрокинутый", "вверх ногами", "вверх тормашками", "извращённый"],
    "перевёрстывав": ["перевёрстывавши"],
    "перевёрстывавши": ["перевёрстывав"],
    "перевёрстываться": ["переформировываться"],
    "перевёртывав": ["перевёртывавши"],
    "перевёртывавши": ["перевёртывав"],
    "перевёртывать": ["переворачивать", "опрокидывать", "приводить в беспорядок"],
    "перевёртываться": ["переворачиваться"],
    "перевёртыш": ["палиндром", "перевертень"],
    "перегадав": ["перегадавши"],
    "перегадавши": ["перегадав"],
    "перегадив": ["перегадивши"],
    "перегадивши": ["перегадив"],
    "перегадывав": ["перегадывавши"],
    "перегадывавши": ["перегадывав"],
    "перегаживав": ["перегаживавши"],
    "перегаживавши": ["перегаживав"],
    "перегазовав": ["перегазовавши"],
    "перегазовавши": ["перегазовав"],
    "перегазовывав": ["перегазовывавши"],
    "перегазовывавши": ["перегазовывав"],
    "перегар": ["перегарь", "амбре", "выхлоп", "во рту двунадесять языков ночуют", "во рту как кошки насрали"],
    "перегасив": ["перегасивши"],
    "перегасивши": ["перегасив"],
    "перегаснув": ["перегаснувши"],
    "перегаснувши": ["перегаснув"],
    "перегенерировав": ["перегенерировавши"],
    "перегенерировавши": ["перегенерировав"],
    "перегиб": ["перегибание", "изогнутость", "выгнутость", "искривлённость", "извилистость"],
    "перегибав": ["перегибавши"],
    "перегибавши": ["перегибав"],
    "перегибать": ["сгибать", "заходить слишком далеко"],
    "перегибать палку": ["перебарщивать", "переходить границу", "хватать лишку"],
    "перегибнув": ["перегибнувши"],
    "перегибнувши": ["перегибнув"],
    "перегладив": ["перегладивши"],
    "перегладивши": ["перегладив"],
    "перегладывав": ["перегладывавши"],
    "перегладывавши": ["перегладывав"],
    "переглаживав": ["переглаживавши"],
    "переглаживавши": ["переглаживав"],
    "перегласовка": ["умлаут"],
    "переглодав": ["переглодавши"],
    "переглодавши": ["переглодав"],
    "переглотав": ["переглотавши"],
    "переглотавши": ["переглотав"],
    "переглохнув": ["переглохнувши"],
    "переглохнувши": ["переглохнув"],
    "переглушив": ["переглушивши"],
    "переглушивши": ["переглушив"],
    "переглядев": ["переглядевши"],
    "переглядевши": ["переглядев"],
    "переглядеться": ["переглянуться"],
    "переглядывав": ["переглядывавши"],
    "переглядывавши": ["переглядывав"],
    "переглянув": ["переглянувши"],
    "переглянувши": ["переглянув"],
    "перегнав": ["перегнавши"],
    "перегнавши": ["перегнав"],
    "перегнаивав": ["перегнаивавши"],
    "перегнаивавши": ["перегнаивав"],
    "перегнив": ["перегнивши"],
    "перегнивав": ["перегнивавши"],
    "перегнивавши": ["перегнивав"],
    "перегнивши": ["перегнив"],
    "перегноив": ["перегноивши"],
    "перегноивши": ["перегноив"],
    "перегной": ["гумус", "компост"],
    "перегнув": ["перегнувши"],
    "перегнувши": ["перегнув"],
    "переговаривав": ["переговаривавши"],
    "переговаривавши": ["переговаривав"],
    "переговняв": ["переговнявши"],
    "переговнявши": ["переговняв"],
    "переговнять": ["перепортить"],
    "переговорив": ["переговоривши"],
    "переговоривши": ["переговорив"],
    "переговорщик": ["парламентёр"],
    "перегодив": ["перегодивши"],
    "перегодивши": ["перегодив"],
    "перегодити": ["перечекати"],
    "переголосовав": ["переголосовавши"],
    "переголосовавши": ["переголосовав"],
    "переголосование": ["переголосовка"],
    "переголосовка": ["переголосование"],
    "переголосовывав": ["переголосовывавши"],
    "переголосовывавши": ["переголосовывав"],
    "перегон": ["перегонка"],
    "перегонка": ["дистилляция"],
    "перегоняв": ["перегонявши"],
    "перегонявши": ["перегоняв"],
    "перегонять": ["обгонять"],
    "перегорав": ["перегоравши"],
    "перегоравши": ["перегорав"],
    "перегораживав": ["перегораживавши"],
    "перегораживавши": ["перегораживав"],
    "перегорев": ["перегоревши"],
    "перегоревав": ["перегоревавши"],
    "перегоревавши": ["перегоревав"],
    "перегоревши": ["перегорев"],
    "перегоркнув": ["перегоркнувши"],
    "перегоркнувши": ["перегоркнув"],
    "перегородив": ["перегородивши"],
    "перегородивши": ["перегородив"],
    "перегорчив": ["перегорчивши"],
    "перегорчивши": ["перегорчив"],
    "перегостив": ["перегостивши"],
    "перегостивши": ["перегостив"],
    "переграбив": ["переграбивши"],
    "переграбивши": ["переграбив"],
    "переградив": ["переградивши"],
    "переградивши": ["переградив"],
    "переграждав": ["переграждавши"],
    "переграждавши": ["переграждав"],
    "перегранив": ["перегранивши"],
    "перегранивав": ["перегранивавши"],
    "перегранивавши": ["перегранивав"],
    "перегранивши": ["перегранив"],
    "переграфив": ["переграфивши"],
    "переграфивши": ["переграфив"],
    "переграфляв": ["переграфлявши"],
    "переграфлявши": ["переграфляв"],
    "перегребав": ["перегребавши"],
    "перегребавши": ["перегребав"],
    "перегревав": ["перегревавши"],
    "перегревавши": ["перегревав"],
    "перегревши": ["перегрев"],
    "перегримировав": ["перегримировавши"],
    "перегримировавши": ["перегримировав"],
    "перегримировывав": ["перегримировывавши"],
    "перегримировывавши": ["перегримировывав"],
    "перегринация": ["странствие", "путешествие", "скитание"],
    "перегрипповав": ["перегрипповавши"],
    "перегрипповавши": ["перегрипповав"],
    "перегружав": ["перегружавши"],
    "перегружавши": ["перегружав"],
    "перегрузив": ["перегрузивши"],
    "перегрузивши": ["перегрузив"],
    "перегрузить": ["перезагрузить"],
    "перегрунтовав": ["перегрунтовавши"],
    "перегрунтовавши": ["перегрунтовав"],
    "перегрунтовывав": ["перегрунтовывавши"],
    "перегрунтовывавши": ["перегрунтовывав"],
    "перегруппировав": ["перегруппировавши"],
    "перегруппировавши": ["перегруппировав"],
    "перегруппировывав": ["перегруппировывавши"],
    "перегруппировывавши": ["перегруппировывав"],
    "перегрызав": ["перегрызавши"],
    "перегрызавши": ["перегрызав"],
    "перегрязнив": ["перегрязнивши"],
    "перегрязнивши": ["перегрязнив"],
    "перегубив": ["перегубивши"],
    "перегубивши": ["перегубив"],
    "перегуд": ["гул", "рокот"],
    "перегуливав": ["перегуливавши"],
    "перегуливавши": ["перегуливав"],
    "перегуляв": ["перегулявши"],
    "перегулявши": ["перегуляв"],
    "перегустив": ["перегустивши"],
    "перегустивши": ["перегустив"],
    "перегущав": ["перегущавши"],
    "перегущавши": ["перегущав"],
    "перед": ["пред", "предо", "передо", "напротив", "впереди", "лицом к", "на фоне", "до", "рядом с"],
    "перед-": ["пред-", "преди-"],
    "передав": ["передавши"],
    "передавав": ["передававши"],
    "передававши": ["передавав"],
    "передавив": ["передавивши"],
    "передавивши": ["передавив"],
    "передавливав": ["передавливавши"],
    "передавливавши": ["передавливав"],
    "передавши": ["передав"],
    "передаивав": ["передаивавши"],
    "передаивавши": ["передаивав"],
    "передарив": ["передаривши"],
    "передаривав": ["передаривавши"],
    "передаривавши": ["передаривав"],
    "передаривши": ["передарив"],
    "передаться": ["переметнуться"],
    "передача": ["переход", "перенос", "трансляция", "трансмиссия", "пас"],
    "передваивав": ["передваивавши"],
    "передваивавши": ["передваивав"],
    "передвигав": ["передвигавши"],
    "передвигавши": ["передвигав"],
    "передвиганье": ["передвигание"],
    "передвигаться": ["перемещаться"],
    "передвижение": ["перемещение", "передвигание"],
    "передвижение согласных": ["перебой согласных"],
    "передвижимый": ["передвижной", "движимый"],
    "передвижной": ["мобильный"],
    "передвинув": ["передвинувши"],
    "передвинувши": ["передвинув"],
    "передвинуть": ["двинуть", "подвинуть", "перенести", "переназначить"],
    "передвоив": ["передвоивши"],
    "передвоивши": ["передвоив"],
    "передев": ["передевши"],
    "передевав": ["передевавши"],
    "передевавши": ["передевав"],
    "передеваться": ["переодеваться"],
    "передевши": ["передев"],
    "переделав": ["переделавши"],
    "переделавши": ["переделав"],
    "переделив": ["переделивши"],
    "переделивав": ["переделивавши"],
    "переделивавши": ["переделивав"],
    "переделивши": ["переделив"],
    "переделывав": ["переделывавши"],
    "переделывавши": ["переделывав"],
    "переделяв": ["переделявши"],
    "переделявши": ["переделяв"],
    "передержав": ["передержавши"],
    "передержавши": ["передержав"],
    "передерживав": ["передерживавши"],
    "передерживавши": ["передерживав"],
    "передешевив": ["передешевивши"],
    "передешевивши": ["передешевив"],
    "передешевляв": ["передешевлявши"],
    "передешевлявши": ["передешевляв"],
    "передирав": ["передиравши"],
    "передиравши": ["передирав"],
    "передислокация": ["перемещение", "передвижение", "переезд", "перестановка"],
    "передислоцировав": ["передислоцировавши"],
    "передислоцировавши": ["передислоцировав"],
    "передислоцировать": ["перераспределять", "перераспределить"],
    "передневав": ["передневавши"],
    "передневавши": ["передневав"],
    "передневерхний": ["передне-верхний"],
    "передненёбный": ["препалатальный"],
    "переднеспинка": ["пронотум"],
    "передний": ["лицевой", "фронтальный", "первый", "предний"],
    "передник": ["передничек", "фартук", "запон", "доска"],
    "передница": ["гениталии", "половой орган"],
    "передньоязиковий": ["передньоязичний"],
    "передньоязичний": ["передньоязиковий"],
    "передняя": ["прихожая"],
    "передняя азия": ["западная азия", "юго-западная азия"],
    "передо": ["перед", "пред", "предо"],
    "передобрив": ["передобривши"],
    "передобривши": ["передобрив"],
    "передоверив": ["передоверивши"],
    "передоверивши": ["передоверив"],
    "передоверяв": ["передоверявши"],
    "передоверявши": ["передоверяв"],
    "передовик": ["ударник", "победитель", "соревнования"],
    "передовой": ["передний", "авангардный", "прогрессивный", "продвинутый"],
    "передоз": ["передоза", "передозняк"],
    "передоза": ["передоз", "передозняк"],
    "передозировав": ["передозировавши"],
    "передозировавши": ["передозировав"],
    "передозировка": ["передоз", "передоза", "передозняк"],
    "передозняк": ["передоз", "передоза"],
    "передоив": ["передоивши"],
    "передоивши": ["передоив"],
    "передокладывав": ["передокладывавши"],
    "передокладывавши": ["передокладывав"],
    "передолжав": ["передолжавши"],
    "передолжавши": ["передолжав"],
    "передолив": ["передоливши"],
    "передоливши": ["передолив"],
    "передоложив": ["передоложивши"],
    "передоложивши": ["передоложив"],
    "передом": ["впереди"],
    "передопрашивав": ["передопрашивавши"],
    "передопрашивавши": ["передопрашивав"],
    "передопросив": ["передопросивши"],
    "передопросивши": ["передопросив"],
    "передохнув": ["передохнувши"],
    "передохнувши": ["передохнув"],
    "передрав": ["передравши"],
    "передравши": ["передрав"],
    "передразнив": ["передразнивши"],
    "передразнивав": ["передразнивавши"],
    "передразнивавши": ["передразнивав"],
    "передразнивание": ["передразниванье", "копирование", "обезьянничанье"],
    "передразниванье": ["передразнивание"],
    "передразнивши": ["передразнив"],
    "передраив": ["передраивши"],
    "передраивав": ["передраивавши"],
    "передраивавши": ["передраивав"],
    "передраивши": ["передраив"],
    "передрассветный": ["предрассветный"],
    "передремав": ["передремавши"],
    "передремавши": ["передремав"],
    "передремнув": ["передремнувши"],
    "передремнувши": ["передремнув"],
    "передрессировав": ["передрессировавши"],
    "передрессировавши": ["передрессировав"],
    "передрессировывав": ["передрессировывавши"],
    "передрессировывавши": ["передрессировывав"],
    "передробив": ["передробивши"],
    "передробивши": ["передробив"],
    "передробляв": ["передроблявши"],
    "передроблявши": ["передробляв"],
    "передрогнув": ["передрогнувши"],
    "передрогнувши": ["передрогнув"],
    "передрогши": ["передрогнув", "передрогнувши"],
    "передружив": ["передруживши"],
    "передруживши": ["передружив"],
    "передряга": ["неприятность", "злоключение", "приключение", "происшествие", "переплёт", "потрясение", "встряска"],
    "передубив": ["передубивши"],
    "передубивши": ["передубив"],
    "передував": ["передувавши"],
    "передувавши": ["передував"],
    "передувши": ["передув"],
    "передумав": ["передумавши"],
    "передумавши": ["передумав"],
    "передумывав": ["передумывавши"],
    "передумывавши": ["передумывав"],
    "передурив": ["передуривши"],
    "передуривши": ["передурив"],
    "передушив": ["передушивши"],
    "передушивши": ["передушив"],
    "передыхав": ["передыхавши"],
    "передыхавши": ["передыхав"],
    "передышаться": ["отдышаться", "передохнуть"],
    "передёргав": ["передёргавши"],
    "передёргавши": ["передёргав"],
    "передёргивав": ["передёргивавши"],
    "передёргивавши": ["передёргивав"],
    "передёргивать": ["подменять понятия", "дрочить"],
    "передёрнув": ["передёрнувши"],
    "передёрнувши": ["передёрнув"],
    "переебав": ["переебавши"],
    "переебавши": ["переебав"],
    "переебать": ["навернуть", "наебнуть", "переебенить", "переебёхать", "переебурить", "перехуярить", "перехуякать", "перехуячить", "разбить", "перебить", "расколотить", "переколотить"],
    "переедав": ["переедавши"],
    "переедавши": ["переедав"],
    "переездив": ["переездивши"],
    "переездивши": ["переездив"],
    "переезжав": ["переезжавши"],
    "переезжавши": ["переезжав"],
    "переезжать": ["переправляться", "пересекать", "перемётываться", "переселяться", "мигрировать"],
    "переехав": ["переехавши"],
    "переехавши": ["переехав"],
    "переехать": ["передвинуться", "переселиться", "перебраться", "перекочевать", "пересечь", "перейти", "миновать", "задавить", "оставить мокрое место", "превратить в лепёшку"],
    "пережабина": ["сужение", "перехват", "переём", "пережим"],
    "пережав": ["пережавши"],
    "пережавши": ["пережав"],
    "пережалев": ["пережалевши"],
    "пережалевши": ["пережалев"],
    "пережалив": ["пережаливши"],
    "пережаливав": ["пережаливавши"],
    "пережаливавши": ["пережаливав"],
    "пережаливши": ["пережалив"],
    "пережаловав": ["пережаловавши"],
    "пережаловавши": ["пережаловав"],
    "пережарив": ["пережаривши"],
    "пережаривав": ["пережаривавши"],
    "пережаривавши": ["пережаривав"],
    "пережаривши": ["пережарив"],
    "переждав": ["переждавши"],
    "переждавши": ["переждав"],
    "пережевав": ["пережевавши"],
    "пережевавши": ["пережевав"],
    "пережелкнув": ["пережелкнувши"],
    "пережелкнувши": ["пережелкнув"],
    "пережелтев": ["пережелтевши"],
    "пережелтевши": ["пережелтев"],
    "пережелтив": ["пережелтивши"],
    "пережелтивши": ["пережелтив"],
    "переженив": ["переженивши"],
    "переженивши": ["переженив"],
    "пережертвовав": ["пережертвовавши"],
    "пережертвовавши": ["пережертвовав"],
    "пережив": ["переживши"],
    "переживав": ["переживавши"],
    "переживавши": ["переживав"],
    "переживание": ["пережиток"],
    "переживать": ["выживать", "беспокоиться", "бояться", "волноваться", "пугаться", "робеть", "содрогаться", "страшиться", "тревожиться", "трепетать", "трусить", "ужасаться"],
    "переживши": ["пережив"],
    "пережигав": ["пережигавши"],
    "пережигавши": ["пережигав"],
    "пережидав": ["пережидавши"],
    "пережидавши": ["пережидав"],
    "пережидать": ["ждать", "дожидаться", "выжидать"],
    "пережимав": ["пережимавши"],
    "пережимавши": ["пережимав"],
    "пережинав": ["пережинавши"],
    "пережинавши": ["пережинав"],
    "пережирав": ["пережиравши"],
    "пережиравши": ["пережирав"],
    "пережиток": ["анахронизм"],
    "пережрав": ["пережравши"],
    "пережравши": ["пережрав"],
    "пережрать": ["переесть", "объесться", "перепить"],
    "пережёвывав": ["пережёвывавши"],
    "пережёвывавши": ["пережёвывав"],
    "перезабыв": ["перезабывши"],
    "перезабывав": ["перезабывавши"],
    "перезабывавши": ["перезабывав"],
    "перезабывши": ["перезабыв"],
    "перезагружав": ["перезагружавши"],
    "перезагружавши": ["перезагружав"],
    "перезагрузив": ["перезагрузивши"],
    "перезагрузивши": ["перезагрузив"],
    "перезагрузить": ["ребутнуть"],
    "перезаказав": ["перезаказавши"],
    "перезаказавши": ["перезаказав"],
    "перезаказывав": ["перезаказывавши"],
    "перезаказывавши": ["перезаказывав"],
    "перезакалив": ["перезакаливши"],
    "перезакаливав": ["перезакаливавши"],
    "перезакаливавши": ["перезакаливав"],
    "перезакаливши": ["перезакалив"],
    "перезакладывав": ["перезакладывавши"],
    "перезакладывавши": ["перезакладывав"],
    "перезаключав": ["перезаключавши"],
    "перезаключавши": ["перезаключав"],
    "перезаключив": ["перезаключивши"],
    "перезаключивши": ["перезаключив"],
    "перезакрепив": ["перезакрепивши"],
    "перезакрепивши": ["перезакрепив"],
    "перезакрепляв": ["перезакреплявши"],
    "перезакреплявши": ["перезакрепляв"],
    "перезаливав": ["перезаливавши"],
    "перезаливавши": ["перезаливав"],
    "перезаливши": ["перезалив"],
    "перезаложив": ["перезаложивши"],
    "перезаложивши": ["перезаложив"],
    "перезанимав": ["перезанимавши"],
    "перезанимавши": ["перезанимав"],
    "перезаняв": ["перезанявши"],
    "перезанявши": ["перезаняв"],
    "перезаписав": ["перезаписавши"],
    "перезаписавши": ["перезаписав"],
    "перезаписать": ["переписать"],
    "перезаписывав": ["перезаписывавши"],
    "перезаписывавши": ["перезаписывав"],
    "перезаписывание": ["перезапись"],
    "перезапрягав": ["перезапрягавши"],
    "перезапрягавши": ["перезапрягав"],
    "перезапускав": ["перезапускавши"],
    "перезапускавши": ["перезапускав"],
    "перезапустив": ["перезапустивши"],
    "перезапустивши": ["перезапустив"],
    "перезапустить": ["рестартовать", "перезагрузить"],
    "перезапущенный": ["перезагруженный"],
    "перезаразив": ["перезаразивши"],
    "перезаразивши": ["перезаразив"],
    "перезарядив": ["перезарядивши"],
    "перезарядивши": ["перезарядив"],
    "перезаряжав": ["перезаряжавши"],
    "перезаряжавши": ["перезаряжав"],
    "перезаселив": ["перезаселивши"],
    "перезаселивши": ["перезаселив"],
    "перезахоранивав": ["перезахоранивавши"],
    "перезахоранивавши": ["перезахоранивав"],
    "перезахоронив": ["перезахоронивши"],
    "перезахоронивши": ["перезахоронив"],
    "перезва": ["перегук"],
    "перезвав": ["перезвавши"],
    "перезвавши": ["перезвав"],
    "перезванивав": ["перезванивавши"],
    "перезванивавши": ["перезванивав"],
    "перезвенев": ["перезвеневши"],
    "перезвеневши": ["перезвенев"],
    "перезволоження": ["перезволожування"],
    "перезволожування": ["перезволоження"],
    "перезвонив": ["перезвонивши"],
    "перезвонивши": ["перезвонив"],
    "перезвякивав": ["перезвякивавши"],
    "перезвякивавши": ["перезвякивав"],
    "перезимовав": ["перезимовавши"],
    "перезимовавши": ["перезимовав"],
    "перезимовывав": ["перезимовывавши"],
    "перезимовывавши": ["перезимовывав"],
    "перезнав": ["перезнавши"],
    "перезнавши": ["перезнав"],
    "перезнакамливав": ["перезнакамливавши"],
    "перезнакамливавши": ["перезнакамливав"],
    "перезнакомив": ["перезнакомивши"],
    "перезнакомивши": ["перезнакомив"],
    "перезолачивав": ["перезолачивавши"],
    "перезолачивавши": ["перезолачивав"],
    "перезолив": ["перезоливши"],
    "перезоливши": ["перезолив"],
    "перезолотив": ["перезолотивши"],
    "перезолотивши": ["перезолотив"],
    "перезонировав": ["перезонировавши"],
    "перезонировавши": ["перезонировав"],
    "перезрада": ["зрадомога", "зрадоперемога"],
    "перезрев": ["перезревши"],
    "перезревав": ["перезревавши"],
    "перезревавши": ["перезревав"],
    "перезревши": ["перезрев"],
    "перезрелый": ["переспелый"],
    "перезывав": ["перезывавши"],
    "перезывавши": ["перезывав"],
    "перезябнув": ["перезябнувши"],
    "перезябнувши": ["перезябнув"],
    "переиграв": ["переигравши"],
    "переигравши": ["переиграв"],
    "переигрывав": ["переигрывавши"],
    "переигрывавши": ["переигрывав"],
    "переизбирав": ["переизбиравши"],
    "переизбиравши": ["переизбирав"],
    "переизбрав": ["переизбравши"],
    "переизбравши": ["переизбрав"],
    "переизбыток": ["избыток"],
    "переизбыточествовав": ["переизбыточествовавши"],
    "переизбыточествовавши": ["переизбыточествовав"],
    "переизведав": ["переизведавши"],
    "переизведавши": ["переизведав"],
    "переиздав": ["переиздавши"],
    "переиздавав": ["переиздававши"],
    "переиздававши": ["переиздавав"],
    "переиздавать": ["перепечатывать"],
    "переиздавши": ["переиздав"],
    "переиздать": ["перепечатать"],
    "переизобретав": ["переизобретавши"],
    "переизобретавши": ["переизобретав"],
    "переименовав": ["переименовавши"],
    "переименовавши": ["переименовав"],
    "переименование": ["переименовывание"],
    "переименовывав": ["переименовывавши"],
    "переименовывавши": ["переименовывав"],
    "переимщик": ["переёмщик", "переимщица", "переймак", "переймала", "пересмешник"],
    "переиначив": ["переиначивши"],
    "переиначивав": ["переиначивавши"],
    "переиначивавши": ["переиначивав"],
    "переиначивать": ["изменять", "переменять"],
    "переиначивши": ["переиначив"],
    "переиндексировав": ["переиндексировавши"],
    "переиндексировавши": ["переиндексировав"],
    "переинструментовав": ["переинструментовавши"],
    "переинструментовавши": ["переинструментовав"],
    "переинструментовывав": ["переинструментовывавши"],
    "переинструментовывавши": ["переинструментовывав"],
    "переинтерпретировав": ["переинтерпретировавши"],
    "переинтерпретировавши": ["переинтерпретировав"],
    "переискав": ["переискавши"],
    "переискавши": ["переискав"],
    "переискивав": ["переискивавши"],
    "переискивавши": ["переискивав"],
    "переиспользовав": ["переиспользовавши"],
    "переиспользовавши": ["переиспользовав"],
    "переиспытав": ["переиспытавши"],
    "переиспытавши": ["переиспытав"],
    "переиспытывав": ["переиспытывавши"],
    "переиспытывавши": ["переиспытывав"],
    "перейти": ["пересечь"],
    "перейти рубикон": ["бросить кости"],
    "переказав": ["переказавши"],
    "переказавши": ["переказав"],
    "переказывав": ["переказывавши"],
    "переказывавши": ["переказывав"],
    "перекалечив": ["перекалечивши"],
    "перекалечивав": ["перекалечивавши"],
    "перекалечивавши": ["перекалечивав"],
    "перекалечивши": ["перекалечив"],
    "перекалибровав": ["перекалибровавши"],
    "перекалибровавши": ["перекалибровав"],
    "перекалив": ["перекаливши"],
    "перекаливав": ["перекаливавши"],
    "перекаливавши": ["перекаливав"],
    "перекаливать": ["перекалять"],
    "перекаливши": ["перекалив"],
    "перекалить": ["перегреть"],
    "перекалывав": ["перекалывавши"],
    "перекалывавши": ["перекалывав"],
    "перекаляв": ["перекалявши"],
    "перекалявши": ["перекаляв"],
    "перекалякав": ["перекалякавши"],
    "перекалякавши": ["перекалякав"],
    "перекалять": ["перекаливать"],
    "перекантовав": ["перекантовавши"],
    "перекантовавши": ["перекантовав"],
    "перекантовывав": ["перекантовывавши"],
    "перекантовывавши": ["перекантовывав"],
    "перекапав": ["перекапавши"],
    "перекапавши": ["перекапав"],
    "перекапитализация": ["сверхкапитализация"],
    "перекапчивав": ["перекапчивавши"],
    "перекапчивавши": ["перекапчивав"],
    "перекапывав": ["перекапывавши"],
    "перекапывавши": ["перекапывав"],
    "перекарикатурив": ["перекарикатуривши"],
    "перекарикатуривав": ["перекарикатуривавши"],
    "перекарикатуривавши": ["перекарикатуривав"],
    "перекарикатуривши": ["перекарикатурив"],
    "перекармливав": ["перекармливавши"],
    "перекармливавши": ["перекармливав"],
    "перекат": ["гул", "раскат", "возвышение"],
    "перекатав": ["перекатавши"],
    "перекатавши": ["перекатав"],
    "перекати-поле": ["бабий ум"],
    "перекатив": ["перекативши"],
    "перекативши": ["перекатив"],
    "перекатный": ["перекатистый", "раскатистый"],
    "перекатывав": ["перекатывавши"],
    "перекатывавши": ["перекатывав"],
    "перекачав": ["перекачавши"],
    "перекачавши": ["перекачав"],
    "перекачивав": ["перекачивавши"],
    "перекачивавши": ["перекачивав"],
    "перекачнув": ["перекачнувши"],
    "перекачнувши": ["перекачнув"],
    "перекашивав": ["перекашивавши"],
    "перекашивавши": ["перекашивав"],
    "перекашиваться": ["перекособочиваться"],
    "переквалифицировав": ["переквалифицировавши"],
    "переквалифицировавши": ["переквалифицировав"],
    "переквасив": ["переквасивши"],
    "переквасивши": ["переквасив"],
    "переквашивав": ["переквашивавши"],
    "переквашивавши": ["переквашивав"],
    "перекидав": ["перекидавши"],
    "перекидавши": ["перекидав"],
    "перекидывав": ["перекидывавши"],
    "перекидывавши": ["перекидывав"],
    "перекидывать": ["перебрасывать"],
    "перекинув": ["перекинувши"],
    "перекинувши": ["перекинув"],
    "перекинуть": ["переводить"],
    "перекипав": ["перекипавши"],
    "перекипавши": ["перекипав"],
    "перекипев": ["перекипевши"],
    "перекипевши": ["перекипев"],
    "перекипятив": ["перекипятивши"],
    "перекипятивши": ["перекипятив"],
    "перекисав": ["перекисавши"],
    "перекисавши": ["перекисав"],
    "перекислив": ["перекисливши"],
    "перекисливши": ["перекислив"],
    "перекисляв": ["перекислявши"],
    "перекислявши": ["перекисляв"],
    "перекиснув": ["перекиснувши"],
    "перекиснувши": ["перекиснув"],
    "перекись": ["пероксид"],
    "перекись водорода": ["пероксид водорода"],
    "перекладина": ["турник"],
    "перекладка": ["перекладывание", "прокладка", "перекладная анимация"],
    "перекладывав": ["перекладывавши"],
    "перекладывавши": ["перекладывав"],
    "переклассифицировать": ["реклассифицировать"],
    "переклевав": ["переклевавши"],
    "переклевавши": ["переклевав"],
    "переклеив": ["переклеивши"],
    "переклеивав": ["переклеивавши"],
    "переклеивавши": ["переклеивав"],
    "переклеивши": ["переклеив"],
    "переклеймив": ["переклеймивши"],
    "переклеймивши": ["переклеймив"],
    "переклепав": ["переклепавши"],
    "переклепавши": ["переклепав"],
    "перекликав": ["перекликавши"],
    "перекликавши": ["перекликав"],
    "перекликанье": ["перекликание"],
    "перекликаться": ["перекликиваться"],
    "перекликивав": ["перекликивавши"],
    "перекликивавши": ["перекликивав"],
    "перекликиваться": ["перекликаться"],
    "перекликнув": ["перекликнувши"],
    "перекликнувши": ["перекликнув"],
    "переклинив": ["переклинивши"],
    "переклинивав": ["переклинивавши"],
    "переклинивавши": ["переклинивав"],
    "переклинивши": ["переклинив"],
    "переключав": ["переключавши"],
    "переключавши": ["переключав"],
    "переключив": ["переключивши"],
    "переключивши": ["переключив"],
    "переклёвывав": ["переклёвывавши"],
    "переклёвывавши": ["переклёвывав"],
    "переклёпывав": ["переклёпывавши"],
    "переклёпывавши": ["переклёпывав"],
    "перековав": ["перековавши"],
    "перековавши": ["перековав"],
    "перековеркав": ["перековеркавши"],
    "перековеркавши": ["перековеркав"],
    "перековеркивав": ["перековеркивавши"],
    "перековеркивавши": ["перековеркивав"],
    "перековывав": ["перековывавши"],
    "перековывавши": ["перековывав"],
    "перековыривав": ["перековыривавши"],
    "перековыривавши": ["перековыривав"],
    "перековыряв": ["перековырявши"],
    "перековырявши": ["перековыряв"],
    "перекодировав": ["перекодировавши"],
    "перекодировавши": ["перекодировав"],
    "перекодирование": ["перекодировка"],
    "перекозлив": ["перекозливши"],
    "перекозливши": ["перекозлив"],
    "перекозыряв": ["перекозырявши"],
    "перекозырявши": ["перекозыряв"],
    "перекокав": ["перекокавши"],
    "перекокавши": ["перекокав"],
    "перекокать": ["побить", "перебить", "поубивать"],
    "перекокошив": ["перекокошивши"],
    "перекокошивши": ["перекокошив"],
    "переколачивав": ["переколачивавши"],
    "переколачивавши": ["переколачивав"],
    "переколев": ["переколевши"],
    "переколевши": ["переколев"],
    "переколов": ["переколовши"],
    "переколовши": ["переколов"],
    "переколотив": ["переколотивши"],
    "переколотивши": ["переколотив"],
    "переколошматив": ["переколошмативши"],
    "переколошмативши": ["переколошматив"],
    "переколупав": ["переколупавши"],
    "переколупавши": ["переколупав"],
    "перекомбинировать": ["перекомпоновывать", "перекомпоновать"],
    "перекомиссия": ["переосвидетельствование"],
    "перекомкав": ["перекомкавши"],
    "перекомкавши": ["перекомкав"],
    "перекомкивав": ["перекомкивавши"],
    "перекомкивавши": ["перекомкивав"],
    "перекоммутировав": ["перекоммутировавши"],
    "перекоммутировавши": ["перекоммутировав"],
    "перекомпилировав": ["перекомпилировавши"],
    "перекомпилировавши": ["перекомпилировав"],
    "перекомплектовав": ["перекомплектовавши"],
    "перекомплектовавши": ["перекомплектовав"],
    "перекомплектовывав": ["перекомплектовывавши"],
    "перекомплектовывавши": ["перекомплектовывав"],
    "перекомпоновав": ["перекомпоновавши"],
    "перекомпоновавши": ["перекомпоновав"],
    "перекомпоновывав": ["перекомпоновывавши"],
    "перекомпоновывавши": ["перекомпоновывав"],
    "перекомпостировав": ["перекомпостировавши"],
    "перекомпостировавши": ["перекомпостировав"],
    "переконопатив": ["переконопативши"],
    "переконопативши": ["переконопатив"],
    "переконопачивав": ["переконопачивавши"],
    "переконопачивавши": ["переконопачивав"],
    "переконструировав": ["переконструировавши"],
    "переконструировавши": ["переконструировав"],
    "переконфузив": ["переконфузивши"],
    "переконфузивши": ["переконфузив"],
    "перекопав": ["перекопавши"],
    "перекопавши": ["перекопав"],
    "перекопировав": ["перекопировавши"],
    "перекопировавши": ["перекопировав"],
    "перекоптив": ["перекоптивши"],
    "перекоптивши": ["перекоптив"],
    "перекормив": ["перекормивши"],
    "перекормивши": ["перекормив"],
    "перекормить": ["обкормить"],
    "перекоробив": ["перекоробивши"],
    "перекоробивши": ["перекоробив"],
    "перекоряв": ["перекорявши"],
    "перекорявши": ["перекоряв"],
    "перекоряться": ["пререкаться"],
    "перекорячив": ["перекорячивши"],
    "перекорячивав": ["перекорячивавши"],
    "перекорячивавши": ["перекорячивав"],
    "перекорячивать": ["перекорёживать"],
    "перекорячивши": ["перекорячив"],
    "перекорячить": ["перекорёжить"],
    "перекорёжив": ["перекорёживши", "искорёжив", "покорёжив"],
    "перекорёживав": ["перекорёживавши"],
    "перекорёживавши": ["перекорёживав"],
    "перекорёживши": ["перекорёжив"],
    "перекос": ["перекашивание", "перегиб"],
    "перекосив": ["перекосивши"],
    "перекосивши": ["перекосив"],
    "перекочевав": ["перекочевавши"],
    "перекочевавши": ["перекочевав"],
    "перекочёвывав": ["перекочёвывавши"],
    "перекочёвывавши": ["перекочёвывав"],
    "перекрадывав": ["перекрадывавши"],
    "перекрадывавши": ["перекрадывав"],
    "перекраивав": ["перекраивавши"],
    "перекраивавши": ["перекраивав"],
    "перекрасив": ["перекрасивши"],
    "перекрасивши": ["перекрасив"],
    "перекрахмалив": ["перекрахмаливши"],
    "перекрахмаливав": ["перекрахмаливавши"],
    "перекрахмаливавши": ["перекрахмаливав"],
    "перекрахмаливши": ["перекрахмалив"],
    "перекрашивав": ["перекрашивавши"],
    "перекрашивавши": ["перекрашивав"],
    "перекредитовав": ["перекредитовавши"],
    "перекредитовавши": ["перекредитовав"],
    "перекрепив": ["перекрепивши"],
    "перекрепивши": ["перекрепив"],
    "перекрепляв": ["перекреплявши"],
    "перекреплявши": ["перекрепляв"],
    "перекрест": ["перекрещенец"],
    "перекрестив": ["перекрестивши"],
    "перекрестивши": ["перекрестив"],
    "перекрестие": ["перекрестье"],
    "перекрестье": ["перекрестие"],
    "перекрещеванец": ["перекрещенец"],
    "перекрещенец": ["анабаптист", "перекрещеванец", "перекрест"],
    "перекрещивав": ["перекрещивавши"],
    "перекрещивавши": ["перекрещивав"],
    "перекривив": ["перекрививши"],
    "перекрививши": ["перекривив"],
    "перекривляв": ["перекривлявши"],
    "перекривлявши": ["перекривляв"],
    "перекрикивав": ["перекрикивавши"],
    "перекрикивавши": ["перекрикивав"],
    "перекристаллизация": ["рекристаллизация"],
    "перекристаллизовав": ["перекристаллизовавши"],
    "перекристаллизовавши": ["перекристаллизовав"],
    "перекристаллизовывав": ["перекристаллизовывавши"],
    "перекристаллизовывавши": ["перекристаллизовывав"],
    "перекричав": ["перекричавши"],
    "перекричавши": ["перекричав"],
    "перекровавив": ["перекровавивши"],
    "перекровавивши": ["перекровавив"],
    "перекроив": ["перекроивши"],
    "перекроивши": ["перекроив"],
    "перекромсав": ["перекромсавши"],
    "перекромсавши": ["перекромсав"],
    "перекрошив": ["перекрошивши"],
    "перекрошивши": ["перекрошив"],
    "перекружив": ["перекруживши"],
    "перекруживши": ["перекружив"],
    "перекрут": ["перекручивание", "скручивание", "закручивание"],
    "перекрутив": ["перекрутивши"],
    "перекрутивши": ["перекрутив"],
    "перекручивав": ["перекручивавши"],
    "перекручивавши": ["перекручивав"],
    "перекрывав": ["перекрывавши"],
    "перекрывавши": ["перекрывав"],
    "перекрывчик": ["перекрыв"],
    "перекрывши": ["перекрыв"],
    "перекрыть кислород": ["связать руки"],
    "перекрытье": ["перекрытие"],
    "перекрёстный": ["перекрещивающийся", "пересекающийся"],
    "перекувыркав": ["перекувыркавши"],
    "перекувыркавши": ["перекувыркав"],
    "перекувыркивав": ["перекувыркивавши"],
    "перекувыркивавши": ["перекувыркивав"],
    "перекувыркнув": ["перекувыркнувши"],
    "перекувыркнувши": ["перекувыркнув"],
    "перекувырнув": ["перекувырнувши"],
    "перекувырнувши": ["перекувырнув"],
    "перекуковав": ["перекуковавши"],
    "перекуковавши": ["перекуковав"],
    "перекультивировав": ["перекультивировавши"],
    "перекультивировавши": ["перекультивировав"],
    "перекуп": ["перекупка"],
    "перекупав": ["перекупавши"],
    "перекупавши": ["перекупав"],
    "перекупив": ["перекупивши"],
    "перекупивши": ["перекупив"],
    "перекупывав": ["перекупывавши"],
    "перекупывавши": ["перекупывав"],
    "перекурив": ["перекуривши"],
    "перекуривав": ["перекуривавши"],
    "перекуривавши": ["перекуривав"],
    "перекуривши": ["перекурив"],
    "перекурить": ["обкуриться"],
    "перекус": ["перечавк", "перегрыз", "закуска"],
    "перекусав": ["перекусавши"],
    "перекусавши": ["перекусав"],
    "перекусив": ["перекусивши"],
    "перекусивши": ["перекусив"],
    "перекусывав": ["перекусывавши"],
    "перекусывавши": ["перекусывав"],
    "перекусывать": ["перегрызать"],
    "перекутав": ["перекутавши"],
    "перекутавши": ["перекутав"],
    "перекутывав": ["перекутывавши"],
    "перекутывавши": ["перекутывав"],
    "перекушав": ["перекушавши"],
    "перекушавши": ["перекушав"],
    "перелавливав": ["перелавливавши"],
    "перелавливавши": ["перелавливав"],
    "перелагав": ["перелагавши"],
    "перелагавши": ["перелагав"],
    "переладив": ["переладивши"],
    "переладивши": ["переладив"],
    "перелаживав": ["перелаживавши"],
    "перелаживавши": ["перелаживав"],
    "перелазав": ["перелазавши"],
    "перелазавши": ["перелазав"],
    "перелазив": ["перелазивши"],
    "перелазивши": ["перелазив"],
    "перелазить": ["перелезать"],
    "перелаивав": ["перелаивавши"],
    "перелаивавши": ["перелаивав"],
    "перелакировав": ["перелакировавши"],
    "перелакировавши": ["перелакировав"],
    "перелакировывав": ["перелакировывавши"],
    "перелакировывавши": ["перелакировывав"],
    "переламывав": ["переламывавши"],
    "переламывавши": ["переламывав"],
    "переласкав": ["переласкавши"],
    "переласкавши": ["переласкав"],
    "перелатав": ["перелатавши"],
    "перелатавши": ["перелатав"],
    "перелатывав": ["перелатывавши"],
    "перелатывавши": ["перелатывав"],
    "перелащивав": ["перелащивавши"],
    "перелащивавши": ["перелащивав"],
    "перелаяв": ["перелаявши"],
    "перелаявши": ["перелаяв"],
    "перелгав": ["перелгавши"],
    "перелгавши": ["перелгав"],
    "перележав": ["перележавши"],
    "перележавши": ["перележав"],
    "перелезав": ["перелезавши"],
    "перелезавши": ["перелезав"],
    "перелезать": ["перелазить", "переползать"],
    "перелезть": ["переползти"],
    "перелепив": ["перелепивши"],
    "перелепивши": ["перелепив"],
    "перелепливав": ["перелепливавши"],
    "перелепливавши": ["перелепливав"],
    "перелепливать": ["перелеплять"],
    "перелепляв": ["перелеплявши"],
    "перелеплявши": ["перелепляв"],
    "перелеска": ["печёночница", "подснежник"],
    "перелесок": ["перелесица", "перелесье", "поляна"],
    "перелетав": ["перелетавши"],
    "перелетавши": ["перелетав"],
    "перелетев": ["перелетевши"],
    "перелетевши": ["перелетев"],
    "перелетовав": ["перелетовавши"],
    "перелетовавши": ["перелетовав"],
    "перелечив": ["перелечивши"],
    "перелечивав": ["перелечивавши"],
    "перелечивавши": ["перелечивав"],
    "перелечивши": ["перелечив"],
    "переливав": ["переливавши"],
    "переливавши": ["переливав"],
    "переливание крови": ["гемотрансфузия", "трансфузия крови"],
    "переливать из пустого в порожнее": ["пустословить", "толочь воду в ступе", "носить воду решетом", "в лес дрова возить"],
    "переливаться": ["перетекать"],
    "переливистый": ["переливчатый"],
    "переливчато": ["радужно"],
    "переливши": ["перелив"],
    "перелизав": ["перелизавши"],
    "перелизавши": ["перелизав"],
    "перелизывав": ["перелизывавши"],
    "перелизывавши": ["перелизывав"],
    "перелинивав": ["перелинивавши"],
    "перелинивавши": ["перелинивав"],
    "перелиновав": ["перелиновавши"],
    "перелиновавши": ["перелиновав"],
    "перелиновывав": ["перелиновывавши"],
    "перелиновывавши": ["перелиновывав"],
    "перелиняв": ["перелинявши"],
    "перелинявши": ["перелиняв"],
    "перелистав": ["перелиставши"],
    "перелиставши": ["перелистав"],
    "перелистаться": ["пролистаться", "дочитаться", "прочитаться", "закончиться", "кончиться", "пройти", "пробежать", "пролететь", "промелькнуть", "миновать", "минуть"],
    "перелистнув": ["перелистнувши"],
    "перелистнувши": ["перелистнув"],
    "перелистнуть": ["листнуть"],
    "перелистовав": ["перелистовавши"],
    "перелистовавши": ["перелистовав"],
    "перелистывав": ["перелистывавши"],
    "перелистывавши": ["перелистывав"],
    "перелистывать": ["листать"],
    "перелитографировав": ["перелитографировавши"],
    "перелитографировавши": ["перелитографировав"],
    "перелицевав": ["перелицевавши"],
    "перелицевавши": ["перелицевав"],
    "перелицовывав": ["перелицовывавши"],
    "перелицовывавши": ["перелицовывав"],
    "перелицовывать": ["лицевать"],
    "перелобызав": ["перелобызавши"],
    "перелобызавши": ["перелобызав"],
    "переловив": ["переловивши"],
    "переловивши": ["переловив"],
    "переложенье": ["переложение"],
    "переложив": ["переложивши"],
    "переложивши": ["переложив"],
    "перелом": ["фрактура", "слом", "разлом", "излом", "поворот"],
    "переломав": ["переломавши"],
    "переломавши": ["переломав"],
    "переломив": ["переломивши"],
    "переломивши": ["переломив"],
    "перелопав": ["перелопавши"],
    "перелопавши": ["перелопав"],
    "перелопатив": ["перелопативши"],
    "перелопативши": ["перелопатив"],
    "перелопачивав": ["перелопачивавши"],
    "перелопачивавши": ["перелопачивав"],
    "перелопачивать": ["лопатить", "перевёртывать", "переворачивать", "перебрасывать", "просматривать", "переделывать"],
    "перелощив": ["перелощивши"],
    "перелощивши": ["перелощив"],
    "перелудив": ["перелудивши"],
    "перелудивши": ["перелудив"],
    "перелуживав": ["перелуживавши"],
    "перелуживавши": ["перелуживав"],
    "перелукавив": ["перелукавивши"],
    "перелукавивши": ["перелукавив"],
    "перелупив": ["перелупивши"],
    "перелупивши": ["перелупив"],
    "перелупливав": ["перелупливавши"],
    "перелупливавши": ["перелупливав"],
    "перелупцевав": ["перелупцевавши"],
    "перелупцевавши": ["перелупцевав"],
    "перелущив": ["перелущивши"],
    "перелущивав": ["перелущивавши"],
    "перелущивавши": ["перелущивав"],
    "перелущивши": ["перелущив"],
    "перелюбив": ["перелюбивши"],
    "перелюбивши": ["перелюбив"],
    "перелютовав": ["перелютовавши"],
    "перелютовавши": ["перелютовав"],
    "перелягав": ["перелягавши"],
    "перелягавши": ["перелягав"],
    "переляк": ["перепуг"],
    "перелёживав": ["перелёживавши"],
    "перелёживавши": ["перелёживав"],
    "перелётывав": ["перелётывавши"],
    "перелётывавши": ["перелётывав"],
    "перемагнитив": ["перемагнитивши"],
    "перемагнитивши": ["перемагнитив"],
    "перемагничивав": ["перемагничивавши"],
    "перемагничивавши": ["перемагничивав"],
    "перемазав": ["перемазавши"],
    "перемазавши": ["перемазав"],
    "перемазывав": ["перемазывавши"],
    "перемазывавши": ["перемазывав"],
    "перемалевав": ["перемалевавши"],
    "перемалевавши": ["перемалевав"],
    "перемалчивав": ["перемалчивавши"],
    "перемалчивавши": ["перемалчивав"],
    "перемалывав": ["перемалывавши"],
    "перемалывавши": ["перемалывав"],
    "перемалёвывав": ["перемалёвывавши"],
    "перемалёвывавши": ["перемалёвывав"],
    "переманив": ["переманивши"],
    "переманивав": ["переманивавши"],
    "переманивавши": ["переманивав"],
    "переманивши": ["переманив"],
    "переманув": ["переманувши"],
    "переманувши": ["переманув"],
    "перемарав": ["перемаравши"],
    "перемаравши": ["перемарав"],
    "перемаривав": ["перемаривавши"],
    "перемаривавши": ["перемаривав"],
    "перемарывав": ["перемарывавши"],
    "перемарывавши": ["перемарывав"],
    "перемаслив": ["перемасливши"],
    "перемасливав": ["перемасливавши"],
    "перемасливавши": ["перемасливав"],
    "перемасливши": ["перемаслив"],
    "перематывав": ["перематывавши"],
    "перематывавши": ["перематывав"],
    "перемах": ["перемахивание"],
    "перемахав": ["перемахавши"],
    "перемахавши": ["перемахав"],
    "перемахивав": ["перемахивавши"],
    "перемахивавши": ["перемахивав"],
    "перемахнув": ["перемахнувши"],
    "перемахнувши": ["перемахнув"],
    "перемачивав": ["перемачивавши"],
    "перемачивавши": ["перемачивав"],
    "перемащивав": ["перемащивавши"],
    "перемащивавши": ["перемащивав"],
    "перемаяв": ["перемаявши"],
    "перемаявши": ["перемаяв"],
    "перемежав": ["перемежавши"],
    "перемежавши": ["перемежав"],
    "перемежать": ["чередовать"],
    "перемежевав": ["перемежевавши"],
    "перемежевавши": ["перемежевав"],
    "перемежив": ["перемеживши"],
    "перемеживши": ["перемежив"],
    "перемежёвывав": ["перемежёвывавши"],
    "перемежёвывавши": ["перемежёвывав"],
    "перемельчив": ["перемельчивши"],
    "перемельчивши": ["перемельчив"],
    "перемена": ["изменение", "переменка", "блюдо"],
    "переменив": ["переменивши"],
    "переменивав": ["переменивавши"],
    "переменивавши": ["переменивав"],
    "переменивши": ["переменив"],
    "переменка": ["перемена", "изменение", "смена"],
    "переменный": ["непостоянный", "изменчивый"],
    "переменчивый": ["изменчивый", "непостоянный"],
    "переменяв": ["переменявши"],
    "переменявши": ["переменяв"],
    "переменять": ["менять", "заменять", "обменивать", "сменять", "замещать", "изменять", "модифицировать"],
    "перемерев": ["перемерши"],
    "перемереть": ["поперемереть"],
    "перемерзав": ["перемерзавши"],
    "перемерзавши": ["перемерзав"],
    "перемерив": ["перемеривши"],
    "перемеривав": ["перемеривавши"],
    "перемеривавши": ["перемеривав"],
    "перемеривши": ["перемерив"],
    "перемерши": ["перемерев"],
    "перемеряв": ["перемерявши"],
    "перемерявши": ["перемеряв"],
    "перемесив": ["перемесивши"],
    "перемесивши": ["перемесив"],
    "переместив": ["переместивши"],
    "переместивши": ["переместив"],
    "переместительность": ["коммутируемость", "коммутативность"],
    "переместительный": ["коммутативный"],
    "переместиться": ["передвинуться"],
    "переметав": ["переметавши"],
    "переметавши": ["переметав"],
    "переметив": ["переметивши"],
    "переметивши": ["переметив"],
    "переметнув": ["переметнувши"],
    "переметнувши": ["переметнув"],
    "перемечав": ["перемечавши"],
    "перемечавши": ["перемечав"],
    "перемечивав": ["перемечивавши"],
    "перемечивавши": ["перемечивав"],
    "перемешав": ["перемешавши"],
    "перемешавши": ["перемешав"],
    "перемешаться": ["смешаться", "спутаться", "перепутаться"],
    "перемешивав": ["перемешивавши"],
    "перемешивавши": ["перемешивав"],
    "перемешивать": ["мешать", "меськать"],
    "перемешивающий": ["смешивающий"],
    "перемешкав": ["перемешкавши"],
    "перемешкавши": ["перемешкав"],
    "перемешкивав": ["перемешкивавши"],
    "перемешкивавши": ["перемешкивав"],
    "перемещав": ["перемещавши"],
    "перемещавши": ["перемещав"],
    "перемещать": ["двигать"],
    "перемещаться": ["двигаться", "передвигаться"],
    "перемещение": ["передвижение", "перестановка", "движение", "сдвиг", "изменение"],
    "перемещенье": ["перемещение"],
    "перемещённое лицо": ["беженец"],
    "перемещённый": ["передвинутый"],
    "перемигиванье": ["перемигивание"],
    "перемиловав": ["перемиловавши"],
    "перемиловавши": ["перемиловав"],
    "переминав": ["переминавши"],
    "переминавши": ["переминав"],
    "переминировав": ["переминировавши"],
    "переминировавши": ["переминировав"],
    "перемирав": ["перемиравши"],
    "перемиравши": ["перемирав"],
    "перемирив": ["перемиривши"],
    "перемиривши": ["перемирив"],
    "перемкнув": ["перемкнувши"],
    "перемкнувши": ["перемкнув"],
    "перемножав": ["перемножавши"],
    "перемножавши": ["перемножав"],
    "перемножать": ["умножать", "множить"],
    "перемножив": ["перемноживши"],
    "перемноживши": ["перемножив"],
    "перемогав": ["перемогавши"],
    "перемогавши": ["перемогав"],
    "перемодничав": ["перемодничавши"],
    "перемодничавши": ["перемодничав"],
    "перемокав": ["перемокавши"],
    "перемокавши": ["перемокав"],
    "перемокнув": ["перемокнувши"],
    "перемокнувши": ["перемокнув"],
    "перемолачивав": ["перемолачивавши"],
    "перемолачивавши": ["перемолачивав"],
    "перемолвив": ["перемолвивши"],
    "перемолвивши": ["перемолвив"],
    "перемолив": ["перемоливши"],
    "перемоливши": ["перемолив"],
    "перемолов": ["перемоловши"],
    "перемоловши": ["перемолов"],
    "перемолотив": ["перемолотивши"],
    "перемолотивши": ["перемолотив"],
    "перемолчав": ["перемолчавши"],
    "перемолчавши": ["перемолчав"],
    "перемонтировав": ["перемонтировавши"],
    "перемонтировавши": ["перемонтировав"],
    "перемораживав": ["перемораживавши"],
    "перемораживавши": ["перемораживав"],
    "переморив": ["переморивши"],
    "переморивши": ["переморив"],
    "переморозив": ["переморозивши"],
    "переморозивши": ["переморозив"],
    "перемостив": ["перемостивши"],
    "перемостивши": ["перемостив"],
    "перемотав": ["перемотавши"],
    "перемотавши": ["перемотав"],
    "перемотоблочив": ["перемотоблочивши"],
    "перемотоблочивши": ["перемотоблочив"],
    "перемочив": ["перемочивши"],
    "перемочивши": ["перемочив"],
    "перемочь": ["превозмочь", "одолеть", "победить", "пересилить"],
    "перемудрив": ["перемудривши"],
    "перемудривши": ["перемудрив"],
    "перемудрить": ["переусложнить"],
    "перемуравив": ["перемуравивши"],
    "перемуравивши": ["перемуравив"],
    "перемуравливав": ["перемуравливавши"],
    "перемуравливавши": ["перемуравливав"],
    "перемуслив": ["перемусливши"],
    "перемусливав": ["перемусливавши"],
    "перемусливавши": ["перемусливав"],
    "перемусливши": ["перемуслив"],
    "перемусолив": ["перемусоливши"],
    "перемусоливав": ["перемусоливавши"],
    "перемусоливавши": ["перемусоливав"],
    "перемусоливши": ["перемусолив"],
    "перемутив": ["перемутивши"],
    "перемутивши": ["перемутив"],
    "перемучав": ["перемучавши"],
    "перемучавши": ["перемучав"],
    "перемучив": ["перемучивши"],
    "перемучивав": ["перемучивавши"],
    "перемучивавши": ["перемучивав"],
    "перемучивши": ["перемучив"],
    "перемчав": ["перемчавши"],
    "перемчавши": ["перемчав"],
    "перемшив": ["перемшивши"],
    "перемшивши": ["перемшив"],
    "перемыв": ["перемывши"],
    "перемывав": ["перемывавши"],
    "перемывавши": ["перемывав"],
    "перемывать косточки": ["костить", "костерить", "мыть кости", "кости мыть"],
    "перемывши": ["перемыв"],
    "перемызгав": ["перемызгавши"],
    "перемызгавши": ["перемызгав"],
    "перемыкав": ["перемыкавши"],
    "перемыкавши": ["перемыкав"],
    "перемылив": ["перемыливши"],
    "перемыливав": ["перемыливавши"],
    "перемыливавши": ["перемыливав"],
    "перемыливши": ["перемылив"],
    "перемяв": ["перемявши"],
    "перемявши": ["перемяв"],
    "перемякнув": ["перемякнувши"],
    "перемякнувши": ["перемякнув"],
    "перемёрзнув": ["перемёрзнувши"],
    "перемёрзнувши": ["перемёрзнув"],
    "перемётывав": ["перемётывавши"],
    "перемётывавши": ["перемётывав"],
    "перенабирав": ["перенабиравши"],
    "перенабиравши": ["перенабирав"],
    "перенабрав": ["перенабравши"],
    "перенабравши": ["перенабрав"],
    "переназначав": ["переназначавши"],
    "переназначавши": ["переназначав"],
    "переназначив": ["переназначивши"],
    "переназначивши": ["переназначив"],
    "переналадив": ["переналадивши"],
    "переналадивши": ["переналадив"],
    "переналаживав": ["переналаживавши"],
    "переналаживавши": ["переналаживав"],
    "перенаполнив": ["перенаполнивши"],
    "перенаполнивши": ["перенаполнив"],
    "перенаполняв": ["перенаполнявши"],
    "перенаполнявши": ["перенаполняв"],
    "перенаправив": ["перенаправивши"],
    "перенаправивши": ["перенаправив"],
    "перенаправить": ["переадресовать"],
    "перенаправление": ["переадресация", "страница-перенаправление", "редирект"],
    "перенаправляв": ["перенаправлявши"],
    "перенаправлявши": ["перенаправляв"],
    "перенапрягав": ["перенапрягавши"],
    "перенапрягавши": ["перенапрягав"],
    "перенапряженье": ["перенапряжение"],
    "перенаряжав": ["перенаряжавши"],
    "перенаряжавши": ["перенаряжав"],
    "перенаселив": ["перенаселивши"],
    "перенаселивши": ["перенаселив"],
    "перенаселить": ["перезаселить"],
    "перенаселяв": ["перенаселявши"],
    "перенаселявши": ["перенаселяв"],
    "перенастраивав": ["перенастраивавши"],
    "перенастраивавши": ["перенастраивав"],
    "перенастроив": ["перенастроивши"],
    "перенастроивши": ["перенастроив"],
    "перенастроить": ["переналадить"],
    "перенасытив": ["перенасытивши"],
    "перенасытивши": ["перенасытив"],
    "перенасыщав": ["перенасыщавши"],
    "перенасыщавши": ["перенасыщав"],
    "перенацелив": ["перенацеливши"],
    "перенацеливав": ["перенацеливавши"],
    "перенацеливавши": ["перенацеливав"],
    "перенацеливши": ["перенацелив"],
    "перенашивав": ["перенашивавши"],
    "перенашивавши": ["перенашивав"],
    "перенервничав": ["перенервничавши"],
    "перенервничавши": ["перенервничав"],
    "перенесенье": ["перенесение"],
    "перенести": ["спроецировать", "вынести", "вытерпеть"],
    "перенизав": ["перенизавши"],
    "перенизавши": ["перенизав"],
    "перенизывав": ["перенизывавши"],
    "перенизывавши": ["перенизывав"],
    "перенимав": ["перенимавши"],
    "перенимавши": ["перенимав"],
    "перенимать": ["перехватывать", "заимствовать"],
    "переномеровав": ["переномеровавши"],
    "переномеровавши": ["переномеровав"],
    "переномеровывав": ["переномеровывавши"],
    "переномеровывавши": ["переномеровывав"],
    "перенормировать": ["ренормировать"],
    "перенос": ["перемещение", "перекладывание", "перевод", "слогоделение", "разбиение", "трансфер"],
    "переносив": ["переносивши"],
    "переносивши": ["переносив"],
    "переносимость": ["выносливость", "портируемость"],
    "переносица": ["переносье"],
    "переносной": ["переносный", "портативный", "мобильный", "транспортируемый"],
    "переносной зенитный ракетный комплекс": ["пзрк"],
    "переносный": ["метафорический", "передвижной", "переносной", "нестационарный", "транспортабельный", "сносный"],
    "переночевав": ["переночевавши"],
    "переночевавши": ["переночевав"],
    "переночевать": ["проспать", "заночевать"],
    "переночёвывав": ["переночёвывавши"],
    "переночёвывавши": ["переночёвывав"],
    "перенумеровав": ["перенумеровавши"],
    "перенумеровавши": ["перенумеровав"],
    "перенумеровывав": ["перенумеровывавши"],
    "перенумеровывавши": ["перенумеровывав"],
    "перенюхав": ["перенюхавши"],
    "перенюхавши": ["перенюхав"],
    "перенюхивав": ["перенюхивавши"],
    "перенюхивавши": ["перенюхивав"],
    "переняв": ["перенявши"],
    "перенявши": ["переняв"],
    "переобезьянив": ["переобезьянивши"],
    "переобезьянивши": ["переобезьянив"],
    "переоблачав": ["переоблачавши"],
    "переоблачавши": ["переоблачав"],
    "переоблачив": ["переоблачивши"],
    "переоблачивши": ["переоблачив"],
    "переоблучав": ["переоблучавши"],
    "переоблучавши": ["переоблучав"],
    "переоблучив": ["переоблучивши"],
    "переоблучивши": ["переоблучив"],
    "переобмундировав": ["переобмундировавши"],
    "переобмундировавши": ["переобмундировав"],
    "переобмундировывав": ["переобмундировывавши"],
    "переобмундировывавши": ["переобмундировывав"],
    "переобнимав": ["переобнимавши"],
    "переобнимавши": ["переобнимав"],
    "переобняв": ["переобнявши"],
    "переобнявши": ["переобняв"],
    "переоборудовав": ["переоборудовавши"],
    "переоборудовавши": ["переоборудовав"],
    "переоборудование": ["переоснащение", "переделка", "переделывание", "переснаряжение"],
    "переобразовав": ["переобразовавши"],
    "переобразовавши": ["переобразовав"],
    "переобразовывав": ["переобразовывавши"],
    "переобразовывавши": ["переобразовывав"],
    "переобременив": ["переобременивши"],
    "переобременивши": ["переобременив"],
    "переобременяв": ["переобременявши"],
    "переобременявши": ["переобременяв"],
    "переобсудив": ["переобсудивши"],
    "переобсудивши": ["переобсудив"],
    "переобсуждав": ["переобсуждавши"],
    "переобсуждавши": ["переобсуждав"],
    "переобув": ["переобувши"],
    "переобував": ["переобувавши"],
    "переобувавши": ["переобував"],
    "переобуваться в воздухе": ["переобуваться в полёте", "переобуваться в прыжке", "переобуваться на лету", "переобуваться на ходу"],
    "переобувши": ["переобув"],
    "переобучав": ["переобучавши"],
    "переобучавши": ["переобучав"],
    "переобучив": ["переобучивши"],
    "переобучивши": ["переобучив"],
    "переодев": ["переодевши"],
    "переодевав": ["переодевавши"],
    "переодевавши": ["переодевав"],
    "переодеванье": ["переодевание"],
    "переодевши": ["переодев"],
    "переозвучив": ["переозвучивши"],
    "переозвучивав": ["переозвучивавши"],
    "переозвучивавши": ["переозвучивав"],
    "переозвучивши": ["переозвучив"],
    "переозвучка": ["переозвучание"],
    "переопределив": ["переопределивши"],
    "переопределивши": ["переопределив"],
    "переопределяв": ["переопределявши"],
    "переопределявши": ["переопределяв"],
    "переопылив": ["переопыливши"],
    "переопыливши": ["переопылив"],
    "переопыляв": ["переопылявши"],
    "переопылявши": ["переопыляв"],
    "переорав": ["переоравши"],
    "переоравши": ["переорав"],
    "переорганизовав": ["переорганизовавши"],
    "переорганизовавши": ["переорганизовав"],
    "переорганизовывав": ["переорганизовывавши"],
    "переорганизовывавши": ["переорганизовывав"],
    "переориентировав": ["переориентировавши"],
    "переориентировавши": ["переориентировав"],
    "переориентирование": ["переориентировка"],
    "переориентировка": ["переориентирование"],
    "переоркестровав": ["переоркестровавши"],
    "переоркестровавши": ["переоркестровав"],
    "переоркестровывав": ["переоркестровывавши"],
    "переоркестровывавши": ["переоркестровывав"],
    "переосвидетельствовав": ["переосвидетельствовавши"],
    "переосвидетельствовавши": ["переосвидетельствовав"],
    "переосвятив": ["переосвятивши"],
    "переосвятивши": ["переосвятив"],
    "переосмысленный": ["пересмотренный"],
    "переосмыслив": ["переосмысливши"],
    "переосмысливав": ["переосмысливавши"],
    "переосмысливавши": ["переосмысливав"],
    "переосмысливание": ["переосмысление"],
    "переосмысливать": ["переосмыслять"],
    "переосмысливши": ["переосмыслив"],
    "переосмысляв": ["переосмыслявши"],
    "переосмыслявши": ["переосмысляв"],
    "переосмыслять": ["переосмысливать"],
    "переоснастив": ["переоснастивши"],
    "переоснастивши": ["переоснастив"],
    "переоснастка": ["переоснащение"],
    "переоснащав": ["переоснащавши"],
    "переоснащавши": ["переоснащав"],
    "переоснащение": ["переоснастка"],
    "переосторожничав": ["переосторожничавши"],
    "переосторожничавши": ["переосторожничав"],
    "переоткрыв": ["переоткрывши"],
    "переоткрывав": ["переоткрывавши"],
    "переоткрывавши": ["переоткрывав"],
    "переоткрывши": ["переоткрыв"],
    "переотравив": ["переотравивши"],
    "переотравивши": ["переотравив"],
    "переотравляв": ["переотравлявши"],
    "переотравлявши": ["переотравляв"],
    "переоформив": ["переоформивши"],
    "переоформивши": ["переоформив"],
    "переоформляв": ["переоформлявши"],
    "переоформлявши": ["переоформляв"],
    "переохладив": ["переохладивши"],
    "переохладивши": ["переохладив"],
    "переохладиться": ["перестудиться", "перестыть"],
    "переохлаждав": ["переохлаждавши"],
    "переохлаждавши": ["переохлаждав"],
    "переоценив": ["переоценивши"],
    "переоценивав": ["переоценивавши"],
    "переоценивавши": ["переоценивав"],
    "переоценивать": ["преувеличивать"],
    "переоценивши": ["переоценив"],
    "переоценка": ["переоценивание"],
    "перепад": ["водопад"],
    "перепадав": ["перепадавши"],
    "перепадавши": ["перепадав"],
    "перепадающий": ["выпадающий", "достающийся"],
    "перепаивав": ["перепаивавши"],
    "перепаивавши": ["перепаивав"],
    "перепаковав": ["перепаковавши"],
    "перепаковавши": ["перепаковав"],
    "перепаковывав": ["перепаковывавши"],
    "перепаковывавши": ["перепаковывав"],
    "перепакостив": ["перепакостивши"],
    "перепакостивши": ["перепакостив"],
    "перепалзывав": ["перепалзывавши"],
    "перепалзывавши": ["перепалзывав"],
    "перепалив": ["перепаливши"],
    "перепаливав": ["перепаливавши"],
    "перепаливавши": ["перепаливав"],
    "перепаливши": ["перепалив"],
    "перепалка": ["перебранка"],
    "перепалывав": ["перепалывавши"],
    "перепалывавши": ["перепалывав"],
    "перепарив": ["перепаривши"],
    "перепаривав": ["перепаривавши"],
    "перепаривавши": ["перепаривав"],
    "перепаривши": ["перепарив"],
    "перепарковав": ["перепарковавши"],
    "перепарковавши": ["перепарковав"],
    "перепарковывав": ["перепарковывавши"],
    "перепарковывавши": ["перепарковывав"],
    "перепародировав": ["перепародировавши"],
    "перепародировавши": ["перепародировав"],
    "перепархивав": ["перепархивавши"],
    "перепархивавши": ["перепархивав"],
    "перепарывав": ["перепарывавши"],
    "перепарывавши": ["перепарывав"],
    "перепас": ["перепасовка"],
    "перепасовав": ["перепасовавши"],
    "перепасовавши": ["перепасовав"],
    "перепасовка": ["перепас"],
    "перепасовывав": ["перепасовывавши"],
    "перепасовывавши": ["перепасовывав"],
    "перепахав": ["перепахавши"],
    "перепахавши": ["перепахав"],
    "перепахивав": ["перепахивавши"],
    "перепахивавши": ["перепахивав"],
    "перепачкав": ["перепачкавши"],
    "перепачкавши": ["перепачкав"],
    "перепачкивав": ["перепачкивавши"],
    "перепачкивавши": ["перепачкивав"],
    "перепаяв": ["перепаявши"],
    "перепаявши": ["перепаяв"],
    "перепевав": ["перепевавши"],
    "перепевавши": ["перепевав"],
    "перепеваться": ["переговариваться"],
    "перепевка": ["кавер", "кавер-версия", "перепев"],
    "перепевши": ["перепев"],
    "перепекав": ["перепекавши"],
    "перепекавши": ["перепекав"],
    "перепел": ["пелепел", "перепелятина"],
    "перепеленав": ["перепеленавши"],
    "перепеленавши": ["перепеленав"],
    "перепелесый": ["пёстрый"],
    "перепелятник": ["ястреб-перепелятник"],
    "перепелёнывав": ["перепелёнывавши"],
    "перепелёнывавши": ["перепелёнывав"],
    "переперев": ["перепёрши"],
    "переперчив": ["переперчивши"],
    "переперчивав": ["переперчивавши"],
    "переперчивавши": ["переперчивав"],
    "переперчивши": ["переперчив"],
    "перепестрив": ["перепестривши"],
    "перепестривши": ["перепестрив"],
    "перепеча": ["шаньга"],
    "перепечатав": ["перепечатавши"],
    "перепечатавши": ["перепечатав"],
    "перепечатывав": ["перепечатывавши"],
    "перепечатывавши": ["перепечатывав"],
    "перепив": ["перепивши"],
    "перепивав": ["перепивавши"],
    "перепивавши": ["перепивав"],
    "перепивши": ["перепив"],
    "перепиздев": ["перепиздевши"],
    "перепиздевши": ["перепиздев"],
    "перепилив": ["перепиливши"],
    "перепиливав": ["перепиливавши"],
    "перепиливавши": ["перепиливав"],
    "перепиливши": ["перепилив"],
    "перепирав": ["перепиравши"],
    "перепиравши": ["перепирав"],
    "переписав": ["переписавши"],
    "переписавши": ["переписав"],
    "переписка": ["корреспонденция", "переписывание", "копирование", "списывание"],
    "переписчик": ["счётчик"],
    "переписывав": ["переписывавши"],
    "переписывавши": ["переписывав"],
    "переписыванье": ["переписывание"],
    "переписывать": ["списывать"],
    "перепихав": ["перепихавши"],
    "перепихавши": ["перепихав"],
    "перепихивав": ["перепихивавши"],
    "перепихивавши": ["перепихивав"],
    "перепихнув": ["перепихнувши"],
    "перепихнувши": ["перепихнув"],
    "перепихнуться": ["потрахаться", "совокупиться"],
    "перепихон": ["потрахушки"],
    "переплав": ["переплавка"],
    "переплавав": ["переплававши"],
    "переплававши": ["переплавав"],
    "переплавив": ["переплавивши"],
    "переплавивши": ["переплавив"],
    "переплавка": ["переплав"],
    "переплавление": ["переплав", "переплавка"],
    "переплавляв": ["переплавлявши"],
    "переплавлявши": ["переплавляв"],
    "переплакав": ["переплакавши"],
    "переплакавши": ["переплакав"],
    "перепланировав": ["перепланировавши"],
    "перепланировавши": ["перепланировав"],
    "перепланировка": ["перепланирование"],
    "перепланировывав": ["перепланировывавши"],
    "перепланировывавши": ["перепланировывав"],
    "перепластав": ["перепластавши"],
    "перепластавши": ["перепластав"],
    "перепластывав": ["перепластывавши"],
    "перепластывавши": ["перепластывав"],
    "переплатив": ["переплативши"],
    "переплативши": ["переплатив"],
    "переплачивав": ["переплачивавши"],
    "переплачивавши": ["переплачивав"],
    "переплевав": ["переплевавши"],
    "переплевавши": ["переплевав"],
    "переплескав": ["переплескавши"],
    "переплескавши": ["переплескав"],
    "переплеснув": ["переплеснувши"],
    "переплеснувши": ["переплеснув"],
    "переплетав": ["переплетавши"],
    "переплетавши": ["переплетав"],
    "переплетаться": ["сплетаться", "свиваться"],
    "переплетение": ["переплетенье"],
    "переплетенье": ["переплетение"],
    "переплетённый": ["сплетённый"],
    "переплотив": ["переплотивши"],
    "переплотивши": ["переплотив"],
    "переплочивав": ["переплочивавши"],
    "переплочивавши": ["переплочивав"],
    "переплутовав": ["переплутовавши"],
    "переплутовавши": ["переплутовав"],
    "переплыв": ["переплывши"],
    "переплывав": ["переплывавши"],
    "переплывавши": ["переплывав"],
    "переплывши": ["переплыв"],
    "переплюнув": ["переплюнувши"],
    "переплюнувши": ["переплюнув"],
    "переплюснув": ["переплюснувши"],
    "переплюснувши": ["переплюснув"],
    "переплющив": ["переплющивши"],
    "переплющивши": ["переплющив"],
    "переплясав": ["переплясавши"],
    "переплясавши": ["переплясав"],
    "переплясывав": ["переплясывавши"],
    "переплясывавши": ["переплясывав"],
    "переплёвывав": ["переплёвывавши"],
    "переплёвывавши": ["переплёвывав"],
    "переплёскивав": ["переплёскивавши"],
    "переплёскивавши": ["переплёскивав"],
    "перепоганив": ["перепоганивши"],
    "перепоганивав": ["перепоганивавши"],
    "перепоганивавши": ["перепоганивав"],
    "перепоганивши": ["перепоганив"],
    "переподав": ["переподавши"],
    "переподавав": ["переподававши"],
    "переподававши": ["переподавав"],
    "переподавши": ["переподав"],
    "переподвыподверт": ["подвыподверт"],
    "переподготавливав": ["переподготавливавши"],
    "переподготавливавши": ["переподготавливав"],
    "переподготавливать": ["переподготовлять"],
    "переподготавливаться": ["переподготовляться"],
    "переподготовив": ["переподготовивши"],
    "переподготовивши": ["переподготовив"],
    "переподготовляв": ["переподготовлявши"],
    "переподготовлявши": ["переподготовляв"],
    "переподготовлять": ["переподготавливать"],
    "переподключав": ["переподключавши"],
    "переподключавши": ["переподключав"],
    "переподписав": ["переподписавши"],
    "переподписавши": ["переподписав"],
    "переподписывав": ["переподписывавши"],
    "переподписывавши": ["переподписывав"],
    "переподчинив": ["переподчинивши"],
    "переподчинивши": ["переподчинив"],
    "переподчиняв": ["переподчинявши"],
    "переподчинявши": ["переподчиняв"],
    "перепозиционировав": ["перепозиционировавши"],
    "перепозиционировавши": ["перепозиционировав"],
    "перепоив": ["перепоивши"],
    "перепоивши": ["перепоив"],
    "переполаскивав": ["переполаскивавши"],
    "переполаскивавши": ["переполаскивав"],
    "переползав": ["переползавши"],
    "переползавши": ["переползав"],
    "переползти": ["отползти", "уползти"],
    "переполнив": ["переполнивши"],
    "переполнивши": ["переполнив"],
    "переполняв": ["переполнявши"],
    "переполнявши": ["переполняв"],
    "переполов": ["переполовши"],
    "переполовинив": ["переполовинивши"],
    "переполовинивав": ["переполовинивавши"],
    "переполовинивавши": ["переполовинивав"],
    "переполовинивши": ["переполовинив"],
    "переполовши": ["переполов"],
    "переполоскав": ["переполоскавши"],
    "переполоскавши": ["переполоскав"],
    "переполосовав": ["переполосовавши"],
    "переполосовавши": ["переполосовав"],
    "переполосовывав": ["переполосовывавши"],
    "переполосовывавши": ["переполосовывав"],
    "переполошив": ["переполошивши"],
    "переполошивши": ["переполошив"],
    "перепоров": ["перепоровши"],
    "перепоровши": ["перепоров"],
    "перепортив": ["перепортивши"],
    "перепортивши": ["перепортив"],
    "перепоручав": ["перепоручавши"],
    "перепоручавши": ["перепоручав"],
    "перепоручив": ["перепоручивши"],
    "перепоручивши": ["перепоручив"],
    "перепорхнув": ["перепорхнувши"],
    "перепорхнувши": ["перепорхнув"],
    "перепосвятив": ["перепосвятивши"],
    "перепосвятивши": ["перепосвятив"],
    "перепост": ["репост"],
    "перепостив": ["перепостивши"],
    "перепостивши": ["перепостив"],
    "перепотев": ["перепотевши"],
    "перепотевши": ["перепотев"],
    "перепотрошив": ["перепотрошивши"],
    "перепотрошивши": ["перепотрошив"],
    "перепоясав": ["перепоясавши"],
    "перепоясавши": ["перепоясав"],
    "перепоясывав": ["перепоясывавши"],
    "перепоясывавши": ["перепоясывав"],
    "переправив": ["переправивши"],
    "переправивши": ["переправив"],
    "переправляв": ["переправлявши"],
    "переправлявши": ["переправляв"],
    "перепрашивав": ["перепрашивавши"],
    "перепрашивавши": ["перепрашивав"],
    "перепрев": ["перепревши"],
    "перепревав": ["перепревавши"],
    "перепревавши": ["перепревав"],
    "перепревши": ["перепрев"],
    "переприватизировав": ["переприватизировавши"],
    "переприватизировавши": ["переприватизировав"],
    "перепривив": ["перепрививши"],
    "перепрививав": ["перепрививавши"],
    "перепрививавши": ["перепрививав"],
    "перепрививши": ["перепривив"],
    "перепридумав": ["перепридумавши"],
    "перепридумавши": ["перепридумав"],
    "перепридумывав": ["перепридумывавши"],
    "перепридумывавши": ["перепридумывав"],
    "перепробег": ["износ"],
    "перепробовав": ["перепробовавши"],
    "перепробовавши": ["перепробовав"],
    "перепроверив": ["перепроверивши"],
    "перепроверивши": ["перепроверив"],
    "перепроверяв": ["перепроверявши"],
    "перепроверявши": ["перепроверяв"],
    "перепрограммировав": ["перепрограммировавши"],
    "перепрограммировавши": ["перепрограммировав"],
    "перепродав": ["перепродавши"],
    "перепродавав": ["перепродававши"],
    "перепродававши": ["перепродавав"],
    "перепродавши": ["перепродав"],
    "перепроектировав": ["перепроектировавши"],
    "перепроектировавши": ["перепроектировав"],
    "перепроизводив": ["перепроизводивши"],
    "перепроизводивши": ["перепроизводив"],
    "перепрокидывав": ["перепрокидывавши"],
    "перепрокидывавши": ["перепрокидывав"],
    "перепрокинув": ["перепрокинувши"],
    "перепрокинувши": ["перепрокинув"],
    "перепрописав": ["перепрописавши"],
    "перепрописавши": ["перепрописав"],
    "перепросив": ["перепросивши"],
    "перепросивши": ["перепросив"],
    "перепрофилировав": ["перепрофилировавши"],
    "перепрофилировавши": ["перепрофилировав"],
    "перепрошивка": ["перепрограммирование", "переустановка"],
    "перепрудив": ["перепрудивши"],
    "перепрудивши": ["перепрудив"],
    "перепруживав": ["перепруживавши"],
    "перепруживавши": ["перепруживав"],
    "перепрыгав": ["перепрыгавши"],
    "перепрыгавши": ["перепрыгав"],
    "перепрыгивав": ["перепрыгивавши"],
    "перепрыгивавши": ["перепрыгивав"],
    "перепрыгивать": ["перескакивать"],
    "перепрыгнув": ["перепрыгнувши"],
    "перепрыгнувши": ["перепрыгнув"],
    "перепрыгнуть": ["перескочить", "перепрыгать"],
    "перепрыскав": ["перепрыскавши"],
    "перепрыскавши": ["перепрыскав"],
    "перепрыскивав": ["перепрыскивавши"],
    "перепрыскивавши": ["перепрыскивав"],
    "перепрыснув": ["перепрыснувши"],
    "перепрыснувши": ["перепрыснув"],
    "перепрядав": ["перепрядавши"],
    "перепрядавши": ["перепрядав"],
    "перепрядывав": ["перепрядывавши"],
    "перепрядывавши": ["перепрядывав"],
    "перепрянув": ["перепрянувши"],
    "перепрянувши": ["перепрянув"],
    "перепрятав": ["перепрятавши"],
    "перепрятавши": ["перепрятав"],
    "перепрятывав": ["перепрятывавши"],
    "перепрятывавши": ["перепрятывав"],
    "перепсиховав": ["перепсиховавши"],
    "перепсиховавши": ["перепсиховав"],
    "перепугав": ["перепугавши"],
    "перепугавши": ["перепугав"],
    "перепугаться": ["испугаться", "напугаться"],
    "перепугивав": ["перепугивавши"],
    "перепугивавши": ["перепугивав"],
    "перепудрив": ["перепудривши"],
    "перепудривав": ["перепудривавши"],
    "перепудривавши": ["перепудривав"],
    "перепудривши": ["перепудрив"],
    "перепужав": ["перепужавши"],
    "перепужавши": ["перепужав"],
    "перепускав": ["перепускавши"],
    "перепускавши": ["перепускав"],
    "перепустив": ["перепустивши"],
    "перепустивши": ["перепустив"],
    "перепутав": ["перепутавши"],
    "перепутавши": ["перепутав"],
    "перепутать": ["обознаться", "промахнуться", "ошибиться", "перемешать", "перетасовать", "спутать"],
    "перепутаться": ["смешаться"],
    "перепутывав": ["перепутывавши"],
    "перепутывавши": ["перепутывав"],
    "перепутье": ["распутье"],
    "перепылив": ["перепыливши"],
    "перепыливши": ["перепылив"],
    "перепытав": ["перепытавши"],
    "перепытавши": ["перепытав"],
    "перепёлочка": ["перепёлка"],
    "перепёрши": ["переперев"],
    "перерабатывав": ["перерабатывавши"],
    "перерабатывавши": ["перерабатывав"],
    "переработав": ["переработавши"],
    "переработавши": ["переработав"],
    "переработка": ["перерабатывание", "кранч"],
    "переразвив": ["переразвивши"],
    "переразвивав": ["переразвивавши"],
    "переразвивавши": ["переразвивав"],
    "переразвивши": ["переразвив"],
    "переразложение": ["деглютинация", "метанализ", "абсорбция"],
    "переразряд": ["глубокий разряд"],
    "переранив": ["переранивши"],
    "переранивши": ["переранив"],
    "перераспределенческий": ["перераспределительный"],
    "перераспределив": ["перераспределивши"],
    "перераспределивши": ["перераспределив"],
    "перераспределительный": ["перераспределенческий"],
    "перераспределяв": ["перераспределявши"],
    "перераспределявши": ["перераспределяв"],
    "перерасследовав": ["перерасследовавши"],
    "перерасследовавши": ["перерасследовав"],
    "перерассчитав": ["перерассчитавши"],
    "перерассчитавши": ["перерассчитав"],
    "перерассчитывав": ["перерассчитывавши"],
    "перерассчитывавши": ["перерассчитывав"],
    "перерастав": ["перераставши"],
    "перераставши": ["перерастав"],
    "перерастать": ["опережать", "превосходить", "преобразовываться", "трансформироваться"],
    "перерастянув": ["перерастянувши"],
    "перерастянувши": ["перерастянув"],
    "перерасходовав": ["перерасходовавши"],
    "перерасходовавши": ["перерасходовав"],
    "перервав": ["перервавши"],
    "перервавши": ["перервав"],
    "перерегистрировав": ["перерегистрировавши"],
    "перерегистрировавши": ["перерегистрировав"],
    "перередактировав": ["перередактировавши"],
    "перередактировавши": ["перередактировав"],
    "перерезав": ["перерезавши"],
    "перерезавши": ["перерезав"],
    "перерезать": ["разрезать", "порезать", "зарезать", "преградить", "разобщить", "избороздить"],
    "перерезывав": ["перерезывавши"],
    "перерезывавши": ["перерезывав"],
    "перерезывать": ["перерезать"],
    "перерешав": ["перерешавши"],
    "перерешавши": ["перерешав"],
    "перерешив": ["перерешивши"],
    "перерешивав": ["перерешивавши"],
    "перерешивавши": ["перерешивав"],
    "перерешивши": ["перерешив"],
    "перержавев": ["перержавевши"],
    "перержавевши": ["перержавев"],
    "перерисовав": ["перерисовавши"],
    "перерисовавши": ["перерисовав"],
    "перерисовать": ["срисовать"],
    "перерисовывав": ["перерисовывавши"],
    "перерисовывавши": ["перерисовывав"],
    "переродив": ["переродивши"],
    "переродивши": ["переродив"],
    "переродиться": ["измениться", "преобразоваться"],
    "перерожав": ["перерожавши"],
    "перерожавши": ["перерожав"],
    "перерождав": ["перерождавши"],
    "перерождавши": ["перерождав"],
    "переруб": ["перерубание"],
    "перерубав": ["перерубавши"],
    "перерубавши": ["перерубав"],
    "перерубив": ["перерубивши"],
    "перерубивши": ["перерубив"],
    "переругав": ["переругавши"],
    "переругавши": ["переругав"],
    "переругаться": ["перессориться", "пересраться"],
    "переругивав": ["переругивавши"],
    "переругивавши": ["переругивав"],
    "переругивание": ["перебранка", "пререкания", "перепалка"],
    "перерумянив": ["перерумянивши"],
    "перерумянивав": ["перерумянивавши"],
    "перерумянивавши": ["перерумянивав"],
    "перерумянивши": ["перерумянив"],
    "перерыв": ["пауза"],
    "перерывав": ["перерывавши"],
    "перерывавши": ["перерывав"],
    "перерывши": ["перерыв"],
    "перерыхлив": ["перерыхливши"],
    "перерыхливши": ["перерыхлив"],
    "перерыхляв": ["перерыхлявши"],
    "перерыхлявши": ["перерыхляв"],
    "перерядив": ["перерядивши"],
    "перерядивши": ["перерядив"],
    "переряжав": ["переряжавши"],
    "переряжавши": ["переряжав"],
    "переряжать": ["переодевать", "перенаряжать"],
    "переряживав": ["переряживавши"],
    "переряживавши": ["переряживав"],
    "переряживание": ["переоблачение", "переодевание"],
    "переряживанье": ["переряживание"],
    "переряживать": ["переряжать", "переодевать", "переоблачать"],
    "переряживаться": ["переодеваться"],
    "пересадив": ["пересадивши"],
    "пересадивши": ["пересадив"],
    "пересадка": ["пересаживание", "трансплантация"],
    "пересажав": ["пересажавши"],
    "пересажавши": ["пересажав"],
    "пересаживав": ["пересаживавши"],
    "пересаживавши": ["пересаживав"],
    "пересалив": ["пересаливши"],
    "пересаливав": ["пересаливавши"],
    "пересаливавши": ["пересаливав"],
    "пересаливши": ["пересалив"],
    "пересалить": ["перепачкать", "перемарать"],
    "пересасывав": ["пересасывавши"],
    "пересасывавши": ["пересасывав"],
    "пересахарив": ["пересахаривши"],
    "пересахаривав": ["пересахаривавши"],
    "пересахаривавши": ["пересахаривав"],
    "пересахаривши": ["пересахарив"],
    "пересбрасывав": ["пересбрасывавши"],
    "пересбрасывавши": ["пересбрасывав"],
    "пересбросив": ["пересбросивши"],
    "пересбросивши": ["пересбросив"],
    "пересватав": ["пересватавши"],
    "пересватавши": ["пересватав"],
    "пересватывав": ["пересватывавши"],
    "пересватывавши": ["пересватывав"],
    "пересверлив": ["пересверливши"],
    "пересверливши": ["пересверлив"],
    "пересветить": ["переэкспонировать"],
    "пересвечивать": ["переэкспонировать"],
    "пересвистав": ["пересвиставши"],
    "пересвиставши": ["пересвистав"],
    "пересвистев": ["пересвистевши"],
    "пересвистевши": ["пересвистев"],
    "пересвистывав": ["пересвистывавши"],
    "пересвистывавши": ["пересвистывав"],
    "пересводив": ["пересводивши"],
    "пересводивши": ["пересводив"],
    "пересдав": ["пересдавши"],
    "пересдавав": ["пересдававши"],
    "пересдававши": ["пересдавав"],
    "пересдавши": ["пересдав"],
    "пересевав": ["пересевавши"],
    "пересевавши": ["пересевав"],
    "переседлав": ["переседлавши"],
    "переседлавши": ["переседлав"],
    "пересеивав": ["пересеивавши"],
    "пересеивавши": ["пересеивав"],
    "пересек": ["перерез", "обрез", "переруб", "полубочье"],
    "пересекав": ["пересекавши"],
    "пересекавши": ["пересекав"],
    "пересекаться": ["скрещиваться", "перекрещиваться", "встречаться", "совпадать", "накладываться", "общаться"],
    "переселенец": ["мигрант"],
    "переселение": ["миграция", "переезд", "депортация", "высылка"],
    "переселенка": ["мигрантка"],
    "переселенье": ["переселение"],
    "переселив": ["переселивши"],
    "переселивши": ["переселив"],
    "переселяв": ["переселявши"],
    "переселявши": ["переселяв"],
    "пересечение": ["пересекание", "скрещение"],
    "пересеченье": ["пересечение"],
    "пересечься": ["скреститься", "перекреститься", "столкнуться", "оборваться", "пресечься"],
    "пересеяв": ["пересеявши"],
    "пересеявши": ["пересеяв"],
    "пересигивав": ["пересигивавши"],
    "пересигивавши": ["пересигивав"],
    "пересигнув": ["пересигнувши"],
    "пересигнувши": ["пересигнув"],
    "пересидев": ["пересидевши"],
    "пересидевши": ["пересидев"],
    "пересидеться": ["засидеться"],
    "пересиживав": ["пересиживавши"],
    "пересиживавши": ["пересиживав"],
    "пересилив": ["пересиливши"],
    "пересиливав": ["пересиливавши"],
    "пересиливавши": ["пересиливав"],
    "пересиливши": ["пересилив"],
    "пересинив": ["пересинивши"],
    "пересинивав": ["пересинивавши"],
    "пересинивавши": ["пересинивав"],
    "пересинивши": ["пересинив"],
    "пересирав": ["пересиравши"],
    "пересиравши": ["пересирав"],
    "пересирать": ["ссать", "бздеть"],
    "пересиропив": ["пересиропивши"],
    "пересиропивши": ["пересиропив"],
    "перескабливав": ["перескабливавши"],
    "перескабливавши": ["перескабливав"],
    "пересказ": ["рассказ", "передача", "переложение", "изложение", "парафраз", "парафраза"],
    "пересказав": ["пересказавши"],
    "пересказавши": ["пересказав"],
    "пересказочное наклонение": ["ренарратив"],
    "пересказывав": ["пересказывавши"],
    "пересказывавши": ["пересказывав"],
    "пересказывательное наклонение": ["неочевидное наклонение", "косвенное наклонение", "латентив", "аудитив", "нарратив", "комментатив", "ренарратив", "пересказывательная форма"],
    "перескакав": ["перескакавши"],
    "перескакавши": ["перескакав"],
    "перескакивав": ["перескакивавши"],
    "перескакивавши": ["перескакивав"],
    "перескакивать": ["перепрыгивать"],
    "перескакнув": ["перескакнувши"],
    "перескакнувши": ["перескакнув"],
    "пересквернив": ["пересквернивши"],
    "пересквернивши": ["пересквернив"],
    "перескверняв": ["пересквернявши"],
    "пересквернявши": ["перескверняв"],
    "перескоблив": ["перескобливши"],
    "перескобливши": ["перескоблив"],
    "перескочив": ["перескочивши"],
    "перескочивши": ["перескочив"],
    "перескочить": ["перепрыгнуть"],
    "переслав": ["переславши"],
    "переславши": ["переслав"],
    "переслаивав": ["переслаивавши"],
    "переслаивавши": ["переслаивав"],
    "пересластив": ["пересластивши"],
    "пересластивши": ["пересластив"],
    "переслащав": ["переслащавши"],
    "переслащавши": ["переслащав"],
    "переслащивав": ["переслащивавши"],
    "переслащивавши": ["переслащивав"],
    "переследовав": ["переследовавши"],
    "переследовавши": ["переследовав"],
    "переслоив": ["переслоивши"],
    "переслоивши": ["переслоив"],
    "переслужив": ["переслуживши"],
    "переслуживав": ["переслуживавши"],
    "переслуживавши": ["переслуживав"],
    "переслуживши": ["переслужив"],
    "переслушав": ["переслушавши"],
    "переслушавши": ["переслушав"],
    "переслушивав": ["переслушивавши"],
    "переслушивавши": ["переслушивав"],
    "переслюнив": ["переслюнивши"],
    "переслюнивав": ["переслюнивавши"],
    "переслюнивавши": ["переслюнивав"],
    "переслюнивши": ["переслюнив"],
    "переслюнявив": ["переслюнявивши"],
    "переслюнявивши": ["переслюнявив"],
    "переслюнявливав": ["переслюнявливавши"],
    "переслюнявливавши": ["переслюнявливав"],
    "пересмаливав": ["пересмаливавши"],
    "пересмаливавши": ["пересмаливав"],
    "пересматривав": ["пересматривавши"],
    "пересматривавши": ["пересматривав"],
    "пересмеивав": ["пересмеивавши"],
    "пересмеивавши": ["пересмеивав"],
    "пересмехав": ["пересмехавши"],
    "пересмехавши": ["пересмехав"],
    "пересмешив": ["пересмешивши"],
    "пересмешивши": ["пересмешив"],
    "пересмешка": ["пересмех", "пересмехание", "пересмеханье", "пересмеивание", "пересмеиванье", "пересмеяние", "пересмеянье"],
    "пересмешник": ["насмешник"],
    "пересмешница": ["насмешница", "язва", "зубоскалка"],
    "пересмешничав": ["пересмешничавши"],
    "пересмешничавши": ["пересмешничав"],
    "пересмеяв": ["пересмеявши"],
    "пересмеявши": ["пересмеяв"],
    "пересмолив": ["пересмоливши"],
    "пересмоливши": ["пересмолив"],
    "пересмотрев": ["пересмотревши"],
    "пересмотревши": ["пересмотрев"],
    "пересмякнув": ["пересмякнувши"],
    "пересмякнувши": ["пересмякнув"],
    "переснарядив": ["переснарядивши"],
    "переснарядивши": ["переснарядив"],
    "переснаряжав": ["переснаряжавши"],
    "переснаряжавши": ["переснаряжав"],
    "переснастив": ["переснастивши"],
    "переснастивши": ["переснастив"],
    "переснащав": ["переснащавши"],
    "переснащавши": ["переснащав"],
    "переснащивав": ["переснащивавши"],
    "переснащивавши": ["переснащивав"],
    "переснимав": ["переснимавши"],
    "переснимавши": ["переснимав"],
    "пересняв": ["переснявши"],
    "переснявши": ["пересняв"],
    "пересовав": ["пересовавши"],
    "пересовавши": ["пересовав"],
    "пересовывав": ["пересовывавши"],
    "пересовывавши": ["пересовывав"],
    "пересогласовав": ["пересогласовавши"],
    "пересогласовавши": ["пересогласовав"],
    "пересогласовывав": ["пересогласовывавши"],
    "пересогласовывавши": ["пересогласовывав"],
    "пересоединив": ["пересоединивши"],
    "пересоединивши": ["пересоединив"],
    "пересоединяв": ["пересоединявши"],
    "пересоединявши": ["пересоединяв"],
    "пересоздав": ["пересоздавши"],
    "пересоздавав": ["пересоздававши"],
    "пересоздававши": ["пересоздавав"],
    "пересоздавши": ["пересоздав"],
    "пересоздать": ["изменить", "переделать"],
    "пересозидав": ["пересозидавши"],
    "пересозидавши": ["пересозидав"],
    "пересолив": ["пересоливши"],
    "пересоливши": ["пересолив"],
    "пересолодив": ["пересолодивши"],
    "пересолодивши": ["пересолодив"],
    "пересопев": ["пересопевши"],
    "пересопевши": ["пересопев"],
    "пересортировав": ["пересортировавши"],
    "пересортировавши": ["пересортировав"],
    "пересортировывав": ["пересортировывавши"],
    "пересортировывавши": ["пересортировывав"],
    "пересосав": ["пересосавши"],
    "пересосавши": ["пересосав"],
    "пересоставив": ["пересоставивши"],
    "пересоставивши": ["пересоставив"],
    "пересоставляв": ["пересоставлявши"],
    "пересоставлявши": ["пересоставляв"],
    "пересохнув": ["пересохнувши"],
    "пересохнувши": ["пересохнув"],
    "пересочинив": ["пересочинивши"],
    "пересочинивши": ["пересочинив"],
    "пересочиняв": ["пересочинявши"],
    "пересочинявши": ["пересочиняв"],
    "переспав": ["переспавши"],
    "переспавши": ["переспав"],
    "переспать": ["переночевать"],
    "переспев": ["переспевши"],
    "переспевав": ["переспевавши"],
    "переспевавши": ["переспевав"],
    "переспевши": ["переспев"],
    "переспелый": ["перезрелый"],
    "переспециализировав": ["переспециализировавши"],
    "переспециализировавши": ["переспециализировав"],
    "переспорив": ["переспоривши"],
    "переспоривав": ["переспоривавши"],
    "переспоривавши": ["переспоривав"],
    "переспоривши": ["переспорив"],
    "переспрашивав": ["переспрашивавши"],
    "переспрашивавши": ["переспрашивав"],
    "переспрос": ["переспрашивание"],
    "переспросив": ["переспросивши"],
    "переспросивши": ["переспросив"],
    "пересрав": ["пересравши"],
    "пересравши": ["пересрав"],
    "пересраться": ["переругаться"],
    "пересрочив": ["пересрочивши"],
    "пересрочивав": ["пересрочивавши"],
    "пересрочивавши": ["пересрочивав"],
    "пересрочивать": ["отсрочивать"],
    "пересрочивши": ["пересрочив"],
    "пересрочить": ["отсрочить"],
    "перессорив": ["перессоривши"],
    "перессоривав": ["перессоривавши"],
    "перессоривавши": ["перессоривав"],
    "перессоривши": ["перессорив"],
    "перестав": ["переставши"],
    "переставав": ["перестававши"],
    "перестававши": ["переставав"],
    "переставать": ["прекращать", "заканчивать", "заканчиваться", "кончаться"],
    "переставив": ["переставивши"],
    "переставивши": ["переставив"],
    "переставляв": ["переставлявши"],
    "переставлявши": ["переставляв"],
    "переставши": ["перестав"],
    "перестаивав": ["перестаивавши"],
    "перестаивавши": ["перестаивав"],
    "перестанавливав": ["перестанавливавши"],
    "перестанавливавши": ["перестанавливав"],
    "перестанавливать": ["переставлять"],
    "перестановив": ["перестановивши"],
    "перестановивши": ["перестановив"],
    "перестановка": ["переконфигурация", "подстановка"],
    "перестараться": ["переусердствовать"],
    "перестать": ["прекратить", "прекратиться"],
    "перестегав": ["перестегавши"],
    "перестегавши": ["перестегав"],
    "перестегнув": ["перестегнувши"],
    "перестегнувши": ["перестегнув"],
    "перестеклив": ["перестекливши"],
    "перестекливши": ["перестеклив"],
    "перестекляв": ["перестеклявши"],
    "перестеклявши": ["перестекляв"],
    "перестелив": ["перестеливши"],
    "перестеливши": ["перестелив"],
    "перестелить": ["перестлать"],
    "перестигав": ["перестигавши"],
    "перестигавши": ["перестигав"],
    "перестигнув": ["перестигнувши"],
    "перестигнувши": ["перестигнув"],
    "перестигши": ["перестигнув", "перестигнувши", "обогнавши"],
    "перестилав": ["перестилавши"],
    "перестилавши": ["перестилав"],
    "перестирав": ["перестиравши"],
    "перестиравши": ["перестирав"],
    "перестирывав": ["перестирывавши"],
    "перестирывавши": ["перестирывав"],
    "перестлав": ["перестлавши"],
    "перестлавши": ["перестлав"],
    "перестояв": ["перестоявши"],
    "перестоявши": ["перестояв"],
    "перестрагивав": ["перестрагивавши"],
    "перестрагивавши": ["перестрагивав"],
    "перестрадав": ["перестрадавши"],
    "перестрадавши": ["перестрадав"],
    "перестраивав": ["перестраивавши"],
    "перестраивавши": ["перестраивав"],
    "перестраивать": ["реконструировать"],
    "перестраховав": ["перестраховавши"],
    "перестраховавши": ["перестраховав"],
    "перестраховывав": ["перестраховывавши"],
    "перестраховывавши": ["перестраховывав"],
    "перестрачивав": ["перестрачивавши"],
    "перестрачивавши": ["перестрачивав"],
    "перестрашити": ["перелякати"],
    "перестращав": ["перестращавши"],
    "перестращавши": ["перестращав"],
    "перестреливав": ["перестреливавши"],
    "перестреливавши": ["перестреливав"],
    "перестрелка": ["стрельба", "перебранка", "перепалка"],
    "перестреляв": ["перестрелявши"],
    "перестрелявши": ["перестреляв"],
    "перестригав": ["перестригавши"],
    "перестригавши": ["перестригав"],
    "перестрогав": ["перестрогавши"],
    "перестрогавши": ["перестрогав"],
    "перестрогать": ["перестругать"],
    "перестроечник": ["перестройщик"],
    "перестроив": ["перестроивши"],
    "перестроивши": ["перестроив"],
    "перестройка": ["бунт вторых секретарей", "революция вторых секретарей", "катастройка"],
    "перестройщик": ["перестроечник"],
    "перестрочив": ["перестрочивши"],
    "перестрочивши": ["перестрочив"],
    "перестругав": ["перестругавши"],
    "перестругавши": ["перестругав"],
    "перестругать": ["перестрогать"],
    "перестругивав": ["перестругивавши"],
    "перестругивавши": ["перестругивав"],
    "перестряпав": ["перестряпавши"],
    "перестряпавши": ["перестряпав"],
    "перестудив": ["перестудивши"],
    "перестудивши": ["перестудив"],
    "перестужав": ["перестужавши"],
    "перестужавши": ["перестужав"],
    "перестуживав": ["перестуживавши"],
    "перестуживавши": ["перестуживав"],
    "перестукав": ["перестукавши"],
    "перестукавши": ["перестукав"],
    "перестукать": ["перестучать"],
    "перестукивав": ["перестукивавши"],
    "перестукивавши": ["перестукивав"],
    "перестукиванье": ["перестукивание"],
    "перестукнув": ["перестукнувши"],
    "перестукнувши": ["перестукнув"],
    "перестукнуть": ["перестукать"],
    "переступав": ["переступавши"],
    "переступавши": ["переступав"],
    "переступень": ["бриония"],
    "переступив": ["переступивши"],
    "переступивши": ["переступив"],
    "перестучав": ["перестучавши"],
    "перестучавши": ["перестучав"],
    "перестучать": ["перестукать"],
    "перестыв": ["перестывши"],
    "перестывав": ["перестывавши"],
    "перестывавши": ["перестывав"],
    "перестывши": ["перестыв"],
    "перестыковав": ["перестыковавши"],
    "перестыковавши": ["перестыковав"],
    "перестыковывав": ["перестыковывавши"],
    "перестыковывавши": ["перестыковывав"],
    "перестынув": ["перестынувши"],
    "перестынувши": ["перестынув"],
    "перестёгивав": ["перестёгивавши"],
    "перестёгивавши": ["перестёгивав"],
    "пересуватися": ["пересовуватися", "проходити", "уявлятися"],
    "пересуд": ["сплетня", "злословие", "злопыхательство", "поношение", "хула"],
    "пересудив": ["пересудивши"],
    "пересудивши": ["пересудив"],
    "пересудчик": ["сплетник"],
    "пересуждав": ["пересуждавши"],
    "пересуждавши": ["пересуждав"],
    "пересуживав": ["пересуживавши"],
    "пересуживавши": ["пересуживав"],
    "пересунув": ["пересунувши"],
    "пересунувши": ["пересунув"],
    "пересупонив": ["пересупонивши"],
    "пересупонивав": ["пересупонивавши"],
    "пересупонивавши": ["пересупонивав"],
    "пересупонивши": ["пересупонив"],
    "пересучив": ["пересучивши"],
    "пересучивав": ["пересучивавши"],
    "пересучивавши": ["пересучивав"],
    "пересучивши": ["пересучив"],
    "пересушав": ["пересушавши"],
    "пересушавши": ["пересушав"],
    "пересушать": ["пересушивать", "обезвоживать"],
    "пересушенность": ["обезвоженность"],
    "пересушив": ["пересушивши"],
    "пересушивав": ["пересушивавши"],
    "пересушивавши": ["пересушивав"],
    "пересушивши": ["пересушив"],
    "пересчитав": ["пересчитавши"],
    "пересчитавши": ["пересчитав"],
    "пересчитывав": ["пересчитывавши"],
    "пересчитывавши": ["пересчитывав"],
    "пересыл": ["пересылка"],
    "пересылав": ["пересылавши"],
    "пересылавши": ["пересылав"],
    "пересыльный": ["пересылочный"],
    "пересыпав": ["пересыпавши"],
    "пересыпавши": ["пересыпав"],
    "пересыпанье": ["пересыпание"],
    "пересытив": ["пересытивши"],
    "пересытивши": ["пересытив"],
    "пересыхав": ["пересыхавши"],
    "пересыхавши": ["пересыхав"],
    "пересыхание": ["высыхание"],
    "пересыщав": ["пересыщавши"],
    "пересыщавши": ["пересыщав"],
    "пересёдлывав": ["пересёдлывавши"],
    "пересёдлывавши": ["пересёдлывав"],
    "перетакивав": ["перетакивавши"],
    "перетакивавши": ["перетакивав"],
    "перетакнув": ["перетакнувши"],
    "перетакнувши": ["перетакнув"],
    "переталкивав": ["переталкивавши"],
    "переталкивавши": ["переталкивав"],
    "перетамаживать": ["перетаможивать"],
    "перетамаживаться": ["перетаможиваться"],
    "перетаможивать": ["перетамаживать"],
    "перетаможиваться": ["перетамаживаться"],
    "перетанцевав": ["перетанцевавши"],
    "перетанцевавши": ["перетанцевав"],
    "перетанцовывав": ["перетанцовывавши"],
    "перетанцовывавши": ["перетанцовывав"],
    "перетапливав": ["перетапливавши"],
    "перетапливавши": ["перетапливав"],
    "перетаптывав": ["перетаптывавши"],
    "перетаптывавши": ["перетаптывав"],
    "перетарив": ["перетаривши"],
    "перетаривав": ["перетаривавши"],
    "перетаривавши": ["перетаривав"],
    "перетаривать": ["переторять"],
    "перетаривши": ["перетарив"],
    "перетарифицировав": ["перетарифицировавши"],
    "перетарифицировавши": ["перетарифицировав"],
    "перетаскав": ["перетаскавши"],
    "перетаскавши": ["перетаскав"],
    "перетаскивав": ["перетаскивавши"],
    "перетаскивавши": ["перетаскивав"],
    "перетасовав": ["перетасовавши"],
    "перетасовавши": ["перетасовав"],
    "перетасовывав": ["перетасовывавши"],
    "перетасовывавши": ["перетасовывав"],
    "перетачав": ["перетачавши"],
    "перетачавши": ["перетачав"],
    "перетачивав": ["перетачивавши"],
    "перетачивавши": ["перетачивав"],
    "перетащив": ["перетащивши"],
    "перетащивши": ["перетащив"],
    "перетащить": ["переместить", "сдвинуть"],
    "перетекав": ["перетекавши"],
    "перетекавши": ["перетекав"],
    "перетелеграфировав": ["перетелеграфировавши"],
    "перетелеграфировавши": ["перетелеграфировав"],
    "перетемнив": ["перетемнивши"],
    "перетемнивши": ["перетемнив"],
    "перетеребив": ["перетеребивши"],
    "перетеребивши": ["перетеребив"],
    "перетерев": ["перетёрши"],
    "перетерпев": ["перетерпевши"],
    "перетерпевши": ["перетерпев"],
    "перетеряв": ["перетерявши"],
    "перетерявши": ["перетеряв"],
    "перетерять": ["растерять"],
    "перетесав": ["перетесавши"],
    "перетесавши": ["перетесав"],
    "перетечь": ["перелиться"],
    "перетик": ["перетинок", "перетика"],
    "перетирав": ["перетиравши"],
    "перетиравши": ["перетирав"],
    "перетирать": ["обсуждать", "обговаривать"],
    "перетискав": ["перетискавши"],
    "перетискавши": ["перетискав"],
    "перетискивав": ["перетискивавши"],
    "перетискивавши": ["перетискивав"],
    "перетиснув": ["перетиснувши"],
    "перетиснувши": ["перетиснув"],
    "перетихав": ["перетихавши"],
    "перетихавши": ["перетихав"],
    "перетихнув": ["перетихнувши"],
    "перетихнувши": ["перетихнув"],
    "переткав": ["переткавши"],
    "переткавши": ["переткав"],
    "переткнув": ["переткнувши"],
    "переткнувши": ["переткнув"],
    "перетлев": ["перетлевши"],
    "перетлевав": ["перетлевавши"],
    "перетлевавши": ["перетлевав"],
    "перетлевши": ["перетлев"],
    "перетолкав": ["перетолкавши"],
    "перетолкавши": ["перетолкав"],
    "перетолкнув": ["перетолкнувши"],
    "перетолкнувши": ["перетолкнув"],
    "перетолковав": ["перетолковавши"],
    "перетолковавши": ["перетолковав"],
    "перетолкование": ["перетолковывание"],
    "перетолковывав": ["перетолковывавши"],
    "перетолковывавши": ["перетолковывав"],
    "перетомив": ["перетомивши"],
    "перетомивши": ["перетомив"],
    "перетонев": ["перетоневши"],
    "перетоневши": ["перетонев"],
    "перетонеть": ["истончать", "утоньшиться"],
    "перетонив": ["перетонивши"],
    "перетонивши": ["перетонив"],
    "перетонув": ["перетонувши"],
    "перетонувши": ["перетонув"],
    "перетончав": ["перетончавши"],
    "перетончавши": ["перетончав"],
    "перетончив": ["перетончивши"],
    "перетончивши": ["перетончив"],
    "перетоняв": ["перетонявши"],
    "перетонявши": ["перетоняв"],
    "перетопив": ["перетопивши"],
    "перетопивши": ["перетопив"],
    "перетоптав": ["перетоптавши"],
    "перетоптавши": ["перетоптав"],
    "переторачивав": ["переторачивавши"],
    "переторачивавши": ["переторачивав"],
    "переторговав": ["переторговавши"],
    "переторговавши": ["переторговав"],
    "переторговывав": ["переторговывавши"],
    "переторговывавши": ["переторговывав"],
    "перетормошив": ["перетормошивши"],
    "перетормошивши": ["перетормошив"],
    "переторочив": ["переторочивши"],
    "переторочивши": ["переторочив"],
    "переторяв": ["переторявши"],
    "переторявши": ["переторяв"],
    "переторять": ["перетаривать"],
    "переточив": ["переточивши"],
    "переточивши": ["переточив"],
    "перетравив": ["перетравивши"],
    "перетравивши": ["перетравив"],
    "перетравливав": ["перетравливавши"],
    "перетравливавши": ["перетравливав"],
    "перетрагивав": ["перетрагивавши"],
    "перетрагивавши": ["перетрагивав"],
    "перетраивав": ["перетраивавши"],
    "перетраивавши": ["перетраивав"],
    "перетрактовав": ["перетрактовавши"],
    "перетрактовавши": ["перетрактовав"],
    "перетрактовывав": ["перетрактовывавши"],
    "перетрактовывавши": ["перетрактовывав"],
    "перетранжирив": ["перетранжиривши"],
    "перетранжиривши": ["перетранжирив"],
    "перетратив": ["перетративши"],
    "перетративши": ["перетратив"],
    "перетрахав": ["перетрахавши"],
    "перетрахавши": ["перетрахав"],
    "перетрахать": ["переебать", "пересношать"],
    "перетрачивав": ["перетрачивавши"],
    "перетрачивавши": ["перетрачивав"],
    "перетревожив": ["перетревоживши"],
    "перетревоживши": ["перетревожив"],
    "перетревожиться": ["переволноваться"],
    "перетренировав": ["перетренировавши"],
    "перетренировавши": ["перетренировав"],
    "перетренированность": ["перетрен"],
    "перетренировка": ["переутомление"],
    "перетрепав": ["перетрепавши"],
    "перетрепавши": ["перетрепав"],
    "перетрогав": ["перетрогавши"],
    "перетрогавши": ["перетрогав"],
    "перетроив": ["перетроивши"],
    "перетроивши": ["перетроив"],
    "перетрудив": ["перетрудивши"],
    "перетрудивши": ["перетрудив"],
    "перетруждав": ["перетруждавши"],
    "перетруждавши": ["перетруждав"],
    "перетруждать": ["перетруживать"],
    "перетруждаться": ["уставать", "напрягаться"],
    "перетруживав": ["перетруживавши"],
    "перетруживавши": ["перетруживав"],
    "перетрусив": ["перетрусивши"],
    "перетрусивши": ["перетрусив"],
    "перетрухав": ["перетрухавши"],
    "перетрухавши": ["перетрухав"],
    "перетрухнув": ["перетрухнувши"],
    "перетрухнувши": ["перетрухнув"],
    "перетрухнуть": ["перепугаться", "струсить"],
    "перетрушивав": ["перетрушивавши"],
    "перетрушивавши": ["перетрушивав"],
    "перетрясав": ["перетрясавши"],
    "перетрясавши": ["перетрясав"],
    "перетрясать": ["перетряхивать"],
    "перетряхав": ["перетряхавши"],
    "перетряхавши": ["перетряхав"],
    "перетряхивав": ["перетряхивавши"],
    "перетряхивавши": ["перетряхивав"],
    "перетряхнув": ["перетряхнувши"],
    "перетряхнувши": ["перетряхнув"],
    "перетрёпывав": ["перетрёпывавши"],
    "перетрёпывавши": ["перетрёпывав"],
    "перетупив": ["перетупивши"],
    "перетупивши": ["перетупив"],
    "перетупляв": ["перетуплявши"],
    "перетуплявши": ["перетупляв"],
    "перетушевав": ["перетушевавши"],
    "перетушевавши": ["перетушевав"],
    "перетушив": ["перетушивши"],
    "перетушивши": ["перетушив"],
    "перетушёвывав": ["перетушёвывавши"],
    "перетушёвывавши": ["перетушёвывав"],
    "перетыкав": ["перетыкавши"],
    "перетыкавши": ["перетыкав"],
    "перетырив": ["перетыривши"],
    "перетыривши": ["перетырив"],
    "переть": ["тащиться", "идти", "тащить", "нести", "переться", "воровать", "красть", "приделывать ноги", "тибрить", "возбуждать", "восхищать"],
    "перетягав": ["перетягавши"],
    "перетягавши": ["перетягав"],
    "перетягивав": ["перетягивавши"],
    "перетягивавши": ["перетягивав"],
    "перетягивание каната": ["тянуть одеяло на себя"],
    "перетягиванье": ["перетягивание"],
    "перетяжелив": ["перетяжеливши"],
    "перетяжеливши": ["перетяжелив"],
    "перетяжеляв": ["перетяжелявши"],
    "перетяжелявши": ["перетяжеляв"],
    "перетянув": ["перетянувши"],
    "перетянувши": ["перетянув"],
    "перетёрши": ["перетерев"],
    "перетёсывав": ["перетёсывавши"],
    "перетёсывавши": ["перетёсывав"],
    "переубедив": ["переубедивши"],
    "переубедивши": ["переубедив"],
    "переубеждав": ["переубеждавши"],
    "переубеждавши": ["переубеждав"],
    "переуверив": ["переуверивши"],
    "переуверивши": ["переуверив"],
    "переуверяв": ["переуверявши"],
    "переуверявши": ["переуверяв"],
    "переувлажнив": ["переувлажнивши"],
    "переувлажнивши": ["переувлажнив"],
    "переувлажняв": ["переувлажнявши"],
    "переувлажнявши": ["переувлажняв"],
    "переуглив": ["переугливши"],
    "переугливав": ["переугливавши"],
    "переугливавши": ["переугливав"],
    "переугливши": ["переуглив"],
    "переудив": ["переудивши"],
    "переудивши": ["переудив"],
    "переудобрив": ["переудобривши"],
    "переудобривши": ["переудобрив"],
    "переудобряв": ["переудобрявши"],
    "переудобрявши": ["переудобряв"],
    "переуживав": ["переуживавши"],
    "переуживавши": ["переуживав"],
    "переузив": ["переузивши"],
    "переузивши": ["переузив"],
    "переузнав": ["переузнавши"],
    "переузнавши": ["переузнав"],
    "переукладывав": ["переукладывавши"],
    "переукладывавши": ["переукладывав"],
    "переукомплектовав": ["переукомплектовавши"],
    "переукомплектовавши": ["переукомплектовав"],
    "переуложив": ["переуложивши"],
    "переуложивши": ["переуложив"],
    "переулок": ["проулок", "проезд"],
    "переумничав": ["переумничавши"],
    "переумничавши": ["переумничав"],
    "переупаковав": ["переупаковавши"],
    "переупаковавши": ["переупаковав"],
    "переупаковывав": ["переупаковывавши"],
    "переупаковывавши": ["переупаковывав"],
    "переуплотнив": ["переуплотнивши"],
    "переуплотнивши": ["переуплотнив"],
    "переуплотняв": ["переуплотнявши"],
    "переуплотнявши": ["переуплотняв"],
    "переупорядочив": ["переупорядочивши"],
    "переупорядочивав": ["переупорядочивавши"],
    "переупорядочивавши": ["переупорядочивав"],
    "переупорядочивши": ["переупорядочив"],
    "переупростить": ["вульгаризировать"],
    "переупрощать": ["вульгаризировать"],
    "переупрощение": ["вульгаризация"],
    "переупрямив": ["переупрямивши"],
    "переупрямивши": ["переупрямив"],
    "переусердствовав": ["переусердствовавши"],
    "переусердствовавши": ["переусердствовав"],
    "переусердствовать": ["перестараться"],
    "переустанавливав": ["переустанавливавши"],
    "переустанавливавши": ["переустанавливав"],
    "переустановив": ["переустановивши"],
    "переустановивши": ["переустановив"],
    "переустраивав": ["переустраивавши"],
    "переустраивавши": ["переустраивав"],
    "переустроив": ["переустроивши"],
    "переустроивши": ["переустроив"],
    "переустройство": ["перестройка", "преобразование", "реформирование"],
    "переуступав": ["переуступавши"],
    "переуступавши": ["переуступав"],
    "переуступив": ["переуступивши"],
    "переуступивши": ["переуступив"],
    "переутвердив": ["переутвердивши"],
    "переутвердивши": ["переутвердив"],
    "переутверждав": ["переутверждавши"],
    "переутверждавши": ["переутверждав"],
    "переутомив": ["переутомивши"],
    "переутомивши": ["переутомив"],
    "переутомление": ["переутомленье"],
    "переутомленье": ["переутомление"],
    "переутомляв": ["переутомлявши"],
    "переутомлявши": ["переутомляв"],
    "переутомлённость": ["переутомление"],
    "переутюжив": ["переутюживши"],
    "переутюживав": ["переутюживавши"],
    "переутюживавши": ["переутюживав"],
    "переутюживши": ["переутюжив"],
    "переучаствовав": ["переучаствовавши"],
    "переучаствовавши": ["переучаствовав"],
    "переучив": ["переучивши"],
    "переучивав": ["переучивавши"],
    "переучивавши": ["переучивав"],
    "переучивши": ["переучив"],
    "переучитывав": ["переучитывавши"],
    "переучитывавши": ["переучитывав"],
    "переучёт": ["аудит", "экспертиза"],
    "перефасонив": ["перефасонивши"],
    "перефасонивав": ["перефасонивавши"],
    "перефасонивавши": ["перефасонивав"],
    "перефасонивши": ["перефасонив"],
    "перефокусировать": ["рефокусировать"],
    "переформатировав": ["переформатировавши"],
    "переформатировавши": ["переформатировав"],
    "переформировав": ["переформировавши"],
    "переформировавши": ["переформировав"],
    "переформирование": ["переформировывание"],
    "переформировывав": ["переформировывавши"],
    "переформировывавши": ["переформировывав"],
    "переформовав": ["переформовавши"],
    "переформовавши": ["переформовав"],
    "переформовывав": ["переформовывавши"],
    "переформовывавши": ["переформовывав"],
    "переформулировав": ["переформулировавши"],
    "переформулировавши": ["переформулировав"],
    "переформулирование": ["перефразирование"],
    "переформулировка": ["переформулирование"],
    "перефотографировав": ["перефотографировавши"],
    "перефотографировавши": ["перефотографировав"],
    "перефразировав": ["перефразировавши"],
    "перефразировавши": ["перефразировав"],
    "перефразирование": ["перефразировка"],
    "перефразировка": ["перефразирование"],
    "перехаживав": ["перехаживавши"],
    "перехаживавши": ["перехаживав"],
    "перехаивав": ["перехаивавши"],
    "перехаивавши": ["перехаивав"],
    "перехаяв": ["перехаявши"],
    "перехаявши": ["перехаяв"],
    "перехвалив": ["перехваливши"],
    "перехваливав": ["перехваливавши"],
    "перехваливавши": ["перехваливав"],
    "перехваливши": ["перехвалив"],
    "перехварывав": ["перехварывавши"],
    "перехварывавши": ["перехварывав"],
    "перехвастав": ["перехваставши"],
    "перехваставши": ["перехвастав"],
    "перехватав": ["перехватавши"],
    "перехватавши": ["перехватав"],
    "перехватив": ["перехвативши"],
    "перехвативши": ["перехватив"],
    "перехватывав": ["перехватывавши"],
    "перехватывавши": ["перехватывав"],
    "перехворав": ["перехворавши"],
    "перехворавши": ["перехворав"],
    "перехерачив": ["перехерачивши"],
    "перехерачивши": ["перехерачив"],
    "перехерачить": ["перебить"],
    "перехитрив": ["перехитривши"],
    "перехитривав": ["перехитривавши"],
    "перехитривавши": ["перехитривав"],
    "перехитривши": ["перехитрив"],
    "перехитрувати": ["перехитрити"],
    "перехитряв": ["перехитрявши"],
    "перехитрявши": ["перехитряв"],
    "перехихикиваться": ["пересмеиваться"],
    "перехлестав": ["перехлеставши"],
    "перехлеставши": ["перехлестав"],
    "перехлестнув": ["перехлестнувши"],
    "перехлестнувши": ["перехлестнув"],
    "перехлопав": ["перехлопавши"],
    "перехлопавши": ["перехлопав"],
    "перехлопывав": ["перехлопывавши"],
    "перехлопывавши": ["перехлопывав"],
    "перехлёстывав": ["перехлёстывавши"],
    "перехлёстывавши": ["перехлёстывав"],
    "переходив": ["переходивши"],
    "переходивши": ["переходив"],
    "переходный": ["транзитивный"],
    "переходчивость": ["изменчивость", "непостоянство", "переменчивость"],
    "переходчивый": ["изменчивый", "непостоянный", "переменчивый", "заразный"],
    "перехолаживав": ["перехолаживавши"],
    "перехолаживавши": ["перехолаживав"],
    "перехолодив": ["перехолодивши"],
    "перехолодивши": ["перехолодив"],
    "перехоранивав": ["перехоранивавши"],
    "перехоранивавши": ["перехоранивав"],
    "перехоранивать": ["перезахоранивать"],
    "перехоронив": ["перехоронивши"],
    "перехоронивши": ["перехоронив"],
    "перехоронить": ["перезахоронить"],
    "перехотев": ["перехотевши"],
    "перехотевши": ["перехотев"],
    "перехотеть": ["расхотеть"],
    "перехуярив": ["перехуяривши"],
    "перехуяривши": ["перехуярив"],
    "перехуячив": ["перехуячивши"],
    "перехуячивши": ["перехуячив"],
    "перехуячить": ["перебить", "переломать", "перекрушить", "разрушить", "перехуярить", "перехуяшить"],
    "перехэшировав": ["перехэшировавши"],
    "перехэшировавши": ["перехэшировав"],
    "перецарапав": ["перецарапавши"],
    "перецарапавши": ["перецарапав"],
    "перецарапывав": ["перецарапывавши"],
    "перецарапывавши": ["перецарапывав"],
    "перецедив": ["перецедивши"],
    "перецедивши": ["перецедив"],
    "перецеживав": ["перецеживавши"],
    "перецеживавши": ["перецеживав"],
    "перецеловав": ["перецеловавши"],
    "перецеловавши": ["перецеловав"],
    "перецеловывав": ["перецеловывавши"],
    "перецеловывавши": ["перецеловывав"],
    "переценив": ["переценивши"],
    "переценивав": ["переценивавши"],
    "переценивавши": ["переценивав"],
    "переценивши": ["переценив"],
    "перецепив": ["перецепивши"],
    "перецепивши": ["перецепив"],
    "перецепляв": ["перецеплявши"],
    "перецеплявши": ["перецепляв"],
    "перецыганив": ["перецыганивши"],
    "перецыганивав": ["перецыганивавши"],
    "перецыганивавши": ["перецыганивав"],
    "перецыганивши": ["перецыганив"],
    "перечалив": ["перечаливши"],
    "перечаливав": ["перечаливавши"],
    "перечаливавши": ["перечаливав"],
    "перечаливши": ["перечалив"],
    "перечахнув": ["перечахнувши"],
    "перечахнувши": ["перечахнув"],
    "перечеканив": ["перечеканивши"],
    "перечеканивав": ["перечеканивавши"],
    "перечеканивавши": ["перечеканивав"],
    "перечеканивши": ["перечеканив"],
    "перечень": ["перечисление", "список", "реестр", "указатель", "индекс", "опись"],
    "перечеркнув": ["перечеркнувши"],
    "перечеркнувши": ["перечеркнув"],
    "перечернив": ["перечернивши"],
    "перечернивши": ["перечернив"],
    "перечерняв": ["перечернявши"],
    "перечернявши": ["перечерняв"],
    "перечерпав": ["перечерпавши"],
    "перечерпавши": ["перечерпав"],
    "перечерпнув": ["перечерпнувши"],
    "перечерпнувши": ["перечерпнув"],
    "перечерпывав": ["перечерпывавши"],
    "перечерпывавши": ["перечерпывав"],
    "перечерствев": ["перечерствевши"],
    "перечерствевши": ["перечерствев"],
    "перечертив": ["перечертивши"],
    "перечертивши": ["перечертив"],
    "перечерчивав": ["перечерчивавши"],
    "перечерчивавши": ["перечерчивав"],
    "перечесав": ["перечесавши"],
    "перечесавши": ["перечесав"],
    "перечесть": ["пересчитать"],
    "перечив": ["перечивши"],
    "перечивши": ["перечив"],
    "перечинив": ["перечинивши"],
    "перечинивав": ["перечинивавши"],
    "перечинивавши": ["перечинивав"],
    "перечинивши": ["перечинив"],
    "перечиркав": ["перечиркавши"],
    "перечиркавши": ["перечиркав"],
    "перечисленье": ["перечисление"],
    "перечислив": ["перечисливши"],
    "перечисливши": ["перечислив"],
    "перечислимый": ["счётный"],
    "перечисляв": ["перечислявши"],
    "перечислявши": ["перечисляв"],
    "перечистив": ["перечистивши"],
    "перечистивши": ["перечистив"],
    "перечитав": ["перечитавши"],
    "перечитавши": ["перечитав"],
    "перечитывав": ["перечитывавши"],
    "перечитывавши": ["перечитывав"],
    "перечитыванье": ["перечитывание"],
    "перечить": ["прекословить", "возражать", "спорить"],
    "перечищав": ["перечищавши"],
    "перечищавши": ["перечищав"],
    "перечница": ["карга", "баба-яга"],
    "перечувствовав": ["перечувствовавши"],
    "перечувствовавши": ["перечувствовав"],
    "перечёркав": ["перечёркавши"],
    "перечёркавши": ["перечёркав"],
    "перечёркивав": ["перечёркивавши"],
    "перечёркивавши": ["перечёркивав"],
    "перечёркивать": ["пересекать", "зачёркивать", "сводить на нет"],
    "перечёсывав": ["перечёсывавши"],
    "перечёсывавши": ["перечёсывав"],
    "перечёт": ["пересчёт", "перечисление", "перечень"],
    "перешагивав": ["перешагивавши"],
    "перешагивавши": ["перешагивав"],
    "перешагнув": ["перешагнувши"],
    "перешагнувши": ["перешагнув"],
    "перешарив": ["перешаривши"],
    "перешаривав": ["перешаривавши"],
    "перешаривавши": ["перешаривав"],
    "перешаривать": ["перерывать"],
    "перешаривши": ["перешарив"],
    "перешвартовав": ["перешвартовавши"],
    "перешвартовавши": ["перешвартовав"],
    "перешвартовывав": ["перешвартовывавши"],
    "перешвартовывавши": ["перешвартовывав"],
    "перешвыривав": ["перешвыривавши"],
    "перешвыривавши": ["перешвыривав"],
    "перешвырнув": ["перешвырнувши"],
    "перешвырнувши": ["перешвырнув"],
    "перешвыряв": ["перешвырявши"],
    "перешвырявши": ["перешвыряв"],
    "перешевелив": ["перешевеливши"],
    "перешевеливав": ["перешевеливавши"],
    "перешевеливавши": ["перешевеливав"],
    "перешевеливши": ["перешевелив"],
    "перешелушив": ["перешелушивши"],
    "перешелушивав": ["перешелушивавши"],
    "перешелушивавши": ["перешелушивав"],
    "перешелушивши": ["перешелушив"],
    "перешельмовав": ["перешельмовавши"],
    "перешельмовавши": ["перешельмовав"],
    "перешепнув": ["перешепнувши"],
    "перешепнувши": ["перешепнув"],
    "перешептав": ["перешептавши"],
    "перешептавши": ["перешептав"],
    "перешерстив": ["перешерстивши"],
    "перешерстивши": ["перешерстив"],
    "перешибав": ["перешибавши"],
    "перешибавши": ["перешибав"],
    "перешибив": ["перешибивши"],
    "перешибивши": ["перешибив"],
    "перешибить": ["перебить", "переломить", "заглушить", "затмить", "пересечь"],
    "перешибленный": ["перебитый"],
    "перешивав": ["перешивавши"],
    "перешивавши": ["перешивав"],
    "перешивши": ["перешив"],
    "перешлифовав": ["перешлифовавши"],
    "перешлифовавши": ["перешлифовав"],
    "перешлифовывав": ["перешлифовывавши"],
    "перешлифовывавши": ["перешлифовывав"],
    "перешлихтовав": ["перешлихтовавши"],
    "перешлихтовавши": ["перешлихтовав"],
    "перешлихтовывав": ["перешлихтовывавши"],
    "перешлихтовывавши": ["перешлихтовывав"],
    "перешмыгнув": ["перешмыгнувши"],
    "перешмыгнувши": ["перешмыгнув"],
    "перешнуровав": ["перешнуровавши"],
    "перешнуровавши": ["перешнуровав"],
    "перешнуровывав": ["перешнуровывавши"],
    "перешнуровывавши": ["перешнуровывав"],
    "перешныривав": ["перешныривавши"],
    "перешныривавши": ["перешныривав"],
    "перешнырнув": ["перешнырнувши"],
    "перешнырнувши": ["перешнырнув"],
    "перешныряв": ["перешнырявши"],
    "перешнырявши": ["перешныряв"],
    "перешпиговав": ["перешпиговавши"],
    "перешпиговавши": ["перешпиговав"],
    "перешпиговывав": ["перешпиговывавши"],
    "перешпиговывавши": ["перешпиговывав"],
    "перешпилив": ["перешпиливши"],
    "перешпиливав": ["перешпиливавши"],
    "перешпиливавши": ["перешпиливав"],
    "перешпиливши": ["перешпилив"],
    "перештемпелевав": ["перештемпелевавши"],
    "перештемпелевавши": ["перештемпелевав"],
    "перештемпелёвывав": ["перештемпелёвывавши"],
    "перештемпелёвывавши": ["перештемпелёвывав"],
    "перештопав": ["перештопавши"],
    "перештопавши": ["перештопав"],
    "перештопывав": ["перештопывавши"],
    "перештопывавши": ["перештопывав"],
    "перештукатурив": ["перештукатуривши"],
    "перештукатуривав": ["перештукатуривавши"],
    "перештукатуривавши": ["перештукатуривав"],
    "перештукатуривши": ["перештукатурив"],
    "перешутив": ["перешутивши"],
    "перешутивши": ["перешутив"],
    "перешучивав": ["перешучивавши"],
    "перешучивавши": ["перешучивав"],
    "перешёптывав": ["перешёптывавши"],
    "перешёптывавши": ["перешёптывав"],
    "перещеголяв": ["перещеголявши"],
    "перещеголявши": ["перещеголяв"],
    "перещеголять": ["превзойти", "обогнать", "затмить", "обставить", "переплюнуть", "заткнуть за пояс"],
    "перещекотав": ["перещекотавши"],
    "перещекотавши": ["перещекотав"],
    "перещелочив": ["перещелочивши"],
    "перещелочивши": ["перещелочив"],
    "перещемив": ["перещемивши"],
    "перещемивши": ["перещемив"],
    "перещемляв": ["перещемлявши"],
    "перещемлявши": ["перещемляв"],
    "перещипав": ["перещипавши"],
    "перещипавши": ["перещипав"],
    "перещипывав": ["перещипывавши"],
    "перещипывавши": ["перещипывав"],
    "перещипыванье": ["перещипывание"],
    "перещупав": ["перещупавши"],
    "перещупавши": ["перещупав"],
    "перещупывав": ["перещупывавши"],
    "перещупывавши": ["перещупывав"],
    "перещёлкав": ["перещёлкавши"],
    "перещёлкавши": ["перещёлкав"],
    "перещёлкивав": ["перещёлкивавши"],
    "перещёлкивавши": ["перещёлкивав"],
    "переэкзаменовав": ["переэкзаменовавши"],
    "переэкзаменовавши": ["переэкзаменовав"],
    "переэкзаменовка": ["пересдача"],
    "переэкзаменовывав": ["переэкзаменовывавши"],
    "переэкзаменовывавши": ["переэкзаменовывав"],
    "переэтерификация": ["рандомизация"],
    "переэтерифицировав": ["переэтерифицировавши"],
    "переэтерифицировавши": ["переэтерифицировав"],
    "переяровизировав": ["переяровизировавши"],
    "переяровизировавши": ["переяровизировав"],
    "переёб": ["перетрах"],
    "периапикальный": ["околоверхушечный"],
    "перив": ["перивши"],
    "перивенозный": ["периваскулярный"],
    "перивши": ["перив"],
    "перигляциальный": ["приледниковый"],
    "перидот": ["оливин"],
    "перидромофилия": ["билетофилия"],
    "перикард": ["околосердечная сумка"],
    "перикардий": ["перикард"],
    "периклинальный": ["периклиновый"],
    "перикоронарит": ["перикоронит"],
    "периметровый": ["периметральный"],
    "перина": ["пуховик"],
    "перинатальный": ["околородовой"],
    "период": ["цикл", "фаза", "отрезок", "эпоха", "геологический период"],
    "периодизировав": ["периодизировавши"],
    "периодизировавши": ["периодизировав"],
    "периодически": ["регулярно"],
    "периодично": ["периодически"],
    "периодичность": ["повторяемость", "цикличность"],
    "периодичный": ["периодический"],
    "периодонтит": ["перицементит"],
    "периоральный": ["околоротовой"],
    "периост": ["надкостница"],
    "периостит": ["флюс"],
    "перипатетизм": ["аристотелизм"],
    "периплазма": ["перипласт"],
    "перипласт": ["периплазма"],
    "перипневмония": ["плевропневмония"],
    "периренальный": ["околопочечный"],
    "перисарк": ["перидерм", "перидерма"],
    "перископический": ["перископный"],
    "перископный": ["перископический"],
    "перисперм": ["периспермий"],
    "периспорий": ["перина"],
    "периссология": ["лексическое излишество"],
    "перистерит": ["беломорит"],
    "перистиль": ["перистилиум"],
    "перистый": ["оперённый"],
    "периться": ["оперяться"],
    "периферийное устройство": ["периферия"],
    "периферийный": ["окраинный", "окрестный", "провинциальный", "периферический"],
    "периферия": ["край", "окраина", "периферийное устройство"],
    "перифраза": ["перифраз", "парафраза", "иносказание"],
    "перифразема": ["перифраз", "перифраза"],
    "перифразировав": ["перифразировавши"],
    "перифразировавши": ["перифразировав"],
    "перицентр": ["периапсис"],
    "перицикл": ["перикамбий"],
    "перколировав": ["перколировавши"],
    "перколировавши": ["перколировав"],
    "перкутировав": ["перкутировавши"],
    "перкутировавши": ["перкутировав"],
    "перл": ["жемчужина", "жемчуг", "бисер", "сокровище", "драгоценность", "украшение", "бриллиант"],
    "перловица": ["ракуша"],
    "перлокутив": ["перлокуция"],
    "перлон": ["капрон"],
    "перлотто": ["орзотто"],
    "перлюстрировав": ["перлюстрировавши"],
    "перлюстрировавши": ["перлюстрировав"],
    "перманганат калия": ["марганцовокислый калий", "марганцовка"],
    "перманентно": ["непрерывно", "постоянно"],
    "перманентность": ["непрерывность", "постоянство"],
    "перманентный": ["постоянный", "беспрерывный", "непрерывный", "бесконечный"],
    "перманентный макияж": ["татуаж"],
    "пермеатальный": ["интрамеатальный"],
    "пермская область": ["молотовская область"],
    "пермь": ["пермский период"],
    "перовой": ["перьевой"],
    "пероксид": ["перекись"],
    "пероксид водорода": ["перекись водорода"],
    "пероксосульфат": ["персульфат"],
    "перостан": ["оростан"],
    "перпендикулярно": ["параллельно", "фиолетово"],
    "перпендикулярный": ["прямой", "вертикальный"],
    "перпетуум-мобиле": ["вечный двигатель"],
    "перрон": ["платформа"],
    "перс": ["иранец"],
    "персеваль": ["персиваль"],
    "персеполис": ["персеполь"],
    "персеполь": ["персеполис"],
    "персептрон": ["перцептрон"],
    "персептронный": ["перцептронный"],
    "персефона": ["персефонея", "ферсефонея", "ферсефона", "феррефатта", "кора", "прозерпина"],
    "персея американская": ["авокадо"],
    "перси": ["грудь", "торс"],
    "персианин": ["перс", "персиянин", "кизильбаш", "хазар"],
    "персида": ["фарс", "парс"],
    "персидская материя": ["парча"],
    "персидский": ["иранский", "фарси"],
    "персидский залив": ["арабский залив"],
    "персидский язык": ["фарси", "персидский"],
    "персифлировав": ["персифлировавши"],
    "персифлировавши": ["персифлировав"],
    "персифлирование": ["высмеивание", "персифляж"],
    "персифлировать": ["высмеивать", "вышучивать", "иронизировать"],
    "персифляж": ["персифлирование"],
    "персифляция": ["астеизм"],
    "персия": ["иран"],
    "персиянин": ["персианин"],
    "персиянка": ["иранка", "персидка"],
    "персобюро": ["персбюро"],
    "персона": ["личность", "особа", "человек", "субъект", "лицо"],
    "персона нон грата": ["изгой"],
    "персонаж": ["лицо", "амплуа", "герой", "особа", "личность"],
    "персонал": ["кадры", "коллектив", "штат", "кадровый состав", "личный состав"],
    "персонализировав": ["персонализировавши"],
    "персонализировавши": ["персонализировав"],
    "персонально": ["лично", "индивидуально"],
    "персональный": ["личный", "индивидуальный", "собственный", "кадровый"],
    "персональный компьютер": ["пк", "персоналка", "комп", "персональная эвм", "пэвм"],
    "персонификация": ["антропоморфизм"],
    "персонифицировав": ["персонифицировавши"],
    "персонифицировавши": ["персонифицировав"],
    "персонифицировать": ["одушевить", "одушевлять", "олицетворить", "олицетворять", "очеловечить", "очеловечивать", "одухотворить", "одухотворять", "персонализировать"],
    "перспективный": ["многообещающий", "подающий надежды", "будущий"],
    "перспирация": ["потение"],
    "перст": ["палец"],
    "перстосложение": ["перстосложенье"],
    "перстративный": ["перестилаемый"],
    "персульфан": ["персероводород", "дисероводород"],
    "персульфат": ["пероксосульфат"],
    "персьют": ["пасьют"],
    "пертинентность": ["точность", "релевантность"],
    "пертинентный": ["релевантный"],
    "пертурбация": ["буча", "возмущение", "катаклизм", "потрясение", "кризис", "перестройка", "метаморфоза", "встряска", "свистопляска", "передряга", "катавасия"],
    "перу": ["республика перу"],
    "перфектный": ["перфективный", "совершенный"],
    "перфекционист": ["идеалист"],
    "перфидност": ["вероломство", "изневяра", "изменничество"],
    "перфокарта": ["карта"],
    "перфоратор": ["шлямбур", "прерыватель"],
    "перфораторий": ["апикальное тельце", "акросома"],
    "перфорационный": ["продырявленный"],
    "перфорация": ["перфорирование", "просечка", "прободение"],
    "перфорировав": ["перфорировавши"],
    "перфорировавши": ["перфорировав"],
    "перформансист": ["перформер"],
    "перформер": ["перформансист"],
    "перфторан": ["голубая кровь"],
    "перфторуглеводород": ["перфторуглерод"],
    "перфузатор": ["инфузомат", "линеамат"],
    "перхав": ["перхавши"],
    "перхавши": ["перхав"],
    "перханье": ["перхание"],
    "перхнув": ["перхнувши"],
    "перхнувши": ["перхнув"],
    "перхота": ["перхание"],
    "перцеед": ["перцеяд", "тукан"],
    "перцентиль": ["процентиль"],
    "перцепировав": ["перцепировавши"],
    "перцепировавши": ["перцепировав"],
    "перцептронный": ["персептронный"],
    "перцеяд": ["перцеед", "тукан"],
    "перципировав": ["перципировавши"],
    "перципировавши": ["перципировав"],
    "перчаточка": ["перчатка"],
    "перчив": ["перчивши"],
    "перчивши": ["перчив"],
    "першение": ["першенье"],
    "першенье": ["першение"],
    "першерон": ["битюг"],
    "першив": ["першивши"],
    "першивши": ["першив"],
    "першить": ["зудеть", "щекотать"],
    "перьевой": ["перовой", "перяной", "сделанный", "из", "перьев"],
    "песах": ["пасха"],
    "песельник": ["певец", "песенник", "хорист", "певун"],
    "песельница": ["песенница"],
    "песец": ["полярная лисица", "арктическая лиса"],
    "песков": ["песочное"],
    "пескоразбрасыватель": ["распределитель"],
    "песнетворчество": ["песнотворчество"],
    "песнопенье": ["песнопение"],
    "песнотворчество": ["песнетворчество"],
    "песнь": ["песня", "поэма", "глава"],
    "песня": ["песнь"],
    "песок": ["сахарный песок"],
    "песок сыплется": ["божий одуванчик", "болезный", "ветхий", "древний", "дряхлый", "престарелый", "при смерти", "слабый", "старая песочница", "старая перечница", "старый"],
    "песочек": ["песок", "сахарный песок"],
    "песочив": ["песочивши"],
    "песочивши": ["песочив"],
    "песочно-коричневый": ["коричнево-песочный"],
    "песочный": ["песчаный"],
    "пессимистичный": ["безнадёжный", "пессимистический", "мрачный", "печальный", "унылый"],
    "пест": ["тёрочник", "курант", "пестик", "макогон"],
    "пестав": ["пеставши"],
    "пеставши": ["пестав"],
    "пестерь": ["котомка"],
    "пестик": ["плодник", "гинецей", "тёрочник", "пест", "курант", "пистолет", "пистик"],
    "пестиковый": ["пестичный"],
    "пестичный": ["пестиковый"],
    "пестовав": ["пестовавши"],
    "пестовавши": ["пестовав"],
    "пестовать": ["нянчить", "воспитывать", "лелеять", "холить"],
    "пестрев": ["пестревши"],
    "пестревши": ["пестрев"],
    "пестреться": ["пестреть"],
    "пестрив": ["пестривши"],
    "пестривши": ["пестрив"],
    "пестрить": ["испещрять", "рябить"],
    "пестроцветный": ["многоцветный", "разноцветный"],
    "пестрядь": ["затрапез"],
    "пестум": ["посейдония"],
    "пестёрка": ["корзинка"],
    "песчаный": ["песочный"],
    "пет-проект": ["сайд-проект"],
    "петанкуист": ["петанкер", "петанкист"],
    "петардний": ["петардовий"],
    "петел": ["петух", "кочет"],
    "петербург": ["санкт-петербург", "ленинград", "петроград", "град петров", "северная венеция", "северная пальмира", "пальмира севера", "финская пальмира", "питер", "путинбург"],
    "петербургский": ["петроградский", "питерский", "ленинградский", "санкт-петербургский"],
    "петербуржанка": ["петербурженка", "петербуржка"],
    "петербурженка": ["петербуржанка", "петербуржка", "ленинградка", "петроградка", "питербургерша", "петробургерша"],
    "петербуржец": ["петербургец", "петербуржанин", "питерец", "ленинградец", "петроградец"],
    "петербуржка": ["петербуржанка", "петербурженка"],
    "петербуржский": ["питерский", "ленинградский", "санкт-петербургский", "санкт-петербуржский"],
    "петергоф": ["петродворец"],
    "петие": ["петье"],
    "петиметр": ["щеголь", "франт", "вертопрах", "ухаживатель"],
    "петитный": ["петитовый"],
    "петитовый": ["петитный"],
    "петиционер": ["заявитель"],
    "петиция": ["ходатайство"],
    "петлеобразный": ["петлеподобный"],
    "петлив": ["петливши"],
    "петливши": ["петлив"],
    "петля": ["силок", "виселица", "верёвка", "удавка", "повешение", "мёртвая петля", "петля нестерова", "круг", "кольцо", "крюк"],
    "петля мёбиуса": ["лента мёбиуса", "лист мёбиуса"],
    "петля нестерова": ["мёртвая петля"],
    "петляв": ["петлявши"],
    "петлявши": ["петляв"],
    "петлянье": ["петляние"],
    "петмез": ["рачел"],
    "петнадесет": ["петнайсет"],
    "петрефактология": ["петроматогнозия", "петрология"],
    "петрив": ["петривши"],
    "петривши": ["петрив"],
    "петрификат": ["кальцинат"],
    "петро": ["пётр"],
    "петрогенез": ["литогенез"],
    "петрогенезис": ["петрогония"],
    "петроглиф": ["писаница"],
    "петрогония": ["петрогенезис", "петрогения"],
    "петроград": ["петрополь", "петербург", "питер", "санкт-петербург", "ленинград"],
    "петроградец": ["петербуржец", "ленинградец", "питерец"],
    "петроградский": ["ленинградский"],
    "петроградъ": ["санктъ-петербургъ"],
    "петродворец": ["петергоф", "город фонтанов", "жемчужина искусств", "столица фонтанов"],
    "петрозаводск": ["петровская слобода", "птз", "петрик"],
    "петрозит": ["апицит"],
    "петрократия": ["петрогосударство"],
    "петролейный эфир": ["нефтяной эфир", "масло шервуда"],
    "петролеум": ["нефть"],
    "петрология": ["петрофактология", "петроматогнозия", "петрография"],
    "петроматогнозия": ["петрефактология", "петрология"],
    "петроний": ["петронио"],
    "петропавловск-камчатский": ["петропавловск"],
    "петрополь": ["санкт-петербург", "петербург", "питер", "петроград", "ленинград"],
    "петросянив": ["петросянивши"],
    "петросянивши": ["петросянив"],
    "петротип": ["литотип"],
    "петрушка": ["петруша", "петруха"],
    "петун": ["кочет", "кур", "певень", "петух", "пестун", "елда", "кляп", "конец", "куль", "мужское достоинство", "пенис", "пиписька", "писька", "хер", "хрен"],
    "петух": ["задира", "забияка", "буян", "опущенный", "обиженный", "мент", "легавый"],
    "петушатник": ["обиженка"],
    "петуший": ["петушиный"],
    "петушиный": ["петуший"],
    "петушня": ["петух"],
    "петушок": ["петух"],
    "петь": ["восхвалять", "воспевать", "воздавать хвалу"],
    "петь осанну": ["восклицать осанну", "славословить", "восхвалять"],
    "петье": ["петие"],
    "петька": ["петя", "пётр"],
    "петя": ["пётр"],
    "пехота": ["инфантерия", "пехтура", "пехотинец"],
    "пехотинец": ["инфантерист"],
    "пехотинка": ["солдатка", "боец", "рядовая", "пехота", "инфантеристка"],
    "пехотный": ["инфатерский"],
    "пехтерь": ["корзина", "пестерь", "бехтерь", "пентюх"],
    "пехтура": ["пехота", "инфантерия", "пехотинец", "пехотинцы", "пешая ходьба", "пеший ход", "пешкодрал", "одиннадцатый маршрут"],
    "пехтурой": ["пешком", "пешкодралом", "пёхом", "одиннадцатым маршрутом"],
    "печалба": ["полза", "изгода", "актив", "резултат", "интерес", "кяр"],
    "печалив": ["печаливши"],
    "печаливши": ["печалив"],
    "печалить": ["огорчать", "кручинить", "сокрушать", "расстраивать"],
    "печалиться": ["грустить", "унывать", "кручиниться", "горевать", "тужить", "скорбеть"],
    "печаловав": ["печаловавши"],
    "печаловавши": ["печаловав"],
    "печалованье": ["печалование"],
    "печаль": ["уныние", "тоска", "грусть", "забота"],
    "печалька": ["огорчение"],
    "печальник": ["заступник"],
    "печально": ["грустно", "уныло", "прискорбно"],
    "печальный": ["грустный", "огорчённый", "опечаленный", "огорчительный", "прискорбный"],
    "печатав": ["печатавши"],
    "печатавши": ["печатав"],
    "печатание": ["печать"],
    "печатанье": ["печатание"],
    "печатлев": ["печатлевши"],
    "печатлевши": ["печатлев"],
    "печатлеть": ["запечатлевать"],
    "печатник": ["типограф", "типографщик"],
    "печатывав": ["печатывавши"],
    "печатывавши": ["печатывав"],
    "печать": ["печатание", "пресса", "штамп"],
    "печенег": ["команы"],
    "печень": ["печёнка", "ливер"],
    "печенька": ["печенюшка"],
    "печка": ["печь"],
    "печки-лавочки": ["мелочь", "пустяк", "тра-ля-ля"],
    "печора": ["пэцора"],
    "печорское море": ["баренцево море"],
    "печь": ["печка"],
    "печься": ["испекаться", "жариться"],
    "печёный": ["испечённый"],
    "пешавар": ["пурушапура"],
    "пешедралом": ["пёхом", "пешочком", "пешкодралом", "пешком", "пешечком", "на своих двоих", "на своих на двоих"],
    "пешеход": ["пешеходец"],
    "пешечком": ["пешочком", "пешком", "одиннадцатый маршрут"],
    "пешешествовав": ["пешешествовавши"],
    "пешешествовавши": ["пешешествовав"],
    "пеши": ["назд"],
    "пешка": ["шашка", "марионетка", "шестёрка", "пеший", "переход"],
    "пешкаш": ["бахшиш"],
    "пешкодралом": ["пёхом", "пешкодрапом", "одиннадцатый маршрут"],
    "пешкодрапом": ["пешкодралом", "пёхом", "одиннадцатый маршрут"],
    "пешком": ["пешочком", "пешечком", "пешиком", "пешаком", "пешкодралом", "пешкарусом", "пешим ходом", "на своих ногах", "на своих двоих", "одиннадцатый маршрут"],
    "пешоб": ["шоша", "бавл", "мезак"],
    "пешочком": ["пешечком", "пешком", "одиннадцатый маршрут"],
    "пещера": ["вертеп", "туннель", "каверна", "полость", "антрум"],
    "пещерный": ["доисторический"],
    "пещур": ["пестерь"],
    "пж": ["пожалуйста"],
    "пзу": ["постоянное запоминающее устройство"],
    "пи": ["лудольфово число"],
    "пи-мезоатом": ["пионный атом"],
    "пи-мезон": ["пион"],
    "пи-пи": ["мочиться", "пись-пись"],
    "пиа": ["пиагдан"],
    "пиала": ["плошка"],
    "пианино": ["фоно"],
    "пианист": ["клавишник"],
    "пиар": ["связи с общественностью", "реклама", "показуха"],
    "пиар-агентство": ["пиар-компания", "пиар-контора", "пиар-фирма"],
    "пиар-акция": ["пиар-мероприятие"],
    "пиар-группа": ["пиар-команда"],
    "пиар-команда": ["пиар-группа"],
    "пиар-компания": ["пиар-агентство", "пиар-контора", "пиар-фирма"],
    "пиар-контора": ["пиар-агентство", "пиар-компания", "пиар-фирма"],
    "пиар-мероприятие": ["пиар-акция"],
    "пиар-служба": ["пиар-структура"],
    "пиар-структура": ["пиар-служба"],
    "пиар-фирма": ["пиар-агентство", "пиар-компания", "пиар-контора"],
    "пиарив": ["пиаривши"],
    "пиаривши": ["пиарив"],
    "пиарист": ["пиарщик", "пиармен", "пиаровец"],
    "пиарить": ["рекламировать", "продвигать"],
    "пиармен": ["пиарист", "пиарщик", "пиаровец"],
    "пиарный": ["пиаровский", "пиарский"],
    "пиаровец": ["пиарист", "пиармен", "пиарщик"],
    "пиаровский": ["пиарный", "пиарский"],
    "пиарский": ["пиарный", "пиаровский"],
    "пиарщик": ["пиарист", "пиармен", "пиаровец", "пиараст"],
    "пиаффе": ["рысь"],
    "пивав": ["пивавши"],
    "пивавши": ["пивав"],
    "пивас": ["пивасик"],
    "пивасик": ["пивас", "пиво", "полпиво", "пивко", "пивцо", "пивчелло", "пивушко", "брага", "бражка", "клыга", "перевара", "шалманка", "сидр"],
    "пивзавод": ["пивоварня"],
    "пивко": ["пивцо", "пивасик"],
    "пивная": ["пивнушка"],
    "пивнуха": ["пивная", "пивбар", "пивзал", "паб", "пивник", "пивнуля", "пивнушка", "пивня", "пивняк", "пивняха", "пивнячка", "пивнячок", "пивняш", "пивняшка"],
    "пивняк": ["пивная", "пивбар", "пивнуля", "пивнуха", "пивнушка", "пивня", "пивняха", "пивнячка", "пивняш", "пивняшка", "пивнячок"],
    "пиво": ["пенное", "джон ячменное зерно"],
    "пивоваренный": ["пивоварный"],
    "пивоварня": ["пивзавод"],
    "пиволюб": ["пивоман"],
    "пивоман": ["пиволюб"],
    "пивохлёб": ["пиволюб", "пивопийца", "пивопиец", "пивоголик"],
    "пивцо": ["пивко"],
    "пивши": ["пив"],
    "пигалица": ["чибис"],
    "пигмалионизм": ["пигмалионофилия", "монументофилия", "иконолагния"],
    "пигмент": ["краситель"],
    "пигментация": ["окрашивание", "окраска"],
    "пигментировав": ["пигментировавши"],
    "пигментировавши": ["пигментировав"],
    "пидарас": ["козёл", "мудак", "урод"],
    "пиджак": ["пинжак", "пинджак", "спинжак", "спенжик", "клифт", "лепень", "жакет"],
    "пидовка": ["педовка"],
    "пидор": ["козёл", "мудак", "гондон", "гандон"],
    "пидорас": ["козёл", "урод", "мудак"],
    "пидорасив": ["пидорасивши"],
    "пидорасивши": ["пидорасив"],
    "пидорасить": ["ебать", "пидорить", "драить"],
    "пидорг": ["пидорас", "пидарас"],
    "пидорев": ["пидоревши"],
    "пидоревши": ["пидорев"],
    "пидорив": ["пидоривши"],
    "пидоривши": ["пидорив"],
    "пидорить": ["драить", "начищать", "пидорасить", "пиздовать", "тащиться"],
    "пидорство": ["жопство", "мудотяпство", "блядство", "херство", "ёбство", "вротъебанство", "хуйство", "пиздомудство"],
    "пидрахуй": ["кидалов"],
    "пиемия": ["гноекровие"],
    "пиетет": ["благоговение", "почтение", "венерация"],
    "пиже": ["сянгяря", "аф кенерьф"],
    "пижек": ["охлюв"],
    "пижма": ["вротич", "глистник", "девятильник", "девятиха", "десятиха", "дикая рябина", "дикая рябинка", "козельник", "полевая рябина", "пуговичник", "романник", "рябишник", "сузик"],
    "пижня": ["фигня", "херня"],
    "пижон": ["щёголь", "франт"],
    "пижонив": ["пижонивши"],
    "пижонивши": ["пижонив"],
    "пизда горит": ["чешется манда", "чешется пиздища", "чешется пиздище", "пизда чешется"],
    "пизда нестроевая": ["мурло шестиугольное", "пизда тебя родила"],
    "пизда пилоткой": ["голодная пизда"],
    "пизда рулю": ["приплыли"],
    "пизда чешется": ["чешется манда", "чешется пиздища", "чешется пиздище", "пизда горит"],
    "пиздабол": ["пиздобол", "болтун", "трепло", "пустомеля"],
    "пизданув": ["пизданувши"],
    "пизданувши": ["пизданув"],
    "пиздануть": ["сказануть"],
    "пиздануться": ["грохнуться", "ёбнуться", "хуякнуться", "шандарахнуться", "повредиться рассудком", "свернуться", "сойти с ума", "сойти с рельсов", "слететь с катушек", "ебануться"],
    "пиздарики": ["пиздец"],
    "пиздатее": ["пиздатей", "попиздатее", "попиздатей", "пизже", "попизже", "пиздаче", "попиздаче"],
    "пиздато": ["отлично", "здорово", "замечательно", "великолепно", "чудесно", "охуительно", "охуетительно"],
    "пиздатый": ["замечательный", "чудесный", "великолепный", "пиздастый", "пиздатейший", "распиздатейший", "заебатый", "заебательский", "ебейший", "охуенный", "охуительный", "охуетительный", "опиздохуительный", "качественный", "высококачественный"],
    "пиздев": ["пиздевши"],
    "пиздевши": ["пиздев"],
    "пизделушка": ["безделушка"],
    "пиздеть": ["лгать", "врать", "сочинять", "обманывать", "трепаться", "гнать", "гнать фуфло", "заливать", "нести вздор", "пиздоболить"],
    "пиздец": ["крах", "катастрофа", "финал", "финиш", "смерть", "кранты", "каюк", "крышка", "капут", "кирдык", "аут", "хана", "амба", "труба", "вилы"],
    "пиздецома": ["спидорак"],
    "пиздив": ["пиздивши"],
    "пиздивши": ["пиздив"],
    "пиздливый": ["празднословный", "пиздлявый"],
    "пиздлявый": ["празднословный", "пиздливый"],
    "пиздоблядство": ["хуеёбство", "хуета", "хуита", "разпиздяйство", "хуйство", "залупенство"],
    "пиздобол": ["обманщик", "лгун", "лжец", "враль", "врун", "врунишка", "брехун", "брехло", "трепло", "трепач", "пиздабол", "пиздомол", "пиздомеля", "болтун", "словоблуд"],
    "пиздоболив": ["пиздоболивши"],
    "пиздоболивши": ["пиздоболив"],
    "пиздобольство": ["лживость"],
    "пиздобратия": ["братия", "шатия-братия", "шайка", "шайка-лейка", "шобла-ёбла"],
    "пиздовав": ["пиздовавши"],
    "пиздовавши": ["пиздовав"],
    "пиздовать": ["пидорить"],
    "пиздоделие": ["пиздоделье"],
    "пиздодельный": ["работящий", "додельный", "дельный", "деловой"],
    "пиздой мух ловить": ["ротозейничать"],
    "пиздой накрыться": ["накрыться медным тазом", "медным тазом накрыться", "накрыться пиздой", "пойти пиздой", "пойти по пизде", "гавкнуться пиздой", "пиздой пойти", "по пизде пойти", "пиздой гавкнуться", "потерпеть фиаско", "потерпеть неудачу", "оказаться несостоятельным", "умереть", "погибнуть", "отдать богу душу"],
    "пиздолиз": ["полировщик"],
    "пиздолизка": ["лесбиянка"],
    "пиздопроёбище": ["подлец", "мерзавец", "мудак", "мудло", "мудачина", "уёбище", "уёбок", "ёбаногандонный хуепедераст", "хуепуполо залупоглазое", "хуепуполо промандоблядское", "блядоёбина хуеротая", "блядомудина пиздокрылая", "блядомудина пиздорылая"],
    "пиздорванец": ["мальчишка", "пацан", "сопляк", "парень", "молодой человек", "распиздяй", "разъебай", "разъёба", "сволочь", "гад", "гадина"],
    "пиздорванец хуев": ["пиздорванец ёбаный"],
    "пиздорванка": ["женщина лёгкого поведения", "куртизанка", "проститутка", "блядь", "курва", "лярва", "марамойка", "потаскуха", "прошмандовка", "шалава", "шлюха"],
    "пиздоремонтник": ["гинеколог"],
    "пиздос": ["пиздец"],
    "пиздострадалец": ["пиздодуй", "пиздострадатель"],
    "пиздуна запускать": ["запускать пиздуна"],
    "пиздуна запустить": ["запустить пиздуна"],
    "пизды дать": ["дать пизды"],
    "пиздык": ["бац", "бах", "бабах", "шлёп", "блямс", "трах", "трах-тарарах", "бумс", "хрясь", "фигак", "хренак", "хренакс", "херак", "херакс", "членак"],
    "пиздюк": ["малолетний", "мелкий", "дошколёнок", "школота", "пиздрон", "пиздюшонок", "пиздёныш", "проныра", "плут", "плутишка", "хитрец", "хитрован", "сволочь", "подлец", "засранец"],
    "пиздюлей отхватить": ["отхватить люлей", "выхватить люлей", "огрести люлей", "люлей отхватить", "люлей выхватить", "люлей огрести", "отхватить пиздюлей", "выхватить пиздюлей", "огрести пиздюлей", "пиздюлей выхватить", "пиздюлей огрести"],
    "пиздюль": ["затрещина", "звездюль", "пендаль", "пендель", "трандюль", "тумак", "физическое замечание", "пиздюлина", "пиздячка", "ебук", "пиздюлинка", "выволочка", "выговор", "нагоняй", "пистон"],
    "пиздюхав": ["пиздюхавши"],
    "пиздюхавши": ["пиздюхав"],
    "пиздюхать": ["пиздовать"],
    "пиздякнуться": ["свалиться", "брякнуться", "сверзиться", "пиздануться", "наебнуться", "уебаться", "хуякнуться"],
    "пиздярив": ["пиздяривши"],
    "пиздяривши": ["пиздярив"],
    "пиздятина": ["пиздятинка", "сметана", "заёбина", "баба", "бабняк", "бабьё", "девичник", "малинник", "блядюшник", "блядьво", "пиздюшник", "пёзды", "конец", "крах", "кранты"],
    "пиздятинка": ["пиздятина"],
    "пиздячив": ["пиздячивши"],
    "пиздячивши": ["пиздячив"],
    "пиздящий": ["ворующий"],
    "пиздёж": ["враньё", "обман", "ложь", "наглая ложь", "художественный свист", "телега", "лапшерезка", "брехня", "абвгдёж", "болтовня", "мандёж", "пиздёж-мандёж", "мандёж-пиздёж"],
    "пизже": ["круче", "лучше"],
    "пизолит": ["шпрудельштейн"],
    "пиит": ["поэт"],
    "пиитический": ["поэтический"],
    "пик победы": ["пик военных топографов"],
    "пика": ["копьё", "остриё"],
    "пикав": ["пикавши"],
    "пикавши": ["пикав"],
    "пикантный": ["пряный"],
    "пикапер": ["соблазнитель"],
    "пикапив": ["пикапивши"],
    "пикапивши": ["пикапив"],
    "пикапить": ["соблазнять"],
    "пикардский": ["пикардийский"],
    "пикареска": ["плутовской роман"],
    "пикарт": ["адамит"],
    "пикать": ["пищать"],
    "пикацизм": ["экскрементофилия", "пика", "парорексия", "аллотриофагия"],
    "пикгард": ["накладка"],
    "пике": ["пикирование"],
    "пикетировав": ["пикетировавши"],
    "пикетировавши": ["пикетировав"],
    "пикетовый": ["пикейный"],
    "пикировав": ["пикировавши"],
    "пикировавши": ["пикировав"],
    "пикироваться": ["перебраниваться"],
    "пикировщик": ["пикирующий бомбардировщик"],
    "пикирующий бомбардировщик": ["пикировщик"],
    "пикнида": ["пикнидий"],
    "пикнидий": ["пикнида"],
    "пикник": ["пикноид"],
    "пикнический": ["гиперстенический"],
    "пикноклин": ["жидкий грунт"],
    "пикнон": ["пикн"],
    "пикнув": ["пикнувши"],
    "пикнувши": ["пикнув"],
    "пикнуть": ["пискнуть", "вякнуть"],
    "пико-": ["микромикро-"],
    "пиковка": ["пика"],
    "пиковый": ["вершинный"],
    "пикограмм": ["пг"],
    "пикометр": ["микромикрон"],
    "пикосекунда": ["микромикросекунда"],
    "пикофарад": ["пикофарада"],
    "пикселив": ["пикселивши"],
    "пикселивши": ["пикселив"],
    "пикселизировав": ["пикселизировавши"],
    "пикселизировавши": ["пикселизировав"],
    "пикселить": ["пикселизировать"],
    "пикульник": ["жабрей"],
    "пикча": ["картинка"],
    "пиленгас": ["пеленгас", "пелингас"],
    "пиление": ["пиленье", "пилка"],
    "пиленье": ["пиление"],
    "пилеолус": ["дзуккетто"],
    "пилив": ["пиливши"],
    "пиливав": ["пиливавши"],
    "пиливавши": ["пиливав"],
    "пиливши": ["пилив"],
    "пилигрим": ["паломник", "странник", "путник"],
    "пилигримка": ["паломница"],
    "пиликав": ["пиликавши"],
    "пиликавши": ["пиликав"],
    "пиликнув": ["пиликнувши"],
    "пиликнувши": ["пиликнув"],
    "пилильщик": ["пильщик"],
    "пилинг": ["эксфолиация"],
    "пилка": ["распилка"],
    "пиллагон": ["зина", "зинапоя", "нардбон"],
    "пиломатериал": ["пилопродукция"],
    "пилопродукция": ["пиломатериал"],
    "пилоро-": ["пилор-"],
    "пилос": ["наварин"],
    "пилосос": ["пилосмок", "порохотяг", "пилотяг"],
    "пилот": ["лётчик", "навигатор"],
    "пилот-проект": ["проект-пилот"],
    "пилотаж": ["пилотирование"],
    "пилотесса": ["лётчица"],
    "пилотировав": ["пилотировавши"],
    "пилотировавши": ["пилотировав"],
    "пилотирование": ["пилотаж"],
    "пилотный": ["экспериментальный", "тестовый", "пилотский"],
    "пилоточник": ["лизун"],
    "пильник": ["терпуг", "напилок"],
    "пильчатый": ["пилообразный", "зубчатый", "зазубренный"],
    "пильщик": ["пилильщик"],
    "пилюга": ["пилюка"],
    "пилюка": ["пилюга"],
    "пилядь": ["блядь"],
    "пилястр": ["пилястра"],
    "пилястра": ["пилястр"],
    "пим": ["валенок", "катанок", "торбас", "унт"],
    "пима": ["акимель-оодхам"],
    "пимарицин": ["натамицин"],
    "пимен": ["пимин"],
    "пимка": ["пинка"],
    "пимокатничав": ["пимокатничавши"],
    "пимокатничавши": ["пимокатничав"],
    "пимпинелла": ["бедренец", "камнеломка"],
    "пин": ["пароль"],
    "пин-код": ["пин"],
    "пинав": ["пинавши"],
    "пинавши": ["пинав"],
    "пинагор": ["морской воробей"],
    "пинакотека": ["картинная галерея"],
    "пинал": ["нуны", "нылпи", "бала", "бебей"],
    "пинать": ["толкать", "ударять", "бить", "лягать"],
    "пинать творог в биндейку": ["пинать творог"],
    "пинг-понг": ["настольный теннис"],
    "пингвинарий": ["пингвинариум"],
    "пингвиний": ["пингвинный"],
    "пингвинный": ["пингвиновый", "пингвиний"],
    "пинге": ["ётка", "ётка-пинге"],
    "пинговав": ["пинговавши"],
    "пинговавши": ["пинговав"],
    "пиндитный": ["привередливый", "въедливый", "педантичный", "напыщенный"],
    "пиндос": ["америкос", "янкес"],
    "пиндосия": ["пиндостан", "сшп"],
    "пиндосский": ["американский"],
    "пиндоштан": ["тасаввур кардан"],
    "пинежье": ["припинежье"],
    "пиния": ["пинна", "сосна итальянская"],
    "пинка": ["пинк"],
    "пиноль": ["гильза"],
    "пинсеттер": ["пинспоттер"],
    "пинспоттер": ["пинсеттер"],
    "пинтия": ["скъперник", "скръндза", "стипца", "циция", "вариклечко"],
    "пинхол": ["стеноп"],
    "пинцет": ["щипцы"],
    "пинч": ["жокс"],
    "пинчос": ["пинчо"],
    "пинькав": ["пинькавши"],
    "пинькавши": ["пинькав"],
    "пиньос": ["пеней"],
    "пио-": ["пи-"],
    "пиогенный": ["гноеродный"],
    "пиомиозит": ["бунгпагга"],
    "пионер": ["первопоселенец", "первопроходец", "новатор", "революционер", "сапёр", "красногалстучник", "чайник"],
    "пионерский": ["колонистский", "первопроходческий", "новаторский", "сапёрный"],
    "пионерский галстук": ["красный галстук", "красная косынка", "красная косыночка", "ошейник"],
    "пиорея": ["гноетечение", "пиоррея"],
    "пиоррея": ["пиорея"],
    "пиперазин": ["гексагидропиразин", "диэтилендиамин"],
    "пиперидин": ["пентаметиленимин"],
    "пипец": ["конец", "полная жопа", "капец", "ппц"],
    "пипидастр": ["помпон"],
    "пипикав": ["пипикавши"],
    "пипикавши": ["пипикав"],
    "пипикать": ["бибикать"],
    "пиписька": ["писька", "гениталии"],
    "пипися": ["пися"],
    "пипифакс": ["туалетная бумага", "туалетка", "подтирка"],
    "пипс": ["пункт"],
    "пипсовка": ["скальпинг", "пипсование"],
    "пир": ["пиршество", "сражение", "сраженье", "битва", "война", "кровопролитие", "кровопролитье"],
    "пиразан": ["кампир"],
    "пирамидальный": ["пирамидный"],
    "пирамидон": ["амидопирин", "диметиламиноантипирин"],
    "пирамидонный": ["пирамидоновый", "амидопириновый"],
    "пирамидоновый": ["пирамидонный", "амидопириновый"],
    "пирамидончик": ["амидопиринчик"],
    "пирамидостроение": ["пирамидостроительство"],
    "пирамидостроитель": ["пирамидчик"],
    "пирамидостроительство": ["пирамидостроение"],
    "пирамидчик": ["пирамидостроитель"],
    "пиранья": ["пирайя"],
    "пират": ["корсар", "флибустьер", "приватир", "капер", "фальсификатор"],
    "пиратив": ["пиративши"],
    "пиративши": ["пиратив"],
    "пиратировав": ["пиратировавши"],
    "пиратировавши": ["пиратировав"],
    "пиратировать": ["пиратить"],
    "пиратить": ["пиратировать"],
    "пиратски": ["незаконно", "нелегально"],
    "пиратствовав": ["пиратствовавши"],
    "пиратствовавши": ["пиратствовав"],
    "пиратствовать": ["пиратить"],
    "пирексия": ["лихорадка", "гипертермия"],
    "пиренейский полуостров": ["иберийский полуостров"],
    "пиретрум": ["ромашник", "ромашка"],
    "пирит": ["инкский камень", "серный колчедан", "железный колчедан", "купоросный колчедан", "железная печёночная руда"],
    "пиритный": ["пиритовый"],
    "пиритовый": ["пиритный"],
    "пирифлегетон": ["флегетон"],
    "пировав": ["пировавши"],
    "пировавши": ["пировав"],
    "пирограф": ["электровыжигатель"],
    "пирография": ["выжигание"],
    "пирожковая": ["пирожная"],
    "пирожная": ["пирожковая"],
    "пирожное": ["десерт", "сладкое", "третье блюдо"],
    "пирожок": ["каблук", "котомка", "пирожковоз", "шиньон"],
    "пирозаряд": ["пироболт", "пиропатрон"],
    "пирокластический": ["вулканогенный", "пепловый"],
    "пироксилин": ["тринитроцеллюлоза"],
    "пиролатрия": ["огнепоклонство"],
    "пироман": ["пироманьяк"],
    "пироманьяк": ["пироман"],
    "пиропатрон": ["пирозаряд"],
    "пироскаф": ["пароход"],
    "пиросмарагд": ["хлорофан"],
    "пиросульфит": ["метабисульфит", "дисульфит"],
    "пирофлегетон": ["флегетон", "пирифлегетон"],
    "пирофосфорный": ["дифосфорный"],
    "пиррихий": ["пириямб", "дибрахий"],
    "пиррова победа": ["победа пирра", "кадмейская победа"],
    "пиррон": ["полибензимидазопирролон"],
    "пирсинговав": ["пирсинговавши"],
    "пирсинговавши": ["пирсинговав"],
    "пиршество": ["фонтан"],
    "пиршествовав": ["пиршествовавши"],
    "пиршествовавши": ["пиршествовав"],
    "писалка": ["перо", "перодръжка"],
    "писало": ["стило", "стиль", "стилус"],
    "писанина": ["писулька"],
    "писаница": ["петроглиф"],
    "писанув": ["писанувши"],
    "писанувши": ["писанув"],
    "писаный": ["написанный", "расписной", "разукрашенный"],
    "писанье": ["вещь", "детище", "работа", "произведение", "создание", "творение", "плод", "труд", "вдохновение", "сочинение", "увраж", "вещица", "вещичка", "творчество"],
    "писар": ["фарзанд", "пур"],
    "писарь": ["писарюга"],
    "писатель": ["литератор", "писака", "бумагомарака", "щелкопёр", "графоман"],
    "писательный": ["писчий", "писательский"],
    "писательский": ["авторский"],
    "писательство": ["сочинительство"],
    "писательствовав": ["писательствовавши"],
    "писательствовавши": ["писательствовав"],
    "писать": ["писять", "пысать", "мочиться", "оправляться", "справлять нужду", "сикать", "ходить до ветру", "ссать"],
    "писать кипятком": ["восторгаться"],
    "писаться": ["писяться"],
    "писачка": ["писака"],
    "писец": ["переписчик", "писарь"],
    "писи": ["пк", "писишка", "писишник", "писюк"],
    "писишка": ["писишник", "писюк"],
    "писишник": ["писишка", "писюк"],
    "писк": ["пищание"],
    "пискав": ["пискавши"],
    "пискавши": ["пискав"],
    "пискливо": ["пискляво"],
    "пискливый": ["писклявый"],
    "пискля": ["пискун"],
    "писклявив": ["писклявивши"],
    "писклявивши": ["писклявив"],
    "писклявий": ["пискливий"],
    "пискляво": ["пискливо"],
    "писклявый": ["пискливый"],
    "писклёнок": ["пискун", "пискунчик", "птенец"],
    "пискнув": ["пискнувши"],
    "пискнувши": ["пискнув"],
    "пискулька": ["гусь-пискулька"],
    "пискун": ["пискля", "писклёнок", "пискунчик"],
    "пискунок": ["пискун", "писклёнок"],
    "пискунчик": ["писклёнок", "пискун"],
    "пискучий": ["пискливый"],
    "писнув": ["писнувши"],
    "писнувши": ["писнув"],
    "писок": ["обличчя", "рот"],
    "писта": ["пистайоки", "валда", "пистаёки"],
    "пистацит": ["эпидот"],
    "пистолет": ["пушка", "ствол", "волына", "короткоствол", "пехаль"],
    "пистолет-пулемёт": ["пп"],
    "пистолетчик": ["спортсмен-пистолетчик", "заправщик-пистолетчик"],
    "пистоль": ["луидор"],
    "пистон": ["капсюль"],
    "писулька": ["записка"],
    "писчебумажный": ["канцелярский"],
    "писывав": ["писывавши"],
    "писывавши": ["писывав"],
    "писька": ["пиписька"],
    "письменник": ["книжник"],
    "письменность": ["письмо", "письменный язык", "словесность", "литература"],
    "письменство": ["письменництво"],
    "письмо": ["письменность", "послание", "сообщение", "грамота"],
    "письмоводитель": ["делопроизводитель"],
    "письмоносец": ["почтальон"],
    "письмоносица": ["письмоноска", "почтальонша"],
    "письмоноска": ["письмоносица", "почтальонша", "почтальонка", "почтарка"],
    "письмоноша": ["почтальон", "письмоносец"],
    "писюк": ["писишка", "писишник"],
    "писюнок": ["пися", "писька", "писюн", "писюлька", "пиписька", "хуёк"],
    "пися": ["пиписька", "писька"],
    "писяв": ["писявши"],
    "писявши": ["писяв"],
    "писять": ["писить"],
    "писяться": ["писять"],
    "питав": ["питавши"],
    "питавши": ["питав"],
    "питание": ["еда", "кормление", "пища", "подкормка", "подпитка", "запитывание"],
    "питанье": ["питание"],
    "питать": ["кормить", "снабжать", "испытывать", "ощущать"],
    "питаться": ["есть", "работать"],
    "питаться акридами и диким мёдом": ["голодать", "недоедать", "алкать"],
    "питахайя": ["питайя", "драконов фрукт", "драконий фрукт", "драгонфрут"],
    "питбуль": ["питбультерьер"],
    "питбультерьер": ["пит", "питбуль"],
    "питейный": ["спиртной"],
    "питекантроп": ["варвар", "троглодит"],
    "питер": ["санкт-петербург", "ленинград", "петроград", "петербург", "град петров", "петрополь", "санкт-питербурх", "питербурх"],
    "питерец": ["петербуржец", "питерщик", "питеряк"],
    "питерский": ["петербургский", "петербуржский"],
    "питие": ["выпивание", "напиток"],
    "питный": ["питьевой"],
    "питомец": ["воспитанник", "вскормленник", "протеже", "ученик", "студент", "выпускник"],
    "питомица": ["приверженка", "сторонница"],
    "питомник": ["рассадник"],
    "питух": ["выпивоха"],
    "питч-сессия": ["питчинг"],
    "питчинг": ["питч-сессия"],
    "питывав": ["питывавши"],
    "питывавши": ["питывав"],
    "пить": ["выпивать", "пьянствовать", "бухать", "закладывать за воротник"],
    "пить мёртвую": ["пить мёртвую чашу"],
    "пить мёртвую чашу": ["пить мёртвую"],
    "питьевая вода": ["варёная вода", "газированная вода"],
    "питьевой": ["питейный"],
    "питьянтьятьяра": ["питянтятяра"],
    "питьё": ["выпивание", "напиток"],
    "пифагореизм": ["пифагорейство"],
    "пифагорейство": ["пифагореизм"],
    "пифийский": ["пифический"],
    "пифический": ["пифийский"],
    "пифия": ["предсказательница"],
    "пих": ["толчок"],
    "пихав": ["пихавши"],
    "пихавши": ["пихав"],
    "пиханье": ["пихание"],
    "пихатий": ["гордовитий", "погордливий", "спесивий", "чванливий", "самовпевнений"],
    "пихать": ["толкать"],
    "пихая": ["толкая"],
    "пихнув": ["пихнувши"],
    "пихнувши": ["пихнув"],
    "пихнуть": ["толкнуть", "трахнуть"],
    "пихора": ["пехора"],
    "пихтарник": ["пихтовник", "пихтач"],
    "пихтач": ["пихтарник", "пихтовник", "пихтовый лес", "пихтарь", "пихта"],
    "пихтия": ["желе"],
    "пихтовник": ["пихтарник", "пихтач"],
    "пиццайоло": ["пиццмейкер"],
    "пиццер": ["пиццайоло"],
    "пичиррос": ["пичир-пичир"],
    "пичкав": ["пичкавши"],
    "пичкавши": ["пичкав"],
    "пичкание": ["пичканье"],
    "пичкать": ["засовывать", "пихать", "заталкивать", "впихивать", "втискивать", "закармливать"],
    "пичуга": ["птичка", "пташка", "птаха", "пичужка"],
    "пичужка": ["птаха", "пташка", "птичка"],
    "пишатися": ["гордитися"],
    "пиши пропало": ["безнадёжно", "плохо дело", "хуже некуда"],
    "пишмание": ["пашмак"],
    "пишущий эти строки": ["автор"],
    "пища для размышлений": ["пища для ума"],
    "пищав": ["пищавши"],
    "пищавши": ["пищав"],
    "пищанье": ["пищание"],
    "пищать": ["вякать", "роптать"],
    "пищеваренье": ["пищеварение"],
    "пищевой": ["пищный"],
    "пищетрест": ["пищевой", "трест"],
    "пищност": ["разкош", "великолепие"],
    "пиявица": ["пиявка", "кровопийца", "кровосос", "угнетатель"],
    "пиявка": ["пьявка", "пиявица", "пивалка"],
    "пияница": ["пияч", "алкохолик"],
    "пияч": ["пияница", "алкохолик"],
    "пиёз": ["басал"],
    "пк": ["писи", "комп", "компьютер"],
    "плав": ["плавание"],
    "плавав": ["плававши"],
    "плававши": ["плавав"],
    "плаванье": ["плавание"],
    "плавари": ["плавцы"],
    "плавательный бассейн": ["басик"],
    "плавать": ["плыть", "купаться", "парить", "ходить", "путаться", "колебаться", "меняться", "изменяться"],
    "плавать в салате": ["в салате плавать"],
    "плавать как топор": ["тонуть", "идти ко дну"],
    "плавать как утюг": ["плавать как топор"],
    "плавающий танк": ["танк-амфибия"],
    "плавдок": ["плавучий док"],
    "плавединица": ["плавучий", "единица"],
    "плавень": ["флюс"],
    "плавив": ["плавивши"],
    "плавивши": ["плавив"],
    "плавик": ["плавиковый шпат", "фторид кальция"],
    "плавиковая кислота": ["фтористоводородная кислота", "фтороводородная кислота"],
    "плавить": ["расплавлять", "выплавлять"],
    "плавка": ["варка"],
    "плавказарма": ["пкз"],
    "плавки": ["плавари", "плавцы"],
    "плавно": ["ровно", "гладко"],
    "плавный": ["ровный", "мерный"],
    "плавсредство": ["плавательное средство"],
    "плавучий док": ["плавдок"],
    "плавый": ["гнедой"],
    "плагиат": ["плагиаторство"],
    "плагиатив": ["плагиативши"],
    "плагиативши": ["плагиатив"],
    "плагиатничав": ["плагиатничавши"],
    "плагиатничавши": ["плагиатничав"],
    "плагиаторша": ["воровка", "грабительница"],
    "плагиаторщик": ["плагиатор"],
    "плагиировав": ["плагиировавши"],
    "плагиировавши": ["плагиировав"],
    "плагин": ["надстройка"],
    "плазмалемма": ["цитолемма"],
    "плазменнодуговой": ["плазменно-дуговой"],
    "плазмин": ["фибринолизин"],
    "плазминоген": ["профибринолизин"],
    "плазмогамия": ["цитогамия"],
    "плазмолемма": ["цитолемма"],
    "плазмолиз": ["плазмолизис"],
    "плакав": ["плакавши"],
    "плакавши": ["плакав"],
    "плакальщица": ["плакуша", "плачея", "вопленица"],
    "плакат": ["афиша", "постер"],
    "плакать": ["лить слёзы", "проливать слёзы", "оплакивать"],
    "плакаться": ["жаловаться", "сетовать", "роптать", "ныть", "хныкать", "скулить"],
    "плакаться в жилетку": ["плакать в жилетку"],
    "плакировав": ["плакировавши"],
    "плакировавши": ["плакировав"],
    "плакировка": ["плакирование"],
    "плакодонт": ["плоскозубый"],
    "плакун": ["плакун-трава", "подбережник"],
    "плакун-трава": ["дербенник вязолистный", "дербенник иволистный"],
    "плакуша": ["плакальщица", "плачея", "вопленица"],
    "пламенев": ["пламеневши"],
    "пламеневши": ["пламенев"],
    "пламенеть": ["гореть", "пылать", "рдеть", "алеть"],
    "пламенник": ["факел", "флокс"],
    "пламенно-красный": ["огненно-красный", "пламенно-рыжий", "огненно-рыжий", "ярко-рыжий"],
    "пламенный": ["огненный", "горячий", "жгучий", "жаркий", "пылающий", "сияющий", "светящийся", "сверкающий", "ярко-красный", "коралловый", "кроваво-красный", "оранжево-красный", "пылкий", "страстный", "воодушевленный"],
    "пламень": ["пламя", "пыл"],
    "план": ["чертёж", "карта", "схема", "рисунок", "проекция", "проект", "намётка", "программа", "намерение", "умысел", "замысел", "задумка", "прожект", "показатель", "значение"],
    "план б": ["запасной вариант"],
    "план полёта": ["флайт-план"],
    "планария": ["ресничный червь"],
    "планарный": ["плоский", "плоскостной"],
    "планер": ["планёр"],
    "планета": ["родина", "земля", "земной шар", "мир", "сфера", "судьба"],
    "планетарность": ["широта", "глобальность", "всеобщность"],
    "планетезималь": ["протопланета"],
    "планетный": ["планетарный"],
    "планетовед": ["планетолог"],
    "планетоведение": ["планетология"],
    "планетоведческий": ["планетологический"],
    "планетологический": ["планетоведческий"],
    "планетотрясение": ["сейсмоактивность"],
    "планида": ["судьба", "участь", "доля", "планета"],
    "планиметрический": ["плоский", "двумерный", "двухмерный"],
    "планинг": ["ежедневник", "органайзер"],
    "планировав": ["планировавши"],
    "планировавши": ["планировав"],
    "планировать": ["проектировать", "замышлять", "задумывать", "собираться", "намереваться", "предполагать", "вознамериться", "намерен", "думать", "запланировать"],
    "плановав": ["плановавши"],
    "плановавши": ["плановав"],
    "плановать": ["планировать"],
    "плановая экономика": ["командная экономика"],
    "планово": ["планомерно"],
    "планово-оперативный": ["плановый"],
    "планово-предупредительный": ["профилактический"],
    "планомерность": ["методичность"],
    "планомерный": ["систематичный", "методичный"],
    "плантарная флексия": ["плантофлексия"],
    "плантарный": ["подошвенный"],
    "плантатор": ["рабовладелец", "эксплуататор"],
    "плантография": ["подография", "подоскопия"],
    "планшет": ["канцелярский планшет", "клипборд", "планшет обстановки", "планшетка", "графический планшет", "планшетный компьютер", "планшетник"],
    "планшетник": ["планшетный компьютер", "планшет"],
    "планшир": ["планширь", "планшер"],
    "планёр": ["планер"],
    "плаппарт": ["блапперт", "блафарт"],
    "пласировав": ["пласировавши"],
    "пласировавши": ["пласировав"],
    "пластав": ["пластавши"],
    "пластавши": ["пластав"],
    "пластбетон": ["полимербетон"],
    "пластик": ["пластическая масса", "пластмасса"],
    "пластиковая карта": ["пластиковая карточка", "карта", "карточка"],
    "пластиковый": ["пластмассовый"],
    "пластинка-гигант": ["гигант", "диск-гигант"],
    "пластинка-миньон": ["миньон"],
    "пластинчатоклювые": ["гусеобразные"],
    "пластифицировав": ["пластифицировавши"],
    "пластифицировавши": ["пластифицировав"],
    "пластифицирование": ["пластификация"],
    "пластицизм": ["пластичность"],
    "пластическая масса": ["пластмасса", "пластик"],
    "пластический": ["изящный", "пластичный"],
    "пластичный": ["стройный", "изящный", "гармоничный", "грациозный", "гибкий", "пластический"],
    "пластмасса": ["пластическая масса", "пластик"],
    "пластмассовый": ["пластиковый"],
    "пластовав": ["пластовавши"],
    "пластовавши": ["пластовав"],
    "пластовать": ["пластать"],
    "пластовый": ["пластовой"],
    "пластом": ["пласт", "неподвижно"],
    "пластосома": ["митохондрия", "хондриосома"],
    "пластырь": ["анаколемма", "анктер", "ацерид", "везикаторий", "горчичник", "гуммоза", "лейкопластырь", "липучка", "мушка", "наклейка", "дропакс", "пикатум", "фляст"],
    "плата": ["выплата", "вознаграждение", "возмещение", "компенсация", "уплата", "воздаяние"],
    "платав": ["платавши"],
    "платавши": ["платав"],
    "платан": ["чинар", "чинара"],
    "платея": ["платеи"],
    "платив": ["плативши"],
    "плативши": ["платив"],
    "платинировав": ["платинировавши"],
    "платинировавши": ["платинировав"],
    "платириния": ["плосконосость"],
    "платиспермический": ["билатерально-симметричный"],
    "платить": ["уплачивать", "отплачивать", "расплачиваться"],
    "платить натурой": ["расплачиваться натурой"],
    "платицефалия": ["плоскоголовость"],
    "платник": ["платный пруд"],
    "платный": ["оплачиваемый"],
    "платобазальтовый": ["трапповый", "плато-базальтовый"],
    "платок": ["плат", "носовой платок"],
    "платонович": ["платоныч"],
    "плаття": ["сукня"],
    "платье": ["одежда"],
    "платье-жакет": ["платье-жилет"],
    "платье-жилет": ["платье-жакет"],
    "платье-коктейль": ["коктейльное платье"],
    "платье-колонна": ["платье-труба"],
    "платье-комбинация": ["платье-сорочка"],
    "платье-рубашка": ["платье-рубаха"],
    "платье-сорочка": ["платье-комбинация"],
    "платье-стрейч": ["платье-чулок"],
    "платье-труба": ["платье-колонна"],
    "платье-футляр": ["платье-чехол"],
    "платье-чехол": ["платье-футляр"],
    "платье-чулок": ["платье-стрейч"],
    "платьишко": ["одежонка"],
    "платёж": ["плата", "оплата", "расчёт", "расчётная операция"],
    "плаун": ["ликоподиум"],
    "плахост": ["боязливост", "плашливост"],
    "плац": ["пляц"],
    "плац-парад": ["плац"],
    "плацебо": ["пустышка"],
    "плацента": ["детское место", "послед"],
    "плач": ["рыдание", "рёв", "слёзы"],
    "плачевно": ["печально"],
    "плачея": ["плакальщица", "плакуша", "вопленица"],
    "плачивав": ["плачивавши"],
    "плачивавши": ["плачивав"],
    "плашка": ["лерка"],
    "плашкот": ["плашкоут", "гондола"],
    "плашливост": ["боязливост", "страхливост", "плахост"],
    "плашмя": ["пластом", "пластью", "плахом", "лежмя", "лежняком", "навзничь", "ничком"],
    "плащ": ["верхнее платье"],
    "плащаница": ["саван"],
    "плащовка": ["плащевая ткань"],
    "плебей": ["мужлан", "быдло", "чернь"],
    "плебейски": ["по-плебейски"],
    "плебисцитарный": ["плебисцитный"],
    "плебисцитный": ["плебисцитарный"],
    "плебс": ["плебейство", "простолюдин", "голытьба"],
    "плевав": ["плевавши"],
    "плевавши": ["плевав"],
    "плеванье": ["плевание"],
    "плевательница": ["плевальница"],
    "плевать": ["выплёвывать", "наплевать", "чихать", "всё равно", "по фигу", "пофиг", "по барабану", "фиолетово"],
    "плевать хотел": ["игнорирование", "безразлично"],
    "плевел": ["ненужный", "фальшивый"],
    "плевритичний": ["плевритний", "плевритовий"],
    "плегия": ["паралич"],
    "плед": ["одеяло"],
    "плеер": ["проигрыватель", "плейер"],
    "плезиантроп": ["африканский австралопитек"],
    "плей-лист": ["репертуар"],
    "плейбой": ["ловелас", "повеса"],
    "плейер": ["плеер", "проигрыватель"],
    "плейотропия": ["плейотропность"],
    "плексиглас": ["органическое стекло", "оргстекло"],
    "плектенхима": ["псевдопаренхима"],
    "плектр": ["медиатор"],
    "племзавод": ["пз"],
    "племянница": ["племяшка", "племяннушка"],
    "племяш": ["племянник"],
    "плененье": ["пленение"],
    "пленив": ["пленивши"],
    "пленивши": ["пленив"],
    "пленительный": ["прелестный", "обаятельный", "очаровательный", "чарующий"],
    "пленник": ["узник", "заключённый"],
    "пленный": ["пленённый", "пленник"],
    "пленяв": ["пленявши"],
    "пленявши": ["пленяв"],
    "пленять": ["брать в плен", "покорять", "очаровывать"],
    "плеоназм": ["излишество", "многословие", "тавтология", "перифраз", "тождесловие", "масло масляное", "амплификация"],
    "плеонастический": ["тавтологический"],
    "плеоцитоз": ["цитемия"],
    "плерома": ["полнота", "прокамбий"],
    "плесенный": ["плесневой"],
    "плесень": ["плесневые грибы", "гнильё"],
    "плескав": ["плескавши"],
    "плескавши": ["плескав"],
    "плескание": ["плескотня", "плеск", "рукоплескание"],
    "плесканув": ["плесканувши"],
    "плесканувши": ["плесканув"],
    "плескануть": ["плеснуть"],
    "плесканье": ["плескание"],
    "плеснев": ["плесневши"],
    "плесневев": ["плесневевши"],
    "плесневевши": ["плесневев"],
    "плесневой": ["плесенный"],
    "плесневши": ["плеснев"],
    "плесневый": ["заплесневелый", "заплесневевший"],
    "плеснеть": ["плесневеть"],
    "плеснув": ["плеснувши"],
    "плеснувши": ["плеснув"],
    "плеснуть под жабры": ["залить жабры", "кинуть под жабры"],
    "плессит": ["никелевый блеск"],
    "плести": ["вить", "свивать", "заплетать", "интриговать", "болтать", "нести", "молоть"],
    "плестись": ["брести", "тащиться"],
    "плетение": ["сплетание", "сплетение"],
    "плетизмовазограф": ["плетизмограф"],
    "плетушка": ["плетёнка"],
    "плеть": ["плётка", "кнут", "хлыст"],
    "плетью обуха не перешибёшь": ["выше лба уши не растут", "выше лба глаза не растут", "выше головы не прыгнешь"],
    "плехнув": ["плехнувши"],
    "плехнувши": ["плехнув"],
    "плечевая": ["дальнобойщица"],
    "плечевой": ["плечной"],
    "плеченогие": ["брахиопод"],
    "плечики": ["тремпель"],
    "плечико": ["плечо"],
    "плечистый": ["широкоплечий"],
    "плечной": ["плечевой"],
    "плечо": ["надплечье", "рамя", "маржа"],
    "плешатый": ["плешивый", "плешастый"],
    "плешивая": ["лысенькая"],
    "плешивев": ["плешивевши"],
    "плешивевши": ["плешивев"],
    "плешивенький": ["лысенький"],
    "плешивый": ["лысый", "безволосый", "голый", "оголённый", "облезлый", "потёртый", "протёртый", "вытершийся", "безлесый", "обезлесевший", "обнажённый"],
    "плешка": ["плешина", "проплешина"],
    "плешь": ["лысина", "плешина", "проплешина", "пролысина"],
    "плешь проесть": ["донять", "достать"],
    "плеяди": ["стожари", "волосожар"],
    "пли": ["огонь", "стрелять"],
    "пливти": ["плисти"],
    "плинтовав": ["плинтовавши"],
    "плинтовавши": ["плинтовав"],
    "плинтусный": ["плинтусовый"],
    "плинтусовый": ["плинтусный"],
    "плис": ["плм", "программируемый логический массив"],
    "плиска": ["жёлтая трясогузка"],
    "плиссе": ["плиссированный", "складчатый"],
    "плиссировав": ["плиссировавши"],
    "плиссировавши": ["плиссировав"],
    "плисти": ["пливти"],
    "плита мдф": ["мдф"],
    "плитковина": ["плитчина"],
    "плитник": ["плитоносец", "плитонос", "плитоноска"],
    "плитоносец": ["плитник", "плитонос", "плитоноска"],
    "плиточный": ["плитчатый"],
    "плитчатый": ["плиточный"],
    "плица": ["ковш", "черпак", "водолейка", "плича", "пличка", "пилушка", "совок", "лопасть"],
    "плов": ["пилав"],
    "пловдив": ["филиппополь", "филибе"],
    "пловец": ["моряк", "мореплаватель"],
    "плоггинг": ["чистобег"],
    "плод": ["фрукт", "зародыш", "результат", "итог", "исход"],
    "плод воображения": ["фикция", "вымысел", "фантазия"],
    "плодив": ["плодивши"],
    "плодивши": ["плодив"],
    "плодиться": ["распложаться"],
    "плодово-выгодное": ["плодо-выгодное"],
    "плодоизгнание": ["аборт"],
    "плодокормный": ["плодокормовой"],
    "плодокормовой": ["плодокормный"],
    "плодолистик": ["плодник", "карпелла", "карпелля"],
    "плодоножка": ["цветоножка"],
    "плодоносив": ["плодоносивши"],
    "плодоносивши": ["плодоносив"],
    "плодоношенье": ["плодоношение"],
    "плодородие": ["плодородность"],
    "плодородье": ["плодородие"],
    "плодотворный": ["продуктивный", "благоприятный", "благотворный", "конструктивный", "результативный"],
    "плодоягодный": ["плодово-ягодный"],
    "плодущий": ["плодовитый", "фертильный", "плодоносный"],
    "плодъ": ["фруктъ", "зародышъ", "результатъ", "итог", "исходъ"],
    "плозивный": ["смычный"],
    "плоив": ["плоивши"],
    "плоивши": ["плоив"],
    "плойка": ["плоение", "завивка", "плой", "складка", "складки", "волна", "волны", "плиссе", "бора", "щипцы для завивки", "складчатость"],
    "плойчатость": ["складчатость"],
    "плойчатый": ["складчатый"],
    "пломба": ["печать"],
    "пломбировав": ["пломбировавши"],
    "пломбировавши": ["пломбировав"],
    "плоский": ["ровный", "гладкий", "планиметрический", "двумерный", "тонкий", "сплющенный", "пошлый", "банальный", "неоригинальный"],
    "плосковер": ["плосковерец", "плоскоземельщик", "плоскоземелец", "плоскоземец"],
    "плоскогорье": ["плато"],
    "плоскогрудка": ["плоскодонка", "доска"],
    "плоскогубцы": ["пассатижи"],
    "плоскоземелец": ["плосковер", "плоскоземельщик"],
    "плоскоземельщик": ["плоскоземелец"],
    "плосконосый додекаэдр": ["курносый додекаэдр", "плосконосый икосододекаэдр"],
    "плоскостность": ["уплощённость"],
    "плоскостопие": ["плоскоступие"],
    "плоскость": ["ровность", "гладкость"],
    "плот": ["пирс"],
    "плотва": ["чебак"],
    "плотвица": ["плотва", "плотица"],
    "плотив": ["плотивши"],
    "плотивши": ["плотив"],
    "плотина": ["дамба", "запруда", "преграда", "препятствие", "барьер", "граница", "заграждение", "стена"],
    "плотнев": ["плотневши"],
    "плотневши": ["плотнев"],
    "плотнив": ["плотнивши"],
    "плотнивши": ["плотнив"],
    "плотник": ["столяр", "древотёс", "древодел"],
    "плотничав": ["плотничавши"],
    "плотничавши": ["плотничав"],
    "плотничание": ["плотничанье", "плотничество"],
    "плотничанье": ["плотничание", "плотничество"],
    "плотнический": ["плотничий"],
    "плотничество": ["плотничанье", "плотничание"],
    "плотничий": ["плотнический"],
    "плотность": ["удельная масса"],
    "плотный": ["густой", "светонепроницаемый", "частый", "сплошной", "толстый", "массивный", "крепкий", "сбитый", "упитанный", "полный", "обильный", "сытный"],
    "плотовщик": ["плотовод", "плотовой", "плотогон", "плотильщик", "плотоводитель", "гонщик", "уромщик", "паромщик"],
    "плотоядный": ["хищный", "сластолюбивый", "сладострастный"],
    "плотский": ["телесный"],
    "плоттер": ["графопостроитель"],
    "плоть": ["тело", "мясо"],
    "плоучница": ["плоучнице"],
    "плоучнице": ["плоучница"],
    "плохо": ["скверно", "нехорошо", "дурно"],
    "плоховав": ["плоховавши"],
    "плоховавши": ["плоховав"],
    "плоховато": ["неважно", "неважнецки"],
    "плоховатый": ["неважный", "неважнецкий", "плохонький"],
    "плоховать": ["плошать"],
    "плохое": ["дурное"],
    "плохой": ["дурной", "нехороший", "некачественный", "скверный", "безнравственный", "аморальный", "недостаточный", "малый", "слабый", "больной"],
    "плохому танцору яйца мешают": ["плохому танцору всегда ноги мешают", "плохому танцору одежда мешает", "плохому танцору и штаны мешают", "плохому танцору фаберже мешают"],
    "плохонько": ["скверненько", "паршивенько"],
    "плошав": ["плошавши"],
    "плошавши": ["плошав"],
    "плоше": ["хуже"],
    "плошка": ["миска"],
    "площа": ["площина", "майдан"],
    "площадной": ["неприличный", "непристойный", "обсценный", "пошлый", "сальный", "вольный", "скабрёзный"],
    "площадь": ["место"],
    "площив": ["площивши"],
    "площивши": ["площив"],
    "площить": ["расплющивать"],
    "площиться": ["расплющиваться"],
    "плоёный": ["плиссированный", "складчатый"],
    "плувиал": ["каппа"],
    "плугарь": ["землероб", "землепашец", "пахарь"],
    "плугатар": ["орач"],
    "плуговой": ["плужный"],
    "плужковый": ["плужный", "плуговой"],
    "плужник": ["лемех", "сошник"],
    "плужный": ["плуговой"],
    "плусиада": ["прусиас", "брусса", "прусса", "пруссиада"],
    "плут": ["мошенник", "обманщик", "бестия", "пройдоха", "прощелыга", "хитрец", "лукавец"],
    "плутав": ["плутавши"],
    "плутавши": ["плутав"],
    "плутаниця": ["плутанина"],
    "плутанье": ["плутание"],
    "плутишка": ["хитрюля"],
    "плутня": ["мошенничество"],
    "плутовав": ["плутовавши"],
    "плутовавши": ["плутовав"],
    "плутоватый": ["хитрый", "хитроумный", "лукавый"],
    "плутовать": ["хитрить", "лукавить"],
    "плутовка": ["врунья", "бесовка"],
    "плутовски": ["мошеннически", "канальски"],
    "плутовской роман": ["пикареска"],
    "плутократия": ["плутократизм"],
    "плутон": ["аид"],
    "плутонг": ["взвод", "батарея"],
    "плутонист": ["геттонианец"],
    "плутос": ["плутус"],
    "плутус": ["плутос"],
    "плът": ["тяло"],
    "плыв": ["плывши"],
    "плывучи": ["плывя"],
    "плывши": ["плыв"],
    "плыть": ["плавать", "оплывать", "плавиться", "расплываться", "растекаться"],
    "пльзень": ["пильзен"],
    "плювиограф": ["осадкомер", "дождемер", "плювиометр"],
    "плювиометр": ["осадкомер"],
    "плюндраваць": ["рабаваць"],
    "плюнув": ["плюнувши"],
    "плюнувши": ["плюнув"],
    "плюнуть в глаза": ["презрительно"],
    "плюрализировав": ["плюрализировавши"],
    "плюрализировавши": ["плюрализировав"],
    "плюригландулярный": ["полигландулярный", "многожелезистый"],
    "плюрицентрический": ["полицентрический", "плюрицентричный"],
    "плюрицентричный": ["плюрицентрический"],
    "плюс": ["прибавить", "выше нуля", "тепло", "добродетель", "достоинство"],
    "плюсанув": ["плюсанувши"],
    "плюсанувши": ["плюсанув"],
    "плюскав": ["плюскавши"],
    "плюскавши": ["плюскав"],
    "плюскать": ["мигать", "моргать", "плескать"],
    "плюсквамперфект": ["давнопрошедшее время", "предпрошедшее время", "раритет"],
    "плюснув": ["плюснувши"],
    "плюснувши": ["плюснув"],
    "плюсовав": ["плюсовавши"],
    "плюсовавши": ["плюсовав"],
    "плюсовальная машина": ["солильная машина"],
    "плюсование": ["прибавление", "добавление", "сложение", "прибавка"],
    "плюсовать": ["складывать", "прибавлять", "добавлять", "лайкать"],
    "плюсомёт": ["банхаммер"],
    "плюх": ["бултых"],
    "плюха": ["затрещина", "промах", "промашка", "лажа", "оплошность", "просчёт", "ляп"],
    "плюхав": ["плюхавши"],
    "плюхавши": ["плюхав"],
    "плюханье": ["плюхание"],
    "плюхнув": ["плюхнувши"],
    "плюхнувши": ["плюхнув"],
    "плюшка": ["пышка", "пампушка", "собака", "собачка", "обезьяна", "обезьянка", "ништяк", "коврижка", "прелесть", "приятность"],
    "плющ": ["вилица"],
    "плющив": ["плющивши"],
    "плющивши": ["плющив"],
    "плющить": ["расплющивать", "сплющивать", "плюскать"],
    "плющиться": ["уплощаться", "развлекаться"],
    "пляжевый": ["пляжный"],
    "пляжный": ["пляжевый"],
    "пляс": ["танец", "пляска"],
    "плясав": ["плясавши"],
    "плясавши": ["плясав"],
    "плясание": ["пляска"],
    "плясанье": ["плясание"],
    "плясать": ["танцевать"],
    "плясать под дудку": ["танцевать под дудку"],
    "пляска": ["танец", "пляс"],
    "пляска святого витта": ["хорея", "виттова пляска"],
    "плясывав": ["плясывавши"],
    "плясывавши": ["плясывав"],
    "плёночный": ["аналоговый"],
    "плёс": ["плесо"],
    "плётка": ["плеть"],
    "пмм": ["пистолет макарова модернизированный", "прикладная математика и механика", "посудомоечная машина", "паромно-мостовая машина", "проволока медная мягкая"],
    "пмр": ["приднестровская молдавская республика"],
    "пневматический": ["воздушный"],
    "пневматическое оружие": ["пневмат"],
    "пневмобетон": ["торкрет-бетон", "торкретбетон", "шприцбетон"],
    "пневмогидроаккумулятор": ["пневмогидравлический аккумулятор", "воздушный гидроаккумулятор"],
    "пневмогидроусилитель": ["пгу"],
    "пневмология": ["пульмонология"],
    "пневмомаммография": ["аэромаммография"],
    "пневмомассаж": ["лимфодренаж", "вакуум-массаж"],
    "пневмомедиастинография": ["медиастинография газовая"],
    "пневмония": ["воспаление лёгких"],
    "пневмонэктомия": ["пульмонэктомия"],
    "пневмопровод": ["пневмотрубопровод"],
    "пневмосинус": ["пневмоцеле"],
    "пниктоген": ["пникоген", "пниктид"],
    "пнр": ["польская народная республика"],
    "пнув": ["пнувши"],
    "пнувши": ["пнув"],
    "пнуть": ["толкнуть", "ударить", "лягнуть"],
    "пнёвый": ["пенечный"],
    "по": ["софт", "софтвер"],
    "по банку": ["ва-банк"],
    "по блату": ["по знакомству"],
    "по версии": ["согласно"],
    "по вечерам": ["вечерами", "вечером"],
    "по возможности": ["если возможно", "насколько можно", "по мере возможности", "если это возможно", "в меру сил", "по мере сил", "насколько возможно", "в меру своих сил", "елико возможно", "посильно"],
    "по временам": ["временами", "время от времени", "порой", "иногда", "подчас"],
    "по всем статьям": ["по всем пунктам"],
    "по горло": ["досыта", "с головой"],
    "по горячим следам": ["по свежим следам"],
    "по диагонали": ["наискось"],
    "по доброте": ["по доброте душевной"],
    "по доброте душевной": ["по доброте"],
    "по душам": ["дружески", "искренно", "откровенно"],
    "по душе": ["по вкусу", "чистосердечно"],
    "по ебалу получить": ["получить по ебалу", "выхватить по ебалу", "по ебалу выхватить"],
    "по жизни": ["по гроб жизни"],
    "по идее": ["предположительно", "кажется", "по задумке"],
    "по конвейеру": ["по цепочке"],
    "по кочану": ["по кочану да по капусте", "по кочану и по капусте", "по кочану с кочерыжкой", "по кочану папайи", "конь в пальто", "на кудыкину гору"],
    "по крайней мере": ["хотя бы", "по меньшей мере"],
    "по левую руку": ["слева", "с левой стороны", "ошуюю"],
    "по мелочи": ["понемногу", "немного", "незначительно", "несерьёзно"],
    "по милости": ["по вине"],
    "по мне": ["как по мне"],
    "по отношению": ["относительно"],
    "по отношению к": ["относительно"],
    "по очереди": ["один за другим"],
    "по пизде мешалкой": ["по рылу помелом", "по пизде калошей", "по пизде калошею"],
    "по пизде мешалкой словить": ["словить по пизде мешалкой"],
    "по пояс": ["до пояса"],
    "по причине": ["из-за", "из", "от", "по", "за", "благодаря", "вследствие", "в результате", "ввиду", "в силу"],
    "по пьяни": ["спьяну", "с пьяных глаз"],
    "по пьяной лавочке": ["навеселе", "под хмельком", "спьяну", "спьяна", "с пьяных глаз", "по пьяни", "под пьяную лавочку"],
    "по пятам": ["как банный лист", "хвостиком"],
    "по рождестве христовом": ["от рождества христова"],
    "по рылу помелом": ["по пизде мешалкой", "по пизде калошей", "по пизде калошею"],
    "по самые помидоры": ["по самое некуда", "по самое не могу", "по самое не балуйся", "по самое не хочу", "по самые нехочухи", "по самы помидоры", "по самы нехочухи", "дальше некуда"],
    "по сей день": ["доныне", "доднесь", "до сего дня", "до сих пор", "по сию пору"],
    "по сеньке шапка": ["по сеньке и шапка"],
    "по серьёзу": ["строго", "без шуток", "кроме шуток", "на серьёзе"],
    "по сию пору": ["до сего дня", "до сих пор", "по сей день", "доныне", "доднесь"],
    "по сравнению": ["сравнительно", "относительно"],
    "по старинке": ["по-старому"],
    "по сути": ["в действительности", "в главном", "фактически", "по существу"],
    "по уши": ["по горло", "по самые помидоры", "по самое не балуй", "по самое не хочу", "целиком и полностью"],
    "по факту": ["фактически"],
    "по фану": ["несерьёзно", "шутки ради", "забавы ради"],
    "по фене ботать": ["курсать по фене", "петрить по фене", "пулять по фене", "стукать по фене", "стучать по фене", "ботать по фене"],
    "по фигу": ["по барабану"],
    "по ходу": ["по направлению"],
    "по цепочке": ["из уст в уста"],
    "по чесноку": ["по честноку", "по-честному", "начистоту", "откровенно"],
    "по честноку": ["по чесноку"],
    "по числу": ["в соответствии с числом"],
    "по щелчку": ["мгновенно", "по щелчку пальцев"],
    "по щелчку пальцев": ["мгновенно", "тотчас"],
    "по-аглицки": ["по-английски"],
    "по-божески": ["праведно", "по-людски"],
    "по-буржуйски": ["по-буржуински"],
    "по-бырому": ["быстро", "быстренько", "по-быстрому", "быренько"],
    "по-быстрому": ["по-бырому"],
    "по-бюрократически": ["формально"],
    "по-видимому": ["наружно", "видимо", "видно", "по всей видимости", "как видится", "имхо", "кажись"],
    "по-воровски": ["исподтишка"],
    "по-вороньему": ["по-вороньи"],
    "по-вороньи": ["по-вороньему"],
    "по-вотски": ["по-удмуртски"],
    "по-всякому": ["всячески", "по-разному"],
    "по-всячески": ["всячески", "по-всякому", "по-разному"],
    "по-гаерски": ["гаерски"],
    "по-гишпански": ["по-испански"],
    "по-гречески": ["по-эллински"],
    "по-девичьему": ["по-девичьи"],
    "по-девичьи": ["по-девичьему"],
    "по-девчоночьи": ["по-девчачьи"],
    "по-деревенски": ["по-крестьянски", "по-деревенскому"],
    "по-деревенскому": ["по-деревенски"],
    "по-доброму": ["добро"],
    "по-домашнему": ["по-простому", "просто"],
    "по-древнеегипетски": ["по-египетски"],
    "по-другому": ["иначе"],
    "по-его": ["по-егонному"],
    "по-её": ["по-еённому"],
    "по-за": ["за"],
    "по-империалистически": ["империалистически", "империалистски", "по-империалистски"],
    "по-империалистски": ["империалистически", "империалистски", "по-империалистически"],
    "по-иному": ["по-другому", "иначе"],
    "по-интеллигентному": ["по-интеллигентски"],
    "по-их": ["по-ихнему", "по-ихому"],
    "по-ихнему": ["по-их"],
    "по-капиталистически": ["капиталистически"],
    "по-карельски": ["по-карело-фински"],
    "по-козлиному": ["по-козлячьи"],
    "по-козлячьи": ["по-козлиному", "по-козьи"],
    "по-корефански": ["по-дружески"],
    "по-кошачьему": ["по-кошачьи"],
    "по-крестьянски": ["по-деревенски"],
    "по-латински": ["по-латыни"],
    "по-латыни": ["по-латински"],
    "по-лебяжьему": ["по-лебединому", "по-лебяжьи"],
    "по-любому": ["всяко", "так или иначе", "всяко-разно", "полюбасу", "полюбас", "полюбак", "без б"],
    "по-майски": ["по-майскому"],
    "по-майскому": ["по-майски"],
    "по-марксистски": ["марксистски"],
    "по-мародёрски": ["мародёрски"],
    "по-медвежьему": ["по-медвежьи"],
    "по-медвежьи": ["по-медвежьему"],
    "по-модному": ["по моде", "модно"],
    "по-моему": ["кажется"],
    "по-морскому": ["по-моряцки"],
    "по-мужицки": ["по-мущински", "по-мужски"],
    "по-мужски": ["по-мущински", "по-мужицки"],
    "по-мурмански": ["по-кольски", "по-варварски"],
    "по-мущински": ["по-мужски"],
    "по-настоящему": ["должным образом", "по-хорошему", "по сути", "в самом деле", "в действительности"],
    "по-нашему": ["по-нашенски"],
    "по-обывательски": ["обывательски"],
    "по-особенному": ["необычно", "особенно", "на особицу"],
    "по-паучьему": ["по-паучьи"],
    "по-паучьи": ["по-паучьему"],
    "по-под": ["под"],
    "по-прежнему": ["так же", "по старинке"],
    "по-приятельски": ["по-дружески", "дружески"],
    "по-пустому": ["попусту", "впустую"],
    "по-пёсьему": ["по-пёсьи"],
    "по-пёсьи": ["по-пёсьему"],
    "по-разному": ["неодинаково", "разно"],
    "по-русски": ["по-москальски", "по-кацапски"],
    "по-рыбачьи": ["по-рыбацки"],
    "по-рыцарски": ["благородно", "великодушно", "рыцарственно", "самоотверженно"],
    "по-садистски": ["садистски"],
    "по-своему": ["на свой лад", "на свой манер", "своеобразно"],
    "по-собачьему": ["по-собачьи"],
    "по-совдеповски": ["по-советски", "по-совковому", "по-совковски"],
    "по-советски": ["по-совейски"],
    "по-спартански": ["аскетично"],
    "по-старому": ["по старинке", "по-прежнему"],
    "по-старушечьи": ["по-старушьи"],
    "по-старушьи": ["по-старушечьи"],
    "по-стахановски": ["по-ударному"],
    "по-стрекозьи": ["по-стрекозиному"],
    "по-топорному": ["топорно"],
    "по-ударному": ["по-передовому", "ударно"],
    "по-украински": ["по-малороссийски", "по-малоросски", "по-хохлацки", "по-хохляцки"],
    "по-философски": ["философски"],
    "по-холопски": ["холопски"],
    "по-хорошему": ["по-человечески", "правильно", "качественно", "обстоятельно", "всерьёз", "хорошо", "по-доброму", "приязненно", "мирно", "ладом"],
    "по-царски": ["царственно"],
    "по-цыплячьи": ["по-цыплёночьи"],
    "по-цыплёночьи": ["по-цыплячьи"],
    "по-человечески": ["человечно", "гуманно"],
    "по-человечьи": ["по-человечески", "по-людски", "человечно", "гуманно"],
    "по-черепашьему": ["по-черепашьи"],
    "по-черепашьи": ["по-черепашьему"],
    "по-черкесски": ["по-адыгейски"],
    "по-честному": ["честно", "без обмана", "по правде", "по-хорошему", "по справедливости", "по чесноку", "откровенно"],
    "по-чёрному": ["курной", "тайно", "секретно", "незаконно", "зверски", "адски", "сильно", "жутко", "немилосердно", "чертовски", "чудовищно"],
    "поавралив": ["поавраливши"],
    "поавраливши": ["поавралив"],
    "поагитировав": ["поагитировавши"],
    "поагитировавши": ["поагитировав"],
    "поалев": ["поалевши"],
    "поалевши": ["поалев"],
    "поалее": ["поалей"],
    "поалей": ["поалее"],
    "поаналив": ["поаналивши"],
    "поаналивши": ["поаналив"],
    "поанта": ["същност", "същина", "смисъл", "цел"],
    "поаплодировав": ["поаплодировавши"],
    "поаплодировавши": ["поаплодировав"],
    "поассистировав": ["поассистировавши"],
    "поассистировавши": ["поассистировав"],
    "поахав": ["поахавши"],
    "поахавши": ["поахав"],
    "побагрив": ["побагривши"],
    "побагривши": ["побагрив"],
    "побагровев": ["побагровевши"],
    "побагровевши": ["побагровев"],
    "побагрянев": ["побагряневши"],
    "побагряневши": ["побагрянев"],
    "побазарив": ["побазаривши"],
    "побазаривши": ["побазарив"],
    "побаиваться": ["бояться", "опасаться"],
    "побайтный": ["побайтовый"],
    "побайтовый": ["побайтный", "посимвольный"],
    "побалаганив": ["побалаганивши"],
    "побалаганивши": ["побалаганив"],
    "побалагурив": ["побалагуривши"],
    "побалагуривши": ["побалагурив"],
    "побалакав": ["побалакавши"],
    "побалакавши": ["побалакав"],
    "побалакать": ["погутарить"],
    "побалдев": ["побалдевши"],
    "побалдевши": ["побалдев"],
    "побаливав": ["побаливавши"],
    "побаливавши": ["побаливав"],
    "побаловав": ["побаловавши"],
    "побаловавши": ["побаловав"],
    "побаловывав": ["побаловывавши"],
    "побаловывавши": ["побаловывав"],
    "побалтывав": ["побалтывавши"],
    "побалтывавши": ["побалтывав"],
    "побанив": ["побанивши"],
    "побанивши": ["побанив"],
    "побарабанив": ["побарабанивши"],
    "побарабанивав": ["побарабанивавши"],
    "побарабанивавши": ["побарабанивав"],
    "побарабанивши": ["побарабанив"],
    "побарывав": ["побарывавши"],
    "побарывавши": ["побарывав"],
    "побарывать": ["одолевать", "преодолевать", "побеждать"],
    "побарышничав": ["побарышничавши"],
    "побарышничавши": ["побарышничав"],
    "побасёнка": ["побаска"],
    "побаюкав": ["побаюкавши"],
    "побаюкавши": ["побаюкав"],
    "побег": ["бегство"],
    "побегав": ["побегавши"],
    "побегавши": ["побегав"],
    "побегать": ["набегаться"],
    "побегушки": ["беготня"],
    "победа": ["виктория", "одоление", "успех", "удача"],
    "победив": ["победивши"],
    "победивши": ["победив"],
    "победить": ["одержать победу", "одержать верх", "восторжествовать", "выиграть", "преодолеть", "превозмочь", "побороть"],
    "победная головка": ["несчастливец", "горемыка", "головка победная", "головка спобедненькая", "головушка спобедненькая"],
    "победный": ["победоносный", "триумфальный"],
    "победоносец": ["победитель"],
    "победоносно": ["победно"],
    "победствовав": ["победствовавши"],
    "победствовавши": ["победствовав"],
    "побежав": ["побежавши"],
    "побежавши": ["побежав"],
    "побежать": ["потечь", "метнуться", "броситься", "драпануть"],
    "побеждав": ["побеждавши"],
    "побеждавши": ["побеждав"],
    "побездельничав": ["побездельничавши"],
    "побездельничавши": ["побездельничав"],
    "побезобразничав": ["побезобразничавши"],
    "побезобразничавши": ["побезобразничав"],
    "побезумствовав": ["побезумствовавши"],
    "побезумствовавши": ["побезумствовав"],
    "побелев": ["побелевши"],
    "побелевши": ["побелев"],
    "побелив": ["побеливши"],
    "побеливши": ["побелив"],
    "побелковав": ["побелковавши"],
    "побелковавши": ["побелковав"],
    "поберегав": ["поберегавши"],
    "поберегавши": ["поберегав"],
    "побережжя": ["узбережжя", "побережина"],
    "побережье": ["берег", "прибрежье"],
    "побеседовав": ["побеседовавши"],
    "побеседовавши": ["побеседовав"],
    "побесив": ["побесивши"],
    "побесивши": ["побесив"],
    "побеспокоив": ["побеспокоивши"],
    "побеспокоивши": ["побеспокоив"],
    "побеспокоить": ["потревожить"],
    "побив": ["побивши"],
    "побивав": ["побивавши"],
    "побивавши": ["побивав"],
    "побивать": ["бить", "забивать", "побеждать", "превосходить", "уничтожать", "повреждать"],
    "побивши": ["побив"],
    "побирав": ["побиравши"],
    "побиравши": ["побирав"],
    "побираться": ["попрошайничать", "нищенствовать"],
    "побируха": ["побирушка", "нищий", "нищенка"],
    "побирушка": ["нищий", "христарадник", "попрошайка"],
    "побирушничав": ["побирушничавши"],
    "побирушничавши": ["побирушничав"],
    "побитный": ["побитовый"],
    "побитовый": ["побитный"],
    "побитье": ["побитие"],
    "поблагодарив": ["поблагодаривши"],
    "поблагодаривши": ["поблагодарив"],
    "поблагодушествовав": ["поблагодушествовавши"],
    "поблагодушествовавши": ["поблагодушествовав"],
    "поблагоприятствовав": ["поблагоприятствовавши"],
    "поблагоприятствовавши": ["поблагоприятствовав"],
    "поблажав": ["поблажавши"],
    "поблажавши": ["поблажав"],
    "поблаженствовав": ["поблаженствовавши"],
    "поблаженствовавши": ["поблаженствовав"],
    "поблажив": ["поблаживши"],
    "поблаживши": ["поблажив"],
    "поблажка": ["послабление", "снисхождение", "потачка"],
    "побледнев": ["побледневши"],
    "побледневши": ["побледнев"],
    "побледнеть": ["побелеть", "позеленеть", "покрыться", "бледность", "потускнеть", "поблекнуть", "отойти на второй план"],
    "поблекнув": ["поблекнувши"],
    "поблекнувши": ["поблекнув"],
    "поблескивав": ["поблескивавши"],
    "поблескивавши": ["поблескивав"],
    "поблескивать": ["поблёскивать", "взблескивать"],
    "поблеснив": ["поблеснивши"],
    "поблеснивши": ["поблеснив"],
    "поблестев": ["поблестевши"],
    "поблестевши": ["поблестев"],
    "поблеяв": ["поблеявши"],
    "поблеявши": ["поблеяв"],
    "поближе": ["ближе"],
    "поблизости": ["неподалёку", "вблизи", "близко", "недалеко", "невдалеке", "рядом"],
    "поблистав": ["поблиставши"],
    "поблиставши": ["поблистав"],
    "поблудив": ["поблудивши"],
    "поблудивши": ["поблудив"],
    "поблуждав": ["поблуждавши"],
    "поблуждавши": ["поблуждав"],
    "поблёкнув": ["поблёкнувши"],
    "поблёкнувши": ["поблёкнув"],
    "поблёскивав": ["поблёскивавши"],
    "поблёскивавши": ["поблёскивав"],
    "поблёскивать": ["поблескивать", "взблескивать"],
    "пободав": ["пободавши"],
    "пободавши": ["пободав"],
    "пободрствовав": ["пободрствовавши"],
    "пободрствовавши": ["пободрствовав"],
    "побои": ["избиение"],
    "поболев": ["поболевши"],
    "поболевши": ["поболев"],
    "поболтав": ["поболтавши"],
    "поболтавши": ["поболтав"],
    "побольше": ["больше", "более большой"],
    "побомбив": ["побомбивши"],
    "побомбивши": ["побомбив"],
    "поборав": ["поборавши"],
    "поборавши": ["поборав"],
    "побормотав": ["побормотавши"],
    "побормотавши": ["побормотав"],
    "поборник": ["защитник", "ревнитель"],
    "поборница": ["сторонница", "адепт", "защитница", "ревнительница", "приверженка"],
    "поборов": ["поборовши"],
    "поборовши": ["поборов"],
    "побороздив": ["побороздивши"],
    "побороздивши": ["побороздив"],
    "поборонив": ["поборонивши"],
    "поборонивши": ["поборонив"],
    "побочный эффект": ["побочка"],
    "побрав": ["побравши"],
    "побравши": ["побрав"],
    "пображничав": ["пображничавши"],
    "пображничавши": ["пображничав"],
    "побраконьерив": ["побраконьеривши"],
    "побраконьеривши": ["побраконьерив"],
    "побраконьерствовав": ["побраконьерствовавши"],
    "побраконьерствовавши": ["побраконьерствовав"],
    "побранив": ["побранивши"],
    "побранивав": ["побранивавши"],
    "побранивавши": ["побранивав"],
    "побранивши": ["побранив"],
    "побранить": ["поругать", "пожурить"],
    "побрасывав": ["побрасывавши"],
    "побрасывавши": ["побрасывав"],
    "побратав": ["побратавши"],
    "побратавши": ["побратав"],
    "побратание": ["побратанье"],
    "побратим": ["названый брат"],
    "побрать": ["взять", "забрать", "схватить"],
    "побредив": ["побредивши"],
    "побредивши": ["побредив"],
    "побрезгав": ["побрезгавши"],
    "побрезгавши": ["побрезгав"],
    "побрезгать": ["побрезговать"],
    "побрезговав": ["побрезговавши"],
    "побрезговавши": ["побрезговав"],
    "побрезговать": ["побрезгать"],
    "побренчав": ["побренчавши"],
    "побренчавши": ["побренчав"],
    "побренькивав": ["побренькивавши"],
    "побренькивавши": ["побренькивав"],
    "побрести": ["заковылять", "поплестись", "потащиться"],
    "побрехав": ["побрехавши"],
    "побрехавши": ["побрехав"],
    "побрив": ["побривши"],
    "побривши": ["побрив"],
    "побритый": ["выбритый", "бритый"],
    "побродив": ["побродивши"],
    "побродивши": ["побродив"],
    "побродяжив": ["побродяживши"],
    "побродяживши": ["побродяжив"],
    "побродяжничав": ["побродяжничавши"],
    "побродяжничавши": ["побродяжничав"],
    "побронзовев": ["побронзовевши"],
    "побронзовевши": ["побронзовев"],
    "побросав": ["побросавши"],
    "побросавши": ["побросав"],
    "побрызгав": ["побрызгавши"],
    "побрызгавши": ["побрызгав"],
    "побрызгивав": ["побрызгивавши"],
    "побрызгивавши": ["побрызгивав"],
    "побрыкав": ["побрыкавши"],
    "побрыкавши": ["побрыкав"],
    "побрюзжав": ["побрюзжавши"],
    "побрюзжавши": ["побрюзжав"],
    "побрякав": ["побрякавши"],
    "побрякавши": ["побрякав"],
    "побрякать": ["побренчать", "побряцать", "позвякать"],
    "побрякивав": ["побрякивавши"],
    "побрякивавши": ["побрякивав"],
    "побрякиванье": ["побрякивание"],
    "побрякивать": ["позвякивать"],
    "побрякушка": ["погремушка", "подвеска", "цацка", "безделушка"],
    "побряцав": ["побряцавши"],
    "побряцавши": ["побряцав"],
    "побряцать": ["побренчать", "побрякать", "позвякать"],
    "побрёхивав": ["побрёхивавши"],
    "побрёхивавши": ["побрёхивав"],
    "побудив": ["побудивши"],
    "побудивши": ["побудив"],
    "побуждав": ["побуждавши"],
    "побуждавши": ["побуждав"],
    "побуждение": ["мотивация"],
    "побужденье": ["побуждение"],
    "побуживав": ["побуживавши"],
    "побуживавши": ["побуживав"],
    "побузив": ["побузивши"],
    "побузивши": ["побузив"],
    "побуйствовав": ["побуйствовавши"],
    "побуйствовавши": ["побуйствовав"],
    "побуксовав": ["побуксовавши"],
    "побуксовавши": ["побуксовав"],
    "побултыхав": ["побултыхавши"],
    "побултыхавши": ["побултыхав"],
    "побулькав": ["побулькавши"],
    "побулькавши": ["побулькав"],
    "побулькивав": ["побулькивавши"],
    "побулькивавши": ["побулькивав"],
    "побунтовав": ["побунтовавши"],
    "побунтовавши": ["побунтовав"],
    "побурев": ["побуревши"],
    "побуревши": ["побурев"],
    "побурлив": ["побурливши"],
    "побурливши": ["побурлив"],
    "побурчав": ["побурчавши"],
    "побурчавши": ["побурчав"],
    "побухать": ["поквасить"],
    "побухивав": ["побухивавши"],
    "побухивавши": ["побухивав"],
    "побушевав": ["побушевавши"],
    "побушевавши": ["побушевав"],
    "побуянив": ["побуянивши"],
    "побуянивши": ["побуянив"],
    "побыв": ["побывши"],
    "побывав": ["побывавши"],
    "побывавши": ["побывав"],
    "побывши": ["побыв"],
    "побыть": ["пробыть"],
    "повабив": ["повабивши"],
    "повабивши": ["повабив"],
    "повадив": ["повадивши"],
    "повадивши": ["повадив"],
    "повадиться": ["привыкнуть", "приучиться", "втянуться", "приохотиться", "пристраститься"],
    "повадный": ["привлекательный", "лакомый", "податливый"],
    "поваживав": ["поваживавши"],
    "поваживавши": ["поваживав"],
    "поважнев": ["поважневши"],
    "поважневши": ["поважнев"],
    "поважничав": ["поважничавши"],
    "поважничавши": ["поважничав"],
    "поваксив": ["поваксивши"],
    "поваксивши": ["поваксив"],
    "повалив": ["поваливши"],
    "поваливав": ["поваливавши"],
    "поваливавши": ["поваливав"],
    "поваливши": ["повалив"],
    "повально": ["массово"],
    "повальный": ["всеобщий", "поголовный", "сплошной", "тотальный", "массовый"],
    "повальсировав": ["повальсировавши"],
    "повальсировавши": ["повальсировав"],
    "поваляв": ["повалявши"],
    "повалявши": ["поваляв"],
    "пованговав": ["пованговавши"],
    "пованговавши": ["пованговав"],
    "пованивав": ["пованивавши"],
    "пованивавши": ["пованивав"],
    "повапив": ["повапивши"],
    "повапивши": ["повапив"],
    "повар": ["кухарка"],
    "поваренная книга": ["кулинарная книга"],
    "поваренная соль": ["хлорид натрия", "каменная соль", "галит", "столовая соль", "пищевая соль"],
    "поварив": ["поваривши"],
    "поваривав": ["поваривавши"],
    "поваривавши": ["поваривав"],
    "поваривши": ["поварив"],
    "повариха": ["кухарка", "стряпуха", "кулинарка"],
    "поварничав": ["поварничавши"],
    "поварничавши": ["поварничав"],
    "поварня": ["кухня", "кашеварня", "стряпущая"],
    "поварчивав": ["поварчивавши"],
    "поварчивавши": ["поварчивав"],
    "поварёшка": ["половник", "черпак"],
    "повдовев": ["повдовевши"],
    "повдовевши": ["повдовев"],
    "повевав": ["повевавши"],
    "повевавши": ["повевав"],
    "поведав": ["поведавши"],
    "поведавши": ["поведав"],
    "поведать": ["рассказать", "изложить", "сообщить"],
    "поведение": ["поступки", "манера", "образ жизни", "динамика"],
    "поведенье": ["поведение"],
    "поведовав": ["поведовавши"],
    "поведовавши": ["поведовав"],
    "поведывав": ["поведывавши"],
    "поведывавши": ["поведывав"],
    "повезя": ["повёзши"],
    "повезясь": ["повёзшись"],
    "повелев": ["повелевши"],
    "повелевав": ["повелевавши"],
    "повелевавши": ["повелевав"],
    "повелевать": ["править", "велеть", "приказывать"],
    "повелевши": ["повелев"],
    "повелеть": ["приказать", "велеть"],
    "повелитель": ["владыка", "властелин", "властитель"],
    "повелительно": ["начальственно", "властно", "требовательно"],
    "повелительное наклонение": ["императив"],
    "повелительный": ["руководящий"],
    "повеличав": ["повеличавши"],
    "повеличавши": ["повеличав"],
    "повеля": ["предписание", "повеление"],
    "повенчав": ["повенчавши"],
    "повенчавши": ["повенчав"],
    "повербанк": ["повер"],
    "повергав": ["повергавши"],
    "повергавши": ["повергав"],
    "повергать": ["опрокидывать", "валить", "низвергать", "побеждать"],
    "повергнув": ["повергнувши"],
    "повергнувши": ["повергнув"],
    "повергнуть": ["опрокинуть", "повалить", "низвергнуть", "положить", "бросить", "кинуть", "сбросить", "скинуть", "победить", "превозмочь"],
    "поверенный": ["агент", "посредник", "стряпчий", "наперсник"],
    "поверещав": ["поверещавши"],
    "поверещавши": ["поверещав"],
    "поверив": ["поверивши"],
    "поверивши": ["поверив"],
    "поверие": ["поверье"],
    "поверить": ["уверовать"],
    "поверка": ["контроль", "проба", "испытание", "верификация"],
    "повернув": ["повернувши"],
    "повернувши": ["повернув"],
    "повернувшийся": ["крутанувшийся", "крутнувшийся", "обернувшийся", "оборотившийся", "обратившийся", "отвернувшийся", "перевалившийся", "поворотившийся", "развернувшийся", "своротившийся"],
    "повернуть": ["поворотить", "свернуть", "переломить"],
    "повернуться": ["обернуться", "провернуться", "поворотиться", "чокнуться"],
    "поверстав": ["поверставши"],
    "поверставши": ["поверстав"],
    "повертев": ["повертевши"],
    "повертевши": ["повертев"],
    "поверх": ["на", "сверху", "над"],
    "поверхностно-активное вещество": ["пав", "сурфактант"],
    "поверхностность": ["неглубокость", "элементарность", "мелкость", "легковесность", "верхоглядство"],
    "поверху": ["сверху"],
    "поверчивав": ["поверчивавши"],
    "поверчивавши": ["поверчивав"],
    "повершав": ["повершавши"],
    "повершавши": ["повершав"],
    "повершив": ["повершивши"],
    "повершивши": ["повершив"],
    "повершити": ["довершити"],
    "поверье": ["поверие", "обычай", "обыкновение"],
    "поверяв": ["поверявши"],
    "поверявши": ["поверяв"],
    "поверять": ["проверять", "сличать", "сравнивать"],
    "повеса": ["ветрогон", "бездельник", "лоботряс", "шалопай", "шалопут", "шаматон", "шалун", "прожига", "озорник", "бандит", "гуляка", "кутила", "плейбой", "развратник", "бабник"],
    "повеселев": ["повеселевши"],
    "повеселевши": ["повеселев"],
    "повеселее": ["веселее"],
    "повеселив": ["повеселивши"],
    "повеселивши": ["повеселив"],
    "повеселить": ["развлечь", "посмешить"],
    "повесив": ["повесивши"],
    "повесивши": ["повесив"],
    "повесить": ["подвесить"],
    "повеситься": ["вздёрнуться", "удавиться"],
    "повесничав": ["повесничавши"],
    "повесничавши": ["повесничав"],
    "повесничать": ["лоботрясничать", "шалить", "проказничать", "кутить"],
    "повествовав": ["повествовавши"],
    "повествовавши": ["повествовав"],
    "повествованье": ["повествование"],
    "повествователь": ["рассказчик", "писатель", "прозаик"],
    "повествовательный": ["нарративный", "эпический", "декларативный"],
    "повествовать": ["рассказывать", "излагать"],
    "повестив": ["повестивши"],
    "повестивши": ["повестив"],
    "повестись": ["подружиться", "скорефаниться", "клюнуть"],
    "повестить": ["оповестить", "известить", "уведомить"],
    "повестка": ["вызов", "повестка дня"],
    "повет": ["повят"],
    "поветрие": ["воздух", "эпидемия", "мор", "мода", "веяние"],
    "поветшав": ["поветшавши"],
    "поветшавши": ["поветшав"],
    "повечерив": ["повечеривши"],
    "повечеривши": ["повечерив"],
    "повечерие": ["павечерница", "комплеторий"],
    "повечерье": ["повечерие"],
    "повечеряв": ["повечерявши"],
    "повечерявши": ["повечеряв"],
    "повешение": ["повешенье"],
    "повешенный": ["подвешенный"],
    "повешенье": ["повешение"],
    "повещав": ["повещавши"],
    "повещавши": ["повещав"],
    "повеяв": ["повеявши"],
    "повеявши": ["повеяв"],
    "повзаимодействовав": ["повзаимодействовавши"],
    "повзаимодействовавши": ["повзаимодействовав"],
    "повздорив": ["повздоривши"],
    "повздоривши": ["повздорив"],
    "повздорить": ["поссориться", "побраниться"],
    "повздыхав": ["повздыхавши"],
    "повздыхавши": ["повздыхав"],
    "повзик": ["поповзень"],
    "повзрослев": ["повзрослевши"],
    "повзрослевши": ["повзрослев"],
    "повибрировав": ["повибрировавши"],
    "повибрировавши": ["повибрировав"],
    "повив": ["повивши"],
    "повивав": ["повивавши"],
    "повивавши": ["повивав"],
    "повивальная бабка": ["акушерка", "повитуха", "бабка-повитуха", "повивальщица"],
    "повивальный": ["акушерский"],
    "повивши": ["повив"],
    "повидав": ["повидавши"],
    "повидавши": ["повидав"],
    "повидать": ["повидаться", "навестить", "проведать"],
    "повидев": ["повидевши"],
    "повидевши": ["повидев"],
    "повиднев": ["повидневши"],
    "повидневши": ["повиднев"],
    "повизгивав": ["повизгивавши"],
    "повизгивавши": ["повизгивав"],
    "повизгиванье": ["повизгивание"],
    "повизжав": ["повизжавши"],
    "повизжавши": ["повизжав"],
    "повиливав": ["повиливавши"],
    "повиливавши": ["повиливав"],
    "повилика": ["повилица", "кускута"],
    "повиляв": ["повилявши"],
    "повилявши": ["повиляв"],
    "повинив": ["повинивши"],
    "повинивши": ["повинив"],
    "повинность": ["долг", "обязанность", "подать"],
    "повинный": ["виноватый", "раскаявшийся", "повинившийся", "обязанный", "должный"],
    "повиноваться": ["подчиниться", "подчиняться", "покориться", "покоряться", "послушать", "послушаться", "склониться", "склоняться", "слушать", "слушаться", "смириться", "смиряться", "согнуться"],
    "повиновение": ["послушание", "подчинение", "послушанье", "подчиненье", "повиновенье"],
    "повиновенье": ["повиновение"],
    "повинтив": ["повинтивши"],
    "повинтивши": ["повинтив"],
    "повинтить": ["свинтить", "упаковать", "свалить"],
    "повинчивав": ["повинчивавши"],
    "повинчивавши": ["повинчивав"],
    "повиражив": ["повираживши"],
    "повираживши": ["повиражив"],
    "повисав": ["повисавши"],
    "повисавши": ["повисав"],
    "повисев": ["повисевши"],
    "повисевши": ["повисев"],
    "повислый": ["повисший", "отвислый"],
    "повиснув": ["повиснувши"],
    "повиснувши": ["повиснув"],
    "повитель": ["повилика"],
    "повитуха": ["повивальная бабка", "бабка-повитуха", "акушерка"],
    "повихнув": ["повихнувши"],
    "повихнувши": ["повихнув"],
    "повкалывав": ["повкалывавши"],
    "повкалывавши": ["повкалывав"],
    "повлажнев": ["повлажневши"],
    "повлажневши": ["повлажнев"],
    "повластвовав": ["повластвовавши"],
    "повластвовавши": ["повластвовав"],
    "повлепливав": ["повлепливавши"],
    "повлепливавши": ["повлепливав"],
    "повлепливать": ["повлеплять"],
    "повлепляв": ["повлеплявши"],
    "повлеплявши": ["повлепляв"],
    "повлечь": ["потащить", "потянуть", "привести", "вызвать"],
    "повлияв": ["повлиявши"],
    "повлиявши": ["повлияв"],
    "повлёкший": ["вызвавший"],
    "повний": ["наповнений"],
    "поводив": ["поводивши"],
    "поводивши": ["поводив"],
    "поводир": ["поводар", "поводатар"],
    "повоевав": ["повоевавши"],
    "повоевавши": ["повоевав"],
    "повоз": ["повинность"],
    "повозвращав": ["повозвращавши"],
    "повозвращавши": ["повозвращав"],
    "повозив": ["повозивши"],
    "повозивши": ["повозив"],
    "повозка": ["возок", "воз"],
    "повозчик": ["извозчик", "кучер"],
    "повойник": ["подубрусник"],
    "поволжец": ["волгарь", "волжанин"],
    "поволив": ["поволивши"],
    "поволивши": ["поволив"],
    "поволновав": ["поволновавши"],
    "поволновавши": ["поволновав"],
    "поволочив": ["поволочивши"],
    "поволочивши": ["поволочив"],
    "поволочить": ["поволочь"],
    "поволынив": ["поволынивши"],
    "поволынивши": ["поволынив"],
    "повольничав": ["повольничавши"],
    "повольничавши": ["повольничав"],
    "повольнодумничав": ["повольнодумничавши"],
    "повольнодумничавши": ["повольнодумничав"],
    "повольнодумствовав": ["повольнодумствовавши"],
    "повольнодумствовавши": ["повольнодумствовав"],
    "повопив": ["повопивши"],
    "повопивши": ["повопив"],
    "поворачивав": ["поворачивавши"],
    "поворачивавши": ["поворачивав"],
    "поворачивать": ["повёртывать", "сворачивать", "вертеть"],
    "поворковав": ["поворковавши"],
    "поворковавши": ["поворковав"],
    "поворовав": ["поворовавши"],
    "поворовавши": ["поворовав"],
    "поворовывав": ["поворовывавши"],
    "поворовывавши": ["поворовывав"],
    "поворожив": ["повороживши"],
    "повороживши": ["поворожив"],
    "поворот": ["перелом", "изгиб"],
    "поворотив": ["поворотивши"],
    "поворотивши": ["поворотив"],
    "поворотливый": ["ловкий", "проворный", "расторопный"],
    "поворочав": ["поворочавши"],
    "поворочавши": ["поворочав"],
    "поворошив": ["поворошивши"],
    "поворошивши": ["поворошив"],
    "поворчав": ["поворчавши"],
    "поворчавши": ["поворчав"],
    "повоспитывав": ["повоспитывавши"],
    "повоспитывавши": ["повоспитывав"],
    "повоёвывав": ["повоёвывавши"],
    "повоёвывавши": ["повоёвывав"],
    "поврав": ["повравши"],
    "повравши": ["поврав"],
    "повраждовав": ["повраждовавши"],
    "повраждовавши": ["повраждовав"],
    "повращав": ["повращавши"],
    "повращавши": ["повращав"],
    "повредив": ["повредивши"],
    "повредивши": ["повредив"],
    "повреждав": ["повреждавши"],
    "повреждавши": ["повреждав"],
    "повреждать": ["портить"],
    "повреждение": ["порча", "дефект"],
    "поврежденье": ["повреждение"],
    "повременив": ["повременивши"],
    "повременивши": ["повременив"],
    "повременный": ["периодический"],
    "поврозь": ["врозь", "порознь"],
    "повседневно": ["ежедневно", "каждый день", "каждодневно"],
    "повсеместно": ["везде", "повсюду"],
    "повсеместность": ["вездесущесть", "вездесущность"],
    "повсеместный": ["вездесущий"],
    "повскакав": ["повскакавши"],
    "повскакавши": ["повскакав"],
    "повскакивав": ["повскакивавши"],
    "повскакивавши": ["повскакивав"],
    "повскакивать": ["повскакать"],
    "повспоминав": ["повспоминавши"],
    "повспоминавши": ["повспоминав"],
    "повстав": ["повставши"],
    "повставав": ["повстававши"],
    "повстававши": ["повставав"],
    "повставши": ["повстав"],
    "повстанец": ["восставший", "инсургент", "бунтовщик", "мятежник"],
    "повстанческий": ["мятежный", "революционный"],
    "повстанье": ["повстание"],
    "повстречав": ["повстречавши"],
    "повстречавши": ["повстречав"],
    "повстречаться": ["встретиться"],
    "повсюдность": ["повсеместность"],
    "повсюду": ["всюду", "повсеместно", "везде"],
    "повтор": ["повторение"],
    "повторение": ["повтор", "копия"],
    "повторенье": ["повторение"],
    "повторив": ["повторивши"],
    "повторивши": ["повторив"],
    "повторить": ["освежить"],
    "повторно": ["вторично", "снова", "опять"],
    "повторный": ["вторичный"],
    "повторяв": ["повторявши"],
    "повторявши": ["повторяв"],
    "повторённый": ["продублированный", "повторный"],
    "повтыкав": ["повтыкавши"],
    "повтыкавши": ["повтыкав"],
    "повърхнина": ["повърхност"],
    "повъёбывать": ["поработать", "повкалывать"],
    "повыбегав": ["повыбегавши"],
    "повыбегавши": ["повыбегав"],
    "повыбежав": ["повыбежавши"],
    "повыбежавши": ["повыбежав"],
    "повыбив": ["повыбивши"],
    "повыбивав": ["повыбивавши"],
    "повыбивавши": ["повыбивав"],
    "повыбивать": ["повыбить"],
    "повыбивши": ["повыбив"],
    "повыбить": ["повыбивать"],
    "повыбрав": ["повыбравши"],
    "повыбравши": ["повыбрав"],
    "повыбрасывав": ["повыбрасывавши"],
    "повыбрасывавши": ["повыбрасывав"],
    "повыбросав": ["повыбросавши"],
    "повыбросавши": ["повыбросав"],
    "повыбросать": ["повыбросить", "повыбрасывать"],
    "повыбросив": ["повыбросивши"],
    "повыбросивши": ["повыбросив"],
    "повыв": ["повывши"],
    "повывав": ["повывавши"],
    "повывавши": ["повывав"],
    "повывалив": ["повываливши"],
    "повываливши": ["повывалив"],
    "повыведав": ["повыведавши"],
    "повыведавши": ["повыведав"],
    "повыведывав": ["повыведывавши"],
    "повыведывавши": ["повыведывав"],
    "повывезши": ["повывезя"],
    "повывезя": ["повывезши"],
    "повывернув": ["повывернувши"],
    "повывернувши": ["повывернув"],
    "повыводив": ["повыводивши"],
    "повыводивши": ["повыводив"],
    "повыворачивав": ["повыворачивавши"],
    "повыворачивавши": ["повыворачивав"],
    "повывши": ["повыв"],
    "повывёртывав": ["повывёртывавши"],
    "повывёртывавши": ["повывёртывав"],
    "повыгнав": ["повыгнавши"],
    "повыгнавши": ["повыгнав"],
    "повыгнать": ["повыгонять"],
    "повыгоняв": ["повыгонявши"],
    "повыгонявши": ["повыгоняв"],
    "повыгонять": ["повыгнать"],
    "повыгорев": ["повыгоревши"],
    "повыгоревши": ["повыгорев"],
    "повыгубив": ["повыгубивши"],
    "повыгубивши": ["повыгубив"],
    "повыдав": ["повыдавши"],
    "повыдавав": ["повыдававши"],
    "повыдававши": ["повыдавав"],
    "повыдавши": ["повыдав"],
    "повыделав": ["повыделавши"],
    "повыделавши": ["повыделав"],
    "повыдергав": ["повыдергавши"],
    "повыдергавши": ["повыдергав"],
    "повыдернув": ["повыдернувши"],
    "повыдернувши": ["повыдернув"],
    "повыдирав": ["повыдиравши"],
    "повыдиравши": ["повыдирав"],
    "повыдирать": ["повыдрать"],
    "повыдрав": ["повыдравши"],
    "повыдравши": ["повыдрав"],
    "повыдрать": ["повыдирать"],
    "повыдув": ["повыдувши"],
    "повыдувши": ["повыдув"],
    "повыдумывав": ["повыдумывавши"],
    "повыдумывавши": ["повыдумывав"],
    "повыдёргивав": ["повыдёргивавши"],
    "повыдёргивавши": ["повыдёргивав"],
    "повыезжав": ["повыезжавши"],
    "повыезжавши": ["повыезжав"],
    "повыехав": ["повыехавши"],
    "повыехавши": ["повыехав"],
    "повыждав": ["повыждавши"],
    "повыждавши": ["повыждав"],
    "повызвав": ["повызвавши"],
    "повызвавши": ["повызвав"],
    "повызнав": ["повызнавши"],
    "повызнавши": ["повызнав"],
    "повыкав": ["повыкавши"],
    "повыкавши": ["повыкав"],
    "повыкалывав": ["повыкалывавши"],
    "повыкалывавши": ["повыкалывав"],
    "повыкатывав": ["повыкатывавши"],
    "повыкатывавши": ["повыкатывав"],
    "повыкидав": ["повыкидавши"],
    "повыкидавши": ["повыкидав"],
    "повыкидывав": ["повыкидывавши"],
    "повыкидывавши": ["повыкидывав"],
    "повыкидывать": ["повыкинуть"],
    "повыкинув": ["повыкинувши"],
    "повыкинувши": ["повыкинув"],
    "повыкинуть": ["повыкидывать"],
    "повыклёвывав": ["повыклёвывавши"],
    "повыклёвывавши": ["повыклёвывав"],
    "повыкопав": ["повыкопавши"],
    "повыкопавши": ["повыкопав"],
    "повыкусывав": ["повыкусывавши"],
    "повыкусывавши": ["повыкусывав"],
    "повылавливав": ["повылавливавши"],
    "повылавливавши": ["повылавливав"],
    "повылазив": ["повылазивши"],
    "повылазивши": ["повылазив"],
    "повылазить": ["повылезти"],
    "повыламывав": ["повыламывавши"],
    "повыламывавши": ["повыламывав"],
    "повылезав": ["повылезавши"],
    "повылезавши": ["повылезав"],
    "повылезать": ["повылезти"],
    "повылезти": ["повылезать"],
    "повылезя": ["повылезши"],
    "повылепливав": ["повылепливавши"],
    "повылепливавши": ["повылепливав"],
    "повылепливать": ["повылеплять"],
    "повылепляв": ["повылеплявши"],
    "повылеплявши": ["повылепляв"],
    "повылетав": ["повылетавши"],
    "повылетавши": ["повылетав"],
    "повылетев": ["повылетевши"],
    "повылетевши": ["повылетев"],
    "повылиняв": ["повылинявши"],
    "повылинявши": ["повылиняв"],
    "повылинять": ["полинять", "вылинять"],
    "повыловив": ["повыловивши"],
    "повыловивши": ["повыловив"],
    "повыломав": ["повыломавши"],
    "повыломавши": ["повыломав"],
    "повымерев": ["повымерши"],
    "повымерзнув": ["повымерзнувши"],
    "повымерзнувши": ["повымерзнув"],
    "повымерши": ["повымерев"],
    "повымирав": ["повымиравши"],
    "повымиравши": ["повымирав"],
    "повыморив": ["повыморивши"],
    "повыморивши": ["повыморив"],
    "повымотав": ["повымотавши"],
    "повымотавши": ["повымотав"],
    "повынимав": ["повынимавши"],
    "повынимавши": ["повынимав"],
    "повыносив": ["повыносивши"],
    "повыносивши": ["повыносив"],
    "повынув": ["повынувши"],
    "повынувши": ["повынув"],
    "повыпадав": ["повыпадавши"],
    "повыпадавши": ["повыпадав"],
    "повыпендрёжничав": ["повыпендрёжничавши"],
    "повыпендрёжничавши": ["повыпендрёжничав"],
    "повыпендрёжничать": ["повыпендриваться", "повыкаблучиваться"],
    "повыписав": ["повыписавши"],
    "повыписавши": ["повыписав"],
    "повыписывав": ["повыписывавши"],
    "повыписывавши": ["повыписывав"],
    "повыползав": ["повыползавши"],
    "повыползавши": ["повыползав"],
    "повыпрашивав": ["повыпрашивавши"],
    "повыпрашивавши": ["повыпрашивав"],
    "повыпрыгивав": ["повыпрыгивавши"],
    "повыпрыгивавши": ["повыпрыгивав"],
    "повыпускав": ["повыпускавши"],
    "повыпускавши": ["повыпускав"],
    "повыпяливав": ["повыпяливавши"],
    "повыпяливавши": ["повыпяливав"],
    "повырастав": ["повыраставши"],
    "повыраставши": ["повырастав"],
    "повырвав": ["повырвавши"],
    "повырвавши": ["повырвав"],
    "повырезав": ["повырезавши"],
    "повырезавши": ["повырезав"],
    "повырезывав": ["повырезывавши"],
    "повырезывавши": ["повырезывав"],
    "повырубав": ["повырубавши"],
    "повырубавши": ["повырубав"],
    "повырубив": ["повырубивши"],
    "повырубивши": ["повырубив"],
    "повырывав": ["повырывавши"],
    "повырывавши": ["повырывав"],
    "повысив": ["повысивши"],
    "повысивши": ["повысив"],
    "повыситься": ["возвыситься", "вырасти", "подняться", "увеличиться", "усилиться"],
    "повыскакав": ["повыскакавши"],
    "повыскакавши": ["повыскакав"],
    "повыскакивав": ["повыскакивавши"],
    "повыскакивавши": ["повыскакивав"],
    "повыскочив": ["повыскочивши"],
    "повыскочивши": ["повыскочив"],
    "повысмотрев": ["повысмотревши"],
    "повысмотревши": ["повысмотрев"],
    "повысовывав": ["повысовывавши"],
    "повысовывавши": ["повысовывав"],
    "повысосав": ["повысосавши"],
    "повысосавши": ["повысосав"],
    "повысохнув": ["повысохнувши"],
    "повысохнувши": ["повысохнув"],
    "повыспрашивав": ["повыспрашивавши"],
    "повыспрашивавши": ["повыспрашивав"],
    "повыспросив": ["повыспросивши"],
    "повыспросивши": ["повыспросив"],
    "повыставив": ["повыставивши"],
    "повыставивши": ["повыставив"],
    "повыстроив": ["повыстроивши"],
    "повыстроивши": ["повыстроив"],
    "повыступив": ["повыступивши"],
    "повыступивши": ["повыступив"],
    "повысунув": ["повысунувши"],
    "повысунувши": ["повысунув"],
    "повысушив": ["повысушивши"],
    "повысушивши": ["повысушив"],
    "повысыпав": ["повысыпавши"],
    "повысыпавши": ["повысыпав"],
    "повысыхав": ["повысыхавши"],
    "повысыхавши": ["повысыхав"],
    "повытаращивав": ["повытаращивавши"],
    "повытаращивавши": ["повытаращивав"],
    "повытаскав": ["повытаскавши"],
    "повытаскавши": ["повытаскав"],
    "повытаскивав": ["повытаскивавши"],
    "повытаскивавши": ["повытаскивав"],
    "повытаскивать": ["повытащить"],
    "повытащив": ["повытащивши"],
    "повытащивши": ["повытащив"],
    "повытащить": ["повытаскивать"],
    "повытеснив": ["повытеснивши"],
    "повытеснивши": ["повытеснив"],
    "повытоптав": ["повытоптавши"],
    "повытоптавши": ["повытоптав"],
    "повытравив": ["повытравивши"],
    "повытравивши": ["повытравив"],
    "повытрусив": ["повытрусивши"],
    "повытрусивши": ["повытрусив"],
    "повытряхав": ["повытряхавши"],
    "повытряхавши": ["повытряхав"],
    "повытряхивав": ["повытряхивавши"],
    "повытряхивавши": ["повытряхивав"],
    "повытряхнув": ["повытряхнувши"],
    "повытряхнувши": ["повытряхнув"],
    "повытчик": ["подьячий", "столоначальник"],
    "повытье": ["департамент", "стол", "надел", "вотчина"],
    "повытянув": ["повытянувши"],
    "повытянувши": ["повытянув"],
    "повыхлестав": ["повыхлеставши"],
    "повыхлеставши": ["повыхлестав"],
    "повыходив": ["повыходивши"],
    "повыходивши": ["повыходив"],
    "повыцарапав": ["повыцарапавши"],
    "повыцарапавши": ["повыцарапав"],
    "повычеркав": ["повычеркавши"],
    "повычеркавши": ["повычеркав"],
    "повычёркивав": ["повычёркивавши"],
    "повычёркивавши": ["повычёркивав"],
    "повышав": ["повышавши"],
    "повышавши": ["повышав"],
    "повышательный": ["восходящий"],
    "повышать": ["увеличивать", "поднимать", "наращивать", "продвигать"],
    "повышаться": ["увеличиваться", "расти"],
    "повышвыривав": ["повышвыривавши"],
    "повышвыривавши": ["повышвыривав"],
    "повышение": ["рост", "возвышение", "увеличение", "карьерный рост"],
    "повышенье": ["повышение"],
    "повышибав": ["повышибавши"],
    "повышибавши": ["повышибав"],
    "повышибив": ["повышибивши"],
    "повышибивши": ["повышибив"],
    "повыщипав": ["повыщипавши"],
    "повыщипавши": ["повыщипав"],
    "повыщипывав": ["повыщипывавши"],
    "повыщипывавши": ["повыщипывав"],
    "повязав": ["повязавши"],
    "повязавши": ["повязав"],
    "повязывав": ["повязывавши"],
    "повязывавши": ["повязывав"],
    "повялив": ["повяливши"],
    "повяливши": ["повялив"],
    "повянув": ["повянувши"],
    "повянувши": ["повянув"],
    "повят": ["повет"],
    "повёзши": ["повезя"],
    "повёзшись": ["повезясь"],
    "повёрстывав": ["повёрстывавши"],
    "повёрстывавши": ["повёрстывав"],
    "повёртывав": ["повёртывавши"],
    "повёртывавши": ["повёртывав"],
    "повёртываться": ["поворачиваться", "ворочаться", "оборачиваться"],
    "погавкав": ["погавкавши"],
    "погавкавши": ["погавкав"],
    "погадав": ["погадавши"],
    "погадавши": ["погадав"],
    "погадка": ["отрыжка"],
    "погазовав": ["погазовавши"],
    "погазовавши": ["погазовав"],
    "погалдев": ["погалдевши"],
    "погалдевши": ["погалдев"],
    "поганец": ["гадёныш"],
    "поганив": ["поганивши"],
    "поганивши": ["поганив"],
    "поганый": ["дрянной", "скверный", "отвратительный", "отвратный", "мерзкий", "ядовитый"],
    "погань": ["гадость", "дрянь", "мерзость", "нечисть", "гнусь", "сброд"],
    "погаркивав": ["погаркивавши"],
    "погаркивавши": ["погаркивав"],
    "погарцевав": ["погарцевавши"],
    "погарцевавши": ["погарцевав"],
    "погасав": ["погасавши"],
    "погасавши": ["погасав"],
    "погасать": ["гаснуть", "затухать", "потухать", "угасать", "тускнеть", "меркнуть"],
    "погасив": ["погасивши"],
    "погасивши": ["погасив"],
    "погасить": ["потушить", "загасить", "подавить", "заглушить", "ослабить"],
    "погаснув": ["погаснувши"],
    "погаснувши": ["погаснув"],
    "погаснуть": ["угаснуть", "потухнуть"],
    "погашав": ["погашавши"],
    "погашавши": ["погашав"],
    "погеройствовав": ["погеройствовавши"],
    "погеройствовавши": ["погеройствовав"],
    "погиб": ["изгиб", "изогнутость"],
    "погибав": ["погибавши"],
    "погибавши": ["погибав"],
    "погибать": ["гибнуть", "пропадать"],
    "погибель": ["гибель"],
    "погибнув": ["погибнувши"],
    "погибнувши": ["погибнув"],
    "погибнуть": ["пасть"],
    "погибший": ["павший", "падший", "опустившийся", "конченый", "гиблый"],
    "погинув": ["погинувши"],
    "погинувши": ["погинув"],
    "погладив": ["погладивши"],
    "погладивши": ["погладив"],
    "погладывав": ["погладывавши"],
    "погладывавши": ["погладывав"],
    "поглаживав": ["поглаживавши"],
    "поглаживавши": ["поглаживав"],
    "поглаживанье": ["поглаживание"],
    "поглазев": ["поглазевши"],
    "поглазевши": ["поглазев"],
    "поглатывав": ["поглатывавши"],
    "поглатывавши": ["поглатывав"],
    "поглодав": ["поглодавши"],
    "поглодавши": ["поглодав"],
    "поглотав": ["поглотавши"],
    "поглотавши": ["поглотав"],
    "поглотив": ["поглотивши"],
    "поглотивши": ["поглотив"],
    "поглотитель": ["абсорбер", "пожиратель", "адсорбер", "гаситель", "сорбент", "нейтрализатор", "абсорбент", "геттер"],
    "поглощав": ["поглощавши"],
    "поглощавши": ["поглощав"],
    "поглощать": ["вбирать", "впитывать"],
    "поглощающий": ["съедающий", "проглатывающий", "пожирающий"],
    "поглощенье": ["поглощение"],
    "поглупев": ["поглупевши"],
    "поглупевши": ["поглупев"],
    "поглупив": ["поглупивши"],
    "поглупивши": ["поглупив"],
    "поглушив": ["поглушивши"],
    "поглушивши": ["поглушив"],
    "поглядев": ["поглядевши"],
    "поглядевши": ["поглядев"],
    "поглядеть": ["посмотреть"],
    "поглядывав": ["поглядывавши"],
    "поглядывавши": ["поглядывав"],
    "поглядыванье": ["поглядывание"],
    "поглядывать": ["посматривать", "обращать внимание", "наблюдать", "присматривать", "следить", "надзирать"],
    "поглянув": ["поглянувши"],
    "поглянувши": ["поглянув"],
    "погмыкав": ["погмыкавши"],
    "погмыкавши": ["погмыкав"],
    "погмыкивав": ["погмыкивавши"],
    "погмыкивавши": ["погмыкивав"],
    "погнав": ["погнавши"],
    "погнавши": ["погнав"],
    "погневив": ["погневивши"],
    "погневивши": ["погневив"],
    "погнив": ["погнивши"],
    "погнивав": ["погнивавши"],
    "погнивавши": ["погнивав"],
    "погнивши": ["погнив"],
    "погноив": ["погноивши"],
    "погноивши": ["погноив"],
    "погнув": ["погнувши"],
    "погнувши": ["погнув"],
    "погнуса": ["отвращение"],
    "погнутость": ["искривлённость", "искривление"],
    "поговаривав": ["поговаривавши"],
    "поговаривавши": ["поговаривав"],
    "поговев": ["поговевши"],
    "поговевши": ["поговев"],
    "поговорив": ["поговоривши"],
    "поговоривши": ["поговорив"],
    "поговорить": ["поболтать", "побеседовать"],
    "погогатывав": ["погогатывавши"],
    "погогатывавши": ["погогатывав"],
    "погоготав": ["погоготавши"],
    "погоготавши": ["погоготав"],
    "погоготывав": ["погоготывавши"],
    "погоготывавши": ["погоготывав"],
    "погода": ["погодка", "ненастье", "непогода", "климат", "атмосфера"],
    "погодив": ["погодивши"],
    "погодивши": ["погодив"],
    "погодить": ["повременить", "подождать"],
    "поголадывав": ["поголадывавши"],
    "поголадывавши": ["поголадывав"],
    "поголовно": ["сплошь"],
    "поголовность": ["тотальность"],
    "поголовный": ["всеобщий", "повальный", "тотальный", "сплошной"],
    "поголодав": ["поголодавши"],
    "поголодавши": ["поголодав"],
    "поголосив": ["поголосивши"],
    "поголосивши": ["поголосив"],
    "поголоска": ["поголос"],
    "поголубев": ["поголубевши"],
    "поголубевши": ["поголубев"],
    "поголубив": ["поголубивши"],
    "поголубивши": ["поголубив"],
    "погомонив": ["погомонивши"],
    "погомонивши": ["погомонив"],
    "погонич": ["погонець"],
    "погонный метр": ["линейный метр"],
    "погоня": ["преследователь"],
    "погоняв": ["погонявши"],
    "погонявши": ["погоняв"],
    "погонялка": ["погоняло"],
    "погоняло": ["погонялка"],
    "погонять": ["гнать", "торопить", "поторапливать"],
    "погорав": ["погоравши"],
    "погоравши": ["погорав"],
    "погордев": ["погордевши"],
    "погордевши": ["погордев"],
    "погорев": ["погоревши"],
    "погоревав": ["погоревавши"],
    "погоревавши": ["погоревав"],
    "погоревши": ["погорев"],
    "погорланив": ["погорланивши"],
    "погорланивши": ["погорланив"],
    "погорлопанив": ["погорлопанивши"],
    "погорлопанивши": ["погорлопанив"],
    "погорчав": ["погорчавши"],
    "погорчавши": ["погорчав"],
    "погорчив": ["погорчивши"],
    "погорчивши": ["погорчив"],
    "погорячив": ["погорячивши"],
    "погорячивши": ["погорячив"],
    "погорячиться": ["вспылить"],
    "погосподствовав": ["погосподствовавши"],
    "погосподствовавши": ["погосподствовав"],
    "погост": ["скудельня", "скудельница", "цвынтарь", "подворье"],
    "погостевав": ["погостевавши"],
    "погостевавши": ["погостевав"],
    "погостив": ["погостивши"],
    "погостивши": ["погостив"],
    "пограбив": ["пограбивши"],
    "пограбивши": ["пограбив"],
    "погравировав": ["погравировавши"],
    "погравировавши": ["погравировав"],
    "погранец": ["пограничник"],
    "погранив": ["погранивши"],
    "погранивши": ["погранив"],
    "пограничник": ["погранец", "зелёнофуражечник"],
    "пограничное расстройство личности": ["прл"],
    "погранпереход": ["контрольно-пропускной пункт", "кпп"],
    "погранпост": ["пограничный пост"],
    "погреб": ["подпол", "подвал"],
    "погребав": ["погребавши"],
    "погребавши": ["погребав"],
    "погребаемый": ["хоронимый"],
    "погребальный": ["похоронный", "траурный"],
    "погребать": ["хоронить"],
    "погребение": ["захоронение", "похороны", "могила"],
    "погребень": ["погребин"],
    "погребец": ["погреб", "подвал", "ларец", "сундучок"],
    "погребин": ["погребень", "погребной", "погребное"],
    "погребное": ["погребень", "погребин", "погребной"],
    "погрев": ["погревши"],
    "погревав": ["погревавши"],
    "погревавши": ["погревав"],
    "погревши": ["погрев"],
    "погрезив": ["погрезивши"],
    "погрезивши": ["погрезив"],
    "погрезиться": ["показаться", "почудиться", "примерещиться", "привидеться", "померещиться", "пригрезиться", "причудиться"],
    "погремев": ["погремевши"],
    "погремевши": ["погремев"],
    "погремливав": ["погремливавши"],
    "погремливавши": ["погремливав"],
    "погремок": ["звонец", "позвонок", "алекторолофус"],
    "погремок эзельский": ["сааремааский погремок"],
    "погремушка": ["побрякушка"],
    "погрешав": ["погрешавши"],
    "погрешавши": ["погрешав"],
    "погрешив": ["погрешивши"],
    "погрешивши": ["погрешив"],
    "погримасничав": ["погримасничавши"],
    "погримасничавши": ["погримасничав"],
    "погрозив": ["погрозивши"],
    "погрозивши": ["погрозив"],
    "погрознев": ["погрозневши"],
    "погрозневши": ["погрознев"],
    "погром": ["разгром"],
    "погромив": ["погромивши"],
    "погромивши": ["погромив"],
    "погромист": ["программист"],
    "погромить": ["разорить", "опустошить"],
    "погромыхав": ["погромыхавши"],
    "погромыхавши": ["погромыхав"],
    "погромыхивав": ["погромыхивавши"],
    "погромыхивавши": ["погромыхивав"],
    "погромыхиванье": ["погромыхивание"],
    "погрохатывав": ["погрохатывавши"],
    "погрохатывавши": ["погрохатывав"],
    "погрохотав": ["погрохотавши"],
    "погрохотавши": ["погрохотав"],
    "погрубев": ["погрубевши"],
    "погрубевши": ["погрубев"],
    "погрубив": ["погрубивши"],
    "погрубивши": ["погрубив"],
    "погружав": ["погружавши"],
    "погружавши": ["погружав"],
    "погружать": ["ввергать", "грузить"],
    "погруженный": ["нагруженный", "помещённый"],
    "погруженье": ["погружение"],
    "погружной": ["погружённый"],
    "погрузив": ["погрузивши"],
    "погрузивши": ["погрузив"],
    "погрузиться": ["потонуть", "подрязгнуть"],
    "погрузнев": ["погрузневши"],
    "погрузневши": ["погрузнев"],
    "погрузнув": ["погрузнувши"],
    "погрузнувши": ["погрузнув"],
    "погрузрайон": ["погрузочный", "район"],
    "погрузчик": ["автопогрузчик"],
    "погрустив": ["погрустивши"],
    "погрустивши": ["погрустив"],
    "погрустнев": ["погрустневши"],
    "погрустневши": ["погрустнев"],
    "погрызывав": ["погрызывавши"],
    "погрызывавши": ["погрызывав"],
    "погрязав": ["погрязавши"],
    "погрязавши": ["погрязав"],
    "погрязать": ["угрязать", "увязать"],
    "погрязнув": ["погрязнувши"],
    "погрязнувши": ["погрязнув"],
    "погубив": ["погубивши"],
    "погубивши": ["погубив"],
    "погубить": ["загубить", "сгубить", "уничтожить", "истребить", "испортить"],
    "погубляв": ["погублявши"],
    "погублявши": ["погубляв"],
    "погуглив": ["погугливши"],
    "погугливши": ["погуглив"],
    "погудев": ["погудевши"],
    "погудевши": ["погудев"],
    "погудывав": ["погудывавши"],
    "погудывавши": ["погудывав"],
    "погуживав": ["погуживавши"],
    "погуживавши": ["погуживав"],
    "погукав": ["погукавши"],
    "погукавши": ["погукав"],
    "погукивав": ["погукивавши"],
    "погукивавши": ["погукивав"],
    "погуливав": ["погуливавши"],
    "погуливавши": ["погуливав"],
    "погуляв": ["погулявши"],
    "погулявши": ["погуляв"],
    "погундосив": ["погундосивши"],
    "погундосивши": ["погундосив"],
    "погуркивав": ["погуркивавши"],
    "погуркивавши": ["погуркивав"],
    "погустев": ["погустевши"],
    "погустевши": ["погустев"],
    "погутарив": ["погутаривши"],
    "погутаривши": ["погутарив"],
    "погутарить": ["поговорить"],
    "погуторив": ["погуторивши"],
    "погуторивши": ["погуторив"],
    "погуторить": ["поговорить", "поболтать", "побеседовать", "подискутировать"],
    "под бобрик": ["бобриком"],
    "под боком": ["под носом"],
    "под газом": ["подшофе", "навеселе"],
    "под дозой": ["под кайфом"],
    "под каблуком": ["под пятой"],
    "под конец": ["наконец", "напоследок"],
    "под монастырь подвести": ["подвести под монастырь", "подложить свинью", "свинью подложить"],
    "под мухой": ["под газом", "подшофе"],
    "под нос": ["тихо", "шёпотом"],
    "под носом как насрано": ["под носом как будто насрано", "будто под носом насрано", "будто насрано под носом", "как будто под носом насрано"],
    "под одной крышей": ["под одной кровлей"],
    "под открытым небом": ["на открытом воздухе", "снаружи"],
    "под покровом": ["под прикрытием", "под защитой"],
    "под прицелом": ["на мушке", "под колпаком"],
    "под пьяную лавочку": ["по пьяной лавочке"],
    "под ружьё": ["сушить штык"],
    "под снос": ["на снос"],
    "под сраку лет": ["одной ногой в гробу"],
    "под сурдинку": ["приглушённо", "вполголоса", "шёпотом", "украдкой", "втихомолку", "под шумок"],
    "под фасадом": ["за фасадом"],
    "под фирмой": ["под видом"],
    "под хмельком": ["навеселе", "подвыпивши", "спьяну", "спьяна", "с пьяных глаз", "на бровях"],
    "под цвет": ["под стать"],
    "под шумок": ["тихой сапой", "за спиной", "под сурдинку", "шито и крыто"],
    "под-": ["при-", "до-"],
    "под-шефе": ["подшофе", "подшефе", "под хмельком", "навеселе"],
    "подав": ["подавши"],
    "подавав": ["подававши"],
    "подававши": ["подавав"],
    "подавальщик": ["подающий", "питчер", "подносчик", "задавальщик", "официант", "разносчик"],
    "подаванье": ["подавание"],
    "подавать": ["давать", "преподносить", "подносить", "сервировать", "доставлять"],
    "подаваться": ["сдвигаться"],
    "подавив": ["подавивши"],
    "подавивши": ["подавив"],
    "подавить": ["понажимать"],
    "подавиться": ["раздавиться", "помяться"],
    "подавленный": ["задавленный", "угнетённый"],
    "подавленье": ["подавление"],
    "подавливав": ["подавливавши"],
    "подавливавши": ["подавливав"],
    "подавляв": ["подавлявши"],
    "подавлявши": ["подавляв"],
    "подавно": ["тем более", "тем паче"],
    "подавши": ["подав"],
    "подалбливав": ["подалбливавши"],
    "подалбливавши": ["подалбливав"],
    "подале": ["подальше", "подалее"],
    "подалее": ["подальше", "подале"],
    "подальше": ["дальше"],
    "подаренье": ["дарить", "подарок"],
    "подарив": ["подаривши"],
    "подаривши": ["подарив"],
    "подарок": ["дар", "поминок", "презент", "сувенир"],
    "подарочек": ["подарок"],
    "податливость": ["уступчивость"],
    "податливый": ["мягкий", "уступчивый", "сговорчивый"],
    "податной": ["налоговый", "налогооблагаемый", "налоговик", "мытарь"],
    "подать": ["тягло", "дань"],
    "подача": ["предоставление", "представление"],
    "подачка": ["подаяние"],
    "подаяние": ["милостыня", "подаянье"],
    "подаяння": ["милостиня"],
    "подаянье": ["подаяние", "милостыня"],
    "подбавив": ["подбавивши"],
    "подбавивши": ["подбавив"],
    "подбавляв": ["подбавлявши"],
    "подбавлявши": ["подбавляв"],
    "подбагрив": ["подбагривши"],
    "подбагривав": ["подбагривавши"],
    "подбагривавши": ["подбагривав"],
    "подбагривши": ["подбагрив"],
    "подбадривав": ["подбадривавши"],
    "подбадривавши": ["подбадривав"],
    "подбадривать": ["подбодрять"],
    "подбадриваться": ["подбодряться"],
    "подбалка": ["подбалочник"],
    "подбалочник": ["подбалка"],
    "подбалтывав": ["подбалтывавши"],
    "подбалтывавши": ["подбалтывав"],
    "подбамбливать": ["раздражать"],
    "подбегав": ["подбегавши"],
    "подбегавши": ["подбегав"],
    "подбежав": ["подбежавши"],
    "подбежавши": ["подбежав"],
    "подбел": ["андромеда", "белолистник", "бесплодница", "бесплодный куст", "болотник", "пьяная трава", "пьяный болотник", "тундрица", "мать-и-мачеха", "двоелистник", "камчужная трава", "лапуха студёная", "лопушник", "матерник", "мачеха"],
    "подбел обыкновенный": ["подбел белолистник", "подбел дубровник", "подбел многолистный"],
    "подбелив": ["подбеливши"],
    "подбеливав": ["подбеливавши"],
    "подбеливавши": ["подбеливав"],
    "подбеливши": ["подбелив"],
    "подберёзовик": ["обабок", "берёзовик"],
    "подбешивать": ["раздражать"],
    "подбив": ["подбивши"],
    "подбивав": ["подбивавши"],
    "подбивавши": ["подбивав"],
    "подбивать": ["подначивать", "подстрекать"],
    "подбивать бабки": ["подводить бабки", "бабки подбивать"],
    "подбивши": ["подбив"],
    "подбинтовав": ["подбинтовавши"],
    "подбинтовавши": ["подбинтовав"],
    "подбинтовывав": ["подбинтовывавши"],
    "подбинтовывавши": ["подбинтовывав"],
    "подбирав": ["подбиравши"],
    "подбиравши": ["подбирав"],
    "подбирать": ["поднимать", "подтягивать", "вбирать", "оправлять", "выбирать"],
    "подбитый ветром": ["неспокойный", "гиперактивный", "буйный"],
    "подбить бабки": ["подвести бабки", "бабки подбить"],
    "подбодрив": ["подбодривши"],
    "подбодривши": ["подбодрив"],
    "подбодриться": ["приободриться"],
    "подбодряв": ["подбодрявши"],
    "подбодрявши": ["подбодряв"],
    "подбодрять": ["подбадривать"],
    "подбодряться": ["подбадриваться"],
    "подбой": ["подбойка", "подбивка", "подкладка"],
    "подболтав": ["подболтавши"],
    "подболтавши": ["подболтав"],
    "подборка": ["подбор", "коллекция", "набор"],
    "подбородок": ["борода"],
    "подбородочек": ["подбородок"],
    "подбочениться": ["избочениться"],
    "подбрасывав": ["подбрасывавши"],
    "подбрасывавши": ["подбрасывав"],
    "подбрасыванье": ["подбрасывание"],
    "подбрасывать": ["подкидывать"],
    "подбредав": ["подбредавши"],
    "подбредавши": ["подбредав"],
    "подбрив": ["подбривши"],
    "подбривав": ["подбривавши"],
    "подбривавши": ["подбривав"],
    "подбривши": ["подбрив"],
    "подбрить": ["стыбзить"],
    "подброс": ["подброска"],
    "подбросав": ["подбросавши"],
    "подбросавши": ["подбросав"],
    "подбросив": ["подбросивши"],
    "подбросивши": ["подбросив"],
    "подбросить": ["подкинуть", "подвезти"],
    "подбрыкивав": ["подбрыкивавши"],
    "подбрыкивавши": ["подбрыкивав"],
    "подбрыкнув": ["подбрыкнувши"],
    "подбрыкнувши": ["подбрыкнув"],
    "подбудител": ["подстрекател", "поощрител", "вдъхновител"],
    "подбуксировав": ["подбуксировавши"],
    "подбуксировавши": ["подбуксировав"],
    "подбухав": ["подбухавши"],
    "подбухавши": ["подбухав"],
    "подбухнув": ["подбухнувши"],
    "подбухнувши": ["подбухнув"],
    "подбухнуть": ["прибухнуть"],
    "подбывав": ["подбывавши"],
    "подбывавши": ["подбывав"],
    "подважив": ["подваживши"],
    "подваживав": ["подваживавши"],
    "подваживавши": ["подваживав"],
    "подваживши": ["подважив"],
    "подваксив": ["подваксивши"],
    "подваксивши": ["подваксив"],
    "подвал": ["подземелье", "погреб", "винный погреб", "подвалка"],
    "подвалив": ["подваливши"],
    "подваливав": ["подваливавши"],
    "подваливавши": ["подваливав"],
    "подваливши": ["подвалив"],
    "подванивав": ["подванивавши"],
    "подванивавши": ["подванивав"],
    "подварив": ["подваривши"],
    "подваривав": ["подваривавши"],
    "подваривавши": ["подваривав"],
    "подваривши": ["подварив"],
    "подвастривав": ["подвастривавши"],
    "подвастривавши": ["подвастривав"],
    "подващивав": ["подващивавши"],
    "подващивавши": ["подващивав"],
    "подвевав": ["подвевавши"],
    "подвевавши": ["подвевав"],
    "подведенье": ["подведение"],
    "подведомый": ["подведомственный", "подчинённый"],
    "подвезя": ["подвёзши"],
    "подвеивав": ["подвеивавши"],
    "подвеивавши": ["подвеивав"],
    "подвергав": ["подвергавши"],
    "подвергавши": ["подвергав"],
    "подвергнув": ["подвергнувши"],
    "подвергнувши": ["подвергнув"],
    "подвергнутый": ["обречённый"],
    "подвергнуться": ["претерпеть"],
    "подвернув": ["подвернувши"],
    "подвернувши": ["подвернув"],
    "подверстав": ["подверставши"],
    "подверставши": ["подверстав"],
    "подверстать": ["приравнять", "уподобить", "отождествить"],
    "подвертев": ["подвертевши"],
    "подвертевши": ["подвертев"],
    "подвертеть": ["подвернуть", "подкрутить"],
    "подверчивав": ["подверчивавши"],
    "подверчивавши": ["подверчивав"],
    "подвершив": ["подвершивши"],
    "подвершивав": ["подвершивавши"],
    "подвершивавши": ["подвершивав"],
    "подвершивши": ["подвершив"],
    "подвеселив": ["подвеселивши"],
    "подвеселивши": ["подвеселив"],
    "подвеселяв": ["подвеселявши"],
    "подвеселявши": ["подвеселяв"],
    "подвесив": ["подвесивши"],
    "подвесивши": ["подвесив"],
    "подвеска": ["украшение", "крючок"],
    "подвесок": ["суспензор", "гиомандибуляре"],
    "подвести под монастырь": ["под монастырь подвести", "подложить свинью", "свинью подложить"],
    "подвечеривав": ["подвечеривавши"],
    "подвечеривавши": ["подвечеривав"],
    "подвечеряв": ["подвечерявши"],
    "подвечерявши": ["подвечеряв"],
    "подвешивав": ["подвешивавши"],
    "подвешивавши": ["подвешивав"],
    "подвеяв": ["подвеявши"],
    "подвеявши": ["подвеяв"],
    "подвздошная кишка": ["илеум"],
    "подвив": ["подвивши"],
    "подвивав": ["подвивавши"],
    "подвивавши": ["подвивав"],
    "подвивши": ["подвив"],
    "подвигав": ["подвигавши"],
    "подвигавши": ["подвигав"],
    "подвигаясь": ["двигаясь", "передвигаясь", "пододвигаясь", "придвигаясь"],
    "подвигнув": ["подвигнувши"],
    "подвигнувши": ["подвигнув"],
    "подвигнуть": ["возбуждать", "принуждать", "подвизать", "подвинуть", "двинуть", "подвигнуться"],
    "подвигнуться": ["сдвинуться", "переместиться", "отважиться", "решиться"],
    "подвижник": ["анахорет", "аскет", "еремит", "затворник", "монах", "отшельник", "постник", "пустынник", "пустынножитель", "скитник"],
    "подвижничав": ["подвижничавши"],
    "подвижничавши": ["подвижничав"],
    "подвижной состав": ["подвижный состав"],
    "подвижность": ["перемещаемость"],
    "подвижный состав": ["подвижной состав"],
    "подвизав": ["подвизавши"],
    "подвизавши": ["подвизав"],
    "подвизанье": ["подвиганье", "подвинутие", "подвиг"],
    "подвизать": ["побуждать", "поощрять"],
    "подвизаться": ["действовать", "бороться"],
    "подвизаться на поприще": ["бороться", "ратовать"],
    "подвизаться на сцене": ["играть"],
    "подвизгивав": ["подвизгивавши"],
    "подвизгивавши": ["подвизгивав"],
    "подвизгиванье": ["подвизгивание"],
    "подвизгнув": ["подвизгнувши"],
    "подвизгнувши": ["подвизгнув"],
    "подвиливав": ["подвиливавши"],
    "подвиливавши": ["подвиливав"],
    "подвильнув": ["подвильнувши"],
    "подвильнувши": ["подвильнув"],
    "подвинтив": ["подвинтивши"],
    "подвинтивши": ["подвинтив"],
    "подвинув": ["подвинувши"],
    "подвинувши": ["подвинув"],
    "подвинчивав": ["подвинчивавши"],
    "подвинчивавши": ["подвинчивав"],
    "подвирав": ["подвиравши"],
    "подвиравши": ["подвирав"],
    "подвисав": ["подвисавши"],
    "подвисавши": ["подвисав"],
    "подвиснув": ["подвиснувши"],
    "подвиснувши": ["подвиснув"],
    "подвихнув": ["подвихнувши"],
    "подвихнувши": ["подвихнув"],
    "подвишенник": ["вишенник", "вишняк", "ивишенник", "ивишень", "подвишень", "клитопилус"],
    "подвишень": ["вишенник", "вишняк", "ивишенник", "ивишень", "подвишенник", "клитопилус"],
    "подвластность": ["зависимость", "подневольность", "подчинённость", "подначальность"],
    "подводив": ["подводивши"],
    "подводивши": ["подводив"],
    "подводить": ["соотносить", "сдавать"],
    "подводить итог": ["заключать", "делать выводы"],
    "подводка": ["подводка для глаз", "лайнер"],
    "подводная лодка": ["субмарина", "подлодка", "пл"],
    "подводничав": ["подводничавши"],
    "подводничавши": ["подводничав"],
    "подводный камень": ["подвох", "ловушка"],
    "подвозив": ["подвозивши"],
    "подвозивши": ["подвозив"],
    "подволакивав": ["подволакивавши"],
    "подволакивавши": ["подволакивав"],
    "подволок": ["подволока"],
    "подволочив": ["подволочивши"],
    "подволочивши": ["подволочив"],
    "подворачивав": ["подворачивавши"],
    "подворачивавши": ["подворачивав"],
    "подворовывав": ["подворовывавши"],
    "подворовывавши": ["подворовывав"],
    "подворотив": ["подворотивши"],
    "подворотивши": ["подворотив"],
    "подворотничок": ["подшива", "подшивка"],
    "подворье": ["усадьба"],
    "подвострив": ["подвостривши"],
    "подвостривши": ["подвострив"],
    "подвох": ["интрига", "козни", "ковы", "шашни", "лукавство", "подсиживание", "каверза", "камуфлет", "подкоп", "подсидка", "происки", "ловушка", "западня"],
    "подвощив": ["подвощивши"],
    "подвощивши": ["подвощив"],
    "подвсплыв": ["подвсплывши"],
    "подвсплывав": ["подвсплывавши"],
    "подвсплывавши": ["подвсплывав"],
    "подвсплывши": ["подвсплыв"],
    "подвывав": ["подвывавши"],
    "подвывавши": ["подвывав"],
    "подвыванье": ["подвывание"],
    "подвывка": ["ваба"],
    "подвывши": ["подвыв"],
    "подвыпив": ["подвыпивши"],
    "подвыпивши": ["подвыпив"],
    "подвысив": ["подвысивши"],
    "подвысивши": ["подвысив"],
    "подвысить": ["приподнять"],
    "подвышав": ["подвышавши"],
    "подвышавши": ["подвышав"],
    "подвядав": ["подвядавши"],
    "подвядавши": ["подвядав"],
    "подвязав": ["подвязавши"],
    "подвязавши": ["подвязав"],
    "подвязывав": ["подвязывавши"],
    "подвязывавши": ["подвязывав"],
    "подвякнув": ["подвякнувши"],
    "подвякнувши": ["подвякнув"],
    "подвялив": ["подвяливши"],
    "подвяливав": ["подвяливавши"],
    "подвяливавши": ["подвяливав"],
    "подвяливши": ["подвялив"],
    "подвянув": ["подвянувши"],
    "подвянувши": ["подвянув"],
    "подвёзши": ["подвезя"],
    "подвёрстывав": ["подвёрстывавши"],
    "подвёрстывавши": ["подвёрстывав"],
    "подвёртывав": ["подвёртывавши"],
    "подвёртывавши": ["подвёртывав"],
    "подвёртывать": ["подворачивать", "подъезжать"],
    "подгадав": ["подгадавши"],
    "подгадавши": ["подгадав"],
    "подгадив": ["подгадивши"],
    "подгадивши": ["подгадив"],
    "подгадывав": ["подгадывавши"],
    "подгадывавши": ["подгадывав"],
    "подгаживав": ["подгаживавши"],
    "подгаживавши": ["подгаживав"],
    "подгазовав": ["подгазовавши"],
    "подгазовавши": ["подгазовав"],
    "подганивав": ["подганивавши"],
    "подганивавши": ["подганивав"],
    "подгарцовывав": ["подгарцовывавши"],
    "подгарцовывавши": ["подгарцовывав"],
    "подгвазживав": ["подгвазживавши"],
    "подгвазживавши": ["подгвазживав"],
    "подгвоздив": ["подгвоздивши"],
    "подгвоздивши": ["подгвоздив"],
    "подгибав": ["подгибавши"],
    "подгибавши": ["подгибав"],
    "подгибать": ["загибать"],
    "подгладив": ["подгладивши"],
    "подгладивши": ["подгладив"],
    "подгладывав": ["подгладывавши"],
    "подгладывавши": ["подгладывав"],
    "подглаживав": ["подглаживавши"],
    "подглаживавши": ["подглаживав"],
    "подглодав": ["подглодавши"],
    "подглодавши": ["подглодав"],
    "подглядев": ["подглядевши"],
    "подглядевши": ["подглядев"],
    "подглядеть": ["подсмотреть"],
    "подглядывав": ["подглядывавши"],
    "подглядывавши": ["подглядывав"],
    "подглядывать": ["подсматривать", "следить", "шпионить", "заглядывать", "списывать", "подмечать"],
    "подгнаивав": ["подгнаивавши"],
    "подгнаивавши": ["подгнаивав"],
    "подгнив": ["подгнивши"],
    "подгнивав": ["подгнивавши"],
    "подгнивавши": ["подгнивав"],
    "подгнивание": ["загнивание"],
    "подгнивши": ["подгнив"],
    "подгноив": ["подгноивши"],
    "подгноивши": ["подгноив"],
    "подговаривав": ["подговаривавши"],
    "подговаривавши": ["подговаривав"],
    "подговняв": ["подговнявши"],
    "подговнявши": ["подговняв"],
    "подговорив": ["подговоривши"],
    "подговоривши": ["подговорив"],
    "подголадывав": ["подголадывавши"],
    "подголадывавши": ["подголадывав"],
    "подголашивав": ["подголашивавши"],
    "подголашивавши": ["подголашивав"],
    "подголосив": ["подголосивши"],
    "подголосивши": ["подголосив"],
    "подголосничав": ["подголосничавши"],
    "подголосничавши": ["подголосничав"],
    "подголубив": ["подголубивши"],
    "подголубивши": ["подголубив"],
    "подгонка": ["подгон", "доводка", "приладка", "подтасовка"],
    "подгонщик": ["сташник"],
    "подгоняв": ["подгонявши"],
    "подгонявши": ["подгоняв"],
    "подгонять": ["торопить", "подстёгивать", "подхлёстывать", "понукать", "поторапливать"],
    "подгорав": ["подгоравши"],
    "подгоравши": ["подгорав"],
    "подгораживав": ["подгораживавши"],
    "подгораживавши": ["подгораживав"],
    "подгорев": ["подгоревши"],
    "подгоревши": ["подгорев"],
    "подгоренский": ["подгорненский"],
    "подгорица": ["титоград", "бургурице", "богуртлен", "рибница", "дукля", "диоклея", "бирзиминиум"],
    "подгородив": ["подгородивши"],
    "подгородивши": ["подгородив"],
    "подгородный": ["загородный"],
    "подгорчив": ["подгорчивши"],
    "подгорчивши": ["подгорчив"],
    "подгорячив": ["подгорячивши"],
    "подгорячивши": ["подгорячив"],
    "подготавливав": ["подготавливавши"],
    "подготавливавши": ["подготавливав"],
    "подготавливаться": ["подготовляться"],
    "подготвеност": ["готовност"],
    "подготовив": ["подготовивши"],
    "подготовивши": ["подготовив"],
    "подготовиться": ["приготовиться"],
    "подготовка": ["приготовления", "тренировка", "обучение", "тренированность", "подготовленность", "квалификация"],
    "подготовляв": ["подготовлявши"],
    "подготовлявши": ["подготовляв"],
    "подготовлять": ["подготавливать", "готовить"],
    "подгребав": ["подгребавши"],
    "подгребавши": ["подгребав"],
    "подгримировав": ["подгримировавши"],
    "подгримировавши": ["подгримировав"],
    "подгримировывав": ["подгримировывавши"],
    "подгримировывавши": ["подгримировывав"],
    "подгромыхав": ["подгромыхавши"],
    "подгромыхавши": ["подгромыхав"],
    "подгромыхивав": ["подгромыхивавши"],
    "подгромыхивавши": ["подгромыхивав"],
    "подгружав": ["подгружавши"],
    "подгружавши": ["подгружав"],
    "подгрузив": ["подгрузивши"],
    "подгрузивши": ["подгрузив"],
    "подгрунтовав": ["подгрунтовавши"],
    "подгрунтовавши": ["подгрунтовав"],
    "подгрунтовывав": ["подгрунтовывавши"],
    "подгрунтовывавши": ["подгрунтовывав"],
    "подгрызав": ["подгрызавши"],
    "подгрызавши": ["подгрызав"],
    "подгузник": ["памперс"],
    "подгуливав": ["подгуливавши"],
    "подгуливавши": ["подгуливав"],
    "подгуляв": ["подгулявши"],
    "подгулявши": ["подгуляв"],
    "подгустив": ["подгустивши"],
    "подгустивши": ["подгустив"],
    "подгущав": ["подгущавши"],
    "подгущавши": ["подгущав"],
    "поддабривав": ["поддабривавши"],
    "поддабривавши": ["поддабривав"],
    "поддав": ["поддавши"],
    "поддавав": ["поддававши"],
    "поддававши": ["поддавав"],
    "поддавать": ["подбавлять", "бухать", "выпивать", "жертвовать"],
    "поддаваться": ["впадать", "отступать", "уступать"],
    "поддаваясь": ["уступая"],
    "поддавив": ["поддавивши"],
    "поддавивши": ["поддавив"],
    "поддавливав": ["поддавливавши"],
    "поддавливавши": ["поддавливав"],
    "поддавши": ["поддав"],
    "поддаивав": ["поддаивавши"],
    "поддаивавши": ["поддаивав"],
    "поддакивав": ["поддакивавши"],
    "поддакивавши": ["поддакивав"],
    "поддакиванье": ["поддакивание"],
    "поддакиватель": ["подпевала", "дакальщик"],
    "поддакивать": ["подтакивать", "благоволить", "льстить", "потворствовать"],
    "поддакнув": ["поддакнувши"],
    "поддакнувши": ["поддакнув"],
    "поддалбливав": ["поддалбливавши"],
    "поддалбливавши": ["поддалбливав"],
    "подданный": ["гражданин", "резидент"],
    "подданство": ["гражданство"],
    "поддатый": ["пьяный", "пьяноватый", "пьяненький", "бухой", "тёплый", "хороший"],
    "поддевав": ["поддевавши"],
    "поддевавши": ["поддевав"],
    "поддевши": ["поддев"],
    "поддедюлив": ["поддедюливши"],
    "поддедюливши": ["поддедюлив"],
    "поддедюлить": ["поддеть", "подцепить", "подхватить", "задеть", "уязвить", "присвоить", "без спроса"],
    "подделав": ["подделавши"],
    "подделавши": ["подделав"],
    "подделавшись": ["притворившись", "подделав"],
    "подделаться": ["притворяться"],
    "подделка": ["подделывание", "фальшивка", "липа"],
    "подделочник": ["подделыватель"],
    "подделывав": ["подделывавши"],
    "подделывавши": ["подделывав"],
    "подделыватель": ["липач", "поддельщик"],
    "подделывать": ["фальсифицировать"],
    "подделываться": ["лисить"],
    "поддельный": ["фальшивый", "притворный", "напускной", "неискренний"],
    "поддельщик": ["подделыватель", "фальсификатор"],
    "поддерево": ["субдерево"],
    "поддержав": ["поддержавши"],
    "поддержавши": ["поддержав"],
    "поддержание": ["сохранение", "поддержанье"],
    "поддержанье": ["поддержание"],
    "поддерживав": ["поддерживавши"],
    "поддерживавши": ["поддерживав"],
    "поддерживание": ["поддержание"],
    "поддерживать": ["подпирать", "держать", "помогать", "защищать", "сохранять", "хранить", "придерживаться"],
    "поддержка": ["поддержание", "помощь", "опора", "подспорье", "пособие", "подкрепление", "подмога"],
    "поддиакон": ["поддьякон", "иподиакон", "субдиакон"],
    "поддирав": ["поддиравши"],
    "поддиравши": ["поддирав"],
    "поддиректория": ["подкаталог"],
    "поддобрив": ["поддобривши"],
    "поддобривши": ["поддобрив"],
    "поддоив": ["поддоивши"],
    "поддоивши": ["поддоив"],
    "поддолбив": ["поддолбивши"],
    "поддолбивши": ["поддолбив"],
    "поддомкратив": ["поддомкративши"],
    "поддомкративши": ["поддомкратив"],
    "поддомкрачивав": ["поддомкрачивавши"],
    "поддомкрачивавши": ["поддомкрачивав"],
    "поддоспешник": ["подлатник"],
    "поддразнив": ["поддразнивши"],
    "поддразнивав": ["поддразнивавши"],
    "поддразнивавши": ["поддразнивав"],
    "поддразниванье": ["поддразнивание"],
    "поддразнивши": ["поддразнив"],
    "поддрачивать": ["подмахивать"],
    "поддрачиваться": ["дрочить"],
    "поддубовик": ["дубовик"],
    "поддув": ["поддувание"],
    "поддував": ["поддувавши"],
    "поддувавши": ["поддував"],
    "поддувало": ["зольник"],
    "поддувши": ["поддув"],
    "поддушив": ["поддушивши"],
    "поддушивав": ["поддушивавши"],
    "поддушивавши": ["поддушивав"],
    "поддушивши": ["поддушив"],
    "поддёргивав": ["поддёргивавши"],
    "поддёргивавши": ["поддёргивав"],
    "поддёрнув": ["поддёрнувши"],
    "поддёрнувши": ["поддёрнув"],
    "подебоширив": ["подебоширивши"],
    "подебоширивши": ["подебоширив"],
    "подевав": ["подевавши"],
    "подевавши": ["подевав"],
    "подевать": ["деть"],
    "подеваться": ["деться"],
    "подежурив": ["подежуривши"],
    "подежуривши": ["подежурив"],
    "подействовав": ["подействовавши"],
    "подействовавши": ["подействовав"],
    "поделав": ["поделавши"],
    "поделавши": ["поделав"],
    "поделив": ["поделивши"],
    "поделивши": ["поделив"],
    "поделикатничав": ["поделикатничавши"],
    "поделикатничавши": ["поделикатничав"],
    "поделить": ["разделить"],
    "поделка": ["рукоделие", "халтура"],
    "поделом": ["заслуженно", "за дело"],
    "поделывав": ["поделывавши"],
    "поделывавши": ["поделывав"],
    "поделывать": ["заниматься", "подрабатывать"],
    "поделываться": ["делаться", "происходить", "деяться"],
    "подельник": ["подельщик", "соучастник", "содельник", "компаньон"],
    "поделяться": ["делиться"],
    "подера": ["подэра", "подэрная кривая", "подошвенная кривая"],
    "подержав": ["подержавши"],
    "подержавши": ["подержав"],
    "подержанье": ["подержание"],
    "подерзив": ["подерзивши"],
    "подерзивши": ["подерзив"],
    "подешевев": ["подешевевши"],
    "подешевевши": ["подешевев"],
    "подешевле": ["дешевле"],
    "поджав": ["поджавши"],
    "поджавши": ["поджав"],
    "поджаренный": ["жареный"],
    "поджарив": ["поджаривши"],
    "поджаривав": ["поджаривавши"],
    "поджаривавши": ["поджаривав"],
    "поджаривать": ["жарить"],
    "поджаривши": ["поджарив"],
    "поджарый": ["жилистый", "сухопарый", "худой", "тощий"],
    "поджениться": ["подбортнуться"],
    "поджечь": ["воспламенить", "запалить", "подпалить", "пережарить"],
    "поджив": ["подживши"],
    "подживав": ["подживавши"],
    "подживавши": ["подживав"],
    "подживив": ["поджививши"],
    "поджививши": ["подживив"],
    "подживляв": ["подживлявши"],
    "подживлявши": ["подживляв"],
    "подживши": ["поджив"],
    "поджигав": ["поджигавши"],
    "поджигавши": ["поджигав"],
    "поджигательница": ["подстрекательница"],
    "поджигательный": ["поджигательский"],
    "поджигать": ["воспламенять", "зажигать", "подстрекать", "возбуждать", "подзуживать"],
    "поджидав": ["поджидавши"],
    "поджидавши": ["поджидав"],
    "поджидать": ["дожидаться", "ожидать"],
    "поджимав": ["поджимавши"],
    "поджимавши": ["поджимав"],
    "поджинав": ["поджинавши"],
    "поджинавши": ["поджинав"],
    "поджог": ["поджигание"],
    "поджопник": ["пендель", "пинок", "поджопетник", "подсрачник", "нагоняй", "сидушка", "попель", "пенка", "тачка"],
    "подзабив": ["подзабивши"],
    "подзабивши": ["подзабив"],
    "подзабить": ["забить"],
    "подзаболев": ["подзаболевши"],
    "подзаболевши": ["подзаболев"],
    "подзаболеть": ["прихворнуть"],
    "подзабросив": ["подзабросивши"],
    "подзабросивши": ["подзабросив"],
    "подзабросить": ["забросить"],
    "подзабухать": ["забухать"],
    "подзабыв": ["подзабывши"],
    "подзабывав": ["подзабывавши"],
    "подзабывавши": ["подзабывав"],
    "подзабывши": ["подзабыв"],
    "подзавалив": ["подзаваливши"],
    "подзаваливши": ["подзавалив"],
    "подзавив": ["подзавивши"],
    "подзавивав": ["подзавивавши"],
    "подзавивавши": ["подзавивав"],
    "подзавивши": ["подзавив"],
    "подзависнув": ["подзависнувши"],
    "подзависнувши": ["подзависнув"],
    "подзаводив": ["подзаводивши"],
    "подзаводивши": ["подзаводив"],
    "подзагнув": ["подзагнувши"],
    "подзагнувши": ["подзагнув"],
    "подзагорев": ["подзагоревши"],
    "подзагоревши": ["подзагорев"],
    "подзагустев": ["подзагустевши"],
    "подзагустевши": ["подзагустев"],
    "подзадев": ["подзадевши"],
    "подзадевши": ["подзадев"],
    "подзадержав": ["подзадержавши"],
    "подзадержавши": ["подзадержав"],
    "подзадолбав": ["подзадолбавши"],
    "подзадолбавши": ["подзадолбав"],
    "подзадорив": ["подзадоривши"],
    "подзадоривав": ["подзадоривавши"],
    "подзадоривавши": ["подзадоривав"],
    "подзадоривши": ["подзадорив"],
    "подзаебать": ["поднадоесть", "подзаебти"],
    "подзаебти": ["поднадоесть", "подзаебать"],
    "подзакалив": ["подзакаливши"],
    "подзакаливши": ["подзакалив"],
    "подзакрутив": ["подзакрутивши"],
    "подзакрутивши": ["подзакрутив"],
    "подзакусив": ["подзакусивши"],
    "подзакусивши": ["подзакусив"],
    "подзакусывав": ["подзакусывавши"],
    "подзакусывавши": ["подзакусывав"],
    "подзалетев": ["подзалетевши"],
    "подзалетевши": ["подзалетев"],
    "подзалупный сыр": ["подзалупный творог", "подзалупный творожок"],
    "подзаняв": ["подзанявши"],
    "подзанявши": ["подзаняв"],
    "подзаняться": ["заняться"],
    "подзапоздав": ["подзапоздавши"],
    "подзапоздавши": ["подзапоздав"],
    "подзаправив": ["подзаправивши"],
    "подзаправивши": ["подзаправив"],
    "подзаправляв": ["подзаправлявши"],
    "подзаправлявши": ["подзаправляв"],
    "подзапустив": ["подзапустивши"],
    "подзапустивши": ["подзапустив"],
    "подзарабатывав": ["подзарабатывавши"],
    "подзарабатывавши": ["подзарабатывав"],
    "подзаработав": ["подзаработавши"],
    "подзаработавши": ["подзаработав"],
    "подзарастав": ["подзараставши"],
    "подзараставши": ["подзарастав"],
    "подзарядив": ["подзарядивши"],
    "подзарядивши": ["подзарядив"],
    "подзарядка": ["подзаряд"],
    "подзаряжав": ["подзаряжавши"],
    "подзаряжавши": ["подзаряжав"],
    "подзатихнув": ["подзатихнувши"],
    "подзатихнувши": ["подзатихнув"],
    "подзатухнув": ["подзатухнувши"],
    "подзатухнувши": ["подзатухнув"],
    "подзатылочный": ["субокципитальный"],
    "подзатыльник": ["затрещина"],
    "подзатянув": ["подзатянувши"],
    "подзатянувши": ["подзатянув"],
    "подзахмелев": ["подзахмелевши"],
    "подзахмелевши": ["подзахмелев"],
    "подзашибив": ["подзашибивши"],
    "подзашибивши": ["подзашибив"],
    "подзашив": ["подзашивши"],
    "подзашивши": ["подзашив"],
    "подзванивав": ["подзванивавши"],
    "подзванивавши": ["подзванивав"],
    "подзвякивав": ["подзвякивавши"],
    "подзвякивавши": ["подзвякивав"],
    "подзвякнув": ["подзвякнувши"],
    "подзвякнувши": ["подзвякнув"],
    "подзеленив": ["подзеленивши"],
    "подзеленивши": ["подзеленив"],
    "подземелие": ["подземелье"],
    "подземелье": ["пещера", "подвал", "подземелие"],
    "подземельный": ["подземный"],
    "подземка": ["метрополитен", "метро"],
    "подземная вода": ["грунтовая вода"],
    "подземная лодка": ["подземоход", "геоход"],
    "подзол": ["белозём"],
    "подзолотив": ["подзолотивши"],
    "подзолотивши": ["подзолотив"],
    "подзорная труба": ["телескоп"],
    "подзубрив": ["подзубривши"],
    "подзубривав": ["подзубривавши"],
    "подзубривавши": ["подзубривав"],
    "подзубривши": ["подзубрив"],
    "подзудив": ["подзудивши"],
    "подзудивши": ["подзудив"],
    "подзуживав": ["подзуживавши"],
    "подзуживавши": ["подзуживав"],
    "подзуживание": ["поддразнивание", "подстрекание"],
    "подзуживатель": ["подстрекатель"],
    "подзуживать": ["поддразнивать", "подначивать", "подсевать"],
    "подзывав": ["подзывавши"],
    "подзывавши": ["подзывав"],
    "поди": ["небось", "попробуй", "попытайся", "посторонись"],
    "подиатр": ["подолог", "хиропод"],
    "подиатрия": ["хироподия", "подология"],
    "подивив": ["подививши"],
    "подививши": ["подивив"],
    "подивляти": ["дивуватися", "розглядати"],
    "подий": ["подиум", "возвышение"],
    "подиктовав": ["подиктовавши"],
    "подиктовавши": ["подиктовав"],
    "подина": ["под"],
    "подинамив": ["подинамивши"],
    "подинамивши": ["подинамив"],
    "подирав": ["подиравши"],
    "подиравши": ["подирав"],
    "подирижировав": ["подирижировавши"],
    "подирижировавши": ["подирижировав"],
    "подиробед": ["следобед"],
    "подискутировав": ["подискутировавши"],
    "подискутировавши": ["подискутировав"],
    "подитожив": ["подитоживши"],
    "подитоживав": ["подитоживавши"],
    "подитоживавши": ["подитоживав"],
    "подитоживши": ["подитожив"],
    "подичав": ["подичавши"],
    "подичавши": ["подичав"],
    "подкадив": ["подкадивши"],
    "подкадивши": ["подкадив"],
    "подкалив": ["подкаливши"],
    "подкаливав": ["подкаливавши"],
    "подкаливавши": ["подкаливав"],
    "подкаливши": ["подкалив"],
    "подкалывав": ["подкалывавши"],
    "подкалывавши": ["подкалывав"],
    "подкалымив": ["подкалымивши"],
    "подкалымивши": ["подкалымив"],
    "подкалымить": ["подхалтурить"],
    "подкапав": ["подкапавши"],
    "подкапавши": ["подкапав"],
    "подкапливав": ["подкапливавши"],
    "подкапливавши": ["подкапливав"],
    "подкапнув": ["подкапнувши"],
    "подкапнувши": ["подкапнув"],
    "подкапчивав": ["подкапчивавши"],
    "подкапчивавши": ["подкапчивав"],
    "подкапывав": ["подкапывавши"],
    "подкапывавши": ["подкапывав"],
    "подкараулив": ["подкарауливши"],
    "подкарауливав": ["подкарауливавши"],
    "подкарауливавши": ["подкарауливав"],
    "подкарауливши": ["подкараулив"],
    "подкараулить": ["подстеречь", "подсторожить"],
    "подкармливав": ["подкармливавши"],
    "подкармливавши": ["подкармливав"],
    "подкартавливав": ["подкартавливавши"],
    "подкартавливавши": ["подкартавливав"],
    "подкастинг": ["подкаст", "аудиоблог"],
    "подкатав": ["подкатавши"],
    "подкатавши": ["подкатав"],
    "подкаталог": ["подпапка", "поддиректория", "субдиректория"],
    "подкатив": ["подкативши"],
    "подкативши": ["подкатив"],
    "подкатывав": ["подкатывавши"],
    "подкатывавши": ["подкатывав"],
    "подкатывать шары": ["шары подкатывать"],
    "подкачав": ["подкачавши"],
    "подкачавши": ["подкачав"],
    "подкачивав": ["подкачивавши"],
    "подкачивавши": ["подкачивав"],
    "подкашивав": ["подкашивавши"],
    "подкашивавши": ["подкашивав"],
    "подкашливав": ["подкашливавши"],
    "подкашливавши": ["подкашливав"],
    "подкашлянув": ["подкашлянувши"],
    "подкашлянувши": ["подкашлянув"],
    "подквасив": ["подквасивши"],
    "подквасивши": ["подквасив"],
    "подквашивав": ["подквашивавши"],
    "подквашивавши": ["подквашивав"],
    "подкидав": ["подкидавши"],
    "подкидавши": ["подкидав"],
    "подкидывав": ["подкидывавши"],
    "подкидывавши": ["подкидывав"],
    "подкидыш": ["найдёныш"],
    "подкинув": ["подкинувши"],
    "подкинувши": ["подкинув"],
    "подкипев": ["подкипевши"],
    "подкипевши": ["подкипев"],
    "подкипятив": ["подкипятивши"],
    "подкипятивши": ["подкипятив"],
    "подкипячивав": ["подкипячивавши"],
    "подкипячивавши": ["подкипячивав"],
    "подкисав": ["подкисавши"],
    "подкисавши": ["подкисав"],
    "подкислив": ["подкисливши"],
    "подкисливши": ["подкислив"],
    "подкисляв": ["подкислявши"],
    "подкислявши": ["подкисляв"],
    "подкиснув": ["подкиснувши"],
    "подкиснувши": ["подкиснув"],
    "подклад": ["подкладка"],
    "подкладав": ["подкладавши"],
    "подкладавши": ["подкладав"],
    "подкладка": ["подклад"],
    "подкладывав": ["подкладывавши"],
    "подкладывавши": ["подкладывав"],
    "подклевав": ["подклевавши"],
    "подклевавши": ["подклевав"],
    "подклеив": ["подклеивши"],
    "подклеивав": ["подклеивавши"],
    "подклеивавши": ["подклеивав"],
    "подклеивши": ["подклеив"],
    "подклепав": ["подклепавши"],
    "подклепавши": ["подклепав"],
    "подклет": ["подклеть"],
    "подклеть": ["подызбица"],
    "подкликав": ["подкликавши"],
    "подкликавши": ["подкликав"],
    "подкликивав": ["подкликивавши"],
    "подкликивавши": ["подкликивав"],
    "подкликнув": ["подкликнувши"],
    "подкликнувши": ["подкликнув"],
    "подклинив": ["подклинивши"],
    "подклинивав": ["подклинивавши"],
    "подклинивавши": ["подклинивав"],
    "подклинивши": ["подклинив"],
    "подклонив": ["подклонивши"],
    "подклонивши": ["подклонив"],
    "подклоняв": ["подклонявши"],
    "подклонявши": ["подклоняв"],
    "подключав": ["подключавши"],
    "подключавши": ["подключав"],
    "подключив": ["подключивши"],
    "подключивши": ["подключив"],
    "подключить": ["присоединить", "привлечь"],
    "подклёвывав": ["подклёвывавши"],
    "подклёвывавши": ["подклёвывав"],
    "подклёпывав": ["подклёпывавши"],
    "подклёпывавши": ["подклёпывав"],
    "подкова": ["гиппосандалия", "дуга", "кольцо"],
    "подковав": ["подковавши"],
    "подковавши": ["подковав"],
    "подковровый": ["подковёрный"],
    "подковывав": ["подковывавши"],
    "подковывавши": ["подковывав"],
    "подковыливав": ["подковыливавши"],
    "подковыливавши": ["подковыливав"],
    "подковыляв": ["подковылявши"],
    "подковылявши": ["подковыляв"],
    "подковыривав": ["подковыривавши"],
    "подковыривавши": ["подковыривав"],
    "подковырнув": ["подковырнувши"],
    "подковырнувши": ["подковырнув"],
    "подковыряв": ["подковырявши"],
    "подковырявши": ["подковыряв"],
    "подковёрный": ["негласный", "закулисный"],
    "подкозлив": ["подкозливши"],
    "подкозливши": ["подкозлив"],
    "подкол": ["подкалывание", "подколка", "шпилька"],
    "подколачивав": ["подколачивавши"],
    "подколачивавши": ["подколачивав"],
    "подколов": ["подколовши"],
    "подколовши": ["подколов"],
    "подколотив": ["подколотивши"],
    "подколотивши": ["подколотив"],
    "подколупнув": ["подколупнувши"],
    "подколупнувши": ["подколупнув"],
    "подколупывав": ["подколупывавши"],
    "подколупывавши": ["подколупывав"],
    "подконопатив": ["подконопативши"],
    "подконопативши": ["подконопатив"],
    "подкопав": ["подкопавши"],
    "подкопавши": ["подкопав"],
    "подкопив": ["подкопивши"],
    "подкопивши": ["подкопив"],
    "подкопнув": ["подкопнувши"],
    "подкопнувши": ["подкопнув"],
    "подкоптив": ["подкоптивши"],
    "подкоптивши": ["подкоптив"],
    "подкорачивав": ["подкорачивавши"],
    "подкорачивавши": ["подкорачивав"],
    "подкормив": ["подкормивши"],
    "подкормивши": ["подкормив"],
    "подкормка": ["подкорм"],
    "подкорнав": ["подкорнавши"],
    "подкорнавши": ["подкорнав"],
    "подкорный": ["подкорковый"],
    "подкоротив": ["подкоротивши"],
    "подкоротивши": ["подкоротив"],
    "подкорректировав": ["подкорректировавши"],
    "подкорректировавши": ["подкорректировав"],
    "подкорчив": ["подкорчивши"],
    "подкорчивши": ["подкорчив"],
    "подкорье": ["заболонь", "мезга"],
    "подкорючив": ["подкорючивши"],
    "подкорючивши": ["подкорючив"],
    "подкос": ["подкашивание", "раскос", "укосина"],
    "подкосив": ["подкосивши"],
    "подкосивши": ["подкосив"],
    "подкочевав": ["подкочевавши"],
    "подкочевавши": ["подкочевав"],
    "подкочёвывав": ["подкочёвывавши"],
    "подкочёвывавши": ["подкочёвывав"],
    "подкраивав": ["подкраивавши"],
    "подкраивавши": ["подкраивав"],
    "подкрасив": ["подкрасивши"],
    "подкрасивши": ["подкрасив"],
    "подкрахмалив": ["подкрахмаливши"],
    "подкрахмаливав": ["подкрахмаливавши"],
    "подкрахмаливавши": ["подкрахмаливав"],
    "подкрахмаливши": ["подкрахмалив"],
    "подкрашивав": ["подкрашивавши"],
    "подкрашивавши": ["подкрашивав"],
    "подкрашивать": ["подмазать", "подмалевать"],
    "подкрепа": ["поддръжка", "съдействие", "помощ"],
    "подкрепив": ["подкрепивши"],
    "подкрепивши": ["подкрепив"],
    "подкрепиться": ["пообедать"],
    "подкрепленье": ["подкрепление"],
    "подкрепляв": ["подкреплявши"],
    "подкреплявши": ["подкрепляв"],
    "подкрикивав": ["подкрикивавши"],
    "подкрикивавши": ["подкрикивав"],
    "подкрикнув": ["подкрикнувши"],
    "подкрикнувши": ["подкрикнув"],
    "подкроив": ["подкроивши"],
    "подкроивши": ["подкроив"],
    "подкрошив": ["подкрошивши"],
    "подкрошивши": ["подкрошив"],
    "подкруглив": ["подкругливши"],
    "подкругливши": ["подкруглив"],
    "подкругляв": ["подкруглявши"],
    "подкруглявши": ["подкругляв"],
    "подкрутив": ["подкрутивши"],
    "подкрутивши": ["подкрутив"],
    "подкрутить": ["подвернуть"],
    "подкручивав": ["подкручивавши"],
    "подкручивавши": ["подкручивав"],
    "подкрыльевой": ["подкрыльный"],
    "подкрыльцовый": ["подкрыльцевый"],
    "подкрякивав": ["подкрякивавши"],
    "подкрякивавши": ["подкрякивав"],
    "подкрякнув": ["подкрякнувши"],
    "подкрякнувши": ["подкрякнув"],
    "подкузьмив": ["подкузьмивши"],
    "подкузьмивши": ["подкузьмив"],
    "подкузьмить": ["подъелдыкнуть", "подъебнуть"],
    "подкупав": ["подкупавши"],
    "подкупавши": ["подкупав"],
    "подкупание": ["подкуп"],
    "подкупать": ["давать взятку", "коррумпировать", "давать на лапу", "привлекать", "докупать", "прикупать"],
    "подкупив": ["подкупивши"],
    "подкупивши": ["подкупив"],
    "подкупить": ["дать взятку", "коррумпировать", "дать на лапу", "привлечь", "докупить", "прикупить"],
    "подкуражив": ["подкураживши"],
    "подкураживав": ["подкураживавши"],
    "подкураживавши": ["подкураживав"],
    "подкураживши": ["подкуражив"],
    "подкурив": ["подкуривши"],
    "подкуривав": ["подкуривавши"],
    "подкуривавши": ["подкуривав"],
    "подкуривши": ["подкурив"],
    "подкусив": ["подкусивши"],
    "подкусивши": ["подкусив"],
    "подкусывав": ["подкусывавши"],
    "подкусывавши": ["подкусывав"],
    "подкутив": ["подкутивши"],
    "подкутивши": ["подкутив"],
    "подкушав": ["подкушавши"],
    "подкушавши": ["подкушав"],
    "подкушивав": ["подкушивавши"],
    "подкушивавши": ["подкушивав"],
    "подлавливав": ["подлавливавши"],
    "подлавливавши": ["подлавливав"],
    "подлагивав": ["подлагивавши"],
    "подлагивавши": ["подлагивав"],
    "подлагивать": ["лагать", "запаздывать", "подтормаживать", "тормозить"],
    "подладив": ["подладивши"],
    "подладивши": ["подладив"],
    "подлаживав": ["подлаживавши"],
    "подлаживавши": ["подлаживав"],
    "подлаживанье": ["подлаживание"],
    "подлазив": ["подлазивши"],
    "подлазивши": ["подлазив"],
    "подлаивав": ["подлаивавши"],
    "подлаивавши": ["подлаивав"],
    "подлаивать": ["вторить", "лаять", "задерживать"],
    "подлакировав": ["подлакировавши"],
    "подлакировавши": ["подлакировав"],
    "подлакировать": ["залакировать", "пригладить", "сгладить углы", "догнать"],
    "подлакировывав": ["подлакировывавши"],
    "подлакировывавши": ["подлакировывав"],
    "подламывав": ["подламывавши"],
    "подламывавши": ["подламывав"],
    "подластиться": ["подмазаться"],
    "подлатав": ["подлатавши"],
    "подлатавши": ["подлатав"],
    "подлатывав": ["подлатывавши"],
    "подлатывавши": ["подлатывав"],
    "подлащиваться": ["подлизываться", "подмасливаться"],
    "подлаяв": ["подлаявши"],
    "подлаявши": ["подлаяв"],
    "подле": ["возле", "близ", "около", "рядом", "близко", "при", "недалеко", "вблизи"],
    "подлев": ["подлевши"],
    "подлевши": ["подлев"],
    "подлегав": ["подлегавши"],
    "подлегавши": ["подлегав"],
    "подледенев": ["подледеневши"],
    "подледеневши": ["подледенев"],
    "подлежав": ["подлежавши"],
    "подлежавши": ["подлежав"],
    "подлежащее": ["субъект"],
    "подлезав": ["подлезавши"],
    "подлезавши": ["подлезав"],
    "подленький": ["подловатенький"],
    "подлепив": ["подлепивши"],
    "подлепивши": ["подлепив"],
    "подлепляв": ["подлеплявши"],
    "подлеплявши": ["подлепляв"],
    "подлесье": ["опушка", "подлесок"],
    "подлетав": ["подлетавши"],
    "подлетавши": ["подлетав"],
    "подлетев": ["подлетевши"],
    "подлетевши": ["подлетев"],
    "подлететь": ["прилететь", "взлететь", "подбежать", "подоспеть", "подскочить", "подпрыгнуть"],
    "подлетнув": ["подлетнувши"],
    "подлетнувши": ["подлетнув"],
    "подлеток": ["подросток", "отрок", "отроковица", "юнец", "мальчик", "девочка", "паренёк"],
    "подлец": ["мерзавец", "подонок", "отморозок", "негодяй"],
    "подлечив": ["подлечивши"],
    "подлечивав": ["подлечивавши"],
    "подлечивавши": ["подлечивав"],
    "подлечивши": ["подлечив"],
    "подлечиться": ["поправиться"],
    "подлещаться": ["подольщаться"],
    "подлещик": ["подлещ"],
    "подлив": ["подливание", "подливка"],
    "подлива": ["подливка"],
    "подливав": ["подливавши"],
    "подливавши": ["подливав"],
    "подливка": ["подливание", "соус"],
    "подливши": ["подлив"],
    "подлиза": ["подхалим", "лизоблюд"],
    "подлизав": ["подлизавши"],
    "подлизавши": ["подлизав"],
    "подлизывав": ["подлизывавши"],
    "подлизывавши": ["подлизывав"],
    "подлизыванье": ["подлизывание"],
    "подлизываться": ["подольщаться", "льстить"],
    "подлиннев": ["подлинневши"],
    "подлинневши": ["подлиннев"],
    "подлинник": ["оригинал"],
    "подлинность": ["аутентичность"],
    "подлинный": ["оригинальный", "аутентичный", "настоящий", "неподдельный", "действительный", "точный", "неизменённый", "неискажённый", "образцовый", "искренний"],
    "подлиняв": ["подлинявши"],
    "подлинявши": ["подлиняв"],
    "подлипав": ["подлипавши"],
    "подлипавши": ["подлипав"],
    "подлипнув": ["подлипнувши"],
    "подлипнувши": ["подлипнув"],
    "подлить масла в огонь": ["подлить бензина в огонь"],
    "подличав": ["подличавши"],
    "подличавши": ["подличав"],
    "подло": ["бесчестно", "низко", "презренно"],
    "подловатенький": ["подленький"],
    "подловив": ["подловивши"],
    "подловивши": ["подловив"],
    "подловка": ["чердак"],
    "подлодка": ["субмарина", "подводная лодка", "подлодочка"],
    "подложив": ["подложивши"],
    "подложивши": ["подложив"],
    "подложить свинью": ["напакостить"],
    "подломав": ["подломавши"],
    "подломавши": ["подломав"],
    "подломив": ["подломивши"],
    "подломивши": ["подломив"],
    "подломиться": ["надломиться"],
    "подлунный": ["земной"],
    "подлупив": ["подлупивши"],
    "подлупивши": ["подлупив"],
    "подлупливав": ["подлупливавши"],
    "подлупливавши": ["подлупливав"],
    "подлущив": ["подлущивши"],
    "подлущивав": ["подлущивавши"],
    "подлущивавши": ["подлущивав"],
    "подлущивши": ["подлущив"],
    "подлый": ["низкий", "бесчестный", "плебейский", "неродовитый"],
    "подлюбливав": ["подлюбливавши"],
    "подлюбливавши": ["подлюбливав"],
    "подлюга": ["подлец", "мерзавец"],
    "подляна": ["пакость", "падло", "ловушка", "неприятность", "удар"],
    "подлянка": ["подлость"],
    "подлёт": ["подлетание"],
    "подлётывав": ["подлётывавши"],
    "подлётывавши": ["подлётывав"],
    "подмазав": ["подмазавши"],
    "подмазавши": ["подмазав"],
    "подмазать": ["дать взятку"],
    "подмазаться": ["подкраситься", "подластиться"],
    "подмазывав": ["подмазывавши"],
    "подмазывавши": ["подмазывав"],
    "подмалевав": ["подмалевавши"],
    "подмалевавши": ["подмалевав"],
    "подмалывав": ["подмалывавши"],
    "подмалывавши": ["подмалывав"],
    "подмалёвок": ["подмалёвка"],
    "подмалёвывав": ["подмалёвывавши"],
    "подмалёвывавши": ["подмалёвывав"],
    "подмамка": ["примамка"],
    "подманив": ["подманивши"],
    "подманивав": ["подманивавши"],
    "подманивавши": ["подманивав"],
    "подманивать": ["заманивать", "обольщать"],
    "подманивши": ["подманив"],
    "подмарав": ["подмаравши"],
    "подмаравши": ["подмарав"],
    "подмаргивав": ["подмаргивавши"],
    "подмаргивавши": ["подмаргивав"],
    "подмаривав": ["подмаривавши"],
    "подмаривавши": ["подмаривав"],
    "подмарывав": ["подмарывавши"],
    "подмарывавши": ["подмарывав"],
    "подмаскировав": ["подмаскировавши"],
    "подмаскировавши": ["подмаскировав"],
    "подмаслив": ["подмасливши"],
    "подмасливав": ["подмасливавши"],
    "подмасливавши": ["подмасливав"],
    "подмасливши": ["подмаслив"],
    "подмастерье": ["ученик", "помощник"],
    "подмастив": ["подмастивши"],
    "подмастивши": ["подмастив"],
    "подмастить": ["угодить", "потрафить", "повезти", "посчастливиться"],
    "подматывав": ["подматывавши"],
    "подматывавши": ["подматывав"],
    "подмахивав": ["подмахивавши"],
    "подмахивавши": ["подмахивав"],
    "подмахнув": ["подмахнувши"],
    "подмахнувши": ["подмахнув"],
    "подмачивав": ["подмачивавши"],
    "подмачивавши": ["подмачивав"],
    "подмащивав": ["подмащивавши"],
    "подмащивавши": ["подмащивав"],
    "подмелив": ["подмеливши"],
    "подмеливши": ["подмелив"],
    "подменив": ["подменивши"],
    "подменивав": ["подменивавши"],
    "подменивавши": ["подменивав"],
    "подменивши": ["подменив"],
    "подменыш": ["обменыш"],
    "подменяв": ["подменявши"],
    "подменявши": ["подменяв"],
    "подмерзав": ["подмерзавши"],
    "подмерзавши": ["подмерзав"],
    "подмес": ["подмешивание", "примесь"],
    "подмесив": ["подмесивши"],
    "подмесивши": ["подмесив"],
    "подмести": ["подчистить", "выгрести", "подмахнуть"],
    "подмесь": ["подмешивание", "примесь", "подмес", "примес"],
    "подметав": ["подметавши"],
    "подметавши": ["подметав"],
    "подметальщик": ["метельщик", "подметала", "дворник"],
    "подметив": ["подметивши"],
    "подметивши": ["подметив"],
    "подметнув": ["подметнувши"],
    "подметнувши": ["подметнув"],
    "подмечав": ["подмечавши"],
    "подмечавши": ["подмечав"],
    "подмечая": ["замечая", "обнаруживая"],
    "подмешав": ["подмешавши"],
    "подмешавши": ["подмешав"],
    "подмешивав": ["подмешивавши"],
    "подмешивавши": ["подмешивав"],
    "подмешивать": ["примешивать"],
    "подмигивав": ["подмигивавши"],
    "подмигивавши": ["подмигивав"],
    "подмигивание": ["подмаргивание", "намёк", "мигание"],
    "подмигиванье": ["подмигивание"],
    "подмигнув": ["подмигнувши"],
    "подмигнувши": ["подмигнув"],
    "подминав": ["подминавши"],
    "подминавши": ["подминав"],
    "подминать": ["придавливать", "подчинять"],
    "подмога": ["помощь"],
    "подмогав": ["подмогавши"],
    "подмогавши": ["подмогав"],
    "подмогнув": ["подмогнувши"],
    "подмогнувши": ["подмогнув"],
    "подмодуль": ["субмодуль"],
    "подмокав": ["подмокавши"],
    "подмокавши": ["подмокав"],
    "подмоклый": ["подмокший"],
    "подмокнув": ["подмокнувши"],
    "подмокнувши": ["подмокнув"],
    "подмолаживав": ["подмолаживавши"],
    "подмолаживавши": ["подмолаживав"],
    "подмолов": ["подмоловши"],
    "подмоловши": ["подмолов"],
    "подмолодив": ["подмолодивши"],
    "подмолодивши": ["подмолодив"],
    "подмонтировав": ["подмонтировавши"],
    "подмонтировавши": ["подмонтировав"],
    "подмораживав": ["подмораживавши"],
    "подмораживавши": ["подмораживав"],
    "подморгнув": ["подморгнувши"],
    "подморгнувши": ["подморгнув"],
    "подморгнуть": ["подмигнуть"],
    "подморив": ["подморивши"],
    "подморивши": ["подморив"],
    "подморозив": ["подморозивши"],
    "подморозивши": ["подморозив"],
    "подмосковье": ["московская область"],
    "подмостив": ["подмостивши"],
    "подмостивши": ["подмостив"],
    "подмостившись": ["подмостясь"],
    "подмостки": ["возвышение", "сцена"],
    "подмосток": ["подмостик", "подмостки"],
    "подмостясь": ["подмостившись"],
    "подмотав": ["подмотавши"],
    "подмотавши": ["подмотав"],
    "подмочив": ["подмочивши"],
    "подмочивши": ["подмочив"],
    "подмурлыкивав": ["подмурлыкивавши"],
    "подмурлыкивавши": ["подмурлыкивав"],
    "подмурманский": ["примурманский"],
    "подмуровав": ["подмуровавши"],
    "подмуровавши": ["подмуровав"],
    "подмуровывав": ["подмуровывавши"],
    "подмуровывавши": ["подмуровывав"],
    "подмывав": ["подмывавши"],
    "подмывавши": ["подмывав"],
    "подмывать": ["хотеться", "тянуть", "не терпеться"],
    "подмывши": ["подмыв"],
    "подмылив": ["подмыливши"],
    "подмыливав": ["подмыливавши"],
    "подмыливавши": ["подмыливав"],
    "подмыливши": ["подмылив"],
    "подмылиться": ["подлизаться", "подмазаться"],
    "подмыха": ["подмышка"],
    "подмышечный": ["аксиллярный"],
    "подмышка": ["подмыха"],
    "подмяв": ["подмявши"],
    "подмявши": ["подмяв"],
    "подмякав": ["подмякавши"],
    "подмякавши": ["подмякав"],
    "подмякнув": ["подмякнувши"],
    "подмякнувши": ["подмякнув"],
    "подмёрзнув": ["подмёрзнувши"],
    "подмёрзнувши": ["подмёрзнув"],
    "подмётка": ["подошва"],
    "подмётывав": ["подмётывавши"],
    "подмётывавши": ["подмётывав"],
    "поднабирав": ["поднабиравши"],
    "поднабиравши": ["поднабирав"],
    "поднабрав": ["поднабравши"],
    "поднабравши": ["поднабрав"],
    "поднавалив": ["поднаваливши"],
    "поднаваливши": ["поднавалив"],
    "поднавес": ["навес"],
    "поднаврав": ["поднавравши"],
    "поднавравши": ["поднаврав"],
    "поднагрузив": ["поднагрузивши"],
    "поднагрузивши": ["поднагрузив"],
    "поднадев": ["поднадевши"],
    "поднадевши": ["поднадев"],
    "поднадоедав": ["поднадоедавши"],
    "поднадоедавши": ["поднадоедав"],
    "поднадорвав": ["поднадорвавши"],
    "поднадорвавши": ["поднадорвав"],
    "поднадув": ["поднадувши"],
    "поднадував": ["поднадувавши"],
    "поднадувавши": ["поднадував"],
    "поднадувши": ["поднадув"],
    "поднажав": ["поднажавши"],
    "поднажавши": ["поднажав"],
    "поднажимав": ["поднажимавши"],
    "поднажимавши": ["поднажимав"],
    "поднажраться": ["поднабраться", "напиться"],
    "подназначив": ["подназначивши"],
    "подназначивши": ["подназначив"],
    "поднакапливав": ["поднакапливавши"],
    "поднакапливавши": ["поднакапливав"],
    "поднакопив": ["поднакопивши"],
    "поднакопивши": ["поднакопив"],
    "поднакопить": ["подкопить"],
    "поднакурив": ["поднакуривши"],
    "поднакуривши": ["поднакурив"],
    "подналадив": ["подналадивши"],
    "подналадивши": ["подналадив"],
    "подналаживав": ["подналаживавши"],
    "подналаживавши": ["подналаживав"],
    "подналегав": ["подналегавши"],
    "подналегавши": ["подналегав"],
    "поднанимав": ["поднанимавши"],
    "поднанимавши": ["поднанимав"],
    "поднаняв": ["поднанявши"],
    "поднанявши": ["поднаняв"],
    "поднаперев": ["поднапёрши"],
    "поднапирав": ["поднапиравши"],
    "поднапиравши": ["поднапирав"],
    "поднапрягав": ["поднапрягавши"],
    "поднапрягавши": ["поднапрягав"],
    "поднапутав": ["поднапутавши"],
    "поднапутавши": ["поднапутав"],
    "поднапёрши": ["поднаперев"],
    "поднасрав": ["поднасравши"],
    "поднасравши": ["поднасрав"],
    "поднасыпав": ["поднасыпавши"],
    "поднасыпавши": ["поднасыпав"],
    "поднатаскав": ["поднатаскавши"],
    "поднатаскавши": ["поднатаскав"],
    "поднатаскивав": ["поднатаскивавши"],
    "поднатаскивавши": ["поднатаскивав"],
    "поднаторев": ["поднаторевши"],
    "поднаторевши": ["поднаторев"],
    "поднатореть": ["поднатаскать", "натореть", "наловчиться"],
    "поднатужив": ["поднатуживши"],
    "поднатуживав": ["поднатуживавши"],
    "поднатуживавши": ["поднатуживав"],
    "поднатуживши": ["поднатужив"],
    "поднатянув": ["поднатянувши"],
    "поднатянувши": ["поднатянув"],
    "подначальственный": ["подчинённый"],
    "подначив": ["подначивши"],
    "подначивав": ["подначивавши"],
    "подначивавши": ["подначивав"],
    "подначивание": ["поддразнивание", "подзадоривание"],
    "подначивать": ["поддразнивать", "подзадоривать", "подбивать"],
    "подначивши": ["подначив"],
    "подначить": ["подзадорить"],
    "подначка": ["поддразнивание", "подначивание", "подзуживание", "подстрекательство"],
    "поднашивав": ["поднашивавши"],
    "поднашивавши": ["поднашивав"],
    "поднебесная": ["китай", "поднебесная империя"],
    "поднебесье": ["небо", "небеса", "небосвод", "небосклон"],
    "подневалив": ["подневаливши"],
    "подневаливши": ["подневалив"],
    "подневольный": ["зависимый", "подчинённый", "рабский"],
    "поднепровский": ["приднепровский"],
    "поднесенье": ["поднесение"],
    "поднесь": ["поныне", "доныне", "доселе", "досель", "доднесь", "посейчас"],
    "поднизав": ["поднизавши"],
    "поднизавши": ["поднизав"],
    "поднизывав": ["поднизывавши"],
    "поднизывавши": ["поднизывав"],
    "поднимав": ["поднимавши"],
    "поднимавши": ["поднимав"],
    "поднимать": ["повышать"],
    "подниматься": ["подыматься", "расти", "увеличиваться", "выситься", "нависать", "виднеться", "вздыматься"],
    "подновив": ["подновивши"],
    "подновивши": ["подновив"],
    "подновление": ["обновление"],
    "подновляв": ["подновлявши"],
    "подновлявши": ["подновляв"],
    "подноготная": ["подробности", "тонкости", "тайна", "подоплёка", "секрет"],
    "подноготный": ["подногтевой", "тайный", "скрытый", "секретный", "искренний", "внимательный", "тщательный", "дотошный"],
    "подножие": ["пьедестал", "подставка", "подножка"],
    "подножный": ["подгорный", "подножный корм"],
    "поднос": ["разнос"],
    "подносив": ["подносивши"],
    "подносивши": ["подносив"],
    "подноска": ["поднос", "поднесение"],
    "подношение": ["поднос", "подарок"],
    "поднывав": ["поднывавши"],
    "поднывавши": ["поднывав"],
    "подныривав": ["подныривавши"],
    "подныривавши": ["подныривав"],
    "поднырнув": ["поднырнувши"],
    "поднырнувши": ["поднырнув"],
    "подняв": ["поднявши"],
    "поднявши": ["подняв"],
    "подняня": ["поднянька"],
    "поднятие": ["подъём"],
    "поднять": ["возвысить", "повысить", "подобрать"],
    "поднять меч": ["обнажить меч"],
    "поднять на зубки": ["поднять на зубок", "поднять на смех"],
    "поднять на зубок": ["поднять на зубки", "поднять на смех"],
    "поднятье": ["поднятие"],
    "подняться": ["возвыситься", "повыситься", "вырасти", "встать", "восстать", "увеличиться", "наладиться", "улучшиться", "подойти", "начаться", "возникнуть", "появиться"],
    "подо": ["ниже", "снизу"],
    "подобав": ["подобавши"],
    "подобавши": ["подобав"],
    "подобать": ["приличествовать", "соответствовать", "надлежать", "следовать"],
    "подобающий": ["надлежащий", "должный"],
    "подобив": ["подобивши"],
    "подобивши": ["подобив"],
    "подобие": ["аналог", "копия", "двойник", "похожесть", "сходство", "подобность"],
    "подобно": ["однородно", "похоже", "схоже"],
    "подобный": ["похожий", "сходный", "схожий", "сопоставимый"],
    "подоборзев": ["подоборзевши"],
    "подоборзевши": ["подоборзев"],
    "подобострастие": ["угодливость", "раболепие"],
    "подобострастничав": ["подобострастничавши"],
    "подобострастничавши": ["подобострастничав"],
    "подобострастно": ["раболепно"],
    "подобострастный": ["раболепный", "угодливый"],
    "подобострастье": ["подобострастие"],
    "подобрав": ["подобравши"],
    "подобравши": ["подобрав"],
    "подобранец": ["подобрыш"],
    "подобрать": ["поднять", "подтянуть", "выбрать", "избрать", "отобрать"],
    "подобрев": ["подобревши"],
    "подобревши": ["подобрев"],
    "подобреть": ["смягчиться", "пополнеть", "раздобреть", "потолстеть", "раздаться", "набрать вес"],
    "подобрыш": ["подобранец"],
    "подобье": ["подобие"],
    "подоврав": ["подовравши"],
    "подовравши": ["подоврав"],
    "подог": ["подожок", "дубинка", "палка", "трость"],
    "подогнав": ["подогнавши"],
    "подогнавши": ["подогнав"],
    "подогнув": ["подогнувши"],
    "подогнувши": ["подогнув"],
    "подогнутый": ["загнутый"],
    "подогрев": ["подогревание"],
    "подогревав": ["подогревавши"],
    "подогревавши": ["подогревав"],
    "подогревание": ["подогрев"],
    "подогреватель": ["обогреватель", "калоризатор", "экономайзер", "нагреватель", "решофер"],
    "подогревать": ["разогревать", "возбуждать", "заводить", "раззадоривать", "распалять"],
    "подогревши": ["подогрев"],
    "подогреть": ["нагреть", "греть", "разогреть", "согреть", "обогреть"],
    "подогреться": ["разогреться", "нагреться", "согреться", "усилиться", "обостриться", "разгорячиться"],
    "пододвигав": ["пододвигавши"],
    "пододвигавши": ["пододвигав"],
    "пододвигать": ["придвигать"],
    "пододвигаться": ["придвигаться"],
    "пододвинув": ["пододвинувши"],
    "пододвинувши": ["пододвинув"],
    "пододвинуть": ["придвинуть"],
    "пододвинуться": ["придвинуться"],
    "пододев": ["пододевши"],
    "пододевав": ["пододевавши"],
    "пододевавши": ["пододевав"],
    "пододевши": ["пододев"],
    "пододелав": ["пододелавши"],
    "пододелавши": ["пододелав"],
    "пододеть": ["поднадеть"],
    "пододрав": ["пододравши"],
    "пододравши": ["пододрав"],
    "подождав": ["подождавши"],
    "подождавши": ["подождав"],
    "подождать": ["повременить", "погодить"],
    "подожди": ["постой"],
    "подозвав": ["подозвавши"],
    "подозвавши": ["подозвав"],
    "подозрев": ["подозревши"],
    "подозревав": ["подозревавши"],
    "подозревавши": ["подозревав"],
    "подозревание": ["подозреванье"],
    "подозревать": ["предполагать", "допускать", "догадываться", "думать", "считать", "казаться"],
    "подозревши": ["подозрев"],
    "подозренье": ["подозрение"],
    "подозрительность": ["недоверчивость", "сомнительность"],
    "подозрительный": ["ненадёжный", "сомнительный", "недоверчивый", "скептический"],
    "подоив": ["подоивши"],
    "подоивши": ["подоив"],
    "подойдя": ["подошед", "подошедши"],
    "подойник": ["дойник"],
    "подойница": ["подойник", "доёнка", "доильник", "доярка"],
    "подойти": ["приблизиться", "наступить", "найти подход", "пригодиться"],
    "подоконница": ["подоконник"],
    "подоконье": ["подоконник"],
    "подол": ["пола"],
    "подолбив": ["подолбивши"],
    "подолбивши": ["подолбив"],
    "подолгу": ["долго"],
    "подолепливав": ["подолепливавши"],
    "подолепливавши": ["подолепливав"],
    "подомовничав": ["подомовничавши"],
    "подомовничавши": ["подомовничав"],
    "подонок": ["подлец", "мерзавец", "негодяй", "гад", "ублюдок", "тварь", "мразь", "выродок", "поганец", "паршивец", "стервец", "подлюка", "скотина", "гнида", "паскуда"],
    "подоплёка": ["подкладка"],
    "подопрев": ["подопревши"],
    "подопревав": ["подопревавши"],
    "подопревавши": ["подопревав"],
    "подопревать": ["подпревать"],
    "подопревши": ["подопрев"],
    "подорвав": ["подорвавши"],
    "подорвавши": ["подорвав"],
    "подорваться": ["начать", "хотеть"],
    "подорлик": ["крикун"],
    "подорожав": ["подорожавши"],
    "подорожавши": ["подорожав"],
    "подорожать": ["вздорожать"],
    "подороже": ["дороже"],
    "подорожив": ["подороживши"],
    "подороживши": ["подорожив"],
    "подорожная": ["свидетельство"],
    "подосадовав": ["подосадовавши"],
    "подосадовавши": ["подосадовав"],
    "подосинник": ["подосиновик", "осиновик", "красноголовик", "красноголовец", "красный гриб"],
    "подосиновик": ["подосинник", "осиновик", "красноголовик", "красноголовец", "красный гриб"],
    "подоскоп": ["подоскан", "плантоскоп", "плантоскан", "плантовизор"],
    "подослав": ["подославши"],
    "подославши": ["подослав"],
    "подоспев": ["подоспевши"],
    "подоспевав": ["подоспевавши"],
    "подоспевавши": ["подоспевав"],
    "подоспевши": ["подоспев"],
    "подосрав": ["подосравши"],
    "подосравши": ["подосрав"],
    "подоставав": ["подостававши"],
    "подостававши": ["подоставав"],
    "подоставать": ["поднадоесть", "притомить"],
    "подостлав": ["подостлавши"],
    "подостлавши": ["подостлав"],
    "подострив": ["подостривши"],
    "подостривши": ["подострив"],
    "подостряв": ["подострявши"],
    "подострявши": ["подостряв"],
    "подостыв": ["подостывши"],
    "подостывши": ["подостыв"],
    "подостыть": ["поостыть"],
    "подоткав": ["подоткавши"],
    "подоткавши": ["подоткав"],
    "подоткнув": ["подоткнувши"],
    "подоткнувши": ["подоткнув"],
    "подотстав": ["подотставши"],
    "подотставши": ["подотстав"],
    "подотчётность": ["подчинённость"],
    "подохнув": ["подохнувши"],
    "подохнувши": ["подохнув"],
    "подохуев": ["подохуевши"],
    "подохуевши": ["подохуев"],
    "подохуеть": ["оборзеть"],
    "подошед": ["подойдя", "подошедши"],
    "подошедши": ["подойдя", "подошед"],
    "подпадав": ["подпадавши"],
    "подпадавши": ["подпадав"],
    "подпадать": ["подчиняться"],
    "подпаивав": ["подпаивавши"],
    "подпаивавши": ["подпаивав"],
    "подпаивать": ["напаивать"],
    "подпакостив": ["подпакостивши"],
    "подпакостивши": ["подпакостив"],
    "подпалзывав": ["подпалзывавши"],
    "подпалзывавши": ["подпалзывав"],
    "подпалив": ["подпаливши"],
    "подпаливав": ["подпаливавши"],
    "подпаливавши": ["подпаливав"],
    "подпаливши": ["подпалив"],
    "подпалина": ["подпал"],
    "подпалить": ["опалить", "поджечь"],
    "подпапка": ["подкаталог", "субдиректория"],
    "подпарадигма": ["полупарадигма", "субпарадигма"],
    "подпарывав": ["подпарывавши"],
    "подпарывавши": ["подпарывав"],
    "подпахав": ["подпахавши"],
    "подпахавши": ["подпахав"],
    "подпахивав": ["подпахивавши"],
    "подпахивавши": ["подпахивав"],
    "подпаяв": ["подпаявши"],
    "подпаявши": ["подпаяв"],
    "подпев": ["подпевши"],
    "подпевав": ["подпевавши"],
    "подпевавши": ["подпевав"],
    "подпевала": ["подголосок", "подпевальщик", "подпевало"],
    "подпеватель": ["подголосок", "подпевала"],
    "подпевка": ["бэк-вокал"],
    "подпевши": ["подпев"],
    "подпекав": ["подпекавши"],
    "подпекавши": ["подпекав"],
    "подперев": ["подпёрши"],
    "подпериод": ["субпериод"],
    "подпечатав": ["подпечатавши"],
    "подпечатавши": ["подпечатав"],
    "подпечатывав": ["подпечатывавши"],
    "подпечатывавши": ["подпечатывав"],
    "подпив": ["подпивши"],
    "подпивав": ["подпивавши"],
    "подпивавши": ["подпивав"],
    "подпивши": ["подпив"],
    "подпизживав": ["подпизживавши"],
    "подпизживавши": ["подпизживав"],
    "подпилив": ["подпиливши"],
    "подпиливав": ["подпиливавши"],
    "подпиливавши": ["подпиливав"],
    "подпиливши": ["подпилив"],
    "подпирав": ["подпиравши"],
    "подпиравши": ["подпирав"],
    "подпирать": ["поддерживать", "наваливаться"],
    "подписав": ["подписавши"],
    "подписавши": ["подписав"],
    "подписать": ["поставить подпись", "расписаться", "скрепить подписью", "приписать", "дописать", "подписчик", "абонент"],
    "подписота": ["подписчик"],
    "подписывав": ["подписывавши"],
    "подписывавши": ["подписывав"],
    "подписывать": ["дозаписывать"],
    "подписываться": ["расписываться", "ставить подпись"],
    "подпись": ["роспись", "автограф"],
    "подпитав": ["подпитавши"],
    "подпитавши": ["подпитав"],
    "подпитывав": ["подпитывавши"],
    "подпитывавши": ["подпитывав"],
    "подпитывать": ["подкармливать", "усиливать"],
    "подпитье": ["подпитие"],
    "подпихав": ["подпихавши"],
    "подпихавши": ["подпихав"],
    "подпихивав": ["подпихивавши"],
    "подпихивавши": ["подпихивав"],
    "подпихнув": ["подпихнувши"],
    "подпихнувши": ["подпихнув"],
    "подплавив": ["подплавивши"],
    "подплавивши": ["подплавив"],
    "подплеснев": ["подплесневши"],
    "подплесневев": ["подплесневевши"],
    "подплесневевши": ["подплесневев"],
    "подплесневши": ["подплеснев"],
    "подплеснув": ["подплеснувши"],
    "подплеснувши": ["подплеснув"],
    "подплетав": ["подплетавши"],
    "подплетавши": ["подплетав"],
    "подплыв": ["подплывши"],
    "подплывав": ["подплывавши"],
    "подплывавши": ["подплывав"],
    "подплывши": ["подплыв"],
    "подплясывав": ["подплясывавши"],
    "подплясывавши": ["подплясывав"],
    "подплёскивав": ["подплёскивавши"],
    "подплёскивавши": ["подплёскивав"],
    "подпоив": ["подпоивши"],
    "подпоивши": ["подпоив"],
    "подпол": ["подполье", "погреб", "голбец", "подклет", "подызбица"],
    "подползав": ["подползавши"],
    "подползавши": ["подползав"],
    "подползти": ["приползти"],
    "подполье": ["подвал", "подпол"],
    "подпольный": ["подземный", "конспиративный", "нелегальный"],
    "подпольщик": ["нелегал"],
    "подпольщица": ["нелегалка"],
    "подпора": ["подпорка"],
    "подпорка": ["опора", "подпора"],
    "подпоров": ["подпоровши"],
    "подпоровши": ["подпоров"],
    "подпортив": ["подпортивши"],
    "подпортивши": ["подпортив"],
    "подпоручик": ["корнет", "хорунжий", "лейтенант"],
    "подпоясав": ["подпоясавши"],
    "подпоясавши": ["подпоясав"],
    "подпоясывав": ["подпоясывавши"],
    "подпоясывавши": ["подпоясывав"],
    "подправив": ["подправивши"],
    "подправивши": ["подправив"],
    "подправляв": ["подправлявши"],
    "подправлявши": ["подправляв"],
    "подпрапорщик": ["портупей-прапорщик", "эстандарт-юнкер", "подхорунжий"],
    "подпревав": ["подпревавши"],
    "подпревавши": ["подпревав"],
    "подпревать": ["подопревать"],
    "подпруга": ["подживотник"],
    "подпрудив": ["подпрудивши"],
    "подпрудивши": ["подпрудив"],
    "подпружив": ["подпруживши"],
    "подпруживав": ["подпруживавши"],
    "подпруживавши": ["подпруживав"],
    "подпруживши": ["подпружив"],
    "подпружинив": ["подпружинивши"],
    "подпружинивав": ["подпружинивавши"],
    "подпружинивавши": ["подпружинивав"],
    "подпружинивши": ["подпружинив"],
    "подпрыгивав": ["подпрыгивавши"],
    "подпрыгивавши": ["подпрыгивав"],
    "подпрыгивание": ["подскакивание"],
    "подпрыгиванье": ["подпрыгивание"],
    "подпрыгивать": ["подскакивать"],
    "подпрыгивающий": ["подскакивающий"],
    "подпрыгнув": ["подпрыгнувши"],
    "подпрыгнувши": ["подпрыгнув"],
    "подпрыскав": ["подпрыскавши"],
    "подпрыскавши": ["подпрыскав"],
    "подпрыскивав": ["подпрыскивавши"],
    "подпрыскивавши": ["подпрыскивав"],
    "подпрягав": ["подпрягавши"],
    "подпрягавши": ["подпрягав"],
    "подпрятав": ["подпрятавши"],
    "подпрятавши": ["подпрятав"],
    "подпрятывав": ["подпрятывавши"],
    "подпрятывавши": ["подпрятывав"],
    "подпугивав": ["подпугивавши"],
    "подпугивавши": ["подпугивав"],
    "подпугнув": ["подпугнувши"],
    "подпугнувши": ["подпугнув"],
    "подпудрив": ["подпудривши"],
    "подпудривав": ["подпудривавши"],
    "подпудривавши": ["подпудривав"],
    "подпудривши": ["подпудрив"],
    "подпускав": ["подпускавши"],
    "подпускавши": ["подпускав"],
    "подпускать": ["допускать"],
    "подпускать турусы": ["нести турусы", "разводить турусы", "подпускать турусы на колёсах", "распускать турусы на колёсах", "распускать турусы"],
    "подпустив": ["подпустивши"],
    "подпустивши": ["подпустив"],
    "подпутав": ["подпутавши"],
    "подпутавши": ["подпутав"],
    "подпутывав": ["подпутывавши"],
    "подпутывавши": ["подпутывав"],
    "подпухав": ["подпухавши"],
    "подпухавши": ["подпухав"],
    "подпухнув": ["подпухнувши"],
    "подпухнувши": ["подпухнув"],
    "подпухший": ["припухший"],
    "подпушав": ["подпушавши"],
    "подпушавши": ["подпушав"],
    "подпушив": ["подпушивши"],
    "подпушивав": ["подпушивавши"],
    "подпушивавши": ["подпушивав"],
    "подпушивши": ["подпушив"],
    "подпущав": ["подпущавши"],
    "подпущавши": ["подпущав"],
    "подпятив": ["подпятивши"],
    "подпятивши": ["подпятив"],
    "подпячивав": ["подпячивавши"],
    "подпячивавши": ["подпячивав"],
    "подпёрши": ["подперев"],
    "подрабатывав": ["подрабатывавши"],
    "подрабатывавши": ["подрабатывав"],
    "подработав": ["подработавши"],
    "подработавши": ["подработав"],
    "подработка": ["халтура", "халтурка", "шабашка"],
    "подрав": ["подравши"],
    "подравнивав": ["подравнивавши"],
    "подравнивавши": ["подравнивав"],
    "подравняв": ["подравнявши"],
    "подравнявши": ["подравняв"],
    "подравши": ["подрав"],
    "подрагивав": ["подрагивавши"],
    "подрагивавши": ["подрагивав"],
    "подрагиванье": ["подрагивание"],
    "подражав": ["подражавши"],
    "подражавши": ["подражав"],
    "подражание": ["копирование", "имитация", "имитирование", "подражанье"],
    "подражанье": ["подражание"],
    "подражательно": ["имитаторски"],
    "подражательный": ["имитационный", "имитаторский"],
    "подражающий": ["имитирующий"],
    "подразвалив": ["подразваливши"],
    "подразваливши": ["подразвалив"],
    "подразведав": ["подразведавши"],
    "подразведавши": ["подразведав"],
    "подраздел": ["рубрика"],
    "подразделение": ["разделение", "классификация", "размежевание", "часть", "отдел"],
    "подразделенье": ["подразделение"],
    "подразделив": ["подразделивши"],
    "подразделивши": ["подразделив"],
    "подразделяв": ["подразделявши"],
    "подразделявши": ["подразделяв"],
    "подразнив": ["подразнивши"],
    "подразнивав": ["подразнивавши"],
    "подразнивавши": ["подразнивав"],
    "подразнивши": ["подразнив"],
    "подразрядив": ["подразрядивши"],
    "подразрядивши": ["подразрядив"],
    "подразумевав": ["подразумевавши"],
    "подразумевавши": ["подразумевав"],
    "подразумевать": ["иметь в виду", "понимать", "трактовать", "предполагать"],
    "подраив": ["подраивши"],
    "подраивши": ["подраив"],
    "подранив": ["подранивши"],
    "подранивав": ["подранивавши"],
    "подранивавши": ["подранивав"],
    "подранивши": ["подранив"],
    "подраспустив": ["подраспустивши"],
    "подраспустивши": ["подраспустив"],
    "подрастав": ["подраставши"],
    "подраставши": ["подрастав"],
    "подрастать": ["расти", "вырастать", "взрослеть"],
    "подрастаять": ["подтаять", "сократиться", "подобреть"],
    "подрастеряв": ["подрастерявши"],
    "подрастерявши": ["подрастеряв"],
    "подрасти": ["вырасти"],
    "подрастив": ["подрастивши"],
    "подрастивши": ["подрастив"],
    "подрачивав": ["подрачивавши"],
    "подрачивавши": ["подрачивав"],
    "подращивав": ["подращивавши"],
    "подращивавши": ["подращивав"],
    "подребезжав": ["подребезжавши"],
    "подребезжавши": ["подребезжав"],
    "подреберье": ["подрёберная область"],
    "подрегулировав": ["подрегулировавши"],
    "подрегулировавши": ["подрегулировав"],
    "подредактировав": ["подредактировавши"],
    "подредактировавши": ["подредактировав"],
    "подредактировать": ["поправить", "скорректировать"],
    "подредба": ["подреждане", "ред", "порядък", "класификация", "систематизация"],
    "подредив": ["подредивши"],
    "подредивши": ["подредив"],
    "подрежав": ["подрежавши"],
    "подрежавши": ["подрежав"],
    "подрезав": ["подрезавши"],
    "подрезавши": ["подрезав"],
    "подрезать": ["укоротить", "подровнять", "сократить", "урезать", "отрезать", "подорвать"],
    "подрезывав": ["подрезывавши"],
    "подрезывавши": ["подрезывав"],
    "подрезюмировав": ["подрезюмировавши"],
    "подрезюмировавши": ["подрезюмировав"],
    "подрейфовав": ["подрейфовавши"],
    "подрейфовавши": ["подрейфовав"],
    "подремав": ["подремавши"],
    "подремавши": ["подремав"],
    "подремать": ["поспать"],
    "подремонтировав": ["подремонтировавши"],
    "подремонтировавши": ["подремонтировав"],
    "подрессировав": ["подрессировавши"],
    "подрессировавши": ["подрессировав"],
    "подрессорив": ["подрессоривши"],
    "подрессоривав": ["подрессоривавши"],
    "подрессоривавши": ["подрессоривав"],
    "подрессоривши": ["подрессорив"],
    "подретушировав": ["подретушировавши"],
    "подретушировавши": ["подретушировав"],
    "подрешетив": ["подрешетивши"],
    "подрешетивши": ["подрешетив"],
    "подрешетина": ["подрешетник"],
    "подрешетник": ["подрешетина"],
    "подрешечивав": ["подрешечивавши"],
    "подрешечивавши": ["подрешечивав"],
    "подрисовав": ["подрисовавши"],
    "подрисовавши": ["подрисовав"],
    "подрисовывав": ["подрисовывавши"],
    "подрисовывавши": ["подрисовывав"],
    "подрифтовав": ["подрифтовавши"],
    "подрифтовавши": ["подрифтовав"],
    "подробив": ["подробивши"],
    "подробивши": ["подробив"],
    "подробнее": ["детальнее", "обстоятельнее"],
    "подробничав": ["подробничавши"],
    "подробничавши": ["подробничав"],
    "подробно": ["детально", "досконально"],
    "подробность": ["скрупулёзность", "детальность", "деталь", "частность"],
    "подробный": ["детальный", "обстоятельный"],
    "подровняв": ["подровнявши"],
    "подровнявши": ["подровняв"],
    "подрогнув": ["подрогнувши"],
    "подрогнувши": ["подрогнув"],
    "подрожав": ["подрожавши"],
    "подрожавши": ["подрожав"],
    "подростковый": ["отроческий", "ювенильный"],
    "подросток": ["отрок", "отроковица", "тинейджер"],
    "подрочив": ["подрочивши"],
    "подрочивши": ["подрочив"],
    "подрочить": ["поонанировать", "пофапать"],
    "подрубав": ["подрубавши"],
    "подрубавши": ["подрубав"],
    "подрубив": ["подрубивши"],
    "подрубивши": ["подрубив"],
    "подрубить": ["подключить"],
    "подрубливав": ["подрубливавши"],
    "подрубливавши": ["подрубливав"],
    "подрубливать": ["подрубать"],
    "подруга": ["подружка", "приятельница", "другиня", "товарка"],
    "подружив": ["подруживши"],
    "подруживши": ["подружив"],
    "подружить": ["сблизить", "сдружить", "объединить", "связать", "настроить"],
    "подружиться": ["сдружиться", "сблизиться"],
    "подружка": ["подруга", "приятельница", "другиня", "товарка"],
    "подрулив": ["подруливши"],
    "подруливав": ["подруливавши"],
    "подруливавши": ["подруливав"],
    "подруливши": ["подрулив"],
    "подрумянив": ["подрумянивши"],
    "подрумянивав": ["подрумянивавши"],
    "подрумянивавши": ["подрумянивав"],
    "подрумянивши": ["подрумянив"],
    "подрумянить": ["поджарить"],
    "подручник": ["вассал", "подручный"],
    "подрывав": ["подрывавши"],
    "подрывавши": ["подрывав"],
    "подрывать": ["взрывать"],
    "подрывной": ["взрывной", "вредительский", "диверсионный"],
    "подрывши": ["подрыв"],
    "подрыгав": ["подрыгавши"],
    "подрыгавши": ["подрыгав"],
    "подрыгивав": ["подрыгивавши"],
    "подрыгивавши": ["подрыгивав"],
    "подрысив": ["подрысивши"],
    "подрысивши": ["подрысив"],
    "подрыхлив": ["подрыхливши"],
    "подрыхливши": ["подрыхлив"],
    "подрыхляв": ["подрыхлявши"],
    "подрыхлявши": ["подрыхляв"],
    "подрюкав": ["подрюкавши"],
    "подрюкавши": ["подрюкав"],
    "подрявкивав": ["подрявкивавши"],
    "подрявкивавши": ["подрявкивав"],
    "подрявкнув": ["подрявкнувши"],
    "подрявкнувши": ["подрявкнув"],
    "подрягивав": ["подрягивавши"],
    "подрягивавши": ["подрягивав"],
    "подрядив": ["подрядивши"],
    "подрядивши": ["подрядив"],
    "подрядить": ["нанять"],
    "подрядничав": ["подрядничавши"],
    "подрядничавши": ["подрядничав"],
    "подряжав": ["подряжавши"],
    "подряжавши": ["подряжав"],
    "подряжать": ["нанимать"],
    "подряжаться": ["наниматься", "договариваться"],
    "подряхлев": ["подряхлевши"],
    "подряхлевши": ["подряхлев"],
    "подрёмывав": ["подрёмывавши"],
    "подрёмывавши": ["подрёмывав"],
    "подсадив": ["подсадивши"],
    "подсадивши": ["подсадив"],
    "подсадить": ["пристрастить", "приобщить", "привить"],
    "подсадная утка": ["кликовая утка"],
    "подсаживав": ["подсаживавши"],
    "подсаживавши": ["подсаживав"],
    "подсаживать": ["пристращать", "приобщать", "прививать"],
    "подсаживаться": ["пристращаться", "приобщаться"],
    "подсак": ["сак", "подсачник"],
    "подсалив": ["подсаливши"],
    "подсаливав": ["подсаливавши"],
    "подсаливавши": ["подсаливав"],
    "подсаливши": ["подсалив"],
    "подсапывав": ["подсапывавши"],
    "подсапывавши": ["подсапывав"],
    "подсаривав": ["подсаривавши"],
    "подсаривавши": ["подсаривав"],
    "подсасывав": ["подсасывавши"],
    "подсасывавши": ["подсасывав"],
    "подсахарив": ["подсахаривши"],
    "подсахаривав": ["подсахаривавши"],
    "подсахаривавши": ["подсахаривав"],
    "подсахаривши": ["подсахарив"],
    "подсачек": ["сачок", "подсачник", "подсак"],
    "подсачив": ["подсачивши"],
    "подсачивав": ["подсачивавши"],
    "подсачивавши": ["подсачивав"],
    "подсачивши": ["подсачив"],
    "подсачник": ["подсачек"],
    "подсвежав": ["подсвежавши"],
    "подсвежавши": ["подсвежав"],
    "подсвежив": ["подсвеживши"],
    "подсвеживши": ["подсвежив"],
    "подсветив": ["подсветивши"],
    "подсветивши": ["подсветив"],
    "подсветка": ["подсвечивание", "подсвет"],
    "подсвечивав": ["подсвечивавши"],
    "подсвечивавши": ["подсвечивав"],
    "подсвечник": ["канделябр", "свечница"],
    "подсвистев": ["подсвистевши"],
    "подсвистевши": ["подсвистев"],
    "подсвистнув": ["подсвистнувши"],
    "подсвистнувши": ["подсвистнув"],
    "подсвистывав": ["подсвистывавши"],
    "подсвистывавши": ["подсвистывав"],
    "подсвистыванье": ["подсвистывание"],
    "подсдать": ["притормозить", "посбавить", "поубавить", "подсдуться", "подустать", "поддать", "сдать"],
    "подсевав": ["подсевавши"],
    "подсевавши": ["подсевав"],
    "подседав": ["подседавши"],
    "подседавши": ["подседав"],
    "подседлав": ["подседлавши"],
    "подседлавши": ["подседлав"],
    "подсеивав": ["подсеивавши"],
    "подсеивавши": ["подсеивав"],
    "подсекав": ["подсекавши"],
    "подсекавши": ["подсекав"],
    "подсекать": ["рубить", "срезать", "подрезать", "подкашивать", "подрубать", "пресекать", "озадачивать", "ошеломлять", "подглядывать"],
    "подсекаться": ["подкашиваться"],
    "подсекция": ["подотдел"],
    "подселив": ["подселивши"],
    "подселивши": ["подселив"],
    "подселяв": ["подселявши"],
    "подселявши": ["подселяв"],
    "подсеребрив": ["подсеребривши"],
    "подсеребривши": ["подсеребрив"],
    "подсесть": ["присесть", "сесть"],
    "подсечка": ["подсека", "подсекание"],
    "подсеяв": ["подсеявши"],
    "подсеявши": ["подсеяв"],
    "подсигивав": ["подсигивавши"],
    "подсигивавши": ["подсигивав"],
    "подсигнув": ["подсигнувши"],
    "подсигнувши": ["подсигнув"],
    "подсидев": ["подсидевши"],
    "подсидевши": ["подсидев"],
    "подсиживав": ["подсиживавши"],
    "подсиживавши": ["подсиживав"],
    "подсиживание": ["подсиживанье"],
    "подсиживанье": ["подсиживание"],
    "подсиненный": ["подсинённый"],
    "подсинив": ["подсинивши"],
    "подсинивав": ["подсинивавши"],
    "подсинивавши": ["подсинивав"],
    "подсинивать": ["синить"],
    "подсинивши": ["подсинив"],
    "подсинённый": ["подсиненный"],
    "подсирала": ["гад", "прихвостень", "подпевала", "шестёрка", "подпёздыш"],
    "подскабливав": ["подскабливавши"],
    "подскабливавши": ["подскабливав"],
    "подсказ": ["подсказка", "подсказывание"],
    "подсказав": ["подсказавши"],
    "подсказавши": ["подсказав"],
    "подсказка": ["совет", "намёк", "напоминание", "шпаргалка", "шпора", "хинт"],
    "подсказывав": ["подсказывавши"],
    "подсказывавши": ["подсказывав"],
    "подсказывать": ["суфлировать", "подшёптывать", "договаривать", "советовать", "намекать", "надоумливать", "рекомендовать"],
    "подскакав": ["подскакавши"],
    "подскакавши": ["подскакав"],
    "подскакивав": ["подскакивавши"],
    "подскакивавши": ["подскакивав"],
    "подскакивание": ["подпрыгивание"],
    "подскакивать": ["подпрыгивать", "нападать"],
    "подскакнув": ["подскакнувши"],
    "подскакнувши": ["подскакнув"],
    "подскальзывав": ["подскальзывавши"],
    "подскальзывавши": ["подскальзывав"],
    "подскоблив": ["подскобливши"],
    "подскобливши": ["подскоблив"],
    "подскок": ["подскакивание"],
    "подскользнув": ["подскользнувши"],
    "подскользнувши": ["подскользнув"],
    "подскользнуться": ["поскользнуться"],
    "подскочив": ["подскочивши"],
    "подскочивши": ["подскочив"],
    "подскочить": ["подпрыгнуть"],
    "подскребав": ["подскребавши"],
    "подскребавши": ["подскребав"],
    "подскрёбывав": ["подскрёбывавши"],
    "подскрёбывавши": ["подскрёбывав"],
    "подслабляв": ["подслаблявши"],
    "подслаблявши": ["подслабляв"],
    "подслаивав": ["подслаивавши"],
    "подслаивавши": ["подслаивав"],
    "подсластив": ["подсластивши"],
    "подсластивши": ["подсластив"],
    "подсластить": ["облегчить", "порадовать"],
    "подсластить пилюлю": ["подзолотить"],
    "подслащав": ["подслащавши"],
    "подслащавши": ["подслащав"],
    "подслащать": ["подслащивать"],
    "подслащение": ["подслащивание"],
    "подслащивав": ["подслащивавши"],
    "подслащивавши": ["подслащивав"],
    "подслащивание": ["подслащение"],
    "подслащивать": ["подслащать"],
    "подследив": ["подследивши"],
    "подследивши": ["подследив"],
    "подследник": ["следочек"],
    "подслеживав": ["подслеживавши"],
    "подслеживавши": ["подслеживав"],
    "подслеповатый": ["близорукий", "слепой", "курица", "слепошарый", "подслепый"],
    "подслоив": ["подслоивши"],
    "подслоивши": ["подслоив"],
    "подслужив": ["подслуживши"],
    "подслуживав": ["подслуживавши"],
    "подслуживавши": ["подслуживав"],
    "подслуживши": ["подслужив"],
    "подслух": ["подслушник"],
    "подслушав": ["подслушавши"],
    "подслушавши": ["подслушав"],
    "подслушивав": ["подслушивавши"],
    "подслушивавши": ["подслушивав"],
    "подслушиванье": ["подслушивание"],
    "подслушник": ["подслух"],
    "подсмаливав": ["подсмаливавши"],
    "подсмаливавши": ["подсмаливав"],
    "подсматривав": ["подсматривавши"],
    "подсматривавши": ["подсматривав"],
    "подсматриванье": ["подсматривание"],
    "подсматривать": ["подглядывать"],
    "подсмеивав": ["подсмеивавши"],
    "подсмеивавши": ["подсмеивав"],
    "подсменив": ["подсменивши"],
    "подсменивши": ["подсменив"],
    "подсменяв": ["подсменявши"],
    "подсменявши": ["подсменяв"],
    "подсмеяв": ["подсмеявши"],
    "подсмеявши": ["подсмеяв"],
    "подсмолив": ["подсмоливши"],
    "подсмоливши": ["подсмолив"],
    "подсмотрев": ["подсмотревши"],
    "подсмотревши": ["подсмотрев"],
    "подсобив": ["подсобивши"],
    "подсобивши": ["подсобив"],
    "подсобить": ["помочь", "пособить"],
    "подсобляв": ["подсоблявши"],
    "подсоблявши": ["подсобляв"],
    "подсобрав": ["подсобравши"],
    "подсобравши": ["подсобрав"],
    "подсов": ["подсовывание"],
    "подсовав": ["подсовавши"],
    "подсовавши": ["подсовав"],
    "подсовывав": ["подсовывавши"],
    "подсовывавши": ["подсовывав"],
    "подсовывание": ["подсов"],
    "подсоединение": ["включение"],
    "подсоединив": ["подсоединивши"],
    "подсоединивши": ["подсоединив"],
    "подсоединить": ["включить", "ввести", "влить"],
    "подсоединяв": ["подсоединявши"],
    "подсоединявши": ["подсоединяв"],
    "подсоединять": ["присоединять", "подключать"],
    "подсознание": ["подсознательное", "подсознанье"],
    "подсознанье": ["подсознание"],
    "подсознательное": ["бессознательное"],
    "подсознательный": ["неосознанный", "смутный", "инстинктивный"],
    "подсократив": ["подсокративши"],
    "подсокративши": ["подсократив"],
    "подсокращав": ["подсокращавши"],
    "подсокращавши": ["подсокращав"],
    "подсолив": ["подсоливши"],
    "подсоливши": ["подсолив"],
    "подсолнечник": ["подсолнух"],
    "подсолнечниковый": ["подсолнуховый"],
    "подсолнух": ["подсолнечник", "семечки"],
    "подсолнуховый": ["подсолнечниковый"],
    "подсолнушек": ["подсолнышек"],
    "подсорив": ["подсоривши"],
    "подсоривши": ["подсорив"],
    "подсортировав": ["подсортировавши"],
    "подсортировавши": ["подсортировав"],
    "подсортировывав": ["подсортировывавши"],
    "подсортировывавши": ["подсортировывав"],
    "подсос": ["прихлебатель", "подхалим", "лизоблюд", "холуй"],
    "подсосав": ["подсосавши"],
    "подсосавши": ["подсосав"],
    "подсохнув": ["подсохнувши"],
    "подсохнувши": ["подсохнув"],
    "подсочив": ["подсочивши"],
    "подсочивши": ["подсочив"],
    "подсошка": ["сошка", "двунога"],
    "подспорив": ["подспоривши"],
    "подспоривши": ["подспорив"],
    "подспорье": ["подмога", "подспор", "подспора", "подспариванье", "подспоренье", "подсоб", "вспоможение", "вспоможенье", "пособие"],
    "подспудно": ["скрыто", "тайно", "затаённо", "бессознательно", "подсознательно", "неосознанно"],
    "подспудный": ["скрытый", "неявный", "латентный"],
    "подсрачник": ["поджопник", "пендель", "пендаль"],
    "подссывав": ["подссывавши"],
    "подссывавши": ["подссывав"],
    "подссывать": ["мочиться", "ссать", "протекать", "подтекать", "побаиваться", "трусить"],
    "подставав": ["подстававши"],
    "подстававши": ["подставав"],
    "подставивши": ["подставив"],
    "подставить": ["приставить"],
    "подставка": ["подставление", "подпорка"],
    "подставляв": ["подставлявши"],
    "подставлявши": ["подставляв"],
    "подставлять": ["приставлять"],
    "подстанавливав": ["подстанавливавши"],
    "подстанавливавши": ["подстанавливав"],
    "подстановив": ["подстановивши"],
    "подстановивши": ["подстановив"],
    "подстанывав": ["подстанывавши"],
    "подстанывавши": ["подстанывав"],
    "подстегав": ["подстегавши"],
    "подстегавши": ["подстегав"],
    "подстегнув": ["подстегнувши"],
    "подстегнувши": ["подстегнув"],
    "подстегнуть": ["пристегнуть"],
    "подстелив": ["подстеливши"],
    "подстеливши": ["подстелив"],
    "подстелить": ["подостлать"],
    "подстерегав": ["подстерегавши"],
    "подстерегавши": ["подстерегав"],
    "подстилав": ["подстилавши"],
    "подстилавши": ["подстилав"],
    "подстораживав": ["подстораживавши"],
    "подстораживавши": ["подстораживав"],
    "подсторожив": ["подстороживши"],
    "подстороживши": ["подсторожив"],
    "подстрагивав": ["подстрагивавши"],
    "подстрагивавши": ["подстрагивав"],
    "подстраивав": ["подстраивавши"],
    "подстраивавши": ["подстраивав"],
    "подстраиваться": ["пристраиваться", "становиться в строй", "присоединяться", "приспосабливаться", "приноравливаться"],
    "подстраховав": ["подстраховавши"],
    "подстраховавши": ["подстраховав"],
    "подстраховывав": ["подстраховывавши"],
    "подстраховывавши": ["подстраховывав"],
    "подстрачивав": ["подстрачивавши"],
    "подстрачивавши": ["подстрачивав"],
    "подстрекав": ["подстрекавши"],
    "подстрекавши": ["подстрекав"],
    "подстрекатель": ["подзуживатель", "провокатор"],
    "подстрекательство": ["возбуждение", "побуждение", "подбадривание", "подговаривание", "подзадоривание", "наущение", "агитация", "импульс", "стимул", "толчок", "аффект"],
    "подстрекать": ["подталкивать", "побуждать"],
    "подстрекая": ["подталкивая", "побуждая"],
    "подстрекнув": ["подстрекнувши"],
    "подстрекнувши": ["подстрекнув"],
    "подстрекнуть": ["спровоцировать", "подговорить", "возбудить"],
    "подстрелив": ["подстреливши"],
    "подстреливав": ["подстреливавши"],
    "подстреливавши": ["подстреливав"],
    "подстреливши": ["подстрелив"],
    "подстрелить": ["застрелить", "пристрелить"],
    "подстригав": ["подстригавши"],
    "подстригавши": ["подстригав"],
    "подстрижка": ["подстригание"],
    "подстрогав": ["подстрогавши"],
    "подстрогавши": ["подстрогав"],
    "подстрогать": ["подстругать"],
    "подстроив": ["подстроивши"],
    "подстроивши": ["подстроив"],
    "подстройка": ["подстраивание"],
    "подстрочив": ["подстрочивши"],
    "подстрочивши": ["подстрочив"],
    "подстругав": ["подстругавши"],
    "подстругавши": ["подстругав"],
    "подстругивав": ["подстругивавши"],
    "подстругивавши": ["подстругивав"],
    "подструнивав": ["подструнивавши"],
    "подструнивавши": ["подструнивав"],
    "подступав": ["подступавши"],
    "подступавши": ["подступав"],
    "подступаться": ["подступать"],
    "подступенник": ["подступенок"],
    "подступенок": ["подступенник"],
    "подступив": ["подступивши"],
    "подступивши": ["подступив"],
    "подстыв": ["подстывши"],
    "подстывав": ["подстывавши"],
    "подстывавши": ["подстывав"],
    "подстывши": ["подстыв"],
    "подстыковав": ["подстыковавши"],
    "подстыковавши": ["подстыковав"],
    "подстыковывав": ["подстыковывавши"],
    "подстыковывавши": ["подстыковывав"],
    "подстынув": ["подстынувши"],
    "подстынувши": ["подстынув"],
    "подстёгивав": ["подстёгивавши"],
    "подстёгивавши": ["подстёгивав"],
    "подсудив": ["подсудивши"],
    "подсудивши": ["подсудив"],
    "подсудно": ["преступно"],
    "подсудный": ["преступный"],
    "подсудобив": ["подсудобивши"],
    "подсудобивши": ["подсудобив"],
    "подсудобливав": ["подсудобливавши"],
    "подсудобливавши": ["подсудобливав"],
    "подсуживав": ["подсуживавши"],
    "подсуживавши": ["подсуживав"],
    "подсуживать": ["подыгрывать"],
    "подсунув": ["подсунувши"],
    "подсунувши": ["подсунув"],
    "подсупонив": ["подсупонивши"],
    "подсупонивав": ["подсупонивавши"],
    "подсупонивавши": ["подсупонивав"],
    "подсупонивать": ["подпоясывать", "обманывать", "одурачивать", "объегоривать", "оплетать", "обводить"],
    "подсупонивши": ["подсупонив"],
    "подсупонить": ["подпоясать", "обмануть", "объегорить", "провести", "оплести", "поддеть"],
    "подсуропив": ["подсуропивши"],
    "подсуропивши": ["подсуропив"],
    "подсуропить": ["подсунуть", "всучить", "напакостить", "навредить", "подложить свинью"],
    "подсурьмив": ["подсурьмивши"],
    "подсурьмивши": ["подсурьмив"],
    "подсурьмливав": ["подсурьмливавши"],
    "подсурьмливавши": ["подсурьмливав"],
    "подсучив": ["подсучивши"],
    "подсучивав": ["подсучивавши"],
    "подсучивавши": ["подсучивав"],
    "подсучивши": ["подсучив"],
    "подсушив": ["подсушивши"],
    "подсушивав": ["подсушивавши"],
    "подсушивавши": ["подсушивав"],
    "подсушивши": ["подсушив"],
    "подсчитав": ["подсчитавши"],
    "подсчитавши": ["подсчитав"],
    "подсчитать": ["посчитать", "сосчитать"],
    "подсчитывав": ["подсчитывавши"],
    "подсчитывавши": ["подсчитывав"],
    "подсчитывать": ["считать"],
    "подсчёт": ["подсчитывание"],
    "подсылав": ["подсылавши"],
    "подсылавши": ["подсылав"],
    "подсыпав": ["подсыпавши"],
    "подсыпавши": ["подсыпав"],
    "подсырев": ["подсыревши"],
    "подсыревши": ["подсырев"],
    "подсыхав": ["подсыхавши"],
    "подсыхавши": ["подсыхав"],
    "подсюсюкивав": ["подсюсюкивавши"],
    "подсюсюкивавши": ["подсюсюкивав"],
    "подсюсюкнув": ["подсюсюкнувши"],
    "подсюсюкнувши": ["подсюсюкнув"],
    "подсёдлывав": ["подсёдлывавши"],
    "подсёдлывавши": ["подсёдлывав"],
    "подтабанив": ["подтабанивши"],
    "подтабанивав": ["подтабанивавши"],
    "подтабанивавши": ["подтабанивав"],
    "подтабанивши": ["подтабанив"],
    "подтаивав": ["подтаивавши"],
    "подтаивавши": ["подтаивав"],
    "подтаивать": ["таять"],
    "подтакивав": ["подтакивавши"],
    "подтакивавши": ["подтакивав"],
    "подтакнув": ["подтакнувши"],
    "подтакнувши": ["подтакнув"],
    "подталкивав": ["подталкивавши"],
    "подталкивавши": ["подталкивав"],
    "подталкиванье": ["подталкивание"],
    "подтанцевав": ["подтанцевавши"],
    "подтанцевавши": ["подтанцевав"],
    "подтанцовывав": ["подтанцовывавши"],
    "подтанцовывавши": ["подтанцовывав"],
    "подтапливав": ["подтапливавши"],
    "подтапливавши": ["подтапливав"],
    "подтаптывав": ["подтаптывавши"],
    "подтаптывавши": ["подтаптывав"],
    "подтаскав": ["подтаскавши"],
    "подтаскавши": ["подтаскав"],
    "подтаскивав": ["подтаскивавши"],
    "подтаскивавши": ["подтаскивав"],
    "подтасовав": ["подтасовавши"],
    "подтасовавши": ["подтасовав"],
    "подтасовка": ["жульничание", "жульничанье", "мухлёж"],
    "подтасовывав": ["подтасовывавши"],
    "подтасовывавши": ["подтасовывав"],
    "подтачав": ["подтачавши"],
    "подтачавши": ["подтачав"],
    "подтачивав": ["подтачивавши"],
    "подтачивавши": ["подтачивав"],
    "подташнивав": ["подташнивавши"],
    "подташнивавши": ["подташнивав"],
    "подташнивать": ["поташнивать", "мутить"],
    "подтащив": ["подтащивши"],
    "подтащивши": ["подтащив"],
    "подтаяв": ["подтаявши"],
    "подтаявши": ["подтаяв"],
    "подтвердив": ["подтвердивши"],
    "подтвердивши": ["подтвердив"],
    "подтверждав": ["подтверждавши"],
    "подтверждавши": ["подтверждав"],
    "подтверждающий": ["доказывающий"],
    "подтверждение": ["подтвержденье"],
    "подтвержденье": ["подтверждение"],
    "подтверживав": ["подтверживавши"],
    "подтверживавши": ["подтверживав"],
    "подтворив": ["подтворивши"],
    "подтворивши": ["подтворив"],
    "подтворяв": ["подтворявши"],
    "подтворявши": ["подтворяв"],
    "подтекав": ["подтекавши"],
    "подтекавши": ["подтекав"],
    "подтекст": ["импликация"],
    "подтекстовав": ["подтекстовавши"],
    "подтекстовавши": ["подтекстовав"],
    "подтекстовывав": ["подтекстовывавши"],
    "подтекстовывавши": ["подтекстовывав"],
    "подтема": ["субтема"],
    "подтенетив": ["подтенетивши"],
    "подтенетивши": ["подтенетив"],
    "подтерев": ["подтёрши"],
    "подтесав": ["подтесавши"],
    "подтесавши": ["подтесав"],
    "подтибрив": ["подтибривши"],
    "подтибривав": ["подтибривавши"],
    "подтибривавши": ["подтибривав"],
    "подтибривши": ["подтибрив"],
    "подтибрить": ["украсть", "спереть", "слямзить", "стащить", "своровать", "упереть", "стибрить"],
    "подтирав": ["подтиравши"],
    "подтиравши": ["подтирав"],
    "подтираться": ["подтирать зад"],
    "подтискав": ["подтискавши"],
    "подтискавши": ["подтискав"],
    "подтискивав": ["подтискивавши"],
    "подтискивавши": ["подтискивав"],
    "подтиснатост": ["угнетеност", "униние"],
    "подтиснув": ["подтиснувши"],
    "подтиснувши": ["подтиснув"],
    "подтоварник": ["поддон"],
    "подтолкав": ["подтолкавши"],
    "подтолкавши": ["подтолкав"],
    "подтолкнув": ["подтолкнувши"],
    "подтолкнувши": ["подтолкнув"],
    "подтолковав": ["подтолковавши"],
    "подтолковавши": ["подтолковав"],
    "подтолковывав": ["подтолковывавши"],
    "подтолковывавши": ["подтолковывав"],
    "подтопив": ["подтопивши"],
    "подтопивши": ["подтопив"],
    "подтопка": ["подтапливание", "растопка"],
    "подтопляв": ["подтоплявши"],
    "подтоплявши": ["подтопляв"],
    "подтоплять": ["подтапливать"],
    "подтоптав": ["подтоптавши"],
    "подтоптавши": ["подтоптав"],
    "подтопывав": ["подтопывавши"],
    "подтопывавши": ["подтопывав"],
    "подторачивав": ["подторачивавши"],
    "подторачивавши": ["подторачивав"],
    "подторговав": ["подторговавши"],
    "подторговавши": ["подторговав"],
    "подторговывав": ["подторговывавши"],
    "подторговывавши": ["подторговывав"],
    "подторкав": ["подторкавши"],
    "подторкавши": ["подторкав"],
    "подторкивав": ["подторкивавши"],
    "подторкивавши": ["подторкивав"],
    "подторкнув": ["подторкнувши"],
    "подторкнувши": ["подторкнув"],
    "подтормаживав": ["подтормаживавши"],
    "подтормаживавши": ["подтормаживав"],
    "подтормозив": ["подтормозивши"],
    "подтормозивши": ["подтормозив"],
    "подторочив": ["подторочивши"],
    "подторочивши": ["подторочив"],
    "подточив": ["подточивши"],
    "подточивши": ["подточив"],
    "подтравив": ["подтравивши"],
    "подтравивши": ["подтравив"],
    "подтравливав": ["подтравливавши"],
    "подтравливавши": ["подтравливав"],
    "подтренькивав": ["подтренькивавши"],
    "подтренькивавши": ["подтренькивав"],
    "подтрепав": ["подтрепавши"],
    "подтрепавши": ["подтрепав"],
    "подтрунив": ["подтрунивши"],
    "подтрунивав": ["подтрунивавши"],
    "подтрунивавши": ["подтрунивав"],
    "подтрунивавший": ["подшучивавший"],
    "подтрунивание": ["подшучивание"],
    "подтруниванье": ["подтрунивание"],
    "подтрунивать": ["подшучивать"],
    "подтрунивши": ["подтрунив"],
    "подтрусив": ["подтрусивши"],
    "подтрусивши": ["подтрусив"],
    "подтрушивав": ["подтрушивавши"],
    "подтрушивавши": ["подтрушивав"],
    "подтрясав": ["подтрясавши"],
    "подтрясавши": ["подтрясав"],
    "подтряхивав": ["подтряхивавши"],
    "подтряхивавши": ["подтряхивав"],
    "подтряхнув": ["подтряхнувши"],
    "подтряхнувши": ["подтряхнув"],
    "подтупив": ["подтупивши"],
    "подтупивши": ["подтупив"],
    "подтупливав": ["подтупливавши"],
    "подтупливавши": ["подтупливав"],
    "подтупливать": ["затуплять", "притуплять", "тормозить", "притормаживать"],
    "подтухав": ["подтухавши"],
    "подтухавши": ["подтухав"],
    "подтухнув": ["подтухнувши"],
    "подтухнувши": ["подтухнув"],
    "подтушевав": ["подтушевавши"],
    "подтушевавши": ["подтушевав"],
    "подтушёвывав": ["подтушёвывавши"],
    "подтушёвывавши": ["подтушёвывав"],
    "подтыкав": ["подтыкавши"],
    "подтыкавши": ["подтыкав"],
    "подтыривав": ["подтыривавши"],
    "подтыривавши": ["подтыривав"],
    "подтявкивав": ["подтявкивавши"],
    "подтявкивавши": ["подтявкивав"],
    "подтягав": ["подтягавши"],
    "подтягавши": ["подтягав"],
    "подтягивав": ["подтягивавши"],
    "подтягивавши": ["подтягивав"],
    "подтягиванье": ["подтягивание"],
    "подтяжка": ["подтяжечка", "помочь", "выправка", "осанка", "подтянутость"],
    "подтянув": ["подтянувши"],
    "подтянувши": ["подтянув"],
    "подтяпав": ["подтяпавши"],
    "подтяпавши": ["подтяпав"],
    "подтяпывав": ["подтяпывавши"],
    "подтяпывавши": ["подтяпывав"],
    "подтёк": ["кровоподтёк", "синяк", "потёк"],
    "подтёрши": ["подтерев"],
    "подтёсывав": ["подтёсывавши"],
    "подтёсывавши": ["подтёсывав"],
    "подубасив": ["подубасивши"],
    "подубасивши": ["подубасив"],
    "подубив": ["подубивши"],
    "подубивши": ["подубив"],
    "подував": ["подувавши"],
    "подувавши": ["подував"],
    "подуванив": ["подуванивши"],
    "подуванивши": ["подуванив"],
    "подувши": ["подув"],
    "подуглив": ["подугливши"],
    "подугливав": ["подугливавши"],
    "подугливавши": ["подугливав"],
    "подугливши": ["подуглив"],
    "подудев": ["подудевши"],
    "подудевши": ["подудев"],
    "подудеть": ["подудить"],
    "подудив": ["подудивши"],
    "подудивши": ["подудив"],
    "подуздав": ["подуздавши"],
    "подуздавши": ["подуздав"],
    "подуздывав": ["подуздывавши"],
    "подуздывавши": ["подуздывав"],
    "подумав": ["подумавши"],
    "подумавши": ["подумав"],
    "подумать": ["порассуждать", "поразмыслить"],
    "подумывав": ["подумывавши"],
    "подумывавши": ["подумывав"],
    "подурачив": ["подурачивши"],
    "подурачивши": ["подурачив"],
    "подурив": ["подуривши"],
    "подуривав": ["подуривавши"],
    "подуривавши": ["подуривав"],
    "подуривши": ["подурив"],
    "подурнев": ["подурневши"],
    "подурневши": ["подурнев"],
    "подустав": ["подуставши"],
    "подуставав": ["подустававши"],
    "подустававши": ["подуставав"],
    "подуставши": ["подустав"],
    "подустив": ["подустивши"],
    "подустивши": ["подустив"],
    "подустить": ["наустить", "подстрекнуть", "поощрить"],
    "подуськав": ["подуськавши"],
    "подуськавши": ["подуськав"],
    "подуськивав": ["подуськивавши"],
    "подуськивавши": ["подуськивав"],
    "подутюжив": ["подутюживши"],
    "подутюживав": ["подутюживавши"],
    "подутюживавши": ["подутюживав"],
    "подутюживши": ["подутюжив"],
    "подучав": ["подучавши"],
    "подучавши": ["подучав"],
    "подучив": ["подучивши"],
    "подучивав": ["подучивавши"],
    "подучивавши": ["подучивав"],
    "подучивши": ["подучив"],
    "подушевой": ["подушный"],
    "подушечка": ["подушка"],
    "подушив": ["подушивши"],
    "подушивши": ["подушив"],
    "подушка безопасности": ["аэрбег", "страховка"],
    "подушка-пердушка": ["вупи"],
    "подушная подать": ["подушный оклад", "подушный налог"],
    "подушный": ["подать"],
    "подущав": ["подущавши"],
    "подущавши": ["подущав"],
    "подущать": ["наущать", "наущивать"],
    "подфабрив": ["подфабривши"],
    "подфабривав": ["подфабривавши"],
    "подфабривавши": ["подфабривав"],
    "подфабривши": ["подфабрив"],
    "подфартив": ["подфартивши"],
    "подфартивши": ["подфартив"],
    "подфартить": ["повезти", "посчастливиться", "удаться", "подвезти", "пофартить", "фартануть", "фортануть"],
    "подфурник": ["фурильщик"],
    "подфутболив": ["подфутболивши"],
    "подфутболивав": ["подфутболивавши"],
    "подфутболивавши": ["подфутболивав"],
    "подфутболивши": ["подфутболив"],
    "подхаживав": ["подхаживавши"],
    "подхаживавши": ["подхаживав"],
    "подхалим": ["подлиза", "лизоблюд"],
    "подхалимаж": ["подхалимство", "лизоблюдство", "угодничество", "раболепие"],
    "подхалимисто": ["подхалимно", "подхалимски"],
    "подхалимничав": ["подхалимничавши"],
    "подхалимничавши": ["подхалимничав"],
    "подхалимничать": ["подхалимствовать", "угодничать", "лакействовать", "холуйствовать", "раболепствовать"],
    "подхалимно": ["подхалимисто", "подхалимски"],
    "подхалимски": ["подхалимисто", "подхалимно"],
    "подхалимство": ["подхалимаж", "угодничание", "угодничанье", "лесть"],
    "подхалимствовав": ["подхалимствовавши"],
    "подхалимствовавши": ["подхалимствовав"],
    "подхалтурив": ["подхалтуривши"],
    "подхалтуривав": ["подхалтуривавши"],
    "подхалтуривавши": ["подхалтуривав"],
    "подхалтуривши": ["подхалтурив"],
    "подхалюзничав": ["подхалюзничавши"],
    "подхалюзничавши": ["подхалюзничав"],
    "подхалюзничать": ["подхалимничать"],
    "подхвалив": ["подхваливши"],
    "подхваливав": ["подхваливавши"],
    "подхваливавши": ["подхваливав"],
    "подхваливши": ["подхвалив"],
    "подхватав": ["подхватавши"],
    "подхватавши": ["подхватав"],
    "подхватив": ["подхвативши"],
    "подхвативши": ["подхватив"],
    "подхватить": ["поднять", "поддержать", "продолжить", "развить", "подцепить", "заполучить", "заразиться", "схватить"],
    "подхватывав": ["подхватывавши"],
    "подхватывавши": ["подхватывав"],
    "подхихикивав": ["подхихикивавши"],
    "подхихикивавши": ["подхихикивав"],
    "подхихикиванье": ["подхихикивание"],
    "подхихикнув": ["подхихикнувши"],
    "подхихикнувши": ["подхихикнув"],
    "подхлестнув": ["подхлестнувши"],
    "подхлестнувши": ["подхлестнув"],
    "подхлёстывав": ["подхлёстывавши"],
    "подхлёстывавши": ["подхлёстывав"],
    "подходив": ["подходивши"],
    "подходивши": ["подходив"],
    "подходимость": ["пригодность"],
    "подходить": ["обращаться", "годиться", "подниматься"],
    "подходяще": ["приемлемо", "должным образом"],
    "подходящий": ["подхожий"],
    "подхолаживав": ["подхолаживавши"],
    "подхолаживавши": ["подхолаживав"],
    "подхохатывав": ["подхохатывавши"],
    "подхохатывавши": ["подхохатывав"],
    "подхрамывав": ["подхрамывавши"],
    "подхрамывавши": ["подхрамывав"],
    "подхрапывав": ["подхрапывавши"],
    "подхрапывавши": ["подхрапывав"],
    "подхромав": ["подхромавши"],
    "подхромавши": ["подхромав"],
    "подхрюкивав": ["подхрюкивавши"],
    "подхрюкивавши": ["подхрюкивав"],
    "подцапав": ["подцапавши"],
    "подцапавши": ["подцапав"],
    "подцапать": ["подцапнуть"],
    "подцапнув": ["подцапнувши"],
    "подцапнувши": ["подцапнув"],
    "подцапнуть": ["подцапать"],
    "подцапывав": ["подцапывавши"],
    "подцапывавши": ["подцапывав"],
    "подцветив": ["подцветивши"],
    "подцветивши": ["подцветив"],
    "подцвечивав": ["подцвечивавши"],
    "подцвечивавши": ["подцвечивав"],
    "подцедив": ["подцедивши"],
    "подцедивши": ["подцедив"],
    "подцеживав": ["подцеживавши"],
    "подцеживавши": ["подцеживав"],
    "подцепив": ["подцепивши"],
    "подцепивши": ["подцепив"],
    "подцепляв": ["подцеплявши"],
    "подцеплявши": ["подцепляв"],
    "подцеплять": ["прицеплять", "поддевать"],
    "подчалив": ["подчаливши"],
    "подчаливав": ["подчаливавши"],
    "подчаливавши": ["подчаливав"],
    "подчаливши": ["подчалив"],
    "подчас": ["иногда", "временами", "порой"],
    "подчеканив": ["подчеканивши"],
    "подчеканивав": ["подчеканивавши"],
    "подчеканивавши": ["подчеканивав"],
    "подчеканивши": ["подчеканив"],
    "подчеркнув": ["подчеркнувши"],
    "подчеркнувши": ["подчеркнув"],
    "подчеркнуть": ["отметить", "выделить", "указать"],
    "подчернив": ["подчернивши"],
    "подчернивши": ["подчернив"],
    "подчерняв": ["подчернявши"],
    "подчернявши": ["подчерняв"],
    "подчерпнув": ["подчерпнувши"],
    "подчерпнувши": ["подчерпнув"],
    "подчерпывав": ["подчерпывавши"],
    "подчерпывавши": ["подчерпывав"],
    "подчертаност": ["емфаза", "емфатичност", "ударение"],
    "подчертив": ["подчертивши"],
    "подчертивши": ["подчертив"],
    "подчерчивав": ["подчерчивавши"],
    "подчерчивавши": ["подчерчивав"],
    "подчерёвина": ["подчерёвок", "пузанина", "пузонина"],
    "подчерёвок": ["подчерёвина"],
    "подчесав": ["подчесавши"],
    "подчесавши": ["подчесав"],
    "подчинение": ["подчинённость", "субординация", "подчиненье"],
    "подчиненье": ["подчинение"],
    "подчинив": ["подчинивши"],
    "подчинивши": ["подчинив"],
    "подчиняв": ["подчинявши"],
    "подчинявши": ["подчиняв"],
    "подчинять": ["покорять"],
    "подчиняться": ["покоряться", "повиноваться"],
    "подчинённость": ["подчинение"],
    "подчинённый": ["служащий", "зависимый", "второстепенный", "исполнитель"],
    "подчистив": ["подчистивши"],
    "подчистивши": ["подчистив"],
    "подчитав": ["подчитавши"],
    "подчитавши": ["подчитав"],
    "подчитывав": ["подчитывавши"],
    "подчитывавши": ["подчитывав"],
    "подчищав": ["подчищавши"],
    "подчищавши": ["подчищав"],
    "подчёркивав": ["подчёркивавши"],
    "подчёркивавши": ["подчёркивав"],
    "подчёркивать": ["оттенять"],
    "подчёсывав": ["подчёсывавши"],
    "подчёсывавши": ["подчёсывав"],
    "подшагивав": ["подшагивавши"],
    "подшагивавши": ["подшагивав"],
    "подшагнув": ["подшагнувши"],
    "подшагнувши": ["подшагнув"],
    "подшакалив": ["подшакаливши"],
    "подшакаливши": ["подшакалив"],
    "подшаманив": ["подшаманивши"],
    "подшаманивши": ["подшаманив"],
    "подшаркивав": ["подшаркивавши"],
    "подшаркивавши": ["подшаркивав"],
    "подшаркнув": ["подшаркнувши"],
    "подшаркнувши": ["подшаркнув"],
    "подшвыривав": ["подшвыривавши"],
    "подшвыривавши": ["подшвыривав"],
    "подшвырнув": ["подшвырнувши"],
    "подшвырнувши": ["подшвырнув"],
    "подшвыряв": ["подшвырявши"],
    "подшвырявши": ["подшвыряв"],
    "подшепнув": ["подшепнувши"],
    "подшепнувши": ["подшепнув"],
    "подшефный": ["подопечный"],
    "подшибав": ["подшибавши"],
    "подшибавши": ["подшибав"],
    "подшибив": ["подшибивши"],
    "подшибивши": ["подшибив"],
    "подшивав": ["подшивавши"],
    "подшивавши": ["подшивав"],
    "подшивши": ["подшив"],
    "подшипник": ["подпятник"],
    "подшлемник": ["балаклава"],
    "подшлифовав": ["подшлифовавши"],
    "подшлифовавши": ["подшлифовав"],
    "подшлифовывав": ["подшлифовывавши"],
    "подшлифовывавши": ["подшлифовывав"],
    "подшлёпнув": ["подшлёпнувши"],
    "подшлёпнувши": ["подшлёпнув"],
    "подшлёпывав": ["подшлёпывавши"],
    "подшлёпывавши": ["подшлёпывав"],
    "подшмыгивав": ["подшмыгивавши"],
    "подшмыгивавши": ["подшмыгивав"],
    "подшмыгнув": ["подшмыгнувши"],
    "подшмыгнувши": ["подшмыгнув"],
    "подшофе": ["подшефе", "под-шефе", "под хмельком", "навеселе"],
    "подшпаклевав": ["подшпаклевавши"],
    "подшпаклевавши": ["подшпаклевав"],
    "подшпаклёвывав": ["подшпаклёвывавши"],
    "подшпаклёвывавши": ["подшпаклёвывав"],
    "подшпилив": ["подшпиливши"],
    "подшпиливав": ["подшпиливавши"],
    "подшпиливавши": ["подшпиливав"],
    "подшпиливши": ["подшпилив"],
    "подшпорив": ["подшпоривши"],
    "подшпоривав": ["подшпоривавши"],
    "подшпоривавши": ["подшпоривав"],
    "подшпоривши": ["подшпорив"],
    "подштанники": ["кальсоны"],
    "подштопав": ["подштопавши"],
    "подштопавши": ["подштопав"],
    "подштопывав": ["подштопывавши"],
    "подштопывавши": ["подштопывав"],
    "подштукатурив": ["подштукатуривши"],
    "подштукатуривав": ["подштукатуривавши"],
    "подштукатуривавши": ["подштукатуривав"],
    "подштукатуривши": ["подштукатурив"],
    "подшумев": ["подшумевши"],
    "подшумевши": ["подшумев"],
    "подшуровав": ["подшуровавши"],
    "подшуровавши": ["подшуровав"],
    "подшустрив": ["подшустривши"],
    "подшустривши": ["подшустрив"],
    "подшустрить": ["пошустрить", "подшустрячить"],
    "подшустрячив": ["подшустрячивши"],
    "подшустрячивши": ["подшустрячив"],
    "подшустрячить": ["подшустрить", "пошустрить"],
    "подшутив": ["подшутивши"],
    "подшутивши": ["подшутив"],
    "подшучивав": ["подшучивавши"],
    "подшучивавши": ["подшучивав"],
    "подшучивание": ["подначивание", "подкалывание"],
    "подшучиванье": ["подшучивание"],
    "подшучивать": ["подтрунивать"],
    "подшёптывав": ["подшёптывавши"],
    "подшёптывавши": ["подшёптывав"],
    "подшёптывать": ["нашёптывать"],
    "подщелачивав": ["подщелачивавши"],
    "подщелачивавши": ["подщелачивав"],
    "подщелачивание": ["алкализация", "ощелачивание"],
    "подщелкнув": ["подщелкнувши"],
    "подщелкнувши": ["подщелкнув"],
    "подщелочив": ["подщелочивши"],
    "подщелочивши": ["подщелочив"],
    "подщепав": ["подщепавши"],
    "подщепавши": ["подщепав"],
    "подщипав": ["подщипавши"],
    "подщипавши": ["подщипав"],
    "подщипывав": ["подщипывавши"],
    "подщипывавши": ["подщипывав"],
    "подщипывание": ["подщипанье"],
    "подщипыванье": ["подщипывание"],
    "подщёлкивав": ["подщёлкивавши"],
    "подщёлкивавши": ["подщёлкивав"],
    "подъебав": ["подъебавши"],
    "подъебавши": ["подъебав"],
    "подъебать": ["подколоть"],
    "подъебаш": ["подделка", "фейк"],
    "подъебнув": ["подъебнувши"],
    "подъебнувши": ["подъебнув"],
    "подъебнуть": ["подшутить", "подтрунить"],
    "подъедав": ["подъедавши"],
    "подъедавши": ["подъедав"],
    "подъезд": ["парадное", "парадная"],
    "подъездив": ["подъездивши"],
    "подъездивши": ["подъездив"],
    "подъезжав": ["подъезжавши"],
    "подъезжавши": ["подъезжав"],
    "подъезжание": ["подъезд"],
    "подъезжать": ["приезжать"],
    "подъелдыкивав": ["подъелдыкивавши"],
    "подъелдыкивавши": ["подъелдыкивав"],
    "подъелдыкивать": ["смеяться", "подсмеиваться", "гладить поперёк шерсти", "подъёбывать", "подъябывать"],
    "подъелдыкнув": ["подъелдыкнувши"],
    "подъелдыкнувши": ["подъелдыкнув"],
    "подъесть": ["подгрызть", "доесть", "съесть", "подкормиться", "подпитаться"],
    "подъехав": ["подъехавши"],
    "подъехавши": ["подъехав"],
    "подъехаться": ["подкатиться"],
    "подъюлив": ["подъюливши"],
    "подъюливши": ["подъюлив"],
    "подъяремный": ["подъярёмный"],
    "подъярёмный": ["порабощённый", "подневольный", "рабский"],
    "подъятие": ["поднятие", "подъём"],
    "подъятый": ["поднятый", "проделанный"],
    "подъять": ["поднять"],
    "подъятье": ["подъятие"],
    "подъёб": ["подколка", "подковыр", "подковырка", "подначка", "подъебон", "подъёбка"],
    "подъёбка": ["подколка", "подковыр", "подковырка", "подначка", "подъебон"],
    "подъёбывав": ["подъёбывавши"],
    "подъёбывавши": ["подъёбывав"],
    "подъёбывать": ["подмахивать", "поддавать", "подъябывать", "подшучивать", "подтрунивать", "соглашаться", "поддакивать"],
    "подыграв": ["подыгравши"],
    "подыгравши": ["подыграв"],
    "подыгрывав": ["подыгрывавши"],
    "подыгрывавши": ["подыгрывав"],
    "подыгрывание": ["аккомпанирование"],
    "подыгрываться": ["подделываться", "подлаживаться"],
    "подызбица": ["голбец", "гульбица", "подклет", "подклеть", "подпол", "подполица", "подызбище"],
    "подыздержаться": ["поиздержаться"],
    "подымав": ["подымавши"],
    "подымавши": ["подымав"],
    "подымать": ["поднимать"],
    "подымать на смех": ["цыганить"],
    "подыматься": ["подниматься"],
    "подымив": ["подымивши"],
    "подымивши": ["подымив"],
    "подыскав": ["подыскавши"],
    "подыскавши": ["подыскав"],
    "подыскать": ["подобрать", "разыскать"],
    "подыскивав": ["подыскивавши"],
    "подыскивавши": ["подыскивав"],
    "подыскивать": ["искать"],
    "подытожив": ["подытоживши"],
    "подытоживав": ["подытоживавши"],
    "подытоживавши": ["подытоживав"],
    "подытоживаемый": ["итожимый", "обобщаемый", "суммируемый", "резюмируемый"],
    "подытоживание": ["подсчёт", "суммирование", "резюмирование"],
    "подытоживать": ["суммировать", "выводить", "заключать"],
    "подытоживши": ["подытожив"],
    "подытожить": ["просуммировать", "вывести", "заключить"],
    "подыхав": ["подыхавши"],
    "подыхавши": ["подыхав"],
    "подышав": ["подышавши"],
    "подышавши": ["подышав"],
    "подэра": ["подера", "подэрная кривая", "подошвенная кривая"],
    "подюжев": ["подюжевши"],
    "подюжевши": ["подюжев"],
    "подюжеть": ["вырасти", "сложиться", "окрепнуть", "поплотнеть", "поздороветь"],
    "подюжив": ["подюживши"],
    "подюживши": ["подюжив"],
    "подялба": ["делба", "разподялба", "разпредяла", "разделяне", "разпределение"],
    "подёнка": ["однодневка", "эфемерида"],
    "подённичав": ["подённичавши"],
    "подённичавши": ["подённичав"],
    "подённичать": ["подрабатывать", "халтурить", "бомбить", "перебиваться", "кусочничать"],
    "подённый": ["посуточный", "ежедневный", "каждодневный", "ежесуточный", "подёнщик"],
    "подёнщик": ["батрак", "бурлак", "подённый", "работник", "рабочий", "наёмник", "труженик"],
    "подёргав": ["подёргавши"],
    "подёргавши": ["подёргав"],
    "подёргивав": ["подёргивавши"],
    "подёргивавши": ["подёргивав"],
    "подёрнув": ["подёрнувши"],
    "подёрнувши": ["подёрнув"],
    "поебав": ["поебавши"],
    "поебавши": ["поебав"],
    "поебаться": ["потрахаться", "повкалывать", "попахать", "повпахивать", "помантулить", "поупираться", "погорбатиться", "поишачить", "повъёбывать", "повъябывать", "поконоёбиться"],
    "поебень": ["штуковина", "ерунда", "ерундень", "дребедень", "срань", "срань господня", "фиговина", "херь", "херня", "хреновина", "хренотень", "хрень", "ебень", "ёбань", "ебатория"],
    "поебота": ["ерунда", "ерундень", "тягомотина", "блевотина", "фигня", "хрень", "херь", "поебень", "поеботина", "хуйня", "хуетень"],
    "поеботина": ["ерунда", "ерундень", "тягомотина", "блевотина", "фигня", "хрень", "херь", "поебень", "поебота", "хуйня", "хуетень"],
    "поебти": ["поебать", "поеть", "поети", "поябать", "поябти", "поять", "пояти"],
    "поев": ["поевши"],
    "поевши": ["поев"],
    "поегозив": ["поегозивши"],
    "поегозивши": ["поегозив"],
    "поедав": ["поедавши"],
    "поедавши": ["поедав"],
    "поедание": ["съедание", "поеданье"],
    "поеданье": ["поедание", "съедание", "съеданье"],
    "поединок": ["дуэль", "борьба", "сражение", "бой", "противоборство", "противостояние", "противодействие", "стычка", "состязание", "соревнование", "схватка", "спор"],
    "поедом есть": ["есть поедом", "сживать со свету", "со свету сживать"],
    "поездив": ["поездивши"],
    "поездивши": ["поездив"],
    "поездка": ["путешествие", "путь", "езда", "ездка"],
    "поездовав": ["поездовавши"],
    "поездовавши": ["поездовав"],
    "поелику": ["поскольку", "так как", "потому что", "ибо", "понеже", "зане"],
    "поелозив": ["поелозивши"],
    "поелозивши": ["поелозив"],
    "поерошив": ["поерошивши"],
    "поерошивши": ["поерошив"],
    "поесть": ["покушать"],
    "поетка": ["поетеса"],
    "поехав": ["поехавши"],
    "поехавши": ["поехав"],
    "поехидничав": ["поехидничавши"],
    "поехидничавши": ["поехидничав"],
    "пожав": ["пожавши"],
    "пожавши": ["пожав"],
    "пожадничав": ["пожадничавши"],
    "пожадничавши": ["пожадничав"],
    "пожадничать": ["поскупиться"],
    "пожалев": ["пожалевши"],
    "пожалевши": ["пожалев"],
    "пожалив": ["пожаливши"],
    "пожаливши": ["пожалив"],
    "пожаловав": ["пожаловавши"],
    "пожаловавши": ["пожаловав"],
    "пожалованье": ["пожалование"],
    "пожалуй": ["вероятно", "возможно", "лучше"],
    "пожарив": ["пожаривши"],
    "пожаривши": ["пожарив"],
    "пожарная машина": ["пожарный автомобиль"],
    "пожарный": ["противопожарный"],
    "пожарный автомобиль": ["пожарная машина"],
    "пожароустойчивость": ["пожаростойкость"],
    "пожароустойчивый": ["пожаростойкий"],
    "пожартовав": ["пожартовавши"],
    "пожартовавши": ["пожартовав"],
    "пожатье": ["пожатие"],
    "пождав": ["пождавши"],
    "пождавши": ["пождав"],
    "пожевав": ["пожевавши"],
    "пожевавши": ["пожевав"],
    "пожелав": ["пожелавши"],
    "пожелавши": ["пожелав"],
    "пожелание": ["желание"],
    "пожелать": ["захотеть"],
    "пожелтев": ["пожелтевши"],
    "пожелтевши": ["пожелтев"],
    "пожелтив": ["пожелтивши"],
    "пожелтивши": ["пожелтив"],
    "поженив": ["поженивши"],
    "поженивши": ["поженив"],
    "поженить": ["женить"],
    "пожениться": ["жениться", "вступить в брак", "пережениться", "попережениться"],
    "пожень": ["пожня"],
    "пожертвовав": ["пожертвовавши"],
    "пожертвовавши": ["пожертвовав"],
    "пожертвование": ["дарение", "подношение", "дар", "взнос", "самопожертвование", "самопожертвованье"],
    "пожертвованье": ["пожертвование"],
    "пожертвователь": ["жертвователь"],
    "пожив": ["поживши"],
    "поживав": ["поживавши"],
    "поживавши": ["поживав"],
    "поживши": ["пожив"],
    "пожигав": ["пожигавши"],
    "пожигавши": ["пожигав"],
    "пожидев": ["пожидевши"],
    "пожидевши": ["пожидев"],
    "пожилой": ["старый", "немолодой"],
    "пожимав": ["пожимавши"],
    "пожимавши": ["пожимав"],
    "пожиманье": ["пожимание"],
    "пожимать": ["сжимать"],
    "пожинав": ["пожинавши"],
    "пожинавши": ["пожинав"],
    "пожинать": ["жать", "сжинать"],
    "пожирав": ["пожиравши"],
    "пожиравши": ["пожирав"],
    "пожирание": ["пожиранье"],
    "пожиранье": ["пожирание"],
    "пожирать": ["поедать", "сжирать"],
    "пожирев": ["пожиревши"],
    "пожиревши": ["пожирев"],
    "пожирнев": ["пожирневши"],
    "пожирневши": ["пожирнев"],
    "пожирнеть": ["пожиреть"],
    "пожировав": ["пожировавши"],
    "пожировавши": ["пожировав"],
    "пожиток": ["пожитки", "скарб"],
    "пожмотничав": ["пожмотничавши"],
    "пожмотничавши": ["пожмотничав"],
    "пожня": ["пожень"],
    "пожолкнув": ["пожолкнувши"],
    "пожолкнувши": ["пожолкнув"],
    "пожрав": ["пожравши"],
    "пожравши": ["пожрав"],
    "пожрать": ["поглотить", "сожрать"],
    "пожужжав": ["пожужжавши"],
    "пожужжавши": ["пожужжав"],
    "пожуировав": ["пожуировавши"],
    "пожуировавши": ["пожуировав"],
    "пожурив": ["пожуривши"],
    "пожуривши": ["пожурив"],
    "пожурить": ["поругать", "попенять"],
    "пожухлый": ["жухлый"],
    "пожухнув": ["пожухнувши"],
    "пожухнувши": ["пожухнув"],
    "пожухнуть": ["потускнеть", "засохнуть"],
    "пожучив": ["пожучивши"],
    "пожучивши": ["пожучив"],
    "пожёвывав": ["пожёвывавши"],
    "пожёвывавши": ["пожёвывав"],
    "поза": ["рисовка", "позёрство"],
    "поза лотоса": ["падмасана", "лотос"],
    "позабавив": ["позабавивши"],
    "позабавивши": ["позабавив"],
    "позабавить": ["повеселить", "развлечь", "потешить"],
    "позабив": ["позабивши"],
    "позабивав": ["позабивавши"],
    "позабивавши": ["позабивав"],
    "позабивши": ["позабив"],
    "позабирав": ["позабиравши"],
    "позабиравши": ["позабирав"],
    "позабрав": ["позабравши"],
    "позабравши": ["позабрав"],
    "позабрасывав": ["позабрасывавши"],
    "позабрасывавши": ["позабрасывав"],
    "позабросив": ["позабросивши"],
    "позабросивши": ["позабросив"],
    "позабросить": ["забросить", "спозабросить"],
    "позабыв": ["позабывши"],
    "позабывав": ["позабывавши"],
    "позабывавши": ["позабывав"],
    "позабывши": ["позабыв"],
    "позабыть": ["забыть", "запамятовать", "спозабыть"],
    "позавив": ["позавивши"],
    "позавивши": ["позавив"],
    "позавидовав": ["позавидовавши"],
    "позавидовавши": ["позавидовав"],
    "позавиствовав": ["позавиствовавши"],
    "позавиствовавши": ["позавиствовав"],
    "позаводив": ["позаводивши"],
    "позаводивши": ["позаводив"],
    "позаволакивав": ["позаволакивавши"],
    "позаволакивавши": ["позаволакивав"],
    "позавтракав": ["позавтракавши"],
    "позавтракавши": ["позавтракав"],
    "позавчера": ["третьего дня", "позавчерась"],
    "позавязнув": ["позавязнувши"],
    "позавязнувши": ["позавязнув"],
    "позаглохнув": ["позаглохнувши"],
    "позаглохнувши": ["позаглохнув"],
    "позаглядывав": ["позаглядывавши"],
    "позаглядывавши": ["позаглядывав"],
    "позагорав": ["позагоравши"],
    "позагоравши": ["позагорав"],
    "позаделав": ["позаделавши"],
    "позаделавши": ["позаделав"],
    "позадержав": ["позадержавши"],
    "позадержавши": ["позадержав"],
    "позади": ["сзади", "в прошлом", "за"],
    "позадилобковый": ["ретролобковый"],
    "позадолжав": ["позадолжавши"],
    "позадолжавши": ["позадолжав"],
    "позадротив": ["позадротивши"],
    "позадротивши": ["позадротив"],
    "позаигрывав": ["позаигрывавши"],
    "позаигрывавши": ["позаигрывав"],
    "позаимствовав": ["позаимствовавши"],
    "позаимствовавши": ["позаимствовав"],
    "позаканчивав": ["позаканчивавши"],
    "позаканчивавши": ["позаканчивав"],
    "позакапывав": ["позакапывавши"],
    "позакапывавши": ["позакапывав"],
    "позакопав": ["позакопавши"],
    "позакопавши": ["позакопав"],
    "позакрыв": ["позакрывши"],
    "позакрывав": ["позакрывавши"],
    "позакрывавши": ["позакрывав"],
    "позакрывши": ["позакрыв"],
    "позалепливав": ["позалепливавши"],
    "позалепливавши": ["позалепливав"],
    "позалепляв": ["позалеплявши"],
    "позалеплявши": ["позалепляв"],
    "позамаслив": ["позамасливши"],
    "позамасливши": ["позамаслив"],
    "позамедлив": ["позамедливши"],
    "позамедливши": ["позамедлив"],
    "позамерзав": ["позамерзавши"],
    "позамерзавши": ["позамерзав"],
    "позамолкнув": ["позамолкнувши"],
    "позамолкнувши": ["позамолкнув"],
    "позамучив": ["позамучивши"],
    "позамучивши": ["позамучив"],
    "позамяв": ["позамявши"],
    "позамявши": ["позамяв"],
    "позамёрзнув": ["позамёрзнувши"],
    "позамёрзнувши": ["позамёрзнув"],
    "позанимав": ["позанимавши"],
    "позанимавши": ["позанимав"],
    "позаносив": ["позаносивши"],
    "позаносивши": ["позаносив"],
    "позаняв": ["позанявши"],
    "позанявши": ["позаняв"],
    "позапамятовав": ["позапамятовавши"],
    "позапамятовавши": ["позапамятовав"],
    "позаперев": ["позаперши"],
    "позаперши": ["позаперев"],
    "позапирав": ["позапиравши"],
    "позапиравши": ["позапирав"],
    "позапоминав": ["позапоминавши"],
    "позапоминавши": ["позапоминав"],
    "позапутав": ["позапутавши"],
    "позапутавши": ["позапутав"],
    "позарастав": ["позараставши"],
    "позараставши": ["позарастав"],
    "позаревав": ["позаревавши"],
    "позаревавши": ["позаревав"],
    "позарез": ["до крайности", "очень", "любой ценой"],
    "позаржавев": ["позаржавевши"],
    "позаржавевши": ["позаржавев"],
    "позарыв": ["позарывши"],
    "позарывав": ["позарывавши"],
    "позарывавши": ["позарывав"],
    "позарывши": ["позарыв"],
    "позарыть": ["позарывать"],
    "позаснув": ["позаснувши"],
    "позаснувши": ["позаснув"],
    "позатихнув": ["позатихнувши"],
    "позатихнувши": ["позатихнув"],
    "позатягивав": ["позатягивавши"],
    "позатягивавши": ["позатягивав"],
    "позатянув": ["позатянувши"],
    "позатянувши": ["позатянув"],
    "позвав": ["позвавши"],
    "позвавши": ["позвав"],
    "позванивав": ["позванивавши"],
    "позванивавши": ["позванивав"],
    "позваниванье": ["позванивание"],
    "позвать": ["обратиться", "пригласить"],
    "позвенев": ["позвеневши"],
    "позвеневши": ["позвенев"],
    "позвенивав": ["позвенивавши"],
    "позвенивавши": ["позвенивав"],
    "позволение": ["разрешение", "позволенье"],
    "позволенье": ["позволение"],
    "позволив": ["позволивши"],
    "позволивши": ["позволив"],
    "позволительно": ["дозволительно", "допустимо"],
    "позволить": ["разрешить", "дозволить", "дать разрешение"],
    "позволяв": ["позволявши"],
    "позволявши": ["позволяв"],
    "позволять": ["дозволять", "разрешать", "давать возможность"],
    "позвонив": ["позвонивши"],
    "позвонивши": ["позвонив"],
    "позвонить": ["брякнуть", "звякнуть", "набрать"],
    "позвоночник": ["позвоночный столб", "спинной хребет", "хребет", "хребтина", "стержень", "основа"],
    "позвоночное": ["черепное"],
    "позвоночный": ["хребтовый", "вертебральный"],
    "позвучав": ["позвучавши"],
    "позвучавши": ["позвучав"],
    "позвякав": ["позвякавши"],
    "позвякавши": ["позвякав"],
    "позвякивав": ["позвякивавши"],
    "позвякивавши": ["позвякивав"],
    "позвякивание": ["звякание"],
    "позвякиванье": ["позвякивание"],
    "позднее": ["попозднее", "попозже", "после", "позже", "потом", "впоследствии"],
    "позднейший": ["последующий"],
    "позднесть": ["поздность"],
    "позднеюрский": ["верхнеюрский"],
    "поздний": ["конечный", "запоздалый", "несвоевременный"],
    "поздника": ["паслён чёрный"],
    "поздно пить боржоми": ["поздняк метаться", "поздняк дёргаться", "элвис покинул здание"],
    "поздновато": ["поздненько"],
    "поздность": ["позднесть"],
    "поздняк": ["поздно"],
    "поздняк метаться": ["поздно пить боржоми", "поздняк дёргаться"],
    "позднёхонько": ["позднёшенько"],
    "позднёшенько": ["позднёхонько"],
    "поздороваться": ["поприветствовать"],
    "поздоровев": ["поздоровевши"],
    "поздоровевши": ["поздоровев"],
    "поздравив": ["поздравивши"],
    "поздравивши": ["поздравив"],
    "поздравленье": ["поздравление"],
    "поздравляв": ["поздравлявши"],
    "поздравлявши": ["поздравляв"],
    "поздравствовав": ["поздравствовавши"],
    "поздравствовавши": ["поздравствовав"],
    "позевав": ["позевавши"],
    "позевавши": ["позевав"],
    "позевнув": ["позевнувши"],
    "позевнувши": ["позевнув"],
    "позеленев": ["позеленевши"],
    "позеленевши": ["позеленев"],
    "позеленелый": ["позеленевший"],
    "позеленеть": ["побелеть", "побледнеть"],
    "позеленив": ["позеленивши"],
    "позеленивши": ["позеленив"],
    "позже": ["позднее", "потом", "затем"],
    "позикодержець": ["позикодержатель", "позикотримач"],
    "позимовав": ["позимовавши"],
    "позимовавши": ["позимовав"],
    "позировав": ["позировавши"],
    "позировавши": ["позировав"],
    "позированье": ["позирование"],
    "позировать": ["рисоваться"],
    "позитивно": ["положительно", "утвердительно"],
    "позитивный": ["положительный", "нормативный"],
    "позитрон": ["антиэлектрон"],
    "позитрон-эмиссионный": ["позитронно-эмиссионный"],
    "позитронно-эмиссионный": ["позитрон-эмиссионный"],
    "позитура": ["поза"],
    "позиционировав": ["позиционировавши"],
    "позиционировавши": ["позиционировав"],
    "позиционировать": ["размещать", "разместить", "располагать", "расположить"],
    "позиция": ["положение", "расположение", "поза", "дислокация", "амплуа", "ситуация", "точка зрения", "мнение", "наименование", "должность"],
    "позичення": ["позичання"],
    "позлатив": ["позлативши"],
    "позлативши": ["позлатив"],
    "позлащав": ["позлащавши"],
    "позлащавши": ["позлащав"],
    "позлащать": ["золотить"],
    "позлив": ["позливши"],
    "позливши": ["позлив"],
    "позлобствовав": ["позлобствовавши"],
    "позлобствовавши": ["позлобствовав"],
    "позлорадствовав": ["позлорадствовавши"],
    "позлорадствовавши": ["позлорадствовав"],
    "позлословив": ["позлословивши"],
    "позлословивши": ["позлословив"],
    "познабливав": ["познабливавши"],
    "познабливавши": ["познабливав"],
    "познав": ["познавши"],
    "познавав": ["познававши"],
    "познававши": ["познавав"],
    "познаванье": ["познавание"],
    "познавательный": ["гносеологический", "занимательный", "информативный", "обучающий"],
    "познавать": ["изучать", "постигать", "испытывать", "переживать", "ощущать", "узнавать"],
    "познавши": ["познав"],
    "познакомив": ["познакомивши"],
    "познакомивши": ["познакомив"],
    "познакомиться": ["встретиться", "узнать", "ознакомиться"],
    "познание": ["познавание"],
    "познанье": ["познание"],
    "познобив": ["познобивши"],
    "познобивши": ["познобив"],
    "позобав": ["позобавши"],
    "позобавши": ["позобав"],
    "позолота": ["золочение"],
    "позолотев": ["позолотевши"],
    "позолотевши": ["позолотев"],
    "позолотив": ["позолотивши"],
    "позолотивши": ["позолотив"],
    "позолотить": ["приукрасить", "подкупить"],
    "позолотчик": ["золотильщик"],
    "позондировав": ["позондировавши"],
    "позондировавши": ["позондировав"],
    "позор": ["бесчестие", "бесчестье", "срам", "вид", "зрелище", "позорище"],
    "позорив": ["позоривши"],
    "позоривши": ["позорив"],
    "позорище": ["зрелище", "позор"],
    "позотонический": ["постуральный"],
    "позубоскалив": ["позубоскаливши"],
    "позубоскаливши": ["позубоскалив"],
    "позубоскалить": ["позубоскальничать", "посмеяться", "пошутить"],
    "позубоскальничав": ["позубоскальничавши"],
    "позубоскальничавши": ["позубоскальничав"],
    "позубрив": ["позубривши"],
    "позубривши": ["позубрив"],
    "позумент": ["галун"],
    "позументщик": ["шмуклер", "бахромщик"],
    "позы": ["буузы"],
    "позыбав": ["позыбавши"],
    "позыбавши": ["позыбав"],
    "позыв": ["призыв"],
    "позывав": ["позывавши"],
    "позывавши": ["позывав"],
    "позывной": ["позывный", "позывной сигнал"],
    "позывный": ["позывной"],
    "позырив": ["позыривши"],
    "позыривши": ["позырив"],
    "позырить": ["посмотреть", "поглядеть", "понаблюдать"],
    "позычив": ["позычивши"],
    "позычивши": ["позычив"],
    "позябнув": ["позябнувши"],
    "позябнувши": ["позябнув"],
    "позёвывав": ["позёвывавши"],
    "позёвывавши": ["позёвывав"],
    "позёмка": ["позёмок"],
    "позёр": ["воображала", "воображуля", "выпендрёжник", "понторез", "выебонщик", "выёбщик", "натурщик", "спортсмен", "физкультурник"],
    "позёрка": ["позёрша"],
    "позёрша": ["позёрка"],
    "поив": ["поивши"],
    "поивши": ["поив"],
    "поиграв": ["поигравши"],
    "поигравши": ["поиграв"],
    "поигрывав": ["поигрывавши"],
    "поигрывавши": ["поигрывав"],
    "поизветшав": ["поизветшавши"],
    "поизветшавши": ["поизветшав"],
    "поиздержав": ["поиздержавши"],
    "поиздержавши": ["поиздержав"],
    "поизломав": ["поизломавши"],
    "поизломавши": ["поизломав"],
    "поизменив": ["поизменивши"],
    "поизменивши": ["поизменив"],
    "поизмотав": ["поизмотавши"],
    "поизмотавши": ["поизмотав"],
    "поизмяв": ["поизмявши"],
    "поизмявши": ["поизмяв"],
    "поизносив": ["поизносивши"],
    "поизносивши": ["поизносив"],
    "поизодрав": ["поизодравши"],
    "поизодравши": ["поизодрав"],
    "поизорвав": ["поизорвавши"],
    "поизорвавши": ["поизорвав"],
    "поизорваться": ["поизноситься"],
    "поизрасходовав": ["поизрасходовавши"],
    "поизрасходовавши": ["поизрасходовав"],
    "поизучав": ["поизучавши"],
    "поизучавши": ["поизучав"],
    "поикав": ["поикавши"],
    "поикавши": ["поикав"],
    "поикивав": ["поикивавши"],
    "поикивавши": ["поикивав"],
    "поилец-кормилец": ["кормилец-поилец"],
    "поильник": ["поилка"],
    "поимев": ["поимевши"],
    "поимевши": ["поимев"],
    "поименовав": ["поименовавши"],
    "поименовавши": ["поименовав"],
    "поиметь": ["отыметь"],
    "поимистый": ["хваткий"],
    "поимка": ["ловля"],
    "поимщик": ["ловец"],
    "поинт": ["пойнт"],
    "поинтересоваться": ["полюбопытствовать", "спросить", "осведомиться"],
    "поинтриговав": ["поинтриговавши"],
    "поинтриговавши": ["поинтриговав"],
    "поиронизировав": ["поиронизировавши"],
    "поиронизировавши": ["поиронизировав"],
    "поиск": ["розыск", "искание"],
    "поискав": ["поискавши"],
    "поискавши": ["поискав"],
    "поискалечив": ["поискалечивши"],
    "поискалечивши": ["поискалечив"],
    "поискивав": ["поискивавши"],
    "поискивавши": ["поискивав"],
    "поисковая система": ["поисковик"],
    "поисковый": ["разыскной", "разведывательный", "искательский", "разведочный", "исследовательский"],
    "поисповедав": ["поисповедавши"],
    "поисповедавши": ["поисповедав"],
    "поисповедовав": ["поисповедовавши"],
    "поисповедовавши": ["поисповедовав"],
    "поиспортив": ["поиспортивши"],
    "поиспортивши": ["поиспортив"],
    "поисправив": ["поисправивши"],
    "поисправивши": ["поисправив"],
    "поиспытав": ["поиспытавши"],
    "поиспытавши": ["поиспытав"],
    "поиссякнув": ["поиссякнувши"],
    "поиссякнувши": ["поиссякнув"],
    "поистаскав": ["поистаскавши"],
    "поистаскавши": ["поистаскав"],
    "поистерев": ["поистёрши"],
    "поистерив": ["поистеривши"],
    "поистеривши": ["поистерив"],
    "поистине": ["действительно", "подлинно", "воистину", "истинно", "вправду"],
    "поистратив": ["поистративши"],
    "поистративши": ["поистратив"],
    "поистребив": ["поистребивши"],
    "поистребивши": ["поистребив"],
    "поистрепав": ["поистрепавши"],
    "поистрепавши": ["поистрепав"],
    "поистязав": ["поистязавши"],
    "поистязавши": ["поистязав"],
    "поистёрши": ["поистерев"],
    "поисходив": ["поисходивши"],
    "поисходивши": ["поисходив"],
    "поисхудав": ["поисхудавши"],
    "поисхудавши": ["поисхудав"],
    "поишачив": ["поишачивши"],
    "поишачивши": ["поишачив"],
    "пой": ["по"],
    "пойкилотермный": ["холоднокровный", "эктотермный"],
    "пойло": ["помои", "бухло"],
    "поймав": ["поймавши"],
    "поймавши": ["поймав"],
    "поймать": ["схватить", "уловить", "задержать", "захватить", "изловить", "остановить", "застать", "встретить", "повидать", "воспринять", "зафиксировать", "уличить", "изобличить", "застигнуть", "врасплох"],
    "поймать белочку": ["допиться до чёртиков"],
    "поймать за руку": ["застукать", "застать", "разоблачить", "спалить"],
    "поймать удачу за хвост": ["вытянуть счастливый билет"],
    "пойменный": ["поёмный"],
    "пойна": ["пэна", "гарпия", "дракон"],
    "пойнт": ["колорпойнт"],
    "пойти": ["двинуться", "зашагать", "начать", "заняться", "давай", "начаться", "сходить", "походить"],
    "пойти в жопу": ["пойти на фиг", "пойти к чёрту"],
    "пойти на лад": ["наладиться"],
    "пойти на попятный": ["отказаться", "отступить", "отступиться"],
    "пойти насмарку": ["пойти прахом"],
    "пойти по пизде": ["сломаться", "испортиться", "по пизде пойти", "гавкнуть пиздой", "пропасть", "исчезнуть", "пойти прахом", "провалиться"],
    "пока": ["до сих пор", "досель", "покамест"],
    "пока жареный петух не клюнет": ["пока жареный петух в жопу не клюнет"],
    "пока не": ["покуда", "покамест", "поколе", "доколе"],
    "пока не родила": ["как сажа бела", "голова пока цела", "дела у прокурора"],
    "пока что": ["пока", "до сих пор", "до сей поры", "до сего времени", "на данный момент"],
    "покадив": ["покадивши"],
    "покадивши": ["покадив"],
    "показ": ["демонстрация", "показывание"],
    "показ мод": ["шоу"],
    "показав": ["показавши"],
    "показавши": ["показав"],
    "показание": ["показ", "показывание"],
    "показанье": ["показание"],
    "показатель": ["данные", "оценка", "индикатор", "индекс", "величина", "степень", "экспонент", "свидетель"],
    "показательная функция": ["экспоненциальная функция", "экспонента"],
    "показательный": ["характерный", "типичный", "экспоненциальный", "показной", "образцовый"],
    "показать": ["продемонстрировать", "указать", "предъявить", "обнаружить", "проявить", "заявить", "дать показания", "припугнуть", "проучить"],
    "показать хуй": ["наебать", "объебать", "хуй показать"],
    "показать хуй огромный": ["показать хуй", "показать огромный хуй", "хуй показать", "хуй огромный показать"],
    "показаться": ["появиться", "возникнуть", "прийти", "обратиться", "померещиться", "привидеться", "почудиться", "понравиться", "приглянуться"],
    "показнив": ["показнивши"],
    "показнивши": ["показнив"],
    "показуха": ["туфта", "очковтирательство"],
    "показушничав": ["показушничавши"],
    "показушничавши": ["показушничав"],
    "показывав": ["показывавши"],
    "показывавши": ["показывав"],
    "показыванье": ["показывание"],
    "показывать": ["демонстрировать", "предъявлять", "выставлять", "указывать", "свидетельствовать"],
    "показываться": ["появляться", "проступать"],
    "покайлив": ["покайливши"],
    "покайливши": ["покайлив"],
    "покайфовав": ["покайфовавши"],
    "покайфовавши": ["покайфовав"],
    "покакав": ["покакавши"],
    "покакавши": ["покакав"],
    "покакать": ["испражниться", "посрать", "опростаться"],
    "покалечив": ["покалечивши"],
    "покалечивши": ["покалечив"],
    "покалечить": ["изувечить"],
    "покалив": ["покаливши"],
    "покаливши": ["покалив"],
    "покалывав": ["покалывавши"],
    "покалывавши": ["покалывав"],
    "покалыванье": ["покалывание"],
    "покалякав": ["покалякавши"],
    "покалякавши": ["покалякав"],
    "покалякать": ["поболтать", "погутарить", "побазарить"],
    "покамест": ["пока что", "до сих пор", "временно", "до поры до времени"],
    "покаместь": ["пока", "покамест", "пока что"],
    "поканителив": ["поканителивши"],
    "поканителивши": ["поканителив"],
    "поканифолив": ["поканифоливши"],
    "поканифоливши": ["поканифолив"],
    "поканючив": ["поканючивши"],
    "поканючивши": ["поканючив"],
    "покапав": ["покапавши"],
    "покапавши": ["покапав"],
    "покапризничав": ["покапризничавши"],
    "покапризничавши": ["покапризничав"],
    "покапчивав": ["покапчивавши"],
    "покапчивавши": ["покапчивав"],
    "покапывав": ["покапывавши"],
    "покапывавши": ["покапывав"],
    "покарав": ["покаравши"],
    "покаравши": ["покарав"],
    "покарать": ["наказать"],
    "покараулив": ["покарауливши"],
    "покарауливши": ["покараулив"],
    "покаркав": ["покаркавши"],
    "покаркавши": ["покаркав"],
    "покаркивав": ["покаркивавши"],
    "покаркивавши": ["покаркивав"],
    "покармливав": ["покармливавши"],
    "покармливавши": ["покармливав"],
    "покарябав": ["покарябавши"],
    "покарябавши": ["покарябав"],
    "покарябать": ["оцарапать"],
    "покаряв": ["круглай", "эчке", "куя"],
    "покасики": ["пока"],
    "покатав": ["покатавши"],
    "покатавши": ["покатав"],
    "покатам": ["упокат"],
    "покатив": ["покативши"],
    "покативши": ["покатив"],
    "покатость": ["пологость"],
    "покатывав": ["покатывавши"],
    "покатывавши": ["покатывав"],
    "покатый": ["пологий", "наклонный"],
    "покачав": ["покачавши"],
    "покачавши": ["покачав"],
    "покачать": ["поколебать", "поколыхать"],
    "покачивав": ["покачивавши"],
    "покачивавши": ["покачивав"],
    "покачиванье": ["покачивание"],
    "покачнув": ["покачнувши"],
    "покачнувши": ["покачнув"],
    "покашивав": ["покашивавши"],
    "покашивавши": ["покашивав"],
    "покашливав": ["покашливавши"],
    "покашливавши": ["покашливав"],
    "покашливанье": ["покашливание"],
    "покашляв": ["покашлявши"],
    "покашлявши": ["покашляв"],
    "покаяние": ["раскаяние"],
    "поквакивав": ["поквакивавши"],
    "поквакивавши": ["поквакивав"],
    "поквара": ["безнравственост", "разпуснатост"],
    "поквартально": ["ежеквартально"],
    "покеда": ["пока", "покедова", "покель", "покелева", "покелича", "поколе"],
    "покейфовав": ["покейфовавши"],
    "покейфовавши": ["покейфовав"],
    "покемарив": ["покемаривши"],
    "покемаривши": ["покемарив"],
    "покемарить": ["поспать"],
    "покемон": ["покэмон"],
    "покер": ["каре"],
    "покер-рум": ["покеррум"],
    "покеррум": ["покер-рум"],
    "покивав": ["покивавши"],
    "покивавши": ["покивав"],
    "покидав": ["покидавши"],
    "покидавши": ["покидав"],
    "покидание": ["оставление"],
    "покидать": ["оставлять", "бросать"],
    "покидающий": ["оставляющий"],
    "покидывав": ["покидывавши"],
    "покидывавши": ["покидывав"],
    "покидь": ["покидьки"],
    "покинув": ["покинувши"],
    "покинувши": ["покинув"],
    "покинуть": ["бросить", "оставить", "уйти"],
    "покипев": ["покипевши"],
    "покипевши": ["покипев"],
    "покипятив": ["покипятивши"],
    "покипятивши": ["покипятив"],
    "поклав": ["положив"],
    "поклавши": ["положив", "положивши", "поклав"],
    "поклавший": ["положивший"],
    "покладав": ["покладавши"],
    "покладавши": ["покладав"],
    "покладистость": ["сговорчивость"],
    "покладистый": ["сговорчивый", "уступчивый"],
    "покладывав": ["покладывавши"],
    "покладывавши": ["покладывав"],
    "поклажа": ["груз", "багаж", "кладь", "ноша", "клад", "сокровище"],
    "покласть": ["положить"],
    "поклацывав": ["поклацывавши"],
    "поклацывавши": ["поклацывав"],
    "поклевав": ["поклевавши"],
    "поклевавши": ["поклевав"],
    "поклеветав": ["поклеветавши"],
    "поклеветавши": ["поклеветав"],
    "поклеив": ["поклеивши"],
    "поклеивши": ["поклеив"],
    "поклеп": ["наклеп"],
    "поклепав": ["поклепавши"],
    "поклепавши": ["поклепав"],
    "покликав": ["покликавши"],
    "покликавши": ["покликав"],
    "покликивав": ["покликивавши"],
    "покликивавши": ["покликивав"],
    "поклоненье": ["поклонение"],
    "поклонив": ["поклонивши"],
    "поклонивши": ["поклонив"],
    "поклониться": ["почтить", "преклониться"],
    "поклоняв": ["поклонявши"],
    "поклонявши": ["поклоняв"],
    "поклянчив": ["поклянчивши"],
    "поклянчивши": ["поклянчив"],
    "покляузничав": ["покляузничавши"],
    "покляузничавши": ["покляузничав"],
    "поклёвка": ["клёв", "поклёвывание"],
    "поклёвывав": ["поклёвывавши"],
    "поклёвывавши": ["поклёвывав"],
    "поклёп": ["клевета", "напраслина", "навет", "наговор", "наушничание", "наушничество", "оговор"],
    "покняжив": ["покняживши"],
    "покняживши": ["покняжив"],
    "поковав": ["поковавши"],
    "поковавши": ["поковав"],
    "поковеркав": ["поковеркавши"],
    "поковеркавши": ["поковеркав"],
    "поковка": ["ковка"],
    "поковыляв": ["поковылявши"],
    "поковылявши": ["поковыляв"],
    "поковыривав": ["поковыривавши"],
    "поковыривавши": ["поковыривав"],
    "поковыряв": ["поковырявши"],
    "поковырявши": ["поковыряв"],
    "покодема": ["трудендама"],
    "покозлив": ["покозливши"],
    "покозливши": ["покозлив"],
    "покоив": ["покоивши"],
    "покоивши": ["покоив"],
    "покой": ["неподвижность", "тишина", "безмятежность", "бесстрастность", "спокойствие", "умиротворённость", "гибернация"],
    "покойная": ["покойница", "упокойница", "усопшая", "почившая"],
    "покойник": ["мертвец", "упокойник", "умерший", "покойный", "усопший", "почивший", "опочивший"],
    "покойница": ["покойная", "упокойница", "почившая", "умершая", "усопшая", "мёртвая"],
    "покойницкая": ["морг", "мертвецкая", "трупарня"],
    "покойничек": ["покойник", "мертвец"],
    "покойный": ["покойник", "мёртвый", "усопший", "мертвец", "умерший", "преставшийся", "почивший в бозе", "почивший", "спокойный", "удобный"],
    "пококав": ["пококавши"],
    "пококавши": ["пококав"],
    "пококетничав": ["пококетничавши"],
    "пококетничавши": ["пококетничав"],
    "поколачивав": ["поколачивавши"],
    "поколачивавши": ["поколачивав"],
    "поколдовав": ["поколдовавши"],
    "поколдовавши": ["поколдовав"],
    "поколе": ["пока", "до тех пор пока", "покуда", "пока не"],
    "поколебав": ["поколебавши"],
    "поколебавши": ["поколебав"],
    "поколебаться": ["покачнуться", "шевельнуться"],
    "поколев": ["поколевши"],
    "поколевав": ["поколевавши"],
    "поколевавши": ["поколевав"],
    "поколевши": ["поколев"],
    "поколенка": ["миди-юбка", "миди", "речушка", "речка", "ручей"],
    "поколенье": ["поколение"],
    "поколесив": ["поколесивши"],
    "поколесивши": ["поколесив"],
    "поколеть": ["сдохнуть", "околеть"],
    "поколобродив": ["поколобродивши"],
    "поколобродивши": ["поколобродив"],
    "поколов": ["поколовши"],
    "поколовши": ["поколов"],
    "поколотив": ["поколотивши"],
    "поколотивши": ["поколотив"],
    "поколупав": ["поколупавши"],
    "поколупавши": ["поколупав"],
    "поколупывав": ["поколупывавши"],
    "поколупывавши": ["поколупывав"],
    "поколыхав": ["поколыхавши"],
    "поколыхавши": ["поколыхав"],
    "поколыхивав": ["поколыхивавши"],
    "поколыхивавши": ["поколыхивав"],
    "покомандовав": ["покомандовавши"],
    "покомандовавши": ["покомандовав"],
    "покомиссарив": ["покомиссаривши"],
    "покомиссаривши": ["покомиссарив"],
    "покомкав": ["покомкавши"],
    "покомкавши": ["покомкав"],
    "поконопатив": ["поконопативши"],
    "поконопативши": ["поконопатив"],
    "поконфиденциальничав": ["поконфиденциальничавши"],
    "поконфиденциальничавши": ["поконфиденциальничав"],
    "поконфиденциальничать": ["посекретничать", "посплетничать"],
    "покончав": ["покончавши"],
    "покончавши": ["покончав"],
    "покончив": ["покончивши"],
    "покончивши": ["покончив"],
    "покончить": ["разделаться"],
    "покончить с собой": ["наложить на себя руки", "свести счёты с жизнью", "покончить жизнь самоубийством", "самоубиться", "суициднуться"],
    "покопав": ["покопавши"],
    "покопавши": ["покопав"],
    "покопаться": ["порыться"],
    "покопив": ["покопивши"],
    "покопивши": ["покопив"],
    "покоптев": ["покоптевши"],
    "покоптевши": ["покоптев"],
    "покоптив": ["покоптивши"],
    "покоптивши": ["покоптив"],
    "покора": ["покорность"],
    "покорежив": ["покореживши"],
    "покореживши": ["покорежив"],
    "покорение": ["подчинение", "завоевание"],
    "покоренье": ["покорение"],
    "покорив": ["покоривши"],
    "покоривши": ["покорив"],
    "покорить": ["подчинить", "завоевать"],
    "покоричневев": ["покоричневевши"],
    "покоричневевши": ["покоричневев"],
    "покоричневеть": ["побуреть", "забуреть"],
    "покормив": ["покормивши"],
    "покормивши": ["покормив"],
    "покорнейше": ["чувствительнейше"],
    "покорно": ["послушно"],
    "покорность": ["покорство"],
    "покорный": ["послушный"],
    "покоробив": ["покоробивши"],
    "покоробивши": ["покоробив"],
    "покоробить": ["искорёжить", "перекорёжить"],
    "покорпев": ["покорпевши"],
    "покорпевши": ["покорпев"],
    "покорствовав": ["покорствовавши"],
    "покорствовавши": ["покорствовав"],
    "покоряв": ["покорявши"],
    "покорявши": ["покоряв"],
    "покоряти": ["завоювати"],
    "покорять": ["завоевывать", "подчинять", "побеждать", "очаровывать", "пленять"],
    "покорёжив": ["покорёживши"],
    "покорёживав": ["покорёживавши"],
    "покорёживавши": ["покорёживав"],
    "покорёживши": ["покорёжив"],
    "покос": ["косьба", "кошение"],
    "покосив": ["покосивши"],
    "покосивши": ["покосив"],
    "покостыляв": ["покостылявши"],
    "покостылявши": ["покостыляв"],
    "покофейничав": ["покофейничавши"],
    "покофейничавши": ["покофейничав"],
    "покоцав": ["покоцавши"],
    "покоцавши": ["покоцав"],
    "покоцанный": ["испорченный", "побитый", "повреждённый", "попорченный", "разбитый"],
    "покоцать": ["повредить", "попортить", "пококать", "кокнуть", "покромсать"],
    "покочевав": ["покочевавши"],
    "покочевавши": ["покочевав"],
    "покощунствовав": ["покощунствовавши"],
    "покощунствовавши": ["покощунствовав"],
    "покоящийся": ["неподвижный"],
    "покрамольничав": ["покрамольничавши"],
    "покрамольничавши": ["покрамольничав"],
    "покрапав": ["покрапавши"],
    "покрапавши": ["покрапав"],
    "покрапывав": ["покрапывавши"],
    "покрапывавши": ["покрапывав"],
    "покрасив": ["покрасивши"],
    "покрасивев": ["покрасивевши"],
    "покрасивевши": ["покрасивев"],
    "покрасивши": ["покрасив"],
    "покраска": ["окраска", "выкраска", "краска"],
    "покраснев": ["покрасневши"],
    "покрасневши": ["покраснев"],
    "покраснеть": ["зарумяниться", "порозоветь", "побагроветь", "запунцоветь", "зардеться", "заалеть"],
    "покрахмалив": ["покрахмаливши"],
    "покрахмаливши": ["покрахмалив"],
    "покреативив": ["покреатививши"],
    "покреатививши": ["покреативив"],
    "покрепчав": ["покрепчавши"],
    "покрепчавши": ["покрепчав"],
    "покрестив": ["покрестивши"],
    "покрестивши": ["покрестив"],
    "покрестить": ["окрестить"],
    "покривев": ["покривевши"],
    "покривевши": ["покривев"],
    "покривив": ["покрививши"],
    "покрививши": ["покривив"],
    "покривляв": ["покривлявши"],
    "покривлявши": ["покривляв"],
    "покрикивав": ["покрикивавши"],
    "покрикивавши": ["покрикивав"],
    "покрикиванье": ["покрикивание"],
    "покрикивать": ["вскрикивать"],
    "покритиковав": ["покритиковавши"],
    "покритиковавши": ["покритиковав"],
    "покричав": ["покричавши"],
    "покричавши": ["покричав"],
    "покровитель": ["протежёр", "споспешествователь", "патрон", "опекун", "попечитель"],
    "покровительница": ["заступница", "защитница"],
    "покровительство": ["опека", "протежирование"],
    "покровительствовав": ["покровительствовавши"],
    "покровительствовавши": ["покровительствовав"],
    "покровительствовать": ["протежировать"],
    "покровск": ["энгельс", "покровская слобода"],
    "покроив": ["покроивши"],
    "покроивши": ["покроив"],
    "покрой": ["фасон", "склад", "характер"],
    "покромсав": ["покромсавши"],
    "покромсавши": ["покромсав"],
    "покропив": ["покропивши"],
    "покропивши": ["покропив"],
    "покрошив": ["покрошивши"],
    "покрошивши": ["покрошив"],
    "покрошить": ["накрошить"],
    "покруглев": ["покруглевши"],
    "покруглевши": ["покруглев"],
    "покружив": ["покруживши"],
    "покруживши": ["покружив"],
    "покрупнев": ["покрупневши"],
    "покрупневши": ["покрупнев"],
    "покрутив": ["покрутивши"],
    "покрутивши": ["покрутив"],
    "покручивав": ["покручивавши"],
    "покручивавши": ["покручивав"],
    "покручинив": ["покручинивши"],
    "покручинивши": ["покручинив"],
    "покрушив": ["покрушивши"],
    "покрушивши": ["покрушив"],
    "покрыв": ["покрывши"],
    "покрывав": ["покрывавши"],
    "покрывавши": ["покрывав"],
    "покрывать": ["крыть", "накрывать", "охватывать", "перекрывать", "заглушать", "возмещать", "спасать", "преодолевать", "делать"],
    "покрываться": ["накрываться"],
    "покрывной": ["покровный"],
    "покрывши": ["покрыв"],
    "покрытие": ["сокрытие", "утаивание", "оболочка", "охват"],
    "покрытосеменной": ["покрытосемянный", "цветковый"],
    "покрытосемянный": ["покрытосеменной", "цветковый"],
    "покрыть": ["прикрыть", "накрыть", "усеять", "заполонить", "заполнить", "охватить", "выплатить", "погасить", "возместить"],
    "покрытье": ["покрытие"],
    "покрыться": ["укрыться", "накрыться", "усеяться", "заполниться", "покрыть себя", "оправдаться", "окупиться"],
    "покрышка": ["шина", "покрывало"],
    "покрякав": ["покрякавши"],
    "покрякавши": ["покрякав"],
    "покрякивав": ["покрякивавши"],
    "покрякивавши": ["покрякивав"],
    "покрякиванье": ["покрякивание"],
    "покряхтев": ["покряхтевши"],
    "покряхтевши": ["покряхтев"],
    "покряхтывав": ["покряхтывавши"],
    "покряхтывавши": ["покряхтывав"],
    "покряхтыванье": ["покряхтывание"],
    "покряхтывать": ["покрёхтывать"],
    "покрёхтывав": ["покрёхтывавши"],
    "покрёхтывавши": ["покрёхтывав"],
    "покрёхтывать": ["покряхтывать"],
    "поксвирус": ["вирус оспы"],
    "покувыркав": ["покувыркавши"],
    "покувыркавши": ["покувыркав"],
    "покуда": ["пока", "доколе"],
    "покудахтав": ["покудахтавши"],
    "покудахтавши": ["покудахтав"],
    "покудова": ["пока", "покуда"],
    "покуковав": ["покуковавши"],
    "покуковавши": ["покуковав"],
    "покумекав": ["покумекавши"],
    "покумекавши": ["покумекав"],
    "покумекать": ["подумать", "поразмыслить", "поразмышлять", "померекать"],
    "покумекивав": ["покумекивавши"],
    "покумекивавши": ["покумекивав"],
    "покупав": ["покупавши"],
    "покупавши": ["покупав"],
    "покупание": ["покупка"],
    "покупатель": ["приобретатель", "клиент", "покупщик", "купец", "покупашка"],
    "покупать": ["выменивать"],
    "покупаться": ["раскупаться", "расходиться", "приобретаться"],
    "покупашка": ["покупатель", "покупательница"],
    "покупив": ["покупивши"],
    "покупивши": ["покупив"],
    "покупка": ["купля", "покупание", "приобретение"],
    "покупной": ["покупаемый", "приобретаемый", "закупаемый", "купленный"],
    "покупщик": ["покупатель", "купец"],
    "покупывав": ["покупывавши"],
    "покупывавши": ["покупывав"],
    "покуражив": ["покураживши"],
    "покураживши": ["покуражив"],
    "покуражить": ["приободрить", "подбодрить", "ободрить", "вселить бодрость", "вселить уверенность", "поднять дух", "придать бодрости", "придать сил", "придать уверенности"],
    "покурив": ["покуривши"],
    "покуривав": ["покуривавши"],
    "покуривавши": ["покуривав"],
    "покуривши": ["покурив"],
    "покурлыкав": ["покурлыкавши"],
    "покурлыкавши": ["покурлыкав"],
    "покуролесив": ["покуролесивши"],
    "покуролесивши": ["покуролесив"],
    "покусав": ["покусавши"],
    "покусавши": ["покусав"],
    "покуситься": ["попытаться", "посягнуть", "замахнуться"],
    "покусывав": ["покусывавши"],
    "покусывавши": ["покусывав"],
    "покутив": ["покутивши"],
    "покутивши": ["покутив"],
    "покутить": ["погулять", "попировать"],
    "покучивав": ["покучивавши"],
    "покучивавши": ["покучивав"],
    "покушав": ["покушавши"],
    "покушавши": ["покушав"],
    "покушать": ["поесть"],
    "покушаться": ["пытаться", "посягать", "замахиваться"],
    "покушение": ["покушенье"],
    "покшеньга": ["покшенга"],
    "покъщнина": ["мебели", "движимости", "мебелировка"],
    "покэмон": ["покемон"],
    "пол-": ["полу-"],
    "пол-лимона": ["полмиллиона"],
    "пол-литра": ["поллитровка", "поллитра"],
    "пол-одиннадцатого": ["десять тридцать", "десять с половиной", "десять с полтиной"],
    "полавировав": ["полавировавши"],
    "полавировавши": ["полавировав"],
    "полагав": ["полагавши"],
    "полагавши": ["полагав"],
    "полагать": ["класть", "определять", "прилагать", "затрачивать"],
    "полагаться": ["надеяться", "доверяться", "причитаться", "долженствовать", "следовать", "приниматься"],
    "поладив": ["поладивши"],
    "поладивши": ["поладив"],
    "поладить": ["ужиться", "договориться", "условиться"],
    "полазав": ["полазавши"],
    "полазавши": ["полазав"],
    "полазив": ["полазивши"],
    "полазивши": ["полазив"],
    "полазоревев": ["полазоревевши"],
    "полазоревевши": ["полазоревев"],
    "полаивав": ["полаивавши"],
    "полаивавши": ["полаивав"],
    "полайкав": ["полайкавши"],
    "полайкавши": ["полайкав"],
    "полакав": ["полакавши"],
    "полакавши": ["полакав"],
    "полакировав": ["полакировавши"],
    "полакировавши": ["полакировав"],
    "полакомив": ["полакомивши"],
    "полакомивши": ["полакомив"],
    "поламывав": ["поламывавши"],
    "поламывавши": ["поламывав"],
    "полапав": ["полапавши"],
    "полапавши": ["полапав"],
    "поласкав": ["поласкавши"],
    "поласкавши": ["поласкав"],
    "поласкаться": ["помиловаться"],
    "полатав": ["полатавши"],
    "полатавши": ["полатав"],
    "полачить": ["залакировать"],
    "полая вода": ["паводок", "половодье", "высокая вода", "разлив"],
    "полаяв": ["полаявши"],
    "полаявши": ["полаяв"],
    "полба": ["спельта", "эммер"],
    "полбеды": ["полгоря"],
    "полбяной": ["полбенный"],
    "полвека": ["полстолетия", "пятьдесят лет"],
    "полгав": ["полгавши"],
    "полгавши": ["полгав"],
    "полгода": ["полугодие"],
    "полгоря": ["полбеды"],
    "полдень": ["юг"],
    "полдневав": ["полдневавши"],
    "полдневавши": ["полдневав"],
    "полдневный": ["полуденный"],
    "полдничав": ["полдничавши"],
    "полдничавши": ["полдничав"],
    "полдороги": ["полпути"],
    "полдюжины": ["шестёрка"],
    "полебезив": ["полебезивши"],
    "полебезивши": ["полебезив"],
    "полевав": ["полевавши"],
    "полевавши": ["полевав"],
    "полевев": ["полевевши"],
    "полевевши": ["полевев"],
    "полевик": ["полевой"],
    "полевой": ["боевой", "походный", "реальный"],
    "полевошпатный": ["полевошпатовый"],
    "полевошпатовый": ["полевошпатный"],
    "полегав": ["полегавши"],
    "полегавши": ["полегав"],
    "полегать": ["ложиться"],
    "полегчав": ["полегчавши"],
    "полегчавши": ["полегчав"],
    "полегчив": ["полегчивши"],
    "полегчивши": ["полегчив"],
    "поледенев": ["поледеневши"],
    "поледеневши": ["поледенев"],
    "поледенеть": ["похолодеть"],
    "полежав": ["полежавши"],
    "полежавши": ["полежав"],
    "полежать": ["поваляться"],
    "полезав": ["полезавши"],
    "полезавши": ["полезав"],
    "полезность": ["нужность", "польза", "выгодность"],
    "полезный": ["благотворный", "пригодный"],
    "полелеяв": ["полелеявши"],
    "полелеявши": ["полелеяв"],
    "полемизировав": ["полемизировавши"],
    "полемизировавши": ["полемизировав"],
    "полемизировать": ["спорить"],
    "полемика": ["дебаты", "дискуссия", "диспут", "прения"],
    "поленика": ["княженика", "мамура"],
    "поленница": ["костёр"],
    "полено": ["полешко", "чурка", "чурбан", "бревно", "хвост"],
    "полентяйничав": ["полентяйничавши"],
    "полентяйничавши": ["полентяйничав"],
    "поленце": ["полешко"],
    "полепетав": ["полепетавши"],
    "полепетавши": ["полепетав"],
    "полепив": ["полепивши"],
    "полепивши": ["полепив"],
    "полепливав": ["полепливавши"],
    "полепливавши": ["полепливав"],
    "полесник": ["охотник"],
    "полесовав": ["полесовавши"],
    "полесовавши": ["полесовав"],
    "полесовщик": ["лесник", "лесничий", "лесовщик"],
    "полетав": ["полетавши"],
    "полетавши": ["полетав"],
    "полетев": ["полетевши"],
    "полетевши": ["полетев"],
    "полеха": ["полещук"],
    "полечив": ["полечивши"],
    "полечивав": ["полечивавши"],
    "полечивавши": ["полечивав"],
    "полечивши": ["полечив"],
    "полешко": ["поленце"],
    "полещук": ["полеха"],
    "ползав": ["ползавши"],
    "ползавши": ["ползав"],
    "ползанье": ["ползание"],
    "ползти": ["передвигаться ползком"],
    "ползть": ["ползти"],
    "ползунки": ["полукомбинезон"],
    "поли-": ["много-"],
    "полиамория": ["немоногамия", "полигамия"],
    "полиандрия": ["многомужие"],
    "полиберальничав": ["полиберальничавши"],
    "полиберальничавши": ["полиберальничав"],
    "полив": ["поливание", "поливка", "орошение"],
    "поливав": ["поливавши"],
    "поливавши": ["поливав"],
    "поливаемый": ["орошаемый"],
    "поливалентность": ["многовалентность"],
    "поливалентный": ["многовалентный", "многоцелевой"],
    "поливалка": ["разбрызгиватель", "ороситель"],
    "поливанный": ["поливной", "поливенный", "поливный"],
    "поливатель": ["поливальщик", "поливщик"],
    "поливать": ["обливать", "орошать"],
    "поливенный": ["поливной", "поливанный", "поливный"],
    "поливинилхлорид": ["полихлорвинил", "пвх"],
    "поливка": ["полив"],
    "поливной": ["поливаемый"],
    "поливный": ["поливенный"],
    "поливши": ["полив"],
    "полигамический": ["многобрачный"],
    "полигамия": ["многобрачие", "многожёнство"],
    "полигамный": ["многобрачный"],
    "полигенез": ["полигенезис"],
    "полигенезис": ["полигенез"],
    "полигимния": ["полимния"],
    "полигиния": ["многожёнство"],
    "полигландулярный": ["плюригландулярный", "многожелезистый"],
    "полиглоссия": ["полилингвизм", "мультилингвизм", "многоязычие"],
    "полигональная сетка": ["меш", "полимеш"],
    "полиграфический": ["типографский"],
    "полидактилия": ["гипердактилия", "многопалость"],
    "полиен": ["полиэн"],
    "полизав": ["полизавши"],
    "полизавши": ["полизав"],
    "полизывав": ["полизывавши"],
    "полизывавши": ["полизывав"],
    "поликарбонат": ["полимерная пластмасса"],
    "поликлиника": ["полуклиника"],
    "поликовав": ["поликовавши"],
    "поликовавши": ["поликовав"],
    "поликонфессиональность": ["многоконфессиональность", "мультиконфессиональность"],
    "полилингв": ["мультилингв", "полиглот"],
    "полилингвизм": ["многоязычие", "мультилингвизм"],
    "полиловев": ["полиловевши"],
    "полиловевши": ["полиловев"],
    "полимастия": ["многогрудость"],
    "полимат": ["мультипотенциал", "эрудит"],
    "полимеразная цепная реакция": ["пцр"],
    "полимербетон": ["пластбетон"],
    "полимеризовав": ["полимеризовавши"],
    "полимеризовавши": ["полимеризовав"],
    "полимерная молекула": ["макромолекула"],
    "полимерный компаунд": ["компаунд"],
    "полиметилен": ["циклоалкан"],
    "полимеш": ["меш", "полигональная сетка"],
    "полимино": ["полиомино"],
    "полиморфный": ["полиморфический"],
    "полин": ["полинь"],
    "полина": ["поля", "полечка", "полиночка", "полинка", "полька"],
    "полиневав": ["полиневавши"],
    "полиневавши": ["полиневав"],
    "полиневропатия": ["полинейропатия"],
    "полинейропатия": ["полирадикулонейропатия", "полиневропатия"],
    "полиновав": ["полиновавши"],
    "полиновавши": ["полиновав"],
    "полиновать": ["полиневать"],
    "полином": ["многочлен"],
    "полиномиальный": ["полиномный", "многочленный"],
    "полиномный": ["полиномиальный"],
    "полиняв": ["полинявши"],
    "полинявши": ["полиняв"],
    "полинялый": ["линялый", "полинявший"],
    "полинять": ["выцвести"],
    "полиокись": ["полиоксид"],
    "полиоксид": ["полиокись"],
    "полионим": ["многоименный"],
    "полионимия": ["многоимённость"],
    "полиорганосилоксан": ["силикон"],
    "полипептид": ["белок"],
    "полиплан": ["многоплан"],
    "полипноэ": ["тахипноэ"],
    "полипообразный": ["полиповидный"],
    "полипрагмазия": ["полифармация"],
    "полипропилен": ["пп"],
    "полипропиленовый": ["пропиленовый"],
    "полировав": ["полировавши"],
    "полировавши": ["полировав"],
    "полировальный": ["сглаживание"],
    "полирование": ["полировка", "лощение"],
    "полированный": ["отполированный"],
    "полисахарид": ["гликан"],
    "полисемантический": ["многозначный", "полисемантичный", "полисемичный"],
    "полисемантичный": ["многозначный", "полисемантический", "полисемичный"],
    "полисемичность": ["полисемия"],
    "полисемичный": ["многозначный", "полисемантический", "полисемантичный"],
    "полисемия": ["многозначность", "полисемичность", "неоднозначность"],
    "полисиллабический": ["многосложный"],
    "полисилоксан": ["силикон"],
    "полисилоксановый": ["силиконовый"],
    "полисиндетон": ["многосоюзие"],
    "полисмен": ["полицейский", "коп", "мент"],
    "полисоматия": ["миксоплоидия"],
    "полисоним": ["астионим"],
    "полистав": ["полиставши"],
    "полиставши": ["полистав"],
    "полистироловый": ["полистирольный"],
    "полистирольный": ["полистироловый"],
    "политань": ["наполитань"],
    "политбюро": ["политическое бюро"],
    "политеизм": ["многобожие"],
    "политеист": ["многобожник", "язычник"],
    "политеистичный": ["политеистический"],
    "политеистка": ["язычница"],
    "политеистский": ["политеистичный", "многобожный"],
    "политен": ["политех"],
    "политес": ["вежливость", "учтивость", "этикет"],
    "политесса": ["политиканша", "политикесса"],
    "политетрафторэтилен": ["птфэ"],
    "политех": ["политен"],
    "политехнизировав": ["политехнизировавши"],
    "политехнизировавши": ["политехнизировав"],
    "политзаключённый": ["политический заключённый"],
    "политизировав": ["политизировавши"],
    "политизировавши": ["политизировав"],
    "политик": ["политический деятель", "тактик", "дипломат"],
    "политиканив": ["политиканивши"],
    "политиканивши": ["политиканив"],
    "политиканствовав": ["политиканствовавши"],
    "политиканствовавши": ["политиканствовав"],
    "политиканша": ["политесса", "политикесса"],
    "политикесса": ["политесса", "политиканша"],
    "политиковав": ["политиковавши"],
    "политиковавши": ["политиковав"],
    "политикум": ["политбомонд"],
    "политипический": ["многотипный", "политипичный"],
    "политическая": ["политическая заключённая", "политзаключённая"],
    "политическая кликуша": ["политикан"],
    "политическая корректность": ["политкорректность"],
    "политическая партия": ["партия", "политпартия"],
    "политическая экономия": ["политэкономия"],
    "политический заключённый": ["политзаключённый", "политический"],
    "политический труп": ["аутсайдер", "труп"],
    "политический украинец": ["политукраинец", "политукр", "политхохол", "украинствующий"],
    "политическое клише": ["идеологическое клише", "пропагандистское клише"],
    "политическое убежище": ["политубежище"],
    "политично": ["тактично", "предусмотрительно", "дипломатично", "вежливо", "обходительно"],
    "политичность": ["дипломатичность"],
    "политкаторжанин": ["политкаторжанка"],
    "политкаторжанка": ["политкаторжанин"],
    "политкорректный": ["политически корректный"],
    "политнекорректный": ["неполиткорректный"],
    "политоринг": ["полиатлон-мониторинг"],
    "политрук": ["комиссар"],
    "политтехнолог": ["политагитатор"],
    "политукр": ["политический украинец", "политукраинец"],
    "политукраинец": ["политический украинец", "политукр", "политхохол"],
    "политэконом": ["политэкономист"],
    "политэкономист": ["политэконом"],
    "политэкономия": ["политическая экономия"],
    "политэмигрант": ["политический эмигрант"],
    "полиурия": ["мочеизнурение"],
    "полифазия": ["логорея"],
    "полифармация": ["полипрагмазия"],
    "полифонизм": ["многозвучность", "многоголосие", "многотонность"],
    "полифония": ["контрапункт", "многоголосие"],
    "полиформальдегид": ["полиацеталь"],
    "полихета": ["многощетинковые черви"],
    "полихлорвинил": ["поливинилхлорид", "пвх"],
    "полихорд": ["звукоряд"],
    "полихроматический": ["многоцветный", "полихромный"],
    "полица": ["присошек"],
    "полицай": ["мент", "мусор"],
    "полицеймейстер": ["полицмейстер"],
    "полицейская": ["милиционерша"],
    "полицемерив": ["полицемеривши"],
    "полицемеривши": ["полицемерив"],
    "полициклический": ["полицикличный"],
    "полиционер": ["полицейский"],
    "полицитемия": ["полицитоз", "эритроцитоз", "эритремия"],
    "полиция": ["милиция"],
    "полицмейстер": ["полицеймейстер"],
    "поличав": ["поличавши"],
    "поличавши": ["поличав"],
    "поличать": ["вменять"],
    "поличба": ["предзнаменование", "знамение"],
    "полиэдр": ["многогранник"],
    "полиэн": ["полиен"],
    "полиэстер": ["полиэтилентерефталат", "лавсан", "терилен", "дакрон"],
    "полиэтиленгликоль": ["макрогол"],
    "полиэтиленполиамин": ["пэпа"],
    "полиэтилентерефталат": ["пэтф"],
    "полиэтиологический": ["многопричинный"],
    "полиэфир": ["полиэстер"],
    "полк": ["воинская часть"],
    "полка": ["койка", "плато"],
    "полкило": ["полкилограмма"],
    "полковник": ["полкаш", "полкан"],
    "полковницкий": ["полковничий", "полковнический"],
    "полковнический": ["полковницкий", "полковничий"],
    "полковничий": ["полковницкий", "полковнический"],
    "полководец": ["военачальник", "командующий"],
    "полкроны": ["полукрона"],
    "полкруга": ["полукруг"],
    "поллак": ["сайда"],
    "поллиноз": ["сезонный аллергический риноконъюнктивит", "сенная лихорадка"],
    "поллитра": ["поллитровка", "пузырь"],
    "поллютант": ["полютант"],
    "полмильона": ["полмиллиона"],
    "полмильярда": ["полмиллиарда"],
    "полминуты": ["половина минуты"],
    "полная жопа": ["жесть", "бардак", "полное ай-ай-ай", "полный привет", "полный атас", "полный вася", "кикоз", "полный кикоз", "пипец", "пиздец"],
    "полная стоимость кредита": ["пск"],
    "полнев": ["полневши"],
    "полневши": ["полнев"],
    "полненький": ["полнёхонький", "пухленький", "толстенький"],
    "полнеть": ["тяжелеть"],
    "полнив": ["полнивши"],
    "полнивши": ["полнив"],
    "полнить": ["наполнять", "пополнять"],
    "полно": ["полностью", "целиком", "исчерпывающе"],
    "полновластье": ["полновластие"],
    "полноводный": ["многоводный"],
    "полногабаритный": ["полноразмерный"],
    "полногранный": ["голоэдрический"],
    "полногрудость": ["грудастость"],
    "полнозвучие": ["полнозвучье"],
    "полнозначный": ["знаменательный"],
    "полнокровие": ["гиперемия"],
    "полнокровье": ["полнокровие"],
    "полнолуние": ["полнолунье"],
    "полнолунье": ["полнолуние"],
    "полнометр": ["полнометражка"],
    "полнометражка": ["полнометр"],
    "полноправие": ["полноправность"],
    "полностью": ["до конца", "без остатка", "целиком", "всецело"],
    "полнота": ["тучность", "округлость", "пышность"],
    "полноте": ["будет"],
    "полнотелость": ["дородность", "упитанность", "полнота"],
    "полноцветный": ["пёстрый"],
    "полночь": ["двенадцать", "полночный", "час", "полнощь", "полуночь", "глубокая", "глухая", "север"],
    "полнощный": ["полночный"],
    "полнощь": ["полночь"],
    "полнощёкий": ["круглощёкий", "пухлощёкий", "толстощёкий", "щекастый"],
    "полный": ["наполненный", "заполненный", "набитый", "увлечённый", "захваченный", "целый", "весь", "законченный", "наивысший", "максимальный", "упитанный", "тучный"],
    "полный пердюмонокль": ["полный горностай и пердюмонокль", "вот такой пердюмонокль с горностаем", "полный пердимонокль", "полный горностай и пердимонокль", "вот такой пердимонокль с горностаем"],
    "полный песец": ["жирный лис", "каюк", "кранты"],
    "полный пиздец": ["ппц", "полный пипец", "пипец", "пиздец", "абздольц", "каюк", "капец", "вешалка", "трындец", "крышка", "кранты", "офигеть", "охренеть"],
    "полный пипец": ["ппц", "пиздец", "пипец", "абздольц", "каюк", "капец", "кабздец", "вешалка", "трындец", "крышка", "кранты", "офигеть", "охренеть"],
    "полный похуист": ["пофигист"],
    "полный товарищ": ["комплиментарий"],
    "полный фарш": ["все дела"],
    "полным-полно": ["полно"],
    "полнёхонький": ["полнёшенький"],
    "полнёхонько": ["полнёшенько"],
    "полнёшенький": ["полнёхонький"],
    "полнёшенько": ["полнёхонько"],
    "полов": ["половши"],
    "полова": ["мякина"],
    "половая клетка": ["гамета"],
    "половец": ["куман", "кипчак"],
    "половив": ["половивши"],
    "половивши": ["половив"],
    "половик": ["дорожка", "циновка"],
    "половинив": ["половинивши"],
    "половинивши": ["половинив"],
    "половинить": ["уполовинивать"],
    "половинка": ["половина"],
    "половник": ["поварёшка", "уполовник", "черпак", "чумичка"],
    "половничав": ["половничавши"],
    "половничавши": ["половничав"],
    "половое влечение": ["либидо", "сексуальное влечение"],
    "половое сношение": ["половой акт", "совокупление", "коитус"],
    "половозрелый": ["полозрелый"],
    "половой демократ": ["импотент"],
    "половой орган": ["гениталии", "писька", "пиписька", "пися"],
    "половосборник": ["половосборщик"],
    "половосборщик": ["половосборник"],
    "половост": ["сексуалност", "сексапил", "чувственост"],
    "половши": ["полов"],
    "половщина": ["сексизм"],
    "половый": ["соломенный", "палевый"],
    "пологий": ["отлогий"],
    "полодырничав": ["полодырничавши"],
    "полодырничавши": ["полодырничав"],
    "положа руку на сердце": ["чистосердечно", "искренне", "откровенно"],
    "положение": ["помещение", "закладка", "местоположение", "место", "координаты", "позиция", "конфигурация", "поза", "ситуация", "обстановка", "условия", "режим", "должность", "статус", "распорядок"],
    "положенный": ["должный", "надлежащий", "подобающий", "полагающийся", "соответствующий"],
    "положив": ["положивши"],
    "положивши": ["положив"],
    "положим": ["допустим", "предположим"],
    "положительно": ["определённо", "окончательно", "одобрительно", "утвердительно", "решительно", "совсем", "конечно", "несомненно"],
    "положительный": ["утвердительный", "количественный"],
    "положительный ион": ["катион"],
    "положить глаз": ["облюбовать"],
    "положить зубы на полку": ["затянуть пояс", "сводить концы с концами"],
    "положить конец": ["прекратить"],
    "положить на месте": ["уложить на месте", "наповал"],
    "положить хуй": ["послать", "положить", "забить болт", "положить болт", "болт забить", "болт положить", "забить хуй", "хуй забить", "хуй положить"],
    "полоз": ["лыжа"],
    "полозный": ["полозной"],
    "полокав": ["полокавши"],
    "полокавши": ["полокав"],
    "полом": ["поломка"],
    "поломав": ["поломавши"],
    "поломавши": ["поломав"],
    "поломка": ["полом", "поломочка"],
    "поломойка": ["уборщица", "техничка"],
    "поломя": ["пламя", "полымя"],
    "полон": ["плен", "добыча", "трофей", "приз"],
    "полонив": ["полонивши"],
    "полонивши": ["полонив"],
    "полонизировав": ["полонизировавши"],
    "полонизировавши": ["полонизировав"],
    "полонизировать": ["ополячивать", "ополячить"],
    "полоний": ["эка-теллур"],
    "полонить": ["пленить", "пленять"],
    "полонофобия": ["полонофобство", "антиполонизм"],
    "полоняв": ["полонявши"],
    "полонявши": ["полоняв"],
    "полонянин": ["полонений"],
    "полопав": ["полопавши"],
    "полопавши": ["полопав"],
    "полопотав": ["полопотавши"],
    "полопотавши": ["полопотав"],
    "полоротой": ["полоротый", "полоротный"],
    "полоротый": ["рассеянный", "невнимательный", "разиня", "дурак", "обормот", "охломон", "охламон", "отетень", "недоделанный"],
    "полоса": ["черта", "линия"],
    "полосанув": ["полосанувши"],
    "полосанувши": ["полосанув"],
    "полосатик": ["кит-полосатик"],
    "полосатое тело": ["стриатум"],
    "полосив": ["полосивши"],
    "полосивши": ["полосив"],
    "полосица": ["чересполосица"],
    "полоскав": ["полоскавши"],
    "полоскавши": ["полоскав"],
    "полоскать": ["болтать"],
    "полоскаться": ["купаться", "плескаться", "виться", "веять", "реять", "трепетать", "развеваться"],
    "полоскун": ["енот-полоскун"],
    "полоснув": ["полоснувши"],
    "полоснувши": ["полоснув"],
    "полоснуть": ["полосануть", "полыснуть"],
    "полосовав": ["полосовавши"],
    "полосовавши": ["полосовав"],
    "полосовой": ["полосной", "однопрокатный"],
    "полосонув": ["полосонувши"],
    "полосонувши": ["полосонув"],
    "полостной": ["внутриполостной"],
    "полотенец": ["полотенце", "ручник", "рукотёрник", "утиральник", "утирник", "полка", "ширинка", "рушник", "блинник", "божник", "накрючник", "наспичник"],
    "полотенечко": ["полотенчико"],
    "полотенце": ["рушник", "ручник", "ширинка", "полотнище"],
    "полотенцесушитель": ["полотенчик"],
    "полотнище": ["полотно"],
    "полотно": ["ткань", "холст", "полотнище", "холстина", "картина", "одежда", "всп", "верхнее строение пути"],
    "полотёнушко": ["полотенечко"],
    "полотёрничав": ["полотёрничавши"],
    "полотёрничавши": ["полотёрничав"],
    "полоумие": ["безрассудность", "безрассудство", "безумие", "безумность", "безумство"],
    "полоумный": ["помешанный", "ненормальный"],
    "полохнув": ["полохнувши"],
    "полохнувши": ["полохнув"],
    "полошив": ["полошивши"],
    "полошивши": ["полошив"],
    "полпенни": ["полпенса"],
    "полпервого": ["половина первого"],
    "полпорция": ["полпорции"],
    "полпредствовав": ["полпредствовавши"],
    "полпредствовавши": ["полпредствовав"],
    "полрубля": ["пятьдесят", "копейка"],
    "полсвета": ["полземли", "полмира"],
    "полсотни": ["пятьдесят", "полста"],
    "полста": ["пятьдесят", "полсотни"],
    "полсть": ["полость", "полстина", "полостья", "полстка"],
    "полтавская область": ["полтавщина"],
    "полтва": ["пелтва"],
    "полтергейст": ["барабашка", "привидение"],
    "полтина": ["полтинник"],
    "полтинник": ["полтина", "полтос"],
    "полтинный": ["пятидесятикопеечный"],
    "полтона": ["полутон"],
    "полтора": ["три вторых", "один с половиной", "один с половиною"],
    "полтора ивана": ["в два с половиной ивана", "в полтора ивана"],
    "полтора человека": ["полторы калеки"],
    "полтораста": ["полторы сотни", "сто пятьдесят"],
    "полтораха": ["полторашка"],
    "полторашка": ["полтораха"],
    "полторы калеки": ["полтора землекопа", "полтора человека", "три калеки"],
    "полтос": ["пятьдесят", "полтинник", "полста"],
    "полтриллиона": ["полтрильона"],
    "полтысячи": ["пятьсот"],
    "полу-": ["семи-", "геми-", "недо-"],
    "полуавтоматизировав": ["полуавтоматизировавши"],
    "полуавтоматизировавши": ["полуавтоматизировав"],
    "полубайт": ["ниббл", "тетрада"],
    "полубольной": ["нездоровый"],
    "полуботинок": ["башмак"],
    "полубрат": ["сиблинг"],
    "полубред": ["чепуха", "ерунда", "бессмыслица"],
    "полубродяжий": ["бродячий"],
    "полуверец": ["сету", "сето", "православный эстонец"],
    "полувечнозелёный": ["полулистопадный"],
    "полугар": ["хмель"],
    "полугаснув": ["полугаснувши"],
    "полугаснувши": ["полугаснув"],
    "полуголодный": ["несытый"],
    "полуголый": ["полуобнажённый", "полунагой", "полураздетый"],
    "полуграмотный": ["малограмотный", "неграмотный"],
    "полуденница": ["хульдра"],
    "полуденный": ["полдневный"],
    "полудив": ["полудивши"],
    "полудивши": ["полудив"],
    "полудка": ["полуда", "лужение"],
    "полудница": ["полуденица", "пилудница", "ржаница"],
    "полудничав": ["полудничавши"],
    "полудничавши": ["полудничав"],
    "полудничать": ["полдничать"],
    "полудновав": ["полудновавши"],
    "полудновавши": ["полудновав"],
    "полудополнение": ["полудуальность"],
    "полудремав": ["полудремавши"],
    "полудремавши": ["полудремав"],
    "полудремота": ["полудрёма"],
    "полудужье": ["полудуга"],
    "полудурье": ["дурак", "дурень", "дурачок", "дебил", "идиот", "кретин", "даун", "имбецил", "балда", "аутист", "дегенерат", "олигофрен", "полудурок", "придурь", "придурок"],
    "полудурья": ["дура", "болванка", "дурёха", "простодырка", "охламонка", "полухвея", "блум", "болван", "тетёха", "баба", "заготовка", "болвашка", "корова", "дурища", "кретинка"],
    "полужесткокрылые": ["членистохоботные"],
    "полуживой": ["полумёртвый"],
    "полужидкий": ["аморфный"],
    "полужильё": ["мезонин"],
    "полужопие": ["полупопие", "полужопица", "задница", "засада", "жопа", "полушарие"],
    "полузабыв": ["полузабывши"],
    "полузабывши": ["полузабыв"],
    "полузабытый": ["полупозабытый"],
    "полузабытьё": ["полусон", "полудрёма"],
    "полузаволочь": ["полузакрыть", "полуприкрыть", "полузатемнить"],
    "полузадушив": ["полузадушивши"],
    "полузадушивши": ["полузадушив"],
    "полузакрыв": ["полузакрывши"],
    "полузакрывав": ["полузакрывавши"],
    "полузакрывавши": ["полузакрывав"],
    "полузакрывши": ["полузакрыв"],
    "полузакрытый": ["полуоткрытый"],
    "полузаносив": ["полузаносивши"],
    "полузаносивши": ["полузаносив"],
    "полузасохнув": ["полузасохнувши"],
    "полузасохнувши": ["полузасохнув"],
    "полузасыпав": ["полузасыпавши"],
    "полузасыпавши": ["полузасыпав"],
    "полузатонув": ["полузатонувши"],
    "полузатонувши": ["полузатонув"],
    "полузатопив": ["полузатопивши"],
    "полузатопивши": ["полузатопив"],
    "полузащитник": ["хавбек", "хав"],
    "полузгивав": ["полузгивавши"],
    "полузгивавши": ["полузгивав"],
    "полузнаменательный": ["полувспомогательный"],
    "полуимя": ["уменьшительное имя"],
    "полуинвариант": ["семиинвариант", "кумулянт"],
    "полуистлев": ["полуистлевши"],
    "полуистлевав": ["полуистлевавши"],
    "полуистлевавши": ["полуистлевав"],
    "полуистлевши": ["полуистлев"],
    "полукафтанье": ["полукафтан"],
    "полуклиника": ["поликлиника"],
    "полукровка": ["гибрид", "помесь", "метис"],
    "полукруг": ["полуокружность"],
    "полукруговой": ["полукруглый"],
    "полукружье": ["полукружие"],
    "полукустарный": ["рукодельный"],
    "полулегальный": ["полунелегальный"],
    "полулежав": ["полулежавши"],
    "полулежавши": ["полулежав"],
    "полулитература": ["паралитература", "псевдолитература", "чтиво"],
    "полулюбитель": ["полупрофессионал"],
    "полумера": ["паллиатив"],
    "полумесяц": ["месяц"],
    "полуметалл": ["металлоид"],
    "полуминутный": ["тридцатисекундный"],
    "полумрак": ["полутьма", "полутемнота", "сумрак"],
    "полумёртвый": ["полуживой", "полудохлый", "полусдохлый", "безжизненный", "мертвенный"],
    "полунаучный": ["малонаучный"],
    "полундра": ["берегись", "атас", "шуба", "шухер"],
    "полунелегальный": ["полулегальный"],
    "полунорма": ["преднорма"],
    "полуночник": ["сова"],
    "полуночничав": ["полуночничавши"],
    "полуночничавши": ["полуночничав"],
    "полуночничать": ["полуношничать", "полунощничать"],
    "полуночный": ["полночный", "полунощный"],
    "полуночь": ["полночь"],
    "полуношничать": ["полуночничать", "полунощничать"],
    "полуношный": ["полуночный", "полунощный"],
    "полунощ": ["среднощ"],
    "полунощничать": ["полуночничать", "полуношничать"],
    "полунощный": ["полуночный", "полуношный"],
    "полуобгорев": ["полуобгоревши"],
    "полуобгоревши": ["полуобгорев"],
    "полуобернуться": ["полуоборотиться"],
    "полуобнажав": ["полуобнажавши"],
    "полуобнажавши": ["полуобнажав"],
    "полуобнажив": ["полуобнаживши"],
    "полуобнаживши": ["полуобнажив"],
    "полуобнимав": ["полуобнимавши"],
    "полуобнимавши": ["полуобнимав"],
    "полуобняв": ["полуобнявши"],
    "полуобнявши": ["полуобняв"],
    "полуобруч": ["полукольцо"],
    "полуодев": ["полуодевши"],
    "полуодевши": ["полуодев"],
    "полуодетый": ["полуголый"],
    "полуопал": ["гидрофан"],
    "полуопускав": ["полуопускавши"],
    "полуопускавши": ["полуопускав"],
    "полуопустив": ["полуопустивши"],
    "полуопустивши": ["полуопустив"],
    "полуосветив": ["полуосветивши"],
    "полуосветивши": ["полуосветив"],
    "полуосвещав": ["полуосвещавши"],
    "полуосвещавши": ["полуосвещав"],
    "полуослепнув": ["полуослепнувши"],
    "полуослепнувши": ["полуослепнув"],
    "полуотворив": ["полуотворивши"],
    "полуотворивши": ["полуотворив"],
    "полуотворяв": ["полуотворявши"],
    "полуотворявши": ["полуотворяв"],
    "полуоткрыв": ["полуоткрывши"],
    "полуоткрывав": ["полуоткрывавши"],
    "полуоткрывавши": ["полуоткрывав"],
    "полуоткрывши": ["полуоткрыв"],
    "полуоткрытый": ["приоткрытый", "полуотворенный", "полуотворённый", "полуполый"],
    "полуоторвав": ["полуоторвавши"],
    "полуоторвавши": ["полуоторвав"],
    "полупалец": ["полутапочка", "получешка"],
    "полупердень": ["полупальто"],
    "полуперчатка": ["митенка"],
    "полупетля": ["иммельман"],
    "полупив": ["полупивши"],
    "полупивши": ["полупив"],
    "полупогаснув": ["полупогаснувши"],
    "полупогаснувши": ["полупогаснув"],
    "полупогружной": ["полуутопленный"],
    "полупокер": ["мажор"],
    "полуполба": ["двузернянка", "эммер"],
    "полупопие": ["полужопица", "полужопие"],
    "полупорожний": ["полупустой"],
    "полупотухнув": ["полупотухнувши"],
    "полупотухнувши": ["полупотухнув"],
    "полуправда": ["полуложь"],
    "полупрезидентский": ["смешанный", "президентско-парламентский", "полупарламентский"],
    "полуприкрыв": ["полуприкрывши"],
    "полуприкрывав": ["полуприкрывавши"],
    "полуприкрывавши": ["полуприкрывав"],
    "полуприкрывши": ["полуприкрыв"],
    "полуприлегающий": ["полуприталенный"],
    "полуприсед": ["полуприседание"],
    "полуприседав": ["полуприседавши"],
    "полуприседавши": ["полуприседав"],
    "полуприталенный": ["полуприлегающий"],
    "полупрофессионал": ["полулюбитель"],
    "полупрямая": ["луч"],
    "полупустой": ["полупорожний"],
    "полупустыня": ["опустыненная степь"],
    "полурабство": ["полузакрепощение"],
    "полуразбив": ["полуразбивши"],
    "полуразбивши": ["полуразбив"],
    "полуразваленный": ["полуразвалившийся", "полуразрушенный"],
    "полуразвалиться": ["рассесться"],
    "полуразрушенный": ["полуразваленный", "полуразвалившийся"],
    "полуразрушив": ["полуразрушивши"],
    "полуразрушивши": ["полуразрушив"],
    "полураскрыв": ["полураскрывши"],
    "полураскрывав": ["полураскрывавши"],
    "полураскрывавши": ["полураскрывав"],
    "полураскрывши": ["полураскрыв"],
    "полурослик": ["хоббит"],
    "полусгнив": ["полусгнивши"],
    "полусгнивши": ["полусгнив"],
    "полусгоревший": ["полусожжённый"],
    "полусерьёзно": ["полушутливо"],
    "полусерьёзный": ["полушутливый"],
    "полусидев": ["полусидевши"],
    "полусидевши": ["полусидев"],
    "полускрыв": ["полускрывши"],
    "полускрывав": ["полускрывавши"],
    "полускрывавши": ["полускрывав"],
    "полускрывши": ["полускрыв"],
    "полуслитный": ["дефисный"],
    "полусогнув": ["полусогнувши"],
    "полусогнувши": ["полусогнув"],
    "полусожжённый": ["полусгоревший"],
    "полусправедливый": ["полуправдивый"],
    "полустерев": ["полустёрши"],
    "полустирав": ["полустиравши"],
    "полустиравши": ["полустирав"],
    "полустишье": ["полустишие"],
    "полустёрши": ["полустерев"],
    "полусфера": ["полушарие"],
    "полусън": ["дрямка", "полудрямка", "просъница"],
    "полутвёрдый": ["полутвердый"],
    "полутон": ["полтона", "оттенок"],
    "полуторагодовой": ["восемнадцатимесячный"],
    "полуторамиллионный": ["полуторамильонный"],
    "полуторатонка": ["полуторка"],
    "полуторная окись": ["трёхокись"],
    "полутруп": ["полумертвец"],
    "полутяж": ["полутяжеловес"],
    "полутяжеловес": ["полутяж"],
    "полуустав": ["полоустав"],
    "полуформальный": ["полуофициальный"],
    "полухвея": ["дурёха", "полудурья", "придурщица", "дура", "придурница", "скудоумка", "болванка", "простодырка", "охламонка"],
    "получа": ["получив", "получивши"],
    "получав": ["получавши"],
    "получавши": ["получав"],
    "получамс": ["сявомс"],
    "получас": ["полчаса"],
    "получатель": ["адресат"],
    "получать": ["принимать", "зарабатывать"],
    "получаться": ["складываться", "выходить", "производиться", "изготовляться", "изготавливаться", "оказываться", "удаваться", "приниматься"],
    "получеловек": ["зверочеловек", "зверолюд", "зверолюдка"],
    "получение": ["взятие", "получка"],
    "полученье": ["получение"],
    "получеть": ["восьмая часть", "восьмушка", "осьмушка", "получетверть"],
    "получив": ["получивши", "получа"],
    "получивши": ["получив"],
    "получить в бубен": ["получить по морде"],
    "получить известность": ["произвести фурор", "заставить о себе говорить", "войти в пословицу", "быть у всех на устах", "прославиться", "иметь успех", "произвести сенсацию", "нашуметь", "наделать шума", "прошуметь", "стать притчей во языцех"],
    "получить крупный хуй": ["получить хуй с маслом", "заработать хуем по спине", "получить хуй", "получить толстым хуем по губе"],
    "получить по шапке": ["по шапке получить"],
    "получить удовлетворение": ["получить сатисфакцию"],
    "получить хрен с маслом": ["получить от хуя уши"],
    "получить хуй": ["получить хуй с маслом", "получить крупный хуй", "получить от хуя уши", "получить от хуя ушки", "заработать хуем по спине"],
    "получиться": ["выйти", "удаться", "сложиться", "произойти", "случиться"],
    "получка": ["получение", "зарплата"],
    "получшав": ["получшавши"],
    "получшавши": ["получшав"],
    "получшать": ["получшеть"],
    "получшев": ["получшевши"],
    "получшевши": ["получшев"],
    "полушалок": ["шаль"],
    "полушарье": ["полушарие"],
    "полушкаф": ["полушкап"],
    "полушубок": ["полушубочек"],
    "полущив": ["полущивши"],
    "полущивав": ["полущивавши"],
    "полущивавши": ["полущивав"],
    "полущивши": ["полущив"],
    "полуют": ["ют"],
    "полуязычие": ["семилингвизм"],
    "полуярус": ["мезонин"],
    "полфунтика": ["полфунта"],
    "полчаса": ["получас"],
    "полчище": ["орда"],
    "полчок": ["соня-полчок"],
    "полый": ["пустой"],
    "полымя": ["огонь", "пламя"],
    "полынья": ["майна", "прорубь", "лунка"],
    "полысев": ["полысевши"],
    "полысевши": ["полысев"],
    "полыснув": ["полыснувши"],
    "полыснувши": ["полыснув"],
    "полыхав": ["полыхавши"],
    "полыхавши": ["полыхав"],
    "полыхание": ["горение"],
    "полыханье": ["полыхание"],
    "полыхать": ["пылать"],
    "полыхнув": ["полыхнувши"],
    "полыхнувши": ["полыхнув"],
    "польза": ["благо", "прок", "толк", "выгода", "нажива", "барыш", "прибыль"],
    "пользительно": ["полезно"],
    "пользовав": ["пользовавши"],
    "пользовавши": ["пользовав"],
    "пользованье": ["пользование"],
    "пользователь": ["эксплуатант", "юзер"],
    "пользовать": ["лечить"],
    "пользоваться": ["задействовать", "использовать", "применять", "употреблять", "прибегать", "эксплуатировать", "утилизировать", "обладать", "лечиться"],
    "пользоваться смутами": ["в мутной воде рыбу ловить"],
    "полька": ["полячка", "пшечка", "ляшка"],
    "полькировав": ["полькировавши"],
    "полькировавши": ["полькировав"],
    "польной воронеж": ["польный воронеж"],
    "польская народная республика": ["пнр", "народная польша", "польская республика"],
    "польский": ["пшековский"],
    "польский язык": ["польский"],
    "польстив": ["польстивши"],
    "польстивши": ["польстив"],
    "польша": ["республика польша", "царство польское", "речь посполитая"],
    "полюбав": ["полюбавши"],
    "полюбавши": ["полюбав"],
    "полюбас": ["всяко", "по-любому", "без вариантов", "однозначно", "точняк"],
    "полюбезничав": ["полюбезничавши"],
    "полюбезничавши": ["полюбезничав"],
    "полюбив": ["полюбивши"],
    "полюбивши": ["полюбив"],
    "полюбовник": ["любовник", "возлюбленный", "сполюбовник"],
    "полюбовница": ["любовница", "возлюбленная"],
    "полюбовно": ["дружески", "мирно", "бесконфликтно"],
    "полюбовность": ["бесконфликтность"],
    "полюбопытничав": ["полюбопытничавши"],
    "полюбопытничавши": ["полюбопытничав"],
    "полюбопытствовав": ["полюбопытствовавши"],
    "полюбопытствовавши": ["полюбопытствовав"],
    "полюднев": ["полюдневши"],
    "полюдневши": ["полюднев"],
    "полюс": ["географический полюс", "геомагнитный полюс"],
    "полютовав": ["полютовавши"],
    "полютовавши": ["полютовав"],
    "полязгав": ["полязгавши"],
    "полязгавши": ["полязгав"],
    "полязгивав": ["полязгивавши"],
    "полязгивавши": ["полязгивав"],
    "поляк": ["лях", "пшек"],
    "поляна": ["прогалина"],
    "поляризовав": ["поляризовавши"],
    "поляризовавши": ["поляризовав"],
    "поляриметр": ["полярископ"],
    "полярка": ["северные", "уральские", "кавэшка", "неёловские"],
    "полярная звезда": ["киносура"],
    "полярная система координат": ["полярные координаты"],
    "полярное сияние": ["полярное сиянье", "северное сияние", "северное сиянье"],
    "полярные координаты": ["полярная система координат"],
    "полярный": ["александровск", "александровск-на-мурмане"],
    "полярный кит": ["гренландский кит"],
    "полячка": ["полька"],
    "полёвка": ["агроцибе"],
    "полёживав": ["полёживавши"],
    "полёживавши": ["полёживав"],
    "полётывав": ["полётывавши"],
    "полётывавши": ["полётывав"],
    "помавав": ["помававши"],
    "помававши": ["помавав"],
    "помадив": ["помадивши"],
    "помадивши": ["помадив"],
    "помазав": ["помазавши"],
    "помазавши": ["помазав"],
    "помазание": ["миропомазание", "елеопомазание"],
    "помазанник": ["мессия"],
    "помазанник божий": ["помазанник господень"],
    "помазанник господень": ["помазанник божий"],
    "помазать": ["намазать"],
    "помазок": ["кисточка", "мазница", "мазок"],
    "помазывав": ["помазывавши"],
    "помазывавши": ["помазывав"],
    "помакав": ["помакавши"],
    "помакавши": ["помакав"],
    "помакивав": ["помакивавши"],
    "помакивавши": ["помакивав"],
    "помакнув": ["помакнувши"],
    "помакнувши": ["помакнув"],
    "помалев": ["помалевши"],
    "помалевав": ["помалевавши"],
    "помалевавши": ["помалевав"],
    "помалевши": ["помалев"],
    "помаленечку": ["помаленьку"],
    "помаленьку": ["понемногу", "полегоньку", "слегонца"],
    "помалиновев": ["помалиновевши"],
    "помалиновевши": ["помалиновев"],
    "помалкивав": ["помалкивавши"],
    "помалкивавши": ["помалкивав"],
    "помалкивание": ["молчание"],
    "помалодушествовав": ["помалодушествовавши"],
    "помалодушествовавши": ["помалодушествовав"],
    "помалчивав": ["помалчивавши"],
    "помалчивавши": ["помалчивав"],
    "помалывав": ["помалывавши"],
    "помалывавши": ["помалывав"],
    "помалёвывав": ["помалёвывавши"],
    "помалёвывавши": ["помалёвывав"],
    "помалёху": ["помаленьку", "понемногу"],
    "помандер": ["флакон"],
    "помандровав": ["помандровавши"],
    "помандровавши": ["помандровав"],
    "поманеврировав": ["поманеврировавши"],
    "поманеврировавши": ["поманеврировав"],
    "поманежив": ["поманеживши"],
    "поманеживши": ["поманежив"],
    "поманив": ["поманивши"],
    "поманивав": ["поманивавши"],
    "поманивавши": ["поманивав"],
    "поманивши": ["поманив"],
    "помарав": ["помаравши"],
    "помаравши": ["помарав"],
    "помараковав": ["помараковавши"],
    "помараковавши": ["помараковав"],
    "помаранча": ["померанець", "помаранч"],
    "помаргивав": ["помаргивавши"],
    "помаргивавши": ["помаргивав"],
    "помарка": ["исправление", "подчистка"],
    "помаршировав": ["помаршировавши"],
    "помаршировавши": ["помаршировав"],
    "помарывав": ["помарывавши"],
    "помарывавши": ["помарывав"],
    "помаслив": ["помасливши"],
    "помасливав": ["помасливавши"],
    "помасливавши": ["помасливав"],
    "помасливши": ["помаслив"],
    "помассажировав": ["помассажировавши"],
    "помассажировавши": ["помассажировав"],
    "помассажировать": ["помассировать"],
    "помассажироваться": ["помассироваться"],
    "помассировав": ["помассировавши"],
    "помассировавши": ["помассировав"],
    "помассировать": ["помассажировать"],
    "помассироваться": ["помассажироваться"],
    "помастерив": ["помастеривши"],
    "помастеривши": ["помастерив"],
    "помастурбировав": ["помастурбировавши"],
    "помастурбировавши": ["помастурбировав"],
    "помастурбировать": ["поонанировать", "подрочить", "погонять лысого"],
    "поматерев": ["поматеревши"],
    "поматеревши": ["поматерев"],
    "поматросив": ["поматросивши"],
    "поматросивши": ["поматросив"],
    "поматросить и бросить": ["поматросить да бросить", "поматросить да и бросить"],
    "поматывав": ["поматывавши"],
    "поматывавши": ["поматывав"],
    "помахав": ["помахавши"],
    "помахавши": ["помахав"],
    "помахивав": ["помахивавши"],
    "помахивавши": ["помахивав"],
    "помахиванье": ["помахивание"],
    "помацав": ["помацавши"],
    "помацавши": ["помацав"],
    "помаяв": ["помаявши"],
    "помаявши": ["помаяв"],
    "помаячив": ["помаячивши"],
    "помаячивши": ["помаячив"],
    "помедитировав": ["помедитировавши"],
    "помедитировавши": ["помедитировав"],
    "помедлив": ["помедливши"],
    "помедливши": ["помедлив"],
    "помежду": ["между"],
    "помекав": ["помекавши"],
    "помекавши": ["помекав"],
    "помелев": ["помелевши"],
    "помелевши": ["помелев"],
    "помелив": ["помеливши"],
    "помеливши": ["помелив"],
    "помело": ["пуммела", "шеддок", "помпельмус"],
    "помелькав": ["помелькавши"],
    "помелькавши": ["помелькав"],
    "помельтешив": ["помельтешивши"],
    "помельтешивши": ["помельтешив"],
    "помельчав": ["помельчавши"],
    "помельчавши": ["помельчав"],
    "помельчив": ["помельчивши"],
    "помельчивши": ["помельчив"],
    "помен": ["спомен", "панихида"],
    "поменьшав": ["поменьшавши"],
    "поменьшавши": ["поменьшав"],
    "поменьше": ["меньший"],
    "поменяв": ["поменявши"],
    "поменявши": ["поменяв"],
    "померанец": ["бигарадия", "горький апельсин", "чинотто", "гесперидий", "севильский апельсин"],
    "померанець": ["помаранча"],
    "померанцевый": ["оранжево-красный"],
    "померев": ["померши"],
    "померекав": ["померекавши"],
    "померекавши": ["померекав"],
    "помереть с голодной смерти": ["умереть голодной смертью"],
    "померещиться": ["почудиться", "показаться"],
    "померзав": ["померзавши"],
    "померзавши": ["померзав"],
    "померив": ["померивши"],
    "померивав": ["померивавши"],
    "померивавши": ["померивав"],
    "померивши": ["померив"],
    "померить": ["примерить", "измерить"],
    "померкав": ["померкавши"],
    "померкавши": ["померкав"],
    "померкнув": ["померкнувши"],
    "померкнувши": ["померкнув"],
    "померлий": ["умерлий"],
    "помертвев": ["помертвевши"],
    "помертвевши": ["помертвев"],
    "померцав": ["померцавши"],
    "померцавши": ["померцав"],
    "померши": ["померев"],
    "померший": ["умерший", "усопший", "покойный", "скончавшийся", "почивший", "опочивший", "преставившийся"],
    "померяв": ["померявши"],
    "померявши": ["померяв"],
    "померять": ["померить"],
    "помесив": ["помесивши"],
    "помесивши": ["помесив"],
    "поместив": ["поместивши"],
    "поместивши": ["поместив"],
    "поместительный": ["просторный"],
    "поместиться": ["вместиться", "уместиться", "водвориться", "расположиться", "разместиться", "поселиться"],
    "поместье": ["имение", "мыза"],
    "помесь": ["гибрид", "бастард", "смесь"],
    "помесь негра с мотоциклом": ["смесь бульдога с носорогом"],
    "помета": ["знак", "надпись", "отметка"],
    "пометав": ["пометавши"],
    "пометавши": ["пометав"],
    "пометив": ["пометивши"],
    "пометивши": ["пометив"],
    "помеха": ["препятствие", "возмущение"],
    "помехозащитный": ["помехоподавляющий"],
    "помечав": ["помечавши"],
    "помечавши": ["помечав"],
    "помечтав": ["помечтавши"],
    "помечтавши": ["помечтав"],
    "помечтать": ["пофантазировать", "погрезить"],
    "помешав": ["помешавши"],
    "помешавши": ["помешав"],
    "помешанная": ["сумасшедшая"],
    "помешательство": ["умопомешательство", "сумасшествие", "безумие"],
    "помешать": ["воспрепятствовать", "стать помехой", "послужить помехой"],
    "помешаться": ["зациклиться"],
    "помешивав": ["помешивавши"],
    "помешивавши": ["помешивав"],
    "помешкав": ["помешкавши"],
    "помешкавши": ["помешкав"],
    "помешчик": ["земевладелец", "чокой", "чокоин"],
    "помещав": ["помещавши"],
    "помещавши": ["помещав"],
    "помещать": ["размещать", "публиковать", "печатать"],
    "помещаться": ["вмещаться", "умещаться", "находиться", "размещаться", "располагаться", "печататься", "публиковаться"],
    "помещение": ["перенос", "размещение", "вкладывание", "помещенье", "пространство"],
    "помещенье": ["помещение"],
    "помещик": ["барин", "латифундист"],
    "помещица": ["барыня"],
    "помещичий": ["помещицкий", "помещиков"],
    "помигав": ["помигавши"],
    "помигавши": ["помигав"],
    "помигивав": ["помигивавши"],
    "помигивавши": ["помигивав"],
    "помидор": ["томат", "амурное яблоко", "помдамур", "помедор", "помадор", "помидорка", "помидорочка", "помидорчик", "помидорина", "помидорище", "баклажка", "цыганка"],
    "помидорина": ["помидор", "помидорка", "помидорчик", "помидорища", "помидорище"],
    "помидорка": ["помидорчик", "помидоринка"],
    "помидорный": ["томатный", "помидоровый"],
    "помидоровый": ["помидорный", "томатный"],
    "помидорчик": ["помидорка"],
    "помилев": ["помилевши"],
    "помилевши": ["помилев"],
    "помиловав": ["помиловавши"],
    "помиловавши": ["помиловав"],
    "помилосердовав": ["помилосердовавши"],
    "помилосердовавши": ["помилосердовав"],
    "помилосердствовав": ["помилосердствовавши"],
    "помилосердствовавши": ["помилосердствовав"],
    "помимо": ["сверх", "вдобавок", "наряду", "кроме", "за исключением"],
    "помин": ["поминовение", "поминание"],
    "поминав": ["поминавши"],
    "поминавши": ["поминав"],
    "поминальник": ["помянник", "синодик"],
    "поминальный": ["поминовенный"],
    "поминание": ["поминовение", "упоминание"],
    "поминки": ["тризна"],
    "поминовенье": ["поминовение"],
    "помирав": ["помиравши"],
    "помиравши": ["помирав"],
    "помирать": ["умирать", "подыхать", "издыхать", "преставляться", "испускать дух", "переходить в мир иной", "отходить", "кончаться", "давать дуба"],
    "помирволив": ["помирволивши"],
    "помирволивши": ["помирволив"],
    "помирив": ["помиривши"],
    "помиривши": ["помирив"],
    "помирител": ["посредник", "примирител", "умирител"],
    "помирить": ["примирить"],
    "помисъл": ["намерение", "замисъл"],
    "помитинговав": ["помитинговавши"],
    "помитинговавши": ["помитинговав"],
    "помкнув": ["помкнувши"],
    "помкнувши": ["помкнув"],
    "помкомвзвода": ["помощник командира взвода"],
    "помнив": ["помнивши"],
    "помнивши": ["помнив"],
    "помнить": ["памятовать"],
    "помногу": ["много"],
    "помножав": ["помножавши"],
    "помножавши": ["помножав"],
    "помножив": ["помноживши"],
    "помноживши": ["помножив"],
    "помножить": ["умножить", "перемножить"],
    "помогав": ["помогавши"],
    "помогавши": ["помогав"],
    "помогатор": ["помощник"],
    "помогать": ["содействовать", "способствовать", "оказывать помощь", "подсоблять"],
    "помозговав": ["помозговавши"],
    "помозговавши": ["помозговав"],
    "помозговать": ["подумать", "поразмышлять"],
    "помойка": ["мусорка", "свалка", "помоечка"],
    "помокав": ["помокавши"],
    "помокавши": ["помокав"],
    "помокать": ["помакать"],
    "помокнув": ["помокнувши"],
    "помокнувши": ["помокнув"],
    "помокрев": ["помокревши"],
    "помокревши": ["помокрев"],
    "помол": ["размол", "помолка"],
    "помолвив": ["помолвивши"],
    "помолвивши": ["помолвив"],
    "помолвить": ["условиться", "сговориться", "согласиться", "обручить", "сговорить"],
    "помолвочный": ["обручальный"],
    "помолебствовав": ["помолебствовавши"],
    "помолебствовавши": ["помолебствовав"],
    "помолец": ["помольщик"],
    "помолов": ["помоловши"],
    "помоловши": ["помолов"],
    "помология": ["сортоведение"],
    "помолодев": ["помолодевши"],
    "помолодевши": ["помолодев"],
    "помолодив": ["помолодивши"],
    "помолодивши": ["помолодив"],
    "помолотив": ["помолотивши"],
    "помолотивши": ["помолотив"],
    "помолчав": ["помолчавши"],
    "помолчавши": ["помолчав"],
    "помольщик": ["помолец"],
    "помолясь": ["помолившись"],
    "помор": ["поморец"],
    "поморгав": ["поморгавши"],
    "поморгавши": ["поморгав"],
    "поморив": ["поморивши"],
    "поморивши": ["поморив"],
    "поморозив": ["поморозивши"],
    "поморозивши": ["поморозив"],
    "помороковав": ["помороковавши"],
    "помороковавши": ["помороковав"],
    "поморосив": ["поморосивши"],
    "поморосивши": ["поморосив"],
    "поморочив": ["поморочивши"],
    "поморочивши": ["поморочив"],
    "поморщив": ["поморщивши"],
    "поморщивав": ["поморщивавши"],
    "поморщивавши": ["поморщивав"],
    "поморщивши": ["поморщив"],
    "поморщиться": ["сморщиться"],
    "помост": ["настил"],
    "помостив": ["помостивши"],
    "помостивши": ["помостив"],
    "помотав": ["помотавши"],
    "помотавши": ["помотав"],
    "помоха": ["туман"],
    "помочи": ["подтяжки"],
    "помочив": ["помочивши"],
    "помочивши": ["помочив"],
    "помочиться": ["пописать"],
    "помочь": ["посодействовать", "поспособствовать", "пособить", "подсобить", "оказать помощь", "позволить", "поддержать", "выручить"],
    "помошенничав": ["помошенничавши"],
    "помошенничавши": ["помошенничав"],
    "помощник": ["пособник", "ассистент", "заместитель"],
    "помощничав": ["помощничавши"],
    "помощничавши": ["помощничав"],
    "помощь": ["поддержка", "содействие", "способствование", "подмога", "пособие", "содействование", "споспешествование", "справка"],
    "помпезно": ["парадно", "пышно", "эффектно", "роскошно", "торжественно", "церемониально"],
    "помпезность": ["напыщенность", "торжественность", "помпа", "пышность"],
    "помпезный": ["пышный", "торжественный"],
    "помпельмус": ["помело", "шеддок"],
    "помпон": ["пипидастр"],
    "помрачав": ["помрачавши"],
    "помрачавши": ["помрачав"],
    "помрачаться": ["омрачаться", "тускнеть"],
    "помраченье": ["помрачение"],
    "помрачив": ["помрачивши"],
    "помрачивши": ["помрачив"],
    "помрачнев": ["помрачневши"],
    "помрачневши": ["помрачнев"],
    "помреж": ["помощник режиссёра"],
    "помудрев": ["помудревши"],
    "помудревши": ["помудрев"],
    "помудрив": ["помудривши"],
    "помудривши": ["помудрив"],
    "помудровав": ["помудровавши"],
    "помудровавши": ["помудровав"],
    "помудрствовав": ["помудрствовавши"],
    "помудрствовавши": ["помудрствовав"],
    "помужествовав": ["помужествовавши"],
    "помужествовавши": ["помужествовав"],
    "помузицировав": ["помузицировавши"],
    "помузицировавши": ["помузицировав"],
    "помуравив": ["помуравивши"],
    "помуравивши": ["помуравив"],
    "помурлыкав": ["помурлыкавши"],
    "помурлыкавши": ["помурлыкав"],
    "помурлыкивав": ["помурлыкивавши"],
    "помурлыкивавши": ["помурлыкивав"],
    "помуслив": ["помусливши"],
    "помусливши": ["помуслив"],
    "помусолив": ["помусоливши"],
    "помусоливши": ["помусолив"],
    "помутив": ["помутивши"],
    "помутивши": ["помутив"],
    "помутнев": ["помутневши"],
    "помутневши": ["помутнев"],
    "помутнение": ["помутненье"],
    "помутненье": ["помутнение"],
    "помутнив": ["помутнивши"],
    "помутнивши": ["помутнив"],
    "помучав": ["помучавши"],
    "помучавши": ["помучав"],
    "помучаться": ["помучиться"],
    "помучив": ["помучивши"],
    "помучивав": ["помучивавши"],
    "помучивавши": ["помучивав"],
    "помучивши": ["помучив"],
    "помучить": ["помучать"],
    "помучиться": ["помучаться"],
    "помуштровав": ["помуштровавши"],
    "помуштровавши": ["помуштровав"],
    "помчав": ["помчавши"],
    "помчавши": ["помчав"],
    "помыв": ["помывши"],
    "помывши": ["помыв"],
    "помыкав": ["помыкавши"],
    "помыкавши": ["помыкав"],
    "помыканье": ["помыкание"],
    "помыкивав": ["помыкивавши"],
    "помыкивавши": ["помыкивав"],
    "помылив": ["помыливши"],
    "помыливши": ["помылив"],
    "помысел": ["мысль", "идея", "помышление", "намерение", "замысел", "интенция"],
    "помыслив": ["помысливши"],
    "помысливши": ["помыслив"],
    "помытарив": ["помытаривши"],
    "помытаривши": ["помытарив"],
    "помыть": ["вымыть"],
    "помычав": ["помычавши"],
    "помычавши": ["помычав"],
    "помышление": ["помышленье"],
    "помышленье": ["помышление"],
    "помышляв": ["помышлявши"],
    "помышлявши": ["помышляв"],
    "помышлять": ["думать", "размышлять", "мыслить", "намереваться"],
    "помяв": ["помявши"],
    "помявши": ["помяв"],
    "помягчав": ["помягчавши"],
    "помягчавши": ["помягчав"],
    "помягчев": ["помягчевши"],
    "помягчевши": ["помягчев"],
    "помягчив": ["помягчивши"],
    "помягчивши": ["помягчив"],
    "помякав": ["помякавши"],
    "помякавши": ["помякав"],
    "помякнув": ["помякнувши"],
    "помякнувши": ["помякнув"],
    "помянув": ["помянувши"],
    "помянувши": ["помянув"],
    "помянуть": ["вспомнить", "упомянуть", "помолиться", "молиться"],
    "помяукав": ["помяукавши"],
    "помяукавши": ["помяукав"],
    "помёрзнув": ["помёрзнувши"],
    "помёрзнувши": ["помёрзнув"],
    "помёт": ["навоз", "выводок"],
    "помётывав": ["помётывавши"],
    "помётывавши": ["помётывав"],
    "пон": ["понятно"],
    "понабежав": ["понабежавши"],
    "понабежавши": ["понабежав"],
    "понабив": ["понабивши"],
    "понабивав": ["понабивавши"],
    "понабивавши": ["понабивав"],
    "понабивши": ["понабив"],
    "понабирав": ["понабиравши"],
    "понабиравши": ["понабирав"],
    "понаблюдав": ["понаблюдавши"],
    "понаблюдавши": ["понаблюдав"],
    "понабрав": ["понабравши"],
    "понабравши": ["понабрав"],
    "понабраться": ["понахвататься", "напиться"],
    "понабрехав": ["понабрехавши"],
    "понабрехавши": ["понабрехав"],
    "понабросав": ["понабросавши"],
    "понабросавши": ["понабросав"],
    "понавалив": ["понаваливши"],
    "понаваливши": ["понавалив"],
    "понавезя": ["понавёзши"],
    "понавертев": ["понавертевши"],
    "понавертевши": ["понавертев"],
    "понавесив": ["понавесивши"],
    "понавесивши": ["понавесив"],
    "понавешав": ["понавешавши"],
    "понавешавши": ["понавешав"],
    "понависнув": ["понависнувши"],
    "понависнувши": ["понависнув"],
    "понаворовав": ["понаворовавши"],
    "понаворовавши": ["понаворовав"],
    "понавыдумывав": ["понавыдумывавши"],
    "понавыдумывавши": ["понавыдумывав"],
    "понавыдёргивав": ["понавыдёргивавши"],
    "понавыдёргивавши": ["понавыдёргивав"],
    "понавыкапывав": ["понавыкапывавши"],
    "понавыкапывавши": ["понавыкапывав"],
    "понавёзши": ["понавезя"],
    "понаглев": ["понаглевши"],
    "понаглевши": ["понаглев"],
    "понаглеть": ["обнаглеть"],
    "понагнав": ["понагнавши"],
    "понагнавши": ["понагнав"],
    "понадавав": ["понадававши"],
    "понадававши": ["понадавав"],
    "понадавив": ["понадавивши"],
    "понадавивши": ["понадавив"],
    "понадвинув": ["понадвинувши"],
    "понадвинувши": ["понадвинув"],
    "понадев": ["понадевши"],
    "понадевав": ["понадевавши"],
    "понадевавши": ["понадевав"],
    "понадевши": ["понадев"],
    "понаделав": ["понаделавши"],
    "понаделавши": ["понаделав"],
    "понадобиться": ["потребоваться", "пригодиться"],
    "понадрав": ["понадравши"],
    "понадравши": ["понадрав"],
    "понадусерик": ["щеневмерлик"],
    "понадёргав": ["понадёргавши"],
    "понадёргавши": ["понадёргав"],
    "понаехав": ["понаехавши"],
    "понаехавши": ["понаехав"],
    "понажав": ["понажавши"],
    "понажавши": ["понажав"],
    "понажимать": ["нажать"],
    "поназанимав": ["поназанимавши"],
    "поназанимавши": ["поназанимав"],
    "поназвав": ["поназвавши"],
    "поназвавши": ["поназвав"],
    "поназывав": ["поназывавши"],
    "поназывавши": ["поназывав"],
    "понакидав": ["понакидавши"],
    "понакидавши": ["понакидав"],
    "понакопав": ["понакопавши"],
    "понакопавши": ["понакопав"],
    "понакопать": ["повыкопать"],
    "понакопив": ["понакопивши"],
    "понакопивши": ["понакопив"],
    "понакрутив": ["понакрутивши"],
    "понакрутивши": ["понакрутив"],
    "понакупив": ["понакупивши"],
    "понакупивши": ["понакупив"],
    "поналепливав": ["поналепливавши"],
    "поналепливавши": ["поналепливав"],
    "поналепляв": ["поналеплявши"],
    "поналеплявши": ["поналепляв"],
    "поналеплять": ["понацеплять", "понаклеивать"],
    "понанимав": ["понанимавши"],
    "понанимавши": ["понанимав"],
    "понаперев": ["понапёрши"],
    "понаписав": ["понаписавши"],
    "понаписавши": ["понаписав"],
    "понапихав": ["понапихавши"],
    "понапихавши": ["понапихав"],
    "понапихать": ["понапхать"],
    "понапихивав": ["понапихивавши"],
    "понапихивавши": ["понапихивав"],
    "понапраслина": ["клевета", "наговор", "напраслина", "изнапраслина"],
    "понаприглашав": ["понаприглашавши"],
    "понаприглашавши": ["понаприглашав"],
    "понапридумав": ["понапридумавши"],
    "понапридумавши": ["понапридумав"],
    "понапридумать": ["понапридумывать"],
    "понапридумывав": ["понапридумывавши"],
    "понапридумывавши": ["понапридумывав"],
    "понапридумывать": ["понапридумать"],
    "понапугав": ["понапугавши"],
    "понапугавши": ["понапугав"],
    "понапутав": ["понапутавши"],
    "понапутавши": ["понапутав"],
    "понапёрши": ["понаперев"],
    "понарошку": ["понарошке"],
    "понарыв": ["понарывши"],
    "понарывши": ["понарыв"],
    "понасадив": ["понасадивши"],
    "понасадивши": ["понасадив"],
    "понасажав": ["понасажавши"],
    "понасажавши": ["понасажав"],
    "понасдирав": ["понасдиравши"],
    "понасдиравши": ["понасдирав"],
    "понасказав": ["понасказавши"],
    "понасказавши": ["понасказав"],
    "понаскучив": ["понаскучивши"],
    "понаскучивши": ["понаскучив"],
    "понаслав": ["понаславши"],
    "понаславши": ["понаслав"],
    "понаследив": ["понаследивши"],
    "понаследивши": ["понаследив"],
    "понасрав": ["понасравши"],
    "понасравши": ["понасрав"],
    "понасрать": ["понагадить"],
    "понаставив": ["понаставивши"],
    "понаставивши": ["понаставив"],
    "понастроив": ["понастроивши"],
    "понастроивши": ["понастроив"],
    "понасыпав": ["понасыпавши"],
    "понасыпавши": ["понасыпав"],
    "понатаскав": ["понатаскавши"],
    "понатаскавши": ["понатаскав"],
    "понатащив": ["понатащивши"],
    "понатащивши": ["понатащив"],
    "понатешив": ["понатешивши"],
    "понатешивши": ["понатешив"],
    "понаткав": ["понаткавши"],
    "понаткавши": ["понаткав"],
    "понаторев": ["понаторевши"],
    "понаторевши": ["понаторев"],
    "понатореть": ["набить руку", "навостриться", "наловчиться", "наметаться", "насобачиться", "поднатореть"],
    "понатужив": ["понатуживши"],
    "понатуживши": ["понатужив"],
    "понатыкав": ["понатыкавши"],
    "понатыкавши": ["понатыкав"],
    "понаушничав": ["понаушничавши"],
    "понаушничавши": ["понаушничав"],
    "понахватав": ["понахватавши"],
    "понахватавши": ["понахватав"],
    "понахлынув": ["понахлынувши"],
    "понахлынувши": ["понахлынув"],
    "поначалу": ["вначале", "сначала", "первоначально", "сперва", "на первых порах"],
    "поначальствовав": ["поначальствовавши"],
    "поначальствовавши": ["поначальствовав"],
    "понашив": ["понашивши"],
    "понашивав": ["понашивавши"],
    "понашивавши": ["понашивав"],
    "понашивши": ["понашив"],
    "пондерация": ["взвешивание", "отвешивание"],
    "пондеромоторный": ["электромагнитный"],
    "поневоле": ["вынужденно", "волей-неволей", "хочешь не хочешь", "непроизвольно"],
    "поневолив": ["поневоливши"],
    "поневоливши": ["поневолив"],
    "поневолювачка": ["поневольниця"],
    "понегодовав": ["понегодовавши"],
    "понегодовавши": ["понегодовав"],
    "понедельник": ["понеделок"],
    "понедельничав": ["понедельничавши"],
    "понедельничавши": ["понедельничав"],
    "понедельно": ["еженедельно", "недельно"],
    "понедельный": ["еженедельный"],
    "понеже": ["зане", "ибо", "поелику", "поскольку", "так как", "потому что"],
    "понежив": ["понеживши"],
    "понеживши": ["понежив"],
    "понежничав": ["понежничавши"],
    "понежничавши": ["понежничав"],
    "понемногу": ["помаленьку", "помалёху", "постепенно", "мало-помалу", "понемножку", "однообразно"],
    "понемножку": ["понемногу", "мало-помалу", "постепенно"],
    "понервничав": ["понервничавши"],
    "понервничавши": ["понервничав"],
    "понеслось дерьмо по трубам": ["понеслось говно по трубам"],
    "понести расходы": ["оплатить", "возместить", "компенсировать", "покрыть убытки"],
    "понижав": ["понижавши"],
    "понижавши": ["понижав"],
    "понижайка": ["понижающая передача"],
    "понижательный": ["нисходящий"],
    "понижать": ["снижать", "уменьшать", "сокращать"],
    "понижаться": ["снижаться", "уменьшаться", "сокращаться", "спадать"],
    "понижающая передача": ["демультипликатор", "понижайка"],
    "понижение": ["снижение"],
    "понизав": ["понизавши"],
    "понизавши": ["понизав"],
    "понизив": ["понизивши"],
    "понизивши": ["понизив"],
    "понизить": ["снизить", "занизить", "опустить", "сбавить"],
    "понизиться": ["снизиться", "уменьшиться"],
    "понизу": ["внизу", "снизу", "низом"],
    "поникав": ["поникавши"],
    "поникавши": ["поникав"],
    "поникать": ["никнуть"],
    "пониклый": ["поникший"],
    "поникнув": ["поникнувши"],
    "поникнувши": ["поникнув"],
    "понимав": ["понимавши"],
    "понимавши": ["понимав"],
    "понимаешь": ["видите ли", "видишь ли", "понимаете", "понимаете ли", "понимаешь ли", "понимашь"],
    "понимание": ["разумение", "осознание", "точка зрения"],
    "понимать": ["знать", "разбираться", "разуметь", "видеть"],
    "понищав": ["понищавши"],
    "понищавши": ["понищав"],
    "поновев": ["поновевши"],
    "поновевши": ["поновев"],
    "поновив": ["поновивши"],
    "поновивши": ["поновив"],
    "поновляв": ["поновлявши"],
    "поновлявши": ["поновляв"],
    "поножовщина": ["резня"],
    "пономарка": ["протезис"],
    "пономарствовав": ["пономарствовавши"],
    "пономарствовавши": ["пономарствовав"],
    "пономарь": ["дьяк", "причётник", "звонарь", "свещеносец", "свечегас", "стихарь", "подмарь"],
    "пономарёв": ["пономарев"],
    "поноравливав": ["поноравливавши"],
    "поноравливавши": ["поноравливав"],
    "поноровив": ["поноровивши"],
    "поноровивши": ["поноровив"],
    "поноровка": ["поблажка"],
    "понос": ["диарея", "дрисня", "дрищ", "логорея"],
    "поносив": ["поносивши"],
    "поносивши": ["поносив"],
    "поносимост": ["търпимост"],
    "поносительный": ["позорящий", "оскорбительный"],
    "поносить": ["дристать"],
    "поноска": ["обножь", "обножка", "взяток"],
    "поносный": ["бранный", "оскорбительный", "позорящий", "поносительный", "порочащий"],
    "поностальгировав": ["поностальгировавши"],
    "поностальгировавши": ["поностальгировав"],
    "поночевав": ["поночевавши"],
    "поночевавши": ["поночевав"],
    "поношенный": ["старый", "потрёпанный", "потасканный"],
    "поношенье": ["поношение"],
    "понравиться": ["полюбиться", "приглянуться"],
    "понсировав": ["понсировавши"],
    "понсировавши": ["понсировав"],
    "понт эвксинский": ["чёрное море"],
    "понтирнув": ["понтирнувши"],
    "понтирнувши": ["понтирнув"],
    "понтировав": ["понтировавши"],
    "понтировавши": ["понтировав"],
    "понтифик": ["папа", "папа римский", "понтифекс"],
    "понтовав": ["понтовавши"],
    "понтовавши": ["понтовав"],
    "понтоваться": ["хвастаться", "хвалиться", "похваляться", "бахвалиться", "рисоваться", "важничать", "гордиться", "красоваться", "выделываться", "выпендриваться"],
    "понтон": ["плашкоут"],
    "понтоёб": ["понтяра", "понтярщик"],
    "понты": ["бахвальство", "чванство", "спесивость", "спесь"],
    "понтяра": ["понт", "понтярщик"],
    "понтярщик": ["понтяра"],
    "понтёрщик": ["понтярщик"],
    "понудев": ["понудевши"],
    "понудевши": ["понудев"],
    "понудив": ["понудивши"],
    "понудивши": ["понудив"],
    "понудиться": ["принудиться"],
    "понужав": ["понужавши"],
    "понужавши": ["понужав"],
    "понуждав": ["понуждавши"],
    "понуждавши": ["понуждав"],
    "понуждать": ["заставлять", "принуждать", "погонять", "понукать"],
    "понужденье": ["понуждение"],
    "понужнув": ["понужнувши"],
    "понужнувши": ["понужнув"],
    "понукав": ["понукавши"],
    "понукавши": ["понукав"],
    "понукание": ["нуканье", "подстёгивание", "подгоняние", "подхлёстывание", "поторапливание", "нахлёстывание"],
    "понуканье": ["понукание"],
    "понукать": ["подгонять", "нукать", "стегать", "пришпоривать", "шпорить", "поторапливать", "подстёгивать", "ускорять", "сподвигать", "помыкать"],
    "понукнув": ["понукнувши"],
    "понукнувши": ["понукнув"],
    "понурив": ["понуривши"],
    "понуривав": ["понуривавши"],
    "понуривавши": ["понуривав"],
    "понуривши": ["понурив"],
    "понуро": ["грустно"],
    "понурый": ["подавленный", "угнетённый", "удручённый", "вялый", "унылый", "безотрадный", "квёлый", "невесёлый", "нерадостный", "обречённый", "печальный", "приунылый", "понурившийся"],
    "пончик": ["баранка"],
    "поныв": ["понывши"],
    "понывав": ["понывавши"],
    "понывавши": ["понывав"],
    "понывши": ["поныв"],
    "поныне": ["до сих пор", "до настоящего времени", "до сей поры", "доныне", "доселе", "досель", "посейчас", "доднесь", "поднесь"],
    "поныряв": ["понырявши"],
    "понырявши": ["поныряв"],
    "понюхав": ["понюхавши"],
    "понюхавши": ["понюхав"],
    "понюхивав": ["понюхивавши"],
    "понюхивавши": ["понюхивав"],
    "поняв": ["понявши"],
    "понява": ["понёва", "панёва"],
    "понявши": ["поняв"],
    "понянчив": ["понянчивши"],
    "понянчивши": ["понянчив"],
    "понятие": ["концепция", "концепт", "идея", "сведение", "понимание", "знание"],
    "понятийный": ["концептуальный"],
    "понятливый": ["смышлёный"],
    "понятненько": ["ясненько", "ясненько-понятненько"],
    "понятно": ["ясно", "очевидно"],
    "понятный": ["ясный", "доступный", "постижимый", "внятный", "оправданный", "справедливый"],
    "понять": ["усвоить", "уяснить", "врубиться", "грокнуть"],
    "понятье": ["понятие"],
    "понёва": ["панёва", "понява"],
    "пооббив": ["пооббивши"],
    "пооббивав": ["пооббивавши"],
    "пооббивавши": ["пооббивав"],
    "пооббивши": ["пооббив"],
    "пообвалив": ["пообваливши"],
    "пообваливав": ["пообваливавши"],
    "пообваливавши": ["пообваливав"],
    "пообваливши": ["пообвалив"],
    "пообветшав": ["пообветшавши"],
    "пообветшавши": ["пообветшав"],
    "пообвиснув": ["пообвиснувши"],
    "пообвиснувши": ["пообвиснув"],
    "пообвыкнув": ["пообвыкнувши"],
    "пообвыкнувши": ["пообвыкнув"],
    "пообгорев": ["пообгоревши"],
    "пообгоревши": ["пообгорев"],
    "пообделав": ["пообделавши"],
    "пообделавши": ["пообделав"],
    "пообдув": ["пообдувши"],
    "пообдувши": ["пообдув"],
    "пообдумав": ["пообдумавши"],
    "пообдумавши": ["пообдумав"],
    "пообедав": ["пообедавши"],
    "пообедавши": ["пообедав"],
    "пообещав": ["пообещавши"],
    "пообещавши": ["пообещав"],
    "пообжив": ["пообживши"],
    "пообживши": ["пообжив"],
    "пообидев": ["пообидевши"],
    "пообидевши": ["пообидев"],
    "пообкопав": ["пообкопавши"],
    "пообкопавши": ["пообкопав"],
    "пообкопать": ["обкопать"],
    "пообламывав": ["пообламывавши"],
    "пообламывавши": ["пообламывав"],
    "пооблепливав": ["пооблепливавши"],
    "пооблепливавши": ["пооблепливав"],
    "пообломав": ["пообломавши"],
    "пообломавши": ["пообломав"],
    "пообмораживав": ["пообмораживавши"],
    "пообмораживавши": ["пообмораживав"],
    "пообморозив": ["пообморозивши"],
    "пообморозивши": ["пообморозив"],
    "пообмякнув": ["пообмякнувши"],
    "пообмякнувши": ["пообмякнув"],
    "пообносив": ["пообносивши"],
    "пообносивши": ["пообносив"],
    "пообогрев": ["пообогревши"],
    "пообогревши": ["пообогрев"],
    "пообождав": ["пообождавши"],
    "пообождавши": ["пообождав"],
    "пооборвав": ["пооборвавши"],
    "пооборвавши": ["пооборвав"],
    "пообрезав": ["пообрезавши"],
    "пообрезавши": ["пообрезав"],
    "пообрывав": ["пообрывавши"],
    "пообрывавши": ["пообрывав"],
    "пообследовав": ["пообследовавши"],
    "пообследовавши": ["пообследовав"],
    "пообсохнув": ["пообсохнувши"],
    "пообсохнувши": ["пообсохнув"],
    "пообсуждав": ["пообсуждавши"],
    "пообсуждавши": ["пообсуждав"],
    "пообтаяв": ["пообтаявши"],
    "пообтаявши": ["пообтаяв"],
    "пообтерев": ["пообтёрши"],
    "пообтесав": ["пообтесавши"],
    "пообтесавши": ["пообтесав"],
    "пообтрепав": ["пообтрепавши"],
    "пообтрепавши": ["пообтрепав"],
    "пообтёрши": ["пообтерев"],
    "пообчистив": ["пообчистивши"],
    "пообчистивши": ["пообчистив"],
    "пообъедав": ["пообъедавши"],
    "пообъедавши": ["пообъедав"],
    "пообыкнув": ["пообыкнувши"],
    "пообыкнувши": ["пообыкнув"],
    "пооглядеться": ["осмотреться", "поосмотреться"],
    "поодаль": ["вдали"],
    "поодев": ["поодевши"],
    "поодевши": ["поодев"],
    "поодичав": ["поодичавши"],
    "поодичавши": ["поодичав"],
    "поозорничав": ["поозорничавши"],
    "поозорничавши": ["поозорничав"],
    "поозоровав": ["поозоровавши"],
    "поозоровавши": ["поозоровав"],
    "поокрепнув": ["поокрепнувши"],
    "поокрепнувши": ["поокрепнув"],
    "поопределив": ["поопределивши"],
    "поопределивши": ["поопределив"],
    "поопрокидывав": ["поопрокидывавши"],
    "поопрокидывавши": ["поопрокидывав"],
    "поорав": ["пооравши"],
    "пооравши": ["поорав"],
    "поораторствовав": ["поораторствовавши"],
    "поораторствовавши": ["поораторствовав"],
    "пооригинальничав": ["пооригинальничавши"],
    "пооригинальничавши": ["пооригинальничав"],
    "поосвежив": ["поосвеживши"],
    "поосвеживши": ["поосвежив"],
    "поослабнув": ["поослабнувши"],
    "поослабнувши": ["поослабнув"],
    "поосторожничав": ["поосторожничавши"],
    "поосторожничавши": ["поосторожничав"],
    "поострив": ["поостривши"],
    "поостривши": ["поострив"],
    "поостудив": ["поостудивши"],
    "поостудивши": ["поостудив"],
    "поостыв": ["поостывши"],
    "поостывши": ["поостыв"],
    "поостынув": ["поостынувши"],
    "поостынувши": ["поостынув"],
    "поостыть": ["подостыть"],
    "поотбив": ["поотбивши"],
    "поотбивав": ["поотбивавши"],
    "поотбивавши": ["поотбивав"],
    "поотбивши": ["поотбив"],
    "поотбирав": ["поотбиравши"],
    "поотбиравши": ["поотбирав"],
    "поотвертев": ["поотвертевши"],
    "поотвертевши": ["поотвертев"],
    "поотвечав": ["поотвечавши"],
    "поотвечавши": ["поотвечав"],
    "поотвыкнув": ["поотвыкнувши"],
    "поотвыкнувши": ["поотвыкнув"],
    "поотвязав": ["поотвязавши"],
    "поотвязавши": ["поотвязав"],
    "поотгадывав": ["поотгадывавши"],
    "поотгадывавши": ["поотгадывав"],
    "поотдавив": ["поотдавивши"],
    "поотдавивши": ["поотдавив"],
    "поотделав": ["поотделавши"],
    "поотделавши": ["поотделав"],
    "поотдохнув": ["поотдохнувши"],
    "поотдохнувши": ["поотдохнув"],
    "пооткровенничав": ["пооткровенничавши"],
    "пооткровенничавши": ["пооткровенничав"],
    "пооткрыв": ["пооткрывши"],
    "пооткрывав": ["пооткрывавши"],
    "пооткрывавши": ["пооткрывав"],
    "пооткрывши": ["пооткрыв"],
    "поотлепливав": ["поотлепливавши"],
    "поотлепливавши": ["поотлепливав"],
    "поотмякнув": ["поотмякнувши"],
    "поотмякнувши": ["поотмякнув"],
    "поотнимав": ["поотнимавши"],
    "поотнимавши": ["поотнимав"],
    "поотняв": ["поотнявши"],
    "поотнявши": ["поотняв"],
    "поотобрав": ["поотобравши"],
    "поотобравши": ["поотобрав"],
    "поотогреть": ["подсогреть"],
    "пооторвав": ["пооторвавши"],
    "пооторвавши": ["пооторвав"],
    "поотпустив": ["поотпустивши"],
    "поотпустивши": ["поотпустив"],
    "поотрывав": ["поотрывавши"],
    "поотрывавши": ["поотрывав"],
    "поотстав": ["поотставши"],
    "поотставши": ["поотстав"],
    "пооттоптав": ["пооттоптавши"],
    "пооттоптавши": ["пооттоптав"],
    "поотшибав": ["поотшибавши"],
    "поотшибавши": ["поотшибав"],
    "поохав": ["поохавши"],
    "поохавши": ["поохав"],
    "поохладив": ["поохладивши"],
    "поохладивши": ["поохладив"],
    "поочерёдно": ["по очереди"],
    "поочистив": ["поочистивши"],
    "поочистивши": ["поочистив"],
    "поошиваться": ["пожить", "перекантоваться"],
    "поощренье": ["поощрение"],
    "поощрив": ["поощривши"],
    "поощривши": ["поощрив"],
    "поощряв": ["поощрявши"],
    "поощрявши": ["поощряв"],
    "поощрять": ["мотивировать", "стимулировать", "поддерживать", "награждать"],
    "поп": ["священник", "батюшка", "святой отец", "попин", "попик", "попина", "попище", "попишка", "попяра", "пресвитер"],
    "поп-группа": ["поп-коллектив"],
    "поп-дива": ["поп-королева"],
    "поп-идол": ["поп-икона"],
    "поп-исполнитель": ["поп-певец"],
    "поп-ит": ["попыт", "попит"],
    "поп-коллектив": ["поп-группа"],
    "поп-королева": ["поп-дива"],
    "поп-король": ["поп-идол"],
    "поп-культура": ["массовая культура"],
    "поп-певец": ["поп-исполнитель"],
    "попа": ["ягодицы", "задница", "зад", "попка", "жопа", "афедрон"],
    "попадав": ["попадавши"],
    "попадавши": ["попадав"],
    "попадалово": ["попадос", "попадосик", "конфуз", "просак"],
    "попаданье": ["попадание"],
    "попадать пальцем в небо": ["пальцем в небо попадать", "попадать пальцем в жопу", "пальцем в жопу попадать"],
    "попадаться": ["попадать", "встречаться", "наблюдаться"],
    "попадейка": ["попадья", "матушка", "матушка-попадья"],
    "попадос": ["попадалово", "засада"],
    "попадьин": ["попадейкин", "попадейский"],
    "попадья": ["попадейка", "матушка", "матушка-попадья"],
    "попаивав": ["попаивавши"],
    "попаивавши": ["попаивав"],
    "попалив": ["попаливши"],
    "попаливав": ["попаливавши"],
    "попаливавши": ["попаливав"],
    "попаливши": ["попалив"],
    "попановать": ["побарствовать", "попанствовать"],
    "попарив": ["попаривши"],
    "попаривши": ["попарив"],
    "попарно": ["парами", "четой", "по двое"],
    "попархивав": ["попархивавши"],
    "попархивавши": ["попархивав"],
    "попас": ["пастьба", "паства", "отвод"],
    "попасть": ["оказаться", "достаться", "прийтись", "ни попадя"],
    "попасть в просак": ["сконфузиться", "опростоволоситься", "сесть в лужу", "сесть в галошу", "облажаться", "ударить лицом в грязь", "дать маху"],
    "попасть впросак": ["сконфузиться", "опростоволоситься", "сесть в лужу", "сесть в галошу", "облажаться", "ударить лицом в грязь", "дать маху"],
    "попасть пальцем в небо": ["пальцем в небо попасть", "попасть пальцем в жопу", "пальцем в жопу попасть", "наугад", "методом тыка"],
    "попасть под раздачу": ["под раздачу попасть"],
    "попасться": ["встретиться"],
    "попасться в глаза": ["попасться на глаза"],
    "попасться на глаза": ["попасться в глаза"],
    "попасться на удочку": ["опростоволоситься", "дать промашку"],
    "попахав": ["попахавши"],
    "попахавши": ["попахав"],
    "попахивав": ["попахивавши"],
    "попахивавши": ["попахивав"],
    "попачкав": ["попачкавши"],
    "попачкавши": ["попачкав"],
    "попаяв": ["попаявши"],
    "попаявши": ["попаяв"],
    "попев": ["попевши"],
    "попевав": ["попевавши"],
    "попевавши": ["попевав"],
    "попевши": ["попев"],
    "попел": ["прысак"],
    "попеняв": ["попенявши"],
    "попенявши": ["попеняв"],
    "попенять": ["попрекнуть", "пожурить"],
    "попердеть": ["попукать"],
    "поперебив": ["поперебивши"],
    "поперебивши": ["поперебив"],
    "поперев": ["попёрши"],
    "попередавив": ["попередавивши"],
    "попередавивши": ["попередавив"],
    "попеределав": ["попеределавши"],
    "попеределавши": ["попеределав"],
    "попереджання": ["попередження"],
    "попереживав": ["попереживавши"],
    "попереживавши": ["попереживав"],
    "попереломав": ["попереломавши"],
    "попереломавши": ["попереломав"],
    "попеременно": ["по очереди"],
    "попеременный": ["чередующийся", "сменный"],
    "поперемешав": ["поперемешавши"],
    "поперемешавши": ["поперемешав"],
    "попереть": ["пойти", "двинуться", "повезти"],
    "поперехуярить": ["поперехуячить", "поперехуяшить"],
    "поперехуячив": ["поперехуячивши"],
    "поперехуячивши": ["поперехуячив"],
    "поперехуячить": ["поперехуяшить", "поперехуярить"],
    "поперечив": ["поперечивши"],
    "поперечивши": ["поперечив"],
    "поперечина": ["траверса", "распорка", "ригель", "переклад"],
    "поперечник": ["диаметр"],
    "поперхнуться": ["подавиться", "закашляться"],
    "поперчив": ["поперчивши"],
    "поперчивши": ["поперчив"],
    "поперёг": ["поперёк", "впоперёк"],
    "поперёд": ["вперёд"],
    "поперёк": ["впоперёк"],
    "поперёшный": ["поперечный"],
    "попестовав": ["попестовавши"],
    "попестовавши": ["попестовав"],
    "попетляв": ["попетлявши"],
    "попетлявши": ["попетляв"],
    "попечатав": ["попечатавши"],
    "попечатавши": ["попечатав"],
    "попеченье": ["попечение"],
    "попечительно": ["заботливо"],
    "попечительствовав": ["попечительствовавши"],
    "попечительствовавши": ["попечительствовав"],
    "попиарив": ["попиаривши"],
    "попиаривши": ["попиарив"],
    "попивав": ["попивавши"],
    "попивавши": ["попивав"],
    "попидорасив": ["попидорасивши"],
    "попидорасивши": ["попидорасив"],
    "попиздев": ["попиздевши"],
    "попиздевши": ["попиздев"],
    "попизделки": ["посиделки"],
    "попиздеть": ["побеседовать", "пообщаться", "поболтать", "потрепаться"],
    "попиздив": ["попиздивши"],
    "попиздивши": ["попиздив"],
    "попиздистее": ["попиздистей", "попиздястее", "попиздястей"],
    "попиздовав": ["попиздовавши"],
    "попиздовавши": ["попиздовав"],
    "попил": ["распил"],
    "попилив": ["попиливши"],
    "попиливав": ["попиливавши"],
    "попиливавши": ["попиливав"],
    "попиливши": ["попилив"],
    "попиликав": ["попиликавши"],
    "попиликавши": ["попиликав"],
    "попинав": ["попинавши"],
    "попинавши": ["попинав"],
    "попиравши": ["попирав"],
    "попирание": ["растаптывание", "попрание"],
    "попиратель": ["нарушитель"],
    "попирать": ["топтать", "наступать", "на"],
    "попировав": ["попировавши"],
    "попировавши": ["попировав"],
    "пописавший": ["помочившийся", "оправившийся"],
    "пописать": ["сделать пи-пи", "помочиться", "справить нужду", "поссать"],
    "попискивав": ["попискивавши"],
    "попискивавши": ["попискивав"],
    "попискиванье": ["попискивание"],
    "пописывав": ["пописывавши"],
    "пописывавши": ["пописывав"],
    "попит": ["попыт"],
    "попихав": ["попихавши"],
    "попихавши": ["попихав"],
    "попихивав": ["попихивавши"],
    "попихивавши": ["попихивав"],
    "попищав": ["попищавши"],
    "попищавши": ["попищав"],
    "попкорн": ["воздушная кукуруза"],
    "поплавав": ["поплававши"],
    "поплававши": ["поплавав"],
    "поплавить": ["порастопить"],
    "поплавок": ["плавучий ресторан"],
    "поплакав": ["поплакавши"],
    "поплакавши": ["поплакав"],
    "поплакаться": ["поканючить"],
    "поплакивав": ["поплакивавши"],
    "поплакивавши": ["поплакивав"],
    "поплевав": ["поплевавши"],
    "поплевавши": ["поплевав"],
    "поплескав": ["поплескавши"],
    "поплескавши": ["поплескав"],
    "поплечник": ["приспешник", "подручный"],
    "поплешивев": ["поплешивевши"],
    "поплешивевши": ["поплешивев"],
    "поплотнев": ["поплотневши"],
    "поплотневши": ["поплотнев"],
    "поплохев": ["поплохевши"],
    "поплохевши": ["поплохев"],
    "поплутав": ["поплутавши"],
    "поплутавши": ["поплутав"],
    "поплыв": ["поплывши"],
    "поплывши": ["поплыв"],
    "поплювко": ["страхливец"],
    "поплясав": ["поплясавши"],
    "поплясавши": ["поплясав"],
    "поплясывав": ["поплясывавши"],
    "поплясывавши": ["поплясывав"],
    "поплёвывав": ["поплёвывавши"],
    "поплёвывавши": ["поплёвывав"],
    "поплёвывать": ["плевать"],
    "поплёскивав": ["поплёскивавши"],
    "поплёскивавши": ["поплёскивав"],
    "попов": ["поповский", "поповий", "попин"],
    "поповец": ["раскольник"],
    "поповзень": ["повзик"],
    "поповна": ["поповка"],
    "поповствовав": ["поповствовавши"],
    "поповствовавши": ["поповствовав"],
    "поподличав": ["поподличавши"],
    "поподличавши": ["поподличав"],
    "поподробнее": ["подетальнее"],
    "попоедство": ["антипоповщина"],
    "попозжа": ["позднее", "попозже", "попозжее", "попозжей"],
    "попозже": ["позднее"],
    "попозировав": ["попозировавши"],
    "попозировавши": ["попозировав"],
    "попоив": ["попоивши"],
    "попоивши": ["попоив"],
    "попойка": ["пьянка", "пьянка-гулянка", "бухалово", "буханка"],
    "пополам": ["напополам", "надвое", "поровну"],
    "пополаскивав": ["пополаскивавши"],
    "пополаскивавши": ["пополаскивав"],
    "пополдничав": ["пополдничавши"],
    "пополдничавши": ["пополдничав"],
    "поползав": ["поползавши"],
    "поползавши": ["поползав"],
    "поползень": ["ямщик"],
    "поползновение": ["намерение", "желание", "стремление"],
    "пополнев": ["пополневши"],
    "пополневши": ["пополнев"],
    "пополнение": ["восполнение", "дополнение"],
    "пополненье": ["пополнение"],
    "пополнеть": ["потолстеть", "потучнеть"],
    "пополнив": ["пополнивши"],
    "пополнивши": ["пополнив"],
    "пополняв": ["пополнявши"],
    "пополнявши": ["пополняв"],
    "пополнять": ["дополнять"],
    "пополов": ["пополовши"],
    "пополовев": ["пополовевши"],
    "пополовевши": ["пополовев"],
    "пополовши": ["пополов"],
    "пополоскав": ["пополоскавши"],
    "пополоскавши": ["пополоскав"],
    "попользовав": ["попользовавши"],
    "попользовавши": ["попользовав"],
    "попользовать": ["полечить"],
    "попомнив": ["попомнивши"],
    "попомнивши": ["попомнив"],
    "попоров": ["попоровши"],
    "попоровши": ["попоров"],
    "попортив": ["попортивши"],
    "попортивши": ["попортив"],
    "попорхав": ["попорхавши"],
    "попорхавши": ["попорхав"],
    "попотев": ["попотевши"],
    "попотевши": ["попотев"],
    "попотеть": ["потрудиться"],
    "попотчевав": ["попотчевавши"],
    "попотчевавши": ["попотчевав"],
    "попотчевать": ["отпотчевать", "угостить", "сделать", "устроить", "побить", "прибить", "ударить"],
    "попочка": ["попка"],
    "попперс": ["амилнитрит", "алкилнитрит", "бутилнитрит"],
    "поппинг": ["поп-локинг"],
    "поправ": ["поправши"],
    "поправев": ["поправевши"],
    "поправевши": ["поправев"],
    "поправив": ["поправивши"],
    "поправивши": ["поправив"],
    "поправить": ["исправить", "подправить", "восстановить"],
    "поправиться": ["выздороветь", "поздороветь", "посвежеть", "окрепнуть", "набраться сил", "пополнеть", "потолстеть", "улучшиться", "исправиться", "поправить ошибку"],
    "поправляв": ["поправлявши"],
    "поправлявши": ["поправляв"],
    "поправлять": ["исправлять"],
    "поправляться": ["выздоравливать", "здороветь", "свежеть", "крепнуть", "набираться сил", "полнеть", "толстеть", "восстанавливаться", "исправляться"],
    "поправши": ["поправ"],
    "попраздновав": ["попраздновавши"],
    "попраздновавши": ["попраздновав"],
    "попрактиковав": ["попрактиковавши"],
    "попрактиковавши": ["попрактиковав"],
    "попранье": ["попрание"],
    "попрать": ["нарушить", "растоптать"],
    "попрашивав": ["попрашивавши"],
    "попрашивавши": ["попрашивав"],
    "попребывав": ["попребывавши"],
    "попребывавши": ["попребывав"],
    "попрев": ["попревши"],
    "попревши": ["попрев"],
    "попрекав": ["попрекавши"],
    "попрекавши": ["попрекав"],
    "попрекать": ["упрекать"],
    "попрекнув": ["попрекнувши"],
    "попрекнувши": ["попрекнув"],
    "попрепятствовав": ["попрепятствовавши"],
    "попрепятствовавши": ["попрепятствовав"],
    "поприбавив": ["поприбавивши"],
    "поприбавивши": ["поприбавив"],
    "поприбив": ["поприбивши"],
    "поприбивав": ["поприбивавши"],
    "поприбивавши": ["поприбивав"],
    "поприбивши": ["поприбив"],
    "поприбрав": ["поприбравши"],
    "поприбравши": ["поприбрав"],
    "поприветствовав": ["поприветствовавши"],
    "поприветствовавши": ["поприветствовав"],
    "попривив": ["попрививши"],
    "попрививав": ["попрививавши"],
    "попрививавши": ["попрививав"],
    "попрививши": ["попривив"],
    "попривыкнув": ["попривыкнувши"],
    "попривыкнувши": ["попривыкнув"],
    "попривыкнуть": ["пообвыкнуть"],
    "поприглядев": ["поприглядевши"],
    "поприглядевши": ["поприглядев"],
    "попридавив": ["попридавивши"],
    "попридавивши": ["попридавив"],
    "поприделав": ["поприделавши"],
    "поприделавши": ["поприделав"],
    "попридержав": ["попридержавши"],
    "попридержавши": ["попридержав"],
    "попридерживав": ["попридерживавши"],
    "попридерживавши": ["попридерживав"],
    "попридумав": ["попридумавши"],
    "попридумавши": ["попридумав"],
    "поприжав": ["поприжавши"],
    "поприжавши": ["поприжав"],
    "поприжигав": ["поприжигавши"],
    "поприжигавши": ["поприжигав"],
    "попризаняв": ["попризанявши"],
    "попризанявши": ["попризаняв"],
    "поприлепливав": ["поприлепливавши"],
    "поприлепливавши": ["поприлепливав"],
    "попримолкнув": ["попримолкнувши"],
    "попримолкнувши": ["попримолкнув"],
    "попринарядив": ["попринарядивши"],
    "попринарядивши": ["попринарядив"],
    "попринимав": ["попринимавши"],
    "попринимавши": ["попринимав"],
    "попринудив": ["попринудивши"],
    "попринудивши": ["попринудив"],
    "поприободрив": ["поприободривши"],
    "поприободривши": ["поприободрив"],
    "поприодев": ["поприодевши"],
    "поприодевши": ["поприодев"],
    "поприоткрывав": ["поприоткрывавши"],
    "поприоткрывавши": ["поприоткрывав"],
    "поприпухнув": ["поприпухнувши"],
    "поприпухнувши": ["поприпухнув"],
    "поприсмотрев": ["поприсмотревши"],
    "поприсмотревши": ["поприсмотрев"],
    "попристав": ["поприставши"],
    "поприставав": ["попристававши"],
    "попристававши": ["поприставав"],
    "поприставши": ["попристав"],
    "попристальней": ["пристальнее", "пристальней"],
    "поприсутствовав": ["поприсутствовавши"],
    "поприсутствовавши": ["поприсутствовав"],
    "попритихнув": ["попритихнувши"],
    "попритихнувши": ["попритихнув"],
    "попритчиться": ["показаться", "почудиться", "представиться", "произойти", "сделаться", "случиться"],
    "поприутихнув": ["поприутихнувши"],
    "поприутихнувши": ["поприутихнув"],
    "поприходив": ["поприходивши"],
    "поприходивши": ["поприходив"],
    "поприще": ["арена", "ристалище", "миля", "верста", "лига", "область", "сфера"],
    "попробовав": ["попробовавши"],
    "попробовавши": ["попробовав"],
    "попроведав": ["попроведавши"],
    "попроведавши": ["попроведав"],
    "попроветрив": ["попроветривши"],
    "попроветривши": ["попроветрив"],
    "попродав": ["попродавши"],
    "попродавав": ["попродававши"],
    "попродававши": ["попродавав"],
    "попродавши": ["попродав"],
    "попроказив": ["попроказивши"],
    "попроказивши": ["попроказив"],
    "попроказничав": ["попроказничавши"],
    "попроказничавши": ["попроказничав"],
    "попромышляв": ["попромышлявши"],
    "попромышлявши": ["попромышляв"],
    "попросив": ["попросивши"],
    "попросивши": ["попросив"],
    "попросохнув": ["попросохнувши"],
    "попросохнувши": ["попросохнув"],
    "попростев": ["попростевши"],
    "попростевши": ["попростев"],
    "попросторнев": ["попросторневши"],
    "попросторневши": ["попросторнев"],
    "попросту": ["просто", "по-простому", "запросто", "просто-напросто", "попросту говоря"],
    "попрохладнеть": ["похолодать"],
    "попрочнев": ["попрочневши"],
    "попрочневши": ["попрочнев"],
    "попрошайка": ["нищий", "побирушка"],
    "попрошайничав": ["попрошайничавши"],
    "попрошайничавши": ["попрошайничав"],
    "попрошайничанье": ["попрошайничество"],
    "попрошайничать": ["побираться", "просить милостыню"],
    "попрощаться": ["проститься"],
    "попрыгав": ["попрыгавши"],
    "попрыгавши": ["попрыгав"],
    "попрыгивав": ["попрыгивавши"],
    "попрыгивавши": ["попрыгивав"],
    "попрыгун": ["попрыгунчик"],
    "попрыгунья": ["вертушка", "егоза", "попрыгушка", "непоседа"],
    "попрыгушка": ["попрыгунья"],
    "попрыскав": ["попрыскавши"],
    "попрыскавши": ["попрыскав"],
    "попрыскивав": ["попрыскивавши"],
    "попрыскивавши": ["попрыскивав"],
    "попрыщавев": ["попрыщавевши"],
    "попрыщавевши": ["попрыщавев"],
    "попрятав": ["попрятавши"],
    "попрятавши": ["попрятав"],
    "попрёк": ["укор", "упрёк"],
    "попс": ["поп", "поп-музыка"],
    "попса": ["поп-музыка", "эстрадная музыка", "дешёвка", "жвачка", "низкопробщина"],
    "попсиховав": ["попсиховавши"],
    "попсиховавши": ["попсиховав"],
    "попсовик": ["попсятник"],
    "попсуха": ["попсятина"],
    "попсятина": ["попсуха"],
    "попсятник": ["попсовик"],
    "попугав": ["попугавши"],
    "попугавши": ["попугав"],
    "попугаичий": ["попугаячий"],
    "попугай": ["патефон", "граммофон", "светофор"],
    "попугайничав": ["попугайничавши"],
    "попугайничавши": ["попугайничав"],
    "попугайный": ["попугайский", "яркий", "пёстрый", "броский"],
    "попугаячий": ["попугайный", "попугайский"],
    "попугивав": ["попугивавши"],
    "попугивавши": ["попугивав"],
    "попудрив": ["попудривши"],
    "попудривши": ["попудрив"],
    "попудрить носик": ["справлять нужду"],
    "попужав": ["попужавши"],
    "попужавши": ["попужав"],
    "попукивав": ["попукивавши"],
    "попукивавши": ["попукивав"],
    "популяризатор": ["пропагандист"],
    "популяризировав": ["популяризировавши"],
    "популяризировавши": ["популяризировав"],
    "популяризировавший": ["популяризовавший"],
    "популяризировать": ["популяризовать", "вульгаризовать", "вульгаризировать", "упрощать", "упростить", "рекламировать"],
    "популяризовав": ["популяризовавши"],
    "популяризовавши": ["популяризовав"],
    "популярничав": ["популярничавши"],
    "популярничавши": ["популярничав"],
    "популярно": ["общедоступно", "в доступной форме"],
    "популярность": ["понятность", "удобоваримость", "толковость", "доступность", "известность", "знаменитость", "слава", "признание", "лавры", "репутация", "мода", "признанность", "вразумительность", "внятность", "рейтинг"],
    "популярный": ["доступный", "общепонятный", "любимый", "уважаемый", "модный", "пресловутый", "известный", "знаменитый", "славный", "достославный", "достопамятный", "народный", "распространённый"],
    "попунцовев": ["попунцовевши"],
    "попунцовевши": ["попунцовев"],
    "попурри": ["кводлибет"],
    "попуск": ["спуск"],
    "попускав": ["попускавши"],
    "попускавши": ["попускав"],
    "попустив": ["попустивши"],
    "попустивши": ["попустив"],
    "попустительствовав": ["попустительствовавши"],
    "попустительствовавши": ["попустительствовав"],
    "попустительствовать": ["потакать", "пропускать мимо глаз", "попускать", "смотреть сквозь пальцы", "делать послабления", "смотреть не строго", "поблажать", "допускать послабления", "закрывать глаза", "смотреть вполглаза", "либеральничать", "потворствовать"],
    "попустить": ["допустить"],
    "попуститься": ["допуститься"],
    "попусту": ["напрасно", "зря", "тщетно", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "попутав": ["попутавши"],
    "попутавши": ["попутав"],
    "попутешествовав": ["попутешествовавши"],
    "попутешествовавши": ["попутешествовав"],
    "попутного ветра": ["счастливого пути"],
    "попутный": ["сонаправленный", "сопутствующий"],
    "попутчик": ["спутник", "сопутник"],
    "попутчица": ["спутница", "сопутница"],
    "попущение": ["попустительство", "бедствие", "несчастие"],
    "попущенье": ["попущение"],
    "попщина": ["поповщина", "невежество", "мракобесие"],
    "попыт": ["поп-ит"],
    "попытав": ["попытавши"],
    "попытавши": ["попытав"],
    "попыхав": ["попыхавши"],
    "попыхавши": ["попыхав"],
    "попыхивав": ["попыхивавши"],
    "попыхивавши": ["попыхивав"],
    "попыхиванье": ["попыхивание"],
    "попыхтев": ["попыхтевши"],
    "попыхтевши": ["попыхтев"],
    "попьянствовав": ["попьянствовавши"],
    "попьянствовавши": ["попьянствовав"],
    "попяра": ["попик"],
    "попятив": ["попятивши"],
    "попятивши": ["попятив"],
    "попятить": ["попереть"],
    "попячивав": ["попячивавши"],
    "попячивавши": ["попячивав"],
    "попёрдывав": ["попёрдывавши"],
    "попёрдывавши": ["попёрдывав"],
    "попёрдывать": ["попукивать"],
    "попёрши": ["поперев"],
    "пора": ["время", "период", "срок", "доба"],
    "порабатывав": ["порабатывавши"],
    "порабатывавши": ["порабатывав"],
    "поработав": ["поработавши"],
    "поработавши": ["поработав"],
    "поработать": ["потрудиться"],
    "поработив": ["поработивши"],
    "поработивши": ["поработив"],
    "поработительница": ["завоевательница", "покорительница"],
    "поработить": ["обратить в рабство", "закабалить"],
    "порабощав": ["порабощавши"],
    "порабощавши": ["порабощав"],
    "порабощать": ["закабалять"],
    "порабощенье": ["порабощение"],
    "поравнив": ["поравнивши"],
    "поравнивши": ["поравнив"],
    "поравняв": ["поравнявши"],
    "поравнявши": ["поравняв"],
    "порадев": ["порадевши"],
    "порадевши": ["порадев"],
    "порадеть": ["позаботиться", "похлопотать"],
    "порадовав": ["порадовавши"],
    "порадовавши": ["порадовав"],
    "порадовать": ["обрадовать"],
    "порадоваться": ["потешиться"],
    "поражав": ["поражавши"],
    "поражавши": ["поражав"],
    "пораженец": ["капитулянт"],
    "поражение": ["повреждение", "проигрыш", "разгром", "неудача", "катастрофа", "крах", "фиаско"],
    "поразбив": ["поразбивши"],
    "поразбивав": ["поразбивавши"],
    "поразбивавши": ["поразбивав"],
    "поразбивши": ["поразбив"],
    "поразбирав": ["поразбиравши"],
    "поразбиравши": ["поразбирав"],
    "поразбросав": ["поразбросавши"],
    "поразбросавши": ["поразбросав"],
    "поразбудив": ["поразбудивши"],
    "поразбудивши": ["поразбудив"],
    "поразвалив": ["поразваливши"],
    "поразваливши": ["поразвалив"],
    "поразведав": ["поразведавши"],
    "поразведавши": ["поразведав"],
    "поразвеселив": ["поразвеселивши"],
    "поразвеселивши": ["поразвеселив"],
    "поразвеселиться": ["повеселеть"],
    "поразвесив": ["поразвесивши"],
    "поразвесивши": ["поразвесив"],
    "поразвешав": ["поразвешавши"],
    "поразвешавши": ["поразвешав"],
    "поразводив": ["поразводивши"],
    "поразводивши": ["поразводив"],
    "поразвратив": ["поразвративши"],
    "поразвративши": ["поразвратив"],
    "поразговаривав": ["поразговаривавши"],
    "поразговаривавши": ["поразговаривав"],
    "поразговорив": ["поразговоривши"],
    "поразговоривши": ["поразговорив"],
    "поразгоняв": ["поразгонявши"],
    "поразгонявши": ["поразгоняв"],
    "пораздав": ["пораздавши"],
    "пораздавав": ["пораздававши"],
    "пораздававши": ["пораздавав"],
    "пораздавив": ["пораздавивши"],
    "пораздавивши": ["пораздавив"],
    "пораздавши": ["пораздав"],
    "пораздвинув": ["пораздвинувши"],
    "пораздвинувши": ["пораздвинув"],
    "поразделав": ["поразделавши"],
    "поразделавши": ["поразделав"],
    "поразделать": ["поразделывать"],
    "поразделывать": ["поразделать"],
    "пораздумав": ["пораздумавши"],
    "пораздумавши": ["пораздумав"],
    "поразевав": ["поразевавши"],
    "поразевавши": ["поразевав"],
    "поразив": ["поразивши"],
    "поразивши": ["поразив"],
    "поразинув": ["поразинувши"],
    "поразинувши": ["поразинув"],
    "поразинуть": ["поразевать"],
    "поразительно": ["удивительно", "восхитительно", "чрезмерно", "чрезвычайно"],
    "поразительный": ["изумительный", "потрясающий"],
    "поразить": ["удивить", "изумить"],
    "поразладив": ["поразладивши"],
    "поразладивши": ["поразладив"],
    "поразлепливав": ["поразлепливавши"],
    "поразлепливавши": ["поразлепливав"],
    "поразложив": ["поразложивши"],
    "поразложивши": ["поразложив"],
    "поразмотав": ["поразмотавши"],
    "поразмотавши": ["поразмотав"],
    "поразмыкать": ["изживать", "утолять"],
    "поразмыслив": ["поразмысливши"],
    "поразмысливши": ["поразмыслив"],
    "поразмышляв": ["поразмышлявши"],
    "поразмышлявши": ["поразмышляв"],
    "поразмяв": ["поразмявши"],
    "поразмявши": ["поразмяв"],
    "поразнообразив": ["поразнообразивши"],
    "поразнообразивши": ["поразнообразив"],
    "поразнюхав": ["поразнюхавши"],
    "поразнюхавши": ["поразнюхав"],
    "поразобрав": ["поразобравши"],
    "поразобравши": ["поразобрав"],
    "поразогнав": ["поразогнавши"],
    "поразогнавши": ["поразогнав"],
    "поразогрев": ["поразогревши"],
    "поразогревши": ["поразогрев"],
    "поразорив": ["поразоривши"],
    "поразоривши": ["поразорив"],
    "поразузнав": ["поразузнавши"],
    "поразузнавши": ["поразузнав"],
    "поразъехав": ["поразъехавши"],
    "поразъехавши": ["поразъехав"],
    "поранение": ["ранение", "рана"],
    "пораненье": ["поранение"],
    "поранив": ["поранивши"],
    "поранивши": ["поранив"],
    "поранить": ["ранить"],
    "пораскидав": ["пораскидавши"],
    "пораскидавши": ["пораскидав"],
    "пораскинув": ["пораскинувши"],
    "пораскинувши": ["пораскинув"],
    "пораскладывав": ["пораскладывавши"],
    "пораскладывавши": ["пораскладывав"],
    "пораскрасив": ["пораскрасивши"],
    "пораскрасивши": ["пораскрасив"],
    "пораспиздяйничав": ["пораспиздяйничавши"],
    "пораспиздяйничавши": ["пораспиздяйничав"],
    "порасправив": ["порасправивши"],
    "порасправивши": ["порасправив"],
    "пораспродав": ["пораспродавши"],
    "пораспродавав": ["пораспродававши"],
    "пораспродававши": ["пораспродавав"],
    "пораспродавши": ["пораспродав"],
    "пораспрямив": ["пораспрямивши"],
    "пораспрямивши": ["пораспрямив"],
    "пораспустив": ["пораспустивши"],
    "пораспустивши": ["пораспустив"],
    "пораспутничав": ["пораспутничавши"],
    "пораспутничавши": ["пораспутничав"],
    "порассеяв": ["порассеявши"],
    "порассеявши": ["порассеяв"],
    "порассказав": ["порассказавши"],
    "порассказавши": ["порассказав"],
    "порассовав": ["порассовавши"],
    "порассовавши": ["порассовав"],
    "порасспрашивав": ["порасспрашивавши"],
    "порасспрашивавши": ["порасспрашивав"],
    "порасспросив": ["порасспросивши"],
    "порасспросивши": ["порасспросив"],
    "порасстреляв": ["порасстрелявши"],
    "порасстрелявши": ["порасстреляв"],
    "порасстроив": ["порасстроивши"],
    "порасстроивши": ["порасстроив"],
    "порассудив": ["порассудивши"],
    "порассудивши": ["порассудив"],
    "порассуждав": ["порассуждавши"],
    "порассуждавши": ["порассуждав"],
    "порастав": ["пораставши"],
    "пораставши": ["порастав"],
    "порастаскав": ["порастаскавши"],
    "порастаскавши": ["порастаскав"],
    "порастаяв": ["порастаявши"],
    "порастаявши": ["порастаяв"],
    "порастворенный": ["приоткрытый", "приотворенный", "приотворённый"],
    "порастворить": ["приотворить", "приоткрыть"],
    "порастеряв": ["порастерявши"],
    "порастерявши": ["порастеряв"],
    "порастив": ["порастивши"],
    "порастивши": ["порастив"],
    "порастолкав": ["порастолкавши"],
    "порастолкавши": ["порастолкав"],
    "порасхватав": ["порасхватавши"],
    "порасхватавши": ["порасхватав"],
    "порасхитив": ["порасхитивши"],
    "порасхитивши": ["порасхитив"],
    "порато": ["порать", "очень", "чересчур", "чрезмерно", "излишне", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры"],
    "поратовав": ["поратовавши"],
    "поратовавши": ["поратовав"],
    "порвав": ["порвавши"],
    "порвавши": ["порвав"],
    "порванка": ["давалка"],
    "порвать": ["разорвать", "расстаться", "уделать"],
    "порвать на британский флаг": ["порвать на немецкий крест"],
    "порваться": ["разорваться", "прекратиться", "окончиться", "оборваться", "возмутиться"],
    "поребрик": ["бордюр", "бровка", "бортовой камень"],
    "поревев": ["поревевши"],
    "поревевши": ["поревев"],
    "поревновав": ["поревновавши"],
    "поревновавши": ["поревновав"],
    "порево": ["постельные сцены", "всё как есть"],
    "пореволюционный": ["послереволюционный"],
    "поредев": ["поредевши"],
    "поредевши": ["поредев"],
    "поредив": ["поредивши"],
    "поредивши": ["поредив"],
    "поредица": ["ред", "низ", "серия"],
    "пореевый": ["порейный"],
    "порезав": ["порезавши"],
    "порезавши": ["порезав"],
    "порезвиться": ["повеселиться"],
    "порезка": ["резка", "разрезание", "резьба"],
    "порей": ["лук-порей"],
    "порейный": ["пореевый"],
    "порекомендовав": ["порекомендовавши"],
    "порекомендовавши": ["порекомендовав"],
    "порепав": ["порепавши"],
    "порепавши": ["порепав"],
    "порепать": ["порепетировать"],
    "порепетировав": ["порепетировавши"],
    "порепетировавши": ["порепетировав"],
    "порефлексировав": ["порефлексировавши"],
    "порефлексировавши": ["порефлексировав"],
    "пореформенный": ["постреформенный"],
    "порешав": ["порешавши"],
    "порешавши": ["порешав"],
    "порешать": ["решить"],
    "порешив": ["порешивши"],
    "порешивши": ["порешив"],
    "порешний": ["выдровый", "выдрий", "порешный"],
    "порешный": ["выдровый", "выдрий", "порешний"],
    "пореяв": ["пореявши"],
    "поржав": ["поржавши"],
    "поржавев": ["поржавевши"],
    "поржавевши": ["поржавев"],
    "поржавши": ["поржав"],
    "поржать": ["погоготать", "похохотать"],
    "порисовав": ["порисовавши"],
    "порисовавши": ["порисовав"],
    "порисовывав": ["порисовывавши"],
    "порисовывавши": ["порисовывав"],
    "порицав": ["порицавши"],
    "порицавши": ["порицав"],
    "порицание": ["укор", "критика"],
    "порицанье": ["порицание"],
    "порицатель": ["хулитель"],
    "порицательный": ["неодобрительный", "осуждающий"],
    "порицать": ["осуждать", "порочить", "укорять", "хаять", "хулить", "критиковать", "громить", "обвинять"],
    "порно": ["порнография"],
    "порноактёр": ["порноартист"],
    "порнобарон": ["порномагнат"],
    "порнобизнес": ["порноиндустрия"],
    "порнография": ["порно", "порнуха", "отстой"],
    "порнодива": ["порнозвезда"],
    "порнозвезда": ["порнодива"],
    "порноиндустрия": ["порнобизнес"],
    "порнокомпания": ["порнопроизводитель", "порнофирма"],
    "порнолента": ["порнофильм"],
    "порномагнат": ["порнобарон"],
    "порномультик": ["порномультфильм"],
    "порномультфильм": ["порномультик"],
    "порнопроизводитель": ["порнокомпания", "порнофирма"],
    "порноснимок": ["порнофото", "порнофотография"],
    "порносцена": ["порноэпизод"],
    "порнофильм": ["порнолента"],
    "порнофирма": ["порнокомпания", "порнопроизводитель"],
    "порнофото": ["порнофотография", "порноснимок"],
    "порнофотография": ["порнофото", "порноснимок"],
    "порноэпизод": ["порносцена"],
    "порнуха": ["порнография", "порно"],
    "порнушка": ["порнуха"],
    "поробев": ["поробевши"],
    "поробевши": ["поробев"],
    "поробител": ["заробител", "завоевател", "подтисник", "угнетител"],
    "поров": ["поровши"],
    "поровняв": ["поровнявши"],
    "поровнявши": ["поровняв"],
    "поровши": ["поров"],
    "порог": ["рубеж", "предел"],
    "порода": ["раса"],
    "породив": ["породивши"],
    "породивши": ["породив"],
    "породнив": ["породнивши"],
    "породнивши": ["породнив"],
    "породнённость": ["побратимство"],
    "порождав": ["порождавши"],
    "порождавши": ["порождав"],
    "порождать": ["рожать", "рождать", "производить на свет", "влечь", "вызывать"],
    "порождение": ["рождение", "создание", "порожденье", "рожденье", "созданье"],
    "порождение разума": ["артефакт"],
    "порожденье": ["порождение"],
    "порожний": ["пустой", "незаполненный", "пустующий", "незагруженный", "запряжённый"],
    "порожняком": ["вхолостую"],
    "порозиметрия": ["порометрия"],
    "порозной": ["пустой", "полый"],
    "порозность": ["пористость"],
    "порозный": ["порожний"],
    "порознь": ["врозь"],
    "порозовев": ["порозовевши"],
    "порозовевши": ["порозовев"],
    "порозовец": ["порозовчанин"],
    "порой": ["временами", "иногда", "иной раз", "подчас", "порою", "местами"],
    "порок": ["недостаток", "разврат", "грех", "греховность", "уродство", "недуг", "дефект"],
    "порометрия": ["порозиметрия"],
    "поронайск": ["сисука", "сикука"],
    "пороняв": ["поронявши"],
    "поронявши": ["пороняв"],
    "пороптав": ["пороптавши"],
    "пороптавши": ["пороптав"],
    "поросив": ["поросивши"],
    "поросивши": ["поросив"],
    "пороскошествовав": ["пороскошествовавши"],
    "пороскошествовавши": ["пороскошествовав"],
    "порости": ["зростити", "виростити", "нарости"],
    "порося": ["поросёнок", "чушка", "свинья", "свинтус"],
    "поросятничав": ["поросятничавши"],
    "поросятничавши": ["поросятничав"],
    "поросячий": ["свиной", "свинский"],
    "поросячья рожа": ["свиная рожа"],
    "пороховая бочка": ["дамоклов меч", "бомба замедленного действия", "осиное гнездо"],
    "пороховой": ["зелийный"],
    "порочив": ["порочивши"],
    "порочивши": ["порочив"],
    "порочить": ["позорить", "бесчестить", "клеветать"],
    "порочный": ["безнравственный", "испорченный", "развращённый", "дурной", "аморальный", "распутный", "распущенный", "ущербный", "дефектный", "ошибочный"],
    "порочный круг": ["заколдованный круг", "дурная бесконечность", "тавтология", "масло масляное"],
    "пороша": ["порошица", "пороха", "порошуха"],
    "порошив": ["порошивши"],
    "порошивши": ["порошив"],
    "порошинка": ["крупинка", "крупица"],
    "порошить": ["идти", "выпадать", "сыпаться", "падать", "посыпать", "сыпать"],
    "порошка": ["пороша"],
    "порошковидный": ["порошкообразный", "пылеобразный", "пылевидный"],
    "порошковое молоко": ["сухое молоко", "восстановленное молоко"],
    "порошкообразный": ["порошковидный", "пылеобразный"],
    "порошок": ["стиральный порошок"],
    "порскав": ["порскавши"],
    "порскавши": ["порскав"],
    "порсканье": ["фырканье"],
    "порскнув": ["порскнувши"],
    "порскнувши": ["порскнув"],
    "порскнуть": ["вспорхнуть", "фыркнуть"],
    "порсок": ["жараток", "горпушка", "загнетка"],
    "порт-кулис": ["герса"],
    "портал": ["веб-портал", "интернет-портал", "флуоксетин", "проём", "проход", "кротовина", "червоточина"],
    "портаменто": ["портато"],
    "портативный": ["переносной"],
    "портач": ["халтурщик", "неумеха", "бракодел"],
    "портачив": ["портачивши"],
    "портачивши": ["портачив"],
    "портвейн": ["портвеш", "портвешок", "портвяшок", "портвик", "портвяш", "портвяга", "портяга", "портвагин", "портогаз", "портваго", "порт", "портик"],
    "портемонет": ["кошелёк", "кошелёчек", "портмоне"],
    "портив": ["портивши"],
    "портивши": ["портив"],
    "портировав": ["портировавши"],
    "портировавши": ["портировав"],
    "портировать": ["адаптировать"],
    "портить": ["вредить", "повреждать", "губить", "ухудшать"],
    "портить кровь": ["раздражать"],
    "портиться": ["ухудшаться", "развращаться"],
    "портки": ["штаны", "порты"],
    "портмоне": ["кошелёк", "портемонет"],
    "портной": ["швец"],
    "портняжив": ["портняживши"],
    "портняживши": ["портняжив"],
    "портняжить": ["портняжничать"],
    "портняжничав": ["портняжничавши"],
    "портняжничавши": ["портняжничав"],
    "портняжничество": ["портняжество"],
    "портокалов": ["оранжев"],
    "портопункт": ["портпункт"],
    "портрет": ["портретик", "образ", "морда", "рожа"],
    "портретировав": ["портретировавши"],
    "портретировавши": ["портретировав"],
    "портретист": ["портретчик"],
    "портретистка": ["портретчица"],
    "портсигар": ["папиросница", "сигаретница", "папиросочница"],
    "португалия": ["португальская республика"],
    "португальский": ["португальский язык"],
    "португальский язык": ["португальский"],
    "портулак": ["дандур"],
    "портшез": ["паланкин"],
    "порты": ["портки", "штаны"],
    "портье": ["рецепционист", "швейцар", "привратник", "придверник"],
    "портянка": ["простыня"],
    "пору": ["саргин"],
    "поруб": ["темница"],
    "порубав": ["порубавши"],
    "порубавши": ["порубав"],
    "порубежник": ["пограничник"],
    "порубив": ["порубивши"],
    "порубивши": ["порубив"],
    "порубка": ["срубка"],
    "порубливав": ["порубливавши"],
    "порубливавши": ["порубливав"],
    "поругав": ["поругавши"],
    "поругавши": ["поругав"],
    "поругание": ["поруганье", "глумление", "надругательство", "над"],
    "поруганье": ["поругание"],
    "поругать": ["побранить", "поглумиться"],
    "поругаться": ["поссориться", "побраниться"],
    "поругивав": ["поругивавши"],
    "поругивавши": ["поругивав"],
    "порука": ["ручательство"],
    "поруководив": ["поруководивши"],
    "поруководивши": ["поруководив"],
    "поруководствовав": ["поруководствовавши"],
    "поруководствовавши": ["поруководствовав"],
    "порулив": ["поруливши"],
    "поруливши": ["порулив"],
    "порумянев": ["порумяневши"],
    "порумяневши": ["порумянев"],
    "порумянив": ["порумянивши"],
    "порумянивши": ["порумянив"],
    "порусев": ["порусевши"],
    "порусевши": ["порусев"],
    "порусия": ["перугия"],
    "порусс": ["борусс", "прусс"],
    "поруссия": ["пруссия"],
    "порутав": ["порутавши"],
    "порутавши": ["порутав"],
    "порух": ["рух"],
    "поручав": ["поручавши"],
    "поручавши": ["поручав"],
    "порученец": ["помоганец", "помощник"],
    "поручение": ["задание", "приказание", "повеление", "распоряжение", "предписание", "наказ", "приказ"],
    "поручень": ["перила", "подлокотник"],
    "порученье": ["поручение"],
    "поручив": ["поручивши"],
    "поручивши": ["поручив"],
    "поручик": ["лейтенант", "сотник"],
    "поручительство": ["порука"],
    "поручительствовав": ["поручительствовавши"],
    "поручительствовавши": ["поручительствовав"],
    "поручительствовать": ["ручаться"],
    "поруш": ["паруш"],
    "порушив": ["порушивши"],
    "порушивши": ["порушив"],
    "порфира": ["багряница"],
    "порфириат": ["порфиризм"],
    "порфиризм": ["порфирия"],
    "порфирия": ["порфиризм"],
    "порфироносец": ["монарх", "царь"],
    "порфироносный": ["царственный"],
    "порфирородный": ["багрянородный", "царский"],
    "порхав": ["порхавши"],
    "порхавши": ["порхав"],
    "порхание": ["перепархивание", "порханье"],
    "порханье": ["порхание", "перепархивание", "перепархиванье"],
    "порхнув": ["порхнувши"],
    "порхнувши": ["порхнув"],
    "порхович": ["порховчанин", "порховец", "порховитянин"],
    "порховичка": ["порховчанка"],
    "порцелан": ["фарфор"],
    "порцеляновий": ["фарфоровий"],
    "порционировав": ["порционировавши"],
    "порционировавши": ["порционировав"],
    "порция": ["порцайка", "порцаечка"],
    "порча": ["ухудшение", "сглаз", "проклятье"],
    "поршень": ["поршенёк"],
    "поршенёк": ["дилдо", "фаллоимитатор"],
    "поршневой": ["поршневый"],
    "порыбалив": ["порыбаливши"],
    "порыбаливши": ["порыбалив"],
    "порыбачив": ["порыбачивши"],
    "порыбачивши": ["порыбачив"],
    "порывав": ["порывавши"],
    "порывавши": ["порывав"],
    "порыванье": ["порывание"],
    "порывши": ["порыв"],
    "порыдав": ["порыдавши"],
    "порыдавши": ["порыдав"],
    "порыжев": ["порыжевши"],
    "порыжевши": ["порыжев"],
    "порыкивав": ["порыкивавши"],
    "порыкивавши": ["порыкивав"],
    "порысив": ["порысивши"],
    "порысивши": ["порысив"],
    "порыскав": ["порыскавши"],
    "порыскавши": ["порыскав"],
    "порыхлев": ["порыхлевши"],
    "порыхлевши": ["порыхлев"],
    "порыхлив": ["порыхливши"],
    "порыхливши": ["порыхлив"],
    "порычав": ["порычавши"],
    "порычавши": ["порычав"],
    "порябев": ["порябевши"],
    "порябевши": ["порябев"],
    "порябив": ["порябивши"],
    "порябивши": ["порябив"],
    "порядив": ["порядивши"],
    "порядивши": ["порядив"],
    "порядка": ["приблизительно", "примерно", "около"],
    "порядковый номер": ["зарядовое число", "атомный номер", "атомное число"],
    "порядком": ["изрядно", "толком"],
    "порядок": ["устроенность", "упорядоченность", "лад", "очередь", "очерёдность", "последовательность", "около", "примерно", "приблизительно", "отряд"],
    "порядок слов": ["порядок слов в предложении"],
    "порядок слов в предложении": ["порядок слов"],
    "порядочно": ["хорошо", "удовлетворительно", "благородно", "благопристойно", "много", "значительно"],
    "порядочный": ["честный", "приличный", "нехилый"],
    "поряжав": ["поряжавши"],
    "поряжавши": ["поряжав"],
    "поряжаться": ["порядиться", "наниматься", "браться", "договариваться", "уславливаться", "торговаться"],
    "поряпаться": ["потрескаться", "продырявиться"],
    "посад": ["подол", "пригород", "предместье", "посёлок городского типа"],
    "посадив": ["посадивши"],
    "посадивши": ["посадив"],
    "посадничав": ["посадничавши"],
    "посадничавши": ["посадничав"],
    "посадочная страница": ["лендинг", "лэндинг", "целевая страница"],
    "посажав": ["посажавши"],
    "посажавши": ["посажав"],
    "посалив": ["посаливши"],
    "посаливав": ["посаливавши"],
    "посаливавши": ["посаливав"],
    "посаливши": ["посалив"],
    "посамовольничав": ["посамовольничавши"],
    "посамовольничавши": ["посамовольничав"],
    "посапывав": ["посапывавши"],
    "посапывавши": ["посапывав"],
    "посапыванье": ["посапывание"],
    "посасывав": ["посасывавши"],
    "посасывавши": ["посасывав"],
    "посасывать": ["суслить"],
    "посахарив": ["посахаривши"],
    "посахаривши": ["посахарив"],
    "посачковав": ["посачковавши"],
    "посачковавши": ["посачковав"],
    "посбавив": ["посбавивши"],
    "посбавивши": ["посбавив"],
    "посбив": ["посбивши"],
    "посбивав": ["посбивавши"],
    "посбивавши": ["посбивав"],
    "посбивши": ["посбив"],
    "посбирав": ["посбиравши"],
    "посбиравши": ["посбирав"],
    "посбрасывав": ["посбрасывавши"],
    "посбрасывавши": ["посбрасывав"],
    "посбрасывать": ["посбросать"],
    "посбросав": ["посбросавши"],
    "посбросавши": ["посбросав"],
    "посбросать": ["посбрасывать"],
    "посбросив": ["посбросивши"],
    "посбросивши": ["посбросив"],
    "посватав": ["посватавши"],
    "посватавши": ["посватав"],
    "посвежев": ["посвежевши"],
    "посвежевши": ["посвежев"],
    "посверкав": ["посверкавши"],
    "посверкавши": ["посверкав"],
    "посверкивав": ["посверкивавши"],
    "посверкивавши": ["посверкивав"],
    "посверкиванье": ["посверкивание"],
    "посверлив": ["посверливши"],
    "посверливши": ["посверлив"],
    "посветив": ["посветивши"],
    "посветивши": ["посветив"],
    "посветлев": ["посветлевши"],
    "посветлевши": ["посветлев"],
    "посветлив": ["посветливши"],
    "посветливши": ["посветлив"],
    "посветлить": ["высветлить"],
    "посвечивав": ["посвечивавши"],
    "посвечивавши": ["посвечивав"],
    "посвиристев": ["посвиристевши"],
    "посвиристевши": ["посвиристев"],
    "посвистав": ["посвиставши"],
    "посвиставши": ["посвистав"],
    "посвистать": ["посвистеть"],
    "посвистев": ["посвистевши"],
    "посвистевши": ["посвистев"],
    "посвистывав": ["посвистывавши"],
    "посвистывавши": ["посвистывав"],
    "посвистыванье": ["посвистывание"],
    "посвистывать": ["свистеть"],
    "посвятив": ["посвятивши"],
    "посвятивши": ["посвятив"],
    "посвящав": ["посвящавши"],
    "посвящавши": ["посвящав"],
    "посвящение": ["посвященье"],
    "посвященье": ["посвящение"],
    "посвящённый": ["предназначенный"],
    "посгладив": ["посгладивши"],
    "посгладивши": ["посгладив"],
    "посдвинув": ["посдвинувши"],
    "посдвинувши": ["посдвинув"],
    "посдержав": ["посдержавши"],
    "посдержавши": ["посдержав"],
    "посдурев": ["посдуревши"],
    "посдуревши": ["посдурев"],
    "посебятничав": ["посебятничавши"],
    "посебятничавши": ["посебятничав"],
    "поседев": ["поседевши"],
    "поседевши": ["поседев"],
    "поседлав": ["поседлавши"],
    "поседлавши": ["поседлав"],
    "посейдон": ["посидон", "нептун"],
    "посейчас": ["доныне", "доднесь", "поныне", "поднесь", "доселе", "досель"],
    "посекав": ["посекавши"],
    "посекавши": ["посекав"],
    "посекретничав": ["посекретничавши"],
    "посекретничавши": ["посекретничав"],
    "посекундно": ["ежесекундно"],
    "посекунчик": ["посикунчик"],
    "поселенец": ["ссыльнопоселенец", "ссыльный"],
    "поселение": ["заселение", "вселение", "населённый пункт", "ссылка"],
    "поселив": ["поселивши"],
    "поселивши": ["поселив"],
    "поселяв": ["поселявши"],
    "поселявши": ["поселяв"],
    "поселянский": ["крестьянский", "деревенский"],
    "посеменив": ["посеменивши"],
    "посеменивши": ["посеменив"],
    "посему": ["поэтому", "потому", "в связи с этим"],
    "посердив": ["посердивши"],
    "посердивши": ["посердив"],
    "посеребрив": ["посеребривши"],
    "посеребривши": ["посеребрив"],
    "посеребряв": ["посеребрявши"],
    "посеребрявши": ["посеребряв"],
    "посерев": ["посеревши"],
    "посеревши": ["посерев"],
    "посередине": ["посредине", "посреди", "в центре", "посерёдке", "посередь"],
    "посередь": ["посредине", "в центре", "посередине", "посерёдке"],
    "посерчав": ["посерчавши"],
    "посерчавши": ["посерчав"],
    "посерьёзнев": ["посерьёзневши"],
    "посерьёзневши": ["посерьёзнев"],
    "посерёдке": ["посредине", "посередине"],
    "посессивность": ["притяжательность"],
    "посессор": ["посессионер"],
    "посестра": ["подруга"],
    "посетивши": ["посетив"],
    "посетить": ["побывать"],
    "посетовав": ["посетовавши"],
    "посетовавши": ["посетовав"],
    "посещав": ["посещавши"],
    "посещавши": ["посещав"],
    "посещать": ["навещать", "приходить с визитом", "приходить", "охватывать"],
    "посещение": ["визит"],
    "посещенье": ["посещение"],
    "посеяв": ["посеявши"],
    "посеявши": ["посеяв"],
    "посеянный": ["высеянный", "зароненный"],
    "посеять": ["заморосить"],
    "посибаритствовав": ["посибаритствовавши"],
    "посибаритствовавши": ["посибаритствовав"],
    "посивев": ["посивевши"],
    "посивевши": ["посивев"],
    "посигналив": ["посигналивши"],
    "посигналивши": ["посигналив"],
    "посидев": ["посидевши"],
    "посидевши": ["посидев"],
    "посиделки": ["беседа", "беседки", "посидки", "посиденки", "супрядки", "гостинки", "досветки", "вечерина", "вечеринка", "вечорка", "вечорочка", "посидёнка", "посидёнки", "посёдки", "посидёнок"],
    "посиживав": ["посиживавши"],
    "посиживавши": ["посиживав"],
    "посизев": ["посизевши"],
    "посизевши": ["посизев"],
    "посикав": ["посикавши"],
    "посикавши": ["посикав"],
    "посикать": ["пописать", "помочиться"],
    "посикунчик": ["посекунчик"],
    "посилати": ["слати"],
    "посинев": ["посиневши"],
    "посиневши": ["посинев"],
    "посиненье": ["посинение"],
    "посинячив": ["посинячивши"],
    "посинячивши": ["посинячив"],
    "посипев": ["посипевши"],
    "посипевши": ["посипев"],
    "посиротив": ["посиротивши"],
    "посиротивши": ["посиротив"],
    "посияв": ["посиявши"],
    "посиявши": ["посияв"],
    "поскабливав": ["поскабливавши"],
    "поскабливавши": ["поскабливав"],
    "поскакав": ["поскакавши"],
    "поскакавши": ["поскакав"],
    "поскакивав": ["поскакивавши"],
    "поскакивавши": ["поскакивав"],
    "поскакушка": ["скакушка", "квакушка"],
    "поскалив": ["поскаливши"],
    "поскаливши": ["поскалив"],
    "поскандалив": ["поскандаливши"],
    "поскандаливши": ["поскандалив"],
    "посквернословив": ["посквернословивши"],
    "посквернословивши": ["посквернословив"],
    "поскидав": ["поскидавши"],
    "поскидавши": ["поскидав"],
    "поскидывав": ["поскидывавши"],
    "поскидывавши": ["поскидывав"],
    "поскоблив": ["поскобливши"],
    "поскобливши": ["поскоблив"],
    "поскользив": ["поскользивши"],
    "поскользивши": ["поскользив"],
    "поскользнуться": ["подскользнуться"],
    "поскольку": ["так как", "ибо", "понеже"],
    "посконница": ["оборванка"],
    "посконный": ["сермяжный"],
    "поскорбев": ["поскорбевши"],
    "поскорбевши": ["поскорбев"],
    "поскорее": ["скорее", "быстрее", "побыстрее", "поживее"],
    "поскрежетав": ["поскрежетавши"],
    "поскрежетавши": ["поскрежетав"],
    "поскрипев": ["поскрипевши"],
    "поскрипевши": ["поскрипев"],
    "поскрипывав": ["поскрипывавши"],
    "поскрипывавши": ["поскрипывав"],
    "поскрипыванье": ["поскрипывание"],
    "поскромнев": ["поскромневши"],
    "поскромневши": ["поскромнев"],
    "поскромничав": ["поскромничавши"],
    "поскромничавши": ["поскромничав"],
    "поскрёбывав": ["поскрёбывавши"],
    "поскрёбывавши": ["поскрёбывав"],
    "поскулив": ["поскуливши"],
    "поскуливав": ["поскуливавши"],
    "поскуливавши": ["поскуливав"],
    "поскуливанье": ["поскуливание"],
    "поскуливши": ["поскулив"],
    "поскучав": ["поскучавши"],
    "поскучавши": ["поскучав"],
    "поскучить": ["затрудниться"],
    "поскучнев": ["поскучневши"],
    "поскучневши": ["поскучнев"],
    "послабев": ["послабевши"],
    "послабевши": ["послабев"],
    "послабив": ["послабивши"],
    "послабивши": ["послабив"],
    "послабленье": ["послабление"],
    "послабляв": ["послаблявши"],
    "послаблявши": ["послабляв"],
    "послав": ["пославши"],
    "пославши": ["послав"],
    "посланец": ["посланник", "гонец", "посыльный"],
    "послание": ["письмо"],
    "посланник": ["посланец"],
    "посланье": ["послание"],
    "посластив": ["посластивши"],
    "посластивши": ["посластив"],
    "послать в пизду": ["послать в эротическое путешествие", "отправить в эротическое путешествие", "послать в пешее эротическое путешествие", "послать к чёртовой бабушке", "отправить к чёртовой бабушке", "послать к едрене фене", "отправить к едрене фене", "послать в жопу", "послать на хуй", "послать к ёбаной матери", "послать к ебеней матери", "послать к ебене матери"],
    "после": ["потом", "затем", "позже", "позднее", "опосля", "за", "вслед за", "по окончании", "по завершении", "по уходу"],
    "после дождичка в четверг": ["когда рак свистнет", "когда рак на горе свистнет"],
    "после драки кулаками не машут": ["спустя лето в лес по малину"],
    "после-": ["пост-"],
    "послеавгустовский": ["поставгустовский"],
    "послеафганский": ["постафганский"],
    "послебольшевистский": ["постбольшевистский"],
    "послевкусье": ["послевкусие"],
    "послевыборный": ["поствыборный"],
    "послегарантийная поддержка": ["послегарантийное обслуживание"],
    "послегарантийный": ["постгарантийный"],
    "послегорбачёвский": ["постгорбачёвский"],
    "послед": ["плацента", "детское место"],
    "последефолтный": ["последефолтовый", "постдефолтный", "постдефолтовый"],
    "последефолтовый": ["последефолтный", "постдефолтный", "постдефолтовый"],
    "последив": ["последивши"],
    "последивши": ["последив"],
    "последний": ["заключительный", "завершительный", "конечный", "крайний", "новейший", "недавний", "свежий"],
    "последний крик моды": ["последний писк моды"],
    "последняя капля": ["терпение лопнуло"],
    "последовав": ["последовавши"],
    "последовавши": ["последовав"],
    "последователь": ["продолжатель", "сторонник", "эпигон"],
    "последовательница": ["приверженка", "сторонница", "ученица", "подруга"],
    "последовательно": ["методично", "систематично", "планомерно", "закономерно", "по очереди", "один за одним"],
    "последовательность": ["логичность", "связность", "непротиворечивость", "порядок", "очерёдность", "череда", "вереница", "цепочка", "ряд"],
    "последовательный": ["поочерёдный", "логичный", "связный", "непротиворечивый"],
    "последствие": ["исход", "итог", "результат", "следствие", "след"],
    "последующий": ["следующий", "очередной"],
    "последыш": ["младшенький", "поскрёбыш"],
    "послеельцинский": ["постъельцинский"],
    "послеживав": ["послеживавши"],
    "послеживавши": ["послеживав"],
    "послезастойный": ["постзастойный"],
    "послеимперский": ["постимперский"],
    "послеинаугурационный": ["постинаугурационный"],
    "послековидный": ["послекоронавирусный", "поствирусный", "посткоронавирусный", "постковидный"],
    "послекоммунистический": ["посткоммунистический"],
    "послеконфликтный": ["постконфликтный"],
    "послекоронавирусный": ["послековидный", "поствирусный", "постковидный", "посткоронавирусный"],
    "послекризисный": ["посткризисный"],
    "послекрымский": ["посткрымский"],
    "послемайданный": ["постмайданный"],
    "послеобраз": ["последовательный образ"],
    "послеолимпийский": ["постолимпийский"],
    "послеотпускной": ["постотпускной"],
    "послеоттепельный": ["постоттепельный"],
    "послепандемийный": ["послепандемический", "постпандемийный", "постпандемический"],
    "послепандемический": ["послепандемийный", "постпандемийный", "постпандемический"],
    "послеперестроечный": ["постперестроечный"],
    "послепис": ["постскриптум"],
    "послепливав": ["послепливавши"],
    "послепливавши": ["послепливав"],
    "послепосевной": ["постпосевной"],
    "послеприватизационный": ["постприватизационный"],
    "послепутчевский": ["послепутчевый", "постпутчевский", "постпутчевый"],
    "послепутчевый": ["послепутчевский", "постпутчевский", "постпутчевый"],
    "послеродовый": ["послеродовой"],
    "послерождественский": ["построждественский"],
    "послесловье": ["послесловие"],
    "послесоветский": ["постсоветский"],
    "послесоциалистический": ["постсоциалистический"],
    "послесоюзный": ["постсоюзный"],
    "послефашистский": ["постфашистский"],
    "послечековый": ["постваучерный", "постчековый"],
    "послечернобыльский": ["постчернобыльский"],
    "послеядерный": ["постъядерный"],
    "пословица": ["поговорка", "крылатое выражение"],
    "пословичный": ["поговорочный"],
    "послойное сканирование": ["томография", "получение среза"],
    "послужив": ["послуживши"],
    "послуживав": ["послуживавши"],
    "послуживавши": ["послуживав"],
    "послуживши": ["послужив"],
    "послушав": ["послушавши"],
    "послушавши": ["послушав"],
    "послушание": ["повиновение", "покорность", "поручение"],
    "послушанье": ["послушание"],
    "послушать": ["прослушать", "услышать"],
    "послушествовав": ["послушествовавши"],
    "послушествовавши": ["послушествовав"],
    "послушивав": ["послушивавши"],
    "послушивавши": ["послушивав"],
    "послушливый": ["послушный"],
    "послушничав": ["послушничавши"],
    "послушничавши": ["послушничав"],
    "послышав": ["послышавши"],
    "послышавши": ["послышав"],
    "послышаться": ["раздаться", "зазвучать", "донестись", "показаться", "померещиться"],
    "послюнив": ["послюнивши"],
    "послюнивав": ["послюнивавши"],
    "послюнивавши": ["послюнивав"],
    "послюнивши": ["послюнив"],
    "послюнявив": ["послюнявивши"],
    "послюнявивши": ["послюнявив"],
    "посмаковав": ["посмаковавши"],
    "посмаковавши": ["посмаковав"],
    "посматривав": ["посматривавши"],
    "посматривавши": ["посматривав"],
    "посматривать": ["глядеть", "взглядывать", "осматриваться", "поглядывать", "смотреть", "наблюдать", "присматривать"],
    "посмев": ["посмевши"],
    "посмевши": ["посмев"],
    "посмекав": ["посмекавши"],
    "посмекавши": ["посмекав"],
    "посмелев": ["посмелевши"],
    "посмелевши": ["посмелев"],
    "посмертный": ["загробный", "замогильный", "некрологический"],
    "посмертье": ["посмертие"],
    "посметь": ["осмелиться", "отважиться"],
    "посмешив": ["посмешивши"],
    "посмешивши": ["посмешив"],
    "посмешище": ["предмет насмешек", "притча во языцех", "чучело гороховое", "шут гороховый", "осмеяние", "глумление", "посмеяние"],
    "посмеянье": ["посмеяние"],
    "посмирнев": ["посмирневши"],
    "посмирневши": ["посмирнев"],
    "посмолив": ["посмоливши"],
    "посмоливши": ["посмолив"],
    "посмотрев": ["посмотревши"],
    "посмотревши": ["посмотрев"],
    "посмотренье": ["посмотрение"],
    "посмотреть": ["взглянуть"],
    "посмуглев": ["посмуглевши"],
    "посмуглевши": ["посмуглев"],
    "посмурнев": ["посмурневши"],
    "посмурневши": ["посмурнев"],
    "посмыв": ["посмывши"],
    "посмывав": ["посмывавши"],
    "посмывавши": ["посмывав"],
    "посмывши": ["посмыв"],
    "поснедав": ["поснедавши"],
    "поснедавши": ["поснедав"],
    "поснимав": ["поснимавши"],
    "поснимавши": ["поснимав"],
    "посновав": ["посновавши"],
    "посновавши": ["посновав"],
    "посносив": ["посносивши"],
    "посносивши": ["посносив"],
    "посношав": ["посношавши"],
    "посношавши": ["посношав"],
    "поснув": ["поснувши"],
    "поснувши": ["поснув"],
    "посняв": ["поснявши"],
    "поснявши": ["посняв"],
    "пособив": ["пособивши"],
    "пособивши": ["пособив"],
    "пособие": ["помощь", "поддержка", "учебник", "вспомоществование", "субсидия", "субвенция"],
    "пособирав": ["пособиравши"],
    "пособиравши": ["пособирав"],
    "пособить": ["помочь", "подсобить"],
    "пособляв": ["пособлявши"],
    "пособлявши": ["пособляв"],
    "пособлять": ["помогать"],
    "пособник": ["помощник", "сообщник", "соучастник", "подельник"],
    "пособничав": ["пособничавши"],
    "пособничавши": ["пособничав"],
    "пособничать": ["содействовать", "помогать"],
    "пособолезновав": ["пособолезновавши"],
    "пособолезновавши": ["пособолезновав"],
    "пособолезновать": ["пожалеть"],
    "пособоровав": ["пособоровавши"],
    "пособоровавши": ["пособоровав"],
    "пособье": ["пособие"],
    "посовав": ["посовавши"],
    "посовавши": ["посовав"],
    "посовестив": ["посовестивши"],
    "посовестивши": ["посовестив"],
    "посоветовав": ["посоветовавши"],
    "посоветовавши": ["посоветовав"],
    "посоветовать": ["дать совет"],
    "посоветоваться": ["проконсультироваться", "посовещаться"],
    "посогрев": ["посогревши"],
    "посогревши": ["посогрев"],
    "посодействовав": ["посодействовавши"],
    "посодействовавши": ["посодействовав"],
    "посодействовать": ["помочь"],
    "посожалев": ["посожалевши"],
    "посожалевши": ["посожалев"],
    "посозерцав": ["посозерцавши"],
    "посозерцавши": ["посозерцав"],
    "посока": ["направление", "насока"],
    "посократив": ["посокративши"],
    "посокративши": ["посократив"],
    "посол": ["амбассадор", "посланец", "гонец", "депутат"],
    "посолив": ["посоливши"],
    "посоливши": ["посолив"],
    "посолиднев": ["посолидневши"],
    "посолидневши": ["посолиднев"],
    "посоловев": ["посоловевши"],
    "посоловевши": ["посоловев"],
    "посолонь": ["по часовой стрелке"],
    "посольство": ["дипмиссия"],
    "посомниться": ["усомниться", "засомневаться", "поколебаться", "поставить под сомнение", "поставить под вопрос"],
    "посоображав": ["посоображавши"],
    "посоображавши": ["посоображав"],
    "посопев": ["посопевши"],
    "посопевши": ["посопев"],
    "посоперничав": ["посоперничавши"],
    "посоперничавши": ["посоперничав"],
    "посорив": ["посоривши"],
    "посоривши": ["посорив"],
    "посорка": ["сорочек"],
    "пососав": ["пососавши"],
    "пососавши": ["пососав"],
    "пососаться": ["поцеловаться"],
    "посотрудничав": ["посотрудничавши"],
    "посотрудничавши": ["посотрудничав"],
    "посохнув": ["посохнувши"],
    "посохнувши": ["посохнув"],
    "посочиняв": ["посочинявши"],
    "посочинявши": ["посочиняв"],
    "посочувствовав": ["посочувствовавши"],
    "посочувствовавши": ["посочувствовав"],
    "посошок": ["посох"],
    "поспав": ["поспавши"],
    "поспавши": ["поспав"],
    "поспалан": ["поспаланко", "сънльо", "сънливко"],
    "поспев": ["поспевши"],
    "поспевав": ["поспевавши"],
    "поспевавши": ["поспевав"],
    "поспевать": ["спеть", "созревать"],
    "поспевши": ["поспев"],
    "поспешав": ["поспешавши"],
    "поспешавши": ["поспешав"],
    "поспешенье": ["поспешение"],
    "поспешествовав": ["поспешествовавши"],
    "поспешествовавши": ["поспешествовав"],
    "поспешествовать": ["способствовать", "содействовать"],
    "поспешив": ["поспешивши"],
    "поспешивши": ["поспешив"],
    "поспешить": ["поторопиться"],
    "поспешно": ["торопливо"],
    "поспешность": ["спешка", "торопливость", "необдуманность", "опрометчивость"],
    "поспешный": ["скоропалительный"],
    "посплетничав": ["посплетничавши"],
    "посплетничавши": ["посплетничав"],
    "посполитый": ["народный", "всенародный", "всеобщий", "простой", "простонародный", "плебейский"],
    "поспорив": ["поспоривши"],
    "поспоривши": ["поспорив"],
    "поспорить": ["заключить пари"],
    "поспособив": ["поспособивши"],
    "поспособивши": ["поспособив"],
    "поспособить": ["помочь", "посодействовать", "поспособствовать", "поспопутствовать", "пособить"],
    "поспособствовав": ["поспособствовавши"],
    "поспособствовавши": ["поспособствовав"],
    "поспособствовать": ["помочь", "посодействовать", "поспособить", "поспопутствовать", "пособить"],
    "поспрашивав": ["поспрашивавши"],
    "поспрашивавши": ["поспрашивав"],
    "поспросив": ["поспросивши"],
    "поспросивши": ["поспросив"],
    "поспрошав": ["поспрошавши"],
    "поспрошавши": ["поспрошав"],
    "поспрошать": ["поспросить", "расспросить", "разузнать"],
    "поспрыгивав": ["поспрыгивавши"],
    "поспрыгивавши": ["поспрыгивав"],
    "посрав": ["посравши"],
    "посравнив": ["посравнивши"],
    "посравнивав": ["посравнивавши"],
    "посравнивавши": ["посравнивав"],
    "посравнивши": ["посравнив"],
    "посравши": ["посрав"],
    "посрамив": ["посрамивши"],
    "посрамивши": ["посрамив"],
    "посрамленье": ["посрамление"],
    "посрамляв": ["посрамлявши"],
    "посрамлявши": ["посрамляв"],
    "посрать": ["сходить по-большому", "сходить в туалет по-большому", "сходить на двор", "сходить до ветру", "покакать", "погадить", "поверзать", "похезать"],
    "посраться": ["поругаться", "разругаться", "поссориться", "повздорить"],
    "посреди": ["посредине", "посередине"],
    "посредине": ["посередине", "посерёдке", "посередь", "посреди", "в центре"],
    "посредник": ["медиатор"],
    "посредница": ["сводница", "агент", "брокер"],
    "посредничав": ["посредничавши"],
    "посредничавши": ["посредничав"],
    "посредственно": ["опосредованно", "неважно", "заурядно"],
    "посредственный": ["заурядный", "изрядный"],
    "посредствовав": ["посредствовавши"],
    "посредствовавши": ["посредствовав"],
    "посредством": ["при помощи", "с помощью"],
    "посрывав": ["посрывавши"],
    "посрывавши": ["посрывав"],
    "поссав": ["поссавши"],
    "поссавши": ["поссав"],
    "поссорив": ["поссоривши"],
    "поссоривши": ["поссорив"],
    "поссорить": ["рассорить"],
    "поссориться": ["рассориться"],
    "пост": ["часовой", "охранник"],
    "пост-": ["после-"],
    "постав": ["бегун"],
    "поставгустовский": ["послеавгустовский"],
    "поставец": ["погребец", "ставец", "светец"],
    "поставив": ["поставивши"],
    "поставивши": ["поставив"],
    "поставить к стенке": ["расстрелять", "приговорить к расстрелу", "к стенке поставить", "вывести в расход", "пустить в расход", "пустить в распыл", "пустить на распыл", "наказать", "поставить в угол"],
    "поставить крест": ["подписаться", "принять", "окончательный", "решение", "перечеркнуть", "отчаяться", "похоронить"],
    "поставить на место": ["осадить", "расставить по местам", "расставить по своим местам", "вернуться на круги своя"],
    "поставить с ног на голову": ["вверх дном", "вверх тормашками", "шиворот на выворот", "посеять хаос"],
    "поставить чайник": ["вскипятить чайник"],
    "поставленье": ["поставление"],
    "поставляв": ["поставлявши"],
    "поставлявши": ["поставляв"],
    "постаивав": ["постаивавши"],
    "постаивавши": ["постаивав"],
    "постамат": ["почтомат"],
    "постамент": ["пьедестал"],
    "постанавливав": ["постанавливавши"],
    "постанавливавши": ["постанавливав"],
    "постановив": ["постановивши"],
    "постановивши": ["постановив"],
    "постановка": ["спектакль"],
    "постановление": ["установка", "обычай", "декрет", "указ", "решение", "резолюция"],
    "постановленье": ["постановление"],
    "постановляв": ["постановлявши"],
    "постановлявши": ["постановляв"],
    "постанывав": ["постанывавши"],
    "постанывавши": ["постанывав"],
    "постаныванье": ["постанывание"],
    "постапок": ["постапокалипсис", "постапокалиптика"],
    "постарев": ["постаревши"],
    "постаревши": ["постарев"],
    "постарелый": ["постаревший", "поседевший", "обветшалый", "одряхлевший", "остаревший", "одряхлелый", "поседелый"],
    "постаренье": ["постарение"],
    "постафганский": ["послеафганский"],
    "постаяв": ["постаявши"],
    "постаявши": ["постаяв"],
    "постбольшевистский": ["послебольшевистский"],
    "постваучерный": ["послечековый", "постчековый", "послеприватизационный", "послеваучерный", "постприватизационный"],
    "поствирусный": ["послековидный", "послекоронавирусный", "постковидный", "посткоронавирусный"],
    "поствыборный": ["послевыборный"],
    "постгарантийный": ["послегарантийный"],
    "постглагольный": ["заглагольный"],
    "постгорбачёвский": ["послегорбачёвский"],
    "постдефолтный": ["последефолтный", "последефолтовый", "постдефолтовый"],
    "постдефолтовый": ["последефолтный", "последефолтовый", "постдефолтный"],
    "постдочив": ["постдочивши"],
    "постдочивши": ["постдочив"],
    "постебав": ["постебавши"],
    "постебавши": ["постебав"],
    "постегав": ["постегавши"],
    "постегавши": ["постегав"],
    "постелив": ["постеливши"],
    "постеливши": ["постелив"],
    "постелить": ["постлать", "расстелить"],
    "постеля": ["постель", "ложе", "одр"],
    "постепенный": ["плавный"],
    "постеролатеральный": ["заднелатеральный"],
    "постеромедиальный": ["заднемедиальный"],
    "постеснив": ["постеснивши"],
    "постеснивши": ["постеснив"],
    "постесняв": ["постеснявши"],
    "постеснявши": ["постесняв"],
    "постзастойный": ["послезастойный"],
    "постив": ["постивши"],
    "постивши": ["постив"],
    "постигав": ["постигавши"],
    "постигавши": ["постигав"],
    "постигання": ["устигання"],
    "постигать": ["понимать", "уяснять", "случаться", "происходить"],
    "постигновение": ["постижение"],
    "постигнувши": ["постигнув"],
    "постигнуть": ["постичь", "понять", "уяснить", "осмыслить", "настигнуть", "настичь"],
    "постиженье": ["постижение"],
    "постижимость": ["понятность"],
    "постижимый": ["понятный", "ясный", "доступный", "внятный"],
    "постилав": ["постилавши"],
    "постилавши": ["постилав"],
    "постимперский": ["послеимперский"],
    "постиндустриальный": ["послеиндустриальный"],
    "постирав": ["постиравши"],
    "постиравши": ["постирав"],
    "постить": ["поститься"],
    "постихнув": ["постихнувши"],
    "постихнувши": ["постихнув"],
    "постичь": ["понять", "постигнуть", "выпасть на долю", "случиться"],
    "постковидный": ["послековидный", "послекоронавирусный", "поствирусный", "посткоронавирусный"],
    "постковидный синдром": ["длинный ковид", "лонг-ковид", "постковид"],
    "посткоммунизм": ["постсоциализм"],
    "посткоммунистический": ["послекоммунистический"],
    "постконфликтный": ["послеконфликтный"],
    "посткоронавирусный": ["послековидный", "послекоронавирусный", "поствирусный", "постковидный"],
    "посткризисный": ["послекризисный"],
    "посткрымский": ["послекрымский"],
    "постлабиум": ["постментум"],
    "постлав": ["постлавши"],
    "постлавши": ["постлав"],
    "постлать": ["постелить"],
    "постмайданный": ["послемайданный"],
    "постмодерация": ["постмодерирование"],
    "постмодернизм": ["постмодерн"],
    "постничав": ["постничавши"],
    "постничавши": ["постничав"],
    "постничать": ["поститься", "скупиться", "жадничать"],
    "постно": ["уныло"],
    "постное масло": ["конопляное масло", "льняное масло", "прованское масло", "маковое масло", "кунжутное масло", "рыбий жир", "подсолнечное масло", "кукурузное масло", "горчичное масло"],
    "постный": ["диетический", "вегетарианский", "голодный", "полуголодный", "трудный", "тяжёлый", "нищий", "унылый", "грустный", "понурый", "тоскливый", "скучный", "вялый"],
    "постоловав": ["постоловавши"],
    "постоловавши": ["постоловав"],
    "постомат": ["почтомат"],
    "постоперационный": ["послеоперационный", "посттравматический"],
    "посторожив": ["постороживши"],
    "постороживши": ["посторожив"],
    "посторонний": ["чужой"],
    "постоттепельный": ["послеоттепельный"],
    "постояв": ["постоявши"],
    "постоявши": ["постояв"],
    "постоялец": ["жилец"],
    "постоянная": ["константа"],
    "постоянно": ["непрерывно", "вечно", "перманентно", "долгосрочно", "всегда", "обычно", "регулярно"],
    "постоянность": ["постоянство", "неизменность"],
    "постоянный": ["неизменный", "непрерывный", "перманентный", "статический", "вечный"],
    "постоянство": ["неизменность"],
    "постоять": ["простоять", "вступиться", "подождать", "повременить", "погодить"],
    "постпандемийный": ["послепандемийный", "послепандемический", "постпандемический"],
    "постпандемический": ["послепандемийный", "послепандемический", "постпандемийный"],
    "постпанковский": ["постпанковый"],
    "постпанковый": ["постпанковский"],
    "постперестроечный": ["послеперестроечный"],
    "постпред": ["постоянный представитель"],
    "постприватизационный": ["послеприватизационный"],
    "постпродакшен": ["постпроизводство"],
    "постпутчевский": ["послепутчевский", "послепутчевый", "постпутчевый"],
    "постпутчевый": ["послепутчевский", "послепутчевый", "постпутчевский"],
    "пострагивав": ["пострагивавши"],
    "пострагивавши": ["пострагивав"],
    "пострадав": ["пострадавши"],
    "пострадавши": ["пострадав"],
    "пострадавший": ["потерпевший", "жертва"],
    "постранничав": ["постранничавши"],
    "постранничавши": ["постранничав"],
    "постранствовав": ["постранствовавши"],
    "постранствовавши": ["постранствовав"],
    "постраховав": ["постраховавши"],
    "постраховавши": ["постраховав"],
    "постращав": ["постращавши"],
    "постращавши": ["постращав"],
    "постращать": ["попугать"],
    "пострегистрационный": ["послерегистрационный"],
    "пострекав": ["пострекавши"],
    "пострекавши": ["пострекав"],
    "пострекотав": ["пострекотавши"],
    "пострекотавши": ["пострекотав"],
    "пострел": ["пострелёнок", "озорник", "сорванец"],
    "пострелив": ["постреливши"],
    "постреливав": ["постреливавши"],
    "постреливавши": ["постреливав"],
    "постреливши": ["пострелив"],
    "постреляв": ["пострелявши"],
    "пострелявши": ["постреляв"],
    "пострелять": ["попалить"],
    "пострелёнок": ["пострел", "озорник", "сорванец"],
    "постригав": ["постригавши"],
    "постригавши": ["постригав"],
    "постригаемый": ["подстригаемый"],
    "постриженье": ["пострижение"],
    "построгав": ["построгавши"],
    "построгавши": ["построгав"],
    "построение": ["выстраивание", "строительство", "строение", "структура", "устройство", "концепция"],
    "построенье": ["построение"],
    "построжав": ["построжавши"],
    "построжавши": ["построжав"],
    "построждественский": ["послерождественский"],
    "построжев": ["построжевши"],
    "построжевши": ["построжев"],
    "построив": ["построивши"],
    "построивши": ["построив"],
    "построитель": ["строитель"],
    "построить": ["соорудить", "выстроить", "созиждить", "сформировать", "организовать"],
    "постройка": ["строение", "корпус"],
    "постройнев": ["постройневши"],
    "постройневши": ["постройнев"],
    "постройщик": ["строитель", "построитель"],
    "построчив": ["построчивши"],
    "построчивши": ["построчив"],
    "постругав": ["постругавши"],
    "постругавши": ["постругав"],
    "постругивав": ["постругивавши"],
    "постругивавши": ["постругивав"],
    "постряпав": ["постряпавши"],
    "постряпавши": ["постряпав"],
    "постсоветский": ["послесоветский"],
    "постсоветское пространство": ["ближнее зарубежье"],
    "постсовок": ["постсоветское пространство"],
    "постсоциализм": ["посткоммунизм"],
    "постсоциалистический": ["послесоциалистический"],
    "постсоюзный": ["послесоюзный"],
    "посттрадиционализм": ["постмодерн"],
    "постудив": ["постудивши"],
    "постудивши": ["постудив"],
    "постукав": ["постукавши"],
    "постукавши": ["постукав"],
    "постукивав": ["постукивавши"],
    "постукивавши": ["постукивав"],
    "постукиванье": ["постукивание"],
    "постулат": ["аксиома"],
    "постулировав": ["постулировавши"],
    "постулировавши": ["постулировав"],
    "поступав": ["поступавши"],
    "поступавши": ["поступав"],
    "поступать": ["достигать", "оказываться", "приходить", "прибывать", "доставляться", "устраиваться", "зачисляться", "действовать", "вести себя"],
    "поступаться": ["жертвовать", "уступать"],
    "поступив": ["поступивши"],
    "поступивши": ["поступив"],
    "поступить": ["делать", "устроиться", "зачислиться", "определиться", "войти"],
    "поступленье": ["поступление"],
    "поступок": ["шаг", "действие"],
    "поступь": ["походка"],
    "постуральный": ["позотонический"],
    "постучав": ["постучавши"],
    "постучавши": ["постучав"],
    "постучаться": ["постучать", "прийти", "наступить", "настать"],
    "постфашистский": ["послефашистский"],
    "постфургаловский": ["постфургальский"],
    "постфургальский": ["постфургаловский"],
    "постчековый": ["послечековый", "постваучерный"],
    "постчернобыльский": ["послечернобыльский"],
    "постъельцинский": ["послеельцинский"],
    "постъядерный": ["послеядерный"],
    "постыв": ["постывши"],
    "постывши": ["постыв"],
    "постыдив": ["постыдивши"],
    "постыдивши": ["постыдив"],
    "постыдить": ["пристыдить", "осрамить", "посрамить", "обесчестить", "нанести бесчестье", "нанести позор", "нанести срам"],
    "постыдный": ["позорный"],
    "постыжать": ["срамить", "бесчестить", "обесчещивать", "осрамлять", "позорить", "посрамлять", "опозоривать", "наносить бесчестье", "наносить срам", "наносить стыд"],
    "постылев": ["постылевши"],
    "постылевши": ["постылев"],
    "постылый": ["надоевший", "нелюбимый", "противный"],
    "постынув": ["постынувши"],
    "постынувши": ["постынув"],
    "постэмбриональный": ["послезародышевый"],
    "постёгивав": ["постёгивавши"],
    "постёгивавши": ["постёгивав"],
    "посудачив": ["посудачивши"],
    "посудачивши": ["посудачив"],
    "посудив": ["посудивши"],
    "посудивши": ["посудив"],
    "посудина": ["посуда"],
    "посудница": ["посудомойка", "посудомойщица", "судомойка"],
    "посудомоечная машина": ["посудомойка"],
    "посудомой": ["посудник"],
    "посудомойка": ["посудница", "посудомойщица", "судомойка", "посудомоечная машина", "мойка", "моечная", "посудомойня"],
    "посудомойщица": ["посудомойка", "посудница", "судомойка"],
    "посуетив": ["посуетивши"],
    "посуетивши": ["посуетив"],
    "посул": ["обещание", "взятка"],
    "посулив": ["посуливши"],
    "посуливши": ["посулив"],
    "посумасшествовав": ["посумасшествовавши"],
    "посумасшествовавши": ["посумасшествовав"],
    "посумерничав": ["посумерничавши"],
    "посумерничавши": ["посумерничав"],
    "посумниться": ["засомневаться"],
    "посумрачнев": ["посумрачневши"],
    "посумрачневши": ["посумрачнев"],
    "посуровев": ["посуровевши"],
    "посуровевши": ["посуровев"],
    "посурьмив": ["посурьмивши"],
    "посурьмивши": ["посурьмив"],
    "посурьмить": ["насурьмить", "начернить"],
    "посурьмиться": ["насурьмиться"],
    "посуслив": ["посусливши"],
    "посусливши": ["посуслив"],
    "посуточно": ["суточно", "краткосрочно"],
    "посутяжив": ["посутяживши"],
    "посутяживши": ["посутяжив"],
    "посуфлировав": ["посуфлировавши"],
    "посуфлировавши": ["посуфлировав"],
    "посуха": ["засуха", "суша"],
    "посучив": ["посучивши"],
    "посучивши": ["посучив"],
    "посушив": ["посушивши"],
    "посушивши": ["посушив"],
    "посхимив": ["посхимивши"],
    "посхимивши": ["посхимив"],
    "посходив": ["посходивши"],
    "посходивши": ["посходив"],
    "посчастливев": ["посчастливевши"],
    "посчастливевши": ["посчастливев"],
    "посчастливив": ["посчастлививши"],
    "посчастлививши": ["посчастливив"],
    "посчастливиться": ["довестись", "повезти"],
    "посчитав": ["посчитавши"],
    "посчитавши": ["посчитав"],
    "посчитать": ["сосчитать", "пересчитать", "перечислить", "подсчитать", "вычислить", "счесть", "принять"],
    "посчитывав": ["посчитывавши"],
    "посчитывавши": ["посчитывав"],
    "посшибав": ["посшибавши"],
    "посшибавши": ["посшибав"],
    "посшибив": ["посшибивши"],
    "посшибивши": ["посшибив"],
    "посылав": ["посылавши"],
    "посылавши": ["посылав"],
    "посылать в пизду": ["посылать в эротическое путешествие", "отправлять в эротическое путешествие", "посылать в пешее эротическое путешествие", "посылать к чёртовой бабушке", "отправлять к чёртовой бабушке", "посылать к едрене фене", "отправлять к едрене фене", "посылать на хуй", "посылать к ёбаной матери", "посылать к ебеней матери", "посылать к ебене матери"],
    "посылать вдогон": ["лакировать", "полировать", "догонять", "пристёгивать", "посылать вдогонку"],
    "посылать вдогонку": ["лакировать", "полировать", "догонять", "пристёгивать", "посылать вдогон"],
    "посылать на три буквы": ["посылать в эротическое путешествие", "отправлять в эротическое путешествие", "посылать в пешее эротическое путешествие", "посылать к чёртовой бабушке", "отправлять к чёртовой бабушке", "посылать к едрене фене", "отправлять к едрене фене", "посылать на хуй", "посылать в пизду", "посылать к ёбаной матери", "посылать к ебеней матери", "посылать к ебене матери"],
    "посылочная торговля": ["посылторг"],
    "посылочный": ["посыльный"],
    "посылторг": ["посылочная торговля"],
    "посыльный": ["курьер", "гонец", "нарочный"],
    "посыпав": ["посыпавши"],
    "посыпавши": ["посыпав"],
    "посыпать": ["пойти", "зачастить", "затараторить"],
    "посыпать голову пеплом": ["рвать на себе волосы"],
    "посыпка": ["штрейзель"],
    "посырев": ["посыревши"],
    "посыревши": ["посырев"],
    "посыхав": ["посыхавши"],
    "посыхавши": ["посыхав"],
    "посюсторонний": ["здешний", "реальный", "земной"],
    "посюсюкав": ["посюсюкавши"],
    "посюсюкавши": ["посюсюкав"],
    "посягав": ["посягавши"],
    "посягавши": ["посягав"],
    "посягание": ["посягательство"],
    "посяганье": ["посягание"],
    "посягательство": ["покушение"],
    "посягнув": ["посягнувши"],
    "посягнувши": ["посягнув"],
    "посёлок": ["село", "городок"],
    "посёрфив": ["посёрфивши"],
    "посёрфивши": ["посёрфив"],
    "пот": ["испарина", "мыло", "потение", "потенье"],
    "пота": ["тогда", "потамест", "потаемест", "дока", "дотоле", "потуды", "по то время", "дотуды"],
    "потаив": ["потаивши"],
    "потаивши": ["потаив"],
    "потайной": ["скрытый", "секретный", "тайный"],
    "потакав": ["потакавши"],
    "потакавши": ["потакав"],
    "потакание": ["попустительство", "потворство"],
    "потаканье": ["потакание"],
    "потакатель": ["потакальщик", "потаковник", "потаковщик", "потатчик"],
    "потакать": ["потворствовать", "попустительствовать"],
    "потакнув": ["потакнувши"],
    "потакнувши": ["потакнув"],
    "потаковщик": ["потакальщик", "потатчик"],
    "потаксовав": ["потаксовавши"],
    "потаксовавши": ["потаксовав"],
    "поталкивав": ["поталкивавши"],
    "поталкивавши": ["поталкивав"],
    "поталь": ["шумиха", "сусаль"],
    "потальный": ["сусальный"],
    "потанцевав": ["потанцевавши"],
    "потанцевавши": ["потанцевав"],
    "потанцевать": ["поплясать", "подрыгаться"],
    "потанцовав": ["потанцовавши"],
    "потанцовавши": ["потанцовав"],
    "потапливав": ["потапливавши"],
    "потапливавши": ["потапливав"],
    "потаптывав": ["потаптывавши"],
    "потаптывавши": ["потаптывав"],
    "потарабанив": ["потарабанивши"],
    "потарабанивши": ["потарабанив"],
    "потараторив": ["потараторивши"],
    "потараторивши": ["потараторив"],
    "потарахтев": ["потарахтевши"],
    "потарахтевши": ["потарахтев"],
    "потаскав": ["потаскавши"],
    "потаскавши": ["потаскав"],
    "потаскивав": ["потаскивавши"],
    "потаскивавши": ["потаскивав"],
    "потаскун": ["развратник", "кобель"],
    "потаскунья": ["потаскушка"],
    "потаскуха": ["развратница", "потаскунья", "женщина лёгкого поведения", "шлюха"],
    "потаскуша": ["потаскуха"],
    "потаскушка": ["потаскуха", "потаскунья", "шлюшка"],
    "потаскушничав": ["потаскушничавши"],
    "потаскушничавши": ["потаскушничав"],
    "потасовав": ["потасовавши"],
    "потасовавши": ["потасовав"],
    "потасовка": ["драка", "перебранка", "ссора"],
    "потасовывав": ["потасовывавши"],
    "потасовывавши": ["потасовывав"],
    "потатор": ["алкоголик", "пьяница"],
    "потатуйка": ["удод", "пустушка"],
    "потатчик": ["потакальщик", "потакатель", "потаковник", "потаковщик"],
    "потатчица": ["потворщица"],
    "потачав": ["потачавши"],
    "потачавши": ["потачав"],
    "потачивав": ["потачивавши"],
    "потачивавши": ["потачивав"],
    "потачка": ["потворство", "поблажка"],
    "потачный": ["потачливый"],
    "поташ": ["карбонат калия", "углекислый калий"],
    "поташнивав": ["поташнивавши"],
    "поташнивавши": ["поташнивав"],
    "потащив": ["потащивши"],
    "потащивши": ["потащив"],
    "потаяв": ["потаявши"],
    "потаявши": ["потаяв"],
    "потаённо": ["скрытно", "тайно"],
    "потаённый": ["затаённый", "покровенный", "прикровенный", "сокрытый"],
    "потвердев": ["потвердевши"],
    "потвердевши": ["потвердев"],
    "потворство": ["поблажка", "попустительство", "потакание", "потачка"],
    "потворствовав": ["потворствовавши"],
    "потворствовавши": ["потворствовав"],
    "потворствовать": ["потакать", "попустительствовать", "мирволить", "поблажать", "угождать"],
    "потев": ["потевши"],
    "потевши": ["потев"],
    "потемнев": ["потемневши"],
    "потемневши": ["потемнев"],
    "потемнее": ["потемней"],
    "потемней": ["потемнее"],
    "потемнение": ["помрачение", "почернение", "потускнение", "затемнение"],
    "потемнеть": ["стемнеть"],
    "потемнив": ["потемнивши"],
    "потемнивши": ["потемнив"],
    "потемняв": ["потемнявши"],
    "потемнявши": ["потемняв"],
    "потемпературив": ["потемпературивши"],
    "потемпературивши": ["потемпературив"],
    "потентат": ["властитель", "властелин"],
    "потенциальность": ["возможность"],
    "потенциальный": ["консервативный", "возможный", "вероятный"],
    "потенциометр": ["переменный резистор"],
    "потенцировав": ["потенцировавши"],
    "потенцировавши": ["потенцировав"],
    "потенье": ["потение"],
    "потеоретизировав": ["потеоретизировавши"],
    "потеоретизировавши": ["потеоретизировав"],
    "потеплев": ["потеплевши"],
    "потеплевши": ["потеплев"],
    "потепленье": ["потепление"],
    "потеребив": ["потеребивши"],
    "потеребивши": ["потеребив"],
    "потерев": ["потёрши"],
    "потерзав": ["потерзавши"],
    "потерзавши": ["потерзав"],
    "потерпев": ["потерпевши"],
    "потерпевши": ["потерпев"],
    "потерпеть": ["стерпеть", "снести"],
    "потерпеть фиаско": ["оказаться при пиковом интересе", "остаться при пиковом интересе", "обломать зубы", "обломать себе зубы", "съесть гриб"],
    "потеря": ["утрата"],
    "потеряв": ["потерявши"],
    "потерявши": ["потеряв"],
    "потерять надежду": ["поставить крест"],
    "потерять сознание": ["лишиться чувств", "упасть в обморок", "впасть в беспамятство", "отключиться", "отрубиться", "вырубиться"],
    "потеряться": ["затеряться", "раствориться", "растеряться"],
    "потесав": ["потесавши"],
    "потесавши": ["потесав"],
    "потеснив": ["потеснивши"],
    "потеснивши": ["потеснив"],
    "потесь": ["гребя", "гребло"],
    "потетёшкав": ["потетёшкавши"],
    "потетёшкавши": ["потетёшкав"],
    "потеха": ["утеха", "развлечение", "отдых", "забава", "увеселение"],
    "потешав": ["потешавши"],
    "потешавши": ["потешав"],
    "потешать": ["развлекать", "веселить", "забавлять", "угождать", "утешать"],
    "потешаться": ["подсмеиваться", "подшучивать", "насмехаться", "глумиться", "издеваться", "смеяться", "играть", "развлекаться", "забавляться", "веселиться", "тешиться"],
    "потешив": ["потешивши"],
    "потешивши": ["потешив"],
    "потешить": ["развлечь", "повеселить", "позабавить", "угодить"],
    "потешиться": ["позабавиться"],
    "потешно": ["забавно"],
    "потешный": ["забавный", "распотешный", "потешненький", "распотешненький"],
    "потирав": ["потиравши"],
    "потиравши": ["потирав"],
    "потискав": ["потискавши"],
    "потискавши": ["потискав"],
    "потиснатост": ["униние", "угнетеност", "депресия"],
    "потисник": ["угнетител", "притеснител"],
    "потихоньку": ["тихо", "бесшумно", "тайком", "тайно", "скрытно", "незаметно", "медленно", "не спеша"],
    "потишев": ["потишевши"],
    "потишевши": ["потишев"],
    "потка": ["птица", "птичка"],
    "поткав": ["поткавши"],
    "поткавши": ["поткав"],
    "потогонка": ["потогонная система"],
    "потогонный": ["эксплуататорский", "крепостнический", "рабский"],
    "поток": ["ток", "течение", "расход", "череда", "последовательность", "ряд"],
    "потоковое вещание": ["стриминг", "онлайн-трансляция"],
    "потоле": ["до тех пор", "дотоль"],
    "потолкав": ["потолкавши"],
    "потолкавши": ["потолкав"],
    "потолковав": ["потолковавши"],
    "потолковавши": ["потолковав"],
    "потолок": ["максимум", "чердак"],
    "потолстев": ["потолстевши"],
    "потолстевши": ["потолстев"],
    "потолстеть": ["потучнеть", "пополнеть"],
    "потом": ["затем", "далее", "после", "позже"],
    "потомив": ["потомивши"],
    "потомивши": ["потомив"],
    "потому": ["по причине", "вследствие", "посему", "поэтому"],
    "потому как": ["так как", "потому что"],
    "потому что": ["так как", "поскольку", "понеже", "бо", "ибо"],
    "потон": ["таван"],
    "потонув": ["потонувши"],
    "потонувши": ["потонув"],
    "потончав": ["потончавши"],
    "потончавши": ["потончав"],
    "потоньшав": ["потоньшавши"],
    "потоньшавши": ["потоньшав"],
    "потоньшев": ["потоньшевши"],
    "потоньшевши": ["потоньшев"],
    "потоп": ["наводнение"],
    "потопав": ["потопавши"],
    "потопавши": ["потопав"],
    "потопельник": ["утопленик"],
    "потопив": ["потопивши"],
    "потопивши": ["потопив"],
    "потопляв": ["потоплявши"],
    "потоплявши": ["потопляв"],
    "потопнув": ["потопнувши"],
    "потопнувши": ["потопнув"],
    "потопотав": ["потопотавши"],
    "потопотавши": ["потопотав"],
    "потоптав": ["потоптавши"],
    "потоптавши": ["потоптав"],
    "потопывав": ["потопывавши"],
    "потопывавши": ["потопывав"],
    "поторапливав": ["поторапливавши"],
    "поторапливавши": ["поторапливав"],
    "поторговав": ["поторговавши"],
    "поторговавши": ["поторговав"],
    "поторговывав": ["поторговывавши"],
    "поторговывавши": ["поторговывав"],
    "поторкав": ["поторкавши"],
    "поторкавши": ["поторкав"],
    "потормошив": ["потормошивши"],
    "потормошивши": ["потормошив"],
    "поторопив": ["поторопивши"],
    "поторопивши": ["поторопив"],
    "поторопиться": ["поспешить"],
    "потороча": ["опудало", "привид"],
    "поторчав": ["поторчавши"],
    "поторчавши": ["поторчав"],
    "потосковав": ["потосковавши"],
    "потосковавши": ["потосковав"],
    "поточив": ["поточивши"],
    "поточивши": ["поточив"],
    "поточка": ["клитор", "похотник", "секель", "курок"],
    "потощав": ["потощавши"],
    "потощавши": ["потощав"],
    "потравив": ["потравивши"],
    "потравивши": ["потравив"],
    "потравливав": ["потравливавши"],
    "потравливавши": ["потравливав"],
    "потрагивав": ["потрагивавши"],
    "потрагивавши": ["потрагивав"],
    "потрактовав": ["потрактовавши"],
    "потрактовавши": ["потрактовав"],
    "потрапезовав": ["потрапезовавши"],
    "потрапезовавши": ["потрапезовав"],
    "потратив": ["потративши"],
    "потративши": ["потратив"],
    "потратить": ["затратить", "истратить"],
    "потрафив": ["потрафивши"],
    "потрафивши": ["потрафив"],
    "потрафить": ["удовлетворить", "ублажить", "услужить", "утрафить", "угодить", "угождать", "суметь"],
    "потрафляв": ["потрафлявши"],
    "потрафлявши": ["потрафляв"],
    "потрафлять": ["угождать"],
    "потрахав": ["потрахавши"],
    "потрахавши": ["потрахав"],
    "потрахивав": ["потрахивавши"],
    "потрахивавши": ["потрахивав"],
    "потрахушки": ["перепихон", "ебля", "трах"],
    "потраченный": ["израсходованный", "использованный", "растраченный"],
    "потреба": ["потребность", "надобность"],
    "потребив": ["потребивши"],
    "потребивши": ["потребив"],
    "потребилка": ["потребиловка"],
    "потребиловка": ["потребилка"],
    "потребительство": ["консьюмеризм"],
    "потребиться": ["использоваться", "употребиться"],
    "потребкредит": ["потребзаём"],
    "потребляв": ["потреблявши"],
    "потреблявши": ["потребляв"],
    "потреблять": ["использовать", "есть", "кушать", "пить"],
    "потребно": ["нужно", "надлежит", "необходимо", "следует", "надо", "требуется"],
    "потребность": ["нужда", "расход"],
    "потребовав": ["потребовавши"],
    "потребовавши": ["потребовав"],
    "потребовать": ["запросить"],
    "потребовать удовлетворения": ["потребовать сатисфакции"],
    "потребоваться": ["понадобиться", "занадобиться", "востребоваться"],
    "потревожив": ["потревоживши"],
    "потревоживши": ["потревожив"],
    "потревожить": ["обеспокоить"],
    "потревожиться": ["встревожиться", "забеспокоиться", "обеспокоиться", "растревожиться", "похлопотать", "затруднить себя", "побеспокоиться"],
    "потренив": ["потренивши"],
    "потренивши": ["потренив"],
    "потренировав": ["потренировавши"],
    "потренировавши": ["потренировав"],
    "потренькав": ["потренькавши"],
    "потренькавши": ["потренькав"],
    "потренькивав": ["потренькивавши"],
    "потренькивавши": ["потренькивав"],
    "потрепав": ["потрепавши"],
    "потрепавши": ["потрепав"],
    "потрепетав": ["потрепетавши"],
    "потрепетавши": ["потрепетав"],
    "потрескав": ["потрескавши"],
    "потрескавши": ["потрескав"],
    "потрескавшийся": ["растрескавшийся"],
    "потрескивав": ["потрескивавши"],
    "потрескивавши": ["потрескивав"],
    "потрескиванье": ["потрескивание"],
    "потрещав": ["потрещавши"],
    "потрещавши": ["потрещав"],
    "потривник": ["врэжмаш", "душман"],
    "потрипка": ["ливер"],
    "потрогав": ["потрогавши"],
    "потрогавши": ["потрогав"],
    "потрогать": ["дотронуться", "прикоснуться"],
    "потрогивав": ["потрогивавши"],
    "потрогивавши": ["потрогивав"],
    "потроллив": ["потролливши"],
    "потролливши": ["потроллив"],
    "потроллить": ["подначить", "поддеть", "подразнить", "поиздеваться", "попровоцировать"],
    "потрох": ["внутренности", "требуха"],
    "потроха": ["внутренности", "кишки", "требуха"],
    "потрошив": ["потрошивши"],
    "потрошивши": ["потрошив"],
    "потрошитель": ["мясник"],
    "потрубив": ["потрубивши"],
    "потрубивши": ["потрубив"],
    "потрудив": ["потрудивши"],
    "потрудивши": ["потрудив"],
    "потрудиться": ["поработать"],
    "потрунив": ["потрунивши"],
    "потрунивав": ["потрунивавши"],
    "потрунивавши": ["потрунивав"],
    "потрунивши": ["потрунив"],
    "потрусив": ["потрусивши"],
    "потрусивши": ["потрусив"],
    "потрухивав": ["потрухивавши"],
    "потрухивавши": ["потрухивав"],
    "потрушивав": ["потрушивавши"],
    "потрушивавши": ["потрушивав"],
    "потрюхав": ["потрюхавши"],
    "потрюхавши": ["потрюхав"],
    "потрясав": ["потрясавши"],
    "потрясавши": ["потрясав"],
    "потрясательный": ["потрясающий", "потрясный"],
    "потрясающе": ["поразительно", "изумительно", "восхитительно", "потрясно", "удивительно", "грандиозно", "очень", "великолепно"],
    "потрясение": ["шок", "катаклизм", "перелом"],
    "потрясенье": ["потрясение"],
    "потрясный": ["потрясающий", "ошеломительный", "сногсшибательный"],
    "потрясти": ["поразить", "впечатлить"],
    "потрясывав": ["потрясывавши"],
    "потрясывавши": ["потрясывав"],
    "потрясывать": ["потряхивать"],
    "потряхивав": ["потряхивавши"],
    "потряхивавши": ["потряхивав"],
    "потряхиванье": ["потряхивание"],
    "потрёпанный": ["обтрепанный", "потасканный"],
    "потужив": ["потуживши"],
    "потуживши": ["потужив"],
    "потузив": ["потузивши"],
    "потузивши": ["потузив"],
    "потупив": ["потупивши"],
    "потупивши": ["потупив"],
    "потупляв": ["потуплявши"],
    "потуплявши": ["потупляв"],
    "потурив": ["потуривши"],
    "потуривши": ["потурив"],
    "потурить": ["вытурить", "выгнать", "вытеснить", "выпихнуть", "вытолкнуть", "попереть"],
    "потурчив": ["потурчивши"],
    "потурчивши": ["потурчив"],
    "потусив": ["потусивши"],
    "потусивши": ["потусив"],
    "потусить": ["потусоваться"],
    "потускнев": ["потускневши"],
    "потускневши": ["потускнев"],
    "потускнув": ["потускнувши"],
    "потускнувши": ["потускнув"],
    "потусторонний": ["неземной", "загробный", "замогильный", "тусветный", "пустой", "опустошённый", "безжизненный"],
    "потусторонний мир": ["загробный мир", "тот свет"],
    "потухав": ["потухавши"],
    "потухавши": ["потухав"],
    "потухать": ["гаснуть", "тухнуть"],
    "потухнув": ["потухнувши"],
    "потухнувши": ["потухнув"],
    "потухнути": ["загаснути", "погаснути", "угаснути"],
    "потухнуть": ["погаснуть", "потускнеть", "померкнуть", "сникнуть", "обмякнуть", "утихнуть", "ослабеть"],
    "потучнев": ["потучневши"],
    "потучневши": ["потучнев"],
    "потушевав": ["потушевавши"],
    "потушевавши": ["потушевав"],
    "потушив": ["потушивши"],
    "потушивши": ["потушив"],
    "потчевав": ["потчевавши"],
    "потчевавши": ["потчевав"],
    "потчеванье": ["потчевание"],
    "потчевать": ["угощать"],
    "потщиться": ["постараться", "попытаться", "поусердствовать"],
    "потыкав": ["потыкавши"],
    "потыкавши": ["потыкав"],
    "потырить": ["стырить", "попятить", "украсть"],
    "потыркав": ["потыркавши"],
    "потыркавши": ["потыркав"],
    "потьма": ["темень", "теметь"],
    "потюкав": ["потюкавши"],
    "потюкавши": ["потюкав"],
    "потюкивав": ["потюкивавши"],
    "потюкивавши": ["потюкивав"],
    "потя": ["мяште"],
    "потявкав": ["потявкавши"],
    "потявкавши": ["потявкав"],
    "потявкивав": ["потявкивавши"],
    "потявкивавши": ["потявкивав"],
    "потягав": ["потягавши"],
    "потягавши": ["потягав"],
    "потягивав": ["потягивавши"],
    "потягивавши": ["потягивав"],
    "потягиванье": ["потягивание"],
    "потягушечки": ["потягивание", "потягунюшки", "потягушеньки", "потягушки"],
    "потяжелев": ["потяжелевши"],
    "потяжелевши": ["потяжелев"],
    "потяжка": ["потягивание"],
    "потямс": ["шокшемс"],
    "потянув": ["потянувши"],
    "потянувши": ["потянув"],
    "потёмкинская деревня": ["показуха", "очковтирательство", "туфта", "туфтянка"],
    "потёрши": ["потерев"],
    "потёсывав": ["потёсывавши"],
    "потёсывавши": ["потёсывав"],
    "поубавив": ["поубавивши"],
    "поубавивши": ["поубавив"],
    "поубив": ["поубивши"],
    "поубивав": ["поубивавши"],
    "поубивавши": ["поубивав"],
    "поубивши": ["поубив"],
    "поубрав": ["поубравши"],
    "поубравши": ["поубрав"],
    "поубыв": ["поубывши"],
    "поубывав": ["поубывавши"],
    "поубывавши": ["поубывав"],
    "поубывать": ["поубыть"],
    "поубывши": ["поубыв"],
    "поубыть": ["поубывать"],
    "поувольняв": ["поувольнявши"],
    "поувольнявши": ["поувольняв"],
    "поувянув": ["поувянувши"],
    "поувянувши": ["поувянув"],
    "поугаснув": ["поугаснувши"],
    "поугаснувши": ["поугаснув"],
    "поугорав": ["поугоравши"],
    "поугоравши": ["поугорав"],
    "поугрюмев": ["поугрюмевши"],
    "поугрюмевши": ["поугрюмев"],
    "поудавив": ["поудавивши"],
    "поудавивши": ["поудавив"],
    "поудаляв": ["поудалявши"],
    "поудалявши": ["поудаляв"],
    "поудалять": ["повыкидывать"],
    "поудив": ["поудивши"],
    "поудивляв": ["поудивлявши"],
    "поудивлявши": ["поудивляв"],
    "поудивши": ["поудив"],
    "поуезжав": ["поуезжавши"],
    "поуезжавши": ["поуезжав"],
    "поужинав": ["поужинавши"],
    "поужинавши": ["поужинав"],
    "поука": ["поучение", "наставление"],
    "поукоротив": ["поукоротивши"],
    "поукоротивши": ["поукоротив"],
    "поул": ["поул-позиция", "поул-позишн"],
    "поул-позиция": ["поул", "поул-позишн"],
    "поул-позишн": ["поул", "поул-позиция"],
    "поулечься": ["осесть", "поуспокоиться"],
    "поуменьшив": ["поуменьшивши"],
    "поуменьшивши": ["поуменьшив"],
    "поумерив": ["поумеривши"],
    "поумеривши": ["поумерив"],
    "поумирав": ["поумиравши"],
    "поумиравши": ["поумирав"],
    "поумнев": ["поумневши"],
    "поумневши": ["поумнев"],
    "поумничав": ["поумничавши"],
    "поумничавши": ["поумничав"],
    "поумствовав": ["поумствовавши"],
    "поумствовавши": ["поумствовав"],
    "поунижав": ["поунижавши"],
    "поунижавши": ["поунижав"],
    "поуняв": ["поунявши"],
    "поунявши": ["поуняв"],
    "поупорствовав": ["поупорствовавши"],
    "поупорствовавши": ["поупорствовав"],
    "поуправляв": ["поуправлявши"],
    "поуправлявши": ["поуправляв"],
    "поупражняв": ["поупражнявши"],
    "поупражнявши": ["поупражняв"],
    "поурезав": ["поурезавши"],
    "поурезавши": ["поурезав"],
    "поуркивав": ["поуркивавши"],
    "поуркивавши": ["поуркивав"],
    "поурчав": ["поурчавши"],
    "поурчавши": ["поурчав"],
    "поусердствовав": ["поусердствовавши"],
    "поусердствовавши": ["поусердствовав"],
    "поусердствовать": ["постараться", "переусердствовать"],
    "поусохнув": ["поусохнувши"],
    "поусохнувши": ["поусохнув"],
    "поуспокоив": ["поуспокоивши"],
    "поуспокоивши": ["поуспокоив"],
    "поустав": ["поуставши"],
    "поуставши": ["поустав"],
    "поустарев": ["поустаревши"],
    "поустаревши": ["поустарев"],
    "поутешив": ["поутешивши"],
    "поутешивши": ["поутешив"],
    "поутихнув": ["поутихнувши"],
    "поутихнувши": ["поутихнув"],
    "поутру": ["утром"],
    "поутюжив": ["поутюживши"],
    "поутюживши": ["поутюжив"],
    "поухаживав": ["поухаживавши"],
    "поухаживавши": ["поухаживав"],
    "поухивав": ["поухивавши"],
    "поухивавши": ["поухивав"],
    "поуходив": ["поуходивши"],
    "поуходивши": ["поуходив"],
    "поучав": ["поучавши"],
    "поучавши": ["поучав"],
    "поучаствовав": ["поучаствовавши"],
    "поучаствовавши": ["поучаствовав"],
    "поучать": ["наставлять", "морализировать", "менторствовать"],
    "поучение": ["проповедь"],
    "поученье": ["поучение"],
    "поучив": ["поучивши"],
    "поучивав": ["поучивавши"],
    "поучивавши": ["поучивав"],
    "поучивши": ["поучив"],
    "поучительствовав": ["поучительствовавши"],
    "поучительствовавши": ["поучительствовав"],
    "пофантазировав": ["пофантазировавши"],
    "пофантазировавши": ["пофантазировав"],
    "пофанфаронив": ["пофанфаронивши"],
    "пофанфаронивши": ["пофанфаронив"],
    "пофартив": ["пофартивши"],
    "пофартивши": ["пофартив"],
    "пофартить": ["повезти", "посчастливиться", "удаться", "подвезти", "подфартить", "фартануть", "фортануть"],
    "пофасонив": ["пофасонивши"],
    "пофасонивши": ["пофасонив"],
    "пофехтовав": ["пофехтовавши"],
    "пофехтовавши": ["пофехтовав"],
    "пофиг": ["по фигу", "по барабану", "всё равно", "безразлично", "плевать"],
    "пофигизм": ["безразличие", "индифферентность", "равнодушие", "пренебрежение", "похуизм"],
    "пофигист": ["всёравношник"],
    "пофигистически": ["пофигистски"],
    "пофигистический": ["пофигистский"],
    "пофигистски": ["пофигистически"],
    "пофигистский": ["пофигистический"],
    "пофиксив": ["пофиксивши"],
    "пофиксивши": ["пофиксив"],
    "пофиксить": ["исправить"],
    "пофилонив": ["пофилонивши"],
    "пофилонивши": ["пофилонив"],
    "пофилософствовав": ["пофилософствовавши"],
    "пофилософствовавши": ["пофилософствовав"],
    "пофланировав": ["пофланировавши"],
    "пофланировавши": ["пофланировав"],
    "пофлиртовав": ["пофлиртовавши"],
    "пофлиртовавши": ["пофлиртовав"],
    "пофокусничав": ["пофокусничавши"],
    "пофокусничавши": ["пофокусничав"],
    "пофорсив": ["пофорсивши"],
    "пофорсивши": ["пофорсив"],
    "пофотографировав": ["пофотографировавши"],
    "пофотографировавши": ["пофотографировав"],
    "пофрантив": ["пофрантивши"],
    "пофрантивши": ["пофрантив"],
    "пофтэ": ["кеф", "густ", "доринцэ"],
    "пофукав": ["пофукавши"],
    "пофукавши": ["пофукав"],
    "пофукивав": ["пофукивавши"],
    "пофукивавши": ["пофукивав"],
    "пофыркав": ["пофыркавши"],
    "пофыркавши": ["пофыркав"],
    "пофыркивав": ["пофыркивавши"],
    "пофыркивавши": ["пофыркивав"],
    "пофыркиванье": ["пофыркивание"],
    "похабель": ["похабень"],
    "похабень": ["похабель"],
    "похабив": ["похабивши"],
    "похабивши": ["похабив"],
    "похабник": ["бесстыдник", "скабрёзник", "страмнюк", "срамословец", "срамословник", "ёрник", "гаер", "матерник", "матерщинник", "пошляк", "сквернослов", "скоморох"],
    "похабничав": ["похабничавши"],
    "похабничавши": ["похабничав"],
    "похабный": ["неприличный", "непристойный", "неблагопристойный", "бесстыдный", "грубо-бесстыдный", "непотребный", "неподобный", "неудобопроизносимый", "неудобь сказуемый", "непечатный", "нецензурный", "матерный", "матерщинный", "срамной", "скабрёзный"],
    "похабство": ["похабщина"],
    "похавав": ["похававши"],
    "похававши": ["похавав"],
    "похавать": ["пожрать", "поесть", "съесть", "схавать"],
    "похаживав": ["похаживавши"],
    "похаживавши": ["похаживав"],
    "похайпив": ["похайпивши"],
    "похайпивши": ["похайпив"],
    "похайповав": ["похайповавши"],
    "похайповавши": ["похайповав"],
    "похайповать": ["похайпить"],
    "похалтурив": ["похалтуривши"],
    "похалтуривши": ["похалтурив"],
    "похандрив": ["похандривши"],
    "похандривши": ["похандрив"],
    "похандрить": ["поунывать", "поболеть"],
    "похарчив": ["похарчивши"],
    "похарчивши": ["похарчив"],
    "похаяв": ["похаявши"],
    "похаявши": ["похаяв"],
    "похва": ["ножны"],
    "похвала": ["хвала"],
    "похвалив": ["похваливши"],
    "похваливав": ["похваливавши"],
    "похваливавши": ["похваливав"],
    "похваливши": ["похвалив"],
    "похвалиться": ["похваляться"],
    "похваляв": ["похвалявши"],
    "похвалявши": ["похваляв"],
    "похваляться": ["хвалиться", "бахвалиться"],
    "похварывав": ["похварывавши"],
    "похварывавши": ["похварывав"],
    "похвастав": ["похваставши"],
    "похваставши": ["похвастав"],
    "похвастаться": ["похвастать"],
    "похватав": ["похватавши"],
    "похватавши": ["похватав"],
    "похватност": ["сръчност", "умение", "умелост", "ловкост"],
    "похворав": ["похворавши"],
    "похворавши": ["похворав"],
    "похеривав": ["похеривавши"],
    "похеривавши": ["похеривав"],
    "похеривать": ["перечёркивать", "зачёркивать"],
    "похеривши": ["похерив"],
    "похерить": ["перечеркнуть", "зачеркнуть", "вычеркнуть", "почёркать", "уничтожить", "погубить", "наплевать", "на", "проигнорировать"],
    "похехекав": ["похехекавши"],
    "похехекавши": ["похехекав"],
    "похилев": ["похилевши"],
    "похилевши": ["похилев"],
    "похиляв": ["похилявши"],
    "похилявши": ["похиляв"],
    "похимичив": ["похимичивши"],
    "похимичивши": ["похимичив"],
    "похитив": ["похитивши"],
    "похитивши": ["похитив"],
    "похитительница": ["воровка", "грабительница", "крадунья", "воровайка"],
    "похитить": ["украсть"],
    "похитрев": ["похитревши"],
    "похитревши": ["похитрев"],
    "похитрив": ["похитривши"],
    "похитривши": ["похитрив"],
    "похихикав": ["похихикавши"],
    "похихикавши": ["похихикав"],
    "похихикивав": ["похихикивавши"],
    "похихикивавши": ["похихикивав"],
    "похищав": ["похищавши"],
    "похищавши": ["похищав"],
    "похищать": ["выкрадывать", "воровать", "красть"],
    "похищенье": ["похищение"],
    "похлебав": ["похлебавши"],
    "похлебавши": ["похлебав"],
    "похлебствовав": ["похлебствовавши"],
    "похлебствовавши": ["похлебствовав"],
    "похлестав": ["похлеставши"],
    "похлеставши": ["похлестав"],
    "похлипывав": ["похлипывавши"],
    "похлипывавши": ["похлипывав"],
    "похлопав": ["похлопавши"],
    "похлопавши": ["похлопав"],
    "похлопотав": ["похлопотавши"],
    "похлопотавши": ["похлопотав"],
    "похлопывав": ["похлопывавши"],
    "похлопывавши": ["похлопывав"],
    "похлопыванье": ["похлопывание"],
    "похлюпав": ["похлюпавши"],
    "похлюпавши": ["похлюпав"],
    "похлюпывав": ["похлюпывавши"],
    "похлюпывавши": ["похлюпывав"],
    "похлёбка": ["суп", "варево", "баланда", "хлебово"],
    "похлёбывав": ["похлёбывавши"],
    "похлёбывавши": ["похлёбывав"],
    "похлёстывав": ["похлёстывавши"],
    "похлёстывавши": ["похлёстывав"],
    "похмелев": ["похмелевши"],
    "похмелевши": ["похмелев"],
    "похмелье": ["бодун", "отходняк", "сушняк"],
    "похмурев": ["похмуревши"],
    "похмуревши": ["похмурев"],
    "похмурнев": ["похмурневши"],
    "похмурневши": ["похмурнев"],
    "похмыкав": ["похмыкавши"],
    "похмыкавши": ["похмыкав"],
    "похмыкивав": ["похмыкивавши"],
    "похмыкивавши": ["похмыкивав"],
    "похныкав": ["похныкавши"],
    "похныкавши": ["похныкав"],
    "похныкивав": ["похныкивавши"],
    "похныкивавши": ["похныкивав"],
    "поховання": ["могила"],
    "поход": ["марш", "кампания", "путешествие", "прогулка", "посещение"],
    "походатайствовав": ["походатайствовавши"],
    "походатайствовавши": ["походатайствовав"],
    "походив": ["походивши"],
    "походивши": ["походив"],
    "походить": ["напоминать"],
    "походка": ["поступь"],
    "походняк": ["походка"],
    "походом": ["походя"],
    "походу": ["похоже", "видимо", "по-видимому", "вероятно", "наверно", "кажется", "судя по всему", "кажись"],
    "похождение": ["похожденье"],
    "похожденье": ["похождение"],
    "похожесть": ["сходство"],
    "похожий": ["подобный", "схожий", "сходный"],
    "похозяйничав": ["похозяйничавши"],
    "похозяйничавши": ["похозяйничав"],
    "похозяйствовав": ["похозяйствовавши"],
    "похозяйствовавши": ["похозяйствовав"],
    "похолив": ["похоливши"],
    "похоливши": ["похолив"],
    "похолодав": ["похолодавши"],
    "похолодавши": ["похолодав"],
    "похолоданье": ["похолодание"],
    "похолодать": ["похолодеть", "охладиться", "иззябнуть", "помёрзнуть", "намёрзнуться"],
    "похолодев": ["похолодевши"],
    "похолодевши": ["похолодев"],
    "похолоделый": ["остывший", "похолодевший"],
    "похолодеть": ["охладиться", "окоченеть"],
    "похолоднев": ["похолодневши"],
    "похолодневши": ["похолоднев"],
    "похороненный": ["схороненный", "захороненный", "покоящийся", "погребённый"],
    "похоронив": ["похоронивши"],
    "похоронивши": ["похоронив"],
    "похоронить": ["захоронить", "погрести", "схоронить", "предать земле", "поставить крест"],
    "похоронка": ["похоронная"],
    "похоронное бюро": ["бюро ритуальных услуг"],
    "похороны": ["проводы", "прощание", "погребение"],
    "похорошев": ["похорошевши"],
    "похорошевши": ["похорошев"],
    "похотев": ["похотевши"],
    "похотевши": ["похотев"],
    "похотливость": ["сладострастие"],
    "похотливый": ["чувственный", "сладострастный", "развратный", "распутный", "блудливый", "сластолюбивый", "любострастный", "порочный"],
    "похотник": ["ловелас", "казанова"],
    "похоть": ["сладострастие", "вожделение", "желание", "страсть", "чреслобесие"],
    "похохатывав": ["похохатывавши"],
    "похохатывавши": ["похохатывав"],
    "похохатыванье": ["похохатывание"],
    "похохмив": ["похохмивши"],
    "похохмивши": ["похохмив"],
    "похохотав": ["похохотавши"],
    "похохотавши": ["похохотав"],
    "похрабрев": ["похрабревши"],
    "похрабревши": ["похрабрев"],
    "похрамывав": ["похрамывавши"],
    "похрамывавши": ["похрамывав"],
    "похранив": ["похранивши"],
    "похранивши": ["похранив"],
    "похрапев": ["похрапевши"],
    "похрапевши": ["похрапев"],
    "похрапывав": ["похрапывавши"],
    "похрапывавши": ["похрапывав"],
    "похрапыванье": ["похрапывание"],
    "похрипев": ["похрипевши"],
    "похрипевши": ["похрипев"],
    "похрипывав": ["похрипывавши"],
    "похрипывавши": ["похрипывав"],
    "похрипыванье": ["похрипывание"],
    "похромав": ["похромавши"],
    "похромавши": ["похромав"],
    "похрумкав": ["похрумкавши"],
    "похрумкавши": ["похрумкав"],
    "похрумкивав": ["похрумкивавши"],
    "похрумкивавши": ["похрумкивав"],
    "похрупывав": ["похрупывавши"],
    "похрупывавши": ["похрупывав"],
    "похрустев": ["похрустевши"],
    "похрустевши": ["похрустев"],
    "похрустывав": ["похрустывавши"],
    "похрустывавши": ["похрустывав"],
    "похрустыванье": ["похрустывание"],
    "похрюкав": ["похрюкавши"],
    "похрюкавши": ["похрюкав"],
    "похрюкивав": ["похрюкивавши"],
    "похрюкивавши": ["похрюкивав"],
    "похрюкивание": ["похрюкиванье"],
    "похрюкиванье": ["похрюкивание"],
    "похудав": ["похудавши"],
    "похудавши": ["похудав"],
    "похудание": ["похудение"],
    "похудев": ["похудевши"],
    "похудевши": ["похудев"],
    "похудевший": ["похуделый"],
    "похуделый": ["похудевший"],
    "похудение": ["похудание"],
    "похудеть": ["похудать", "похужать", "схуднуть", "сбросить вес"],
    "похужев": ["похужевши"],
    "похужевши": ["похужев"],
    "похужеть": ["ухудшиться"],
    "похуизм": ["безразличие", "равнодушие", "пренебрежение", "индифферентность", "пофигизм"],
    "похуист": ["пофигист", "всёравношник"],
    "похуистка": ["пофигистка"],
    "похуление": ["неодобрение"],
    "похулив": ["похуливши"],
    "похуливши": ["похулив"],
    "похулиганив": ["похулиганивши"],
    "похулиганивши": ["похулиганив"],
    "похулить": ["побранить", "поругать"],
    "похуястее": ["похуястей"],
    "похуястей": ["похуястее"],
    "поц": ["пенис", "половой член", "глупец", "дурак", "ничтожество"],
    "поцапав": ["поцапавши"],
    "поцапавши": ["поцапав"],
    "поцарапав": ["поцарапавши"],
    "поцарапавши": ["поцарапав"],
    "поцарствовав": ["поцарствовавши"],
    "поцарствовавши": ["поцарствовав"],
    "поцвиркивав": ["поцвиркивавши"],
    "поцвиркивавши": ["поцвиркивав"],
    "поцедив": ["поцедивши"],
    "поцедивши": ["поцедив"],
    "поцеживав": ["поцеживавши"],
    "поцеживавши": ["поцеживав"],
    "поцеловав": ["поцеловавши"],
    "поцеловавши": ["поцеловав"],
    "поцеловать в пробой да пойти домой": ["никого не застать", "поцеловать в пробой", "поцеловать пробой", "поцеловать замок", "уйти ни с чем", "уйти несолоно хлебавши"],
    "поцеловать замок": ["никого не застать", "поцеловать пробой", "поцеловать в пробой", "поцеловать пробой да пойти домой", "поцеловать в пробой да пойти домой", "уйти ни с чем", "уйти несолоно хлебавши"],
    "поцеловать пробой": ["никого не застать", "поцеловать в пробой", "поцеловать в пробой да пойти домой", "поцеловать пробой да пойти домой", "поцеловать замок", "уйти ни с чем", "уйти несолоно хлебавши"],
    "поцелуй": ["лобзание", "чмок", "цемик"],
    "поцик": ["поц", "пацан"],
    "поциничнее": ["поциничней"],
    "поцокав": ["поцокавши"],
    "поцокавши": ["поцокав"],
    "поцокивав": ["поцокивавши"],
    "поцокивавши": ["поцокивав"],
    "поцреот": ["джингоист", "ура-патриот"],
    "поцреотня": ["поцреот"],
    "поцыкивав": ["поцыкивавши"],
    "поцыкивавши": ["поцыкивав"],
    "почав": ["почавши"],
    "почавкав": ["почавкавши"],
    "почавкавши": ["почавкав"],
    "почавкивав": ["почавкивавши"],
    "почавкивавши": ["почавкивав"],
    "почавши": ["почав"],
    "почадив": ["почадивши"],
    "почадивши": ["почадив"],
    "почаевав": ["почаевавши"],
    "почаевавши": ["почаевав"],
    "почайничав": ["почайничавши"],
    "почайничавши": ["почайничав"],
    "почайпив": ["почайпивши"],
    "почайпивши": ["почайпив"],
    "почапав": ["почапавши"],
    "почапавши": ["почапав"],
    "почасту": ["часто"],
    "початие": ["начинание", "почин", "начатие"],
    "початковидный": ["початкообразный"],
    "початкообразный": ["початковидный"],
    "початок": ["начало", "почин"],
    "початый": ["начатый"],
    "почать": ["начать"],
    "почахнув": ["почахнувши"],
    "почахнувши": ["почахнув"],
    "почаёвничав": ["почаёвничавши"],
    "почаёвничавши": ["почаёвничав"],
    "почаёвничать": ["попить", "чай"],
    "почва": ["земля", "фундамент", "основание"],
    "почеканив": ["почеканивши"],
    "почеканивши": ["почеканив"],
    "почему знать": ["почём знать"],
    "почему-либо": ["почему-нибудь"],
    "почему-нибудь": ["почему-либо"],
    "почему-то": ["отчего-то", "по какой-то причине"],
    "почемукав": ["почемукавши"],
    "почемукавши": ["почемукав"],
    "почерк": ["рука", "росчерк"],
    "почерковед": ["графолог"],
    "почернев": ["почерневши"],
    "почерневши": ["почернев"],
    "почернив": ["почернивши"],
    "почернивши": ["почернив"],
    "почерниться": ["потемнеть"],
    "почерпав": ["почерпавши"],
    "почерпавши": ["почерпав"],
    "почерпнув": ["почерпнувши"],
    "почерпнувши": ["почерпнув"],
    "почерпывав": ["почерпывавши"],
    "почерпывавши": ["почерпывав"],
    "почерствев": ["почерствевши"],
    "почерствевши": ["почерствев"],
    "почертив": ["почертивши"],
    "почертивши": ["почертив"],
    "почесав": ["почесавши"],
    "почесавши": ["почесав"],
    "почесать": ["поскрести", "поцарапать"],
    "почесать репу": ["подумать", "размыслить", "поразмыслить", "прикинуть", "прикинуть хуй к носу"],
    "почествовав": ["почествовавши"],
    "почествовавши": ["почествовав"],
    "почесть": ["почёт"],
    "почесуха": ["пруриго", "почесуха овец", "скрейпи"],
    "почечный клубочек": ["мальпигиев почечный клубочек", "почечное тельце", "мальпигиево тельце"],
    "почечуй": ["геморрой"],
    "почив": ["почивши"],
    "почивав": ["почивавши"],
    "почивавши": ["почивав"],
    "почивать": ["спать", "покоиться"],
    "почившая": ["покойная", "упокойница", "покойница", "умершая", "усопшая", "мёртвая"],
    "почивши": ["почив"],
    "почивший": ["успокоившийся", "прекратившийся", "стихнувший", "уснувший", "заснувший", "умерший", "усопший", "покойный", "опочивший", "покойник", "мертвец"],
    "почиликав": ["почиликавши"],
    "почиликавши": ["почиликав"],
    "почиликивав": ["почиликивавши"],
    "почиликивавши": ["почиликивав"],
    "починав": ["починавши"],
    "починавши": ["починав"],
    "починать": ["начинать"],
    "починив": ["починивши"],
    "починивав": ["починивавши"],
    "починивавши": ["починивав"],
    "починиваться": ["починяться", "ремонтироваться", "чиниться"],
    "починивши": ["починив"],
    "починить": ["отремонтировать"],
    "починка": ["ремонт", "наладка", "исправление", "чинка"],
    "починщик": ["ремонтник", "чинила"],
    "починяв": ["починявши"],
    "починявши": ["починяв"],
    "починять": ["чинить", "ремонтировать"],
    "починяться": ["ремонтироваться", "реставрироваться"],
    "почирикав": ["почирикавши"],
    "почирикавши": ["почирикав"],
    "почиркав": ["почиркавши"],
    "почиркавши": ["почиркав"],
    "почислив": ["почисливши"],
    "почисливши": ["почислив"],
    "почистив": ["почистивши"],
    "почистивши": ["почистив"],
    "почистить": ["очистить"],
    "почитав": ["почитавши"],
    "почитавши": ["почитав"],
    "почитай": ["пожалуй", "вероятно", "наверное", "почти"],
    "почитание": ["поклонение", "культ"],
    "почитанье": ["почитание"],
    "почитатель": ["поклонник", "ценитель"],
    "почитывав": ["почитывавши"],
    "почитывавши": ["почитывав"],
    "почить": ["успокоиться", "прекратиться", "стихнуть", "уснуть", "опочить", "умереть"],
    "почить в бозе": ["исчезнуть"],
    "почихав": ["почихавши"],
    "почихавши": ["почихав"],
    "почихивав": ["почихивавши"],
    "почихивавши": ["почихивав"],
    "почкованье": ["почкование"],
    "почмокав": ["почмокавши"],
    "почмокавши": ["почмокав"],
    "почмокивав": ["почмокивавши"],
    "почмокивавши": ["почмокивав"],
    "почт-амт": ["почтамт"],
    "почта": ["пошта", "корреспонденция", "мейл"],
    "почта-автомат": ["почтовый автомат"],
    "почталион": ["письмоносец", "почтарь"],
    "почтальон": ["письмоносец", "почтарь", "почталион"],
    "почтальонив": ["почтальонивши"],
    "почтальонивши": ["почтальонив"],
    "почтальонша": ["письмоносица", "письмоноска", "почтальонка", "почтарка"],
    "почтарив": ["почтаривши"],
    "почтаривши": ["почтарив"],
    "почтариха": ["письмоносица", "письмоноска", "почтальонка", "почтальонша", "почтарка"],
    "почтарка": ["письмоносица", "письмоноска", "почтальонка", "почтальонша"],
    "почтарь": ["почтальон", "письмоносец", "ямщик"],
    "почтение": ["уважение", "пиетет", "венерация"],
    "почтенный": ["уважаемый", "многоуважаемый", "достопочтенный", "порядочный"],
    "почтенье": ["уважение"],
    "почти": ["почти что", "без малого", "около", "приблизительно"],
    "почтив": ["почтивши"],
    "почтивши": ["почтив"],
    "почтительность": ["уважительность"],
    "почтительный": ["уважительный", "порядочный", "значительный"],
    "почтовая марка": ["марка"],
    "почтовый ящик": ["ящик"],
    "почтомат": ["постамат"],
    "почувствовав": ["почувствовавши"],
    "почувствовавши": ["почувствовав"],
    "почувствовать": ["ощутить"],
    "почудачив": ["почудачивши"],
    "почудачивши": ["почудачив"],
    "почудачить": ["почудаковать", "почудить", "пошалить"],
    "почудив": ["почудивши"],
    "почудивши": ["почудив"],
    "почудиться": ["померещиться", "показаться"],
    "почужав": ["почужавши"],
    "почужавши": ["почужав"],
    "почужев": ["почужевши"],
    "почужевши": ["почужев"],
    "почуя": ["почуявши"],
    "почуявши": ["почуяв"],
    "почём": ["по какой цене", "в какую цену", "сколько стоит"],
    "почёркав": ["почёркавши"],
    "почёркавши": ["почёркав"],
    "почёркивав": ["почёркивавши"],
    "почёркивавши": ["почёркивав"],
    "почёсывав": ["почёсывавши"],
    "почёсывавши": ["почёсывав"],
    "почёт": ["уважение", "почтение"],
    "пошабашив": ["пошабашивши"],
    "пошабашивши": ["пошабашив"],
    "пошабашничав": ["пошабашничавши"],
    "пошабашничавши": ["пошабашничав"],
    "пошагав": ["пошагавши"],
    "пошагавши": ["пошагав"],
    "пошагивав": ["пошагивавши"],
    "пошагивавши": ["пошагивав"],
    "пошагово": ["последовательно"],
    "пошаговый": ["инкрементальный", "поочерёдный"],
    "пошалив": ["пошаливши"],
    "пошаливав": ["пошаливавши"],
    "пошаливавши": ["пошаливав"],
    "пошаливши": ["пошалив"],
    "пошамав": ["пошамавши"],
    "пошамавши": ["пошамав"],
    "пошаманив": ["пошаманивши"],
    "пошаманивши": ["пошаманив"],
    "пошамкав": ["пошамкавши"],
    "пошамкавши": ["пошамкав"],
    "пошантажировав": ["пошантажировавши"],
    "пошантажировавши": ["пошантажировав"],
    "пошарив": ["пошаривши"],
    "пошаривши": ["пошарив"],
    "пошаркав": ["пошаркавши"],
    "пошаркавши": ["пошаркав"],
    "пошаркивав": ["пошаркивавши"],
    "пошаркивавши": ["пошаркивав"],
    "пошаркиванье": ["пошаркивание"],
    "пошарлатанив": ["пошарлатанивши"],
    "пошарлатанивши": ["пошарлатанив"],
    "пошарпанный": ["потёртый", "использованный", "обшарпанный"],
    "пошастав": ["пошаставши"],
    "пошаставши": ["пошастав"],
    "пошастать": ["побродить", "послоняться"],
    "пошатав": ["пошатавши"],
    "пошатавши": ["пошатав"],
    "пошатнув": ["пошатнувши"],
    "пошатнувши": ["пошатнув"],
    "пошатнуть": ["покачнуть", "поколебать"],
    "пошатывав": ["пошатывавши"],
    "пошатывавши": ["пошатывав"],
    "пошвыривав": ["пошвыривавши"],
    "пошвыривавши": ["пошвыривав"],
    "пошвыряв": ["пошвырявши"],
    "пошвырявши": ["пошвыряв"],
    "пошебаршив": ["пошебаршивши"],
    "пошебаршивши": ["пошебаршив"],
    "пошебуршив": ["пошебуршивши"],
    "пошебуршивши": ["пошебуршив"],
    "пошевелив": ["пошевеливши"],
    "пошевеливав": ["пошевеливавши"],
    "пошевеливавши": ["пошевеливав"],
    "пошевеливши": ["пошевелив"],
    "пошевельнув": ["пошевельнувши"],
    "пошевельнувши": ["пошевельнув"],
    "пошевни": ["обшевни"],
    "пошелестев": ["пошелестевши"],
    "пошелестевши": ["пошелестев"],
    "пошелушив": ["пошелушивши"],
    "пошелушивши": ["пошелушив"],
    "пошептав": ["пошептавши"],
    "пошептавши": ["пошептав"],
    "пошептом": ["шёпотом", "тихо"],
    "пошерудив": ["пошерудивши"],
    "пошерудивши": ["пошерудив"],
    "пошесть": ["лихо", "напасть"],
    "пошетта": ["пошет"],
    "пошефствовав": ["пошефствовавши"],
    "пошефствовавши": ["пошефствовав"],
    "пошиб": ["манера", "характер", "повадка", "замашки", "стиль"],
    "пошибав": ["пошибавши"],
    "пошибавши": ["пошибав"],
    "пошибив": ["пошибивши"],
    "пошибивши": ["пошибив"],
    "пошив": ["пошивка", "шитьё"],
    "пошивав": ["пошивавши"],
    "пошивавши": ["пошивав"],
    "пошивочная": ["швейная мастерская", "швальня", "портняжная мастерская", "портновская мастерская", "швальная", "ателье"],
    "пошивши": ["пошив"],
    "пошинковав": ["пошинковавши"],
    "пошинковавши": ["пошинковав"],
    "пошипев": ["пошипевши"],
    "пошипевши": ["пошипев"],
    "пошипывав": ["пошипывавши"],
    "пошипывавши": ["пошипывав"],
    "пошире": ["шире"],
    "поширев": ["поширевши"],
    "поширевши": ["поширев"],
    "поширення": ["розширення", "поширювання"],
    "поширкав": ["поширкавши"],
    "поширкавши": ["поширкав"],
    "поширкивав": ["поширкивавши"],
    "поширкивавши": ["поширкивав"],
    "пошкодив": ["пошкодивши"],
    "пошкодивши": ["пошкодив"],
    "пошкодничав": ["пошкодничавши"],
    "пошкодничавши": ["пошкодничав"],
    "пошкрябав": ["пошкрябавши"],
    "пошкрябавши": ["пошкрябав"],
    "пошла писать губерния": ["пошла плясать губерния"],
    "пошлев": ["пошлевши"],
    "пошлевши": ["пошлев"],
    "пошлей": ["пошлее"],
    "пошлив": ["пошливши"],
    "пошливши": ["пошлив"],
    "пошлифовав": ["пошлифовавши"],
    "пошлифовавши": ["пошлифовав"],
    "пошло": ["низкопробно", "избито", "банально", "тривиально", "вульгарно"],
    "пошло-поехало": ["и пошло-поехало", "и пошло и повезло", "пошло говно по трубам", "понеслось говно по трубам", "понеслась пизда по кочкам"],
    "пошлость": ["низость", "грубость", "скабрёзность", "неприличность", "вульгарность", "банальность"],
    "пошлый": ["заурядный", "избитый", "банальный", "недалёкий", "примитивный", "плоский", "вульгарный", "похабный", "старинный", "исконный"],
    "пошлятина": ["пошлость"],
    "пошлёпав": ["пошлёпавши"],
    "пошлёпавши": ["пошлёпав"],
    "пошлёпывав": ["пошлёпывавши"],
    "пошлёпывавши": ["пошлёпывав"],
    "пошмыгав": ["пошмыгавши"],
    "пошмыгавши": ["пошмыгав"],
    "пошмыгивав": ["пошмыгивавши"],
    "пошмыгивавши": ["пошмыгивав"],
    "пошныривав": ["пошныривавши"],
    "пошныривавши": ["пошныривав"],
    "пошныряв": ["пошнырявши"],
    "пошнырявши": ["пошныряв"],
    "пошоркав": ["пошоркавши"],
    "пошоркавши": ["пошоркав"],
    "пошпионив": ["пошпионивши"],
    "пошпионивши": ["пошпионив"],
    "пошпыняв": ["пошпынявши"],
    "пошпынявши": ["пошпыняв"],
    "поштопав": ["поштопавши"],
    "поштопавши": ["поштопав"],
    "поштудировав": ["поштудировавши"],
    "поштудировавши": ["поштудировав"],
    "поштукатурив": ["поштукатуривши"],
    "поштукатуривши": ["поштукатурив"],
    "пошукав": ["пошукавши"],
    "пошукавши": ["пошукав"],
    "пошумев": ["пошумевши"],
    "пошумевши": ["пошумев"],
    "пошумливав": ["пошумливавши"],
    "пошумливавши": ["пошумливав"],
    "пошуровав": ["пошуровавши"],
    "пошуровавши": ["пошуровав"],
    "пошуршав": ["пошуршавши"],
    "пошуршавши": ["пошуршав"],
    "пошустрив": ["пошустривши"],
    "пошустривши": ["пошустрив"],
    "пошустрить": ["подшустрить", "подшустрячить"],
    "пошутив": ["пошутивши"],
    "пошутивши": ["пошутив"],
    "пошутковав": ["пошутковавши"],
    "пошутковавши": ["пошутковав"],
    "пошучивав": ["пошучивавши"],
    "пошучивавши": ["пошучивав"],
    "пошушукав": ["пошушукавши"],
    "пошушукавши": ["пошушукав"],
    "пошый": ["поши"],
    "пошёптывав": ["пошёптывавши"],
    "пошёптывавши": ["пошёптывав"],
    "пощада": ["милость"],
    "пощадив": ["пощадивши"],
    "пощадивши": ["пощадив"],
    "пощадить": ["помиловать", "пожалеть"],
    "пощебетав": ["пощебетавши"],
    "пощебетавши": ["пощебетав"],
    "пощеголяв": ["пощеголявши"],
    "пощеголявши": ["пощеголяв"],
    "пощекотав": ["пощекотавши"],
    "пощекотавши": ["пощекотав"],
    "пощенье": ["пощение"],
    "пощепав": ["пощепавши"],
    "пощепавши": ["пощепав"],
    "пощипав": ["пощипавши"],
    "пощипавши": ["пощипав"],
    "пощипывав": ["пощипывавши"],
    "пощипывавши": ["пощипывав"],
    "пощипывание": ["пощипыванье"],
    "пощипыванье": ["пощипывание"],
    "пощупав": ["пощупавши"],
    "пощупавши": ["пощупав"],
    "пощупывав": ["пощупывавши"],
    "пощупывавши": ["пощупывав"],
    "пощурив": ["пощуривши"],
    "пощуривав": ["пощуривавши"],
    "пощуривавши": ["пощуривав"],
    "пощуривши": ["пощурив"],
    "пощявка": ["желание", "искане"],
    "пощёлкав": ["пощёлкавши"],
    "пощёлкавши": ["пощёлкав"],
    "пощёлкивав": ["пощёлкивавши"],
    "пощёлкивавши": ["пощёлкивав"],
    "пощёчина": ["затрещина", "оплеуха", "чапалах", "обида", "оскорбление", "плевок", "удар", "унижение"],
    "поэзия": ["стихосложение", "стихотворство", "стихотворчество", "возвышенный слог", "лирика", "стихи", "поэтичность", "лиризм"],
    "поэкзаменовав": ["поэкзаменовавши"],
    "поэкзаменовавши": ["поэкзаменовав"],
    "поэкономив": ["поэкономивши"],
    "поэкономивши": ["поэкономив"],
    "поэкономничав": ["поэкономничавши"],
    "поэкономничавши": ["поэкономничав"],
    "поэкспериментировав": ["поэкспериментировавши"],
    "поэкспериментировавши": ["поэкспериментировав"],
    "поэксплуатировав": ["поэксплуатировавши"],
    "поэксплуатировавши": ["поэксплуатировав"],
    "поэпизодник": ["поэпизодный план"],
    "поэпизодный план": ["поэпизодник"],
    "поэт": ["стихотворец", "бард", "пиит", "рифмоплёт", "рифмач", "версификатор", "поэтишка", "мечтатель"],
    "поэтесса": ["поэтка"],
    "поэтизировав": ["поэтизировавши"],
    "поэтизировавши": ["поэтизировав"],
    "поэтически": ["возвышенно", "идеально"],
    "поэтишка": ["рифмоплёт", "стихоплёт", "виршеплёт", "версификатор"],
    "поэтка": ["поэтесса"],
    "поэтовать": ["поэтывать", "этовать"],
    "поэтому": ["посему", "потому", "по каковой причине", "вследствие чего", "в связи с чем"],
    "поэтъ": ["стихотворецъ", "бардъ", "пиитъ", "версификаторъ", "поэтишка"],
    "поюзанный": ["использованный"],
    "поюзать": ["попользоваться"],
    "поюлив": ["поюливши"],
    "поюливши": ["поюлив"],
    "поюнев": ["поюневши"],
    "поюневши": ["поюнев"],
    "поюродствовав": ["поюродствовавши"],
    "поюродствовавши": ["поюродствовав"],
    "поябедничав": ["поябедничавши"],
    "поябедничавши": ["поябедничав"],
    "поява": ["явлення"],
    "появиться": ["возникнуть", "начаться", "образоваться", "показаться", "явиться", "выйти"],
    "появление": ["возникновение", "возникновенье", "появленье"],
    "появлення": ["поява"],
    "появленье": ["появление"],
    "появляться": ["возникать", "рождаться"],
    "поязвив": ["поязвивши"],
    "поязвивши": ["поязвив"],
    "поярчав": ["поярчавши"],
    "поярчавши": ["поярчав"],
    "поярчев": ["поярчевши"],
    "поярчевши": ["поярчев"],
    "пояс": ["ремень", "поясок", "гайтан", "кушак", "обвязка", "опоясок", "опояска", "подпояска", "талия", "обод"],
    "пояснев": ["поясневши"],
    "поясневши": ["пояснев"],
    "пояснив": ["пояснивши"],
    "пояснивши": ["пояснив"],
    "поясняв": ["пояснявши"],
    "пояснявши": ["поясняв"],
    "пояснять": ["объяснять", "растолковывать"],
    "поясняться": ["объясняться"],
    "поясовый камень": ["урал", "уральские горы", "камень"],
    "поясок": ["ремешок"],
    "поёбав": ["поёбавши"],
    "поёбавши": ["поёбав"],
    "поёбать": ["почапать"],
    "поёбывав": ["поёбывавши"],
    "поёбывавши": ["поёбывав"],
    "поёбывать": ["потрахивать", "попихивать", "ёбывать"],
    "поёрзав": ["поёрзавши"],
    "поёрзавши": ["поёрзав"],
    "поёрзать": ["поелозить", "поегозить"],
    "поёрничав": ["поёрничавши"],
    "поёрничавши": ["поёрничав"],
    "ппш": ["пистолет-пулемёт шпагина"],
    "пра-": ["прото-", "пред-"],
    "пра-финно-угорский язык": ["пра-финно-угорский"],
    "праалбанский": ["протоалбанский", "протоалбанский язык", "праалбанский язык"],
    "праалбанский язык": ["праалбанский", "протоалбанский", "протоалбанский язык"],
    "прабабка": ["прабабушка"],
    "прабабушка": ["прабабка"],
    "прабалтийский": ["прабалтийский язык", "протобалтийский", "протобалтийский язык"],
    "прабалтийский язык": ["прабалтийский", "протобалтийский", "протобалтийский язык"],
    "прабалтославянский": ["прабалтославянский язык"],
    "прабалтославянский язык": ["прабалтославянский"],
    "прабанту": ["протобанту"],
    "прабачаць": ["дараваць"],
    "права": ["водительские права"],
    "правда": ["истина", "справедливость"],
    "правдивость": ["правдолюбие", "искренность", "честность", "достоверность", "истинность"],
    "правдивый": ["правдолюбивый", "честный", "истинный", "достоверный", "действительный", "искренний"],
    "правдоискатель": ["правдолюб", "правдолюбец", "правдоруб"],
    "правдолюб": ["правдоискатель"],
    "правдолюбец": ["правдолюб"],
    "правдоподобие": ["правдоподобность"],
    "правдоподобность": ["правдоподобие"],
    "правдоподобный": ["вероятный", "благовидный"],
    "правдоподобье": ["правдоподобие"],
    "правдуха": ["правдолюб"],
    "правев": ["правевши"],
    "правевши": ["правев"],
    "праведно": ["благочестиво", "безгрешно", "законно", "справедливо"],
    "праведный": ["благочестивый", "святой", "жизни", "угодный", "бог", "справедливый", "правый", "правосудный"],
    "праветь": ["леветь"],
    "правив": ["правивши"],
    "правивши": ["правив"],
    "правий": ["консервативний"],
    "правила землепользования и застройки": ["пзз"],
    "правилник": ["устав", "статут", "наредба"],
    "правило": ["закон", "закономерность", "предписание", "обычай", "обиход", "принцип", "обыкновение", "привычка"],
    "правильний": ["слушний"],
    "правильно": ["верно", "корректно", "грамотно", "справедливо", "точно", "и то верно"],
    "правильность": ["верность"],
    "правильный": ["верный", "подходящий", "должный", "истинный", "нормальный", "нужный", "удовлетворительный"],
    "правильный треугольник": ["равносторонний треугольник"],
    "правильный тринадцатиугольник": ["тринадцатиугольник"],
    "правильный четырнадцатиугольник": ["четырнадцатиугольник"],
    "правильный шестиугольник": ["гексагон"],
    "правильный шестнадцатиугольник": ["шестнадцатиугольник"],
    "правист": ["правник", "юрист"],
    "правитель": ["властелин", "руководитель", "управляющий", "заведующий", "кормчий"],
    "правительственно-парламентский": ["парламентско-правительственный"],
    "правительство": ["власть", "начальник", "начальство", "кабинет", "говнительство"],
    "правительствовав": ["правительствовавши"],
    "правительствовавши": ["правительствовав"],
    "править": ["руководить", "управлять", "командовать", "властвовать", "возглавлять", "направлять", "княжить", "задавать тон", "начальствовать", "держать бразды правления", "водить", "предводительствовать", "заведовать", "распоряжаться", "дирижировать"],
    "править бал": ["царствовать"],
    "правка": ["исправление", "корректура"],
    "правление": ["управление", "руководство", "администрация"],
    "правленье": ["правление"],
    "правнучатный": ["правнучатый"],
    "правнучатый": ["правнучатный"],
    "право": ["объективное право", "закон", "юриспруденция", "субъективное право", "притязание", "разрешение"],
    "право слово": ["действительно"],
    "правобережная украина": ["правобережье", "тогобочная украина", "заднепровский край"],
    "правоведение": ["юриспруденция"],
    "правоведческий": ["юридический"],
    "правоверный": ["ревностный", "ортодоксальный", "мусульманин", "православный"],
    "правовой": ["юридический"],
    "правограмма": ["декстрограмма"],
    "праводушие": ["добросовестность"],
    "правомерный": ["законный", "закономерный"],
    "правомочность": ["законность", "легитимность", "правомерность", "правильность", "обоснованность"],
    "правомочный": ["полномочный", "правомерный"],
    "правоохранение": ["правоохраненье", "правоохренение"],
    "правоохраненье": ["правоохранение", "правоохренение"],
    "правоохранитель": ["блюститель порядка", "страж порядка", "страж закона"],
    "правоохранительный": ["правонарушительный", "правоохренительный", "правоотравительный"],
    "правоохранник": ["правоохранитель"],
    "правоохренение": ["правоохранение", "правоохраненье"],
    "правописание": ["орфография"],
    "правописанье": ["правописание"],
    "правопредшественник": ["наследодатель"],
    "правопреемник": ["наследник"],
    "правопреемство": ["правопреемственность"],
    "праворадикал": ["праворадикалист", "ультраправый"],
    "праворулевой": ["праворульный"],
    "праворульный": ["праворулевой"],
    "правосек": ["бандеровец", "укронацист", "азовец"],
    "православие головного мозга": ["христоз головного мозга", "пгм", "фофудья"],
    "православнутый": ["православный"],
    "православье": ["православие"],
    "правословие": ["этимология"],
    "правосторонний": ["левосторонний"],
    "правосточнославянский": ["древнерусский"],
    "правосудие": ["юстиция", "суд", "судопроизводство", "судебное производство"],
    "правосудье": ["правосудие"],
    "правота": ["правильность", "справедливость"],
    "правша": ["праворукий"],
    "прагерманский": ["протогерманский"],
    "прагматик": ["прагматист"],
    "прагматика": ["практичность", "прагматизм"],
    "прагматист": ["прагматик"],
    "прагматический": ["прагматичный"],
    "прагматично": ["утилитарно", "приземлённо", "практично"],
    "прадед": ["прадедушка"],
    "прадедовский": ["прадедов"],
    "прадедушка": ["прадед"],
    "пражанин": ["пражец"],
    "празападногерманский": ["протозападногерманский"],
    "празднество": ["празднование"],
    "празднив": ["празднивши"],
    "празднивши": ["празднив"],
    "праздник": ["празднество", "торжество", "празднование"],
    "праздник жизни": ["молодость"],
    "праздник кущей": ["суккот"],
    "праздничав": ["праздничавши"],
    "праздничавши": ["праздничав"],
    "праздновав": ["праздновавши"],
    "праздновавши": ["праздновав"],
    "празднованье": ["празднование"],
    "празднолюбивый": ["праздный", "ленивый"],
    "праздномыслив": ["праздномысливши"],
    "праздномысливши": ["праздномыслив"],
    "празднослов": ["пустослов", "пустозвон"],
    "празднословив": ["празднословивши"],
    "празднословивши": ["празднословив"],
    "празднословие": ["пустословие", "словоблудие"],
    "празднословье": ["празднословие"],
    "праздность": ["безделье", "леность", "бездельничанье"],
    "праздношатательствовав": ["праздношатательствовавши"],
    "праздношатательствовавши": ["праздношатательствовав"],
    "праздношатающийся": ["праздный"],
    "праздный": ["порожний", "пустой", "пустопорожний", "свободный", "вакантный", "бездельный", "досужий"],
    "празнина": ["дупка", "шупла", "кухина", "луфт"],
    "праиндоевропейский": ["праиндоевропейский язык"],
    "праиндоевропейский язык": ["праиндоевропейский", "пие"],
    "праиталийский": ["праиталийский язык", "протоиталийский", "протоиталийский язык"],
    "праиталийский язык": ["праиталийский", "протоиталийский", "протоиталийский язык"],
    "прайвеси": ["приватность"],
    "праймер": ["затравка"],
    "праймовый": ["прайм-таймовый"],
    "прайс": ["прайс-лист"],
    "прайс-лист": ["прайс", "прейскурант"],
    "прайс-тейкер": ["ценополучатель", "прайстейкер"],
    "прайсмейкер": ["прайс-мейкер", "ценопроизводитель"],
    "пракельтский": ["пракельтский язык", "протокельтский", "протокельтский язык"],
    "пракельтский язык": ["пракельтский", "протокельтский", "протокельтский язык"],
    "праксеологический": ["праксиологический"],
    "праксеология": ["праксиология"],
    "праксиологический": ["праксеологический"],
    "праксиология": ["праксеология"],
    "практика": ["опыт", "оборот"],
    "практикабль": ["вышка"],
    "практикантка": ["лаборантка"],
    "практиковав": ["практиковавши"],
    "практиковавши": ["практиковав"],
    "практиковать": ["применять"],
    "практикум": ["лабораторка"],
    "практицизм": ["практичность", "рациональность"],
    "практически": ["эмпирически", "фактически", "по существу", "на практике", "по сути дела"],
    "практический": ["реальный"],
    "практичный": ["прагматичный", "деловой"],
    "пральна машина": ["пралка", "пралька"],
    "пральная машына": ["пральня"],
    "праматерь": ["родоначальница", "прародительница"],
    "прамс": ["велямс", "сяворемс", "шудемс"],
    "пранкер": ["пранкстер"],
    "пранковав": ["пранковавши", "разыгрывав"],
    "пранковавши": ["пранковав", "разыгрывав"],
    "пранковавший": ["разыгрывавший"],
    "пранковать": ["разыгрывать", "подшучивать"],
    "пранкстер": ["пранкер"],
    "праобраз": ["первообраз", "архетип"],
    "праотец": ["предок", "пращур", "прародитель", "родитель", "родоначальник"],
    "праотець": ["прабатько", "праотця"],
    "прапор": ["знамя", "прапорец", "флюгель", "копьё", "флажок"],
    "прапорщик": ["прапор"],
    "прапорщичий": ["прапорщицкий"],
    "прапрабабушка": ["прапрабабка"],
    "прапрадед": ["прапрадедушка"],
    "прапрадедушка": ["прапрадед"],
    "прапрапрабабушка": ["прапрапрабабка"],
    "прапрапрадед": ["прапрапрадедушка"],
    "прапрапрадедушка": ["прапрапрадед", "прапредок", "пращур"],
    "прапредок": ["прапрапрадедушка"],
    "прародительница": ["праматерь"],
    "прасаамский язык": ["прасаамский"],
    "праславянский": ["общеславянский"],
    "праславянский язык": ["праславянский"],
    "прасумаваць": ["прасмуткаваць"],
    "пратеник": ["делегат", "представител", "посланик", "депутат"],
    "пратохарский язык": ["пратохарский"],
    "прать": ["переть"],
    "пратюркский": ["общетюркский"],
    "прауральский": ["прауральский язык"],
    "прауральский язык": ["прауральский"],
    "прах": ["порошок", "пыль", "пепел", "труп", "останки"],
    "прах культуры": ["крах культуры", "парк культуры имени отдыха"],
    "прахоляк": ["пушилка"],
    "працювати": ["робити", "трудитися"],
    "праця": ["робота", "труд"],
    "прашивав": ["прашивавши"],
    "прашивавши": ["прашивав"],
    "пращ": ["праща"],
    "праща": ["пращ"],
    "пращур": ["прапрапрадед", "прапрапрадедушка", "прародитель", "праотец", "родоначальник", "зачинатель"],
    "праязык": ["протоязык"],
    "праязыковой": ["праязычный"],
    "пре": ["пред"],
    "пре-": ["архи-", "сверх-", "супер-", "пред-", "про-"],
    "преагональный": ["предагональный"],
    "преагония": ["предагония"],
    "преамбула": ["введение", "предисловие"],
    "преархей": ["предархей", "катархей", "преархейский эон"],
    "пребрадка": ["забрадка"],
    "пребыв": ["пребывши"],
    "пребывав": ["пребывавши"],
    "пребывавши": ["пребывав"],
    "пребыванье": ["пребывание"],
    "пребывать": ["находиться", "быть"],
    "пребывши": ["пребыв"],
    "пребыть": ["остаться"],
    "прев": ["превши"],
    "превалировав": ["превалировавши"],
    "превалировавши": ["превалировав"],
    "превалирование": ["преобладание", "преимущество", "доминирование", "превосходство"],
    "превалировать": ["преобладать"],
    "превеликий": ["великий", "громадный", "огромный", "выдающийся"],
    "превентивно": ["упреждающе", "заранее", "заблаговременно", "загодя"],
    "превентивный": ["предупреждающий", "упреждающий", "предохранительный", "предупредительный", "профилактический", "опережающий"],
    "превентировав": ["превентировавши"],
    "превентировавши": ["превентировав"],
    "превзойти": ["превысить"],
    "превоз": ["превозване", "транспорт", "пренос"],
    "превозвысив": ["превозвысивши"],
    "превозвысивши": ["превозвысив"],
    "превозвышав": ["превозвышавши"],
    "превозвышавши": ["превозвышав"],
    "превозгласив": ["превозгласивши"],
    "превозгласивши": ["превозгласив"],
    "превозглашав": ["превозглашавши"],
    "превозглашавши": ["превозглашав"],
    "превозмогав": ["превозмогавши"],
    "превозмогавши": ["превозмогав"],
    "превозмогание": ["преодоление"],
    "превозмогающий": ["преодолевающий"],
    "превозмочь": ["преодолеть", "пересилить", "одолеть", "победить", "побороть"],
    "превознестись": ["зазнаться", "возгордиться"],
    "превозносив": ["превозносивши"],
    "превозносивши": ["превозносив"],
    "превозносить": ["возвеличивать", "восхвалять", "славить", "расхваливать", "хвалить"],
    "превокальный": ["предвокальный"],
    "превосходив": ["превосходивши"],
    "превосходивши": ["превосходив"],
    "превосходная степень": ["суперлатив"],
    "превосходно": ["великолепно", "замечательно", "изумительно"],
    "превосходный": ["отличный", "наилучший", "великолепный", "идеальный", "перворазрядный", "чудесный"],
    "превосходство": ["преимущество"],
    "превосходствовав": ["превосходствовавши"],
    "превосходствовавши": ["превосходствовав"],
    "превосхождение": ["превосходство", "преодоление", "преодоленье"],
    "преврат": ["промяна", "обрат", "прелом"],
    "превратив": ["превративши"],
    "превративши": ["превратив"],
    "превратительный": ["включительный"],
    "превратительный падеж": ["транслатив", "второй винительный падеж", "включительный падеж"],
    "превратить": ["переменить", "претворить"],
    "превратиться": ["стать", "обратиться"],
    "превратно": ["искажённо", "ложно", "изменчиво"],
    "превратность": ["изменчивость", "непостоянство", "злоключение"],
    "превратный": ["изменчивый", "непостоянный", "шаткий", "ненадёжный", "лживый", "ложный", "мнимый", "несправедливый", "обманный", "облыжный", "фиктивный", "воображаемый", "поддельный", "подложный", "подставной"],
    "превращав": ["превращавши"],
    "превращавши": ["превращав"],
    "превращаться в тыкву": ["превращаться в кирпич", "превращаться в говно"],
    "превращение": ["преобразование", "метаморфоза", "трансформация"],
    "превращенье": ["превращение"],
    "превши": ["прев"],
    "превысив": ["превысивши"],
    "превысивши": ["превысив"],
    "превышав": ["превышавши"],
    "превышавши": ["превышав"],
    "превышать": ["превосходить"],
    "превыше": ["выше", "важнее"],
    "превышенье": ["превышение"],
    "превью": ["предпросмотр"],
    "прегадкий": ["препоганый"],
    "прегледност": ["нагледност", "яснота", "разбираемост", "изразителност"],
    "преглубокий": ["глубочайший", "глубоченный"],
    "преголя": ["преголи"],
    "преграда": ["препятствие", "препона"],
    "преградив": ["преградивши"],
    "преградивши": ["преградив"],
    "преградить": ["перегородить"],
    "преграждав": ["преграждавши"],
    "преграждавши": ["преграждав"],
    "прегрешав": ["прегрешавши"],
    "прегрешавши": ["прегрешав"],
    "прегрешенье": ["прегрешение"],
    "прегрешив": ["прегрешивши"],
    "прегрешивши": ["прегрешив"],
    "пред": ["перед", "передо", "предо"],
    "пред-": ["до-"],
    "предав": ["предавши"],
    "предавав": ["предававши"],
    "предававши": ["предавав"],
    "предавать": ["подвергать", "отдавать", "передавать", "делать достоянием", "изменять"],
    "предавать земле": ["хоронить"],
    "предавши": ["предав"],
    "предагональный": ["преагональный"],
    "предагония": ["преагония"],
    "преданность": ["верность", "приверженность", "привязанность", "лояльность"],
    "преданный": ["верный"],
    "предархей": ["преархей"],
    "предатель": ["изменник", "изменщик", "иуда", "веролом", "вероотступник", "дезертир", "душепродавец", "христопродавец", "израдник", "искариот", "каин", "кидок", "отступник", "клятвопреступник", "перебежчик"],
    "предательница": ["врагиня"],
    "предательски": ["вероломно", "коварно"],
    "предательский": ["изменнический", "коварный"],
    "предательство": ["измена", "вероломство"],
    "предательствовав": ["предательствовавши"],
    "предательствовавши": ["предательствовав"],
    "предать": ["изменить", "передать", "подвергнуть"],
    "предать земле": ["погрести", "захоронить", "похоронить", "схоронить", "закопать"],
    "предварение": ["предшествование", "пролог", "предисловие"],
    "предваренье": ["предварение"],
    "предварив": ["предваривши"],
    "предваривши": ["предварив"],
    "предварилка": ["предвариловка"],
    "предварительно напряжённый железобетон": ["преднапряжённый железобетон"],
    "предварительный": ["подготовительный", "вступительный", "неокончательный", "заблаговременный", "упредительный"],
    "предварительный усилитель": ["предусилитель", "преамп", "фонокорректор"],
    "предварить": ["предупредить", "уведомить", "известить", "опередить", "предпослать"],
    "предваряв": ["предварявши"],
    "предварявши": ["предваряв"],
    "предварять": ["упреждать", "предвосхищать", "опережать"],
    "предведенье": ["предведение"],
    "предвестив": ["предвестивши"],
    "предвестивши": ["предвестив"],
    "предвестие": ["знак", "знамение", "предвещание", "предзнаменование", "предсказание", "примета", "провозвестие", "предчувствие"],
    "предвестить": ["предсказать", "предречь", "напророчить", "предзнаменовать"],
    "предвестник": ["предзнаменование", "предвестие"],
    "предвестье": ["предвестие"],
    "предвечерие": ["предвечерье"],
    "предвечерний": ["подвечерний"],
    "предвечерье": ["предвечерие"],
    "предвещав": ["предвещавши"],
    "предвещавши": ["предвещав"],
    "предвещанье": ["предвещание"],
    "предвещать": ["предсказывать", "предрекать", "предупреждать"],
    "предвещение": ["предсказание", "предзнаменование"],
    "предвзято": ["пристрастно", "необъективно"],
    "предвзятый": ["пристрастный", "необъективный", "предубеждённый"],
    "предвидев": ["предвидевши"],
    "предвидевши": ["предвидев"],
    "предвидение": ["предсказание", "предугадывание", "прогноз", "ясновидение"],
    "предвиденье": ["предвидение"],
    "предвидеть": ["предсказать", "предугадать", "провидеть", "предполагать"],
    "предвидеться": ["предугадываться", "предполагаться"],
    "предвкусив": ["предвкусивши"],
    "предвкусивши": ["предвкусив"],
    "предвкушав": ["предвкушавши"],
    "предвкушавши": ["предвкушав"],
    "предвкушение": ["предвкушенье", "ожидание", "ожиданье", "предвосхищение", "предвосхищенье"],
    "предвкушенье": ["предвкушение"],
    "предводив": ["предводивши"],
    "предводивши": ["предводив"],
    "предводитель": ["глава", "руководитель", "предводитель дворянства"],
    "предводитель дворянства": ["предводитель"],
    "предводительница": ["глава", "руководительница", "предводитель дворянства"],
    "предводительство": ["руководство"],
    "предводительствовав": ["предводительствовавши"],
    "предводительствовавши": ["предводительствовав"],
    "предвозвестив": ["предвозвестивши"],
    "предвозвестивши": ["предвозвестив"],
    "предвозвестить": ["предсказать"],
    "предвозвестник": ["предвестник"],
    "предвозвещав": ["предвозвещавши"],
    "предвозвещавши": ["предвозвещав"],
    "предвозвещать": ["провозвещать", "предвещать", "предрекать", "предсказывать"],
    "предвозрождение": ["проторенессанс"],
    "предвокальный": ["превокальный"],
    "предвосхитив": ["предвосхитивши"],
    "предвосхитивши": ["предвосхитив"],
    "предвосхищав": ["предвосхищавши"],
    "предвосхищавши": ["предвосхищав"],
    "предвосхищать": ["предугадывать"],
    "предвосхищение": ["предугадывание", "предвидение", "предсказывание", "предсказание", "пророчество", "прорицание", "антиципация"],
    "предвосхищенье": ["предвосхищение"],
    "предвычислив": ["предвычисливши"],
    "предвычисливши": ["предвычислив"],
    "предвычисляв": ["предвычислявши"],
    "предвычислявши": ["предвычисляв"],
    "предговор": ["увод", "встъпление", "пролог", "предисловие"],
    "предгорье": ["предгорие"],
    "преддверие": ["порог", "канун"],
    "преддверье": ["преддверие"],
    "преддиабетический": ["предиабетический"],
    "предел": ["граница", "рубеж", "край", "грань", "максимум", "лимит", "страна"],
    "предел количественного определения": ["пко"],
    "предельно": ["крайне", "максимально"],
    "предельно допустимая концентрация": ["пдк"],
    "предельный": ["крайний", "максимальный"],
    "предельный углеводород": ["алкан", "насыщенный углеводород"],
    "предержащий": ["имущий"],
    "предестинация": ["предопределение", "рок", "фатум"],
    "предзаказав": ["предзаказавши"],
    "предзаказавши": ["предзаказав"],
    "предзаказывав": ["предзаказывавши"],
    "предзаказывавши": ["предзаказывав"],
    "предзастольный": ["предпраздничный"],
    "предзвенев": ["предзвеневши"],
    "предзвеневши": ["предзвенев"],
    "предзнаменовав": ["предзнаменовавши"],
    "предзнаменовавши": ["предзнаменовав"],
    "предзнаменование": ["предвестие", "знамение", "примета", "предзнаменованье"],
    "предзнаменованье": ["предзнаменование"],
    "предзнаменовывав": ["предзнаменовывавши"],
    "предзнаменовывавши": ["предзнаменовывав"],
    "предзнаменовывать": ["предвещать"],
    "преди-": ["перед-", "пред-"],
    "предиабет": ["преддиабет"],
    "предиабетический": ["преддиабетический"],
    "предизвикател": ["подстрекател", "подбудител", "провокатор"],
    "предика": ["проповедь", "нравоучение"],
    "предикат": ["сказуемое"],
    "предикатив": ["категория состояния"],
    "предикативная группа": ["предикатив", "сказуемое"],
    "предикативная единица": ["предложение"],
    "предикативний": ["присудковий"],
    "предикативный": ["предикатный", "сказуемостный"],
    "предикатный": ["предикативный"],
    "предисловие": ["пролог", "введение"],
    "предисловье": ["предисловие"],
    "предицировав": ["предицировавши"],
    "предицировавши": ["предицировав"],
    "предклинический": ["доклинический"],
    "предковидный": ["доковидный", "докоронавирусный", "докоронный", "предкоронавирусный"],
    "предковый": ["предковский"],
    "предкоронавирусный": ["доковидный", "докоронавирусный", "докоронный", "предковидный"],
    "предлагав": ["предлагавши"],
    "предлагавши": ["предлагав"],
    "предлежав": ["предлежавши"],
    "предлежавши": ["предлежав"],
    "предлинно": ["длинно-предлинно"],
    "предлог": ["повод", "довод", "отговорка"],
    "предложение": ["приглашение"],
    "предложивши": ["предложив"],
    "предложный падеж": ["препозитив"],
    "предменструальный синдром": ["пмс"],
    "предместье": ["пригород"],
    "предмет": ["вещь", "событие", "факт", "тема", "дисциплина"],
    "предметный": ["вещественный"],
    "предназначав": ["предназначавши"],
    "предназначавши": ["предназначав"],
    "предназначение": ["назначение", "функция", "миссия", "роль"],
    "предназначенье": ["предназначение"],
    "предназначив": ["предназначивши"],
    "предназначивши": ["предназначив"],
    "преднамеренный": ["умышленный"],
    "предначав": ["предначавши"],
    "предначавши": ["предначав"],
    "предначертав": ["предначертавши"],
    "предначертавши": ["предначертав"],
    "предначертанный": ["предопределённый", "предписанный", "предрешённый"],
    "предначертанье": ["предначертание"],
    "предначинав": ["предначинавши"],
    "предначинавши": ["предначинав"],
    "преднейший": ["главнейший", "первейший"],
    "предний": ["передний"],
    "предносив": ["предносивши"],
    "предносивши": ["предносив"],
    "предобеденный": ["дообеденный"],
    "предображав": ["предображавши"],
    "предображавши": ["предображав"],
    "предобразив": ["предобразивши"],
    "предобразивши": ["предобразив"],
    "предобуславливание": ["предобусловливание"],
    "предобуславливатель": ["предобусловливатель"],
    "предобусловив": ["предобусловивши"],
    "предобусловивши": ["предобусловив"],
    "предобусловливание": ["сенсорное предобусловливание"],
    "предобусловливатель": ["предобуславливатель"],
    "предок": ["пращур", "родитель"],
    "предоктябрьский": ["предпраздничный", "предъюбилейный"],
    "предоплатив": ["предоплативши"],
    "предоплативши": ["предоплатив"],
    "предоплачивав": ["предоплачивавши"],
    "предоплачивавши": ["предоплачивав"],
    "предопределение": ["предопределенье", "предназначение", "обусловленность", "судьба", "предестинация"],
    "предопределенье": ["предопределение"],
    "предопределив": ["предопределивши"],
    "предопределивши": ["предопределив"],
    "предопределить": ["предначертать", "обусловить", "предрешить"],
    "предопределяв": ["предопределявши"],
    "предопределявши": ["предопределяв"],
    "предопределённый": ["предначертанный", "неизбежный", "неотвратимый", "обусловленный", "предрешённый", "детерминированный"],
    "предоставив": ["предоставивши"],
    "предоставивши": ["предоставив"],
    "предоставляв": ["предоставлявши"],
    "предоставлявши": ["предоставляв"],
    "предоставлять": ["давать", "позволять"],
    "предостерегав": ["предостерегавши"],
    "предостерегавши": ["предостерегав"],
    "предостерегательный": ["предупредительный", "предостерегающий", "оповещательный", "извещательный", "предуведомительный"],
    "предостерегать": ["предупреждать"],
    "предостерегающий": ["предупреждающий"],
    "предостережение": ["предупреждение"],
    "предостереженье": ["предостережение"],
    "предосторожность": ["настороженность", "мера предосторожности"],
    "предосудительность": ["неблаговидность", "непозволительность"],
    "предотвратив": ["предотвративши"],
    "предотвративши": ["предотвратив"],
    "предотвратить": ["предупредить"],
    "предотвращав": ["предотвращавши"],
    "предотвращавши": ["предотвращав"],
    "предотвращение": ["профилактика", "недопущение"],
    "предохранив": ["предохранивши"],
    "предохранивши": ["предохранив"],
    "предохранительный": ["предохраняющий", "превентивный", "защитный"],
    "предохраняв": ["предохранявши"],
    "предохранявши": ["предохраняв"],
    "предощутив": ["предощутивши"],
    "предощутивши": ["предощутив"],
    "предощущав": ["предощущавши"],
    "предощущавши": ["предощущав"],
    "предощущать": ["предчувствовать"],
    "предощущение": ["предчаяние", "предчувствие", "предвкушение"],
    "предощущенье": ["предощущение"],
    "предпандемийный": ["допандемийный", "допандемический", "предпандемический"],
    "предпандемический": ["допандемийный", "допандемический", "предпандемийный"],
    "предписав": ["предписавши"],
    "предписавши": ["предписав"],
    "предписание": ["приказ"],
    "предписанье": ["предписание"],
    "предписать": ["приказать"],
    "предписывав": ["предписывавши"],
    "предписывавши": ["предписывав"],
    "предписывать": ["приказывать", "распоряжаться"],
    "предписьменность": ["протописьменность"],
    "предполагав": ["предполагавши"],
    "предполагавши": ["предполагав"],
    "предполагаемо": ["предположительно", "гипотетически"],
    "предполагать": ["предположить", "собираться", "намереваться", "вознамериться", "намерен", "думать", "планировать", "запланировать"],
    "предположение": ["план", "замысел", "намерение"],
    "предположенье": ["предположение"],
    "предположив": ["предположивши"],
    "предположивши": ["предположив"],
    "предположительно": ["гипотетически", "предполагаемо"],
    "предполётный": ["дополётный"],
    "предпослав": ["предпославши"],
    "предпославши": ["предпослав"],
    "предпослать": ["предварить"],
    "предпосылав": ["предпосылавши"],
    "предпосылавши": ["предпосылав"],
    "предпосылать": ["предварять"],
    "предпосылка": ["условие"],
    "предпочитав": ["предпочитавши"],
    "предпочитавши": ["предпочитав"],
    "предпочитать": ["отдавать предпочтение", "перед", "считать за благо"],
    "предпочтительнее": ["предпочтительней"],
    "предпочтительней": ["предпочтительнее"],
    "предпочтительный": ["желательный"],
    "предпраздновав": ["предпраздновавши"],
    "предпраздновавши": ["предпраздновав"],
    "предпремьерный": ["допремьерный"],
    "предприимав": ["предприимавши"],
    "предприимавши": ["предприимав"],
    "предприимать": ["предпринимать"],
    "предприимчивость": ["активность", "деятельность", "деловитость", "энергичность", "инициативность"],
    "предприимчивый": ["деловой", "энергичный", "инициативный"],
    "предпринимав": ["предпринимавши"],
    "предпринимавши": ["предпринимав"],
    "предприниматель": ["бизнесмен", "делец", "коммерсант", "хозяйствующий субъект"],
    "предпринимательство": ["бизнес"],
    "предпринимательствовав": ["предпринимательствовавши"],
    "предпринимательствовавши": ["предпринимательствовав"],
    "предпринимательствовать": ["хозяйствовать"],
    "предприняв": ["предпринявши"],
    "предпринявши": ["предприняв"],
    "предпринятие": ["делание"],
    "предприятие": ["проект", "инициатива", "начинание", "бизнес", "организация", "фирма"],
    "предприятье": ["предприятие"],
    "предпрошедший": ["плюсквамперфектный"],
    "предразсъдък": ["предубеждение", "заблуда"],
    "предрасполагав": ["предрасполагавши"],
    "предрасполагавши": ["предрасполагав"],
    "предрасположение": ["предрасположенность"],
    "предрасположенность": ["склонность", "расположение", "предрасположение"],
    "предрасположив": ["предрасположивши"],
    "предрасположивши": ["предрасположив"],
    "предрассудок": ["предубеждение", "суеверие", "суперстиция"],
    "предрассудочек": ["предрассудок"],
    "предрассуждение": ["предрассудок", "суеверие"],
    "предрассужденье": ["предрассуждение"],
    "предрекав": ["предрекавши"],
    "предрекавши": ["предрекав"],
    "предрекать": ["предсказывать", "пророчить", "пророчествовать", "прорицать", "прогнозировать"],
    "предрекающий": ["предсказывающий"],
    "предреченье": ["предречение"],
    "предрешав": ["предрешавши"],
    "предрешавши": ["предрешав"],
    "предрешать": ["решать", "определять", "предопределять"],
    "предрешив": ["предрешивши"],
    "предрешивши": ["предрешив"],
    "предрешить": ["решить", "определить", "предопределить"],
    "предрика": ["председатель райисполкома"],
    "предросток": ["заросток"],
    "председав": ["председавши"],
    "председавши": ["председав"],
    "председательница": ["членка"],
    "председательствовав": ["председательствовавши"],
    "председательствовавши": ["председательствовав"],
    "председать": ["председательствовать"],
    "предсердечный": ["прекардиальный"],
    "предсердье": ["предсердие"],
    "предсерийный": ["досерийный"],
    "предсказав": ["предсказавши"],
    "предсказавши": ["предсказав"],
    "предсказание": ["предсказывание", "пророчествование", "прорицание", "предвидение", "пророчество", "прогноз"],
    "предсказанье": ["предсказание"],
    "предсказательный": ["предвещательный", "пророчественный", "прогностический"],
    "предсказуемый": ["ожидаемый"],
    "предсказывав": ["предсказывавши"],
    "предсказывавши": ["предсказывав"],
    "предсказывать": ["предрекать", "пророчить", "пророчествовать", "прорицать", "прогнозировать"],
    "предсменный": ["досменный"],
    "предсмертье": ["предсмертие"],
    "представ": ["представши"],
    "представав": ["представавши"],
    "представавши": ["представав"],
    "представать": ["являться", "появляться"],
    "представив": ["представивши"],
    "представивши": ["представив"],
    "представимый": ["мыслимый", "вообразимый", "возможный"],
    "представитель": ["агент", "президент", "член", "образец", "образчик", "экземпляр"],
    "представительно": ["авторитетно", "солидно", "почтенно"],
    "представительность": ["внушительность", "солидность", "импозантность", "авантажность", "респектабельность", "чинность", "важность", "осанистость", "вальяжность", "степенность", "видность", "величавость", "почтительность", "сановитость", "презентабельность"],
    "представительский": ["официальный", "парадный", "высококомфортабельный", "элитный", "люкс", "роскошный", "шикарный"],
    "представительствовав": ["представительствовавши"],
    "представительствовавши": ["представительствовав"],
    "представиться": ["назваться", "возникнуть", "появиться", "показаться", "предстать", "пригрезиться", "помыслиться", "произвести впечатление", "притвориться", "прикинуться"],
    "представление": ["спектакль", "шоу", "прошение", "ходатайство", "понятие", "подача"],
    "представленье": ["представление"],
    "представляв": ["представлявши"],
    "представлявши": ["представляв"],
    "представлять": ["мыслить", "воображать", "представлять себе", "имажинировать", "являться", "представлять собой", "доставлять", "предъявлять", "предоставлять", "знакомить"],
    "представляться": ["казаться", "сдаваться", "думаться"],
    "представши": ["представ"],
    "предстарческий": ["пресенильный", "инволюционный"],
    "предстательная железа": ["простата", "второе сердце мужчины"],
    "предстательствовав": ["предстательствовавши"],
    "предстательствовавши": ["предстательствовав"],
    "предстояв": ["предстоявши"],
    "предстоявши": ["предстояв"],
    "предстоящий": ["будущий"],
    "предсуществовав": ["предсуществовавши"],
    "предсуществовавши": ["предсуществовав"],
    "предсуществование": ["преэкзистенция"],
    "предтеча": ["предшественник", "предвестник"],
    "предтече в шерсти": ["раскольник"],
    "предтечка": ["проэструс", "проэструм"],
    "предубедив": ["предубедивши"],
    "предубедивши": ["предубедив"],
    "предубеждав": ["предубеждавши"],
    "предубеждавши": ["предубеждав"],
    "предубеждение": ["предвзятость", "предубеждённость", "предубежденье"],
    "предубежденье": ["предубеждение"],
    "предуведомив": ["предуведомивши"],
    "предуведомивши": ["предуведомив"],
    "предуведомляв": ["предуведомлявши"],
    "предуведомлявши": ["предуведомляв"],
    "предугадав": ["предугадавши"],
    "предугадавши": ["предугадав"],
    "предугадывав": ["предугадывавши"],
    "предугадывавши": ["предугадывав"],
    "предуготовив": ["предуготовивши"],
    "предуготовивши": ["предуготовив"],
    "предуготовляв": ["предуготовлявши"],
    "предуготовлявши": ["предуготовляв"],
    "предузнав": ["предузнавши"],
    "предузнавав": ["предузнававши"],
    "предузнававши": ["предузнавав"],
    "предузнавши": ["предузнав"],
    "предузнать": ["предугадать"],
    "предуказав": ["предуказавши"],
    "предуказавши": ["предуказав"],
    "предуказывав": ["предуказывавши"],
    "предуказывавши": ["предуказывав"],
    "предумышленно": ["преднамеренно", "умышленно"],
    "предумышленный": ["преднамеренный", "умышленный"],
    "предупредив": ["предупредивши"],
    "предупредивши": ["предупредив"],
    "предупредительность": ["почтительность", "заботливость", "тактичность", "внимательность"],
    "предупредить": ["предуведомить", "оповестить", "предотвратить", "упредить"],
    "предупреждав": ["предупреждавши"],
    "предупреждавши": ["предупреждав"],
    "предупреждать": ["сообщать", "информировать", "извещать", "уведомлять", "осведомлять", "докладывать", "доносить", "заявлять", "объявлять", "оповещать"],
    "предупреждение": ["предуведомление", "предостережение", "сообщение", "извещение", "упреждение", "предотвращение"],
    "предупрежденье": ["предупреждение"],
    "предусматривав": ["предусматривавши"],
    "предусматривавши": ["предусматривав"],
    "предусматривать": ["предвидеть", "учитывать", "предвкушать"],
    "предусмотрев": ["предусмотревши"],
    "предусмотревши": ["предусмотрев"],
    "предусмотрение": ["предвидение"],
    "предусмотренный": ["предустановленный", "рассчитанный", "предугаданный", "предвиденный"],
    "предусмотрительный": ["дальновидный", "расчётливый"],
    "предустанавливав": ["предустанавливавши"],
    "предустанавливавши": ["предустанавливав"],
    "предустановив": ["предустановивши"],
    "предустановивши": ["предустановив"],
    "предходив": ["предходивши"],
    "предходивши": ["предходив"],
    "предчелюстной": ["премаксиллярный"],
    "предчувствовав": ["предчувствовавши"],
    "предчувствовавши": ["предчувствовав"],
    "предчувствовать": ["предвидеть", "предугадывать"],
    "предчувствье": ["предчувствие"],
    "предшественник": ["предтеча"],
    "предшествие": ["предшествование"],
    "предшествовав": ["предшествовавши"],
    "предшествовавши": ["предшествовав"],
    "предшествующий": ["прошлый", "предыдущий"],
    "предъява": ["упрёк", "укор", "укоризна", "жалоба"],
    "предъявив": ["предъявивши"],
    "предъявивши": ["предъявив"],
    "предъявление": ["представление"],
    "предъявляв": ["предъявлявши"],
    "предъявлявши": ["предъявляв"],
    "предыдущий": ["предшествующий", "прошлый"],
    "предызбирав": ["предызбиравши"],
    "предызбиравши": ["предызбирав"],
    "предызбрав": ["предызбравши"],
    "предызбравши": ["предызбрав"],
    "предызображав": ["предызображавши"],
    "предызображавши": ["предызображав"],
    "предызобразив": ["предызобразивши"],
    "предызобразивши": ["предызобразив"],
    "предызъявлять": ["предусматривать"],
    "предэякулят": ["предсемя", "куперова жидкость"],
    "преемник": ["последователь", "выкормыш"],
    "преемница": ["наследница", "правопреемница", "продолжательница"],
    "преемственность": ["преемничество", "преемство"],
    "прежде": ["некогда", "раньше", "в прошлом", "сперва", "сначала"],
    "прежде всего": ["в первую очередь", "перво-наперво", "особенно", "превыше всего"],
    "преждевременно": ["раньше времени", "рано", "рановато", "досрочно"],
    "преживелица": ["случка", "приключение", "събитие", "отживелица", "отживялост"],
    "прежний": ["былой", "минувший", "прошлый", "прошедший", "бывший", "старый"],
    "презабавный": ["занимательный"],
    "презанятно": ["интересно"],
    "презенс": ["настоящее время"],
    "презент": ["подарок"],
    "презентабельность": ["представительность"],
    "презентабельный": ["представительный", "порядочный", "приличный"],
    "презентация": ["представление"],
    "презентировав": ["презентировавши"],
    "презентировавши": ["презентировав"],
    "презентировать": ["презентовать"],
    "презентирующий": ["презентующий"],
    "презентовав": ["презентовавши"],
    "презентовавши": ["презентовав"],
    "презентовать": ["представлять", "представить", "дарить", "подарить"],
    "презервативный": ["предохранительный"],
    "президент": ["первое лицо", "пересидент", "презик"],
    "президент министров": ["премьер-министр"],
    "президентская академия": ["ранхигс", "ранепа"],
    "президентский": ["презиковский"],
    "президентско-парламентский": ["парламентско-президентский"],
    "президентствовав": ["президентствовавши"],
    "президентствовавши": ["президентствовав"],
    "президентша": ["директорша", "директриса", "руководительница", "председательница", "первая леди"],
    "презинджантроп": ["хабилис", "человек умелый"],
    "презирав": ["презиравши"],
    "презиравши": ["презирав"],
    "презирать": ["пренебрегать", "ни во что не ставить", "манкировать", "смотреть свысока", "попирать"],
    "презирство": ["зневага"],
    "презлющий": ["злющий"],
    "презорный": ["презренный", "презрительный"],
    "презрев": ["презревши"],
    "презревши": ["презрев"],
    "презрение": ["презренье", "пренебрежение", "попрание"],
    "презренье": ["презрение"],
    "презреть": ["пренебречь"],
    "презрительно": ["снисходительно", "пренебрежительно"],
    "презрительный": ["снисходительный", "презренный"],
    "презумпция": ["допущение"],
    "презюмировав": ["презюмировавши"],
    "презюмировавши": ["презюмировав"],
    "преизбыточествовав": ["преизбыточествовавши"],
    "преизбыточествовавши": ["преизбыточествовав"],
    "преизобиловав": ["преизобиловавши"],
    "преизобиловавши": ["преизобиловав"],
    "преимущественно": ["главным образом", "в основном", "наиболее", "особенно", "обычно"],
    "преимущество": ["превосходство", "приоритет", "предпочтение", "перевес", "привилегия"],
    "преимуществовав": ["преимуществовавши"],
    "преимуществовавши": ["преимуществовав"],
    "преисподний": ["адский"],
    "преисподняя": ["ад", "геенна", "инферно", "пекло"],
    "преисполнив": ["преисполнивши"],
    "преисполнивши": ["преисполнив"],
    "преисполнить": ["наполнить"],
    "преисполняв": ["преисполнявши"],
    "преисполнявши": ["преисполняв"],
    "преистория": ["доисторический период", "доисторическое время"],
    "прейскурант": ["прайс-лист"],
    "прейти": ["перейти", "пройти", "минуть"],
    "прекардиальный": ["предсердечный"],
    "преклонение": ["склонение", "сгибание", "культ", "поклонение", "обожествление", "почитание"],
    "преклоненье": ["преклонение"],
    "преклонив": ["преклонивши"],
    "преклонивши": ["преклонив"],
    "преклонный": ["престарелый"],
    "преклоняв": ["преклонявши"],
    "преклонявши": ["преклоняв"],
    "преклонять": ["склонять"],
    "преклоняться": ["опускаться", "снимать шляпу"],
    "прекокс": ["ранний", "преждевременный"],
    "прекословив": ["прекословивши"],
    "прекословивши": ["прекословив"],
    "прекословить": ["возражать", "перечить"],
    "прекословный": ["несогласный", "противоречащий", "противоположный"],
    "прекословье": ["прекословие"],
    "прекраснейший": ["великолепнейший"],
    "прекрасний": ["гарний"],
    "прекрасно": ["превосходно", "отлично", "замечательно", "чудесно"],
    "прекраснодушествовав": ["прекраснодушествовавши"],
    "прекраснодушествовавши": ["прекраснодушествовав"],
    "прекраснодушничав": ["прекраснодушничавши"],
    "прекраснодушничавши": ["прекраснодушничав"],
    "прекрасный": ["восхитительный", "красивый", "превосходный", "отличный", "чудесный", "замечательный", "красота"],
    "прекрасный пол": ["нежный пол", "слабый пол"],
    "прекратив": ["прекративши"],
    "прекративши": ["прекратив"],
    "прекратить": ["закончить", "перестать", "кончить", "положить конец", "покончить"],
    "прекращав": ["прекращавши"],
    "прекращавши": ["прекращав"],
    "прекращать": ["заканчивать", "завершать", "кончать", "переставать"],
    "прекращаться": ["завершаться", "заканчиваться", "прерываться", "переставать"],
    "прекращаясь": ["заканчиваясь", "завершаясь", "оканчиваясь"],
    "прекращение": ["остановка", "окончание", "завершение"],
    "прекращенье": ["прекращение"],
    "прекурсор": ["предшественник"],
    "прекъсвач": ["ключ", "превключвател", "комутатор"],
    "прелабиум": ["прементум"],
    "прелагав": ["прелагавши"],
    "прелагавши": ["прелагав"],
    "прелагать": ["переводить", "перелагать", "превращать", "обращать", "изменять", "заменять"],
    "прелестница": ["обольстительница", "соблазнительница"],
    "прелестный": ["очаровательный", "чарующий", "обаятельный", "обворожительный", "пленительный"],
    "преливник": ["клоака", "отток"],
    "прелиминарный": ["вводный", "предварительный", "приуготовительный"],
    "прелка": ["портянка", "носок"],
    "преложив": ["преложивши"],
    "преложивши": ["преложив"],
    "преломив": ["преломивши"],
    "преломивши": ["преломив"],
    "преломление": ["рефракция"],
    "преломленье": ["преломление"],
    "преломляв": ["преломлявши"],
    "преломлявши": ["преломляв"],
    "прелъстител": ["съблазнител", "изкушител"],
    "прелый": ["истлевший", "сгнивший", "подопревший", "затхлый", "гнилой"],
    "прельстив": ["прельстивши"],
    "прельстивши": ["прельстив"],
    "прельщав": ["прельщавши"],
    "прельщавши": ["прельщав"],
    "прельщать": ["обольщать"],
    "прелюбодейка": ["любодеица"],
    "прелюбодейничав": ["прелюбодейничавши"],
    "прелюбодейничавши": ["прелюбодейничав"],
    "прелюбодейски": ["развратно"],
    "прелюбодейство": ["прелюбодеяние"],
    "прелюбодействовав": ["прелюбодействовавши"],
    "прелюбодействовавши": ["прелюбодействовав"],
    "прелюбодействовать": ["греховодничать", "изменять", "гулять", "развратничать", "беспутничать"],
    "прелюбодеяние": ["адюльтер"],
    "прелюбодеянье": ["прелюбодеяние", "прелюбодейство", "адюльтер"],
    "прелюд": ["прелюдия"],
    "прелюдировав": ["прелюдировавши"],
    "прелюдировавши": ["прелюдировав"],
    "прелюдия": ["прелюд"],
    "пременив": ["пременивши"],
    "пременивши": ["пременив"],
    "пременяв": ["пременявши"],
    "пременявши": ["пременяв"],
    "премиальный": ["люкс", "люксовый", "дорогой"],
    "преминув": ["преминувши"],
    "преминувши": ["преминув"],
    "преминуть": ["упустить", "упустить случай"],
    "премировав": ["премировавши"],
    "премировавши": ["премировав"],
    "премиум-бренд": ["премиум-марка"],
    "премиум-марка": ["премиум-бренд"],
    "премия": ["скидка"],
    "премного": ["очень", "весьма", "много"],
    "премодерация": ["премодерирование"],
    "премоляр": ["малый коренной зуб"],
    "премудрость": ["наука", "хитрость"],
    "премудрый": ["мудрый", "замысловатый"],
    "премьер": ["премьер-министр"],
    "премьер-министр": ["премьер"],
    "премьерив": ["премьеривши"],
    "премьеривши": ["премьерив"],
    "премьерствовав": ["премьерствовавши"],
    "премьерствовавши": ["премьерствовав"],
    "пренебрегав": ["пренебрегавши"],
    "пренебрегавши": ["пренебрегав"],
    "пренебрегать": ["гнушаться", "презирать"],
    "пренебрежение": ["небрежение", "пренебреженье", "презрение"],
    "пренебреженно": ["пренебрежительно", "презрительно"],
    "пренебреженье": ["пренебрежение"],
    "пренебрежимость": ["незначительность", "несущественность", "малозначительность"],
    "пренебрежимый": ["несущественный"],
    "пренебрежительно": ["высокомерно", "презрительно"],
    "пренепременно": ["всенепременно"],
    "пренос": ["превоз", "транспорт"],
    "преносвач": ["носач", "хамалин"],
    "преносив": ["преносивши"],
    "преносивши": ["преносив"],
    "пренье": ["прение"],
    "преобладав": ["преобладавши"],
    "преобладавши": ["преобладав"],
    "преобладание": ["доминирование", "господство", "превалирование", "примат"],
    "преобладанье": ["преобладание"],
    "преобладать": ["господствовать", "первенствовать", "превалировать"],
    "преоборав": ["преоборавши"],
    "преоборавши": ["преоборав"],
    "преоборов": ["преоборовши"],
    "преоборовши": ["преоборов"],
    "преображав": ["преображавши"],
    "преображавши": ["преображав"],
    "преображение": ["преображение господне", "яблочный спас"],
    "преображенье": ["преображение"],
    "преобразив": ["преобразивши"],
    "преобразивши": ["преобразив"],
    "преобразовав": ["преобразовавши"],
    "преобразовавши": ["преобразовав"],
    "преобразование": ["трансформация", "реформирование", "реформа"],
    "преобразованье": ["преобразование"],
    "преобразовывав": ["преобразовывавши"],
    "преобразовывавши": ["преобразовывав"],
    "преобратив": ["преобративши"],
    "преобративши": ["преобратив"],
    "преобращав": ["преобращавши"],
    "преобращавши": ["преобращав"],
    "преогромный": ["громадный", "огромный"],
    "преодолев": ["преодолевши"],
    "преодолевав": ["преодолевавши"],
    "преодолевавши": ["преодолевав"],
    "преодолевать": ["превозмогать", "проходить"],
    "преодолевши": ["преодолев"],
    "преодоление": ["превозмогание"],
    "преодоленье": ["преодоление"],
    "преотличный": ["отличный", "превосходный"],
    "препарат": ["лекарственное средство", "лекарство", "медикамент"],
    "препарация": ["препарирование"],
    "препарировав": ["препарировавши"],
    "препарировавши": ["препарировав"],
    "препинав": ["препинавши"],
    "препинавши": ["препинав"],
    "препинание": ["пунктуация"],
    "препинаться": ["запинаться", "препираться"],
    "препирание": ["препирательство", "пререкание"],
    "препирательство": ["препирание", "пререкание"],
    "препираться": ["пререкаться", "препинаться"],
    "препирня": ["спор", "прение", "диспут", "кавга", "караница"],
    "преписка": ["кореспонденция"],
    "препнув": ["препнувши"],
    "препнувши": ["препнув"],
    "препобедив": ["препобедивши"],
    "препобедивши": ["препобедив"],
    "препобеждав": ["препобеждавши"],
    "препобеждавши": ["препобеждав"],
    "препоганый": ["прегадкий", "прескверный"],
    "препод": ["учитель", "преподаватель", "педагог"],
    "преподав": ["преподавши"],
    "преподавав": ["преподававши"],
    "преподававши": ["преподавав"],
    "преподаванье": ["преподавание"],
    "преподавателка": ["учителка"],
    "преподаватель": ["учитель", "педагог", "препод"],
    "преподавательница": ["учительница"],
    "преподавательство": ["преподавание", "учительство"],
    "преподавательствовав": ["преподавательствовавши"],
    "преподавательствовавши": ["преподавательствовав"],
    "преподавать": ["давать уроки", "учить", "наставлять", "учительствовать"],
    "преподавши": ["преподав"],
    "преподло": ["гнусно", "гадко"],
    "преподносив": ["преподносивши"],
    "преподносивши": ["преподносив"],
    "преподобье": ["преподобие"],
    "преподша": ["учительница", "преподавательница", "училка"],
    "препожаловав": ["препожаловавши"],
    "препожаловавши": ["препожаловав"],
    "препона": ["препятствие", "помеха", "затруднение", "средостение"],
    "препоручав": ["препоручавши"],
    "препоручавши": ["препоручав"],
    "препоручив": ["препоручивши"],
    "препоручивши": ["препоручив"],
    "препотешно": ["уморительно"],
    "препочтенный": ["достопочтенный", "почтеннейший", "досточтимый", "уважаемый", "достоуважаемый", "многоуважаемый", "глубокоуважаемый", "достойный", "именитый", "признанный", "честной"],
    "препоясав": ["препоясавши"],
    "препоясавши": ["препоясав"],
    "препоясывав": ["препоясывавши"],
    "препоясывавши": ["препоясывав"],
    "преправка": ["преработка"],
    "препринт": ["предпубликация"],
    "препроводив": ["препроводивши"],
    "препроводивши": ["препроводив"],
    "препровождав": ["препровождавши"],
    "препровождавши": ["препровождав"],
    "препровожденье": ["препровождение"],
    "препротивный": ["гадкий", "мерзкий", "омерзительный", "отвратный", "отвратительный"],
    "препуций": ["крайняя плоть"],
    "препятствовав": ["препятствовавши"],
    "препятствовавши": ["препятствовав"],
    "препятствование": ["помеха", "противодействие"],
    "препятствовать": ["мешать", "препинать", "являться помехой", "тормозить", "саботировать"],
    "прервав": ["прервавши"],
    "прервавши": ["прервав"],
    "прерванный": ["прекращённый", "приостановленный", "остановленный", "перебитый"],
    "прервать": ["оборвать", "прекратить", "перебить", "остановить"],
    "прерваться": ["пресечься", "прекратиться", "оборваться"],
    "пререкаемый": ["спорный", "сомнительный"],
    "пререкание": ["препирательство", "препирание"],
    "пререканье": ["пререкание"],
    "пререкаться": ["спорить", "препираться", "перечить", "возражать"],
    "прерывав": ["прерывавши"],
    "прерывавши": ["прерывав"],
    "прерывание": ["остановка", "разрыв", "прекращение", "пресечение", "перебой", "выключение", "приостановка", "разрывание", "перебивание", "приостанавливание", "прерыванье"],
    "прерывать": ["обрывать", "перебивать"],
    "прерывающийся": ["прерывистый"],
    "прерывистый": ["прерывающийся", "прерывный"],
    "пресбиопия": ["дальнозоркость"],
    "пресвитерианец": ["пресвитерианин"],
    "пресекав": ["пресекавши"],
    "пресекавши": ["пресекав"],
    "пресекать": ["останавливать", "прекращать", "преграждать", "пересекать"],
    "преселник": ["изселник"],
    "преселять": ["переносить", "переселять"],
    "пресенильный": ["инволюционный", "предстарческий"],
    "пресеченье": ["пресечение"],
    "пресечь": ["остановить", "прекратить"],
    "пресиан": ["прусиан", "пресиян", "персиан"],
    "пресита": ["пресищане", "преситеност"],
    "пресиян": ["пресиан", "персиян"],
    "прескриптивность": ["нормативность"],
    "прескриптивный": ["предписывающий", "нормативный"],
    "прескёвю": ["на кончике языка"],
    "преследовав": ["преследовавши"],
    "преследовавши": ["преследовав"],
    "преследование": ["погоня", "гонение", "притеснение"],
    "преследованье": ["преследование"],
    "преследовать": ["травить", "притеснять", "угнетать", "надоедать", "досаждать", "докучать", "донимать"],
    "преследующий": ["гонящийся"],
    "пресловутый": ["знаменитый", "славный", "нашумевший"],
    "преслушание": ["преслушанье"],
    "пресмешной": ["презабавный"],
    "пресмыканье": ["пресмыкание"],
    "пресмыкаться": ["раболепствовать", "пролазничать"],
    "пресмыкающееся": ["рептилия", "гад"],
    "пресно": ["безвкусно", "бледно"],
    "пресс-брифинг": ["брифинг"],
    "пресс-волл": ["бренд-волл"],
    "пресс-камера": ["пресс-хата"],
    "пресс-конференция": ["прессуха"],
    "пресс-хата": ["пресс-камера"],
    "прессанув": ["прессанувши"],
    "прессанувши": ["прессанув"],
    "прессинг": ["нажим", "напор", "натиск", "давление"],
    "прессинговав": ["прессинговавши"],
    "прессинговавши": ["прессинговав"],
    "прессовав": ["прессовавши"],
    "прессовавши": ["прессовав"],
    "прессовать": ["давить", "давить на психику"],
    "прессотерапия": ["лимфодренаж"],
    "престав": ["преставши"],
    "преставав": ["престававши"],
    "престававши": ["преставав"],
    "преставиться": ["помереть", "скончаться", "кончиться", "сдохнуть", "окочуриться", "отдать богу душу", "почить", "протянуть ноги", "приказать долго жить", "сыграть в ящик", "щёлкнуть ластами", "хлопнуть дверью", "откинуть копыта", "принять ислам"],
    "преставленье": ["преставление"],
    "преставши": ["престав"],
    "престарелый": ["старый", "старик"],
    "престидижитатор": ["манипулятор"],
    "престиж": ["авторитет", "влиятельность", "реноме", "слава"],
    "престижно": ["модно"],
    "престижный": ["привлекательный", "влиятельный", "весомый", "родной", "авторитетный", "элитарный", "высокопрестижный", "элитный"],
    "престолонаследник": ["принц"],
    "престолонаследница": ["принцесса"],
    "престоница": ["главни град"],
    "престореност": ["неестественост", "изкуственост", "неискреност", "прикриване", "притворство"],
    "престрашный": ["страшенный", "страшнющий", "престрашенный", "сильнющий", "огроменный"],
    "преступав": ["преступавши"],
    "преступавши": ["преступав"],
    "преступив": ["преступивши"],
    "преступивши": ["преступив"],
    "преступить": ["переступить", "перейти", "нарушить"],
    "преступление": ["правонарушение", "злодеяние", "злодейство"],
    "преступно": ["подсудно"],
    "преступность": ["криминалитет", "криминал"],
    "преступный": ["криминальный", "уголовный", "подсудный", "незаконный", "противозаконный", "неправомерный", "противоправный", "недозволенный", "запрещённый", "нелегальный", "недопустимый", "непозволительный", "возмутительный", "греховный", "порочный"],
    "пресуппозиция": ["презумпция", "предположение", "импликация"],
    "пресуществив": ["пресуществивши"],
    "пресуществивши": ["пресуществив"],
    "пресуществляв": ["пресуществлявши"],
    "пресуществлявши": ["пресуществляв"],
    "пресытив": ["пресытивши"],
    "пресытивши": ["пресытив"],
    "пресыщав": ["пресыщавши"],
    "пресыщавши": ["пресыщав"],
    "пресыщение": ["переедание", "пресыщенность"],
    "претворив": ["претворивши"],
    "претворивши": ["претворив"],
    "претворить": ["превратить", "воплотить", "осуществить"],
    "претворяв": ["претворявши"],
    "претворявши": ["претворяв"],
    "претворять": ["превращать", "преобразовывать", "воплощать", "реализовывать"],
    "претворяться": ["превращаться"],
    "претекст": ["предлог", "повод"],
    "претендент": ["кандидат", "соискатель"],
    "претендовав": ["претендовавши"],
    "претендовавши": ["претендовав"],
    "претендовать": ["притязать", "рассчитывать"],
    "претендующий": ["добивающийся", "домогающийся", "конкурирующий", "притязающий"],
    "претензия": ["рекламация", "жалоба", "амбиция"],
    "претенциозно": ["вычурно", "напыщенно"],
    "претенциозный": ["вычурный", "манерный"],
    "претерпев": ["претерпевши"],
    "претерпевав": ["претерпевавши"],
    "претерпевавши": ["претерпевав"],
    "претерпевая": ["страдая"],
    "претерпевши": ["претерпев"],
    "претерпеть": ["перенести", "вытерпеть", "испытать", "подвергнуться"],
    "претив": ["претивши"],
    "претивши": ["претив"],
    "претить": ["запрещать", "отвращать", "отталкивать"],
    "преткновение": ["препятствие", "затруднение"],
    "преткновенье": ["преткновение"],
    "преткнуться": ["споткнуться", "запнуться"],
    "претыкаться": ["спотыкаться", "запинаться"],
    "преть": ["тухнуть"],
    "преувеличение": ["преувеличивание", "гиперболизация", "преувеличенье", "гипербола", "гротеск"],
    "преувеличенье": ["преувеличение", "преувеличивание", "гиперболизация"],
    "преувеличив": ["преувеличивши"],
    "преувеличивав": ["преувеличивавши"],
    "преувеличивавши": ["преувеличивав"],
    "преувеличивание": ["преувеличение", "преувеличенье", "гиперболизация"],
    "преувеличивать": ["гиперболизировать", "приукрасить", "раздуть", "передёргивать", "утрировать", "возводить в квадрат", "делать из мухи слона", "сгущать краски"],
    "преувеличивши": ["преувеличив"],
    "преувеличить": ["приукрасить", "раздуть", "передёргивать", "гиперболизировать", "утрировать", "возводить в квадрат", "делать из мухи слона", "сгущать краски"],
    "преумалив": ["преумаливши"],
    "преумаливши": ["преумалив"],
    "преумаляв": ["преумалявши"],
    "преумалявши": ["преумаляв"],
    "преуменьшав": ["преуменьшавши"],
    "преуменьшавши": ["преуменьшав"],
    "преуменьшение": ["преуменьшенье"],
    "преуменьшенье": ["преуменьшение"],
    "преуменьшив": ["преуменьшивши"],
    "преуменьшивши": ["преуменьшив"],
    "преуменьшить": ["недооценить"],
    "преумножав": ["преумножавши"],
    "преумножавши": ["преумножав"],
    "преумножив": ["преумноживши"],
    "преумноживши": ["преумножив"],
    "преуспев": ["преуспевши"],
    "преуспевав": ["преуспевавши"],
    "преуспевавши": ["преуспевав"],
    "преуспевание": ["преуспеяние", "благоденствие"],
    "преуспевать": ["благоденствовать", "процветать"],
    "преуспевающий": ["процветающий", "благоденствующий"],
    "преуспевши": ["преуспев"],
    "преуспеяние": ["преуспевание", "процветание", "благоденствие"],
    "преуспеянье": ["преуспеяние"],
    "префектурный": ["префектуральный"],
    "преферанс": ["пулька", "фавор", "преимущество", "перевес", "предпочтение"],
    "преференциальный": ["преимущественный", "льготный", "предпочтительный"],
    "префикс": ["приставка", "представка", "преверб", "конфикс", "циркумфикс", "амбификс"],
    "префиксально-постфиксальный": ["приставочно-постфиксальный"],
    "префиксально-суффиксально-постфиксальный": ["приставочно-суффиксально-постфиксальный"],
    "префиксально-суффиксальный": ["конфиксальный", "приставочно-суффиксальный"],
    "префиксальный": ["префиксный", "приставочный"],
    "преформация": ["преформизм"],
    "преформировав": ["преформировавши"],
    "преформировавши": ["преформировав"],
    "прехитрый": ["хитрый-прехитрый", "замысловатый", "мудрёный"],
    "преходив": ["преходивши"],
    "преходивши": ["преходив"],
    "преходить": ["переходить", "переправляться", "переступать", "миновать"],
    "преходящесть": ["преходящность"],
    "преходящий": ["переходящий", "проходящий", "минующий", "временный", "недолговечный"],
    "преходящность": ["преходящесть", "бренность", "эфемерность", "недолговечность", "тленность"],
    "прехрана": ["препитание", "издръжка"],
    "прецедент": ["пример", "случай"],
    "преценка": ["оценка", "мнение"],
    "прецессировав": ["прецессировавши"],
    "прецессировавши": ["прецессировав"],
    "прецизионно": ["точно", "высокоточно", "аккуратно"],
    "прецизионный": ["высокоточный"],
    "прецизировав": ["прецизировавши"],
    "прецизировавши": ["прецизировав"],
    "преципитировав": ["преципитировавши"],
    "преципитировавши": ["преципитировав"],
    "преципитированный": ["осаждённый"],
    "пречка": ["преграда", "препятствие", "бариера"],
    "преширокий": ["широченный"],
    "прещав": ["прещавши"],
    "прещавши": ["прещав"],
    "прещать": ["претить", "грозить", "стращать", "запрещать", "воспрещать"],
    "прещаться": ["претиться", "запрещаться", "воспрещаться"],
    "прещение": ["прещенье"],
    "прещенье": ["прещение"],
    "преэкзистенция": ["предсуществование"],
    "при": ["возле", "близ", "около", "близко к", "во время", "во времена"],
    "при всём том": ["при всём при том"],
    "при деньгах": ["обеспеченный", "в шоколаде"],
    "при закрытых дверях": ["за закрытыми дверями"],
    "при капусте": ["при деньгах"],
    "при параде": ["во всём параде"],
    "при помощи": ["с помощью"],
    "при смерти": ["на смертном одре", "одной ногой в могиле", "на краю гроба", "на последнем издыхании", "дни сочтены", "у смерти"],
    "при условии": ["если", "когда"],
    "при царе горохе": ["в незапамятные времена", "во время оно", "во времена оны", "когда царь горох с грибами воевал", "за царя панька"],
    "при этом": ["одновременно"],
    "приазиаченный": ["с азиатчинкой"],
    "приамурец": ["амурчанин", "приамурчанин"],
    "приамурский земский край": ["чёрный буфер"],
    "приамурье": ["амурская область"],
    "приарендовав": ["приарендовавши"],
    "приарендовавши": ["приарендовав"],
    "приарендовывав": ["приарендовывавши"],
    "приарендовывавши": ["приарендовывав"],
    "приарканив": ["приарканивши"],
    "приарканивав": ["приарканивавши"],
    "приарканивавши": ["приарканивав"],
    "приарканивши": ["приарканив"],
    "приаттачив": ["приаттачивши"],
    "приаттачивши": ["приаттачив"],
    "прибабахнув": ["прибабахнувши"],
    "прибабахнувши": ["прибабахнув"],
    "прибавив": ["прибавивши"],
    "прибавивши": ["прибавив"],
    "прибавить": ["добавить", "увеличить", "повысить", "подрасти", "приплюсовать"],
    "прибавление": ["прибавка"],
    "прибавленье": ["прибавление"],
    "прибавляв": ["прибавлявши"],
    "прибавлявши": ["прибавляв"],
    "прибавлять": ["добавлять"],
    "прибавочный": ["лишний", "добавочный"],
    "прибайкалье": ["предбайкалье"],
    "прибалдев": ["прибалдевши"],
    "прибалдевши": ["прибалдев"],
    "прибалдеть": ["опешить", "офигеть", "приторчать"],
    "прибаливав": ["прибаливавши"],
    "прибаливавши": ["прибаливав"],
    "прибалт": ["прибалтиец"],
    "прибалтика": ["балтия", "балтика", "проебалтика", "рейхскомиссариат остланд"],
    "прибалтывав": ["прибалтывавши"],
    "прибалтывавши": ["прибалтывав"],
    "прибамбас": ["шутка", "розыгрыш", "анекдот", "прикол", "примочка", "рюшечка", "фенечка", "прилада", "гаджет", "фишка", "мулька", "штучка"],
    "прибарахлиться": ["приодеться"],
    "прибаска": ["частуха", "сказуха", "стишок", "припевка", "припевочка", "пригудка", "коротелька", "коротушка", "собирушка", "вертушка", "страдания", "повертушка", "канавушка"],
    "прибаутничав": ["прибаутничавши"],
    "прибаутничавши": ["прибаутничав"],
    "прибауточник": ["прибаутник", "прибаутчик"],
    "прибаюкав": ["прибаюкавши"],
    "прибаюкавши": ["прибаюкав"],
    "прибаюкивав": ["прибаюкивавши"],
    "прибаюкивавши": ["прибаюкивав"],
    "прибегав": ["прибегавши"],
    "прибегавши": ["прибегав"],
    "прибегнув": ["прибегнувши"],
    "прибегнувши": ["прибегнув"],
    "прибегнуть": ["обращаться", "использовать", "пользоваться", "употреблять", "применять"],
    "прибедняться": ["скромничать"],
    "прибежав": ["прибежавши"],
    "прибежавши": ["прибежав"],
    "прибелив": ["прибеливши"],
    "прибеливши": ["прибелив"],
    "приберегав": ["приберегавши"],
    "приберегавши": ["приберегав"],
    "прибережный": ["прибрежный", "береговой"],
    "прибережье": ["прибрежье", "побережье"],
    "прибив": ["прибивши"],
    "прибивав": ["прибивавши"],
    "прибивавши": ["прибивав"],
    "прибивать": ["приколачивать", "подгонять", "прилаживать"],
    "прибивши": ["прибив"],
    "прибинтовав": ["прибинтовавши"],
    "прибинтовавши": ["прибинтовав"],
    "прибинтовывав": ["прибинтовывавши"],
    "прибинтовывавши": ["прибинтовывав"],
    "прибирав": ["прибиравши"],
    "прибиравши": ["прибирав"],
    "прибираться": ["убираться", "принаряжаться"],
    "прибить": ["приколотить", "пригнать"],
    "приближав": ["приближавши"],
    "приближавши": ["приближав"],
    "приближаться": ["подходить", "наступать"],
    "приближив": ["приближивши"],
    "приближивши": ["приближив"],
    "приближиться": ["приблизиться"],
    "приближённо": ["приблизительно"],
    "приблизив": ["приблизивши"],
    "приблизивши": ["приблизив"],
    "приблизительно": ["примерно", "неточно", "на глаз", "на глазок", "около", "порядка", "ориентировочно", "приближённо"],
    "приблизительность": ["неточность", "ориентировочность", "приближённость"],
    "приблизительный": ["примерный", "приближённый"],
    "приблуда": ["бродяга", "ублюдок"],
    "приблудив": ["приблудивши"],
    "приблудивши": ["приблудив"],
    "приблудка": ["приблуда"],
    "прибодрив": ["прибодривши"],
    "прибодривши": ["прибодрив"],
    "прибодряв": ["прибодрявши"],
    "прибодрявши": ["прибодряв"],
    "прибой": ["наплеск"],
    "приболев": ["приболевши"],
    "приболевши": ["приболев"],
    "приболеть": ["прихворнуть"],
    "приболтав": ["приболтавши"],
    "приболтавши": ["приболтав"],
    "приболтать": ["уболтать", "приплести", "присочинить", "подболтать"],
    "прибор": ["устройство", "приспособление", "аппарат", "механизм", "набор", "комплект", "член", "хрен", "болт"],
    "приборка": ["уборка"],
    "прибрав": ["прибравши"],
    "прибравши": ["прибрав"],
    "прибранив": ["прибранивши"],
    "прибранивав": ["прибранивавши"],
    "прибранивавши": ["прибранивав"],
    "прибранивши": ["прибранив"],
    "прибранить": ["выбранить", "отругать"],
    "прибрасывав": ["прибрасывавши"],
    "прибрасывавши": ["прибрасывав"],
    "прибрасывать": ["прикидывать"],
    "прибрать к рукам": ["прикарманить"],
    "прибредав": ["прибредавши"],
    "прибредавши": ["прибредав"],
    "прибрежный": ["прибережный", "береговой"],
    "прибрежный регион": ["прибрежная провинция"],
    "прибрехнув": ["прибрехнувши"],
    "прибрехнувши": ["прибрехнув"],
    "прибросав": ["прибросавши"],
    "прибросавши": ["прибросав"],
    "прибросив": ["прибросивши"],
    "прибросивши": ["прибросив"],
    "прибуксировав": ["прибуксировавши"],
    "прибуксировавши": ["прибуксировав"],
    "прибуксировать": ["доставить", "перетащить", "довезти", "затаскать"],
    "прибухнув": ["прибухнувши"],
    "прибухнувши": ["прибухнув"],
    "прибухнуть": ["подбухнуть"],
    "прибыв": ["приехав", "доехав"],
    "прибывав": ["прибывавши"],
    "прибывавши": ["прибывав"],
    "прибывать": ["являться", "приходить", "доставляться"],
    "прибывши": ["прибыв"],
    "прибылой": ["прибывший"],
    "прибыль": ["приток", "прибавление", "доход", "профит"],
    "прибыльный": ["доходный"],
    "прибыток": ["доход", "прибыль"],
    "прибыть": ["достигнуть", "добраться"],
    "прибытье": ["прибытие"],
    "привада": ["приманка"],
    "привадив": ["привадивши"],
    "привадивши": ["привадив"],
    "приваживав": ["приваживавши"],
    "приваживавши": ["приваживав"],
    "привалив": ["приваливши"],
    "приваливав": ["приваливавши"],
    "приваливавши": ["приваливав"],
    "приваливши": ["привалив"],
    "привалиться": ["прислониться", "навалиться", "прилечь", "привалить", "припереться", "подвалить"],
    "приварив": ["приваривши"],
    "приваривав": ["приваривавши"],
    "приваривавши": ["приваривав"],
    "приваривши": ["приварив"],
    "приварка": ["приваривание"],
    "приват-доцентура": ["приват-доцентство"],
    "приватизация": ["разгосударствление", "прихватизация"],
    "приватизировав": ["приватизировавши"],
    "приватизировавши": ["приватизировав"],
    "приватир": ["капер", "корсар"],
    "приведенье": ["приведение"],
    "привезя": ["привёзши"],
    "привезясь": ["привёзшись"],
    "привенчав": ["привенчавши"],
    "привенчавши": ["привенчав"],
    "привенчивав": ["привенчивавши"],
    "привенчивавши": ["привенчивав"],
    "привереда": ["привередник", "привередница"],
    "привередливо": ["взыскательно", "придирчиво", "разборчиво", "требовательно"],
    "привередливость": ["придирчивость", "прихотливость", "разборчивость", "требовательность"],
    "привередливый": ["взыскательный", "капризный", "придирчивый", "разборчивый", "требовательный"],
    "привередник": ["привереда"],
    "привередничав": ["привередничавши"],
    "привередничавши": ["привередничав"],
    "привередничать": ["с жиру беситься", "капризничать"],
    "приверженец": ["сторонник", "поборник", "последователь", "адепт", "поклонник"],
    "приверженность": ["приязнь", "привязанность", "пристрастие", "преданность", "верность"],
    "приверженный": ["привязанный", "преданный", "верный"],
    "привернув": ["привернувши"],
    "привернувши": ["привернув"],
    "приверстав": ["приверставши"],
    "приверставши": ["приверстав"],
    "привертев": ["привертевши"],
    "привертевши": ["привертев"],
    "приверчивав": ["приверчивавши"],
    "приверчивавши": ["приверчивав"],
    "привесив": ["привесивши"],
    "привесивши": ["привесив"],
    "привет": ["приветствие"],
    "приветив": ["приветивши"],
    "приветивши": ["приветив"],
    "приветить": ["приютить", "приветствовать"],
    "приветливо": ["радушно", "благожелательно"],
    "приветливость": ["благожелательность", "дружелюбность", "любезность", "радушие"],
    "приветливый": ["радушный"],
    "приветно": ["ласково"],
    "приветствовав": ["приветствовавши"],
    "приветствовавши": ["приветствовав"],
    "приветствовать": ["здороваться", "привечать", "одобрять", "одобрить", "поддерживать", "поддержать", "салютовать", "отдавать честь"],
    "привечав": ["привечавши"],
    "привечавши": ["привечав"],
    "привешивав": ["привешивавши"],
    "привешивавши": ["привешивав"],
    "привздёрнув": ["привздёрнувши"],
    "привздёрнувши": ["привздёрнув"],
    "привив": ["прививши"],
    "прививав": ["прививавши"],
    "прививавши": ["прививав"],
    "прививание": ["прививка", "привитие"],
    "прививать": ["приспосабливать", "акклиматизировать", "вакцинировать"],
    "прививка": ["вакцинация", "вакцина"],
    "прививши": ["привив"],
    "привид": ["потороча"],
    "привидение": ["призрак", "фантом", "дух"],
    "привидывав": ["привидывавши"],
    "привидывавши": ["привидывав"],
    "привизгивав": ["привизгивавши"],
    "привизгивавши": ["привизгивав"],
    "привизгнув": ["привизгнувши"],
    "привизгнувши": ["привизгнув"],
    "привилегированность": ["привилегия", "преимущество"],
    "привилегия": ["приоритет"],
    "привинтив": ["привинтивши"],
    "привинтивши": ["привинтив"],
    "привинчивав": ["привинчивавши"],
    "привинчивавши": ["привинчивав"],
    "привирав": ["привиравши"],
    "привиравши": ["привирав"],
    "привирать": ["присочинять"],
    "привитав": ["привитавши"],
    "привитавши": ["привитав"],
    "привитие": ["прививание", "прививка", "насаждение", "укоренение"],
    "привлекав": ["привлекавши"],
    "привлекавши": ["привлекав"],
    "привлекательность": ["заманчивость", "приятность", "соблазнительность"],
    "привлекательный": ["приятный", "пленительный", "обольстительный", "соблазнительный", "заманчивый", "увлекательный"],
    "привлеченье": ["привлечение"],
    "привлечь": ["притянуть", "приманить", "мобилизовать", "заинтересовать"],
    "привлечённый": ["притянутый"],
    "привлёкши": ["привлеча", "привлекя"],
    "привносив": ["привносивши"],
    "привносивши": ["привносив"],
    "привносить": ["добавлять"],
    "привод": ["механизм", "передача", "дисковод"],
    "приводив": ["приводивши"],
    "приводивши": ["приводив"],
    "приводненье": ["приводнение"],
    "приводнив": ["приводнивши"],
    "приводнивши": ["приводнив"],
    "приводняв": ["приводнявши"],
    "приводнявши": ["приводняв"],
    "привоз": ["развал"],
    "привозив": ["привозивши"],
    "привозивши": ["привозив"],
    "привозной": ["привозный", "ввозимый", "ввозной"],
    "приволакивав": ["приволакивавши"],
    "приволакивавши": ["приволакивав"],
    "приволочив": ["приволочивши"],
    "приволочивши": ["приволочив"],
    "приволье": ["простор", "даль", "ширь", "раздолье"],
    "привольно": ["вольно"],
    "привольный": ["раздольный", "вольный"],
    "привораживав": ["привораживавши"],
    "привораживавши": ["привораживав"],
    "приворачивав": ["приворачивавши"],
    "приворачивавши": ["приворачивав"],
    "приворовывав": ["приворовывавши"],
    "приворовывавши": ["приворовывав"],
    "приворожив": ["привороживши"],
    "привороживши": ["приворожив"],
    "приворот": ["чары"],
    "приворотив": ["приворотивши"],
    "приворотивши": ["приворотив"],
    "приворотничав": ["приворотничавши"],
    "приворотничавши": ["приворотничав"],
    "приврав": ["привравши"],
    "привравши": ["приврав"],
    "привратник": ["портье", "швейцар"],
    "привскакивав": ["привскакивавши"],
    "привскакивавши": ["привскакивав"],
    "привскакнув": ["привскакнувши"],
    "привскакнувши": ["привскакнув"],
    "привскочив": ["привскочивши"],
    "привскочивши": ["привскочив"],
    "привсплыв": ["привсплывши"],
    "привсплывав": ["привсплывавши"],
    "привсплывавши": ["привсплывав"],
    "привсплывши": ["привсплыв"],
    "привстав": ["привставши"],
    "привставав": ["привстававши"],
    "привстававши": ["привставав"],
    "привставши": ["привстав"],
    "привстать": ["приподняться", "приостановиться", "замедлить", "бег"],
    "привсхлипывав": ["привсхлипывавши"],
    "привсхлипывавши": ["привсхлипывав"],
    "привходив": ["привходивши"],
    "привходивши": ["привходив"],
    "привързаност": ["вярност", "преданост"],
    "привывав": ["привывавши"],
    "привывавши": ["привывав"],
    "привыкав": ["привыкавши"],
    "привыкавши": ["привыкав"],
    "привыканье": ["привыкание"],
    "привыкать": ["приобретать привычку", "обыкать", "приспосабливаться", "приноравливаться"],
    "привыкнув": ["привыкнувши"],
    "привыкнувши": ["привыкнув"],
    "привыкнуть": ["приучиться", "втянуться", "приохотиться", "пристраститься", "повадиться", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться"],
    "привыкший": ["адаптировавшийся"],
    "привычка": ["повадка", "приученность"],
    "привычный": ["обычный", "привыкший"],
    "привьючив": ["привьючивши"],
    "привьючивав": ["привьючивавши"],
    "привьючивавши": ["привьючивав"],
    "привьючивши": ["привьючив"],
    "привядав": ["привядавши"],
    "привядавши": ["привядав"],
    "привязав": ["привязавши"],
    "привязавши": ["привязав"],
    "привязаться": ["полюбить", "прикипеть", "прилепиться", "возлюбить", "придраться", "пристать"],
    "привязывав": ["привязывавши"],
    "привязывавши": ["привязывав"],
    "привялив": ["привяливши"],
    "привяливав": ["привяливавши"],
    "привяливавши": ["привяливав"],
    "привяливши": ["привялив"],
    "привянув": ["привянувши"],
    "привянувши": ["привянув"],
    "привёзши": ["привезя"],
    "привёзшись": ["привезясь"],
    "привёрстывав": ["привёрстывавши"],
    "привёрстывавши": ["привёрстывав"],
    "привёртывав": ["привёртывавши"],
    "привёртывавши": ["привёртывав"],
    "привёртывать": ["прикручивать"],
    "пригадав": ["пригадавши"],
    "пригадавши": ["пригадав"],
    "пригадывав": ["пригадывавши"],
    "пригадывавши": ["пригадывав"],
    "пригаркивав": ["пригаркивавши"],
    "пригаркивавши": ["пригаркивав"],
    "пригаркнув": ["пригаркнувши"],
    "пригаркнувши": ["пригаркнув"],
    "пригарчивав": ["пригарчивавши"],
    "пригарчивавши": ["пригарчивав"],
    "пригасав": ["пригасавши"],
    "пригасавши": ["пригасав"],
    "пригасив": ["пригасивши"],
    "пригасивши": ["пригасив"],
    "пригашав": ["пригашавши"],
    "пригашавши": ["пригашав"],
    "пригашивав": ["пригашивавши"],
    "пригашивавши": ["пригашивав"],
    "пригвождав": ["пригвождавши"],
    "пригвождавши": ["пригвождав"],
    "пригвоздив": ["пригвоздивши"],
    "пригвоздивши": ["пригвоздив"],
    "пригибав": ["пригибавши"],
    "пригибавши": ["пригибав"],
    "пригибающийся": ["нагибающийся", "наклоняющийся"],
    "пригладив": ["пригладивши"],
    "пригладивши": ["пригладив"],
    "приглаживав": ["приглаживавши"],
    "приглаживавши": ["приглаживав"],
    "пригласив": ["пригласивши"],
    "пригласивши": ["пригласив"],
    "приглашав": ["приглашавши"],
    "приглашавши": ["приглашав"],
    "приглашать": ["зазывать", "звать", "призывать", "нанимать", "привлекать"],
    "приглашающе": ["зовуще"],
    "приглашенье": ["приглашение"],
    "приглос": ["инвайт"],
    "приглохнув": ["приглохнувши"],
    "приглохнувши": ["приглохнув"],
    "приглубив": ["приглубивши"],
    "приглубивши": ["приглубив"],
    "приглубляв": ["приглублявши"],
    "приглублявши": ["приглубляв"],
    "приглушав": ["приглушавши"],
    "приглушавши": ["приглушав"],
    "приглушив": ["приглушивши"],
    "приглушивши": ["приглушив"],
    "приглушённо": ["тихо"],
    "приглушённый": ["глуховатый", "сдавленный", "тусклый"],
    "приглядев": ["приглядевши"],
    "приглядевши": ["приглядев"],
    "приглядеть": ["присмотреть", "подыскать", "наметить"],
    "приглядеться": ["присмотреться"],
    "приглядывав": ["приглядывавши"],
    "приглядывавши": ["приглядывав"],
    "приглядывать": ["присматривать"],
    "приглядываться": ["присматриваться", "вглядываться"],
    "приглянув": ["приглянувши"],
    "приглянувши": ["приглянув"],
    "пригнав": ["пригнавши"],
    "пригнавши": ["пригнав"],
    "пригнетав": ["пригнетавши"],
    "пригнетавши": ["пригнетав"],
    "пригнув": ["пригнувши"],
    "пригнувши": ["пригнув"],
    "приговаривав": ["приговаривавши"],
    "приговаривавши": ["приговаривав"],
    "приговор": ["вердикт", "осуждение", "присловье"],
    "приговорив": ["приговоривши"],
    "приговоривши": ["приговорив"],
    "приговорить": ["постановить", "присудить"],
    "приговорка": ["побасенка", "байка", "присловие", "присловка", "присказка", "причет", "приговорочка"],
    "пригодный": ["годный", "подходящий", "применимый"],
    "пригожев": ["пригожевши"],
    "пригожевши": ["пригожев"],
    "пригожий": ["красивый", "привлекательный", "ясный", "солнечный"],
    "приголубив": ["приголубивши"],
    "приголубивши": ["приголубив"],
    "приголубить": ["приласкать"],
    "приголубливав": ["приголубливавши"],
    "приголубливавши": ["приголубливав"],
    "пригон": ["пригонка"],
    "пригоняв": ["пригонявши"],
    "пригонявши": ["пригоняв"],
    "пригонять": ["доставлять", "прилаживать", "подгонять"],
    "пригорав": ["пригоравши"],
    "пригоравши": ["пригорав"],
    "пригораживав": ["пригораживавши"],
    "пригораживавши": ["пригораживав"],
    "пригорбив": ["пригорбивши"],
    "пригорбивши": ["пригорбив"],
    "пригорев": ["пригоревши"],
    "пригоревши": ["пригорев"],
    "пригорелый": ["подгорелый"],
    "пригорнув": ["пригорнувши"],
    "пригорнувши": ["пригорнув"],
    "пригород": ["загород"],
    "пригородив": ["пригородивши"],
    "пригородивши": ["пригородив"],
    "пригорок": ["бугорок", "холмик", "горка"],
    "пригортати": ["прикидати", "присипати"],
    "пригоршня": ["горсть", "жменя"],
    "пригорюниться": ["загрустить", "приуныть", "опечалиться"],
    "приготавливав": ["приготавливавши"],
    "приготавливавши": ["приготавливав"],
    "приготавливать": ["приготовлять", "готовить"],
    "приготовив": ["приготовивши"],
    "приготовивши": ["приготовив"],
    "приготовительный": ["подготовительный", "предуготовительный"],
    "приготовить": ["состряпать"],
    "приготовление": ["приготавливание", "подготовка"],
    "приготовленье": ["приготовление"],
    "приготовлины": ["припас"],
    "приготовляв": ["приготовлявши"],
    "приготовлявши": ["приготовляв"],
    "приготовлять": ["готовить", "заготавливать", "заготовлять", "изготовлять"],
    "приготовляться": ["приготавливаться"],
    "приграничный": ["пограничный"],
    "пригребав": ["пригребавши"],
    "пригребавши": ["пригребав"],
    "пригревав": ["пригревавши"],
    "пригревавши": ["пригревав"],
    "пригревши": ["пригрев"],
    "пригрозив": ["пригрозивши"],
    "пригрозивши": ["пригрозив"],
    "пригрохотав": ["пригрохотавши"],
    "пригрохотавши": ["пригрохотав"],
    "пригружав": ["пригружавши"],
    "пригружавши": ["пригружав"],
    "пригрузив": ["пригрузивши"],
    "пригрузивши": ["пригрузив"],
    "пригрустив": ["пригрустивши"],
    "пригрустивши": ["пригрустив"],
    "пригрустнув": ["пригрустнувши"],
    "пригрустнувши": ["пригрустнув"],
    "пригубив": ["пригубивши"],
    "пригубивши": ["пригубив"],
    "пригубливав": ["пригубливавши"],
    "пригубливавши": ["пригубливав"],
    "пригубляв": ["пригублявши"],
    "пригублявши": ["пригубляв"],
    "пригудка": ["байка", "прибаска", "частушка"],
    "пригуливав": ["пригуливавши"],
    "пригуливавши": ["пригуливав"],
    "пригуляв": ["пригулявши"],
    "пригулявши": ["пригуляв"],
    "придав": ["придавши"],
    "придавав": ["придававши"],
    "придававши": ["придавав"],
    "придавать": ["прибавлять", "додавать", "давать", "сообщать", "усиливать", "приписывать"],
    "придавив": ["придавивши"],
    "придавивши": ["придавив"],
    "придавливав": ["придавливавши"],
    "придавливавши": ["придавливав"],
    "придавши": ["придав"],
    "придакивав": ["придакивавши"],
    "придакивавши": ["придакивав"],
    "придакнув": ["придакнувши"],
    "придакнувши": ["придакнув"],
    "придалбываться": ["доёбываться"],
    "приданье": ["придание"],
    "придверник": ["привратник"],
    "придвигав": ["придвигавши"],
    "придвигавши": ["придвигав"],
    "придвигать": ["приближать"],
    "придвигаться": ["пододвигаться", "приближаться", "надвигаться"],
    "придвинув": ["придвинувши"],
    "придвинувши": ["придвинув"],
    "приделав": ["приделавши"],
    "приделавши": ["приделав"],
    "приделывав": ["приделывавши"],
    "приделывавши": ["приделывав"],
    "приделывание": ["прикрепление", "присоединение"],
    "приделывать": ["прикреплять"],
    "придержав": ["придержавши"],
    "придержавши": ["придержав"],
    "придерживав": ["придерживавши"],
    "придерживавши": ["придерживав"],
    "придирка": ["подколка"],
    "приднепровский": ["поднепровский"],
    "приднепровье": ["поднепровье"],
    "приднестровская молдавская республика": ["приднестровье", "пмр"],
    "придобивка": ["облага", "полза", "печалба"],
    "придолбаться": ["приебаться", "доебаться"],
    "придохнув": ["придохнувши"],
    "придохнувши": ["придохнув"],
    "придрав": ["придравши"],
    "придравши": ["придрав"],
    "придрейфовав": ["придрейфовавши"],
    "придрейфовавши": ["придрейфовав"],
    "придремав": ["придремавши"],
    "придремавши": ["придремав"],
    "придремать": ["задремать"],
    "придремнув": ["придремнувши"],
    "придремнувши": ["придремнув"],
    "придрочиться": ["приспособиться", "приноровиться"],
    "придружив": ["придруживши"],
    "придруживши": ["придружив"],
    "придрёмывав": ["придрёмывавши"],
    "придрёмывавши": ["придрёмывав"],
    "придрёмывать": ["задрёмывать"],
    "придти": ["прийти"],
    "придув": ["придувши"],
    "придував": ["придувавши"],
    "придувавши": ["придував"],
    "придувши": ["придув"],
    "придумав": ["придумавши"],
    "придумавши": ["придумав"],
    "придумать": ["изобрести", "сообразить", "решить", "сочинить", "выдумать", "измыслить", "вообразить"],
    "придумывав": ["придумывавши"],
    "придумывавши": ["придумывав"],
    "придумыванье": ["придумывание"],
    "придуривав": ["придуривавши"],
    "придуривавши": ["придуривав"],
    "придурковатый": ["придурочный"],
    "придурок": ["болван стоеросовый", "осёл на двух копытах", "пень березовый", "пень с глазами", "чурка с глазами", "долбоёб", "дуроёб"],
    "придурочный": ["придурковатый", "бестолковый", "глупый"],
    "придушив": ["придушивши"],
    "придушивши": ["придушив"],
    "придых": ["придыхание", "придыханье"],
    "придыхав": ["придыхавши"],
    "придыхавши": ["придыхав"],
    "придыхание": ["придых", "придыханье", "аспирация"],
    "придыханье": ["придыхание", "придых"],
    "придя": ["пришедши", "пришед"],
    "придёргивав": ["придёргивавши"],
    "придёргивавши": ["придёргивав"],
    "придёрнув": ["придёрнувши"],
    "придёрнувши": ["придёрнув"],
    "придётся солоно": ["несладко"],
    "приебаться": ["прицепиться", "докопаться", "доколупаться"],
    "приедав": ["приедавши"],
    "приедавши": ["приедав"],
    "приездив": ["приездивши"],
    "приездивши": ["приездив"],
    "приезжав": ["приезжавши"],
    "приезжавши": ["приезжав"],
    "приемлемо": ["годно", "уместно"],
    "приемлемый": ["годный", "уместный"],
    "приесться": ["надоесть", "осточертеть", "наскучить", "опостылеть"],
    "приехавши": ["приехав"],
    "приехавший": ["прибывший"],
    "приехать": ["приплыли", "пизда рулю"],
    "прижав": ["прижавши"],
    "прижавши": ["прижав"],
    "прижарив": ["прижаривши"],
    "прижаривав": ["прижаривавши"],
    "прижаривавши": ["прижаривав"],
    "прижаривши": ["прижарив"],
    "прижать": ["прищучить"],
    "прижать жопу": ["жопу прижать"],
    "приждав": ["приждавши"],
    "приждавши": ["приждав"],
    "прижив": ["приживши"],
    "приживав": ["приживавши"],
    "приживавши": ["приживав"],
    "приживала": ["приживальщик", "приживальщица", "приживалка"],
    "приживалка": ["приживальщица"],
    "приживальщик": ["приживал", "приживала", "дармоед", "прихлебатель", "чужеспинник"],
    "приживаться": ["осваиваться", "приспосабливаться", "акклиматизироваться", "вживляться", "имплантироваться"],
    "приживив": ["прижививши"],
    "прижививши": ["приживив"],
    "приживляв": ["приживлявши"],
    "приживлявши": ["приживляв"],
    "приживши": ["прижив"],
    "прижившийся": ["приживившийся"],
    "прижиг": ["прижигание"],
    "прижигав": ["прижигавши"],
    "прижигавши": ["прижигав"],
    "прижигание": ["прижжение", "прижиг", "прижег", "прижига", "прижиганье", "прижженье", "каутеризация"],
    "прижиганье": ["прижигание"],
    "прижим": ["прижимание", "прижатие", "фиксатор", "притеснение"],
    "прижимав": ["прижимавши"],
    "прижимавши": ["прижимав"],
    "прижимать": ["придавливать", "притискивать"],
    "прижимистость": ["скупость", "скупердяйство"],
    "прижимистый": ["скупой", "скаредный"],
    "прижиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "освоиться"],
    "прижмурив": ["прижмуривши"],
    "прижмуривав": ["прижмуривавши"],
    "прижмуривавши": ["прижмуривав"],
    "прижмуривши": ["прижмурив"],
    "прижопив": ["прижопивши"],
    "прижопивши": ["прижопив"],
    "прижукнув": ["прижукнувши"],
    "прижукнувши": ["прижукнув"],
    "прижукнуться": ["притихнуть", "примолкнуть", "присмиреть"],
    "прижухнув": ["прижухнувши"],
    "прижухнувши": ["прижухнув"],
    "прижучив": ["прижучивши"],
    "прижучивши": ["прижучив"],
    "прижучить": ["прищучить", "наказать", "спросить", "взыскать", "притеснить", "приневолить"],
    "призабыв": ["призабывши"],
    "призабывав": ["призабывавши"],
    "призабывавши": ["призабывав"],
    "призабывши": ["призабыв"],
    "призавянув": ["призавянувши"],
    "призавянувши": ["призавянув"],
    "призадержав": ["призадержавши"],
    "призадержавши": ["призадержав"],
    "призадумываться": ["задумываться"],
    "призакрыв": ["призакрывши"],
    "призакрывши": ["призакрыв"],
    "призамолкнув": ["призамолкнувши"],
    "призамолкнувши": ["призамолкнув"],
    "призанимав": ["призанимавши"],
    "призанимавши": ["призанимав"],
    "призаняв": ["призанявши"],
    "призанявши": ["призаняв"],
    "призасохнув": ["призасохнувши"],
    "призасохнувши": ["призасохнув"],
    "призатихнув": ["призатихнувши"],
    "призатихнувши": ["призатихнув"],
    "призбирання": ["збирання", "призбирування"],
    "призвав": ["призвавши"],
    "призвавши": ["призвав"],
    "призвание": ["призыв", "склонность", "способность", "предрасположенность", "назначение", "предназначение", "миссия", "приглашение"],
    "призванье": ["призвание"],
    "призвук": ["обертон", "оттенок"],
    "приземистый": ["коренастый"],
    "приземление": ["посадка"],
    "приземленье": ["приземление"],
    "приземлив": ["приземливши"],
    "приземливши": ["приземлив"],
    "приземлиться": ["сесть", "опуститься"],
    "приземляв": ["приземлявши"],
    "приземлявши": ["приземляв"],
    "приземляться": ["садиться"],
    "приземлённый": ["обыденный", "прозаический", "мещанский", "повседневный"],
    "призирав": ["призиравши"],
    "призиравши": ["призирав"],
    "призирать": ["призревать"],
    "призматоид": ["призмоид"],
    "призмоид": ["призматоид"],
    "призмоидальный": ["призмообразный"],
    "признав": ["признавши"],
    "признавав": ["признававши"],
    "признававши": ["признавав"],
    "признавши": ["признав"],
    "признак": ["атрибут", "знак"],
    "признака": ["ознака"],
    "признанье": ["признание"],
    "признательность": ["благодарность"],
    "признательный": ["благодарный"],
    "призрак": ["мираж", "привидение", "фантом"],
    "призрак пера": ["литературный призрак", "литературный негр"],
    "призрачность": ["иллюзорность", "ирреальность", "обманчивость", "химеричность", "эфемерность", "мнимость", "ложность", "неясность"],
    "призрев": ["призревши"],
    "призревав": ["призревавши"],
    "призревавши": ["призревав"],
    "призревши": ["призрев"],
    "призрение": ["забота", "попечение", "опека", "присмотр"],
    "призренный": ["облагодетельствованный", "препорученный", "пригретый"],
    "призренье": ["призрение"],
    "призреть": ["взглянуть", "воззреть", "приглядеть", "присмотреть", "приветить", "приютить"],
    "призрив": ["призривши"],
    "призривши": ["призрив"],
    "призыв": ["клич", "зов"],
    "призывав": ["призывавши"],
    "призывавши": ["призывав"],
    "призыванье": ["призывание"],
    "призыватель": ["призватель"],
    "призывать": ["приглашать", "зазывать", "взывать", "увещевать", "побуждать"],
    "призёр": ["победитель", "чемпион", "медалист"],
    "призёрка": ["победительница", "чемпионка", "медалистка"],
    "призёрша": ["победительница", "чемпионка", "медалистка", "призёрка"],
    "приимав": ["приимавши"],
    "приимавши": ["приимав"],
    "приимать": ["принимать"],
    "приискав": ["приискавши"],
    "приискавши": ["приискав"],
    "приискивав": ["приискивавши"],
    "приискивавши": ["приискивав"],
    "приискивание": ["приискиванье"],
    "приискиванье": ["поиск", "приискивание"],
    "приискивать": ["подыскивать"],
    "прийдясь": ["придясь"],
    "приймак": ["примак"],
    "приймальна": ["приймальня"],
    "приймальня": ["приймальна"],
    "прийняти": ["приймати", "узяти"],
    "прийти": ["прибыть", "наступить", "настать"],
    "прийти в бешенство": ["разозлиться", "рассвирепеть"],
    "прийти в себя": ["очнуться", "опомниться"],
    "прийти на смену": ["заменить"],
    "прийтись": ["угодно"],
    "приказ": ["приказание", "команда", "распоряжение", "повеление"],
    "приказ общественного призрения": ["вдовий дом", "богадельня"],
    "приказав": ["приказавши"],
    "приказавши": ["приказав"],
    "приказание": ["приказ", "распоряжение", "наказ"],
    "приказать": ["велеть", "отдать распоряжение", "распорядиться"],
    "приказливост": ["словоохотливост", "бъбривост", "разговорливост"],
    "приказная": ["приказная изба"],
    "приказная изба": ["приказная"],
    "приказная строка": ["канцелярская крыса", "крапивное семя", "крючкотвор", "казуист"],
    "приказной": ["командный", "строгий"],
    "приказный": ["чиновник", "клерк", "служащий"],
    "приказчик": ["прикащик"],
    "приказчикъ": ["прикащикъ"],
    "приказывав": ["приказывавши"],
    "приказывавши": ["приказывав"],
    "приказывать": ["распоряжаться", "командовать", "велеть", "поручать"],
    "прикалывав": ["прикалывавши"],
    "прикалывавши": ["прикалывав"],
    "прикалываться": ["шутить", "подшучивать", "забавляться", "веселиться", "развлекаться", "потешаться", "шалить", "озорничать"],
    "приканчивав": ["приканчивавши"],
    "приканчивавши": ["приканчивав"],
    "приканчивать": ["убивать", "умерщвлять", "добивать"],
    "прикапливав": ["прикапливавши"],
    "прикапливавши": ["прикапливав"],
    "прикапливать": ["приберегать", "припасать", "припрятывать"],
    "прикапывав": ["прикапывавши"],
    "прикапывавши": ["прикапывав"],
    "прикапываться": ["приставать", "придираться", "прицепляться"],
    "прикарманивав": ["прикарманивавши"],
    "прикарманивавши": ["прикарманивав"],
    "прикарманивши": ["прикарманив"],
    "прикарманить": ["присвоить"],
    "прикармливав": ["прикармливавши"],
    "прикармливавши": ["прикармливав"],
    "прикасание": ["касание", "прикосновение"],
    "прикасанье": ["прикасание"],
    "прикасательный": ["прикладной"],
    "прикасаться": ["дотрагиваться", "касаться", "трогать"],
    "прикатав": ["прикатавши"],
    "прикатавши": ["прикатав"],
    "прикатив": ["прикативши"],
    "прикативши": ["прикатив"],
    "прикатывав": ["прикатывавши"],
    "прикатывавши": ["прикатывав"],
    "прикачав": ["прикачавши"],
    "прикачавши": ["прикачав"],
    "прикачивав": ["прикачивавши"],
    "прикачивавши": ["прикачивав"],
    "прикачнув": ["прикачнувши"],
    "прикачнувши": ["прикачнув"],
    "прикашлянув": ["прикашлянувши"],
    "прикашлянувши": ["прикашлянув"],
    "прикащик": ["приказчик"],
    "прикащикъ": ["приказчикъ"],
    "прикемарив": ["прикемаривши"],
    "прикемаривши": ["прикемарив"],
    "прикемарить": ["задремать", "поспать", "соснуть"],
    "прикеттлевав": ["прикеттлевавши"],
    "прикеттлевавши": ["прикеттлевав"],
    "прикид": ["вид"],
    "прикидав": ["прикидавши"],
    "прикидавши": ["прикидав"],
    "прикидывав": ["прикидывавши"],
    "прикидывавши": ["прикидывав"],
    "прикидывание": ["примерный", "расчёт", "примерное", "рассчитывание", "притворство", "игра", "лицемерие"],
    "прикидывать": ["прибрасывать", "докидывать", "накидывать"],
    "прикидываться": ["притворяться", "симулировать"],
    "прикидывающийся": ["притворяющийся", "симулирующий"],
    "прикинув": ["прикинувши"],
    "прикинувши": ["прикинув"],
    "прикинуть": ["прибросить", "добавить", "надбавить", "посчитать", "оценить"],
    "прикинуться ветошью": ["прикинуться шлангом", "прикинуться пиджаком", "прикинуться вельветовым пиджаком", "прикинуться декорацией", "прикинуться урной", "прикинуться фонарным столбом", "прикинуться памятником", "прикинуться фантиком", "прикинуться чучелом ульянова", "слинять", "свинтить", "свинтиться"],
    "прикинуться шлангом": ["шлангом прикинуться", "включить дурака", "включить дуру", "включить дурку", "включить дурочку", "включить идиота", "гнать дуру", "гнать дурку", "гнать дурочку"],
    "прикинь": ["подумать", "представить", "вообразить"],
    "прикипав": ["прикипавши"],
    "прикипавши": ["прикипав"],
    "прикипев": ["прикипевши"],
    "прикипевши": ["прикипев"],
    "прикипеть": ["пригореть", "привариться", "прирасти", "привязаться"],
    "прикладной": ["практический"],
    "прикладывав": ["прикладывавши"],
    "прикладывавши": ["прикладывав"],
    "приклеив": ["приклеивши"],
    "приклеивав": ["приклеивавши"],
    "приклеивавши": ["приклеивав"],
    "приклеивать": ["наклеивать", "на"],
    "приклеиваться": ["наклеиваться", "прилепляться"],
    "приклеивши": ["приклеив"],
    "приклеить": ["наклеить", "на"],
    "приклепав": ["приклепавши"],
    "приклепавши": ["приклепав"],
    "прикликав": ["прикликавши"],
    "прикликавши": ["прикликав"],
    "приклонив": ["приклонивши"],
    "приклонивши": ["приклонив"],
    "приклоняв": ["приклонявши"],
    "приклонявши": ["приклоняв"],
    "приключав": ["приключавши"],
    "приключавши": ["приключав"],
    "приключаться": ["происходить", "случаться"],
    "приключенец": ["авантюрист"],
    "приключение": ["происшествие", "случай"],
    "приключенческий": ["авантюрный"],
    "приключенье": ["приключение"],
    "приключив": ["приключивши"],
    "приключивши": ["приключив"],
    "приключиться": ["случиться"],
    "приклёпывав": ["приклёпывавши"],
    "приклёпывавши": ["приклёпывав"],
    "прикнопив": ["прикнопивши"],
    "прикнопивши": ["прикнопив"],
    "прикнопливав": ["прикнопливавши"],
    "прикнопливавши": ["прикнопливав"],
    "приковав": ["приковавши"],
    "приковавши": ["приковав"],
    "приковывав": ["приковывавши"],
    "приковывавши": ["приковывав"],
    "приковыливав": ["приковыливавши"],
    "приковыливавши": ["приковыливав"],
    "приковыляв": ["приковылявши"],
    "приковылявши": ["приковыляв"],
    "прикокав": ["прикокавши"],
    "прикокавши": ["прикокав"],
    "прикокнув": ["прикокнувши"],
    "прикокнувши": ["прикокнув"],
    "прикокошив": ["прикокошивши"],
    "прикокошивши": ["прикокошив"],
    "приколачивав": ["приколачивавши"],
    "приколачивавши": ["приколачивав"],
    "приколачивание": ["прибивание", "прибивка"],
    "приколачивать": ["прибивать", "пригвождать"],
    "приколдовав": ["приколдовавши"],
    "приколдовавши": ["приколдовав"],
    "приколдовывав": ["приколдовывавши"],
    "приколдовывавши": ["приколдовывав"],
    "приколесив": ["приколесивши"],
    "приколесивши": ["приколесив"],
    "приколист": ["приколёр", "шутник", "остряк", "хохмач", "весельчак", "юморист"],
    "приколов": ["приколовши"],
    "приколовши": ["приколов"],
    "приколотив": ["приколотивши"],
    "приколотивши": ["приколотив"],
    "приколотить": ["прибить", "поколотить"],
    "приколхозив": ["приколхозивши"],
    "приколхозивши": ["приколхозив"],
    "приколхозить": ["присобачить", "пришпандорить", "прикрепить", "присоединить"],
    "прикольнув": ["прикольнувши"],
    "прикольнувши": ["прикольнув"],
    "прикомандировав": ["прикомандировавши"],
    "прикомандировавши": ["прикомандировав"],
    "прикомандировать": ["откомандировать", "подать", "принести"],
    "прикомандировывав": ["прикомандировывавши"],
    "прикомандировывавши": ["прикомандировывав"],
    "прикончив": ["прикончивши"],
    "прикончивши": ["прикончив"],
    "прикончить": ["добить", "закончить", "окончить", "завершить", "довершить", "прекратить"],
    "прикопав": ["прикопавши"],
    "прикопавши": ["прикопав"],
    "прикопаться": ["пристать", "придраться", "прицепиться"],
    "прикопив": ["прикопивши"],
    "прикопивши": ["прикопив"],
    "прикопляв": ["прикоплявши"],
    "прикоплявши": ["прикопляв"],
    "прикормив": ["прикормивши"],
    "прикормивши": ["прикормив"],
    "прикорнув": ["прикорнувши"],
    "прикорнувши": ["прикорнув"],
    "прикорнуть": ["прилечь"],
    "прикосив": ["прикосивши"],
    "прикосивши": ["прикосив"],
    "прикосновенный": ["причастный", "прилежащий", "смежный"],
    "прикосновенье": ["прикосновение"],
    "прикоснуться": ["дотронуться", "притронуться", "тронуть"],
    "прикостыляв": ["прикостылявши"],
    "прикостылявши": ["прикостыляв"],
    "прикочевав": ["прикочевавши"],
    "прикочевавши": ["прикочевав"],
    "прикочёвывав": ["прикочёвывавши"],
    "прикочёвывавши": ["прикочёвывав"],
    "прикраивав": ["прикраивавши"],
    "прикраивавши": ["прикраивав"],
    "прикраса": ["гипербола", "украшение"],
    "прикрасив": ["прикрасивши"],
    "прикрасивши": ["прикрасив"],
    "прикрашивав": ["прикрашивавши"],
    "прикрашивавши": ["прикрашивав"],
    "прикрашивать": ["скрашивать", "приукрашивать"],
    "прикрепив": ["прикрепивши"],
    "прикрепивши": ["прикрепив"],
    "прикрепить": ["приделать"],
    "прикрепляв": ["прикреплявши"],
    "прикреплявши": ["прикрепляв"],
    "прикреплять": ["приделывать", "присоединять"],
    "прикрикивав": ["прикрикивавши"],
    "прикрикивавши": ["прикрикивав"],
    "прикрикнув": ["прикрикнувши"],
    "прикрикнувши": ["прикрикнув"],
    "прикроив": ["прикроивши"],
    "прикроивши": ["прикроив"],
    "прикрутив": ["прикрутивши"],
    "прикрутивши": ["прикрутив"],
    "прикручивав": ["прикручивавши"],
    "прикручивавши": ["прикручивав"],
    "прикручиниваться": ["опечаливаться", "пригорюниваться"],
    "прикрыв": ["прикрывши"],
    "прикрывав": ["прикрывавши"],
    "прикрывавши": ["прикрывав"],
    "прикрывать": ["накрывать", "укрывать", "скрывать"],
    "прикрывши": ["прикрыв"],
    "прикрытие": ["защита", "охрана", "сокрытие", "утаивание", "затушёвывание", "маскировка", "ширма"],
    "прикрыть лавочку": ["закрыть лавочку"],
    "прикрытье": ["прикрытие"],
    "прикрякивав": ["прикрякивавши"],
    "прикрякивавши": ["прикрякивав"],
    "прикрякнув": ["прикрякнувши"],
    "прикрякнувши": ["прикрякнув"],
    "прикряхтывав": ["прикряхтывавши"],
    "прикряхтывавши": ["прикряхтывав"],
    "прикупав": ["прикупавши"],
    "прикупавши": ["прикупав"],
    "прикупив": ["прикупивши"],
    "прикупивши": ["прикупив"],
    "прикурив": ["прикуривши"],
    "прикуривав": ["прикуривавши"],
    "прикуривавши": ["прикуривав"],
    "прикуривши": ["прикурив"],
    "прикурнув": ["прикурнувши"],
    "прикурнувши": ["прикурнув"],
    "прикурнуть": ["прикорнуть"],
    "прикус": ["укус"],
    "прикусив": ["прикусивши"],
    "прикусивши": ["прикусив"],
    "прикусить язык": ["проглотить язык", "набрать воды в рот"],
    "прикусывав": ["прикусывавши"],
    "прикусывавши": ["прикусывав"],
    "прикусывание": ["покусывание"],
    "прикушав": ["прикушавши"],
    "прикушавши": ["прикушав"],
    "прикушивав": ["прикушивавши"],
    "прикушивавши": ["прикушивав"],
    "прилагав": ["прилагавши"],
    "прилагавши": ["прилагав"],
    "прилагательное": ["имя прилагательное"],
    "прилагать": ["прибавлять", "присоединять"],
    "прилагать усилия": ["стремиться", "стараться"],
    "приладив": ["приладивши"],
    "приладивши": ["приладив"],
    "приладить": ["приспособить", "приделать"],
    "приладиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться"],
    "прилаженный": ["адаптированный", "вработанный", "закрепленный", "подлаженный", "подогнанный", "пригнанный", "приделанный", "прикрепленный", "прикроенный", "приляпанный", "примастеренный", "припиленный", "припряженный", "приработанный", "прирубленный"],
    "прилаживав": ["прилаживавши"],
    "прилаживавши": ["прилаживав"],
    "прилаживать": ["приспосабливать", "приделывать", "пристраивать"],
    "прилаживаться": ["приспосабливаться", "приноравливаться", "устраиваться", "пристраиваться"],
    "приламывав": ["приламывавши"],
    "приламывавши": ["приламывав"],
    "приласкав": ["приласкавши"],
    "приласкавши": ["приласкав"],
    "приласкивав": ["приласкивавши"],
    "приласкивавши": ["приласкивав"],
    "прилатав": ["прилатавши"],
    "прилатавши": ["прилатав"],
    "прилгав": ["прилгавши"],
    "прилгавши": ["прилгав"],
    "прилгнув": ["прилгнувши"],
    "прилгнувши": ["прилгнув"],
    "прилегав": ["прилегавши"],
    "прилегавши": ["прилегав"],
    "прилежав": ["прилежавши"],
    "прилежавши": ["прилежав"],
    "прилежание": ["усердие"],
    "прилежанье": ["прилежание"],
    "прилежать": ["усердствовать", "стараться", "склоняться", "прилегать", "соседствовать"],
    "прилежно": ["усердно", "старательно"],
    "прилежность": ["прилежание", "старательность", "усердие"],
    "прилежный": ["усердный", "старательный", "усидчивый", "добросовестный"],
    "прилезав": ["прилезавши"],
    "прилезавши": ["прилезав"],
    "прилепа": ["прилеп"],
    "прилепив": ["прилепивши"],
    "прилепивши": ["прилепив"],
    "прилепливав": ["прилепливавши"],
    "прилепливавши": ["прилепливав"],
    "прилепливать": ["прилеплять"],
    "прилепляв": ["прилеплявши"],
    "прилеплявши": ["прилепляв"],
    "прилеплять": ["приклеивать"],
    "прилепчивост": ["инфекциозност", "прихватливост", "заразност"],
    "прилетав": ["прилетавши"],
    "прилетавши": ["прилетав"],
    "прилетев": ["прилетевши"],
    "прилетевши": ["прилетев"],
    "прилив": ["приливши", "долив", "доливши", "подлив", "подливши"],
    "приливав": ["приливавши"],
    "приливавши": ["приливав"],
    "приливный захват": ["синхронное вращение"],
    "приливши": ["прилив"],
    "прилизав": ["прилизавши"],
    "прилизавши": ["прилизав"],
    "прилизывав": ["прилизывавши"],
    "прилизывавши": ["прилизывав"],
    "прилика": ["улика", "прилик"],
    "прилипав": ["прилипавши"],
    "прилипавши": ["прилипав"],
    "прилипала": ["присос", "держилодья", "рыба-прилипала"],
    "прилипать": ["липнуть"],
    "прилипаться": ["приклеиваться", "прикрепляться", "присасываться", "примыкаться", "прижиматься"],
    "прилипнув": ["прилипнувши"],
    "прилипнувши": ["прилипнув"],
    "прилипчивый": ["липкий", "липучий"],
    "приличать": ["изобличать"],
    "приличаться": ["изобличаться"],
    "приличествовав": ["приличествовавши"],
    "приличествовавши": ["приличествовав"],
    "приличествовать": ["подобать"],
    "приличествующий": ["достойный", "заслуженный", "подходящий", "положенный", "подобающий", "надлежащий", "достодолжный", "соответствующий", "отвечающий", "должный", "приличный"],
    "приличие": ["пристойность", "благопристойность", "благовидность", "благообразие", "декорум", "благочиние", "приличье", "благочинье"],
    "приличить": ["изобличить"],
    "приличиться": ["изобличиться"],
    "приличия": ["приличья"],
    "прилично": ["пристойно", "порядочно"],
    "приличность": ["соответственность", "сообразность", "подобие", "уместность", "удобность", "приличие"],
    "приличный": ["пристойный", "подобающий", "подходящий", "порядочный", "значительный"],
    "приличье": ["приличие"],
    "приличья": ["приличия"],
    "прилка": ["приложуха", "апп"],
    "приловчиться": ["приноровиться"],
    "приложение": ["прикладывание", "добавление", "добавка", "придаток", "применение", "использование", "прикладная программа", "апп", "апликуха", "прилка", "приложуха"],
    "приложенье": ["приложение"],
    "приложив": ["приложивши"],
    "приложивши": ["приложив"],
    "приложимый": ["применимый"],
    "приложуха": ["прилка", "апп"],
    "прилунив": ["прилунивши"],
    "прилунивши": ["прилунив"],
    "прилуняв": ["прилунявши"],
    "прилунявши": ["прилуняв"],
    "прилупив": ["прилупивши"],
    "прилупивши": ["прилупив"],
    "прилучав": ["прилучавши"],
    "прилучавши": ["прилучав"],
    "прилучив": ["прилучивши"],
    "прилучивши": ["прилучив"],
    "прилыгав": ["прилыгавши"],
    "прилыгавши": ["прилыгав"],
    "прилыгать": ["привирать", "присочинять"],
    "прильнув": ["прильнувши"],
    "прильнувши": ["прильнув"],
    "прильнуть": ["прижаться", "приникнуть"],
    "прильнуться": ["прибиться"],
    "прилюбив": ["прилюбивши"],
    "прилюбивши": ["прилюбив"],
    "прилюдно": ["гласно", "публично", "открыто"],
    "приляпав": ["приляпавши"],
    "приляпавши": ["приляпав"],
    "приляпывав": ["приляпывавши"],
    "приляпывавши": ["приляпывав"],
    "прима": ["премьер"],
    "примав": ["примавши"],
    "примавши": ["примав"],
    "примагнитив": ["примагнитивши"],
    "примагнитивши": ["примагнитив"],
    "примагниченный": ["прилипший"],
    "примагничивав": ["примагничивавши"],
    "примагничивавши": ["примагничивав"],
    "примаж": ["каплак"],
    "примазав": ["примазавши"],
    "примазавши": ["примазав"],
    "примазаться": ["смазаться"],
    "примазывав": ["примазывавши"],
    "примазывавши": ["примазывав"],
    "примазывать": ["приманивать"],
    "примак": ["приймак", "вдомник", "влазень", "призяченный", "вабий"],
    "примакивав": ["примакивавши"],
    "примакивавши": ["примакивав"],
    "примакнув": ["примакнувши"],
    "примакнувши": ["примакнув"],
    "прималчивав": ["прималчивавши"],
    "прималчивавши": ["прималчивав"],
    "прималывав": ["прималывавши"],
    "прималывавши": ["прималывав"],
    "примамливост": ["привлекателност", "съблазнителност"],
    "приманив": ["приманивши"],
    "приманивав": ["приманивавши"],
    "приманивавши": ["приманивав"],
    "приманивши": ["приманив"],
    "приманный": ["приманчивый"],
    "приманочный": ["приманный"],
    "примаргивав": ["примаргивавши"],
    "примаргивавши": ["примаргивав"],
    "примарность": ["первичность"],
    "примаршировав": ["примаршировавши"],
    "примаршировавши": ["примаршировав"],
    "примаслив": ["примасливши"],
    "примасливав": ["примасливавши"],
    "примасливавши": ["примасливав"],
    "примасливши": ["примаслив"],
    "примастерив": ["примастеривши"],
    "примастеривши": ["примастерив"],
    "примат": ["гоминида"],
    "приматник": ["обезьянник"],
    "приматывав": ["приматывавши"],
    "приматывавши": ["приматывав"],
    "примахав": ["примахавши"],
    "примахавши": ["примахав"],
    "примахнув": ["примахнувши"],
    "примахнувши": ["примахнув"],
    "примахнуть": ["примахать"],
    "примачивав": ["примачивавши"],
    "примачивавши": ["примачивав"],
    "примащивав": ["примащивавши"],
    "примащивавши": ["примащивав"],
    "примащиваться": ["моститься"],
    "примедлив": ["примедливши"],
    "примедливши": ["примедлив"],
    "примежевав": ["примежевавши"],
    "примежевавши": ["примежевав"],
    "примежёвывав": ["примежёвывавши"],
    "примежёвывавши": ["примежёвывав"],
    "применение": ["использование", "приложение", "употребление"],
    "применив": ["применивши"],
    "применивши": ["применив"],
    "применимость": ["пригодность"],
    "применимый": ["пригодный"],
    "применительно к": ["смотря по", "судя по", "в зависимости от", "в отношении", "по отношению к"],
    "применительный": ["употребительный", "применимый"],
    "применить": ["использовать", "задействовать", "употребить", "воспользоваться"],
    "примениться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "вжиться", "сжиться", "прижиться", "освоиться", "использоваться"],
    "применяв": ["применявши"],
    "применявши": ["применяв"],
    "применять": ["использовать", "задействовать", "употреблять", "эксплуатировать", "утилизировать", "пускать в ход", "пускать в дело", "пользоваться", "прибегать"],
    "пример": ["случай", "образец", "экземпляр"],
    "примерев": ["примерши"],
    "примереть": ["перемереть"],
    "примерзав": ["примерзавши"],
    "примерзавши": ["примерзав"],
    "примерзать": ["примораживаться", "подмерзать", "зябнуть"],
    "примерив": ["примеривши"],
    "примеривав": ["примеривавши"],
    "примеривавши": ["примеривав"],
    "примеривание": ["примерка"],
    "примериванье": ["примеривание"],
    "примеривать": ["примерять"],
    "примериваться": ["примеряться", "приноровляться", "изловчаться"],
    "примеривши": ["примерив"],
    "примеркав": ["примеркавши"],
    "примеркавши": ["примеркав"],
    "примеркнув": ["примеркнувши"],
    "примеркнувши": ["примеркнув"],
    "примерно": ["приблизительно", "около"],
    "примерный": ["образцовый", "показательный"],
    "примерши": ["примерев"],
    "примеряв": ["примерявши"],
    "примерявши": ["примеряв"],
    "примес": ["примесь"],
    "примесив": ["примесивши"],
    "примесивши": ["примесив"],
    "примесный": ["присадочный"],
    "примесь": ["примес"],
    "примета": ["особенность", "черта", "отличие", "свойство", "проявление", "признак", "симптом", "показатель", "предзнаменование", "предвестие", "знамение"],
    "приметав": ["приметавши"],
    "приметавши": ["приметав"],
    "приметивши": ["приметив"],
    "приметить": ["заметить", "отметить"],
    "приметно": ["заметно", "ощутимо"],
    "приметнув": ["приметнувши"],
    "приметнувши": ["приметнув"],
    "приметный": ["заметный", "примечательный"],
    "примечав": ["примечавши"],
    "примечавши": ["примечав"],
    "примечание": ["замечание", "комментарий"],
    "примечанье": ["примечание"],
    "примечательный": ["замечательный"],
    "примешав": ["примешавши"],
    "примешавши": ["примешав"],
    "примешивав": ["примешивавши"],
    "примешивавши": ["примешивав"],
    "примешивать": ["вставлять", "вовлекать", "впутывать"],
    "приминав": ["приминавши"],
    "приминавши": ["приминав"],
    "примирение": ["замирение", "перемирие", "мир", "согласие"],
    "примирив": ["примиривши"],
    "примиривши": ["примирив"],
    "примировав": ["примировавши"],
    "примировавши": ["примировав"],
    "примиряв": ["примирявши"],
    "примирявши": ["примиряв"],
    "примиряюще": ["примирительно", "мирно", "умиротворяюще", "успокаивающе"],
    "примитивизация": ["упрощение"],
    "примитивизировав": ["примитивизировавши"],
    "примитивизировавши": ["примитивизировав"],
    "примитивизм": ["наивное искусство"],
    "примитивно": ["бесхитростно", "безыскусно", "незамысловато", "грубо", "неглубоко"],
    "примитивность": ["элементарность"],
    "примитивный": ["простой", "грубый", "ограниченный", "первобытный", "дикий", "пещерный"],
    "примитизировав": ["примитизировавши"],
    "примитизировавши": ["примитизировав"],
    "примкнув": ["примкнувши"],
    "примкнувши": ["примкнув"],
    "примкнувший шепилов": ["и примкнувший к ним шепилов"],
    "примкнуть": ["присоединить", "прикрепить", "подсоединить", "нацепить", "прицепить", "присоединиться", "объединиться", "влиться в ряды", "подключиться", "примазаться", "припереть", "отнести", "причислить", "сопричислить", "прибавить"],
    "примова": ["закляття", "заклинання", "замовляння"],
    "примокнув": ["примокнувши"],
    "примокнувши": ["примокнув"],
    "примолачивав": ["примолачивавши"],
    "примолачивавши": ["примолачивав"],
    "примолвив": ["примолвивши"],
    "примолвивши": ["примолвив"],
    "примолвить": ["прибавить"],
    "примолвливав": ["примолвливавши"],
    "примолвливавши": ["примолвливав"],
    "примолвляв": ["примолвлявши"],
    "примолвлявши": ["примолвляв"],
    "примолкав": ["примолкавши"],
    "примолкавши": ["примолкав"],
    "примолкнув": ["примолкнувши"],
    "примолкнувши": ["примолкнув"],
    "примолкнуть": ["замолкнуть"],
    "примолов": ["примоловши"],
    "примоловши": ["примолов"],
    "примолотив": ["примолотивши"],
    "примолотивши": ["примолотив"],
    "примолчав": ["примолчавши"],
    "примолчавши": ["примолчав"],
    "примолчать": ["примолкнуть", "промолчать", "смолчать"],
    "примонтировав": ["примонтировавши"],
    "примонтировавши": ["примонтировав"],
    "примораживав": ["примораживавши"],
    "примораживавши": ["примораживав"],
    "примордиализм": ["эссенциализм"],
    "примордиальный": ["первичный", "первоначальный"],
    "приморив": ["приморивши"],
    "приморивши": ["приморив"],
    "приморозив": ["приморозивши"],
    "приморозивши": ["приморозив"],
    "приморский край": ["приморье", "пк"],
    "приморье": ["приморский край"],
    "примостив": ["примостивши"],
    "примостивши": ["примостив"],
    "примостить": ["примащивать"],
    "примоститься": ["пристроиться", "присоединиться"],
    "примотав": ["примотавши"],
    "примотавши": ["примотав"],
    "примочив": ["примочивши"],
    "примочивши": ["примочив"],
    "примула": ["первоцвет"],
    "примундирив": ["примундиривши"],
    "примундиривав": ["примундиривавши"],
    "примундиривавши": ["примундиривав"],
    "примундиривши": ["примундирив"],
    "примурманский": ["подмурманский"],
    "примучив": ["примучивши"],
    "примучивав": ["примучивавши"],
    "примучивавши": ["примучивав"],
    "примучивши": ["примучив"],
    "примчав": ["примчавши"],
    "примчавши": ["примчав"],
    "примчаться": ["примчать", "принестись"],
    "примыв": ["примывши"],
    "примывав": ["примывавши"],
    "примывавши": ["примывав"],
    "примывши": ["примыв"],
    "примыкав": ["примыкавши"],
    "примыкавши": ["примыкав"],
    "примыслив": ["примысливши"],
    "примысливав": ["примысливавши"],
    "примысливавши": ["примысливав"],
    "примысливши": ["примыслив"],
    "примышляв": ["примышлявши"],
    "примышлявши": ["примышляв"],
    "примяв": ["примявши"],
    "примявши": ["примяв"],
    "примёрзнув": ["примёрзнувши"],
    "примёрзнувши": ["примёрзнув"],
    "примёрзнуть": ["приморозиться", "подмёрзнуть", "озябнуть"],
    "примётывав": ["примётывавши"],
    "примётывавши": ["примётывав"],
    "принагибав": ["принагибавши"],
    "принагибавши": ["принагибав"],
    "принагнув": ["принагнувши"],
    "принагнувши": ["принагнув"],
    "принадвигав": ["принадвигавши"],
    "принадвигавши": ["принадвигав"],
    "принадвинув": ["принадвинувши"],
    "принадвинувши": ["принадвинув"],
    "принадлежав": ["принадлежавши"],
    "принадлежавши": ["принадлежав"],
    "принадлежность": ["собственность"],
    "принадоедав": ["принадоедавши"],
    "принадоедавши": ["принадоедав"],
    "принажав": ["принажавши"],
    "принажавши": ["принажав"],
    "приназаленный": ["носовой"],
    "принайтовав": ["принайтовавши"],
    "принайтовавши": ["принайтовав"],
    "принайтовив": ["принайтовивши"],
    "принайтовивши": ["принайтовив"],
    "принайтовливав": ["принайтовливавши"],
    "принайтовливавши": ["принайтовливав"],
    "принайтовывав": ["принайтовывавши"],
    "принайтовывавши": ["принайтовывав"],
    "принакапливав": ["принакапливавши"],
    "принакапливавши": ["принакапливав"],
    "принакопив": ["принакопивши"],
    "принакопивши": ["принакопив"],
    "принакрыв": ["принакрывши"],
    "принакрывав": ["принакрывавши"],
    "принакрывавши": ["принакрывав"],
    "принакрывши": ["принакрыв"],
    "приналегав": ["приналегавши"],
    "приналегавши": ["приналегав"],
    "приналечь": ["подналечь", "налечь"],
    "приналовчиться": ["напрактиковаться", "наловчиться", "насобачиться"],
    "принанимав": ["принанимавши"],
    "принанимавши": ["принанимав"],
    "принаняв": ["принанявши"],
    "принанявши": ["принаняв"],
    "принарядив": ["принарядивши"],
    "принарядивши": ["принарядив"],
    "принарядить": ["приодеть", "разодеть", "приукрасить", "разукрасить"],
    "принарядиться": ["нарядиться"],
    "принаряжав": ["принаряжавши"],
    "принаряжавши": ["принаряжав"],
    "принаряжаться": ["наряжаться"],
    "принаряживав": ["принаряживавши"],
    "принаряживавши": ["принаряживав"],
    "принахмурив": ["принахмуривши"],
    "принахмуривав": ["принахмуривавши"],
    "принахмуривавши": ["принахмуривав"],
    "принахмуривши": ["принахмурив"],
    "принашивав": ["принашивавши"],
    "принашивавши": ["принашивав"],
    "приневолив": ["приневоливши"],
    "приневоливав": ["приневоливавши"],
    "приневоливавши": ["приневоливав"],
    "приневоливши": ["приневолив"],
    "принесенье": ["принесение"],
    "принижав": ["принижавши"],
    "принижавши": ["принижав"],
    "принижать": ["унижать", "умалять"],
    "принижаться": ["понижаться"],
    "принизав": ["принизавши"],
    "принизавши": ["принизав"],
    "принизив": ["принизивши"],
    "принизивши": ["принизив"],
    "принизить": ["унизить", "умалить"],
    "принизывав": ["принизывавши"],
    "принизывавши": ["принизывав"],
    "приникав": ["приникавши"],
    "приникавши": ["приникав"],
    "приникать": ["прижиматься", "припадать"],
    "приникнув": ["приникнувши"],
    "приникнувши": ["приникнув"],
    "приникнуть": ["прижаться", "припасть"],
    "принимав": ["принимавши"],
    "принимавши": ["принимав"],
    "принимать": ["получать", "брать"],
    "принимать во внимание": ["учитывать", "принимать в расчёт"],
    "принимать за чистую монету": ["купиться", "поверить"],
    "приниматься": ["браться", "приступать", "приживаться"],
    "приноравливав": ["приноравливавши"],
    "приноравливавши": ["приноравливав"],
    "приноравливание": ["приспосабливание"],
    "приноровив": ["приноровивши"],
    "приноровивши": ["приноровив"],
    "приноровиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться"],
    "приноровляв": ["приноровлявши"],
    "приноровлявши": ["приноровляв"],
    "приносив": ["приносивши"],
    "приносивши": ["приносив"],
    "приносный": ["приносимый", "принесённый", "приносной", "наносный", "пригнанный", "пригонный"],
    "приношенье": ["приношение"],
    "принтер": ["печатник"],
    "принтив": ["принтивши"],
    "принтивши": ["принтив"],
    "принудив": ["принудивши"],
    "принудивши": ["принудив"],
    "принудиловка": ["принудительные работы"],
    "принудительно": ["насильственно", "насильно"],
    "принудительные работы": ["принудтруд", "принудработа", "принудиловка"],
    "принудительный": ["насильственный"],
    "принудить": ["заставить", "вынудить", "понудить"],
    "принуждав": ["принуждавши"],
    "принуждавши": ["принуждав"],
    "принуждать": ["заставлять", "неволить", "понуждать"],
    "принуждение": ["принужденье", "вынуждение", "давление"],
    "принужденье": ["принуждение"],
    "принуждённый": ["натянутый"],
    "принц": ["князь", "королевич"],
    "принцесса": ["королевна"],
    "принцип": ["основа", "догмат", "постулат", "доктрина", "убеждение", "точка зрения"],
    "принцип работы": ["принцип действия"],
    "принципиальничав": ["принципиальничавши"],
    "принципиальничавши": ["принципиальничав"],
    "принципиально": ["бескомпромиссно"],
    "принюхивав": ["принюхивавши"],
    "принюхивавши": ["принюхивав"],
    "принюхиваться": ["выслеживать", "разведывать"],
    "приняв": ["принявши"],
    "принявши": ["приняв"],
    "принятие": ["приём"],
    "принять": ["получить", "взять"],
    "принять участие": ["позаботиться"],
    "принятье": ["принятие"],
    "приняться": ["приступить", "взяться", "прижиться"],
    "приобвыкав": ["приобвыкавши"],
    "приобвыкавши": ["приобвыкав"],
    "приобвыкнув": ["приобвыкнувши"],
    "приобвыкнувши": ["приобвыкнув"],
    "приобнимав": ["приобнимавши"],
    "приобнимавши": ["приобнимав"],
    "приобняв": ["приобнявши"],
    "приобнявши": ["приобняв"],
    "приободрив": ["приободривши"],
    "приободривши": ["приободрив"],
    "приободрить": ["обрадовать", "подбодрить"],
    "приободряв": ["приободрявши"],
    "приободрявши": ["приободряв"],
    "приобрести": ["заполучить", "добыть", "обзавестись", "купить", "заслужить", "завоевать", "обрести", "снискать", "стяжать"],
    "приобретав": ["приобретавши"],
    "приобретавши": ["приобретав"],
    "приобретать": ["обретать", "получать", "завладевать"],
    "приобретаться": ["покупаться"],
    "приобретение": ["покупка", "пополнение"],
    "приобретенье": ["приобретение"],
    "приобув": ["приобувши"],
    "приобувши": ["приобув"],
    "приобучав": ["приобучавши"],
    "приобучавши": ["приобучав"],
    "приобучив": ["приобучивши"],
    "приобучивши": ["приобучив"],
    "приобщав": ["приобщавши"],
    "приобщавши": ["приобщав"],
    "приобщенье": ["приобщение"],
    "приобщив": ["приобщивши"],
    "приобщивши": ["приобщив"],
    "приобщённость": ["вовлечённость"],
    "приобыкав": ["приобыкавши"],
    "приобыкавши": ["приобыкав"],
    "приобыкнув": ["приобыкнувши"],
    "приобыкнувши": ["приобыкнув"],
    "приодев": ["приодевши"],
    "приодевши": ["приодев"],
    "приодеться": ["одеться", "нарядиться", "принарядиться", "разодеться"],
    "приокулировав": ["приокулировавши"],
    "приокулировавши": ["приокулировав"],
    "приопускав": ["приопускавши"],
    "приопускавши": ["приопускав"],
    "приопускаться": ["приподниматься"],
    "приопустив": ["приопустивши"],
    "приопустивши": ["приопустив"],
    "приопуститься": ["приподняться"],
    "приоритет": ["первенство", "преимущество", "цель"],
    "приоритетность": ["важность"],
    "приоритетный": ["важный", "первостепенный"],
    "приоритизировав": ["приоритизировавши"],
    "приоритизировавши": ["приоритизировав"],
    "приоритизировать": ["ранжировать"],
    "приосенив": ["приосенивши"],
    "приосенивши": ["приосенив"],
    "приосеняв": ["приосенявши"],
    "приосенявши": ["приосеняв"],
    "приостанавливав": ["приостанавливавши"],
    "приостанавливавши": ["приостанавливав"],
    "приостановив": ["приостановивши"],
    "приостановивши": ["приостановив"],
    "приостановка": ["возобновление"],
    "приострив": ["приостривши"],
    "приостривши": ["приострив"],
    "приостряв": ["приострявши"],
    "приострявши": ["приостряв"],
    "приостыв": ["приостывши"],
    "приостывав": ["приостывавши"],
    "приостывавши": ["приостывав"],
    "приостывши": ["приостыв"],
    "приостынув": ["приостынувши"],
    "приостынувши": ["приостынув"],
    "приотворив": ["приотворивши"],
    "приотворивши": ["приотворив"],
    "приотвориться": ["приоткрыться"],
    "приотворяв": ["приотворявши"],
    "приотворявши": ["приотворяв"],
    "приотворяться": ["приоткрываться"],
    "приотдохнув": ["приотдохнувши"],
    "приотдохнувши": ["приотдохнув"],
    "приоткидывав": ["приоткидывавши"],
    "приоткидывавши": ["приоткидывав"],
    "приоткинув": ["приоткинувши"],
    "приоткинувши": ["приоткинув"],
    "приоткрыв": ["приоткрывши"],
    "приоткрывав": ["приоткрывавши"],
    "приоткрывавши": ["приоткрывав"],
    "приоткрывши": ["приоткрыв"],
    "приоткрыть": ["приотворить", "раскрыть"],
    "приоткрыться": ["приотвориться"],
    "приотпускав": ["приотпускавши"],
    "приотпускавши": ["приотпускав"],
    "приотпустив": ["приотпустивши"],
    "приотпустивши": ["приотпустив"],
    "приотстав": ["приотставши"],
    "приотставав": ["приотстававши"],
    "приотстававши": ["приотставав"],
    "приотставши": ["приотстав"],
    "приохотив": ["приохотивши"],
    "приохотивши": ["приохотив"],
    "приохотиться": ["привыкнуть", "приучиться", "втянуться", "пристраститься", "повадиться"],
    "приохочивав": ["приохочивавши"],
    "приохочивавши": ["приохочивав"],
    "припадав": ["припадавши"],
    "припадавши": ["припадав"],
    "припадок": ["приступ"],
    "припаздывав": ["припаздывавши"],
    "припаздывавши": ["припаздывав"],
    "припаивав": ["припаивавши"],
    "припаивавши": ["припаивав"],
    "припалзывав": ["припалзывавши"],
    "припалзывавши": ["припалзывав"],
    "припалив": ["припаливши"],
    "припаливав": ["припаливавши"],
    "припаливавши": ["припаливав"],
    "припаливши": ["припалив"],
    "припарив": ["припаривши"],
    "припаривав": ["припаривавши"],
    "припаривавши": ["припаривав"],
    "припаривши": ["припарив"],
    "припарка": ["компресс"],
    "припарковав": ["припарковавши"],
    "припарковавши": ["припарковав"],
    "припарковаться": ["запарковаться"],
    "припарковывав": ["припарковывавши"],
    "припарковывавши": ["припарковывав"],
    "припархивав": ["припархивавши"],
    "припархивавши": ["припархивав"],
    "припас": ["запас", "резерв", "снаряжение", "провиант"],
    "припасав": ["припасавши"],
    "припасавши": ["припасав"],
    "припасать": ["запасать"],
    "припасовав": ["припасовавши"],
    "припасовавши": ["припасовав"],
    "припасовывав": ["припасовывавши"],
    "припасовывавши": ["припасовывав"],
    "припахав": ["припахавши"],
    "припахавши": ["припахав"],
    "припахивав": ["припахивавши"],
    "припахивавши": ["припахивав"],
    "припаяв": ["припаявши"],
    "припаявши": ["припаяв"],
    "припаять": ["приписать", "присудить"],
    "припев": ["рефрен", "напев", "присказка"],
    "припевав": ["припевавши"],
    "припевавши": ["припевав"],
    "припеваючи": ["как сыр в масле"],
    "припевка": ["запевка", "частушка"],
    "припевши": ["припев"],
    "припекав": ["припекавши"],
    "припекавши": ["припекав"],
    "приперев": ["припёрши"],
    "приперчив": ["приперчивши"],
    "приперчивав": ["приперчивавши"],
    "приперчивавши": ["приперчивав"],
    "приперчивши": ["приперчив"],
    "припечатав": ["припечатавши"],
    "припечатавши": ["припечатав"],
    "припечатывав": ["припечатывавши"],
    "припечатывавши": ["припечатывав"],
    "припив": ["припивши"],
    "припивав": ["припивавши"],
    "припивавши": ["припивав"],
    "припивши": ["припив"],
    "припиздив": ["припиздивши"],
    "припиздивши": ["припиздив"],
    "припизднув": ["припизднувши"],
    "припизднувши": ["припизднув"],
    "припилив": ["припиливши"],
    "припиливав": ["припиливавши"],
    "припиливавши": ["припиливав"],
    "припиливши": ["припилив"],
    "припирав": ["припиравши"],
    "припиравши": ["припирав"],
    "приписав": ["приписавши"],
    "приписавши": ["приписав"],
    "приписывав": ["приписывавши"],
    "приписывавши": ["приписывав"],
    "припись": ["подпись"],
    "припихивав": ["припихивавши"],
    "припихивавши": ["припихивав"],
    "припихнув": ["припихнувши"],
    "припихнувши": ["припихнув"],
    "приплавив": ["приплавивши"],
    "приплавивши": ["приплавив"],
    "приплавливав": ["приплавливавши"],
    "приплавливавши": ["приплавливав"],
    "приплавляв": ["приплавлявши"],
    "приплавлявши": ["приплавляв"],
    "приплакивав": ["приплакивавши"],
    "приплакивавши": ["приплакивав"],
    "приплатив": ["приплативши"],
    "приплативши": ["приплатив"],
    "приплачивав": ["приплачивавши"],
    "приплачивавши": ["приплачивав"],
    "приплеснув": ["приплеснувши"],
    "приплеснувши": ["приплеснув"],
    "приплетав": ["приплетавши"],
    "приплетавши": ["приплетав"],
    "приплывав": ["приплывавши"],
    "приплывавши": ["приплывав"],
    "приплывши": ["приплыв"],
    "приплюскивав": ["приплюскивавши"],
    "приплюскивавши": ["приплюскивав"],
    "приплюснув": ["приплюснувши"],
    "приплюснувши": ["приплюснув"],
    "приплюснутый": ["прижатый", "придавленный", "сплющенный", "сплюснутый"],
    "приплюсовав": ["приплюсовавши"],
    "приплюсовавши": ["приплюсовав"],
    "приплюсовывав": ["приплюсовывавши"],
    "приплюсовывавши": ["приплюсовывав"],
    "приплющив": ["приплющивши"],
    "приплющивав": ["приплющивавши"],
    "приплющивавши": ["приплющивав"],
    "приплющивши": ["приплющив"],
    "приплясывав": ["приплясывавши"],
    "приплясывавши": ["приплясывав"],
    "приплясыванье": ["приплясывание"],
    "приплясывать": ["пританцовывать", "притоптывать"],
    "приплёскивав": ["приплёскивавши"],
    "приплёскивавши": ["приплёскивав"],
    "приподнимав": ["приподнимавши"],
    "приподнимавши": ["приподнимав"],
    "приподнимать": ["приподымать", "возбуждать", "оживлять"],
    "приподниматься": ["приподыматься"],
    "приподняв": ["приподнявши"],
    "приподнявши": ["приподняв"],
    "приподымав": ["приподымавши"],
    "приподымавши": ["приподымав"],
    "приподымать": ["приподнимать"],
    "приподыматься": ["приподниматься"],
    "припожаловав": ["припожаловавши"],
    "припожаловавши": ["припожаловав"],
    "припоздав": ["припоздавши"],
    "припоздавши": ["припоздав"],
    "припоздать": ["запоздать"],
    "припоздниться": ["запоздать", "припоздать"],
    "приползав": ["приползавши"],
    "приползавши": ["приползав"],
    "приползать": ["подползать"],
    "приполюсный": ["приполярный", "околополюсный", "околополярный"],
    "припомадив": ["припомадивши"],
    "припомадивши": ["припомадив"],
    "припомаживав": ["припомаживавши"],
    "припомаживавши": ["припомаживав"],
    "припоминав": ["припоминавши"],
    "припоминавши": ["припоминав"],
    "припоминать": ["вспоминать"],
    "припомнив": ["припомнивши"],
    "припомнивши": ["припомнив"],
    "припомнить": ["вспомнить"],
    "припорашивав": ["припорашивавши"],
    "припорашивавши": ["припорашивав"],
    "припорошив": ["припорошивши"],
    "припорошивши": ["припорошив"],
    "припорошить": ["присыпать", "запорошить"],
    "припорхнув": ["припорхнувши"],
    "припорхнувши": ["припорхнув"],
    "припосадив": ["припосадивши"],
    "припосадивши": ["припосадив"],
    "припосаживав": ["припосаживавши"],
    "припосаживавши": ["припосаживав"],
    "припотев": ["припотевши"],
    "припотевши": ["припотев"],
    "приправа": ["приварок", "соус", "специи", "пряность"],
    "приправив": ["приправивши"],
    "приправивши": ["приправив"],
    "приправляв": ["приправлявши"],
    "приправлявши": ["приправляв"],
    "припрашивав": ["припрашивавши"],
    "припрашивавши": ["припрашивав"],
    "припрессовав": ["припрессовавши"],
    "припрессовавши": ["припрессовав"],
    "припрессовка": ["припрессовывание"],
    "припрессовывав": ["припрессовывавши"],
    "припрессовывавши": ["припрессовывав"],
    "припросив": ["припросивши"],
    "припросивши": ["припросив"],
    "припрошення": ["запрошення"],
    "припрудив": ["припрудивши"],
    "припрудивши": ["припрудив"],
    "припружать": ["припруживать"],
    "припруживав": ["припруживавши"],
    "припруживавши": ["припруживав"],
    "припруживать": ["припружать"],
    "припрыгав": ["припрыгавши"],
    "припрыгавши": ["припрыгав"],
    "припрыгивав": ["припрыгивавши"],
    "припрыгивавши": ["припрыгивав"],
    "припрыгнув": ["припрыгнувши"],
    "припрыгнувши": ["припрыгнув"],
    "припрыскивав": ["припрыскивавши"],
    "припрыскивавши": ["припрыскивав"],
    "припрыснув": ["припрыснувши"],
    "припрыснувши": ["припрыснув"],
    "припрягав": ["припрягавши"],
    "припрягавши": ["припрягав"],
    "припрядав": ["припрядавши"],
    "припрядавши": ["припрядав"],
    "припрядывав": ["припрядывавши"],
    "припрядывавши": ["припрядывав"],
    "припрятав": ["припрятавши"],
    "припрятавши": ["припрятав"],
    "припрятывав": ["припрятывавши"],
    "припрятывавши": ["припрятывав"],
    "припугивав": ["припугивавши"],
    "припугивавши": ["припугивав"],
    "припугнув": ["припугнувши"],
    "припугнувши": ["припугнув"],
    "припудрив": ["припудривши"],
    "припудривав": ["припудривавши"],
    "припудривавши": ["припудривав"],
    "припудривши": ["припудрив"],
    "припудриться": ["попудриться"],
    "припускав": ["припускавши"],
    "припускавши": ["припускав"],
    "припускать": ["допускать", "подпускать", "случать", "спаривать", "бежать", "бежать бегом", "припускаться", "торопиться", "добавлять", "усиливать", "усиливаться", "тушить"],
    "припустив": ["припустивши"],
    "припустивши": ["припустив"],
    "припустить": ["погнать", "усилиться"],
    "припутав": ["припутавши"],
    "припутавши": ["припутав"],
    "припутывав": ["припутывавши"],
    "припутывавши": ["припутывав"],
    "припухав": ["припухавши"],
    "припухавши": ["припухав"],
    "припухнув": ["припухнувши"],
    "припухнувши": ["припухнув"],
    "припушив": ["припушивши"],
    "припушивши": ["припушив"],
    "припыл": ["припыливание"],
    "припылив": ["припыливши"],
    "припыливав": ["припыливавши"],
    "припыливавши": ["припыливав"],
    "припыливание": ["припыл"],
    "припыливши": ["припылив"],
    "припыляв": ["припылявши"],
    "припылявши": ["припыляв"],
    "припёк": ["солнцепёк", "тёплое местечко", "пригрев"],
    "припёка": ["добавка", "приправа"],
    "припёрши": ["приперев"],
    "прирабатывав": ["прирабатывавши"],
    "прирабатывавши": ["прирабатывав"],
    "приработав": ["приработавши"],
    "приработавши": ["приработав"],
    "приработка": ["пригонка"],
    "приравнивав": ["приравнивавши"],
    "приравнивавши": ["приравнивав"],
    "приравниванье": ["приравнивание"],
    "приравнивать": ["равнять", "уравнивать"],
    "приравняв": ["приравнявши"],
    "приравнявши": ["приравняв"],
    "прираст": ["растеж", "нарастване", "увеличение"],
    "прирастав": ["прираставши"],
    "прираставши": ["прирастав"],
    "прирастив": ["прирастивши"],
    "прирастивши": ["прирастив"],
    "приращав": ["приращавши"],
    "приращавши": ["приращав"],
    "приращенье": ["приращение"],
    "приращивав": ["приращивавши"],
    "приращивавши": ["приращивав"],
    "приревновав": ["приревновавши"],
    "приревновавши": ["приревновав"],
    "прирезав": ["прирезавши"],
    "прирезавши": ["прирезав"],
    "прирезка": ["прирез", "прирезание", "прирезывание", "прирезок"],
    "прирезывав": ["прирезывавши"],
    "прирезывавши": ["прирезывав"],
    "прирельсовый": ["околорельсовый"],
    "приржавев": ["приржавевши"],
    "приржавевши": ["приржавев"],
    "пририсовав": ["пририсовавши"],
    "пририсовавши": ["пририсовав"],
    "пририсовать": ["дорисовать"],
    "пририсовывав": ["пририсовывавши"],
    "пририсовывавши": ["пририсовывав"],
    "пририсовывать": ["дорисовывать"],
    "прировняв": ["прировнявши"],
    "прировнявши": ["прировняв"],
    "природа": ["вселенная", "мир", "естество", "натура", "загород", "сущность", "подоплёка"],
    "природив": ["природивши"],
    "природивши": ["природив"],
    "природноочаговый": ["природно-очаговый"],
    "природный": ["естественный", "натуральный", "врождённый", "прирождённый", "исконный", "коренной", "наследственный", "туземный", "здешний", "местный"],
    "природоведение": ["естествоведение"],
    "природоохранник": ["экозащитник"],
    "природоохранный": ["природоохранительный"],
    "прирождённый": ["врождённый", "природный"],
    "прирост": ["увеличение"],
    "прирубав": ["прирубавши"],
    "прирубавши": ["прирубав"],
    "прирубив": ["прирубивши"],
    "прирубивши": ["прирубив"],
    "прирулив": ["прируливши"],
    "прируливав": ["прируливавши"],
    "прируливавши": ["прируливав"],
    "прируливши": ["прирулив"],
    "прирулить": ["подрулить"],
    "приручав": ["приручавши"],
    "приручавши": ["приручав"],
    "приручать": ["одомашнивать"],
    "прирученье": ["приручение"],
    "приручив": ["приручивши"],
    "приручивши": ["приручив"],
    "приручить": ["привязать", "подчинить"],
    "приручённый": ["одомашненный", "ручной", "послушный", "домашний"],
    "присадив": ["присадивши"],
    "присадивши": ["присадив"],
    "присаживав": ["присаживавши"],
    "присаживавши": ["присаживав"],
    "присаживаться": ["подсаживаться"],
    "присалив": ["присаливши"],
    "присаливав": ["присаливавши"],
    "присаливавши": ["присаливав"],
    "присаливши": ["присалив"],
    "присасывав": ["присасывавши"],
    "присасывавши": ["присасывав"],
    "присахарив": ["присахаривши"],
    "присахаривав": ["присахаривавши"],
    "присахаривавши": ["присахаривав"],
    "присахаривши": ["присахарив"],
    "присборив": ["присборивши"],
    "присборивав": ["присборивавши"],
    "присборивавши": ["присборивав"],
    "присборивши": ["присборив"],
    "присваивав": ["присваивавши"],
    "присваивавши": ["присваивав"],
    "присватав": ["присватавши"],
    "присватавши": ["присватав"],
    "присватывав": ["присватывавши"],
    "присватывавши": ["присватывав"],
    "присветив": ["присветивши"],
    "присветивши": ["присветив"],
    "присвечивав": ["присвечивавши"],
    "присвечивавши": ["присвечивав"],
    "присвистав": ["присвиставши"],
    "присвиставши": ["присвистав"],
    "присвистнув": ["присвистнувши"],
    "присвистнувши": ["присвистнув"],
    "присвистывав": ["присвистывавши"],
    "присвистывавши": ["присвистывав"],
    "присвистыванье": ["присвистывание"],
    "присвоив": ["присвоивши"],
    "присвоивав": ["присвоивавши"],
    "присвоивавши": ["присвоивав"],
    "присвоивши": ["присвоив"],
    "присворив": ["присворивши"],
    "присворивав": ["присворивавши"],
    "присворивавши": ["присворивав"],
    "присворивши": ["присворив"],
    "присвояв": ["присвоявши"],
    "присвоявши": ["присвояв"],
    "присевав": ["присевавши"],
    "присевавши": ["присевав"],
    "присед": ["приседание"],
    "приседав": ["приседавши"],
    "приседавши": ["приседав"],
    "приседание": ["присед", "приседанье", "реверанс"],
    "приседанье": ["приседание"],
    "приседать на уши": ["ездить по ушам", "тереть уши", "втирать уши", "причёсывать уши", "шлифовать уши", "искать свободные уши", "находить свободные уши"],
    "присекав": ["присекавши"],
    "присекавши": ["присекав"],
    "приселив": ["приселивши"],
    "приселивши": ["приселив"],
    "приселяв": ["приселявши"],
    "приселявши": ["приселяв"],
    "присеменив": ["присеменивши"],
    "присеменивав": ["присеменивавши"],
    "присеменивавши": ["присеменивав"],
    "присеменивши": ["присеменив"],
    "присеменник": ["ариллус"],
    "присемянник": ["ариллус"],
    "присесть на уши": ["съездить по ушам", "втереть в уши", "причесать уши", "отшлифовать уши", "шлифануть уши", "шлифануть по ушам", "найти свободные уши", "отыскать свободные уши"],
    "присеяв": ["присеявши"],
    "присеявши": ["присеяв"],
    "присказав": ["присказавши"],
    "присказавши": ["присказав"],
    "присказка": ["прибаутка"],
    "присказывав": ["присказывавши"],
    "присказывавши": ["присказывав"],
    "прискакав": ["прискакавши"],
    "прискакавши": ["прискакав"],
    "прискакивав": ["прискакивавши"],
    "прискакивавши": ["прискакивав"],
    "приской": ["прискойский эон", "катархей", "гадей", "антезой", "азой", "преархей"],
    "прискорбно": ["огорчительно"],
    "прискорбный": ["горестный", "скорбный", "печальный", "траурный"],
    "прискочив": ["прискочивши"],
    "прискочивши": ["прискочив"],
    "прискучав": ["прискучавши"],
    "прискучавши": ["прискучав"],
    "прискучив": ["прискучивши"],
    "прискучивав": ["прискучивавши"],
    "прискучивавши": ["прискучивав"],
    "прискучивши": ["прискучив"],
    "прискучить": ["надоесть", "наскучить", "приесться", "набить оскомину"],
    "прислав": ["приславши"],
    "приславши": ["прислав"],
    "прислать": ["переслать", "доставить", "послать"],
    "прислонив": ["прислонивши"],
    "прислонивши": ["прислонив"],
    "прислоняв": ["прислонявши"],
    "прислонявши": ["прислоняв"],
    "прислуга": ["служанка", "слуги", "расчёт"],
    "прислужив": ["прислуживши"],
    "прислуживав": ["прислуживавши"],
    "прислуживавши": ["прислуживав"],
    "прислуживанье": ["прислуживание"],
    "прислуживши": ["прислужив"],
    "прислужник": ["слуга", "служитель", "приспешник"],
    "прислужничав": ["прислужничавши"],
    "прислужничавши": ["прислужничав"],
    "прислушав": ["прислушавши"],
    "прислушавши": ["прислушав"],
    "прислушивав": ["прислушивавши"],
    "прислушивавши": ["прислушивав"],
    "прислушиваться": ["вслушиваться"],
    "присмактывав": ["присмактывавши"],
    "присмактывавши": ["присмактывав"],
    "присмаливав": ["присмаливавши"],
    "присмаливавши": ["присмаливав"],
    "присматривав": ["присматривавши"],
    "присматривавши": ["присматривав"],
    "присматривать": ["приглядывать", "наблюдать", "надзирать", "посматривать", "подыскивать"],
    "присмирев": ["присмиревши"],
    "присмиревши": ["присмирев"],
    "присмирив": ["присмиривши"],
    "присмиривши": ["присмирив"],
    "присмиряв": ["присмирявши"],
    "присмирявши": ["присмиряв"],
    "присмирять": ["усмирять", "успокаивать"],
    "присмолив": ["присмоливши"],
    "присмоливши": ["присмолив"],
    "присмотрев": ["присмотревши"],
    "присмотревши": ["присмотрев"],
    "присмотреться": ["приглядеться"],
    "приснастив": ["приснастивши"],
    "приснастивши": ["приснастив"],
    "приснащивав": ["приснащивавши"],
    "приснащивавши": ["приснащивав"],
    "присно": ["всегда"],
    "приснопамятный": ["достопамятный", "незабвенный"],
    "присноравливав": ["присноравливавши"],
    "присноравливавши": ["присноравливав"],
    "присноровив": ["присноровивши"],
    "присноровивши": ["присноровив"],
    "присный": ["свой", "родной", "приспешник", "единомышленник", "вечный", "всегдашний"],
    "присобачив": ["присобачивши"],
    "присобачивав": ["присобачивавши"],
    "присобачивавши": ["присобачивав"],
    "присобачивать": ["приделывать", "прикреплять", "прилаживать"],
    "присобачиваться": ["приделываться"],
    "присобачивши": ["присобачив"],
    "присобачить": ["прикрепить", "пристроить", "приделать"],
    "присобирав": ["присобиравши"],
    "присобиравши": ["присобирав"],
    "присобрав": ["присобравши"],
    "присобравши": ["присобрав"],
    "присоветовав": ["присоветовавши"],
    "присоветовавши": ["присоветовав"],
    "присовокупив": ["присовокупивши"],
    "присовокупивши": ["присовокупив"],
    "присовокупляв": ["присовокуплявши"],
    "присовокуплявши": ["присовокупляв"],
    "присовокуплённый": ["присоединённый"],
    "присовывав": ["присовывавши"],
    "присовывавши": ["присовывав"],
    "присогнув": ["присогнувши"],
    "присогнувши": ["присогнув"],
    "присоединенье": ["присоединение"],
    "присоединив": ["присоединивши"],
    "присоединивши": ["присоединив"],
    "присоединиться": ["соединиться", "подключиться"],
    "присоединяв": ["присоединявши"],
    "присоединявши": ["присоединяв"],
    "присоединять": ["присовокуплять", "включать", "причислять", "подключать", "подсоединять"],
    "присолив": ["присоливши"],
    "присоливши": ["присолив"],
    "присос": ["присасывание"],
    "присосав": ["присосавши"],
    "присосавши": ["присосав"],
    "присоска": ["присос", "присосок"],
    "присохнув": ["присохнувши"],
    "присохнувши": ["присохнув"],
    "присочинив": ["присочинивши"],
    "присочинивши": ["присочинив"],
    "присочиняв": ["присочинявши"],
    "присочинявши": ["присочиняв"],
    "приспав": ["приспавши"],
    "приспавши": ["приспав"],
    "приспев": ["приспевши"],
    "приспевав": ["приспевавши"],
    "приспевавши": ["приспевав"],
    "приспевши": ["приспев"],
    "приспешник": ["соучастник", "пособник", "помощник", "пекарь"],
    "приспешничав": ["приспешничавши"],
    "приспешничавши": ["приспешничав"],
    "приспичив": ["приспичивши"],
    "приспичивши": ["приспичив"],
    "приспосабливав": ["приспосабливавши"],
    "приспосабливавши": ["приспосабливав"],
    "приспосабливать": ["приспособлять"],
    "приспосабливаться": ["приспособляться", "адаптироваться"],
    "приспособа": ["приспособление"],
    "приспособив": ["приспособивши"],
    "приспособивши": ["приспособив"],
    "приспособиться": ["привыкнуть", "свыкнуться", "притерпеться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться", "обвыкнуть", "обвыкнуться"],
    "приспособленец": ["двурушник", "соглашатель", "оппортунист", "конформист", "конъюнктурщик", "хамелеон"],
    "приспособление": ["приспосабливание", "прилаживание", "устройство", "инструмент"],
    "приспособленье": ["приспособление"],
    "приспособляв": ["приспособлявши"],
    "приспособлявши": ["приспособляв"],
    "приспособлять": ["приспосабливать"],
    "приспускав": ["приспускавши"],
    "приспускавши": ["приспускав"],
    "приспустив": ["приспустивши"],
    "приспустивши": ["приспустив"],
    "пристав": ["судебный исполнитель"],
    "приставав": ["пристававши"],
    "пристававши": ["приставав"],
    "приставала": ["приставалкин", "приставалкина", "надоедкин", "надоедкина", "надоеда", "надоедина"],
    "приставанье": ["приставание"],
    "приставать": ["прилипать", "закрепляться", "передаваться", "присоединяться", "надоедать", "преследовать", "ухаживать", "причаливать", "поселяться"],
    "приставив": ["приставивши"],
    "приставивши": ["приставив"],
    "приставить": ["придвинуть", "приблизить", "прислонить"],
    "приставка": ["приставление", "подпорка", "префикс", "представка"],
    "приставляв": ["приставлявши"],
    "приставлявши": ["приставляв"],
    "приставлять": ["придвигать", "прислонять"],
    "приставочно-постфиксальный": ["префиксально-постфиксальный"],
    "приставочно-суффиксальный": ["конфиксальный", "префиксально-суффиксальный"],
    "приставочный": ["приставной", "консольный", "префиксальный"],
    "приставучий": ["назойливый", "надоедливый"],
    "приставши": ["пристав"],
    "пристально": ["сосредоточенно", "внимательно", "неотрывно", "в оба глаза"],
    "пристальный": ["сосредоточенный"],
    "пристан": ["кей"],
    "пристанище": ["приют", "притон", "угол", "обиталище", "обитель", "кров", "крыша над головой"],
    "пристанодержательствовав": ["пристанодержательствовавши"],
    "пристанодержательствовавши": ["пристанодержательствовав"],
    "пристарев": ["пристаревши"],
    "пристаревши": ["пристарев"],
    "пристать": ["привязаться", "прицепиться", "причалить"],
    "пристегав": ["пристегавши"],
    "пристегавши": ["пристегав"],
    "пристегнув": ["пристегнувши"],
    "пристегнувши": ["пристегнув"],
    "пристежной": ["пристёгивающийся"],
    "пристигав": ["пристигавши"],
    "пристигавши": ["пристигав"],
    "пристигнув": ["пристигнувши"],
    "пристигнувши": ["пристигнув"],
    "пристойно": ["прилично"],
    "пристойный": ["приличный", "добропорядочный", "благовоспитанный", "уместный"],
    "пристрагивав": ["пристрагивавши"],
    "пристрагивавши": ["пристрагивав"],
    "пристраивав": ["пристраивавши"],
    "пристраивавши": ["пристраивав"],
    "пристраиваться": ["устраиваться", "жениться"],
    "пристранствовав": ["пристранствовавши"],
    "пристранствовавши": ["пристранствовав"],
    "пристрастив": ["пристрастивши"],
    "пристрастивши": ["пристрастив"],
    "пристрастие": ["любовь", "влечение", "слабость", "предвзятость", "пристрастность"],
    "пристраститься": ["привыкнуть", "приучиться", "втянуться", "приохотиться", "повадиться"],
    "пристрастно": ["предвзято"],
    "пристрастность": ["предвзятость", "тенденциозность", "ангажированность"],
    "пристрастье": ["пристрастие"],
    "пристрачивав": ["пристрачивавши"],
    "пристрачивавши": ["пристрачивав"],
    "пристращав": ["пристращавши"],
    "пристращавши": ["пристращав"],
    "пристращивав": ["пристращивавши"],
    "пристращивавши": ["пристращивав"],
    "пристрелив": ["пристреливши"],
    "пристреливав": ["пристреливавши"],
    "пристреливавши": ["пристреливав"],
    "пристреливать": ["застреливать"],
    "пристреливши": ["пристрелив"],
    "пристрелить": ["застрелить", "подстрелить"],
    "пристрелиться": ["застрелиться"],
    "пристреляв": ["пристрелявши"],
    "пристрелявши": ["пристреляв"],
    "пристрогав": ["пристрогавши"],
    "пристрогавши": ["пристрогав"],
    "пристрожив": ["пристроживши"],
    "пристроживши": ["пристрожив"],
    "пристроив": ["пристроивши"],
    "пристроивав": ["пристроивавши"],
    "пристроивавши": ["пристроивав"],
    "пристроивши": ["пристроив"],
    "пристроить в дымоход": ["заехать под хвост", "заехать под хвостик", "под хвост заехать", "под хвостик заехать"],
    "пристройка": ["пристраивание"],
    "пристрочив": ["пристрочивши"],
    "пристрочивши": ["пристрочив"],
    "пристрочить": ["пристрачивать", "строчить"],
    "пристругав": ["пристругавши"],
    "пристругавши": ["пристругав"],
    "пристругивав": ["пристругивавши"],
    "пристругивавши": ["пристругивав"],
    "приструнив": ["приструнивши"],
    "приструнивав": ["приструнивавши"],
    "приструнивавши": ["приструнивав"],
    "приструнивши": ["приструнив"],
    "пристряв": ["пристрявши"],
    "пристрявши": ["пристряв"],
    "пристукав": ["пристукавши"],
    "пристукавши": ["пристукав"],
    "пристукивав": ["пристукивавши"],
    "пристукивавши": ["пристукивав"],
    "пристукнув": ["пристукнувши"],
    "пристукнувши": ["пристукнув"],
    "приступ": ["экскурсия"],
    "приступав": ["приступавши"],
    "приступавши": ["приступав"],
    "приступив": ["приступивши"],
    "приступивши": ["приступив"],
    "пристыв": ["пристывши"],
    "пристывав": ["пристывавши"],
    "пристывавши": ["пристывав"],
    "пристывши": ["пристыв"],
    "пристыдив": ["пристыдивши"],
    "пристыдивши": ["пристыдив"],
    "пристыжав": ["пристыжавши"],
    "пристыжавши": ["пристыжав"],
    "пристыжённый": ["пристыженный"],
    "пристыковав": ["пристыковавши"],
    "пристыковавши": ["пристыковав"],
    "пристыковывав": ["пристыковывавши"],
    "пристыковывавши": ["пристыковывав"],
    "пристынув": ["пристынувши"],
    "пристынувши": ["пристынув"],
    "пристыть": ["пристынуть", "подморозить", "приморозить", "примёрзнуть", "застыть", "привязаться"],
    "пристяжная": ["пристяжка"],
    "пристяжь": ["пристяжка"],
    "пристёгивав": ["пристёгивавши"],
    "пристёгивавши": ["пристёгивав"],
    "пристёгивающийся": ["пристежной"],
    "присударивав": ["присударивавши"],
    "присударивавши": ["присударивав"],
    "присударивать": ["присударкивать"],
    "присударкивав": ["присударкивавши"],
    "присударкивавши": ["присударкивав"],
    "присударкивать": ["присударивать"],
    "присудив": ["присудивши"],
    "присудивши": ["присудив"],
    "присудковий": ["предикативний"],
    "присудок": ["предикат"],
    "присуждав": ["присуждавши"],
    "присуждавши": ["присуждав"],
    "присунув": ["присунувши"],
    "присунувши": ["присунув"],
    "присунуть": ["припихнуть"],
    "присупонив": ["присупонивши"],
    "присупонивав": ["присупонивавши"],
    "присупонивавши": ["присупонивав"],
    "присупонивши": ["присупонив"],
    "присутствие": ["наличие", "существование", "пребывание", "служба", "учреждение", "офис"],
    "присутствовав": ["присутствовавши"],
    "присутствовавши": ["присутствовав"],
    "присутулив": ["присутуливши"],
    "присутуливав": ["присутуливавши"],
    "присутуливавши": ["присутуливав"],
    "присутуливши": ["присутулив"],
    "присучав": ["присучавши"],
    "присучавши": ["присучав"],
    "присучальщик": ["присучальщица"],
    "присучив": ["присучивши"],
    "присучивав": ["присучивавши"],
    "присучивавши": ["присучивав"],
    "присучивать": ["присучать"],
    "присучивши": ["присучив"],
    "присушив": ["присушивши"],
    "присушивав": ["присушивавши"],
    "присушивавши": ["присушивав"],
    "присушивши": ["присушив"],
    "присушка": ["подсушка", "привораживание", "привораживанье"],
    "присущий": ["свойственный", "характерный"],
    "присчитав": ["присчитавши"],
    "присчитавши": ["присчитав"],
    "присчитывав": ["присчитывавши"],
    "присчитывавши": ["присчитывав"],
    "присъда": ["решение", "резолюция", "вердикт"],
    "присылав": ["присылавши"],
    "присылавши": ["присылав"],
    "присыпав": ["присыпавши"],
    "присыпавши": ["присыпав"],
    "присыхав": ["присыхавши"],
    "присыхавши": ["присыхав"],
    "присюсюкивав": ["присюсюкивавши"],
    "присюсюкивавши": ["присюсюкивав"],
    "присяга": ["клятва"],
    "присягав": ["присягавши"],
    "присягавши": ["присягав"],
    "присягать": ["давать присягу", "клясться"],
    "присягнув": ["присягнувши"],
    "присягнувши": ["присягнув"],
    "притабанив": ["притабанивши"],
    "притабанивши": ["притабанив"],
    "притаив": ["притаивши"],
    "притаивав": ["притаивавши"],
    "притаивавши": ["притаивав"],
    "притаивши": ["притаив"],
    "притакивав": ["притакивавши"],
    "притакивавши": ["притакивав"],
    "притакнув": ["притакнувши"],
    "притакнувши": ["притакнув"],
    "приталенный": ["в талию"],
    "приталив": ["приталивши"],
    "приталивав": ["приталивавши"],
    "приталивавши": ["приталивав"],
    "приталивши": ["приталив"],
    "приталкивав": ["приталкивавши"],
    "приталкивавши": ["приталкивав"],
    "пританцовывав": ["пританцовывавши"],
    "пританцовывавши": ["пританцовывав"],
    "притапливав": ["притапливавши"],
    "притапливавши": ["притапливав"],
    "притаптывав": ["притаптывавши"],
    "притаптывавши": ["притаптывав"],
    "притаранив": ["притаранивши"],
    "притаранивав": ["притаранивавши"],
    "притаранивавши": ["притаранивав"],
    "притаранивши": ["притаранив"],
    "притаранить": ["припереть", "притащить"],
    "притаскивав": ["притаскивавши"],
    "притаскивавши": ["притаскивав"],
    "притачав": ["притачавши"],
    "притачавши": ["притачав"],
    "притачивав": ["притачивавши"],
    "притачивавши": ["притачивав"],
    "притачивание": ["притачка"],
    "притачка": ["притачивание"],
    "притащив": ["притащивши"],
    "притащивши": ["притащив"],
    "притаяв": ["притаявши"],
    "притаявши": ["притаяв"],
    "притвор": ["пронаос", "закваска"],
    "притвора": ["притворщик", "притворщица"],
    "притворив": ["притворивши"],
    "притворивши": ["притворив"],
    "притворничав": ["притворничавши"],
    "притворничавши": ["притворничав"],
    "притворство": ["лицемерие"],
    "притворствовав": ["притворствовавши"],
    "притворствовавши": ["притворствовав"],
    "притворщик": ["симулянт"],
    "притворщица": ["врунья"],
    "притворяв": ["притворявши"],
    "притворявши": ["притворяв"],
    "притворять": ["прикрывать", "затворять"],
    "притворяться": ["прикидываться", "симулировать", "делать вид"],
    "притекав": ["притекавши"],
    "притекавши": ["притекав"],
    "прительный": ["вздорный"],
    "притемнив": ["притемнивши"],
    "притемнивши": ["притемнив"],
    "притемняв": ["притемнявши"],
    "притемнявши": ["притемняв"],
    "притенив": ["притенивши"],
    "притенивши": ["притенив"],
    "притеняв": ["притенявши"],
    "притенявши": ["притеняв"],
    "притерев": ["притёрши"],
    "притереться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться"],
    "притерпеться": ["привыкнуть", "свыкнуться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "сжиться", "прижиться", "освоиться"],
    "притесав": ["притесавши"],
    "притесавши": ["притесав"],
    "притесаться": ["прибиться", "присоединиться", "пристроиться"],
    "притеснение": ["ущемление"],
    "притесненье": ["притеснение"],
    "притеснив": ["притеснивши"],
    "притеснивши": ["притеснив"],
    "притеснительница": ["угнетательница"],
    "притесняв": ["притеснявши"],
    "притеснявши": ["притесняв"],
    "притин": ["граница", "грань", "предел", "рубеж", "караул"],
    "притирав": ["притиравши"],
    "притиравши": ["притирав"],
    "притиранье": ["притирание"],
    "притирка": ["притирание"],
    "притискав": ["притискавши"],
    "притискавши": ["притискав"],
    "притискивав": ["притискивавши"],
    "притискивавши": ["притискивав"],
    "притиснув": ["притиснувши"],
    "притиснувши": ["притиснув"],
    "притихав": ["притихавши"],
    "притихавши": ["притихав"],
    "притихнув": ["притихнувши"],
    "притихнувши": ["притихнув"],
    "притихнувший": ["притихший"],
    "приткав": ["приткавши"],
    "приткавши": ["приткав"],
    "приткнув": ["приткнувши"],
    "приткнувши": ["приткнув"],
    "приток": ["прилив", "приход"],
    "притолкав": ["притолкавши"],
    "притолкавши": ["притолкав"],
    "притолкнув": ["притолкнувши"],
    "притолкнувши": ["притолкнув"],
    "притом": ["кроме того"],
    "притомив": ["притомивши"],
    "притомивши": ["притомив"],
    "притомить": ["утомить", "переутомить", "изнурить", "уморить", "умучить", "измотать", "вымотать", "измочалить", "измаять", "умаять", "наморить", "намаять", "затомить", "потомить", "протомить"],
    "притомляв": ["притомлявши"],
    "притомлявши": ["притомляв"],
    "притон": ["пристанище", "прибежище", "убежище", "приют", "пристань", "место сборища", "место сходбища", "вертеп"],
    "притонив": ["притонивши"],
    "притонивав": ["притонивавши"],
    "притонивавши": ["притонивав"],
    "притонивши": ["притонив"],
    "притоняв": ["притонявши"],
    "притонявши": ["притоняв"],
    "притоняться": ["притониваться"],
    "притопав": ["притопавши"],
    "притопавши": ["притопав"],
    "притопив": ["притопивши"],
    "притопивши": ["притопив"],
    "притопнув": ["притопнувши"],
    "притопнувши": ["притопнув"],
    "притоптав": ["притоптавши"],
    "притоптавши": ["притоптав"],
    "притоптывав": ["притоптывавши"],
    "притоптывавши": ["притоптывав"],
    "притоптыванье": ["притоптывание"],
    "притоптывать": ["притопывать"],
    "притопывав": ["притопывавши"],
    "притопывавши": ["притопывав"],
    "притопыванье": ["притопывание"],
    "притопывать": ["притоптывать"],
    "приторачивав": ["приторачивавши"],
    "приторачивавши": ["приторачивав"],
    "приторговав": ["приторговавши"],
    "приторговавши": ["приторговав"],
    "приторговывав": ["приторговывавши"],
    "приторговывавши": ["приторговывав"],
    "притормаживав": ["притормаживавши"],
    "притормаживавши": ["притормаживав"],
    "притормозив": ["притормозивши"],
    "притормозивши": ["притормозив"],
    "приторочив": ["приторочивши"],
    "приторочивши": ["приторочив"],
    "приторцевав": ["приторцевавши"],
    "приторцевавши": ["приторцевав"],
    "приторцовывав": ["приторцовывавши"],
    "приторцовывавши": ["приторцовывав"],
    "приточив": ["приточивши"],
    "приточивши": ["приточив"],
    "притравив": ["притравивши"],
    "притравивши": ["притравив"],
    "притравливав": ["притравливавши"],
    "притравливавши": ["притравливав"],
    "притравляв": ["притравлявши"],
    "притравлявши": ["притравляв"],
    "притрепав": ["притрепавши"],
    "притрепавши": ["притрепав"],
    "притрусив": ["притрусивши"],
    "притрусивши": ["притрусив"],
    "притрухивав": ["притрухивавши"],
    "притрухивавши": ["притрухивав"],
    "притрухнув": ["притрухнувши"],
    "притрухнувши": ["притрухнув"],
    "притрушивав": ["притрушивавши"],
    "притрушивавши": ["притрушивав"],
    "притряхивав": ["притряхивавши"],
    "притряхивавши": ["притряхивав"],
    "притряхнув": ["притряхнувши"],
    "притряхнувши": ["притряхнув"],
    "притужив": ["притуживши"],
    "притуживши": ["притужив"],
    "притужить": ["погоревать", "попечалиться", "потужить", "покручиниться", "пригорюниться"],
    "притузив": ["притузивши"],
    "притузивши": ["притузив"],
    "притузить": ["оттузить"],
    "притулив": ["притуливши"],
    "притуливши": ["притулив"],
    "притулиться": ["пристроиться", "приютиться"],
    "притуляв": ["притулявши"],
    "притулявши": ["притуляв"],
    "притуманив": ["притуманивши"],
    "притуманивши": ["притуманив"],
    "притупев": ["притупевши"],
    "притупевши": ["притупев"],
    "притупив": ["притупивши"],
    "притупивши": ["притупив"],
    "притупленный": ["притуплённый"],
    "притупляв": ["притуплявши"],
    "притуплявши": ["притупляв"],
    "притурка": ["приложение", "допълнение"],
    "притухав": ["притухавши"],
    "притухавши": ["притухав"],
    "притухнув": ["притухнувши"],
    "притухнувши": ["притухнув"],
    "притушив": ["притушивши"],
    "притушивав": ["притушивавши"],
    "притушивавши": ["притушивав"],
    "притушивши": ["притушив"],
    "притча": ["иносказание"],
    "притча во языцех": ["навязло в зубах"],
    "притыкав": ["притыкавши"],
    "притыкавши": ["притыкав"],
    "притягав": ["притягавши"],
    "притягавши": ["притягав"],
    "притягивав": ["притягивавши"],
    "притягивавши": ["притягивав"],
    "притяжательный падеж": ["посессив", "родительный приименной", "генитив"],
    "притяжка": ["притяжение"],
    "притязав": ["притязавши"],
    "притязавши": ["притязав"],
    "притязание": ["претензия"],
    "притязанье": ["притязание"],
    "притязательность": ["требовательность", "взыскательность"],
    "притязать": ["претендовать"],
    "притянув": ["притянувши"],
    "притянувши": ["притянув"],
    "притянуть за волосы": ["притянуть за уши"],
    "притянуть за уши": ["притянуть за волосы"],
    "притёрши": ["притерев"],
    "притёсывав": ["притёсывавши"],
    "притёсывавши": ["притёсывав"],
    "приубавив": ["приубавивши"],
    "приубавивши": ["приубавив"],
    "приубавляв": ["приубавлявши"],
    "приубавлявши": ["приубавляв"],
    "приубрав": ["приубравши"],
    "приубравши": ["приубрав"],
    "приугасав": ["приугасавши"],
    "приугасавши": ["приугасав"],
    "приугаснув": ["приугаснувши"],
    "приугаснувши": ["приугаснув"],
    "приуготавливав": ["приуготавливавши"],
    "приуготавливавши": ["приуготавливав"],
    "приуготовив": ["приуготовивши"],
    "приуготовивши": ["приуготовив"],
    "приуготовительный": ["подготовительный", "предварительный"],
    "приуготовляв": ["приуготовлявши"],
    "приуготовлявши": ["приуготовляв"],
    "приударив": ["приударивши"],
    "приударивав": ["приударивавши"],
    "приударивавши": ["приударивав"],
    "приударивши": ["приударив"],
    "приударяв": ["приударявши"],
    "приударявши": ["приударяв"],
    "приудержав": ["приудержавши"],
    "приудержавши": ["приудержав"],
    "приудерживав": ["приудерживавши"],
    "приудерживавши": ["приудерживав"],
    "приуз": ["гужик"],
    "приукрасив": ["приукрасивши"],
    "приукрасивши": ["приукрасив"],
    "приукрашав": ["приукрашавши"],
    "приукрашавши": ["приукрашав"],
    "приукрашивав": ["приукрашивавши"],
    "приукрашивавши": ["приукрашивав"],
    "приукрыв": ["приукрывши"],
    "приукрывав": ["приукрывавши"],
    "приукрывавши": ["приукрывав"],
    "приукрывши": ["приукрыв"],
    "приуменьшав": ["приуменьшавши"],
    "приуменьшавши": ["приуменьшав"],
    "приуменьшив": ["приуменьшивши"],
    "приуменьшивши": ["приуменьшив"],
    "приумножав": ["приумножавши"],
    "приумножавши": ["приумножав"],
    "приумножаться": ["умножаться"],
    "приумножив": ["приумноживши"],
    "приумноживши": ["приумножив"],
    "приумолкав": ["приумолкавши"],
    "приумолкавши": ["приумолкав"],
    "приумолкнув": ["приумолкнувши"],
    "приумолкнувши": ["приумолкнув"],
    "приумолкнуть": ["примолкнуть", "замолчать", "притихнуть"],
    "приумыв": ["приумывши"],
    "приумывши": ["приумыв"],
    "приумяв": ["приумявши"],
    "приумявши": ["приумяв"],
    "приуныв": ["приунывши"],
    "приунывав": ["приунывавши"],
    "приунывавши": ["приунывав"],
    "приунывши": ["приуныв"],
    "приуныть": ["загрустить", "опечалиться", "пригорюниться"],
    "приуроченность": ["отнесённость", "соотнесённость"],
    "приурочив": ["приурочивши"],
    "приурочивав": ["приурочивавши"],
    "приурочивавши": ["приурочивав"],
    "приурочивать": ["привязывать"],
    "приурочиваться": ["приноравливаться"],
    "приурочивши": ["приурочив"],
    "приуснув": ["приуснувши"],
    "приуснувши": ["приуснув"],
    "приустав": ["приуставши"],
    "приуставав": ["приустававши"],
    "приустававши": ["приуставав"],
    "приуставши": ["приустав"],
    "приутихав": ["приутихавши"],
    "приутихавши": ["приутихав"],
    "приутихнув": ["приутихнувши"],
    "приутихнувши": ["приутихнув"],
    "приутюжив": ["приутюживши"],
    "приутюживав": ["приутюживавши"],
    "приутюживавши": ["приутюживав"],
    "приутюживши": ["приутюжив"],
    "приучав": ["приучавши"],
    "приучавши": ["приучав"],
    "приучив": ["приучивши"],
    "приучивав": ["приучивавши"],
    "приучивавши": ["приучивав"],
    "приучивши": ["приучив"],
    "приучить": ["научить"],
    "приучиться": ["привыкнуть", "втянуться", "приохотиться", "пристраститься", "повадиться"],
    "прифабрив": ["прифабривши"],
    "прифабривав": ["прифабривавши"],
    "прифабривавши": ["прифабривав"],
    "прифабривши": ["прифабрив"],
    "прифальцевав": ["прифальцевавши"],
    "прифальцевавши": ["прифальцевав"],
    "прифальцовывав": ["прифальцовывавши"],
    "прифальцовывавши": ["прифальцовывав"],
    "прифотошопив": ["прифотошопивши"],
    "прифотошопивши": ["прифотошопив"],
    "прифрантив": ["прифрантивши"],
    "прифрантивши": ["прифрантив"],
    "прифранчивав": ["прифранчивавши"],
    "прифранчивавши": ["прифранчивав"],
    "прифуговав": ["прифуговавши"],
    "прифуговавши": ["прифуговав"],
    "прифуговывав": ["прифуговывавши"],
    "прифуговывавши": ["прифуговывав"],
    "прихаживав": ["прихаживавши"],
    "прихаживавши": ["прихаживав"],
    "прихвалив": ["прихваливши"],
    "прихваливав": ["прихваливавши"],
    "прихваливавши": ["прихваливав"],
    "прихваливши": ["прихвалив"],
    "прихварывав": ["прихварывавши"],
    "прихварывавши": ["прихварывав"],
    "прихвастнув": ["прихвастнувши"],
    "прихвастнувши": ["прихвастнув"],
    "прихвастывав": ["прихвастывавши"],
    "прихвастывавши": ["прихвастывав"],
    "прихватив": ["прихвативши"],
    "прихвативши": ["прихватив"],
    "прихватизировав": ["прихватизировавши"],
    "прихватизировавши": ["прихватизировав"],
    "прихватливост": ["инфекциозност", "прилепчивост", "заразност"],
    "прихватывав": ["прихватывавши"],
    "прихватывавши": ["прихватывав"],
    "прихворнув": ["прихворнувши"],
    "прихворнувши": ["прихворнув"],
    "прихвостень": ["шестёрка"],
    "прихвостничав": ["прихвостничавши"],
    "прихвостничавши": ["прихвостничав"],
    "прихилиться": ["затаиться", "притаиться", "схорониться", "спрятаться"],
    "прихиляв": ["прихилявши"],
    "прихилявши": ["прихиляв"],
    "прихлебатель": ["подхалим", "лизоблюд", "холуй", "нахлебник", "приживальщик", "паразит", "блюдолиз", "прихлебала", "приживала", "прикорытник"],
    "прихлебательство": ["дармоедство"],
    "прихлебательствовав": ["прихлебательствовавши"],
    "прихлебательствовавши": ["прихлебательствовав"],
    "прихлебнув": ["прихлебнувши"],
    "прихлебнувши": ["прихлебнув"],
    "прихлеснув": ["прихлеснувши"],
    "прихлеснувши": ["прихлеснув"],
    "прихлеснуть": ["подхлестнуть", "подстегнуть"],
    "прихлестнув": ["прихлестнувши"],
    "прихлестнувши": ["прихлестнув"],
    "прихлопнув": ["прихлопнувши"],
    "прихлопнувши": ["прихлопнув"],
    "прихлопывав": ["прихлопывавши"],
    "прихлопывавши": ["прихлопывав"],
    "прихлынув": ["прихлынувши"],
    "прихлынувши": ["прихлынув"],
    "прихлёбывав": ["прихлёбывавши"],
    "прихлёбывавши": ["прихлёбывав"],
    "прихлёбывать": ["попивать", "цедить", "посасывать", "потягивать"],
    "прихлёстывав": ["прихлёстывавши"],
    "прихлёстывавши": ["прихлёстывав"],
    "прихмурив": ["прихмуривши"],
    "прихмуривав": ["прихмуривавши"],
    "прихмуривавши": ["прихмуривав"],
    "прихмуривши": ["прихмурив"],
    "приходив": ["приходивши"],
    "приходивши": ["приходив"],
    "приходить в голову": ["приходить в мысль", "приходить на мысль"],
    "приходить в мысль": ["приходить в голову"],
    "приходовав": ["приходовавши"],
    "приходовавши": ["приходовав"],
    "прихожая": ["передняя", "лакейская"],
    "прихожка": ["прихожая"],
    "прихолив": ["прихоливши"],
    "прихоливав": ["прихоливавши"],
    "прихоливавши": ["прихоливав"],
    "прихоливши": ["прихолив"],
    "прихомутав": ["прихомутавши"],
    "прихомутавши": ["прихомутав"],
    "прихорашивав": ["прихорашивавши"],
    "прихорашивавши": ["прихорашивав"],
    "прихорашивать": ["украшать"],
    "прихорашиваться": ["украшаться", "приукрашиваться", "чистить пёрышки"],
    "прихоронив": ["прихоронивши"],
    "прихоронивши": ["прихоронив"],
    "прихотливый": ["капризный", "привередливый", "притязательный", "разборчивый", "причудливый", "затейливый"],
    "прихотничав": ["прихотничавши"],
    "прихотничавши": ["прихотничав"],
    "прихоть": ["каприз", "причуда"],
    "прихрамывав": ["прихрамывавши"],
    "прихрамывавши": ["прихрамывав"],
    "прихрамывать": ["ковылять", "хромать"],
    "прихромав": ["прихромавши"],
    "прихромавши": ["прихромав"],
    "прихуев": ["прихуевши"],
    "прихуевши": ["прихуев"],
    "прихуеть": ["обалдеть", "ошалеть", "офигеть", "охренеть", "охереть", "охуеть", "подхуеть", "подохуеть", "обнаглеть", "оборзеть", "охаметь", "очертеть", "сдуреть", "с ума сойти"],
    "прихуярив": ["прихуяривши"],
    "прихуяривав": ["прихуяривавши"],
    "прихуяривавши": ["прихуяривав"],
    "прихуяривши": ["прихуярив"],
    "прихуярить": ["пришпандорить"],
    "прицедив": ["прицедивши"],
    "прицедивши": ["прицедив"],
    "прицеживав": ["прицеживавши"],
    "прицеживавши": ["прицеживав"],
    "прицел": ["прицеливание"],
    "прицелив": ["прицеливши"],
    "прицеливав": ["прицеливавши"],
    "прицеливавши": ["прицеливав"],
    "прицеливаться": ["целиться", "метить"],
    "прицеливши": ["прицелив"],
    "приценив": ["приценивши"],
    "приценивание": ["приценка"],
    "приценивать": ["приценять"],
    "прицениваться": ["приценяться"],
    "приценивши": ["приценив"],
    "приценять": ["приценивать"],
    "приценяться": ["прицениваться"],
    "прицепив": ["прицепивши"],
    "прицепивши": ["прицепив"],
    "прицепляв": ["прицеплявши"],
    "прицеплявши": ["прицепляв"],
    "прицокивав": ["прицокивавши"],
    "прицокивавши": ["прицокивав"],
    "прицокнув": ["прицокнувши"],
    "прицокнувши": ["прицокнув"],
    "прицыганенный": ["цыгановатый"],
    "прицыкивав": ["прицыкивавши"],
    "прицыкивавши": ["прицыкивав"],
    "прицыкнув": ["прицыкнувши"],
    "прицыкнувши": ["прицыкнув"],
    "прич": ["причёска", "причесон", "стрижка", "укладка"],
    "прича": ["причёска"],
    "причал": ["причаливание", "пирс", "швартов"],
    "причалив": ["причаливши"],
    "причаливав": ["причаливавши"],
    "причаливавши": ["причаливав"],
    "причаливши": ["причалив"],
    "причапав": ["причапавши"],
    "причапавши": ["причапав"],
    "причаровав": ["причаровавши"],
    "причаровавши": ["причаровав"],
    "причаровывав": ["причаровывавши"],
    "причаровывавши": ["причаровывав"],
    "причастив": ["причастивши"],
    "причастивши": ["причастив"],
    "причастие": ["причащение", "евхаристия", "причастность"],
    "причастить": ["приобщить", "присоединить"],
    "причастность": ["касательство", "вовлечённость"],
    "причастный": ["соучастный", "сопричастный"],
    "причастье": ["причастие"],
    "причащав": ["причащавши"],
    "причащавши": ["причащав"],
    "причащение": ["причастие"],
    "причащенье": ["причащение"],
    "причерноморье": ["циркумпонтида"],
    "причертив": ["причертивши"],
    "причертивши": ["причертив"],
    "причерчивав": ["причерчивавши"],
    "причерчивавши": ["причерчивав"],
    "причесав": ["причесавши"],
    "причесавши": ["причесав"],
    "причесать": ["расчесать", "уложить"],
    "причесон": ["причёска", "прича"],
    "причет": ["причитание", "причитанье", "причёт"],
    "причетник": ["церковнослужитель"],
    "причетничествовав": ["причетничествовавши"],
    "причетничествовавши": ["причетничествовав"],
    "причинав": ["причинавши"],
    "причинавши": ["причинав"],
    "причиндал": ["принадлежность"],
    "причинив": ["причинивши"],
    "причинивши": ["причинив"],
    "причинно-следственный": ["каузальный"],
    "причинность": ["каузальность"],
    "причинный": ["каузальный"],
    "причиняв": ["причинявши"],
    "причинявши": ["причиняв"],
    "причинять": ["вызывать", "каузировать", "порождать", "доставлять"],
    "причислив": ["причисливши"],
    "причисливши": ["причислив"],
    "причисляв": ["причислявши"],
    "причислявши": ["причисляв"],
    "причитав": ["причитавши"],
    "причитавши": ["причитав"],
    "причитальщица": ["вопленица", "плакальщица"],
    "причитание": ["жалоба", "плач"],
    "причитанье": ["причитание"],
    "причитаться": ["полагаться"],
    "причитывав": ["причитывавши"],
    "причитывавши": ["причитывав"],
    "причитыванье": ["причитывание"],
    "причленив": ["причленивши"],
    "причленивши": ["причленив"],
    "причленяв": ["причленявши"],
    "причленявши": ["причленяв"],
    "причмокивав": ["причмокивавши"],
    "причмокивавши": ["причмокивав"],
    "причмокиванье": ["причмокивание"],
    "причмокнув": ["причмокнувши"],
    "причмокнувши": ["причмокнув"],
    "причт": ["причет", "клир"],
    "причудиться": ["примерещиться", "померещиться", "почудиться"],
    "причудливо": ["замысловато", "затейливо", "необычно"],
    "причудливость": ["затейливость", "замысловатость", "вычурность", "прихотливость", "мудрёность", "фантасмагоричность", "оригинальность", "самобытность", "необыкновенность", "сложность", "хитроумность", "цветистость", "витиеватость"],
    "причудливый": ["необычный", "чудной", "замысловатый", "странный"],
    "причудница": ["чудачка"],
    "причудничав": ["причудничавши"],
    "причудничавши": ["причудничав"],
    "причуивав": ["причуивавши"],
    "причуивавши": ["причуивав"],
    "причуяв": ["причуявши"],
    "причуявши": ["причуяв"],
    "причём": ["при этом", "да и", "вместе с тем", "к тому же", "при чём"],
    "причёсанный": ["приглаженный", "упорядоченный", "ровный"],
    "причёска": ["причёсывание", "расчёсывание", "причесон", "стрижка", "хайр", "куафюр", "куафюра"],
    "причёсывав": ["причёсывавши"],
    "причёсывавши": ["причёсывав"],
    "причёсываться": ["расчёсываться"],
    "пришабрив": ["пришабривши"],
    "пришабривав": ["пришабривавши"],
    "пришабривавши": ["пришабривав"],
    "пришабривши": ["пришабрив"],
    "пришагав": ["пришагавши"],
    "пришагавши": ["пришагав"],
    "пришаливав": ["пришаливавши"],
    "пришаливавши": ["пришаливав"],
    "пришамкивав": ["пришамкивавши"],
    "пришамкивавши": ["пришамкивав"],
    "пришаркивав": ["пришаркивавши"],
    "пришаркивавши": ["пришаркивав"],
    "пришаркнув": ["пришаркнувши"],
    "пришаркнувши": ["пришаркнув"],
    "пришвартовав": ["пришвартовавши"],
    "пришвартовавши": ["пришвартовав"],
    "пришвартовывав": ["пришвартовывавши"],
    "пришвартовывавши": ["пришвартовывав"],
    "пришвартовывать": ["швартовать"],
    "пришвартовываться": ["швартоваться"],
    "пришвидшення": ["прискорення"],
    "пришед": ["пришедши", "придя"],
    "пришедши": ["придя", "пришед"],
    "пришелец": ["переселенец", "выходец", "приезжий", "пришлец", "инопланетянин", "инопланетный пришелец", "алиен"],
    "пришепётывав": ["пришепётывавши"],
    "пришепётывавши": ["пришепётывав"],
    "пришепётывать": ["шепелявить"],
    "пришествие": ["приход"],
    "пришибав": ["пришибавши"],
    "пришибавши": ["пришибав"],
    "пришибив": ["пришибивши"],
    "пришибивши": ["пришибив"],
    "пришибленность": ["угнетённость", "придавленность"],
    "пришив": ["пришивши"],
    "пришивав": ["пришивавши"],
    "пришивавши": ["пришивав"],
    "пришивши": ["пришив"],
    "пришипиться": ["притаиться", "присмиреть", "затаиться", "притихнуть"],
    "пришкандыбав": ["пришкандыбавши"],
    "пришкандыбавши": ["пришкандыбав"],
    "пришлифовав": ["пришлифовавши"],
    "пришлифовавши": ["пришлифовав"],
    "пришлифовывав": ["пришлифовывавши"],
    "пришлифовывавши": ["пришлифовывав"],
    "пришлый": ["пришелец"],
    "пришлёпав": ["пришлёпавши"],
    "пришлёпавши": ["пришлёпав"],
    "пришлёпнув": ["пришлёпнувши"],
    "пришлёпнувши": ["пришлёпнув"],
    "пришлёпнуть": ["всплеснуть"],
    "пришлёпывав": ["пришлёпывавши"],
    "пришлёпывавши": ["пришлёпывав"],
    "пришпандорив": ["пришпандоривши"],
    "пришпандоривав": ["пришпандоривавши"],
    "пришпандоривавши": ["пришпандоривав"],
    "пришпандоривши": ["пришпандорив"],
    "пришпандорить": ["присобачить", "подстегнуть"],
    "пришпилив": ["пришпиливши"],
    "пришпиливав": ["пришпиливавши"],
    "пришпиливавши": ["пришпиливав"],
    "пришпиливши": ["пришпилив"],
    "пришпорив": ["пришпоривши"],
    "пришпоривав": ["пришпоривавши"],
    "пришпоривавши": ["пришпоривав"],
    "пришпоривши": ["пришпорив"],
    "приштуковав": ["приштуковавши"],
    "приштуковавши": ["приштуковав"],
    "приштуковывав": ["приштуковывавши"],
    "приштуковывавши": ["приштуковывав"],
    "пришёптывав": ["пришёптывавши"],
    "пришёптывавши": ["пришёптывав"],
    "прищелкнув": ["прищелкнувши"],
    "прищелкнувши": ["прищелкнув"],
    "прищемив": ["прищемивши"],
    "прищемивши": ["прищемив"],
    "прищемляв": ["прищемлявши"],
    "прищемлявши": ["прищемляв"],
    "прищепив": ["прищепивши"],
    "прищепивши": ["прищепив"],
    "прищепка": ["защепка"],
    "прищепляв": ["прищеплявши"],
    "прищеплявши": ["прищепляв"],
    "прищипнув": ["прищипнувши"],
    "прищипнувши": ["прищипнув"],
    "прищипывав": ["прищипывавши"],
    "прищипывавши": ["прищипывав"],
    "прищипывание": ["пикировка"],
    "прищипывать": ["пощипывать"],
    "прищур": ["прищуривание"],
    "прищурив": ["прищуривши"],
    "прищуривав": ["прищуривавши"],
    "прищуривавши": ["прищуривав"],
    "прищуривши": ["прищурив"],
    "прищучив": ["прищучивши"],
    "прищучивав": ["прищучивавши"],
    "прищучивавши": ["прищучивав"],
    "прищучивши": ["прищучив"],
    "прищучить": ["прижать"],
    "прищёлкивав": ["прищёлкивавши"],
    "прищёлкивавши": ["прищёлкивав"],
    "прищёлкнув": ["прищёлкнувши"],
    "прищёлкнувши": ["прищёлкнув"],
    "приют": ["убежище", "прибежище", "пристанище", "угол", "обиталище", "обитель", "кров", "крыша над головой"],
    "приютив": ["приютивши"],
    "приютивши": ["приютив"],
    "приютить": ["дать приют"],
    "приючав": ["приючавши"],
    "приючавши": ["приючав"],
    "прияв": ["приявши"],
    "приявши": ["прияв"],
    "приявший": ["принявший"],
    "приязний": ["доброзичливий", "приятельський"],
    "приязнь": ["благосклонность", "доброжелательство", "расположение", "симпатия"],
    "приямок": ["заглубление", "углубление"],
    "приятелство": ["дружба"],
    "приятель": ["знакомец", "товарищ", "знакомый"],
    "приятельница": ["подруга", "подружка", "другиня", "товарка"],
    "приятельствовав": ["приятельствовавши"],
    "приятельствовавши": ["приятельствовав"],
    "приятие": ["признание"],
    "приятность": ["привлекательность", "очаровательность", "симпатичность", "удовольствие"],
    "приятный": ["милый", "миловидный", "замечательный", "привлекательный", "притягательный", "симпатичный"],
    "приятствовав": ["приятствовавши"],
    "приятствовавши": ["приятствовав"],
    "приять": ["принять"],
    "приятье": ["приятие"],
    "приёбываться": ["надоедать", "докапываться", "доколупываться", "цепляться"],
    "приём": ["получение", "подход", "раз", "действие", "техника", "способ", "хитрость", "торжество", "праздник", "обращение"],
    "приёмистый": ["чуткий", "отзывчивый", "динамичный", "гостеприимный"],
    "приёмник": ["радиоприёмник"],
    "приёмник-распределитель": ["спецприёмник"],
    "приёмопередатчик": ["трансивер"],
    "приёмыш": ["приёмный", "воспитанник", "вскормленник", "выкормок", "выкормыш"],
    "про": ["касательно", "относительно", "для", "на"],
    "про запас": ["на чёрный день", "на случай", "на всякий случай", "впрок"],
    "про пизду ни слова": ["о пизде ни слова"],
    "проаккомпанировав": ["проаккомпанировавши"],
    "проаккомпанировавши": ["проаккомпанировав"],
    "проактивный": ["упреждающий", "превентивный"],
    "проанализировав": ["проанализировавши"],
    "проанализировавши": ["проанализировав"],
    "проанатомировав": ["проанатомировавши"],
    "проанатомировавши": ["проанатомировав"],
    "проанкетировав": ["проанкетировавши"],
    "проанкетировавши": ["проанкетировав"],
    "проаннотировав": ["проаннотировавши"],
    "проаннотировавши": ["проаннотировав"],
    "проанонсировав": ["проанонсировавши"],
    "проанонсировавши": ["проанонсировав"],
    "проантоцианидин": ["процианидин"],
    "проапгрейдив": ["проапгрейдивши"],
    "проапгрейдивши": ["проапгрейдив"],
    "проапгрейдить": ["прокачать"],
    "проахав": ["проахавши"],
    "проахавши": ["проахав"],
    "проба": ["испытание", "проверка", "пробирование"],
    "проба пера": ["первый опыт", "первые шаги", "дебют"],
    "пробавив": ["пробавивши"],
    "пробавивши": ["пробавив"],
    "пробавляв": ["пробавлявши"],
    "пробавлявши": ["пробавляв"],
    "пробавляться": ["кормиться", "довольствоваться", "обходиться", "заниматься", "коротать"],
    "пробалагурив": ["пробалагуривши"],
    "пробалагуривши": ["пробалагурив"],
    "пробалансировав": ["пробалансировавши"],
    "пробалансировавши": ["пробалансировав"],
    "пробаллотировав": ["пробаллотировавши"],
    "пробаллотировавши": ["пробаллотировав"],
    "пробалтывав": ["пробалтывавши"],
    "пробалтывавши": ["пробалтывав"],
    "пробалтываться": ["проговариваться"],
    "пробанив": ["пробанивши"],
    "пробанивав": ["пробанивавши"],
    "пробанивавши": ["пробанивав"],
    "пробанивши": ["пробанив"],
    "пробарабанив": ["пробарабанивши"],
    "пробарабанивши": ["пробарабанив"],
    "пробасив": ["пробасивши"],
    "пробасивши": ["пробасив"],
    "пробастовав": ["пробастовавши"],
    "пробастовавши": ["пробастовав"],
    "пробатрачив": ["пробатрачивши"],
    "пробатрачивши": ["пробатрачив"],
    "пробачення": ["вибачення"],
    "пробдев": ["пробдевши"],
    "пробдевши": ["пробдев"],
    "пробдеть": ["просмотреть", "пропустить", "прошляпить", "просрать", "профукать", "упустить"],
    "пробег": ["пробегание", "торможение"],
    "пробегав": ["пробегавши"],
    "пробегавши": ["пробегав"],
    "пробедствовав": ["пробедствовавши"],
    "пробедствовавши": ["пробедствовав"],
    "пробежав": ["пробежавши"],
    "пробежавши": ["пробежав"],
    "пробездельничав": ["пробездельничавши"],
    "пробездельничавши": ["пробездельничав"],
    "пробел": ["промежуток", "просвет", "дыра", "дырка", "разрыв", "зазор", "упущение", "дефект", "недоработка", "незавершённость", "пробельный элемент"],
    "пробелив": ["пробеливши"],
    "пробеливав": ["пробеливавши"],
    "пробеливавши": ["пробеливав"],
    "пробеливание": ["выбеливание"],
    "пробеливши": ["пробелив"],
    "пробеседовав": ["пробеседовавши"],
    "пробеседовавши": ["пробеседовав"],
    "пробздеть": ["пробояться", "проссать", "просрать", "профукать"],
    "пробздеться": ["прогуляться", "пройтись", "подышать воздухом"],
    "пробив": ["пробивка"],
    "пробивав": ["пробивавши"],
    "пробивавши": ["пробивав"],
    "пробивать": ["вычислять", "выяснять", "проверять", "узнавать"],
    "пробивши": ["пробив"],
    "пробирав": ["пробиравши"],
    "пробиравши": ["пробирав"],
    "пробирный камень": ["пробный камень", "лидийский камень", "лидит"],
    "пробировав": ["пробировавши"],
    "пробировавши": ["пробировав"],
    "пробитие": ["пробивание", "пробой"],
    "пробить": ["вычислить", "выяснить", "проверить", "узнать"],
    "пробитье": ["пробитие"],
    "пробка": ["затор", "предохранитель", "дюбель"],
    "пробковое дерево": ["бархатное дерево", "бархат амурский", "феллодендрон амурский"],
    "проблема": ["задача", "вопрос", "затруднение", "препятствие", "трабл"],
    "проблематизировав": ["проблематизировавши"],
    "проблематизировавши": ["проблематизировав"],
    "проблематизировать": ["проблематизовать"],
    "проблематизовав": ["проблематизовавши"],
    "проблематизовавши": ["проблематизовав"],
    "проблематизовать": ["проблематизировать"],
    "проблематичный": ["проблематический", "маловероятный", "сомнительный"],
    "проблемист": ["композитор"],
    "проблемно": ["проблематично", "хлопотно"],
    "проблеск": ["вспышка", "просвет", "намёк", "предзнаменование"],
    "проблескивав": ["проблескивавши"],
    "проблескивавши": ["проблескивав"],
    "проблесковый маячок": ["мигалка"],
    "проблеснув": ["проблеснувши"],
    "проблеснувши": ["проблеснув"],
    "проблестев": ["проблестевши"],
    "проблестевши": ["проблестев"],
    "проблеяв": ["проблеявши"],
    "проблеявши": ["проблеяв"],
    "проблистав": ["проблиставши"],
    "проблиставши": ["проблистав"],
    "проблудив": ["проблудивши"],
    "проблудивши": ["проблудив"],
    "проблуждав": ["проблуждавши"],
    "проблуждавши": ["проблуждав"],
    "проблёскивав": ["проблёскивавши"],
    "проблёскивавши": ["проблёскивав"],
    "пробный камень": ["пробирный камень", "лидийский камень", "лидит", "лакмусовая бумажка"],
    "пробный шар": ["зонд", "попытка"],
    "пробовав": ["пробовавши"],
    "пробовавши": ["пробовав"],
    "пробовать": ["пытаться", "стараться", "силиться", "испытывать", "примерять", "проверять", "опробовать", "тестировать", "отведывать", "дегустировать"],
    "прободав": ["прободавши"],
    "прободавши": ["прободав"],
    "прободение": ["перфорация", "прободнение"],
    "прободрствовав": ["прободрствовавши"],
    "прободрствовавши": ["прободрствовав"],
    "пробой": ["пробивание", "пробив", "пробивка", "пробитие", "пробойка", "проламывание", "пролом", "прорывание", "прорыв", "электрический пробой", "проушина", "пробоина", "пробойник"],
    "пробойник": ["бородок", "шлямбур"],
    "проболев": ["проболевши"],
    "проболевши": ["проболев"],
    "проболтав": ["проболтавши"],
    "проболтавши": ["проболтав"],
    "проболтаться": ["проговориться", "проболтнуться"],
    "пробомбив": ["пробомбивши"],
    "пробомбивши": ["пробомбив"],
    "проборанивав": ["проборанивавши"],
    "проборанивавши": ["проборанивав"],
    "пробормотав": ["пробормотавши"],
    "пробормотавши": ["пробормотав"],
    "пробормотать": ["буркнуть"],
    "пробороздив": ["пробороздивши"],
    "пробороздивши": ["пробороздив"],
    "проборонив": ["проборонивши"],
    "проборонивши": ["проборонив"],
    "пробороновав": ["пробороновавши"],
    "пробороновавши": ["пробороновав"],
    "пробочник": ["штопор", "открывашка", "купор"],
    "пробрав": ["пробравши"],
    "пробравши": ["пробрав"],
    "пробрасывав": ["пробрасывавши"],
    "пробрасывавши": ["пробрасывав"],
    "пробраться": ["прокрасться"],
    "пробредив": ["пробредивши"],
    "пробредивши": ["пробредив"],
    "пробрезжив": ["пробрезживши"],
    "пробрезживши": ["пробрезжив"],
    "пробренчав": ["пробренчавши"],
    "пробренчавши": ["пробренчав"],
    "пробренькав": ["пробренькавши"],
    "пробренькавши": ["пробренькав"],
    "пробрести": ["проплестись"],
    "пробрехав": ["пробрехавши"],
    "пробрехавши": ["пробрехав"],
    "пробрив": ["пробривши"],
    "пробривав": ["пробривавши"],
    "пробривавши": ["пробривав"],
    "пробривши": ["пробрив"],
    "пробродив": ["пробродивши"],
    "пробродивши": ["пробродив"],
    "пробродяжничав": ["пробродяжничавши"],
    "пробродяжничавши": ["пробродяжничав"],
    "пробросав": ["пробросавши"],
    "пробросавши": ["пробросав"],
    "пробросив": ["пробросивши"],
    "пробросивши": ["пробросив"],
    "пробрызгивав": ["пробрызгивавши"],
    "пробрызгивавши": ["пробрызгивав"],
    "пробрызнув": ["пробрызнувши"],
    "пробрызнувши": ["пробрызнув"],
    "пробрюзжав": ["пробрюзжавши"],
    "пробрюзжавши": ["пробрюзжав"],
    "пробряцав": ["пробряцавши"],
    "пробряцавши": ["пробряцав"],
    "пробу ставить негде": ["пробы негде ставить", "пробу ставить некуда", "прожжённый"],
    "пробубнив": ["пробубнивши"],
    "пробубнивши": ["пробубнив"],
    "пробубниться": ["проиграться", "пробубениться", "продуться", "промотаться", "профершпилиться"],
    "пробудив": ["пробудивши"],
    "пробудивши": ["пробудив"],
    "пробудиться": ["проснуться", "ожить", "оживиться"],
    "пробуждав": ["пробуждавши"],
    "пробуждавши": ["пробуждав"],
    "пробуждаться": ["просыпаться"],
    "пробуждение": ["просыпание"],
    "пробужденье": ["пробуждение"],
    "пробуксировав": ["пробуксировавши"],
    "пробуксировавши": ["пробуксировав"],
    "пробуксовав": ["пробуксовавши"],
    "пробуксовавши": ["пробуксовав"],
    "пробуксовывав": ["пробуксовывавши"],
    "пробуксовывавши": ["пробуксовывав"],
    "пробуксовывать": ["буксовать", "стопориться"],
    "пробулькивав": ["пробулькивавши"],
    "пробулькивавши": ["пробулькивав"],
    "пробулькиватель": ["барботёр"],
    "пробуравив": ["пробуравивши"],
    "пробуравивши": ["пробуравив"],
    "пробуравливав": ["пробуравливавши"],
    "пробуравливавши": ["пробуравливав"],
    "пробуравливать": ["буравить", "дырявить"],
    "пробурив": ["пробуривши"],
    "пробуривав": ["пробуривавши"],
    "пробуривавши": ["пробуривав"],
    "пробуривши": ["пробурив"],
    "пробуркувати": ["пробуджувати"],
    "пробурлив": ["пробурливши"],
    "пробурливши": ["пробурлив"],
    "пробурчав": ["пробурчавши"],
    "пробурчавши": ["пробурчав"],
    "пробухав": ["пробухавши"],
    "пробухавши": ["пробухав"],
    "пробушевав": ["пробушевавши"],
    "пробушевавши": ["пробушевав"],
    "пробуянив": ["пробуянивши"],
    "пробуянивши": ["пробуянив"],
    "пробыв": ["пробывши"],
    "пробывав": ["пробывавши"],
    "пробывавши": ["пробывав"],
    "пробывать": ["пребывать", "находиться", "быть"],
    "пробывши": ["пробыв"],
    "пробюллетенив": ["пробюллетенивши"],
    "пробюллетенивши": ["пробюллетенив"],
    "пробюллетенить": ["проболеть"],
    "провадити": ["проводити"],
    "проваживав": ["проваживавши"],
    "проваживавши": ["проваживав"],
    "провайдер": ["интернет-провайдер"],
    "провал": ["проваливание", "яма", "дыра", "отключка"],
    "провал его возьми": ["чёрт возьми", "чёрт побери"],
    "проваландав": ["проваландавши"],
    "проваландавши": ["проваландав"],
    "проваландать": ["прошататься", "пробаклушить"],
    "проваландаться": ["провозиться"],
    "провалив": ["проваливши"],
    "проваливав": ["проваливавши"],
    "проваливавши": ["проваливав"],
    "проваливши": ["провалив"],
    "провалить": ["завалить"],
    "провальсировав": ["провальсировавши"],
    "провальсировавши": ["провальсировав"],
    "проваляв": ["провалявши"],
    "провалявши": ["проваляв"],
    "провансалец": ["провансал"],
    "провансальский": ["прованский"],
    "провансальский язык": ["окситанский язык"],
    "прованский": ["провансальский"],
    "проварив": ["проваривши"],
    "проваривав": ["проваривавши"],
    "проваривавши": ["проваривав"],
    "проваривши": ["проварив"],
    "провафлив": ["провафливши"],
    "провафливши": ["провафлив"],
    "провафлить": ["упустить", "проморгать", "прошляпить"],
    "проващивав": ["проващивавши"],
    "проващивавши": ["проващивав"],
    "провевав": ["провевавши"],
    "провевавши": ["провевав"],
    "провевать": ["веять", "провеивать"],
    "провеваться": ["провеиваться"],
    "проведав": ["проведавши"],
    "проведавши": ["проведав"],
    "проведать": ["навестить", "посетить", "наведаться", "дознаться", "разузнать", "прознать", "доведать", "вызнать", "дознать", "выведать", "разведать", "доведаться"],
    "проведенье": ["проведение"],
    "проведывав": ["проведывавши"],
    "проведывавши": ["проведывав"],
    "провезя": ["провёзши"],
    "провеивав": ["провеивавши"],
    "провеивавши": ["провеивав"],
    "провеивать": ["веять", "провевать"],
    "провеличав": ["провеличавши"],
    "провеличавши": ["провеличав"],
    "провеличать": ["прославить"],
    "провениенция": ["происхождение"],
    "провентилировав": ["провентилировавши"],
    "провентилировавши": ["провентилировав"],
    "провентилировать": ["продуть", "проветрить", "разобраться", "выяснить"],
    "проверещав": ["проверещавши"],
    "проверещавши": ["проверещав"],
    "проверив": ["проверивши"],
    "проверивши": ["проверив"],
    "проверить": ["проконтролировать", "обследовать", "опробовать", "испытать"],
    "проверка боем": ["стресс-тест", "проверка на прочность", "боевое крещение"],
    "провернув": ["провернувши"],
    "провернувши": ["провернув"],
    "провертев": ["провертевши"],
    "провертевши": ["провертев"],
    "проверчивав": ["проверчивавши"],
    "проверчивавши": ["проверчивав"],
    "проверщик": ["проверяльщик"],
    "проверяв": ["проверявши"],
    "проверявши": ["проверяв"],
    "проверяться": ["обследоваться"],
    "провесив": ["провесивши"],
    "провесивши": ["провесив"],
    "провесить": ["недовесить", "провялить", "завялить"],
    "провесна": ["провесень"],
    "провести": ["сопроводить", "проводить", "обозначить", "начертить", "определить", "осуществить", "обмануть", "перехитрить"],
    "провести время": ["отмотать", "прокантоваться", "перекантоваться", "прособачиться"],
    "провести на бобах": ["одурачить"],
    "проветрив": ["проветривши"],
    "проветривав": ["проветривавши"],
    "проветривавши": ["проветривав"],
    "проветривание": ["проветриванье"],
    "проветриванье": ["проветривание"],
    "проветривши": ["проветрив"],
    "провешив": ["провешивши"],
    "провешивав": ["провешивавши"],
    "провешивавши": ["провешивав"],
    "провешивать": ["вялить", "завяливать", "провяливать", "обвешивать"],
    "провешиваться": ["вялиться", "завяливаться", "провяливаться", "обвешиваться", "провисать"],
    "провешивши": ["провешив"],
    "провещав": ["провещавши"],
    "провещавши": ["провещав"],
    "провеяв": ["провеявши"],
    "провеявши": ["провеяв"],
    "провзаимодействовав": ["провзаимодействовавши"],
    "провзаимодействовавши": ["провзаимодействовав"],
    "провздыхав": ["провздыхавши"],
    "провздыхавши": ["провздыхав"],
    "провиант": ["продовольствие", "провизия"],
    "провибрировав": ["провибрировавши"],
    "провибрировавши": ["провибрировав"],
    "провидев": ["провидевши"],
    "провидевши": ["провидев"],
    "провидение": ["предвидение"],
    "провиденциализм": ["предопределённость"],
    "провиденциальный": ["предопределённый", "неизбежный", "роковой"],
    "провидческий": ["пророческий"],
    "провидящий": ["прозорливый"],
    "провизжав": ["провизжавши"],
    "провизжавши": ["провизжав"],
    "провизорша": ["аптекарша"],
    "провинтив": ["провинтивши"],
    "провинтивши": ["провинтив"],
    "провинциал": ["деревня"],
    "провинциализм": ["диалектизм", "локализм", "регионализм"],
    "провинциальный": ["деревенский", "сельский", "отсталый"],
    "провинция": ["село", "деревня"],
    "провинчивав": ["провинчивавши"],
    "провинчивавши": ["провинчивав"],
    "провисав": ["провисавши"],
    "провисавши": ["провисав"],
    "провисев": ["провисевши"],
    "провисевши": ["провисев"],
    "провиснув": ["провиснувши"],
    "провиснувши": ["провиснув"],
    "провод": ["проводка", "электропроводка", "электропровод"],
    "проводив": ["проводивши"],
    "проводивши": ["проводив"],
    "проводины": ["проводы"],
    "проводить": ["водить", "вести", "сопровождать", "прогуливать"],
    "проводник": ["гид", "пропонент", "адепт", "последователь"],
    "проводок": ["провод"],
    "проводы": ["проводины", "провожаны"],
    "провоевав": ["провоевавши"],
    "провоевавши": ["провоевав"],
    "провожав": ["провожавши"],
    "провожавши": ["провожав"],
    "провожаны": ["проводы"],
    "провожанье": ["провожание"],
    "провождав": ["провождавши"],
    "провождавши": ["провождав"],
    "провожжаться": ["проканителиться", "провозиться"],
    "провозвестив": ["провозвестивши"],
    "провозвестивши": ["провозвестив"],
    "провозвестие": ["предвещение", "предвозвестие", "предвозвещение", "предвестие"],
    "провозвестник": ["предвестник", "предвещатель", "предсказатель"],
    "провозвестница": ["предвестница", "предсказательница"],
    "провозвестье": ["провозвестие"],
    "провозвещав": ["провозвещавши"],
    "провозвещавши": ["провозвещав"],
    "провозгласив": ["провозгласивши"],
    "провозгласивши": ["провозгласив"],
    "провозглашав": ["провозглашавши"],
    "провозглашавши": ["провозглашав"],
    "провозглашенье": ["провозглашение"],
    "провозив": ["провозивши"],
    "провозивши": ["провозив"],
    "провокатор": ["доносчик", "стукач", "наседка", "подстрекатель", "тролль", "интернет-тролль"],
    "провокационный": ["провоцирующий", "подстрекающий", "вызывающий"],
    "провокация": ["апелляция"],
    "провокировав": ["провокировавши"],
    "провокировавши": ["провокировав"],
    "проволакивав": ["проволакивавши"],
    "проволакивавши": ["проволакивав"],
    "проволока": ["проволочка"],
    "проволочив": ["проволочивши"],
    "проволочивши": ["проволочив"],
    "проволынив": ["проволынивши"],
    "проволынивши": ["проволынив"],
    "проволынить": ["проканителить"],
    "проволыниться": ["проканителиться"],
    "провоняв": ["провонявши"],
    "провонявши": ["провоняв"],
    "провонялый": ["завоненный", "завонялый", "провонявший", "пропитанный", "неприятным", "запах", "затхлый", "тухлый", "вонючий", "зловонный", "смердящий", "дурно", "пахнущий"],
    "провопив": ["провопивши"],
    "провопивши": ["провопив"],
    "проворачивав": ["проворачивавши"],
    "проворачивавши": ["проворачивав"],
    "проворачивать": ["просверливать", "провёртывать", "прокручивать", "поворачивать"],
    "проворив": ["проворивши"],
    "проворивши": ["проворив"],
    "провориться": ["спориться", "удаваться"],
    "проворковав": ["проворковавши"],
    "проворковавши": ["проворковав"],
    "проворно": ["ловко"],
    "проворный": ["быстрый", "стремительный", "резвый", "расторопный"],
    "проворожив": ["провороживши"],
    "провороживши": ["проворожив"],
    "проворонив": ["проворонивши"],
    "проворонивав": ["проворонивавши"],
    "проворонивавши": ["проворонивав"],
    "проворонивать": ["прозёвывать"],
    "проворонивши": ["проворонив"],
    "проворонить": ["прошляпить", "прозевать", "проморгать", "пропустить"],
    "проворотив": ["проворотивши"],
    "проворотивши": ["проворотив"],
    "проворочав": ["проворочавши"],
    "проворочавши": ["проворочав"],
    "проворство": ["проворность", "расторопность", "прыть", "прыткость", "сноровка"],
    "проворчав": ["проворчавши"],
    "проворчавши": ["проворчав"],
    "провоцировав": ["провоцировавши"],
    "провоцировавши": ["провоцировав"],
    "провоцировать": ["подстрекать"],
    "провощив": ["провощивши"],
    "провощивши": ["провощив"],
    "провоёвывав": ["провоёвывавши"],
    "провоёвывавши": ["провоёвывав"],
    "проврав": ["провравши"],
    "провравши": ["проврав"],
    "провтыкать": ["пропустить", "проворонить", "прошляпить", "проебать"],
    "провыв": ["провывши"],
    "провывши": ["провыв"],
    "провязав": ["провязавши"],
    "провязавши": ["провязав"],
    "провязывав": ["провязывавши"],
    "провязывавши": ["провязывав"],
    "провялив": ["провяливши"],
    "провяливав": ["провяливавши"],
    "провяливавши": ["провяливав"],
    "провяливши": ["провялив"],
    "провянув": ["провянувши"],
    "провянувши": ["провянув"],
    "провёзши": ["провезя"],
    "провёртывав": ["провёртывавши"],
    "провёртывавши": ["провёртывав"],
    "прог": ["прогрессивный рок"],
    "прог-рок": ["прогрессивный рок"],
    "прога": ["компьютерная программа"],
    "прогавкав": ["прогавкавши"],
    "прогавкавши": ["прогавкав"],
    "прогавкать": ["пролаять", "протявкать"],
    "прогадав": ["прогадавши"],
    "прогадавши": ["прогадав"],
    "прогадывав": ["прогадывавши"],
    "прогадывавши": ["прогадывав"],
    "прогал": ["прогалина", "просвет"],
    "прогалина": ["междулесье", "перелесье", "пролесок"],
    "прогалок": ["прогалина"],
    "прогалопировав": ["прогалопировавши"],
    "прогалопировавши": ["прогалопировав"],
    "прогар": ["прогорание"],
    "прогарцевав": ["прогарцевавши"],
    "прогарцевавши": ["прогарцевав"],
    "прогащивав": ["прогащивавши"],
    "прогащивавши": ["прогащивав"],
    "прогестеронный": ["прогестероновый"],
    "прогестероновый": ["прогестеронный"],
    "прогибав": ["прогибавши"],
    "прогибавши": ["прогибав"],
    "прогибать": ["выгибать"],
    "проглаголав": ["проглаголавши"],
    "проглаголавши": ["проглаголав"],
    "прогладив": ["прогладивши"],
    "прогладивши": ["прогладив"],
    "прогладывав": ["прогладывавши"],
    "прогладывавши": ["прогладывав"],
    "проглаживав": ["проглаживавши"],
    "проглаживавши": ["проглаживав"],
    "проглазев": ["проглазевши"],
    "проглазевши": ["проглазев"],
    "проглатывав": ["проглатывавши"],
    "проглатывавши": ["проглатывав"],
    "проглодав": ["проглодавши"],
    "проглодавши": ["проглодав"],
    "проглот": ["кишкамёт"],
    "проглотив": ["проглотивши"],
    "проглотивши": ["проглотив"],
    "проглотить": ["заглотнуть"],
    "проглядев": ["проглядевши"],
    "проглядевши": ["проглядев"],
    "проглядеть": ["просмотреть", "пропустить", "упустить"],
    "проглядывав": ["проглядывавши"],
    "проглядывавши": ["проглядывав"],
    "проглядываться": ["просматриваться"],
    "проглянув": ["проглянувши"],
    "проглянувши": ["проглянув"],
    "прогнав": ["прогнавши"],
    "прогнавши": ["прогнав"],
    "прогнание": ["изгнание"],
    "прогнать": ["выставить", "выгнать"],
    "прогневав": ["прогневавши"],
    "прогневавши": ["прогневав"],
    "прогневать": ["прогневить"],
    "прогневаться": ["прогневиться"],
    "прогневив": ["прогневивши"],
    "прогневивши": ["прогневив"],
    "прогневляв": ["прогневлявши"],
    "прогневлявши": ["прогневляв"],
    "прогнив": ["прогнивши"],
    "прогнивав": ["прогнивавши"],
    "прогнивавши": ["прогнивав"],
    "прогнивши": ["прогнив"],
    "прогноз": ["предсказание"],
    "прогнозировав": ["прогнозировавши"],
    "прогнозировавши": ["прогнозировав"],
    "прогнозировать": ["предсказывать", "предрекать", "пророчить", "пророчествовать", "прорицать"],
    "прогноив": ["прогноивши"],
    "прогноивши": ["прогноив"],
    "прогнув": ["прогнувши"],
    "прогнувши": ["прогнув"],
    "прогнусавив": ["прогнусавивши"],
    "прогнусавивши": ["прогнусавив"],
    "прогнусавить": ["прогнусить"],
    "прогнусив": ["прогнусивши"],
    "прогнусивши": ["прогнусив"],
    "прогнусить": ["прогнусавить"],
    "проговаривав": ["проговаривавши"],
    "проговаривавши": ["проговаривав"],
    "проговаривать": ["произносить", "говорить", "выговаривать", "обговаривать"],
    "проговариваться": ["выбалтываться", "обмолвливаться"],
    "проговорив": ["проговоривши"],
    "проговоривши": ["проговорив"],
    "проговорить": ["вымолвить", "произнести", "промолвить", "сказать"],
    "прогоготав": ["прогоготавши"],
    "прогоготавши": ["прогоготав"],
    "проголодав": ["проголодавши"],
    "проголодавши": ["проголодав"],
    "проголосив": ["проголосивши"],
    "проголосивши": ["проголосив"],
    "проголосовав": ["проголосовавши"],
    "проголосовавши": ["проголосовав"],
    "прогоняв": ["прогонявши"],
    "прогонявши": ["прогоняв"],
    "прогоняние": ["прогнание"],
    "прогорав": ["прогоравши"],
    "прогоравши": ["прогорав"],
    "прогорание": ["выгорание"],
    "прогорання": ["прогоряння"],
    "прогорев": ["прогоревши"],
    "прогоревав": ["прогоревавши"],
    "прогоревавши": ["прогоревав"],
    "прогоревши": ["прогорев"],
    "прогореть": ["прополыхать", "догореть", "сгореть", "разориться"],
    "прогоркав": ["прогоркавши"],
    "прогоркавши": ["прогоркав"],
    "прогоркать": ["горкнуть"],
    "прогорклый": ["прогоркший", "прогоркнувший", "горклый", "горьклый", "горький", "удушливый"],
    "прогоркнув": ["прогоркнувши"],
    "прогоркнувши": ["прогоркнув"],
    "прогорланив": ["прогорланивши"],
    "прогорланивши": ["прогорланив"],
    "прогостив": ["прогостивши"],
    "прогостивши": ["прогостив"],
    "прогосударственный": ["провластный"],
    "проградуировав": ["проградуировавши"],
    "проградуировавши": ["проградуировав"],
    "программа": ["план", "проект", "курс", "концепция", "программка", "буклет", "канал", "по", "прога", "приложение"],
    "программатор": ["прошивальщик"],
    "программер": ["кодер", "прогер"],
    "программировав": ["программировавши"],
    "программировавши": ["программировав"],
    "программирование": ["кодинг", "кодирование", "программированье"],
    "программировать": ["кодить", "прогать"],
    "программист": ["программер", "кодер", "девелопер", "хакер", "разработчик"],
    "программно": ["планируемо"],
    "программное обеспечение": ["по", "софт", "софтвер"],
    "программное средство": ["программное изделие", "программное обеспечение", "программный продукт"],
    "программный": ["компьютерный", "цифровой"],
    "програссировав": ["програссировавши"],
    "програссировавши": ["програссировав"],
    "прографив": ["прографивши"],
    "прографивши": ["прографив"],
    "прографляв": ["прографлявши"],
    "прографлявши": ["прографляв"],
    "прогребав": ["прогребавши"],
    "прогребавши": ["прогребав"],
    "прогрев": ["подготовка"],
    "прогревав": ["прогревавши"],
    "прогревавши": ["прогревав"],
    "прогревающий": ["прогревательный"],
    "прогревши": ["прогрев"],
    "прогредиентный": ["непрерывный", "злокачественный"],
    "прогрейдировав": ["прогрейдировавши"],
    "прогрейдировавши": ["прогрейдировав"],
    "прогремев": ["прогремевши"],
    "прогремевши": ["прогремев"],
    "прогресс": ["развитие", "продвижение", "эволюция", "улучшение"],
    "прогрессив-метал": ["прогрессивный металл"],
    "прогрессив-рок": ["прогрессивный рок", "прогрессив"],
    "прогрессивизм": ["прогрессизм"],
    "прогрессивный": ["передовой", "возрастающий"],
    "прогрессивный рок": ["прог", "прогрессив", "прогрессив-рок", "прог-рок"],
    "прогрессизм": ["прогрессивизм"],
    "прогрессировав": ["прогрессировавши"],
    "прогрессировавши": ["прогрессировав"],
    "прогрессирование": ["увеличение", "усиление", "возрастание"],
    "прогрессист": ["прогрессивист"],
    "прогромыхав": ["прогромыхавши"],
    "прогромыхавши": ["прогромыхав"],
    "прогромыхивав": ["прогромыхивавши"],
    "прогромыхивавши": ["прогромыхивав"],
    "прогрохав": ["прогрохавши"],
    "прогрохавши": ["прогрохав"],
    "прогрохотав": ["прогрохотавши"],
    "прогрохотавши": ["прогрохотав"],
    "прогрохотив": ["прогрохотивши"],
    "прогрохотивши": ["прогрохотив"],
    "прогрузив": ["прогрузивши"],
    "прогрузивши": ["прогрузив"],
    "прогрустив": ["прогрустивши"],
    "прогрустивши": ["прогрустив"],
    "прогрызав": ["прогрызавши"],
    "прогрызавши": ["прогрызав"],
    "прогуглив": ["прогугливши"],
    "прогугливши": ["прогуглив"],
    "прогудев": ["прогудевши"],
    "прогудевши": ["прогудев"],
    "прогул": ["пропуск", "невыход"],
    "прогуливав": ["прогуливавши"],
    "прогуливавши": ["прогуливав"],
    "прогуливаться": ["прохаживаться"],
    "прогулка": ["променад"],
    "прогуляв": ["прогулявши"],
    "прогулявши": ["прогуляв"],
    "прогундосив": ["прогундосивши"],
    "прогундосивши": ["прогундосив"],
    "прогусарив": ["прогусаривши"],
    "прогусаривши": ["прогусарив"],
    "прогусарить": ["промотать", "прокутить", "пролихачить", "промолодцевать"],
    "прода": ["продолжение"],
    "продав": ["продавши"],
    "продавав": ["продававши"],
    "продававши": ["продавав"],
    "продаван": ["барыга"],
    "продавать": ["сбывать", "торговать", "поставлять", "реализовывать"],
    "продаваться": ["сбываться", "реализовываться"],
    "продавец": ["торговец", "поставщик", "торгаш", "продажник", "продаван"],
    "продавив": ["продавивши"],
    "продавивши": ["продавив"],
    "продавить": ["вдавить", "выдавить", "протаранить", "проломить", "пробить", "просадить", "надавить", "высадить", "принудить"],
    "продавливав": ["продавливавши"],
    "продавливавши": ["продавливав"],
    "продавчиня": ["продавщиця"],
    "продавши": ["продав"],
    "продавщица": ["торговка", "продавчиха", "торгашка", "торгашиха"],
    "продавщиця": ["продавчиня"],
    "продаж": ["збыт", "гандаль", "тавараабарот", "абарот"],
    "продажа": ["сбыт", "торговля", "обращение"],
    "продажник": ["менеджер по продажам", "сейлз-менеджер", "проститутка"],
    "продажность": ["продаваемость", "коррумпированность"],
    "продажный": ["товарный", "коррумпированный"],
    "продалбливав": ["продалбливавши"],
    "продалбливавши": ["продалбливав"],
    "продалбывать": ["продалбливать", "профукивать"],
    "продать": ["распродать", "сбыть", "впарить", "втюхать", "загнать", "сплавить", "толкнуть"],
    "продать душу дьяволу": ["продать душу чёрту", "подписать душу дьяволу", "подписать душу чёрту", "продать душу за овсяный блин"],
    "продвигав": ["продвигавши"],
    "продвигавши": ["продвигав"],
    "продвигательный": ["промоутерский"],
    "продвигаться": ["прогрессировать"],
    "продвижение": ["перемещение", "промоушн"],
    "продвиженье": ["продвижение"],
    "продвинув": ["продвинувши"],
    "продвинувши": ["продвинув"],
    "продвинутый пользователь": ["новичок"],
    "продебатировав": ["продебатировавши"],
    "продебатировавши": ["продебатировав"],
    "продебютировав": ["продебютировавши"],
    "продебютировавши": ["продебютировав"],
    "продев": ["продевши"],
    "продевав": ["продевавши"],
    "продевавши": ["продевав"],
    "продевать": ["вдевать", "просовывать"],
    "продеваться": ["вдеваться"],
    "продевши": ["продев"],
    "продегустировав": ["продегустировавши"],
    "продегустировавши": ["продегустировав"],
    "продегустировать": ["распробовать"],
    "продежурив": ["продежуривши"],
    "продежуривав": ["продежуривавши"],
    "продежуривавши": ["продежуривав"],
    "продежуривши": ["продежурив"],
    "продезинфицировав": ["продезинфицировавши"],
    "продезинфицировавши": ["продезинфицировав"],
    "продезинфицировать": ["обеззаразить"],
    "продекламировав": ["продекламировавши"],
    "продекламировавши": ["продекламировав"],
    "продекламировать": ["прочитать", "прочесть"],
    "продекларировав": ["продекларировавши"],
    "продекларировавши": ["продекларировав"],
    "проделав": ["проделавши"],
    "проделавши": ["проделав"],
    "проделка": ["проделывание", "шалость"],
    "проделывав": ["проделывавши"],
    "проделывавши": ["проделывав"],
    "продемонстрировав": ["продемонстрировавши"],
    "продемонстрировавши": ["продемонстрировав"],
    "продержав": ["продержавши"],
    "продержавши": ["продержав"],
    "продефилировав": ["продефилировавши"],
    "продефилировавши": ["продефилировав"],
    "продешевив": ["продешевивши"],
    "продешевивши": ["продешевив"],
    "продешевляв": ["продешевлявши"],
    "продешевлявши": ["продешевляв"],
    "продиктовав": ["продиктовавши"],
    "продиктовавши": ["продиктовав"],
    "продимати": ["продувати"],
    "продинамив": ["продинамивши"],
    "продинамивши": ["продинамив"],
    "продиноцерас": ["продиноцерат"],
    "продирав": ["продиравши"],
    "продиравши": ["продирав"],
    "продирижировав": ["продирижировавши"],
    "продирижировавши": ["продирижировав"],
    "продисковав": ["продисковавши"],
    "продисковавши": ["продисковав"],
    "продифференцировав": ["продифференцировавши"],
    "продифференцировавши": ["продифференцировав"],
    "продлевав": ["продлевавши"],
    "продлевавши": ["продлевав"],
    "продлевать": ["продлять"],
    "продленье": ["продление"],
    "продлив": ["продливши"],
    "продливши": ["продлив"],
    "продляв": ["продлявши"],
    "продлявши": ["продляв"],
    "продлять": ["продлевать"],
    "продлёнка": ["группа продлённого дня", "гпд"],
    "продмаг": ["продовольственный"],
    "продневав": ["продневавши"],
    "продневавши": ["продневав"],
    "продовольственный": ["пищевой", "продуктовый"],
    "продовольственный пункт": ["продпункт"],
    "продовольствие": ["еда", "пища", "провиант"],
    "продовольствовав": ["продовольствовавши"],
    "продовольствовавши": ["продовольствовав"],
    "продолбав": ["продолбавши"],
    "продолбавши": ["продолбав"],
    "продолбать": ["пробить", "продолбить", "разбить", "испортить", "потерять", "посеять", "профукать"],
    "продолбив": ["продолбивши"],
    "продолбивши": ["продолбив"],
    "продолговатый": ["удлинённый", "вытянутый"],
    "продолжав": ["продолжавши"],
    "продолжавши": ["продолжав"],
    "продолжать": ["продлевать"],
    "продолжающийся": ["длящийся"],
    "продолжение": ["продолженье"],
    "продолженье": ["продолжение"],
    "продолжив": ["продолживши"],
    "продолживши": ["продолжив"],
    "продолжительность": ["длительность"],
    "продолжительный": ["долгий", "длительный", "протяжный"],
    "продольно": ["в длину", "вдоль"],
    "продотрядник": ["продотрядовец", "продотрядчик"],
    "продотрядовец": ["продотрядник", "продотрядчик"],
    "продотрядчик": ["продотрядник", "продотрядовец"],
    "продохнув": ["продохнувши"],
    "продохнувши": ["продохнув"],
    "продрав": ["продравши"],
    "продравши": ["продрав"],
    "продразвёрстка": ["продовольственная развёрстка"],
    "продразнив": ["продразнивши"],
    "продразнивши": ["продразнив"],
    "продраив": ["продраивши"],
    "продраивав": ["продраивавши"],
    "продраивавши": ["продраивав"],
    "продраивши": ["продраив"],
    "продребезжав": ["продребезжавши"],
    "продребезжавши": ["продребезжав"],
    "продрейфовав": ["продрейфовавши"],
    "продрейфовавши": ["продрейфовав"],
    "продремав": ["продремавши"],
    "продремавши": ["продремав"],
    "продрематься": ["проспаться", "продрыхнуться"],
    "продрогнув": ["продрогнувши"],
    "продрогнувши": ["продрогнув"],
    "продрогнуть": ["замёрзнуть", "оледенеть"],
    "продрожав": ["продрожавши"],
    "продрожавши": ["продрожав"],
    "продрыхав": ["продрыхавши"],
    "продрыхавши": ["продрыхав"],
    "продрыхнув": ["продрыхнувши"],
    "продрыхнувши": ["продрыхнув"],
    "продрыхнуться": ["проспаться", "продрематься"],
    "продубив": ["продубивши"],
    "продубивши": ["продубив"],
    "продубливав": ["продубливавши"],
    "продубливавши": ["продубливав"],
    "продублировав": ["продублировавши"],
    "продублировавши": ["продублировав"],
    "продув": ["продувка"],
    "продував": ["продувавши"],
    "продувавши": ["продував"],
    "продувши": ["продув"],
    "продудев": ["продудевши"],
    "продудевши": ["продудев"],
    "продудив": ["продудивши"],
    "продудивши": ["продудив"],
    "продукт": ["изделие", "продовольствие"],
    "продуктивно": ["эффективно", "производительно", "с большой отдачей", "с полной отдачей", "плодотворно", "результативно"],
    "продуктивность": ["производительность", "плодотворность"],
    "продуктивный": ["производительный", "плодотворный", "полезный"],
    "продуктовый": ["продовольственный", "продуктовый магазин"],
    "продуктообмен": ["бартер"],
    "продукувати": ["виробляти", "виготовляти", "випускати"],
    "продумав": ["продумавши"],
    "продумавши": ["продумав"],
    "продуманный": ["обдуманный", "взвешенный", "хитрый", "хитрожопый"],
    "продумывав": ["продумывавши"],
    "продумывавши": ["продумывав"],
    "продумывать": ["обдумывать"],
    "продурачив": ["продурачивши"],
    "продурачивши": ["продурачив"],
    "продуться": ["проиграться", "промотаться"],
    "продух": ["продушина"],
    "продуцент": ["автотроф"],
    "продуцировав": ["продуцировавши"],
    "продуцировавши": ["продуцировав"],
    "продуцирование": ["вырабатывание", "производство"],
    "продуцировать": ["производить", "произвести", "вырабатывать", "выработать"],
    "продуцируемый": ["производимый", "вырабатываемый"],
    "продушив": ["продушивши"],
    "продушивши": ["продушив"],
    "продымив": ["продымивши"],
    "продымивши": ["продымив"],
    "продырявив": ["продырявивши"],
    "продырявивши": ["продырявив"],
    "продырявленный": ["дырчатый", "дырявый", "перфорированный"],
    "продырявливав": ["продырявливавши"],
    "продырявливавши": ["продырявливав"],
    "продырявливаться": ["дырявиться", "проковыриваться"],
    "продыхав": ["продыхавши"],
    "продыхавши": ["продыхав"],
    "продыхнув": ["продыхнувши"],
    "продыхнувши": ["продыхнув"],
    "продышав": ["продышавши"],
    "продышавши": ["продышав"],
    "продюсер": ["арт-менеджер", "битмейкер"],
    "продюсировав": ["продюсировавши"],
    "продюсировавши": ["продюсировав"],
    "продёргав": ["продёргавши"],
    "продёргавши": ["продёргав"],
    "продёргивав": ["продёргивавши"],
    "продёргивавши": ["продёргивав"],
    "продёрнув": ["продёрнувши"],
    "продёрнувши": ["продёрнув"],
    "проебав": ["проебавши"],
    "проебавши": ["проебав"],
    "проебланив": ["проебланивши"],
    "проебланивши": ["проебланив"],
    "проебланить": ["проебать"],
    "проедав": ["проедавши"],
    "проедавши": ["проедав"],
    "проезд": ["проездка", "переулок"],
    "проездив": ["проездивши"],
    "проездивши": ["проездив"],
    "проездной": ["карточка"],
    "проездной билет": ["абонемент"],
    "проездом": ["мимоездом"],
    "проезжав": ["проезжавши"],
    "проезжавши": ["проезжав"],
    "проезживав": ["проезживавши"],
    "проезживавши": ["проезживав"],
    "проект": ["план", "черновик", "набросок", "намерение", "умысел", "замысел", "задумка", "прожект", "инициатива", "предприятие"],
    "проект-пилот": ["пилот-проект"],
    "проектант": ["проектировщик"],
    "проектировав": ["проектировавши"],
    "проектировавши": ["проектировав"],
    "проектирование": ["проектировка"],
    "проектировать": ["разрабатывать", "устраивать"],
    "проектно-строительный": ["строительно-проектный"],
    "проекция": ["проецирование", "изображение"],
    "проелозив": ["проелозивши"],
    "проелозивши": ["проелозив"],
    "проехав": ["проехавши"],
    "проехавши": ["проехав"],
    "проехать": ["миновать", "пропустить", "объехать", "преодолеть", "сделать", "оставить", "забить"],
    "проехидна": ["проехидна брюйна", "проехидна бруийна", "волосатая проехидна"],
    "проецировав": ["проецировавши"],
    "проецировавши": ["проецировав"],
    "прожав": ["прожавши"],
    "прожавши": ["прожав"],
    "прожарив": ["прожаривши"],
    "прожаривав": ["прожаривавши"],
    "прожаривавши": ["прожаривав"],
    "прожаривши": ["прожарив"],
    "прождав": ["прождавши"],
    "прождавши": ["прождав"],
    "прожевав": ["прожевавши"],
    "прожевавши": ["прожевав"],
    "прожевать": ["промямлить"],
    "прожект": ["замысел", "умысел", "план", "предположение", "проект", "расчёт", "намерение", "задумка"],
    "прожектерствовав": ["прожектерствовавши"],
    "прожектерствовавши": ["прожектерствовав"],
    "прожектировав": ["прожектировавши"],
    "прожектировавши": ["прожектировав"],
    "прожектёр": ["донкихот"],
    "прожектёрствовав": ["прожектёрствовавши"],
    "прожектёрствовавши": ["прожектёрствовав"],
    "прожерливий": ["прожерний", "ненажерливий"],
    "прожив": ["проживши"],
    "проживав": ["проживавши"],
    "проживавши": ["проживав"],
    "проживанье": ["проживание"],
    "проживать": ["жить", "существовать"],
    "проживши": ["прожив"],
    "прожиг": ["прошивка"],
    "прожигав": ["прожигавши"],
    "прожигавши": ["прожигав"],
    "прожидав": ["прожидавши"],
    "прожидавши": ["прожидав"],
    "прожилка": ["прожилина", "жилка"],
    "прожилок": ["прожилка"],
    "прожимав": ["прожимавши"],
    "прожимавши": ["прожимав"],
    "прожинав": ["прожинавши"],
    "прожинавши": ["прожинав"],
    "прожирав": ["прожиравши"],
    "прожиравши": ["прожирав"],
    "прожирив": ["прожиривши"],
    "прожиривав": ["прожиривавши"],
    "прожиривавши": ["прожиривав"],
    "прожиривши": ["прожирив"],
    "прожировав": ["прожировавши"],
    "прожировавши": ["прожировав"],
    "прожировывав": ["прожировывавши"],
    "прожировывавши": ["прожировывав"],
    "прожиток": ["прожитие"],
    "прожитье": ["прожитие"],
    "прожог": ["прогар"],
    "прожолкнув": ["прожолкнувши"],
    "прожолкнувши": ["прожолкнув"],
    "прожопив": ["прожопивши"],
    "прожопивши": ["прожопив"],
    "прожопить": ["проморгать", "просрать", "проебать", "продуть", "просадить"],
    "прожорливость": ["обжорливость", "ненасытность", "неуёмность"],
    "прожорливый": ["ненасытный", "неутолимый", "обжорливый"],
    "прожрав": ["прожравши"],
    "прожравши": ["прожрав"],
    "прожрать": ["растратить", "пропить", "прокутить", "протранжирить"],
    "прожужжав": ["прожужжавши"],
    "прожужжавши": ["прожужжав"],
    "прожурчав": ["прожурчавши"],
    "прожурчавши": ["прожурчав"],
    "прожёвывав": ["прожёвывавши"],
    "прожёвывавши": ["прожёвывав"],
    "прожёвывать": ["разжёвывать"],
    "прозаизировав": ["прозаизировавши"],
    "прозаизировавши": ["прозаизировав"],
    "прозаик": ["прозаист"],
    "прозаически": ["прозаично", "буднично", "обыденно", "приземлённо"],
    "прозаический": ["прозаичный", "будничный", "обыденный", "деловой", "практический"],
    "прозаично": ["обыденно", "приземлённо", "прозаически"],
    "прозаичный": ["прозаический", "приземлённый", "обыденный", "обыкновенный", "обычный", "будничный", "повседневный", "деловой", "практичный", "скучный", "житейский"],
    "прозак": ["флуоксетин"],
    "прозакладывав": ["прозакладывавши"],
    "прозакладывавши": ["прозакладывав"],
    "прозаседав": ["прозаседавши"],
    "прозаседавши": ["прозаседав"],
    "прозвав": ["прозвавши"],
    "прозвавши": ["прозвав"],
    "прозванивав": ["прозванивавши"],
    "прозванивавши": ["прозванивав"],
    "прозваниваться": ["звониться"],
    "прозвать": ["назвать", "наречь", "окрестить"],
    "прозвенев": ["прозвеневши"],
    "прозвеневши": ["прозвенев"],
    "прозвонив": ["прозвонивши"],
    "прозвонивши": ["прозвонив"],
    "прозвучав": ["прозвучавши"],
    "прозвучавши": ["прозвучав"],
    "прозвякав": ["прозвякавши"],
    "прозвякавши": ["прозвякав"],
    "прозевав": ["прозевавши"],
    "прозевавши": ["прозевав"],
    "прозевать": ["проглядеть", "проморгать", "проворонить"],
    "прозектор": ["диссектор"],
    "прозекторская": ["морг", "мертвецкая", "покойницкая"],
    "прозеленев": ["прозеленевши"],
    "прозеленевши": ["прозеленев"],
    "прозелит": ["неофит", "новообращённый"],
    "прозимовав": ["прозимовавши"],
    "прозимовавши": ["прозимовав"],
    "прозирав": ["прозиравши"],
    "прозиравши": ["прозирав"],
    "прознав": ["прознавши"],
    "прознавав": ["прознававши"],
    "прознававши": ["прознавав"],
    "прознавши": ["прознав"],
    "прознобив": ["прознобивши"],
    "прознобивши": ["прознобив"],
    "прозомбировав": ["прозомбировавши"],
    "прозомбировавши": ["прозомбировав"],
    "прозондировав": ["прозондировавши"],
    "прозондировавши": ["прозондировав"],
    "прозопопея": ["антропопатизм", "олицетворение", "персонификация", "просопопея"],
    "прозор": ["просвет", "щель", "прогал", "прогалина"],
    "прозорливец": ["всевидец"],
    "прозорливость": ["дальновидность", "проницательность"],
    "прозорливый": ["проницательный", "дальновидный"],
    "прозрачность": ["транспарентность", "чистота", "доверительность"],
    "прозрачный": ["просвечивающий"],
    "прозрев": ["прозревши"],
    "прозревав": ["прозревавши"],
    "прозревавши": ["прозревав"],
    "прозревши": ["прозрев"],
    "прозрение": ["прозренье", "озарение"],
    "прозренье": ["прозрение"],
    "прозубрив": ["прозубривши"],
    "прозубривав": ["прозубривавши"],
    "прозубривавши": ["прозубривав"],
    "прозубривши": ["прозубрив"],
    "прозывав": ["прозывавши"],
    "прозывавши": ["прозывав"],
    "прозябав": ["прозябавши"],
    "прозябавши": ["прозябав"],
    "прозябать": ["расти", "произрастать", "прорастать", "влачить существование"],
    "прозябнув": ["прозябнувши"],
    "прозябнувши": ["прозябнув"],
    "прозябнуть": ["промёрзнуть"],
    "прозёвывав": ["прозёвывавши"],
    "прозёвывавши": ["прозёвывав"],
    "прозёвывать": ["проворонивать"],
    "проигнорировав": ["проигнорировавши"],
    "проигнорировавши": ["проигнорировав"],
    "проиграв": ["проигравши"],
    "проигравши": ["проиграв"],
    "проигрывав": ["проигрывавши"],
    "проигрывавши": ["проигрывав"],
    "проигрыватель": ["плеер"],
    "проигрываться": ["продуваться"],
    "проигрыш": ["поражение", "убыток"],
    "произ-": ["проис-"],
    "произведение": ["творение", "сотворение", "продуцирование", "производство", "создание"],
    "произведённый": ["выданный", "выделанный", "вызванный", "выполненный", "выпущенный", "выработанный", "деланный", "изготовленный", "изданный", "исполненный", "испущенный", "наделанный", "наштампованный", "новопроизведенный", "осуществленный"],
    "произвести": ["выработать", "изготовить", "сделать", "соорудить", "выполнить"],
    "произвестковав": ["произвестковавши"],
    "произвестковавши": ["произвестковав"],
    "производив": ["производивши"],
    "производивши": ["производив"],
    "производитель": ["делатель", "изготовитель", "фабрикант", "сомножитель", "множитель"],
    "производительность": ["быстродействие", "продуктивность", "эффективность", "плодотворность"],
    "производить": ["совершать", "осуществлять", "создавать", "вырабатывать", "изготовлять", "выпускать", "порождать"],
    "производная": ["дифференциал"],
    "произвол": ["прихоть", "самочиние"],
    "произволение": ["воля", "желание", "изволение", "изволенье", "произволенье", "соизволение"],
    "произволенье": ["воля", "желание", "произволение", "соизволение"],
    "произволив": ["произволивши"],
    "произволивши": ["произволив"],
    "произволяв": ["произволявши"],
    "произволявши": ["произволяв"],
    "произнесение": ["выговаривание"],
    "произнесенье": ["произнесение"],
    "произнести": ["сказать", "выговорить", "проговорить", "молвить", "вымолвить", "промолвить", "изречь"],
    "произнеся": ["произнёсши"],
    "произносив": ["произносивши"],
    "произносивши": ["произносив"],
    "произносить": ["выговаривать", "говорить", "высказывать"],
    "произношение": ["произнесение", "выговор", "фонетика"],
    "произношенье": ["произношение"],
    "произойти": ["случиться", "совершиться", "свершиться", "появиться"],
    "произошедший": ["происшедший", "случившийся", "родившийся", "возникший"],
    "произрастав": ["произраставши"],
    "произраставши": ["произрастав"],
    "произрастанье": ["произрастание"],
    "произрастать": ["расти", "водиться"],
    "произрастение": ["растение", "произрастание"],
    "произрастив": ["произрастивши"],
    "произрастивши": ["произрастив"],
    "произращав": ["произращавши"],
    "произращавши": ["произращав"],
    "произродив": ["произродивши"],
    "произродивши": ["произродив"],
    "произрождав": ["произрождавши"],
    "произрождавши": ["произрождав"],
    "проиллюстрировав": ["проиллюстрировавши"],
    "проиллюстрировавши": ["проиллюстрировав"],
    "проименовав": ["проименовавши"],
    "проименовавши": ["проименовав"],
    "проименовывав": ["проименовывавши"],
    "проименовывавши": ["проименовывав"],
    "проимитировав": ["проимитировавши"],
    "проимитировавши": ["проимитировав"],
    "проинвентаризировав": ["проинвентаризировавши"],
    "проинвентаризировавши": ["проинвентаризировав"],
    "проинвестировав": ["проинвестировавши"],
    "проинвестировавши": ["проинвестировав"],
    "проиндексировав": ["проиндексировавши"],
    "проиндексировавши": ["проиндексировав"],
    "проинкубировав": ["проинкубировавши"],
    "проинкубировавши": ["проинкубировав"],
    "проинспектировав": ["проинспектировавши"],
    "проинспектировавши": ["проинспектировав"],
    "проинструктировав": ["проинструктировавши"],
    "проинструктировавши": ["проинструктировав"],
    "проинтегрировав": ["проинтегрировавши"],
    "проинтегрировавши": ["проинтегрировав"],
    "проинтервьюировав": ["проинтервьюировавши"],
    "проинтервьюировавши": ["проинтервьюировав"],
    "проинтерпретировав": ["проинтерпретировавши"],
    "проинтерпретировавши": ["проинтерпретировав"],
    "проинтонировав": ["проинтонировавши"],
    "проинтонировавши": ["проинтонировав"],
    "проинтуировав": ["проинтуировавши"],
    "проинтуировавши": ["проинтуировав"],
    "проинформировав": ["проинформировавши"],
    "проинформировавши": ["проинформировав"],
    "проинформировать": ["известить", "поставить в известность", "ввести в курс дела", "предупредить"],
    "проиронизировав": ["проиронизировавши"],
    "проиронизировавши": ["проиронизировав"],
    "проис-": ["произ-"],
    "проискав": ["проискавши"],
    "проискавши": ["проискав"],
    "происки": ["козни", "интриги"],
    "проискивав": ["проискивавши"],
    "проискивавши": ["проискивав"],
    "проистекав": ["проистекавши"],
    "проистекавши": ["проистекав"],
    "проистекать": ["истекать", "вытекать", "следовать", "происходить"],
    "происходив": ["происходивши"],
    "происходивши": ["происходив"],
    "происходить": ["случаться", "бывать", "встречаться", "делаться", "проистекать", "вести происхождение"],
    "происхождение": ["рождение", "возникновение"],
    "происшедший": ["произошедший"],
    "происшествие": ["событие", "приключение", "случай", "инцидент"],
    "пройдошничав": ["пройдошничавши"],
    "пройдошничавши": ["пройдошничав"],
    "пройдя": ["прошедши"],
    "пройдённый": ["пройденный"],
    "пройти": ["миновать", "преодолеть", "покрыть", "распространиться", "произойти", "состояться", "протянуться", "пролечь", "исчезнуть", "уйти", "прекратиться", "закончиться", "выпасть", "сдать", "прорыть"],
    "пройтись": ["прогуляться"],
    "прок": ["резон", "толк", "смысл", "польза", "выгода"],
    "прокадив": ["прокадивши"],
    "прокадивши": ["прокадив"],
    "прокажав": ["прокажавши"],
    "прокажавши": ["прокажав"],
    "проказа": ["лепра", "хронический гранулематоз", "болезнь гансена"],
    "проказив": ["проказивши"],
    "проказивши": ["проказив"],
    "проказить": ["проказничать", "шалить"],
    "проказливо": ["шаловливо"],
    "проказник": ["сорванец", "озорник", "хулиган", "шалун"],
    "проказница": ["шалунья"],
    "проказничав": ["проказничавши"],
    "проказничавши": ["проказничав"],
    "проказничать": ["шалить", "озорничать"],
    "прокалибровав": ["прокалибровавши"],
    "прокалибровавши": ["прокалибровав"],
    "прокалив": ["прокаливши"],
    "прокаливав": ["прокаливавши"],
    "прокаливавши": ["прокаливав"],
    "прокаливши": ["прокалив"],
    "прокалывав": ["прокалывавши"],
    "прокалывавши": ["прокалывав"],
    "прокалывание": ["прокол"],
    "прокалякав": ["прокалякавши"],
    "прокалякавши": ["прокалякав"],
    "прокамбиевый": ["прокамбийный"],
    "прокамбийный": ["прокамбиевый"],
    "проканав": ["проканавши"],
    "проканавши": ["проканав"],
    "проканать": ["прокатить"],
    "проканителив": ["проканителивши"],
    "проканителивши": ["проканителив"],
    "проканючив": ["проканючивши"],
    "проканючивши": ["проканючив"],
    "прокапав": ["прокапавши"],
    "прокапавши": ["прокапав"],
    "прокапчивав": ["прокапчивавши"],
    "прокапчивавши": ["прокапчивав"],
    "прокапывав": ["прокапывавши"],
    "прокапывавши": ["прокапывав"],
    "прокараулив": ["прокарауливши"],
    "прокарауливав": ["прокарауливавши"],
    "прокарауливавши": ["прокарауливав"],
    "прокарауливши": ["прокараулив"],
    "прокариот": ["безъядерный"],
    "прокаркав": ["прокаркавши"],
    "прокаркавши": ["прокаркав"],
    "прокармливав": ["прокармливавши"],
    "прокармливавши": ["прокармливав"],
    "прокармливать": ["пропитывать"],
    "прокартавив": ["прокартавивши"],
    "прокартавивши": ["прокартавив"],
    "прокат": ["аренда", "наём", "кинопрокат", "кинопоказ"],
    "прокатав": ["прокатавши"],
    "прокатавши": ["прокатав"],
    "прокатив": ["прокативши"],
    "прокативши": ["прокатив"],
    "прокатить на веретене": ["прокатить на вересине"],
    "прокатить на вороных": ["накидать чёрных шаров", "провалить"],
    "прокатиться": ["проехаться", "пронестись", "разнестись", "раздаться"],
    "прокатування": ["вальцування"],
    "прокатчик": ["вальцовщик", "кинопрокатчик"],
    "прокатывав": ["прокатывавши"],
    "прокатывавши": ["прокатывав"],
    "прокачав": ["прокачавши"],
    "прокачавши": ["прокачав"],
    "прокачивав": ["прокачивавши"],
    "прокачивавши": ["прокачивав"],
    "прокашивав": ["прокашивавши"],
    "прокашивавши": ["прокашивав"],
    "прокашливав": ["прокашливавши"],
    "прокашливавши": ["прокашливав"],
    "прокашливаться": ["откашливаться"],
    "прокашляв": ["прокашлявши"],
    "прокашлявши": ["прокашляв"],
    "прокашлянув": ["прокашлянувши"],
    "прокашлянувши": ["прокашлянув"],
    "прокварцевав": ["прокварцевавши"],
    "прокварцевавши": ["прокварцевав"],
    "проквасив": ["проквасивши"],
    "проквасивши": ["проквасив"],
    "проквашивав": ["проквашивавши"],
    "проквашивавши": ["проквашивав"],
    "прокемарив": ["прокемаривши"],
    "прокемаривши": ["прокемарив"],
    "прокидав": ["прокидавши"],
    "прокидавши": ["прокидав"],
    "прокидывав": ["прокидывавши"],
    "прокидывавши": ["прокидывав"],
    "прокинув": ["прокинувши"],
    "прокинувши": ["прокинув"],
    "прокинутися": ["проснутися"],
    "прокипав": ["прокипавши"],
    "прокипавши": ["прокипав"],
    "прокипев": ["прокипевши"],
    "прокипевши": ["прокипев"],
    "прокипятив": ["прокипятивши"],
    "прокипятивши": ["прокипятив"],
    "прокипячивав": ["прокипячивавши"],
    "прокипячивавши": ["прокипячивав"],
    "прокисав": ["прокисавши"],
    "прокисавши": ["прокисав"],
    "прокисание": ["скисание"],
    "прокисать": ["скисать"],
    "прокиснув": ["прокиснувши"],
    "прокиснувши": ["прокиснув"],
    "прокладка": ["проводка", "прослойка", "тампон"],
    "прокладывав": ["прокладывавши"],
    "прокладывавши": ["прокладывав"],
    "прокладывание": ["прокладыванье"],
    "прокладывать": ["проторять"],
    "прокламация": ["листовка", "указ"],
    "прокламировав": ["прокламировавши"],
    "прокламировавши": ["прокламировав"],
    "прокламирование": ["провозглашение"],
    "прокламировать": ["провозглашать", "провозгласить", "объявлять", "объявить"],
    "проклевав": ["проклевавши"],
    "проклевавши": ["проклевав"],
    "проклеив": ["проклеивши"],
    "проклеивав": ["проклеивавши"],
    "проклеивавши": ["проклеивав"],
    "проклеивальщик": ["проклейщик"],
    "проклеивши": ["проклеив"],
    "проклеймив": ["проклеймивши"],
    "проклеймивши": ["проклеймив"],
    "проклейщик": ["проклеивальщик"],
    "проклепав": ["проклепавши"],
    "проклепавши": ["проклепав"],
    "прокликав": ["прокликавши"],
    "прокликавши": ["прокликав"],
    "прокликивав": ["прокликивавши"],
    "прокликивавши": ["прокликивав"],
    "проклинав": ["проклинавши"],
    "проклинавши": ["проклинав"],
    "проклинать": ["клясть"],
    "прокльон": ["прокляття"],
    "проклюнув": ["проклюнувши"],
    "проклюнувши": ["проклюнув"],
    "проклятие": ["анафема", "ругательство", "бич", "несчастье", "порча", "сглаз"],
    "проклёвывав": ["проклёвывавши"],
    "проклёвывавши": ["проклёвывав"],
    "проклёпывав": ["проклёпывавши"],
    "проклёпывавши": ["проклёпывав"],
    "прокняжив": ["прокняживши"],
    "прокняживши": ["прокняжив"],
    "проковав": ["проковавши"],
    "проковавши": ["проковав"],
    "проковывав": ["проковывавши"],
    "проковывавши": ["проковывав"],
    "проковыливав": ["проковыливавши"],
    "проковыливавши": ["проковыливав"],
    "проковыляв": ["проковылявши"],
    "проковылявши": ["проковыляв"],
    "проковыривав": ["проковыривавши"],
    "проковыривавши": ["проковыривав"],
    "проковырнув": ["проковырнувши"],
    "проковырнувши": ["проковырнув"],
    "проковыряв": ["проковырявши"],
    "проковырявши": ["проковыряв"],
    "проковырять": ["проколупать", "продырявить"],
    "прокозыряв": ["прокозырявши"],
    "прокозырявши": ["прокозыряв"],
    "прокол": ["прокалывание"],
    "проколачивав": ["проколачивавши"],
    "проколачивавши": ["проколачивав"],
    "проколесив": ["проколесивши"],
    "проколесивши": ["проколесив"],
    "проколка": ["прокол", "прокалывание"],
    "проколов": ["проколовши"],
    "проколовши": ["проколов"],
    "проколотив": ["проколотивши"],
    "проколотивши": ["проколотив"],
    "проколупав": ["проколупавши"],
    "проколупавши": ["проколупав"],
    "проколупывав": ["проколупывавши"],
    "проколупывавши": ["проколупывав"],
    "прокомандовав": ["прокомандовавши"],
    "прокомандовавши": ["прокомандовав"],
    "прокомментировав": ["прокомментировавши"],
    "прокомментировавши": ["прокомментировав"],
    "прокомментировать": ["дать комментарий", "пояснить"],
    "прокомпостировав": ["прокомпостировавши"],
    "прокомпостировавши": ["прокомпостировав"],
    "проконвертировав": ["проконвертировавши"],
    "проконвертировавши": ["проконвертировав"],
    "проконнессос": ["мармара"],
    "проконопатив": ["проконопативши"],
    "проконопативши": ["проконопатив"],
    "проконопачивав": ["проконопачивавши"],
    "проконопачивавши": ["проконопачивав"],
    "проконспектировав": ["проконспектировавши"],
    "проконспектировавши": ["проконспектировав"],
    "проконсульствовав": ["проконсульствовавши"],
    "проконсульствовавши": ["проконсульствовав"],
    "проконсультировав": ["проконсультировавши"],
    "проконсультировавши": ["проконсультировав"],
    "проконтролировав": ["проконтролировавши"],
    "проконтролировавши": ["проконтролировав"],
    "прокоп": ["копание", "прокапывание", "нора", "туннель"],
    "прокопав": ["прокопавши"],
    "прокопавши": ["прокопав"],
    "прокопий": ["прокоп", "прокофий"],
    "прокопсия": ["успех", "сполука", "преуспяване", "късмет"],
    "прокоптев": ["прокоптевши"],
    "прокоптевши": ["прокоптев"],
    "прокоптив": ["прокоптивши"],
    "прокоптивши": ["прокоптив"],
    "прокормив": ["прокормивши"],
    "прокормивши": ["прокормив"],
    "прокормленье": ["прокормление"],
    "прокоротав": ["прокоротавши"],
    "прокоротавши": ["прокоротав"],
    "прокорпев": ["прокорпевши"],
    "прокорпевши": ["прокорпев"],
    "прокорректировав": ["прокорректировавши"],
    "прокорректировавши": ["прокорректировав"],
    "прокосив": ["прокосивши"],
    "прокосивши": ["прокосив"],
    "прокотировав": ["прокотировавши"],
    "прокотировавши": ["прокотировав"],
    "прокофий": ["прокопий", "прокоп"],
    "прокочевав": ["прокочевавши"],
    "прокочевавши": ["прокочевав"],
    "прокрасив": ["прокрасивши"],
    "прокрасивши": ["прокрасив"],
    "прокрастинатор": ["копуша"],
    "прокрастинация": ["откладывание", "отсрочивание", "затягивание", "отсрочка", "синдром скарлетт"],
    "прокрастинировав": ["прокрастинировавши"],
    "прокрастинировавши": ["прокрастинировав"],
    "прокрахмалив": ["прокрахмаливши"],
    "прокрахмаливав": ["прокрахмаливавши"],
    "прокрахмаливавши": ["прокрахмаливав"],
    "прокрахмаливши": ["прокрахмалив"],
    "прокрашивав": ["прокрашивавши"],
    "прокрашивавши": ["прокрашивав"],
    "прокредитовав": ["прокредитовавши"],
    "прокредитовавши": ["прокредитовав"],
    "прокрехтев": ["прокрехтевши"],
    "прокрехтевши": ["прокрехтев"],
    "прокрикивав": ["прокрикивавши"],
    "прокрикивавши": ["прокрикивав"],
    "прокричав": ["прокричавши"],
    "прокричавши": ["прокричав"],
    "прокроив": ["прокроивши"],
    "прокроивши": ["прокроив"],
    "прокружив": ["прокруживши"],
    "прокруживши": ["прокружив"],
    "прокрут": ["прокрутка", "прокручивание", "проворачивание", "провёртывание", "оборот"],
    "прокрутив": ["прокрутивши"],
    "прокрутивши": ["прокрутив"],
    "прокрутить": ["провернуть", "провертеть", "воспроизвести", "показать", "вспомнить", "пустить в оборот"],
    "прокручивав": ["прокручивавши"],
    "прокручивавши": ["прокручивав"],
    "прокручивать": ["проворачивать"],
    "прокрыв": ["прокрывши"],
    "прокрывав": ["прокрывавши"],
    "прокрывавши": ["прокрывав"],
    "прокрывши": ["прокрыв"],
    "прокрякав": ["прокрякавши"],
    "прокрякавши": ["прокрякав"],
    "прокряхтев": ["прокряхтевши"],
    "прокряхтевши": ["прокряхтев"],
    "прокс": ["бъта"],
    "проксамин": ["тетроник"],
    "проксанол": ["плюроник"],
    "прокси": ["прокси-сервер"],
    "прокси-война": ["война по доверенности", "война чужими руками", "опосредованная война"],
    "проксимальный": ["центральный", "ближний"],
    "проксировав": ["проксировавши"],
    "проксировавши": ["проксировав"],
    "проктоколэктомия": ["колопроктэктомия"],
    "проктология": ["колопроктология"],
    "прокудахтав": ["прокудахтавши"],
    "прокудахтавши": ["прокудахтав"],
    "прокудив": ["прокудивши"],
    "прокудивши": ["прокудив"],
    "прокукарекав": ["прокукарекавши"],
    "прокукарекавши": ["прокукарекав"],
    "прокуковав": ["прокуковавши"],
    "прокуковавши": ["прокуковав"],
    "прокуликав": ["прокуликавши"],
    "прокуликавши": ["прокуликав"],
    "прокультивировав": ["прокультивировавши"],
    "прокультивировавши": ["прокультивировав"],
    "прокупоросив": ["прокупоросивши"],
    "прокупоросивши": ["прокупоросив"],
    "прокурат": ["пройдоха", "ловкач", "проказник", "озорник"],
    "прокуратив": ["прокуративши"],
    "прокуративши": ["прокуратив"],
    "прокуратить": ["озорничать", "прокудить", "проказить", "прикидываться", "притворяться", "притворно", "болеть", "огуряться", "лытать", "от", "работы", "прокуролесить", "куролесить", "несколько", "времени"],
    "прокуратор": ["наместник", "управляющий"],
    "прокурив": ["прокуривши"],
    "прокуривав": ["прокуривавши"],
    "прокуривавши": ["прокуривав"],
    "прокуривши": ["прокурив"],
    "прокурлыкав": ["прокурлыкавши"],
    "прокурлыкавши": ["прокурлыкав"],
    "прокурныкав": ["прокурныкавши"],
    "прокурныкавши": ["прокурныкав"],
    "прокурор": ["обвинитель"],
    "прокурорка": ["прокурорша"],
    "прокусав": ["прокусавши"],
    "прокусавши": ["прокусав"],
    "прокусив": ["прокусивши"],
    "прокусивши": ["прокусив"],
    "прокусывав": ["прокусывавши"],
    "прокусывавши": ["прокусывав"],
    "прокутив": ["прокутивши"],
    "прокутивши": ["прокутив"],
    "прокутить": ["промотать", "просадить"],
    "прокучивав": ["прокучивавши"],
    "прокучивавши": ["прокучивав"],
    "пролабирование": ["выпячивание", "выпадение", "выдавливание"],
    "пролавировав": ["пролавировавши"],
    "пролавировавши": ["пролавировав"],
    "пролагав": ["пролагавши"],
    "пролагавши": ["пролагав"],
    "пролагать": ["прокладывать"],
    "пролазав": ["пролазавши"],
    "пролазавши": ["пролазав"],
    "пролазив": ["пролазивши"],
    "пролазивши": ["пролазив"],
    "пролазничав": ["пролазничавши"],
    "пролазничавши": ["пролазничав"],
    "пролакомив": ["пролакомивши"],
    "пролакомивши": ["пролакомив"],
    "пролактин": ["лактотропный гормон", "лактогенный гормон", "маммотропин", "маммотропный гормон", "лютеотропный гормон"],
    "проламывав": ["проламывавши"],
    "проламывавши": ["проламывав"],
    "пролатив": ["виалис"],
    "пролащивав": ["пролащивавши"],
    "пролащивавши": ["пролащивав"],
    "пролаяв": ["пролаявши"],
    "пролаявши": ["пролаяв"],
    "пролегав": ["пролегавши"],
    "пролегавши": ["пролегав"],
    "пролегать": ["проходить", "тянуться"],
    "пролегомен": ["пролегомена"],
    "пролегомена": ["пролегомен"],
    "пролежав": ["пролежавши"],
    "пролежавши": ["пролежав"],
    "пролезав": ["пролезавши"],
    "пролезавши": ["пролезав"],
    "пролентяйничав": ["пролентяйничавши"],
    "пролентяйничавши": ["пролентяйничав"],
    "пролепетав": ["пролепетавши"],
    "пролепетавши": ["пролепетав"],
    "пролепив": ["пролепивши"],
    "пролепивши": ["пролепив"],
    "пролепливав": ["пролепливавши"],
    "пролепливавши": ["пролепливав"],
    "пролесок": ["просека", "перелесок"],
    "пролессировав": ["пролессировавши"],
    "пролессировавши": ["пролессировав"],
    "пролетав": ["пролетавши"],
    "пролетавши": ["пролетав"],
    "пролетариат": ["рабочий класс", "прол"],
    "пролетаризировав": ["пролетаризировавши"],
    "пролетаризировавши": ["пролетаризировав"],
    "пролетаризовав": ["пролетаризовавши"],
    "пролетаризовавши": ["пролетаризовав"],
    "пролетарий": ["прол"],
    "пролетев": ["пролетевши"],
    "пролетевши": ["пролетев"],
    "пролечив": ["пролечивши"],
    "пролечивав": ["пролечивавши"],
    "пролечивавши": ["пролечивав"],
    "пролечивши": ["пролечив"],
    "пролив мурманца": ["мурманец"],
    "проливав": ["проливавши"],
    "проливавши": ["проливав"],
    "проливать": ["разливать"],
    "проливать кровь": ["гибнуть", "погибать", "страдать", "убивать"],
    "проливать свет": ["разъяснять"],
    "проливень": ["ливень", "дождь"],
    "проливши": ["пролив"],
    "пролизав": ["пролизавши"],
    "пролизавши": ["пролизав"],
    "пролизывав": ["пролизывавши"],
    "пролизывавши": ["пролизывав"],
    "пролиновав": ["пролиновавши"],
    "пролиновавши": ["пролиновав"],
    "пролиняв": ["пролинявши"],
    "пролинявши": ["пролиняв"],
    "пролистав": ["пролиставши"],
    "пролиставши": ["пролистав"],
    "пролистать": ["просмотреть"],
    "пролистнув": ["пролистнувши"],
    "пролистнувши": ["пролистнув"],
    "пролистнуть": ["просмотреть"],
    "пролистывав": ["пролистывавши"],
    "пролистывавши": ["пролистывав"],
    "пролить": ["разлить", "полить", "пройти"],
    "пролить кровь": ["погибнуть", "пострадать"],
    "пролитье": ["пролитие"],
    "пролиферировав": ["пролиферировавши"],
    "пролиферировавши": ["пролиферировав"],
    "пролицензировав": ["пролицензировавши"],
    "пролицензировавши": ["пролицензировав"],
    "пролоббировав": ["пролоббировавши"],
    "пролоббировавши": ["пролоббировав"],
    "пролов": ["безрыбье", "недолов"],
    "проловив": ["проловивши"],
    "проловивши": ["проловив"],
    "пролог": ["предисловие", "введение"],
    "прологарифмировав": ["прологарифмировавши"],
    "прологарифмировавши": ["прологарифмировав"],
    "проложив": ["проложивши"],
    "проложивши": ["проложив"],
    "проложить": ["установить", "монтировать", "проторить"],
    "проломав": ["проломавши"],
    "проломавши": ["проломав"],
    "проломив": ["проломивши"],
    "проломивши": ["проломив"],
    "пролонгация": ["продължение"],
    "пролонгировав": ["пролонгировавши"],
    "пролонгировавши": ["пролонгировав"],
    "пролонгирование": ["продление"],
    "пролонгировать": ["продлевать", "отсрочивать"],
    "пролопотав": ["пролопотавши"],
    "пролопотавши": ["пролопотав"],
    "пролопушив": ["пролопушивши"],
    "пролопушивши": ["пролопушив"],
    "пролощив": ["пролощивши"],
    "пролощивши": ["пролощив"],
    "пролубь": ["прорубь", "проруб", "пролуб"],
    "пролюбезничав": ["пролюбезничавши"],
    "пролюбезничавши": ["пролюбезничав"],
    "пролюбив": ["пролюбивши"],
    "пролюбивши": ["пролюбив"],
    "пролязгав": ["пролязгавши"],
    "пролязгавши": ["пролязгав"],
    "пролёживав": ["пролёживавши"],
    "пролёживавши": ["пролёживав"],
    "пролётка": ["дрожки", "бричка", "такси"],
    "пролётывав": ["пролётывавши"],
    "пролётывавши": ["пролётывав"],
    "промазав": ["промазавши"],
    "промазавши": ["промазав"],
    "промазывав": ["промазывавши"],
    "промазывавши": ["промазывав"],
    "промакав": ["промакавши"],
    "промакавши": ["промакав"],
    "промакнув": ["промакнувши"],
    "промакнувши": ["промакнув"],
    "промалчивав": ["промалчивавши"],
    "промалчивавши": ["промалчивав"],
    "промалывав": ["промалывавши"],
    "промалывавши": ["промалывав"],
    "проманав": ["проманавши"],
    "проманавши": ["проманав"],
    "проманать": ["манкировать"],
    "промандев": ["промандевши"],
    "промандевши": ["промандев"],
    "проманежив": ["проманеживши"],
    "проманеживши": ["проманежив"],
    "проманкировав": ["проманкировавши"],
    "проманкировавши": ["проманкировав"],
    "промаргивав": ["промаргивавши"],
    "промаргивавши": ["промаргивав"],
    "промариновав": ["промариновавши"],
    "промариновавши": ["промариновав"],
    "промаркировав": ["промаркировавши"],
    "промаркировавши": ["промаркировав"],
    "промаршировав": ["промаршировавши"],
    "промаршировавши": ["промаршировав"],
    "промаслив": ["промасливши"],
    "промасливав": ["промасливавши"],
    "промасливавши": ["промасливав"],
    "промасливши": ["промаслив"],
    "проматывав": ["проматывавши"],
    "проматывавши": ["проматывав"],
    "промахав": ["промахавши"],
    "промахавши": ["промахав"],
    "промахивав": ["промахивавши"],
    "промахивавши": ["промахивав"],
    "промахиваться": ["мазать"],
    "промахнув": ["промахнувши"],
    "промахнувши": ["промахнув"],
    "промачивав": ["промачивавши"],
    "промачивавши": ["промачивав"],
    "промащивав": ["промащивавши"],
    "промащивавши": ["промащивав"],
    "промаяв": ["промаявши"],
    "промаявши": ["промаяв"],
    "промаячив": ["промаячивши"],
    "промаячивши": ["промаячив"],
    "промедление": ["отсрочка", "задержка"],
    "промедленье": ["промедление"],
    "промедлив": ["промедливши"],
    "промедливши": ["промедлив"],
    "промеж": ["меж", "между"],
    "промежуток": ["расстояние", "отрезок"],
    "промежуточный": ["мезосомный"],
    "промелькав": ["промелькавши"],
    "промелькавши": ["промелькав"],
    "промелькивав": ["промелькивавши"],
    "промелькивавши": ["промелькивав"],
    "промелькнув": ["промелькнувши"],
    "промелькнувши": ["промелькнув"],
    "промен": ["обмен", "комиссия", "промена"],
    "променад": ["прогулка", "моцион", "променада", "променаж"],
    "променаж": ["променад", "прогулка"],
    "променивав": ["променивавши"],
    "променивавши": ["променивав"],
    "променливост": ["променчивост"],
    "променчивост": ["променливост"],
    "променяв": ["променявши"],
    "променявши": ["променяв"],
    "промерзав": ["промерзавши"],
    "промерзавши": ["промерзав"],
    "промерив": ["промеривши"],
    "промеривав": ["промеривавши"],
    "промеривавши": ["промеривав"],
    "промеривши": ["промерив"],
    "промерцав": ["промерцавши"],
    "промерцавши": ["промерцав"],
    "промеряв": ["промерявши"],
    "промерявши": ["промеряв"],
    "промесив": ["промесивши"],
    "промесивши": ["промесив"],
    "прометав": ["прометавши"],
    "прометавши": ["прометав"],
    "прометнув": ["прометнувши"],
    "прометнувши": ["прометнув"],
    "промечтав": ["промечтавши"],
    "промечтавши": ["промечтав"],
    "промешав": ["промешавши"],
    "промешавши": ["промешав"],
    "промешивав": ["промешивавши"],
    "промешивавши": ["промешивав"],
    "промешкав": ["промешкавши"],
    "промешкавши": ["промешкав"],
    "промзона": ["промышленная зона"],
    "промигав": ["промигавши"],
    "промигавши": ["промигав"],
    "промигивав": ["промигивавши"],
    "промигивавши": ["промигивав"],
    "промигнув": ["промигнувши"],
    "промигнувши": ["промигнув"],
    "промизансценировав": ["промизансценировавши"],
    "промизансценировавши": ["промизансценировав"],
    "проминав": ["проминавши"],
    "проминавши": ["проминав"],
    "проминать": ["мять", "сминать", "продавливать", "проторять", "протаптывать", "утрамбовывать"],
    "проминовав": ["проминовавши"],
    "проминовавши": ["проминовав"],
    "проминув": ["проминувши"],
    "проминувши": ["проминув"],
    "промискуитет": ["панмиксия", "свальный грех"],
    "промо": ["промоматериал"],
    "промо-гёрлз": ["промодевушка"],
    "промо-девочка": ["промо-модель", "промщица"],
    "промоакция": ["промомероприятие", "промоушн-акция"],
    "промовидео": ["промоклип", "проморолик", "промоушн-ролик"],
    "промовировав": ["промовировавши"],
    "промовировавши": ["промовировав"],
    "промогруппа": ["промокоманда", "промоушн-группа"],
    "промодевушка": ["промо-гёрлз"],
    "промоделировав": ["промоделировавши"],
    "промоделировавши": ["промоделировав"],
    "промозгло": ["влажно", "дождливо", "зябко", "сыро"],
    "промозгнув": ["промозгнувши"],
    "промозгнувши": ["промозгнув"],
    "промоина": ["арабатский пролив"],
    "промой": ["промоина"],
    "промокав": ["промокавши"],
    "промокавши": ["промокав"],
    "промокампания": ["промоушн-кампания", "промоушн-программа"],
    "промоклип": ["промовидео", "проморолик", "промоушн-ролик"],
    "промокнув": ["промокнувши"],
    "промокнувши": ["промокнув"],
    "промокоманда": ["промогруппа", "промоушн-группа"],
    "промолачивав": ["промолачивавши"],
    "промолачивавши": ["промолачивав"],
    "промолвив": ["промолвивши"],
    "промолвивши": ["промолвив"],
    "промолвить": ["сказать", "проговорить", "молвить", "изречь", "произнести", "вымолвить"],
    "промолов": ["промоловши"],
    "промоловши": ["промолов"],
    "промолотив": ["промолотивши"],
    "промолотивши": ["промолотив"],
    "промолчав": ["промолчавши"],
    "промолчавши": ["промолчав"],
    "промоматериал": ["промо"],
    "промомероприятие": ["промоакция", "промоушн-акция"],
    "промомодель": ["промо-девочка", "промщица"],
    "промониторив": ["промониторивши"],
    "промониторивши": ["промониторив"],
    "промораживав": ["промораживавши"],
    "промораживавши": ["промораживав"],
    "проморгав": ["проморгавши"],
    "проморгавши": ["проморгав"],
    "проморгать": ["промохать", "просмотреть", "прозевать"],
    "проморив": ["проморивши"],
    "проморивши": ["проморив"],
    "проморозив": ["проморозивши"],
    "проморозивши": ["проморозив"],
    "проморолик": ["промовидео", "промоклип", "промоушн-ролик"],
    "проморочив": ["проморочивши"],
    "проморочивши": ["проморочив"],
    "промостив": ["промостивши"],
    "промостивши": ["промостив"],
    "промостраница": ["промо-страница"],
    "промотав": ["промотавши"],
    "промотавши": ["промотав"],
    "промотать": ["растранжирить"],
    "промотур": ["промотурне", "промоушн-тур", "промоушн-турне"],
    "промотурне": ["промотур", "промоушн-тур", "промоушн-турне"],
    "промотыжив": ["промотыживши"],
    "промотыживав": ["промотыживавши"],
    "промотыживавши": ["промотыживав"],
    "промотыживши": ["промотыжив"],
    "промоутер": ["рекламист", "рекламщик", "зазывала"],
    "промоутировав": ["промоутировавши"],
    "промоутировавши": ["промоутировав"],
    "промоутировать": ["продвигать", "продвинуть"],
    "промоушн": ["продвижение"],
    "промоушн-агентство": ["промоушн-компания", "промоушн-центр"],
    "промоушн-акция": ["промоакция", "промомероприятие"],
    "промоушн-группа": ["промогруппа", "промокоманда"],
    "промоушн-кампания": ["промокампания", "промоушн-программа"],
    "промоушн-компания": ["промоушн-агентство", "промоушн-центр"],
    "промоушн-программа": ["промокампания", "промоушн-кампания"],
    "промоушн-ролик": ["промовидео", "промоклип", "проморолик"],
    "промоушн-тур": ["промотур", "промотурне", "промоушн-турне"],
    "промоушн-турне": ["промотур", "промотурне", "промоушн-тур"],
    "промоушн-центр": ["промоушн-агентство", "промоушн-компания"],
    "промочив": ["промочивши"],
    "промочивши": ["промочив"],
    "промочить горло": ["выпить", "бухнуть"],
    "промперегрев": ["промежуточный перегрев", "вторичный перегрев"],
    "промпереселенец": ["промышленный", "переселенец"],
    "промудев": ["промудевши"],
    "промудевши": ["промудев"],
    "промурлыкав": ["промурлыкавши"],
    "промурлыкавши": ["промурлыкав"],
    "промурыжив": ["промурыживши"],
    "промурыживши": ["промурыжив"],
    "промусолив": ["промусоливши"],
    "промусоливав": ["промусоливавши"],
    "промусоливавши": ["промусоливав"],
    "промусоливши": ["промусолив"],
    "промутив": ["промутивши"],
    "промутивши": ["промутив"],
    "промучав": ["промучавши"],
    "промучавши": ["промучав"],
    "промучив": ["промучивши"],
    "промучивав": ["промучивавши"],
    "промучивавши": ["промучивав"],
    "промучивши": ["промучив"],
    "промуштровав": ["промуштровавши"],
    "промуштровавши": ["промуштровав"],
    "промфинплан": ["промышленно-финансовый", "план", "выполнение"],
    "промчав": ["промчавши"],
    "промчавши": ["промчав"],
    "промчаться": ["пронестись", "пролететь", "миновать"],
    "промшив": ["промшивши"],
    "промшивши": ["промшив"],
    "промщица": ["промо-модель", "промо-девочка"],
    "промывав": ["промывавши"],
    "промывавши": ["промывав"],
    "промывание мозгов": ["одурачивание"],
    "промыванье": ["промывание"],
    "промывательный": ["промывочный", "промывной", "промывальный"],
    "промывочный": ["промывной"],
    "промывши": ["промыв"],
    "промылив": ["промыливши"],
    "промыливав": ["промыливавши"],
    "промыливавши": ["промыливав"],
    "промыливши": ["промылив"],
    "промысел": ["добывание", "добыча", "провидение"],
    "промысл": ["провидение"],
    "промыслив": ["промысливши"],
    "промысливши": ["промыслив"],
    "промытарив": ["промытаривши"],
    "промытаривав": ["промытаривавши"],
    "промытаривавши": ["промытаривав"],
    "промытаривши": ["промытарив"],
    "промычав": ["промычавши"],
    "промычавши": ["промычав"],
    "промышленная зона": ["промзона"],
    "промышленник": ["предприниматель", "капиталист", "ремесленник"],
    "промышленно-финансовый": ["производственно-экономический"],
    "промышленное предприятие": ["промпредприятие"],
    "промышленность": ["индустрия", "занятие", "промысел"],
    "промышленный": ["индустриальный", "профессиональный"],
    "промышляв": ["промышлявши"],
    "промышлявши": ["промышляв"],
    "промяв": ["промявши"],
    "промявши": ["промяв"],
    "промякнув": ["промякнувши"],
    "промякнувши": ["промякнув"],
    "промямлив": ["промямливши"],
    "промямливши": ["промямлив"],
    "промямлить": ["пробормотать"],
    "промяна": ["изменение", "променяне"],
    "промяться": ["получить", "вмятина", "размяться", "прогуляться"],
    "промяукав": ["промяукавши"],
    "промяукавши": ["промяукав"],
    "промяучив": ["промяучивши"],
    "промяучивши": ["промяучив"],
    "промяучить": ["промяукать"],
    "промёрзнув": ["промёрзнувши"],
    "промёрзнувши": ["промёрзнув"],
    "промётывав": ["промётывавши"],
    "промётывавши": ["промётывав"],
    "пронаблюдав": ["пронаблюдавши"],
    "пронаблюдавши": ["пронаблюдав"],
    "пронаблюдать": ["проследить", "проверить"],
    "пронаос": ["предхрамие", "паперть", "вестибюль"],
    "пронатализм": ["натализм"],
    "пронафталинив": ["пронафталинивши"],
    "пронафталинивав": ["пронафталинивавши"],
    "пронафталинивавши": ["пронафталинивав"],
    "пронафталинивши": ["пронафталинив"],
    "пронашивав": ["пронашивавши"],
    "пронашивавши": ["пронашивав"],
    "пронзав": ["пронзавши"],
    "пронзавши": ["пронзав"],
    "пронзать": ["протыкать", "прокалывать"],
    "пронзив": ["пронзивши"],
    "пронзивши": ["пронзив"],
    "пронзить взглядом": ["пригвоздить"],
    "пронивелировав": ["пронивелировавши"],
    "пронивелировавши": ["пронивелировав"],
    "пронизав": ["пронизавши"],
    "пронизавши": ["пронизав"],
    "пронизать": ["нанизать"],
    "пронизывав": ["пронизывавши"],
    "пронизывавши": ["пронизывав"],
    "пронизывать": ["нанизывать", "низать", "продевать", "продырявливать", "протыкать", "пронзать", "проникать", "пропитывать"],
    "пронизывающий": ["протыкающий", "пронзительный"],
    "проникав": ["проникавши"],
    "проникавши": ["проникав"],
    "проникать": ["входить", "ломиться", "влезать", "проходить", "залезать", "пробираться", "забираться", "врываться", "вторгаться", "продираться", "протискиваться", "вкрадываться", "закрадываться"],
    "проникновенье": ["проникновение"],
    "проникнув": ["проникнувши"],
    "проникнувши": ["проникнув"],
    "проникнуть": ["попасть", "просочиться", "пройти", "пробиться", "щель", "отверстие", "въесться", "пыль"],
    "проникнуться": ["прочувствовать"],
    "пронимав": ["пронимавши"],
    "пронимавши": ["пронимав"],
    "проницав": ["проницавши"],
    "проницавши": ["проницав"],
    "проницательность": ["зоркость"],
    "проницать": ["проникать"],
    "прономеровывав": ["прономеровывавши"],
    "прономеровывавши": ["прономеровывав"],
    "прономинальный": ["местоименный"],
    "прономинация": ["антономасия"],
    "прононс": ["манера", "акцент", "говор"],
    "прононциация": ["выговор", "произношение"],
    "пронормировав": ["пронормировавши"],
    "пронормировавши": ["пронормировав"],
    "проносив": ["проносивши"],
    "проносивши": ["проносив"],
    "проночевав": ["проночевавши"],
    "проночевавши": ["проночевав"],
    "пронумеровав": ["пронумеровавши"],
    "пронумеровавши": ["пронумеровав"],
    "пронумерованный": ["прономерованный"],
    "пронумеровывав": ["пронумеровывавши"],
    "пронумеровывавши": ["пронумеровывав"],
    "проныв": ["пронывши"],
    "пронывши": ["проныв"],
    "проныра": ["ловкач"],
    "проныривав": ["проныривавши"],
    "проныривавши": ["проныривав"],
    "пронырливость": ["изворотливость", "ловкачество"],
    "пронырливый": ["ловкий", "хваткий", "находчивый"],
    "пронырнув": ["пронырнувши"],
    "пронырнувши": ["пронырнув"],
    "проныряв": ["пронырявши"],
    "пронырявши": ["проныряв"],
    "пронюхивав": ["пронюхивавши"],
    "пронюхивавши": ["пронюхивав"],
    "проняв": ["пронявши"],
    "пронявши": ["проняв"],
    "пронянчив": ["пронянчивши"],
    "пронянчивши": ["пронянчив"],
    "прообедав": ["прообедавши"],
    "прообедавши": ["прообедав"],
    "прообедывав": ["прообедывавши"],
    "прообедывавши": ["прообедывав"],
    "прообраз": ["прототип"],
    "прообразовав": ["прообразовавши"],
    "прообразовавши": ["прообразовав"],
    "прообразовывав": ["прообразовывавши"],
    "прообразовывавши": ["прообразовывав"],
    "проолифив": ["проолифивши"],
    "проолифивши": ["проолифив"],
    "проолифливав": ["проолифливавши"],
    "проолифливавши": ["проолифливав"],
    "прооперировав": ["прооперировавши"],
    "прооперировавши": ["прооперировав"],
    "прооппонировав": ["прооппонировавши"],
    "прооппонировавши": ["прооппонировав"],
    "проорав": ["прооравши"],
    "прооравши": ["проорав"],
    "проорать": ["крикнуть"],
    "проохав": ["проохавши"],
    "проохавши": ["проохав"],
    "проохивав": ["проохивавши"],
    "проохивавши": ["проохивав"],
    "пропаганда": ["реклама", "популяризация"],
    "пропагандировав": ["пропагандировавши"],
    "пропагандировавши": ["пропагандировав"],
    "пропагандировать": ["агитировать", "рекламировать"],
    "пропагандист": ["пиарщик"],
    "пропагандистский": ["пропагандный"],
    "пропагандистское клише": ["идеологическое клише", "политическое клише"],
    "пропагандный": ["пропагандистский"],
    "пропагандон": ["пропагандошка"],
    "пропагандонство": ["пропагандонщина"],
    "пропагандонствовав": ["пропагандонствовавши"],
    "пропагандонствовавши": ["пропагандонствовав"],
    "пропагатор": ["функция распространения", "причинная функция грина"],
    "пропагировав": ["пропагировавши"],
    "пропагировавши": ["пропагировав"],
    "пропагировать": ["пропагандировать"],
    "пропадав": ["пропадавши"],
    "пропадавши": ["пропадав"],
    "пропадание": ["исчезновение", "пропажа"],
    "пропадать": ["исчезать"],
    "пропаивав": ["пропаивавши"],
    "пропаивавши": ["пропаивав"],
    "пропаклив": ["пропакливши"],
    "пропакливши": ["пропаклив"],
    "пропалзывав": ["пропалзывавши"],
    "пропалзывавши": ["пропалзывав"],
    "пропалив": ["пропаливши"],
    "пропаливав": ["пропаливавши"],
    "пропаливавши": ["пропаливав"],
    "пропаливши": ["пропалив"],
    "пропалывав": ["пропалывавши"],
    "пропалывавши": ["пропалывав"],
    "пропалывание": ["прополка"],
    "пропалывать": ["полоть"],
    "пропаналь": ["пропиональдегид"],
    "пропант": ["проппант"],
    "пропарив": ["пропаривши"],
    "пропаривав": ["пропаривавши"],
    "пропаривавши": ["пропаривав"],
    "пропаривши": ["пропарив"],
    "пропарить": ["упустить", "пропустить", "замохать"],
    "пропархивав": ["пропархивавши"],
    "пропархивавши": ["пропархивав"],
    "пропарывав": ["пропарывавши"],
    "пропарывавши": ["пропарывав"],
    "пропасть": ["бездна"],
    "пропахав": ["пропахавши"],
    "пропахавши": ["пропахав"],
    "пропахивав": ["пропахивавши"],
    "пропахивавши": ["пропахивав"],
    "пропахнув": ["пропахнувши"],
    "пропахнувши": ["пропахнув"],
    "пропаяв": ["пропаявши"],
    "пропаявши": ["пропаяв"],
    "пропев": ["пропевши"],
    "пропевав": ["пропевавши"],
    "пропевавши": ["пропевав"],
    "пропевши": ["пропев"],
    "пропедевтика": ["вводный курс", "для чайников"],
    "пропедевтический": ["подготовительный", "вводный"],
    "пропекав": ["пропекавши"],
    "пропекавши": ["пропекав"],
    "пропеллер": ["воздушный винт"],
    "пропемзовав": ["пропемзовавши"],
    "пропемзовавши": ["пропемзовав"],
    "пропемзовывав": ["пропемзовывавши"],
    "пропемзовывавши": ["пропемзовывав"],
    "пропердев": ["пропердевши"],
    "пропердевши": ["пропердев"],
    "пропердеть": ["пропукать", "провонять", "пропыхтеть", "прогреметь", "проиграть", "пропердонить", "просрать", "профукать"],
    "пропердеться": ["пробздеться", "сходить по нужде"],
    "проперев": ["пропёрши"],
    "пропереться": ["прошагать", "отшагать", "пропереть", "влезть", "пролезть", "втиснуться"],
    "проперчив": ["проперчивши"],
    "проперчивав": ["проперчивавши"],
    "проперчивавши": ["проперчивав"],
    "проперчивши": ["проперчив"],
    "пропесочив": ["пропесочивши"],
    "пропесочивав": ["пропесочивавши"],
    "пропесочивавши": ["пропесочивав"],
    "пропесочивать": ["вздрючивать", "дрючить", "давать нагоняй"],
    "пропесочивши": ["пропесочив"],
    "пропесочить": ["вздрючить", "дать нагоняй"],
    "пропетляв": ["пропетлявши"],
    "пропетлявши": ["пропетляв"],
    "пропеть": ["спеть"],
    "пропечатав": ["пропечатавши"],
    "пропечатавши": ["пропечатав"],
    "пропечатывав": ["пропечатывавши"],
    "пропечатывавши": ["пропечатывав"],
    "пропиарив": ["пропиаривши"],
    "пропиаривши": ["пропиарив"],
    "пропиарить": ["прорекламировать", "разрекламировать"],
    "пропив": ["пропивши"],
    "пропивав": ["пропивавши"],
    "пропивавши": ["пропивав"],
    "пропивоха": ["выпивоха"],
    "пропивши": ["пропив"],
    "пропиздев": ["пропиздевши"],
    "пропиздевши": ["пропиздев"],
    "пропиздеться": ["проболтаться"],
    "пропиздячив": ["пропиздячивши"],
    "пропиздячивши": ["пропиздячив"],
    "пропилей": ["пропилон"],
    "пропилен": ["пропен"],
    "пропиленгликоль": ["пропандиол"],
    "пропилив": ["пропиливши"],
    "пропиливав": ["пропиливавши"],
    "пропиливавши": ["пропиливав"],
    "пропиливши": ["пропилив"],
    "пропиликав": ["пропиликавши"],
    "пропиликавши": ["пропиликав"],
    "пропилон": ["пропилей"],
    "пропинав": ["пропинавши"],
    "пропинавши": ["пропинав"],
    "пропирав": ["пропиравши"],
    "пропиравши": ["пропирав"],
    "пропировавши": ["пропировав"],
    "прописав": ["прописавши"],
    "прописавши": ["прописав"],
    "прописная буква": ["заглавная буква", "большая буква"],
    "прописная истина": ["азбучная истина"],
    "прописной": ["заглавный", "упрощённый", "шаблонный", "тривиальный", "общеизвестный", "избитый", "пошлый"],
    "прописывав": ["прописывавши"],
    "прописывавши": ["прописывав"],
    "прописывать дубинала": ["дубинала прописывать"],
    "пропись": ["рецепт"],
    "пропитав": ["пропитавши"],
    "пропитавши": ["пропитав"],
    "пропитание": ["прокорм", "пропитанье"],
    "пропитанье": ["пропитание"],
    "пропитать": ["прокормить"],
    "пропитаться": ["пропахнуть"],
    "пропитка": ["пропитывание"],
    "пропитывав": ["пропитывавши"],
    "пропитывавши": ["пропитывав"],
    "пропитывать": ["напитывать", "промачивать", "наполнять", "пронизывать", "проникать"],
    "пропихав": ["пропихавши"],
    "пропихавши": ["пропихав"],
    "пропихивав": ["пропихивавши"],
    "пропихивавши": ["пропихивав"],
    "пропихнув": ["пропихнувши"],
    "пропихнувши": ["пропихнув"],
    "пропищав": ["пропищавши"],
    "пропищавши": ["пропищав"],
    "проплавав": ["проплававши"],
    "проплававши": ["проплавав"],
    "проплавив": ["проплавивши"],
    "проплавивши": ["проплавив"],
    "проплавливав": ["проплавливавши"],
    "проплавливавши": ["проплавливав"],
    "проплавливать": ["проплавлять"],
    "проплавляв": ["проплавлявши"],
    "проплавлявши": ["проплавляв"],
    "проплакав": ["проплакавши"],
    "проплакавши": ["проплакав"],
    "проплакивав": ["проплакивавши"],
    "проплакивавши": ["проплакивав"],
    "проплакнув": ["проплакнувши"],
    "проплакнувши": ["проплакнув"],
    "проплатив": ["проплативши"],
    "проплативши": ["проплатив"],
    "проплатить": ["предоплатить"],
    "проплачивав": ["проплачивавши"],
    "проплачивавши": ["проплачивав"],
    "проплачивать": ["предоплачивать"],
    "проплевав": ["проплевавши"],
    "проплевавши": ["проплевав"],
    "проплеснев": ["проплесневши"],
    "проплесневев": ["проплесневевши"],
    "проплесневевши": ["проплесневев"],
    "проплесневеть": ["проплеснеть"],
    "проплесневши": ["проплеснев"],
    "проплеснеть": ["проплесневеть"],
    "проплетав": ["проплетавши"],
    "проплетавши": ["проплетав"],
    "проплешина": ["плешь", "пролысина", "плешина"],
    "проплоив": ["проплоивши"],
    "проплоивши": ["проплоив"],
    "проплутав": ["проплутавши"],
    "проплутавши": ["проплутав"],
    "проплывав": ["проплывавши"],
    "проплывавши": ["проплывав"],
    "проплывши": ["проплыв"],
    "проплющив": ["проплющивши"],
    "проплющивав": ["проплющивавши"],
    "проплющивавши": ["проплющивав"],
    "проплющивши": ["проплющив"],
    "проплясав": ["проплясавши"],
    "проплясавши": ["проплясав"],
    "проплясывав": ["проплясывавши"],
    "проплясывавши": ["проплясывав"],
    "проплёвывав": ["проплёвывавши"],
    "проплёвывавши": ["проплёвывав"],
    "пропнув": ["пропнувши"],
    "пропнувши": ["пропнув"],
    "проповедав": ["проповедавши"],
    "проповедавши": ["проповедав"],
    "проповедник": ["пропонент", "последователь", "агитатор", "пропагандист"],
    "проповедовав": ["проповедовавши"],
    "проповедовавши": ["проповедовав"],
    "проповедывав": ["проповедывавши"],
    "проповедывавши": ["проповедывав"],
    "проповедь": ["поучение", "нравоучение", "наставление", "пропаганда"],
    "пропозициональный": ["сужденческий"],
    "пропозиция": ["предложение", "предпосылка"],
    "пропоив": ["пропоивши"],
    "пропоивши": ["пропоив"],
    "пропой": ["выпивка", "пропивание", "пропивка", "пропитие", "распитие"],
    "пропойца": ["пьяница", "пьянчуга", "алкоголик", "алкоголичка"],
    "прополаскивав": ["прополаскивавши"],
    "прополаскивавши": ["прополаскивав"],
    "прополаскивать": ["полоскать"],
    "проползав": ["проползавши"],
    "проползавши": ["проползав"],
    "прополис": ["пчелиный клей", "уза"],
    "прополов": ["прополовши"],
    "прополовши": ["прополов"],
    "прополоскав": ["прополоскавши"],
    "прополоскавши": ["прополоскав"],
    "прополоснув": ["прополоснувши"],
    "прополоснувши": ["прополоснув"],
    "прополыхав": ["прополыхавши"],
    "прополыхавши": ["прополыхав"],
    "пропоносив": ["пропоносивши"],
    "пропоносивши": ["пропоносив"],
    "пропонтида": ["мраморное море"],
    "пропонтировав": ["пропонтировавши"],
    "пропонтировавши": ["пропонтировав"],
    "пропоров": ["пропоровши"],
    "пропоровши": ["пропоров"],
    "пропорхав": ["пропорхавши"],
    "пропорхавши": ["пропорхав"],
    "пропорхнув": ["пропорхнувши"],
    "пропорхнувши": ["пропорхнув"],
    "пропорционально": ["соразмерно"],
    "пропорциональность": ["соразмерность"],
    "пропорциональный": ["соразмерный", "правомерный", "справедливый"],
    "пропорция": ["соотношение"],
    "пропотев": ["пропотевши"],
    "пропотевав": ["пропотевавши"],
    "пропотевавши": ["пропотевав"],
    "пропотевши": ["пропотев"],
    "пропотенцировав": ["пропотенцировавши"],
    "пропотенцировавши": ["пропотенцировав"],
    "проправительственный": ["лояльный", "официозный"],
    "пропрев": ["пропревши"],
    "пропревав": ["пропревавши"],
    "пропревавши": ["пропревав"],
    "пропревши": ["пропрев"],
    "проприетарный": ["собственнический", "частный"],
    "проприорецептор": ["проприоцептор"],
    "проприорецепция": ["проприоцепция"],
    "проприоцептор": ["проприорецептор"],
    "проприоцепция": ["проприорецепция"],
    "пропс": ["рудстойка", "крепь"],
    "пропуделяв": ["пропуделявши"],
    "пропуделявши": ["пропуделяв"],
    "пропуделять": ["промахнуться"],
    "пропудрив": ["пропудривши"],
    "пропудривав": ["пропудривавши"],
    "пропудривавши": ["пропудривав"],
    "пропудривши": ["пропудрив"],
    "пропуск": ["упущение", "непосещение", "манкирование", "неявка", "лакуна"],
    "пропускав": ["пропускавши"],
    "пропускавши": ["пропускав"],
    "пропускать": ["давать пройти", "давать дорогу", "упускать", "зевать", "течь", "протекать"],
    "пропустив": ["пропустивши"],
    "пропустивши": ["пропустив"],
    "пропустить": ["проспать", "профукать"],
    "пропутешествовав": ["пропутешествовавши"],
    "пропутешествовавши": ["пропутешествовав"],
    "пропутинский": ["запутинский"],
    "пропущав": ["пропущавши"],
    "пропущавши": ["пропущав"],
    "пропхеньянский": ["просеверокорейский"],
    "пропылав": ["пропылавши"],
    "пропылавши": ["пропылав"],
    "пропылесосив": ["пропылесосивши"],
    "пропылесосивши": ["пропылесосив"],
    "пропылив": ["пропыливши"],
    "пропыливав": ["пропыливавши"],
    "пропыливавши": ["пропыливав"],
    "пропыливши": ["пропылив"],
    "пропыхтев": ["пропыхтевши"],
    "пропыхтевши": ["пропыхтев"],
    "пропьянствовав": ["пропьянствовавши"],
    "пропьянствовавши": ["пропьянствовав"],
    "пропяв": ["пропявши"],
    "пропявши": ["пропяв"],
    "пропятив": ["пропятивши"],
    "пропятивши": ["пропятив"],
    "пропятие": ["распятие", "распятье", "пропятье"],
    "пропячивав": ["пропячивавши"],
    "пропячивавши": ["пропячивав"],
    "пропёрши": ["проперев"],
    "прорабатывав": ["прорабатывавши"],
    "прорабатывавши": ["прорабатывав"],
    "проработав": ["проработавши"],
    "проработавши": ["проработав"],
    "проработать": ["протрудиться", "проштудировать", "пропесочить", "разругать", "раскритиковать"],
    "проранивав": ["проранивавши"],
    "проранивавши": ["проранивав"],
    "прорастав": ["прораставши"],
    "прораставши": ["прорастав"],
    "прорастание": ["герминация"],
    "прорастанье": ["прорастание"],
    "прорастать": ["пробиваться", "всходить", "проклёвываться"],
    "прорастающий": ["герминативный"],
    "прорастив": ["прорастивши"],
    "прорастивши": ["прорастив"],
    "проращивав": ["проращивавши"],
    "проращивавши": ["проращивав"],
    "прорвав": ["прорвавши"],
    "прорвавши": ["прорвав"],
    "прорванный": ["продранный", "продырявленный", "пробитый", "проломанный", "проломленный", "разорванный", "изорванный", "рваный", "дырявый"],
    "прорвочка ушастая": ["прорвочка"],
    "прореагировав": ["прореагировавши"],
    "прореагировавши": ["прореагировав"],
    "проревев": ["проревевши"],
    "проревевши": ["проревев"],
    "проредактировав": ["проредактировавши"],
    "проредактировавши": ["проредактировав"],
    "проредев": ["проредевши"],
    "проредевши": ["проредев"],
    "проредив": ["проредивши"],
    "проредивши": ["проредив"],
    "прорежав": ["прорежавши"],
    "прорежавши": ["прорежав"],
    "прорежать": ["редить", "прореживать"],
    "прореживав": ["прореживавши"],
    "прореживавши": ["прореживав"],
    "прореживаемый": ["пропалываемый", "продёргиваемый"],
    "прореживать": ["прорежать"],
    "прорезав": ["прорезавши"],
    "прорезавши": ["прорезав"],
    "прорезинив": ["прорезинивши"],
    "прорезинивав": ["прорезинивавши"],
    "прорезинивавши": ["прорезинивав"],
    "прорезинивание": ["гуммирование"],
    "прорезинивать": ["резинить", "гуммировать"],
    "прорезинивши": ["прорезинив"],
    "прорезывав": ["прорезывавши"],
    "прорезывавши": ["прорезывав"],
    "прорезывать": ["прорезать"],
    "прорекав": ["прорекавши"],
    "прорекавши": ["прорекав"],
    "прорекламив": ["прорекламивши"],
    "прорекламивши": ["прорекламив"],
    "прорекламировав": ["прорекламировавши"],
    "прорекламировавши": ["прорекламировав"],
    "проремонтировав": ["проремонтировавши"],
    "проремонтировавши": ["проремонтировав"],
    "прорепетировав": ["прорепетировавши"],
    "прорепетировавши": ["прорепетировав"],
    "прореферировав": ["прореферировавши"],
    "прореферировавши": ["прореферировав"],
    "прореформаторский": ["прореформенный"],
    "прореформенный": ["прореформаторский"],
    "прореха": ["дыра", "дырка", "проруха"],
    "прорецензировав": ["прорецензировавши"],
    "прорецензировавши": ["прорецензировав"],
    "прорешивав": ["прорешивавши"],
    "прорешивавши": ["прорешивав"],
    "прореяв": ["прореявши"],
    "прореявши": ["прореяв"],
    "проржав": ["проржавши"],
    "проржавев": ["проржавевши"],
    "проржавевши": ["проржавев"],
    "проржавив": ["проржавивши"],
    "проржавивши": ["проржавив"],
    "проржавши": ["проржав"],
    "прорисовав": ["прорисовавши"],
    "прорисовавши": ["прорисовав"],
    "прорисовывав": ["прорисовывавши"],
    "прорисовывавши": ["прорисовывав"],
    "прорицав": ["прорицавши"],
    "прорицавши": ["прорицав"],
    "прорицанье": ["прорицание"],
    "прорицатель": ["предсказатель", "провидец"],
    "прорицательница": ["пророчица", "гадалка"],
    "прорицать": ["предсказывать", "предрекать", "пророчить", "пророчествовать", "прогнозировать", "предвещать", "провозвещать", "провидеть"],
    "пророк": ["прорицатель", "предсказатель", "провозвестник"],
    "пророкотав": ["пророкотавши"],
    "пророкотавши": ["пророкотав"],
    "проронив": ["проронивши"],
    "проронивши": ["проронив"],
    "пророняв": ["проронявши"],
    "проронявши": ["пророняв"],
    "пророчествовав": ["пророчествовавши"],
    "пророчествовавши": ["пророчествовав"],
    "пророчествовать": ["предсказывать", "предрекать", "пророчить", "прорицать", "прогнозировать"],
    "пророчив": ["пророчивши"],
    "пророчивши": ["пророчив"],
    "пророчить": ["предсказывать", "предрекать", "пророчествовать", "прорицать", "прогнозировать"],
    "прорубав": ["прорубавши"],
    "прорубавши": ["прорубав"],
    "прорубив": ["прорубивши"],
    "прорубивши": ["прорубив"],
    "проруха": ["ошибка", "оплошность", "неудача", "поруха", "прореха", "утрата"],
    "прорыв": ["провал"],
    "прорывав": ["прорывавши"],
    "прорывавши": ["прорывав"],
    "прорываться": ["продырявливаться", "лопаться"],
    "прорывной": ["революционный"],
    "прорывный": ["отстающий", "худой"],
    "прорывши": ["прорыв"],
    "прорыдав": ["прорыдавши"],
    "прорыдавши": ["прорыдав"],
    "прорысив": ["прорысивши"],
    "прорысивши": ["прорысив"],
    "прорыскав": ["прорыскавши"],
    "прорыскавши": ["прорыскав"],
    "прорыскивав": ["прорыскивавши"],
    "прорыскивавши": ["прорыскивав"],
    "прорыхлив": ["прорыхливши"],
    "прорыхливав": ["прорыхливавши"],
    "прорыхливавши": ["прорыхливав"],
    "прорыхливши": ["прорыхлив"],
    "прорыхляв": ["прорыхлявши"],
    "прорыхлявши": ["прорыхляв"],
    "прорыхлять": ["прорыхливать"],
    "прорычав": ["прорычавши"],
    "прорычавши": ["прорычав"],
    "прорюхав": ["прорюхавши"],
    "прорюхавши": ["прорюхав"],
    "просадив": ["просадивши"],
    "просадивши": ["просадив"],
    "просадить": ["пробить", "проломить", "проколоть", "издержать", "прокутить", "промотать"],
    "просажав": ["просажавши"],
    "просажавши": ["просажав"],
    "просаживав": ["просаживавши"],
    "просаживавши": ["просаживав"],
    "просак": ["конфуз"],
    "просалив": ["просаливши"],
    "просаливав": ["просаливавши"],
    "просаливавши": ["просаливав"],
    "просаливши": ["просалив"],
    "просаривав": ["просаривавши"],
    "просаривавши": ["просаривав"],
    "просасывав": ["просасывавши"],
    "просасывавши": ["просасывав"],
    "просачиванье": ["просачивание"],
    "просватав": ["просватавши"],
    "просватавши": ["просватав"],
    "просватанье": ["просватание"],
    "просватывав": ["просватывавши"],
    "просватывавши": ["просватывав"],
    "просвежав": ["просвежавши"],
    "просвежавши": ["просвежав"],
    "просвежив": ["просвеживши"],
    "просвеживши": ["просвежив"],
    "просверкав": ["просверкавши"],
    "просверкавши": ["просверкав"],
    "просверкивав": ["просверкивавши"],
    "просверкивавши": ["просверкивав"],
    "просверкнув": ["просверкнувши"],
    "просверкнувши": ["просверкнув"],
    "просверлив": ["просверливши"],
    "просверливав": ["просверливавши"],
    "просверливавши": ["просверливав"],
    "просверливши": ["просверлив"],
    "просветив": ["просветивши"],
    "просветивши": ["просветив"],
    "просветлев": ["просветлевши"],
    "просветлевши": ["просветлев"],
    "просветлив": ["просветливши"],
    "просветливши": ["просветлив"],
    "просветляв": ["просветлявши"],
    "просветлявши": ["просветляв"],
    "просвечивав": ["просвечивавши"],
    "просвечивавши": ["просвечивав"],
    "просвещав": ["просвещавши"],
    "просвещавши": ["просвещав"],
    "просвещение": ["образование", "обучение", "просвещенье", "просветительство"],
    "просвещенье": ["просвещение"],
    "просвира": ["просфора"],
    "просвиристев": ["просвиристевши"],
    "просвиристевши": ["просвиристев"],
    "просвирка": ["просвира", "алтей", "просвирник", "просвирняк", "проскурняк", "калачики", "слизь-трава", "собачья рожа"],
    "просвирник": ["алтей", "проскурняк", "просвирняк", "просвирка", "калачики", "слизь-трава", "собачья рожа"],
    "просвирняк": ["алтей", "просвирник", "проскурняк", "просвирка", "калачики", "слизь-трава", "собачья рожа"],
    "просвистав": ["просвиставши"],
    "просвиставши": ["просвистав"],
    "просвистев": ["просвистевши"],
    "просвистевши": ["просвистев"],
    "просвистеть": ["свистнуть", "просвистать", "насвистеть", "пронестись", "профукать"],
    "просвистывав": ["просвистывавши"],
    "просвистывавши": ["просвистывав"],
    "просевав": ["просевавши"],
    "просевавши": ["просевав"],
    "просеверокорейский": ["пропхеньянский"],
    "проседав": ["проседавши"],
    "проседавши": ["проседав"],
    "проседать": ["опускаться", "оседать", "прогибаться", "понижаться", "уменьшаться", "сокращаться"],
    "просеивав": ["просеивавши"],
    "просеивавши": ["просеивав"],
    "просека": ["просек"],
    "просекав": ["просекавши"],
    "просекавши": ["просекав"],
    "просекательный": ["перфорационный"],
    "просемафорив": ["просемафоривши"],
    "просемафоривши": ["просемафорив"],
    "просеменив": ["просеменивши"],
    "просеменивши": ["просеменив"],
    "просесть": ["осесть", "опуститься"],
    "просеяв": ["просеявши"],
    "просеявши": ["просеяв"],
    "просеять": ["перебрать"],
    "просив": ["просивши"],
    "просивши": ["просив"],
    "просигналив": ["просигналивши"],
    "просигналивши": ["просигналив"],
    "просигнализировав": ["просигнализировавши"],
    "просигнализировавши": ["просигнализировав"],
    "просидев": ["просидевши"],
    "просидевши": ["просидев"],
    "просиживав": ["просиживавши"],
    "просиживавши": ["просиживав"],
    "просиживать штаны": ["протирать штаны"],
    "просикав": ["просикавши"],
    "просикавши": ["просикав"],
    "просинев": ["просиневши"],
    "просиневши": ["просинев"],
    "просинив": ["просинивши"],
    "просинивав": ["просинивавши"],
    "просинивавши": ["просинивав"],
    "просинивши": ["просинив"],
    "просипев": ["просипевши"],
    "просипевши": ["просипев"],
    "просирав": ["просиравши"],
    "просиравши": ["просирав"],
    "просирать": ["проматывать", "проигрывать"],
    "просить милостыню": ["попрошайничать"],
    "просифонив": ["просифонивши"],
    "просифонивши": ["просифонив"],
    "просияв": ["просиявши"],
    "просиявав": ["просиявавши"],
    "просиявавши": ["просиявав"],
    "просиявши": ["просияв"],
    "проскабливав": ["проскабливавши"],
    "проскабливавши": ["проскабливав"],
    "проскакав": ["проскакавши"],
    "проскакавши": ["проскакав"],
    "проскакивав": ["проскакивавши"],
    "проскакивавши": ["проскакивав"],
    "проскальзывав": ["проскальзывавши"],
    "проскальзывавши": ["проскальзывав"],
    "проскандировав": ["проскандировавши"],
    "проскандировавши": ["проскандировав"],
    "просканировав": ["просканировавши"],
    "просканировавши": ["просканировав"],
    "просквозив": ["просквозивши"],
    "просквозивши": ["просквозив"],
    "просклоняв": ["просклонявши"],
    "просклонявши": ["просклоняв"],
    "проскоблив": ["проскобливши"],
    "проскобливши": ["проскоблив"],
    "проскользав": ["проскользавши"],
    "проскользавши": ["проскользав"],
    "проскользив": ["проскользивши"],
    "проскользивши": ["проскользив"],
    "проскользнув": ["проскользнувши"],
    "проскользнувши": ["проскользнув"],
    "проскочив": ["проскочивши"],
    "проскочивши": ["проскочив"],
    "проскочить": ["промчаться", "пропустить"],
    "проскочить между ёбаных": ["проскочить между струйками", "проскочить между струйками дождя"],
    "проскребав": ["проскребавши"],
    "проскребавши": ["проскребав"],
    "проскрежетав": ["проскрежетавши"],
    "проскрежетавши": ["проскрежетав"],
    "проскрипев": ["проскрипевши"],
    "проскрипевши": ["проскрипев"],
    "проскрёбывав": ["проскрёбывавши"],
    "проскрёбывавши": ["проскрёбывав"],
    "проскулив": ["проскуливши"],
    "проскуливши": ["проскулив"],
    "проскурняк": ["алтей", "просвирник", "просвирняк", "просвирка", "калачики", "слизь-трава", "собачья рожа"],
    "проскучав": ["проскучавши"],
    "проскучавши": ["проскучав"],
    "прослабив": ["прослабивши"],
    "прослабивши": ["прослабив"],
    "прослава": ["прославяне", "възхваляване", "славословие"],
    "прославив": ["прославивши"],
    "прославивши": ["прославив"],
    "прославление": ["восхваление", "превозношение"],
    "прославленный": ["воспетый"],
    "прославленье": ["прославление"],
    "прославляв": ["прославлявши"],
    "прославлявши": ["прославляв"],
    "прослаивав": ["прослаивавши"],
    "прослаивавши": ["прослаивав"],
    "проследив": ["проследивши"],
    "проследивши": ["проследив"],
    "проследовав": ["проследовавши"],
    "проследовавши": ["проследовав"],
    "прослеживав": ["прослеживавши"],
    "прослеживавши": ["прослеживав"],
    "прослеживание": ["отслеживание", "слежение"],
    "прослезив": ["прослезивши"],
    "прослезивши": ["прослезив"],
    "прослоив": ["прослоивши"],
    "прослоивши": ["прослоив"],
    "прослой": ["прослойка"],
    "прослужив": ["прослуживши"],
    "прослуживав": ["прослуживавши"],
    "прослуживавши": ["прослуживав"],
    "прослуживши": ["прослужив"],
    "прослушав": ["прослушавши"],
    "прослушавши": ["прослушав"],
    "прослушать": ["выслушать", "пропустить мимо ушей"],
    "прослушивав": ["прослушивавши"],
    "прослушивавши": ["прослушивав"],
    "прослушиванье": ["прослушивание"],
    "прослушивать": ["пропускать"],
    "прослушка": ["прослушивание", "подслушивание"],
    "прослыв": ["прослывши"],
    "прослывав": ["прослывавши"],
    "прослывавши": ["прослывав"],
    "прослывши": ["прослыв"],
    "прослышав": ["прослышавши"],
    "прослышавши": ["прослышав"],
    "просмаковав": ["просмаковавши"],
    "просмаковавши": ["просмаковав"],
    "просмаливав": ["просмаливавши"],
    "просмаливавши": ["просмаливав"],
    "просматривав": ["просматривавши"],
    "просматривавши": ["просматривав"],
    "просматривать по диагонали": ["читать по диагонали", "листать", "пробегаться глазами"],
    "просмеивав": ["просмеивавши"],
    "просмеивавши": ["просмеивав"],
    "просмеиваться": ["высмеиваться"],
    "просмеяв": ["просмеявши"],
    "просмеявши": ["просмеяв"],
    "просмолив": ["просмоливши"],
    "просмоливши": ["просмолив"],
    "просмотрев": ["просмотревши"],
    "просмотревши": ["просмотрев"],
    "просмотреть": ["проглядеть", "пропустить", "упустить", "проморгать", "прошляпить"],
    "просмотровка": ["скринер"],
    "проснутися": ["прокинутися"],
    "проснуться": ["пробудиться", "активизироваться", "появиться", "обнаружиться"],
    "просо": ["гоми", "дагусса", "канакай", "пайза", "могар", "чумиза"],
    "прособирав": ["прособиравши"],
    "прособиравши": ["прособирав"],
    "просовывав": ["просовывавши"],
    "просовывавши": ["просовывав"],
    "просодика": ["просодия"],
    "просодически": ["интонационно"],
    "просодия": ["припевание", "просодика"],
    "просолев": ["просолевши"],
    "просолевши": ["просолев"],
    "просолив": ["просоливши"],
    "просоливши": ["просолив"],
    "просома": ["головогрудь"],
    "просопев": ["просопевши"],
    "просопевши": ["просопев"],
    "просорив": ["просоривши"],
    "просоривши": ["просорив"],
    "просортировав": ["просортировавши"],
    "просортировавши": ["просортировав"],
    "просортировывав": ["просортировывавши"],
    "просортировывавши": ["просортировывав"],
    "просортировывать": ["сортировать"],
    "прососав": ["прососавши"],
    "прососавши": ["прососав"],
    "просохатив": ["просохативши"],
    "просохативши": ["просохатив"],
    "просохатить": ["проворонить", "прощёлкать", "пролососить"],
    "просохнув": ["просохнувши"],
    "просохнувши": ["просохнув"],
    "просочиняв": ["просочинявши"],
    "просочинявши": ["просочиняв"],
    "проспав": ["проспавши"],
    "проспавши": ["проспав"],
    "проспаривав": ["проспаривавши"],
    "проспаривавши": ["проспаривав"],
    "проспаться": ["выспаться", "отоспаться"],
    "проспект": ["авеню", "план"],
    "проспективный": ["прогрессивный", "направляющий"],
    "просперитет": ["процъфтяване", "прогрес", "преуспяване"],
    "проспиртовав": ["проспиртовавши"],
    "проспиртовавши": ["проспиртовав"],
    "проспиртовывав": ["проспиртовывавши"],
    "проспиртовывавши": ["проспиртовывав"],
    "проспойлерив": ["проспойлеривши"],
    "проспойлеривши": ["проспойлерив"],
    "проспонсировав": ["проспонсировавши"],
    "проспонсировавши": ["проспонсировав"],
    "проспорив": ["проспоривши"],
    "проспоривав": ["проспоривавши"],
    "проспоривавши": ["проспоривав"],
    "проспоривши": ["проспорив"],
    "проспрягав": ["проспрягавши"],
    "проспрягавши": ["проспрягав"],
    "просрав": ["просравши"],
    "просравши": ["просрав"],
    "просрать": ["потерять", "проиграть"],
    "просрачивав": ["просрачивавши"],
    "просрачивавши": ["просрачивав"],
    "просрочив": ["просрочивши"],
    "просрочивав": ["просрочивавши"],
    "просрочивавши": ["просрочивав"],
    "просрочивши": ["просрочив"],
    "просрочка": ["второй свежести", "не первой свежести", "просрок", "залежалый", "испортившийся", "неликвид", "тухлятина"],
    "проссав": ["проссавши"],
    "проссавши": ["проссав"],
    "проссать": ["проиграть", "потерять", "растратить", "просикать", "пропить", "продуть", "просадить", "прогадать", "прожопить", "продудеть", "просрать", "облажаться", "понять", "догадаться"],
    "прост": ["лесен", "обикновен"],
    "проставив": ["проставивши"],
    "проставивши": ["проставив"],
    "проставиться": ["накрыть поляну"],
    "проставление": ["простановка"],
    "проставляв": ["проставлявши"],
    "проставлявши": ["проставляв"],
    "проставляться": ["вноситься", "записываться"],
    "простаивав": ["простаивавши"],
    "простаивавши": ["простаивав"],
    "простак": ["простец", "простофиля"],
    "простановка": ["проставление", "внесение", "занесение", "промедление"],
    "простанывав": ["простанывавши"],
    "простанывавши": ["простанывав"],
    "простата": ["предстательная железа", "второе сердце мужчины"],
    "простатическая маточка": ["орган вебера"],
    "простачок": ["простак", "простофиля"],
    "простев": ["простевши"],
    "простевши": ["простев"],
    "простегав": ["простегавши"],
    "простегавши": ["простегав"],
    "простегнув": ["простегнувши"],
    "простегнувши": ["простегнув"],
    "простейший": ["легчайший"],
    "простелив": ["простеливши"],
    "простеливши": ["простелив"],
    "простелить": ["простлать"],
    "простенографировав": ["простенографировавши"],
    "простенографировавши": ["простенографировав"],
    "простенький": ["глуповатый"],
    "простенько": ["незамысловато", "бесхитростно"],
    "простерев": ["простёрши"],
    "простерилизовав": ["простерилизовавши"],
    "простерилизовавши": ["простерилизовав"],
    "простец": ["простак", "простофиля", "мирянин"],
    "простецкий": ["простой", "скромный", "добродушный", "прямой", "бесхитростный"],
    "прости господи": ["с позволения сказать", "прошу прощения"],
    "простив": ["простивши"],
    "простивши": ["простив"],
    "простикеровав": ["простикеровавши"],
    "простикеровавши": ["простикеровав"],
    "простилав": ["простилавши"],
    "простилавши": ["простилав"],
    "простимулировав": ["простимулировавши"],
    "простимулировавши": ["простимулировав"],
    "простипома": ["рыба", "проститутка", "шлюха", "путана", "падшая"],
    "простирав": ["простиравши"],
    "простиравши": ["простирав"],
    "простирадло": ["простирало"],
    "простирание": ["продление", "протягивание", "протяжение", "распростертие", "распространение"],
    "простирнув": ["простирнувши"],
    "простирнувши": ["простирнув"],
    "простирывав": ["простирывавши"],
    "простирывавши": ["простирывав"],
    "простирывать": ["стирать"],
    "простите": ["извините"],
    "простите мой французский": ["извините за выражение"],
    "простительно": ["извинительно"],
    "простительный": ["извинительный"],
    "проституировав": ["проституировавши"],
    "проституировавши": ["проституировав"],
    "проститут": ["жиголо"],
    "проститутка": ["публичная женщина", "путана", "женщина лёгкого поведения", "девочка по вызову", "девушка по вызову", "ночная бабочка", "жрица любви", "эскортница", "индивидуалка", "плечевая", "русалка", "интердевочка", "дева ночи", "фея", "шлюха"],
    "проститутничав": ["проститутничавши"],
    "проститутничавши": ["проститутничав"],
    "проститутничество": ["шлюшничество"],
    "проститутствовав": ["проститутствовавши"],
    "проститутствовавши": ["проститутствовав"],
    "простить": ["извинить"],
    "проститься": ["попрощаться", "распрощаться"],
    "простлав": ["простлавши"],
    "простлавши": ["простлав"],
    "просто": ["легко", "несложно"],
    "просто так": ["просто так и чирей не вскочит", "просто так даже мухи не летают", "просто так даже мухи не ебутся"],
    "просто-напросто": ["просто", "попросту", "просто-запросто"],
    "простоволосив": ["простоволосивши"],
    "простоволосивши": ["простоволосив"],
    "простодушие": ["простодушность", "чистосердечие"],
    "простодушничав": ["простодушничавши"],
    "простодушничавши": ["простодушничав"],
    "простодушно": ["бесхитростно", "наивно"],
    "простодушный": ["простоватый", "невинный", "бесхитростный", "прямодушный", "доверчивый", "наивный"],
    "простодушье": ["простодушие"],
    "простодырка": ["дура", "дурында", "охламонка", "дурочка", "полудурья", "полухвея", "скудоумка"],
    "простой": ["понятный", "доступный", "лёгкий", "несложный", "элементарный", "примитивный", "незамысловатый", "беспримесный", "обычный", "обыкновенный", "скромный", "дешёвый", "непритязательный", "непривилегированный", "бедный"],
    "простолюдин": ["низкородный", "плебей"],
    "простонав": ["простонавши"],
    "простонавши": ["простонав"],
    "простонародье": ["простолюдин", "чернь"],
    "простор": ["даль", "ширь", "приволье", "раздолье"],
    "простораживав": ["простораживавши"],
    "простораживавши": ["простораживав"],
    "просторечие": ["просторечье"],
    "просторечный": ["разговорный"],
    "просторечье": ["просторечие"],
    "просторожив": ["простороживши"],
    "простороживши": ["просторожив"],
    "простофиля": ["недотёпа", "простак", "разиня"],
    "простояв": ["простоявши"],
    "простоявши": ["простояв"],
    "прострагивав": ["прострагивавши"],
    "прострагивавши": ["прострагивав"],
    "прострадав": ["прострадавши"],
    "прострадавши": ["прострадав"],
    "простраивав": ["простраивавши"],
    "простраивавши": ["простраивав"],
    "пространнейший": ["обширнейший"],
    "пространно": ["широко", "длинно", "подробно", "многословно"],
    "пространность": ["объёмность", "обширность"],
    "пространный": ["обширный", "подробный"],
    "пространство": ["вселенная", "объём"],
    "пространствовав": ["пространствовавши"],
    "пространствовавши": ["пространствовав"],
    "простратиграфия": ["достратиграфия"],
    "прострация": ["ступор", "подавленность", "угнетённость", "расслабленность", "уныние", "унылость", "депрессуха", "упадок", "депрессия", "истощённость", "безразличность", "безразличие", "беспомощность", "дух"],
    "прострачивав": ["прострачивавши"],
    "прострачивавши": ["прострачивав"],
    "прострев": ["простревши"],
    "простревши": ["прострев"],
    "прострекотав": ["прострекотавши"],
    "прострекотавши": ["прострекотав"],
    "прострел": ["простреливание", "прострелка", "перфорирование"],
    "прострелив": ["простреливши"],
    "простреливав": ["простреливавши"],
    "простреливавши": ["простреливав"],
    "простреливши": ["прострелив"],
    "простреляв": ["прострелявши"],
    "прострелявши": ["простреляв"],
    "простригав": ["простригавши"],
    "простригавши": ["простригав"],
    "прострогав": ["прострогавши"],
    "прострогавши": ["прострогав"],
    "прострогать": ["простругать"],
    "простроив": ["простроивши"],
    "простроивши": ["простроив"],
    "прострочив": ["прострочивши"],
    "прострочивши": ["прострочив"],
    "простругав": ["простругавши"],
    "простругавши": ["простругав"],
    "простругивав": ["простругивавши"],
    "простругивавши": ["простругивав"],
    "простуда": ["орви", "простудифилис"],
    "простудив": ["простудивши"],
    "простудивши": ["простудив"],
    "простудить": ["застудить"],
    "простудиться": ["простыть"],
    "простужав": ["простужавши"],
    "простужавши": ["простужав"],
    "простужаться": ["простывать"],
    "простуживав": ["простуживавши"],
    "простуживавши": ["простуживав"],
    "простукав": ["простукавши"],
    "простукавши": ["простукав"],
    "простукивав": ["простукивавши"],
    "простукивавши": ["простукивав"],
    "проступав": ["проступавши"],
    "проступавши": ["проступав"],
    "проступив": ["проступивши"],
    "проступивши": ["проступив"],
    "проступок": ["провинность"],
    "простучав": ["простучавши"],
    "простучавши": ["простучав"],
    "простъпка": ["провинение", "нарушение", "грешка", "вина"],
    "простыв": ["простывши"],
    "простывав": ["простывавши"],
    "простывавши": ["простывав"],
    "простывши": ["простыв"],
    "простывший": ["озябший", "простуженный", "остывший", "охладившийся"],
    "простынув": ["простынувши"],
    "простынувши": ["простынув"],
    "простынуть": ["остыть", "простыть", "простудиться"],
    "простынь": ["простыня"],
    "простыня": ["простынь", "портянка"],
    "простыть": ["остыть", "охладиться", "охладеть"],
    "простяк": ["простак", "простофиля", "лопух", "водка", "горькая"],
    "простёгивав": ["простёгивавши"],
    "простёгивавши": ["простёгивав"],
    "простёрши": ["простерев"],
    "просубсидировав": ["просубсидировавши"],
    "просубсидировавши": ["просубсидировав"],
    "просудачив": ["просудачивши"],
    "просудачивши": ["просудачив"],
    "просудив": ["просудивши"],
    "просудивши": ["просудив"],
    "просуживав": ["просуживавши"],
    "просуживавши": ["просуживав"],
    "просуммировав": ["просуммировавши"],
    "просуммировавши": ["просуммировав"],
    "просунув": ["просунувши"],
    "просунувши": ["просунув"],
    "просутяжив": ["просутяживши"],
    "просутяживши": ["просутяжив"],
    "просутяжничав": ["просутяжничавши"],
    "просутяжничавши": ["просутяжничав"],
    "просуфлировав": ["просуфлировавши"],
    "просуфлировавши": ["просуфлировав"],
    "просушив": ["просушивши"],
    "просушивав": ["просушивавши"],
    "просушивавши": ["просушивав"],
    "просушивать": ["сушить", "высушивать"],
    "просушиваться": ["просыхать"],
    "просушивши": ["просушив"],
    "просушиться": ["просохнуть"],
    "просуществовав": ["просуществовавши"],
    "просуществовавши": ["просуществовав"],
    "просфора": ["просвира"],
    "просцениум": ["пульпитум", "авансцена", "проскений"],
    "просчитав": ["просчитавши"],
    "просчитавши": ["просчитав"],
    "просчитывав": ["просчитывавши"],
    "просчитывавши": ["просчитывав"],
    "просчёт": ["просчитывание", "ошибка", "промах"],
    "просъница": ["дрямка", "полусън"],
    "просыпав": ["просыпавши"],
    "просыпавши": ["просыпав"],
    "просыпанье": ["просыпание"],
    "просырев": ["просыревши"],
    "просыревши": ["просырев"],
    "просыхав": ["просыхавши"],
    "просыхавши": ["просыхав"],
    "просюсюкав": ["просюсюкавши"],
    "просюсюкавши": ["просюсюкав"],
    "просяк": ["бедняк", "сиромах", "дрипльо"],
    "протабанив": ["протабанивши"],
    "протабанивши": ["протабанив"],
    "протагонист": ["главный герой"],
    "протаив": ["протаивши"],
    "протаивав": ["протаивавши"],
    "протаивавши": ["протаивав"],
    "протаивши": ["протаив"],
    "протакав": ["протакавши"],
    "протакавши": ["протакав"],
    "протактиний": ["бревий"],
    "проталина": ["прогалина"],
    "проталинка": ["талинка", "выталинка", "подталинка", "прогалинка"],
    "проталкивав": ["проталкивавши"],
    "проталкивавши": ["проталкивав"],
    "протандрия": ["протерандрия", "протоандрия"],
    "протанцевав": ["протанцевавши"],
    "протанцевавши": ["протанцевав"],
    "протанцевать": ["станцевать", "плясать", "потанцевать"],
    "протанцовав": ["протанцовавши"],
    "протанцовавши": ["протанцовав"],
    "протанцовывав": ["протанцовывавши"],
    "протанцовывавши": ["протанцовывав"],
    "протапливав": ["протапливавши"],
    "протапливавши": ["протапливав"],
    "протаптывав": ["протаптывавши"],
    "протаптывавши": ["протаптывав"],
    "протаранив": ["протаранивши"],
    "протаранивав": ["протаранивавши"],
    "протаранивавши": ["протаранивав"],
    "протаранивши": ["протаранив"],
    "протараторив": ["протараторивши"],
    "протараторивши": ["протараторив"],
    "протарахтев": ["протарахтевши"],
    "протарахтевши": ["протарахтев"],
    "протаривав": ["протаривавши"],
    "протаривавши": ["протаривав"],
    "протаскав": ["протаскавши"],
    "протаскавши": ["протаскав"],
    "протаскивав": ["протаскивавши"],
    "протаскивавши": ["протаскивав"],
    "протасовав": ["протасовавши"],
    "протасовавши": ["протасовав"],
    "протачав": ["протачавши"],
    "протачавши": ["протачав"],
    "протачивав": ["протачивавши"],
    "протачивавши": ["протачивав"],
    "протащив": ["протащивши"],
    "протащивши": ["протащив"],
    "протаяв": ["протаявши"],
    "протаявши": ["протаяв"],
    "протвердив": ["протвердивши"],
    "протвердивши": ["протвердив"],
    "протверживав": ["протверживавши"],
    "протверживавши": ["протверживав"],
    "протеаза": ["протеиназа"],
    "протеже": ["подопечный"],
    "протежировав": ["протежировавши"],
    "протежировавши": ["протежировав"],
    "протежирование": ["протекция", "покровительство"],
    "протезировав": ["протезировавши"],
    "протезировавши": ["протезировав"],
    "протезис": ["пономарка"],
    "протеид": ["холопротеин"],
    "протеин": ["белок", "полипептид"],
    "протеиназа": ["протеаза"],
    "протеинурия": ["альбуминурия"],
    "протекав": ["протекавши"],
    "протекавши": ["протекав"],
    "протекторат богемии и моравии": ["рейхспротекторат"],
    "протекция": ["патронаж", "покровительство", "протежирование"],
    "протелеграфировав": ["протелеграфировавши"],
    "протелеграфировавши": ["протелеграфировав"],
    "протелефонировав": ["протелефонировавши"],
    "протелефонировавши": ["протелефонировав"],
    "протерандрия": ["протандрия", "протоандрия"],
    "протерев": ["протёрши"],
    "протерозой": ["протерозойский эон"],
    "протерпев": ["протерпевши"],
    "протерпевши": ["протерпев"],
    "протесав": ["протесавши"],
    "протесавши": ["протесав"],
    "протесниться": ["протиснуться"],
    "протесняться": ["протискиваться"],
    "протест": ["выступление"],
    "протестант": ["протестующий"],
    "протестантизм": ["протестантство"],
    "протестация": ["протест"],
    "протестировав": ["протестировавши"],
    "протестировавши": ["протестировав"],
    "протестовав": ["протестовавши"],
    "протестовавши": ["протестовав"],
    "протесьмив": ["протесьмивши"],
    "протесьмивши": ["протесьмив"],
    "протечный": ["влаговпитывающий", "промокательный", "проточный", "текучий", "свежий", "чистый"],
    "против": ["напротив"],
    "против ветра ссать": ["писать против ветра", "ссать против ветра"],
    "против лома нет приёма": ["плетью обуха не перешибёшь", "ссать против ветра"],
    "противев": ["противевши"],
    "противевши": ["противев"],
    "противень": ["протвень"],
    "противительный": ["адверсативный"],
    "противиться": ["сопротивляться"],
    "противленье": ["противление"],
    "противник": ["недоброжелатель", "супротивник", "враг", "недруг", "супостат", "конкурент", "соперник", "неприятель"],
    "противничка": ["противница", "съперница", "съперничка"],
    "противный": ["гадкий", "мерзкий", "отвратительный", "противоположный"],
    "противо-": ["анти-", "контр-"],
    "противоаварийный": ["антиаварийный"],
    "противоалкогольный": ["антиалкогольный"],
    "противоаллергенный": ["противоаллергический"],
    "противоаллергический": ["антиаллергический", "противоаллергенный"],
    "противоболевой": ["болеутоляющий", "обезболивающий"],
    "противоборство": ["борьба", "противоборствие"],
    "противоборствовав": ["противоборствовавши"],
    "противоборствовавши": ["противоборствовав"],
    "противоборствовать": ["противодействовать", "противостоять"],
    "противовирусный": ["антивирусный"],
    "противовоздушная оборона": ["пво"],
    "противогазный": ["противогазовый", "противохимический"],
    "противогазовый": ["противогазный", "противохимический"],
    "противогосударственный": ["антигосударственный"],
    "противогриппозный": ["антигриппозный"],
    "противодействие": ["препятствование", "сопротивление"],
    "противодействовав": ["противодействовавши"],
    "противодействовавши": ["противодействовав"],
    "противодействовать": ["бороться", "сопротивляться", "противостоять", "препятствовать", "оказывать противодействие"],
    "противодействующий": ["препятствующий", "сопротивляющийся"],
    "противодронный": ["антидронный", "антидроновый", "противодроновый"],
    "противодроновый": ["антидронный", "антидроновый", "противодронный"],
    "противозаконный": ["недозволенный", "незаконный", "преступный", "неправомерный", "противоправный", "нелегальный", "запрещённый", "запретный", "воспрещённый"],
    "противозачаточное": ["контрацептив"],
    "противозачаточный": ["контрацептивный"],
    "противоион": ["гегенион"],
    "противокашлевый": ["антикашлевый"],
    "противоковидный": ["антиковидный", "антикоронавирусный", "противокоронавирусный"],
    "противокоронавирусный": ["антиковидный", "антикоронавирусный", "противоковидный"],
    "противокоррозийный": ["противокоррозионный", "антикоррозийный", "антикоррозионный"],
    "противокоррозионный": ["противокоррозийный", "антикоррозийный", "антикоррозионный"],
    "противолежав": ["противолежавши"],
    "противолежавши": ["противолежав"],
    "противолежащий": ["противоположный"],
    "противолуна": ["антиселена", "антилуна"],
    "противомикробный": ["антимикробный"],
    "противообразный": ["несочетаемый", "несовместимый"],
    "противообщественный": ["антиобщественный"],
    "противоокислительный": ["антиокислительный"],
    "противопаразитарный": ["противопаразитный"],
    "противопартизанский": ["антипартизанский", "контрпартизанский"],
    "противопенный": ["антипенный"],
    "противопожарный": ["охраннопожарный"],
    "противополагав": ["противополагавши"],
    "противополагавши": ["противополагав"],
    "противополагать": ["противопоставлять"],
    "противоположенный": ["противопоставленный"],
    "противоположив": ["противоположивши"],
    "противоположивши": ["противоположив"],
    "противоположить": ["противопоставить"],
    "противоположность": ["антагонизм"],
    "противоположный": ["противолежащий", "обратный"],
    "противопоставив": ["противопоставивши"],
    "противопоставивши": ["противопоставив"],
    "противопоставление": ["противоположение", "сопоставление"],
    "противопоставляв": ["противопоставлявши"],
    "противопоставлявши": ["противопоставляв"],
    "противопоточный": ["противоточный"],
    "противоправность": ["незаконность", "противозаконность"],
    "противоправный": ["незаконный", "противозаконный", "неправомерный", "недозволенный", "преступный", "нелегальный"],
    "противопрививочный": ["антипрививочный"],
    "противопростудный": ["антипростудный"],
    "противоракета": ["антиракета"],
    "противоракетный": ["антиракетный"],
    "противоречив": ["противоречивши"],
    "противоречивши": ["противоречив"],
    "противоречивый": ["неоднозначный"],
    "противоречить": ["возражать", "спорить", "вступать в противоречие", "не согласовываться"],
    "противоречье": ["противоречие"],
    "противосвёртывающий": ["антикоагулянтный"],
    "противоселевый": ["антиселевой", "антиселевый", "противоселевой"],
    "противосолонь": ["противусолонь", "обсолонь"],
    "противоспазматический": ["антиспазматический"],
    "противоспутниковый": ["антиспутниковый"],
    "противостав": ["противоставши"],
    "противоставив": ["противоставивши"],
    "противоставивши": ["противоставив"],
    "противоставляв": ["противоставлявши"],
    "противоставлявши": ["противоставляв"],
    "противоставши": ["противостав"],
    "противостояв": ["противостоявши"],
    "противостоявши": ["противостояв"],
    "противостояние": ["оппозиция", "конфликт", "конфронтация", "антагонизм"],
    "противостоянье": ["противостояние"],
    "противотанковая управляемая ракета": ["птур"],
    "противотанковое орудие": ["пто"],
    "противотанковый ракетный комплекс": ["птрк"],
    "противотанковый ёж": ["звёздочка гориккера"],
    "противоточный": ["противопоточный"],
    "противотревожный": ["анксиолитический"],
    "противотромбозный": ["антитромбический"],
    "противотуберкулёзный": ["антитуберкулёзный"],
    "противофаза": ["антифаза"],
    "противохимический": ["противогазовый", "противогазный"],
    "противоцеллюлитный": ["антицеллюлитный"],
    "противоядье": ["противоядие"],
    "противуборствовав": ["противуборствовавши"],
    "противуборствовавши": ["противуборствовав"],
    "противуполагав": ["противуполагавши"],
    "противуполагавши": ["противуполагав"],
    "противуречив": ["противуречивши"],
    "противуречивши": ["противуречив"],
    "противусолонь": ["противосолонь", "обсолонь"],
    "противуставив": ["противуставивши"],
    "противуставивши": ["противуставив"],
    "противуставляв": ["противуставлявши"],
    "противуставлявши": ["противуставляв"],
    "протий": ["водород"],
    "протирав": ["протиравши"],
    "протиравши": ["протирав"],
    "протирать": ["вытирать", "натирать"],
    "протирать штаны": ["просиживать штаны"],
    "протирщик": ["рабочий", "клинер", "протиратель"],
    "протискав": ["протискавши"],
    "протискавши": ["протискав"],
    "протискаться": ["протиснуться"],
    "протискивав": ["протискивавши"],
    "протискивавши": ["протискивав"],
    "протискивать": ["проталкивать", "просовывать"],
    "протискиваться": ["проталкиваться", "продираться", "пробираться"],
    "протиснув": ["протиснувши"],
    "протиснувши": ["протиснув"],
    "проткав": ["проткавши"],
    "проткавши": ["проткав"],
    "проткнув": ["проткнувши"],
    "проткнувши": ["проткнув"],
    "проткнутый": ["пронзённый", "продырявленный"],
    "проткнуть": ["пронзить", "проколоть"],
    "протлев": ["протлевши"],
    "протлевши": ["протлев"],
    "прото-": ["пра-", "перво-", "калька", "протоиерей", "первосвященник"],
    "протоалбанский": ["протоалбанский язык", "праалбанский", "пралаалбанский язык"],
    "протоалбанский язык": ["протоалбанский", "праалбанский", "праалбанский язык"],
    "протоандрия": ["протандрия"],
    "протобалтийский": ["протобалтийский язык", "прабалтийский", "прабалтийский язык"],
    "протобалтийский язык": ["протобалтийский", "прабалтийский", "прабалтийский язык"],
    "протобанту": ["прабанту"],
    "протогерманский": ["прагерманский"],
    "протогиния": ["протерогиния"],
    "протограф": ["оригинал"],
    "протодиакон": ["протодьякон"],
    "протодьякон": ["протодиакон"],
    "протозоа": ["протозой"],
    "протоиерей": ["настоятель"],
    "протоиерейша": ["протоиерейская жена"],
    "протоиталийский": ["праиталийский", "праиталийский язык", "протоиталийский язык"],
    "протоиталийский язык": ["праиталийский", "праиталийский язык", "протоиталийский"],
    "протоколизм": ["протокольность"],
    "протоколировав": ["протоколировавши"],
    "протоколировавши": ["протоколировав"],
    "протокольность": ["протоколизм"],
    "протолкав": ["протолкавши"],
    "протолкавши": ["протолкав"],
    "протолкнув": ["протолкнувши"],
    "протолкнувши": ["протолкнув"],
    "протолкнуть": ["пропихнуть"],
    "протолковав": ["протолковавши"],
    "протолковавши": ["протолковав"],
    "протолковывав": ["протолковывавши"],
    "протолковывавши": ["протолковывав"],
    "протологизм": ["окказионализм"],
    "протомер": ["субъединица"],
    "протомив": ["протомивши"],
    "протомивши": ["протомив"],
    "протоморф": ["протоморфа"],
    "протон": ["водород", "протий"],
    "протонировав": ["протонировавши"],
    "протонировавши": ["протонировав"],
    "протопав": ["протопавши"],
    "протопавши": ["протопав"],
    "протопив": ["протопивши"],
    "протопивши": ["протопив"],
    "протопоп": ["протоиерей"],
    "протоптав": ["протоптавши"],
    "протоптавши": ["протоптав"],
    "протоптер": ["паолиидовые"],
    "проторговав": ["проторговавши"],
    "проторговавши": ["проторговав"],
    "проторговка": ["боковик", "консолидация", "флэт"],
    "проторговывав": ["проторговывавши"],
    "проторговывавши": ["проторговывав"],
    "проторив": ["проторивши"],
    "проторивши": ["проторив"],
    "проторчав": ["проторчавши"],
    "проторчавши": ["проторчав"],
    "проторяв": ["проторявши"],
    "проторявши": ["проторяв"],
    "проторять": ["торить", "прокладывать"],
    "протосковав": ["протосковавши"],
    "протосковавши": ["протосковав"],
    "прототип": ["прообраз", "оригинал", "модель", "бета-версия"],
    "прототипировав": ["прототипировавши"],
    "прототипировавши": ["прототипировав"],
    "прототипический": ["исходный", "образцовый", "первичный", "первообразный"],
    "прототрофный": ["автотрофный", "аутотрофный"],
    "протоукр": ["протоукраинец"],
    "протоукраинец": ["праукраинец", "протохохол"],
    "проточив": ["проточивши"],
    "проточивши": ["проточив"],
    "протоязык": ["праязык"],
    "протравив": ["протравивши"],
    "протравивши": ["протравив"],
    "протравливав": ["протравливавши"],
    "протравливавши": ["протравливав"],
    "протравляв": ["протравлявши"],
    "протравлявши": ["протравляв"],
    "протрагировав": ["протрагировавши"],
    "протрагировавши": ["протрагировав"],
    "протрактор": ["транспортир"],
    "протралив": ["протраливши"],
    "протраливав": ["протраливавши"],
    "протраливавши": ["протраливав"],
    "протраливши": ["протралив"],
    "протранжирив": ["протранжиривши"],
    "протранжиривав": ["протранжиривавши"],
    "протранжиривавши": ["протранжиривав"],
    "протранжиривши": ["протранжирив"],
    "протранскрибировав": ["протранскрибировавши"],
    "протранскрибировавши": ["протранскрибировав"],
    "протратив": ["протративши"],
    "протративши": ["протратив"],
    "протрачивав": ["протрачивавши"],
    "протрачивавши": ["протрачивав"],
    "протрезвев": ["протрезвевши"],
    "протрезвевши": ["протрезвев"],
    "протрезветь": ["протрезвиться"],
    "протрезвив": ["протрезвивши"],
    "протрезвивши": ["протрезвив"],
    "протрезвиться": ["протрезветь"],
    "протрезвление": ["отрезвление"],
    "протрезвляв": ["протрезвлявши"],
    "протрезвлявши": ["протрезвляв"],
    "протрезвляться": ["трезветь"],
    "протренькав": ["протренькавши"],
    "протренькавши": ["протренькав"],
    "протрепав": ["протрепавши"],
    "протрепавши": ["протрепав"],
    "протрещав": ["протрещавши"],
    "протрещавши": ["протрещав"],
    "протриеровав": ["протриеровавши"],
    "протриеровавши": ["протриеровав"],
    "протрубив": ["протрубивши"],
    "протрубивши": ["протрубив"],
    "протрусив": ["протрусивши"],
    "протрусивши": ["протрусив"],
    "протрясав": ["протрясавши"],
    "протрясавши": ["протрясав"],
    "протряхивав": ["протряхивавши"],
    "протряхивавши": ["протряхивав"],
    "протряхнув": ["протряхнувши"],
    "протряхнувши": ["протряхнув"],
    "протрёпывав": ["протрёпывавши"],
    "протрёпывавши": ["протрёпывав"],
    "протупив": ["протупивши"],
    "протупивши": ["протупив"],
    "протурив": ["протуривши"],
    "протуривши": ["протурив"],
    "протусив": ["протусивши"],
    "протусивши": ["протусив"],
    "протухав": ["протухавши"],
    "протухавши": ["протухав"],
    "протухать": ["тухнуть"],
    "протухлость": ["тухлость"],
    "протухнув": ["протухнувши"],
    "протухнувши": ["протухнув"],
    "протухнуть": ["испортиться", "ухудшиться", "пропахнуть", "устареть"],
    "протушевав": ["протушевавши"],
    "протушевавши": ["протушевав"],
    "протушив": ["протушивши"],
    "протушивши": ["протушив"],
    "протушёвывав": ["протушёвывавши"],
    "протушёвывавши": ["протушёвывав"],
    "протыкав": ["протыкавши"],
    "протыкавши": ["протыкав"],
    "протырив": ["протыривши"],
    "протыривши": ["протырив"],
    "протявкав": ["протявкавши"],
    "протявкавши": ["протявкав"],
    "протявкивав": ["протявкивавши"],
    "протявкивавши": ["протявкивав"],
    "протягав": ["протягавши"],
    "протягавши": ["протягав"],
    "протягивав": ["протягивавши"],
    "протягивавши": ["протягивав"],
    "протяженье": ["протяжение"],
    "протяжность": ["протяжённость"],
    "протяжённый": ["длительный", "длинный"],
    "протянув": ["протянувши"],
    "протянувши": ["протянув"],
    "протянуть": ["растянуть", "провести", "натянуть", "выставить", "выдвинуть", "преподнести"],
    "протёк": ["протекание"],
    "протёрши": ["протерев"],
    "протёсывав": ["протёсывавши"],
    "протёсывавши": ["протёсывав"],
    "проужинав": ["проужинавши"],
    "проужинавши": ["проужинав"],
    "проулок": ["переулок"],
    "проурчав": ["проурчавши"],
    "проурчавши": ["проурчав"],
    "проутюжив": ["проутюживши"],
    "проутюживав": ["проутюживавши"],
    "проутюживавши": ["проутюживав"],
    "проутюживши": ["проутюжив"],
    "проух": ["проушина"],
    "проучив": ["проучивши"],
    "проучивав": ["проучивавши"],
    "проучивавши": ["проучивав"],
    "проучивши": ["проучив"],
    "проучительствовав": ["проучительствовавши"],
    "проучительствовавши": ["проучительствовав"],
    "проушина": ["проух"],
    "профайл": ["профиль"],
    "профайлер": ["верификатор"],
    "профакапить": ["просрать"],
    "профан": ["невежда", "неспециалист", "дилетант", "неуч", "недоучка", "пошляк"],
    "профанация": ["осквернение", "кощунство"],
    "профанировав": ["профанировавши"],
    "профанировавши": ["профанировав"],
    "профанировать": ["осквернять", "осквернить", "опошлять", "опошлить"],
    "профанный": ["светский"],
    "профбилет": ["профсоюзный", "билет"],
    "профбосс": ["профлидер"],
    "профгрупорг": ["профорг", "профгруппорг"],
    "профгруппорг": ["профгрупорг"],
    "профдеформация": ["профессиональная деформация"],
    "профеминистический": ["профеминистский"],
    "профеминистский": ["профеминистический"],
    "профермент": ["зимоген"],
    "профершпилив": ["профершпиливши"],
    "профершпиливши": ["профершпилив"],
    "профершпилить": ["проиграть"],
    "профершпилиться": ["проиграться", "пробубниться", "пробубениться", "продуться", "промотаться"],
    "профессионализировав": ["профессионализировавши"],
    "профессионализировавши": ["профессионализировав"],
    "профессиональная деформация": ["профдеформация"],
    "профессионально-техническое училище": ["профессиональное техническое училище", "пту"],
    "профессиональное техническое училище": ["профессионально-техническое училище", "пту", "профтехучилище"],
    "профессиональное училище": ["пу", "профессионально-техническое училище", "профессиональное техническое училище", "пту", "учага"],
    "профессиональный": ["квалификационный", "квалифицированный"],
    "профессиональный жаргон": ["профессиолект"],
    "профессия": ["специальность", "ремесло"],
    "профессор": ["лектор", "мастер", "знаток"],
    "профессорствовав": ["профессорствовавши"],
    "профессорствовавши": ["профессорствовав"],
    "профессура": ["профессорство", "профессорат"],
    "профи": ["профессиональный спортсмен", "профессионал", "специалист"],
    "профилактика": ["предупреждение"],
    "профилактировав": ["профилактировавши"],
    "профилактировавши": ["профилактировав"],
    "профилировав": ["профилировавши"],
    "профилировавши": ["профилировав"],
    "профилирующий": ["профильный"],
    "профильный": ["контурный", "фигурный", "профилирующий"],
    "профильный погонаж": ["столярная тяга"],
    "профильтровав": ["профильтровавши"],
    "профильтровавши": ["профильтровав"],
    "профильтровывав": ["профильтровывавши"],
    "профильтровывавши": ["профильтровывав"],
    "профинансировав": ["профинансировавши"],
    "профинансировавши": ["профинансировав"],
    "профинтив": ["профинтивши"],
    "профинтивши": ["профинтив"],
    "профискалив": ["профискаливши"],
    "профискаливши": ["профискалив"],
    "профит": ["выгода", "прибыль", "барыш", "интерес", "польза", "толк", "прок", "благо"],
    "профицит": ["бюджетный профицит", "торговый профицит"],
    "профком": ["местком", "профбюро"],
    "профлидер": ["профбосс"],
    "профлист": ["профнастил"],
    "профнастил": ["профлист"],
    "профорганизатор": ["профорг"],
    "профосмотр": ["профилактический осмотр", "медосмотр", "диспансеризация"],
    "профпригодность": ["профессиональная пригодность"],
    "профсоюз": ["профессиональный союз"],
    "профтехучилище": ["пту", "профучилище"],
    "профузный": ["обильный", "сильный"],
    "профукав": ["профукавши"],
    "профукавши": ["профукав"],
    "профукать": ["профинтить", "промотать", "профуфукать"],
    "профукивав": ["профукивавши"],
    "профукивавши": ["профукивав"],
    "профукивать": ["растрачивать", "разбазаривать", "транжирить"],
    "профура": ["профурсетка", "проститутка"],
    "профургаловский": ["профургальский"],
    "профургальский": ["профургаловский"],
    "профурсетка": ["проститутка", "путана", "профура", "шлюха", "бичёвка", "блядь", "гулящая девка", "подстилка", "потаскунья", "потаскуха", "модница", "щеголиха", "кокетка", "вертихвостка"],
    "профуфукав": ["профуфукавши"],
    "профуфукавши": ["профуфукав"],
    "профучилище": ["профтехучилище", "пту"],
    "прохаживав": ["прохаживавши"],
    "прохаживавши": ["прохаживав"],
    "прохаживаться": ["прогуливаться"],
    "прохарчив": ["прохарчивши"],
    "прохарчивши": ["прохарчив"],
    "прохати": ["просити"],
    "прохварывав": ["прохварывавши"],
    "прохварывавши": ["прохварывав"],
    "прохватив": ["прохвативши"],
    "прохвативши": ["прохватив"],
    "прохватывав": ["прохватывавши"],
    "прохватывавши": ["прохватывав"],
    "прохворав": ["прохворавши"],
    "прохворавши": ["прохворав"],
    "прохвост": ["подлец", "негодяй", "дурак", "профос"],
    "прохиндей": ["мошенник", "махинатор", "жулик", "аферист", "плут"],
    "прохиндейство": ["жульничать", "ловкачествовать", "ловчить", "мошенничать"],
    "прохиндействовав": ["прохиндействовавши"],
    "прохиндействовавши": ["прохиндействовав"],
    "прохладив": ["прохладивши"],
    "прохладивши": ["прохладив"],
    "прохладно": ["холодновато", "холодно", "равнодушно", "безразлично", "зябко"],
    "прохладный": ["свежий", "равнодушный", "холодно-безразличный"],
    "прохладца": ["холодок", "холод"],
    "прохлаждав": ["прохлаждавши"],
    "прохлаждавши": ["прохлаждав"],
    "прохлаждаться": ["бездельничать", "тунеядствовать"],
    "прохлаждение": ["охлаждение"],
    "прохлажденье": ["прохлаждение"],
    "прохлопав": ["прохлопавши"],
    "прохлопавши": ["прохлопав"],
    "прохлопать": ["проморгать", "прозевать"],
    "прохлопотав": ["прохлопотавши"],
    "прохлопотавши": ["прохлопотав"],
    "прохлопывав": ["прохлопывавши"],
    "прохлопывавши": ["прохлопывав"],
    "прохныкав": ["прохныкавши"],
    "прохныкавши": ["прохныкав"],
    "проход": ["прохождение", "марш", "раз"],
    "проходив": ["проходивши"],
    "проходивши": ["проходив"],
    "проходимец": ["плут", "мошенник", "пройдоха", "проныра", "жулик", "прохожий"],
    "проходка": ["контрамарка", "флаер"],
    "прохождение": ["проход"],
    "прохожденье": ["прохождение"],
    "прохожий": ["путник", "пешеход"],
    "прохозяйничав": ["прохозяйничавши"],
    "прохозяйничавши": ["прохозяйничав"],
    "прохолаживав": ["прохолаживавши"],
    "прохолаживавши": ["прохолаживав"],
    "прохолодив": ["прохолодивши"],
    "прохолодивши": ["прохолодив"],
    "прохоря": ["кирзачи", "кирза"],
    "прохохотав": ["прохохотавши"],
    "прохохотавши": ["прохохотав"],
    "прохрапев": ["прохрапевши"],
    "прохрапевши": ["прохрапев"],
    "прохрипев": ["прохрипевши"],
    "прохрипевши": ["прохрипев"],
    "прохромав": ["прохромавши"],
    "прохромавши": ["прохромав"],
    "прохронометрировав": ["прохронометрировавши"],
    "прохронометрировавши": ["прохронометрировав"],
    "прохрустев": ["прохрустевши"],
    "прохрустевши": ["прохрустев"],
    "прохрюкав": ["прохрюкавши"],
    "прохрюкавши": ["прохрюкав"],
    "прохудиться": ["продырявиться"],
    "проц": ["процессор", "цп", "камень"],
    "процарапав": ["процарапавши"],
    "процарапавши": ["процарапав"],
    "процарапывав": ["процарапывавши"],
    "процарапывавши": ["процарапывав"],
    "процарствовав": ["процарствовавши"],
    "процарствовавши": ["процарствовав"],
    "процветав": ["процветавши"],
    "процветавши": ["процветав"],
    "процветание": ["благоденствие", "преуспевание", "благополучие", "расцвет", "взлёт"],
    "процветанье": ["процветание"],
    "процветать": ["преуспевать", "цвести", "благоденствовать", "расцветать", "распускаться"],
    "процветающий": ["преуспевающий"],
    "процедив": ["процедивши"],
    "процедивши": ["процедив"],
    "процедить": ["отфильтровать", "профильтровать"],
    "процедурная": ["процедурный кабинет"],
    "процедурный кабинет": ["процедурная"],
    "процеживав": ["процеживавши"],
    "процеживавши": ["процеживав"],
    "процеживать": ["цедить", "фильтровать"],
    "процензуровав": ["процензуровавши"],
    "процензуровавши": ["процензуровав"],
    "процентиль": ["перцентиль", "центиль"],
    "процентировав": ["процентировавши"],
    "процентировавши": ["процентировав"],
    "процентщик": ["ростовщик"],
    "процентщица": ["ростовщица"],
    "процерковный": ["клерикальный"],
    "процессия": ["шествие", "процесыа"],
    "процессор": ["редактор"],
    "процитировав": ["процитировавши"],
    "процитировавши": ["процитировав"],
    "процокав": ["процокавши"],
    "процокавши": ["процокав"],
    "прочавкав": ["прочавкавши"],
    "прочавкавши": ["прочавкав"],
    "прочайничав": ["прочайничавши"],
    "прочайничавши": ["прочайничав"],
    "прочахнув": ["прочахнувши"],
    "прочахнувши": ["прочахнув"],
    "прочекав": ["прочекавши"],
    "прочекавши": ["прочекав"],
    "прочеканив": ["прочеканивши"],
    "прочеканивав": ["прочеканивавши"],
    "прочеканивавши": ["прочеканивав"],
    "прочеканивши": ["прочеканив"],
    "прочекать": ["чекнуть", "проверять"],
    "прочеркнув": ["прочеркнувши"],
    "прочеркнувши": ["прочеркнув"],
    "прочернев": ["прочерневши"],
    "прочерневши": ["прочернев"],
    "прочертив": ["прочертивши"],
    "прочертивши": ["прочертив"],
    "прочерчивав": ["прочерчивавши"],
    "прочерчивавши": ["прочерчивав"],
    "прочесав": ["прочесавши"],
    "прочесавши": ["прочесав"],
    "прочесть": ["прочитать", "зачитать"],
    "прочив": ["прочивши"],
    "прочивши": ["прочив"],
    "прочий": ["остальной", "другой", "оставшийся"],
    "прочиликав": ["прочиликавши"],
    "прочиликавши": ["прочиликав"],
    "прочинив": ["прочинивши"],
    "прочинивав": ["прочинивавши"],
    "прочинивавши": ["прочинивав"],
    "прочинивать": ["прочинять"],
    "прочинивши": ["прочинив"],
    "прочиняв": ["прочинявши"],
    "прочинявши": ["прочиняв"],
    "прочинять": ["прочинивать"],
    "прочирикав": ["прочирикавши"],
    "прочирикавши": ["прочирикав"],
    "прочистив": ["прочистивши"],
    "прочистивши": ["прочистив"],
    "прочитав": ["прочитавши"],
    "прочитавши": ["прочитав"],
    "прочитать": ["прочесть", "продекламировать"],
    "прочитывав": ["прочитывавши"],
    "прочитывавши": ["прочитывав"],
    "прочить": ["предназначать", "определять", "сулить", "заготовлять"],
    "прочихав": ["прочихавши"],
    "прочихавши": ["прочихав"],
    "прочихнув": ["прочихнувши"],
    "прочихнувши": ["прочихнув"],
    "прочищав": ["прочищавши"],
    "прочищавши": ["прочищав"],
    "прочкнув": ["прочкнувши"],
    "прочкнувши": ["прочкнув"],
    "прочнев": ["прочневши"],
    "прочневши": ["прочнев"],
    "прочнеть": ["крепчать", "крепнуть"],
    "прочность": ["крепкость", "устойчивость"],
    "прочный": ["крепкий", "долговечный", "неразрушенный", "целый", "сильный", "выносливый", "неизменный", "постоянный", "надёжный", "основательный", "солидный"],
    "прочувствовав": ["прочувствовавши"],
    "прочувствовавши": ["прочувствовав"],
    "прочувствовывав": ["прочувствовывавши"],
    "прочувствовывавши": ["прочувствовывав"],
    "прочухав": ["прочухавши"],
    "прочухавши": ["прочухав"],
    "прочухан": ["прочуханка", "натруска"],
    "прочуяв": ["прочуявши"],
    "прочуявши": ["прочуяв"],
    "прочь": ["вон", "долой", "подальше"],
    "прочёркивав": ["прочёркивавши"],
    "прочёркивавши": ["прочёркивав"],
    "прочёркивать": ["прочерчивать", "пересекать", "пронизывать"],
    "прочёсывав": ["прочёсывавши"],
    "прочёсывавши": ["прочёсывав"],
    "прошав": ["прошавши"],
    "прошавши": ["прошав"],
    "прошагав": ["прошагавши"],
    "прошагавши": ["прошагав"],
    "прошалив": ["прошаливши"],
    "прошаливши": ["прошалив"],
    "прошамкав": ["прошамкавши"],
    "прошамкавши": ["прошамкав"],
    "прошаренный": ["опытный", "квалифицированный", "подготовленный", "грамотный"],
    "прошарив": ["прошаривши"],
    "прошаривши": ["прошарив"],
    "прошаркав": ["прошаркавши"],
    "прошаркавши": ["прошаркав"],
    "прошароёбив": ["прошароёбивши"],
    "прошароёбивши": ["прошароёбив"],
    "прошва": ["прошивка"],
    "прошвырнув": ["прошвырнувши"],
    "прошвырнувши": ["прошвырнув"],
    "прошедши": ["пройдя"],
    "прошедший": ["прошествовавший"],
    "прошелестев": ["прошелестевши"],
    "прошелестевши": ["прошелестев"],
    "прошение": ["просьба", "ходатайство"],
    "прошенье": ["прошение"],
    "прошепелявив": ["прошепелявивши"],
    "прошепелявивши": ["прошепелявив"],
    "прошептав": ["прошептавши"],
    "прошептавши": ["прошептав"],
    "прошептать": ["шепнуть"],
    "прошерстив": ["прошерстивши"],
    "прошерстивши": ["прошерстив"],
    "прошествовав": ["прошествовавши"],
    "прошествовавши": ["прошествовав"],
    "прошибав": ["прошибавши"],
    "прошибавши": ["прошибав"],
    "прошибив": ["прошибивши"],
    "прошибивши": ["прошибив"],
    "прошив": ["прошивши"],
    "прошивав": ["прошивавши"],
    "прошивавши": ["прошивав"],
    "прошивальщик": ["программатор"],
    "прошивать": ["сшивать", "прострачивать", "пробивать", "проходить", "простреливать", "программировать", "пересекать"],
    "прошивка": ["прошивание"],
    "прошивши": ["прошив"],
    "прошипев": ["прошипевши"],
    "прошипевши": ["прошипев"],
    "прошка": ["прохор"],
    "прошколив": ["прошколивши"],
    "прошколивав": ["прошколивавши"],
    "прошколивавши": ["прошколивав"],
    "прошколивши": ["прошколив"],
    "прошкурив": ["прошкуривши"],
    "прошкуривав": ["прошкуривавши"],
    "прошкуривавши": ["прошкуривав"],
    "прошкуривши": ["прошкурив"],
    "прошлифовав": ["прошлифовавши"],
    "прошлифовавши": ["прошлифовав"],
    "прошлифовывав": ["прошлифовывавши"],
    "прошлифовывавши": ["прошлифовывав"],
    "прошлиховав": ["прошлиховавши"],
    "прошлиховавши": ["прошлиховав"],
    "прошлогодний снег": ["лишний", "бесполезный"],
    "прошлое": ["былое"],
    "прошлый": ["предыдущий", "предшествующий", "истекший", "прежний", "минувший", "миновавший", "прошедший", "ушедший"],
    "прошляпив": ["прошляпивши"],
    "прошляпивши": ["прошляпив"],
    "прошляпить": ["прозевать"],
    "прошлёпав": ["прошлёпавши"],
    "прошлёпавши": ["прошлёпав"],
    "прошмыгивав": ["прошмыгивавши"],
    "прошмыгивавши": ["прошмыгивав"],
    "прошмыгнув": ["прошмыгнувши"],
    "прошмыгнувши": ["прошмыгнув"],
    "прошнуровав": ["прошнуровавши"],
    "прошнуровавши": ["прошнуровав"],
    "прошнуровывав": ["прошнуровывавши"],
    "прошнуровывавши": ["прошнуровывав"],
    "прошпаклевав": ["прошпаклевавши"],
    "прошпаклевавши": ["прошпаклевав"],
    "прошпаклёвывав": ["прошпаклёвывавши"],
    "прошпаклёвывавши": ["прошпаклёвывав"],
    "прошпиговав": ["прошпиговавши"],
    "прошпиговавши": ["прошпиговав"],
    "прошпиговывав": ["прошпиговывавши"],
    "прошпиговывавши": ["прошпиговывав"],
    "прошприцевав": ["прошприцевавши"],
    "прошприцевавши": ["прошприцевав"],
    "проштамповав": ["проштамповавши"],
    "проштамповавши": ["проштамповав"],
    "проштамповывав": ["проштамповывавши"],
    "проштамповывавши": ["проштамповывав"],
    "проштемпелевав": ["проштемпелевавши"],
    "проштемпелевавши": ["проштемпелевав"],
    "проштемпелёвывав": ["проштемпелёвывавши"],
    "проштемпелёвывавши": ["проштемпелёвывав"],
    "проштилевав": ["проштилевавши"],
    "проштилевавши": ["проштилевав"],
    "проштопав": ["проштопавши"],
    "проштопавши": ["проштопав"],
    "проштопывав": ["проштопывавши"],
    "проштопывавши": ["проштопывав"],
    "проштудировав": ["проштудировавши"],
    "проштудировавши": ["проштудировав"],
    "проштудировать": ["изучить"],
    "проштукатурив": ["проштукатуривши"],
    "проштукатуривав": ["проштукатуривавши"],
    "проштукатуривавши": ["проштукатуривав"],
    "проштукатуривши": ["проштукатурив"],
    "прошумев": ["прошумевши"],
    "прошумевши": ["прошумев"],
    "прошуршав": ["прошуршавши"],
    "прошуршавши": ["прошуршав"],
    "прошутив": ["прошутивши"],
    "прошутивши": ["прошутив"],
    "прошучивав": ["прошучивавши"],
    "прошучивавши": ["прошучивав"],
    "прошушукав": ["прошушукавши"],
    "прошушукавши": ["прошушукав"],
    "прощав": ["прощавши"],
    "прощавши": ["прощав"],
    "прощай": ["прощайте"],
    "прощай молодость": ["прощайки"],
    "прощайки": ["прощай молодость"],
    "прощайте": ["прощай"],
    "прощание": ["прощанье"],
    "прощанье": ["прощание"],
    "прощать": ["извинять", "освобождать", "от"],
    "прощаясь": ["откланиваясь"],
    "проще пареной репы": ["проще простого", "плёвое дело", "проще пареной репы и солёного огурца"],
    "прощебетав": ["прощебетавши"],
    "прощебетавши": ["прощебетав"],
    "прощеголяв": ["прощеголявши"],
    "прощеголявши": ["прощеголяв"],
    "прощение": ["прощенье", "извинение", "помилование", "помилованье"],
    "прощенье": ["прощение"],
    "прощупав": ["прощупавши"],
    "прощупавши": ["прощупав"],
    "прощупывав": ["прощупывавши"],
    "прощупывавши": ["прощупывав"],
    "прощупыванье": ["прощупывание"],
    "прощёлкав": ["прощёлкавши"],
    "прощёлкавши": ["прощёлкав"],
    "проэкзаменовав": ["проэкзаменовавши"],
    "проэкзаменовавши": ["проэкзаменовав"],
    "проэкзаменовать": ["отэкзаменовать"],
    "проэкзаменовывав": ["проэкзаменовывавши"],
    "проэкзаменовывавши": ["проэкзаменовывав"],
    "проэкспериментировав": ["проэкспериментировавши"],
    "проэкспериментировавши": ["проэкспериментировав"],
    "проэкспонировав": ["проэкспонировавши"],
    "проэкспонировавши": ["проэкспонировав"],
    "проэкспонировать": ["засветить"],
    "проэструм": ["проэструс", "предтечка"],
    "проэструс": ["проэструм", "предтечка"],
    "проэтосамив": ["проэтосамивши"],
    "проэтосамивши": ["проэтосамив"],
    "проэтосамить": ["профукать", "просрать", "упустить"],
    "проюркивав": ["проюркивавши"],
    "проюркивавши": ["проюркивав"],
    "проюркивать": ["проскальзывать"],
    "проюркнув": ["проюркнувши"],
    "проюркнувши": ["проюркнув"],
    "проявив": ["проявивши"],
    "проявивши": ["проявив"],
    "проявитель": ["носитель"],
    "проявить": ["показать", "продемонстрировать", "выявить"],
    "проявиться": ["обнаружиться", "выявиться"],
    "проявление": ["манифестация"],
    "проявляв": ["проявлявши"],
    "проявлявши": ["проявляв"],
    "прояровизировав": ["прояровизировавши"],
    "прояровизировавши": ["прояровизировав"],
    "прояснев": ["проясневши"],
    "проясневши": ["прояснев"],
    "прояснив": ["прояснивши"],
    "прояснивав": ["прояснивавши"],
    "прояснивавши": ["прояснивав"],
    "прояснивши": ["прояснив"],
    "проясниться": ["опогодиться"],
    "проясняв": ["прояснявши"],
    "прояснявши": ["проясняв"],
    "прояснять": ["разъяснять", "выяснять"],
    "проёбщик": ["бездельник", "лодырь", "прогульщик", "сачкун"],
    "проёбщица": ["бездельница", "лодырница", "прогульщица"],
    "проёбывав": ["проёбывавши"],
    "проёбывавши": ["проёбывав"],
    "проёрзав": ["проёрзавши"],
    "проёрзавши": ["проёрзав"],
    "пруд": ["озерцо"],
    "пруд пруди": ["завались", "навалом", "хоть жопой ешь", "куры не клюют"],
    "прудив": ["прудивши"],
    "прудивши": ["прудив"],
    "прудонист": ["мютюэлист"],
    "пружина": ["рессора"],
    "пружинив": ["пружинивши"],
    "пружинивши": ["пружинив"],
    "пружинонавивочный": ["пружинно-навивочный"],
    "пружок": ["силок"],
    "пруса": ["прусса", "брусса", "бурса"],
    "прусиад": ["прусий"],
    "прусиада": ["пруса"],
    "прусиан": ["прусий"],
    "прусиана": ["киос"],
    "прусиас": ["плусиада"],
    "прусия": ["русь", "русия", "русция", "ругая"],
    "прусс": ["прус"],
    "прусса": ["пруса", "бурса", "брусса"],
    "пруссиада": ["прусиас", "брусса", "прусса", "плусиада", "гемлик", "киус", "киос", "ускюб", "киерос"],
    "пруссиас": ["прус"],
    "пруссий": ["прус", "прусий", "прусиус"],
    "прустит": ["рубиновое серебро", "рубиновая обманка", "серебряная обманка"],
    "прусъ": ["пресъ", "прысъ"],
    "прутняк": ["витекс"],
    "пруток": ["прутик"],
    "пруфлинк": ["пруф"],
    "пруха": ["удача", "везение", "везуха"],
    "пръч": ["козел"],
    "пръчка": ["съчка", "клечка", "клонче"],
    "прыг-скок": ["прыг-прыг", "скок-поскок"],
    "прыгав": ["прыгавши"],
    "прыгавши": ["прыгав"],
    "прыгалка": ["скакалка", "прыгалки"],
    "прыгалки": ["прыгалка", "скакалка"],
    "прыгание": ["прыганье"],
    "прыганье": ["прыгание"],
    "прыгать": ["подпрыгивать", "подскакивать", "скакать", "гарцевать"],
    "прыгивав": ["прыгивавши"],
    "прыгивавши": ["прыгивав"],
    "прыгнув": ["прыгнувши"],
    "прыгнувши": ["прыгнув"],
    "прыгнуть": ["скакнуть"],
    "прыгнуть на хуй": ["на хуй прыгнуть"],
    "прыгунчик": ["прыгун", "тетригид"],
    "прыжок": ["подскок", "скачок", "скок"],
    "прыскав": ["прыскавши"],
    "прыскавши": ["прыскав"],
    "прыскалка": ["брызгалка", "пшикалка"],
    "прыскун": ["прыскала"],
    "прыснув": ["прыснувши"],
    "прыснувши": ["прыснув"],
    "прыснуть": ["брызнуть", "рвануть"],
    "прысъ": ["прыскунъ", "прусъ"],
    "прыткий": ["подвижный", "резвый", "ловкий", "бойкий"],
    "прыть": ["прыткость", "резвость", "подвижность", "живость", "быстрота", "скорость"],
    "прыцемак": ["змярканне"],
    "прыщ": ["пупырь", "волдырь", "бубон", "бутон", "плюгавец", "хмырь"],
    "прыщавев": ["прыщавевши"],
    "прыщавевши": ["прыщавев"],
    "прыщик": ["пупырышек"],
    "прьсть": ["прахъ"],
    "пря": ["противостояние", "противоборство", "свара", "распря", "раздор", "грызня"],
    "прягать": ["натягивать"],
    "прядав": ["прядавши"],
    "прядавши": ["прядав"],
    "прядение": ["пряденье"],
    "пряженец": ["пряженик"],
    "пряжение": ["фритюр"],
    "пряженик": ["пряженец"],
    "пряженица": ["яичница"],
    "пряжив": ["пряживши"],
    "пряживши": ["пряжив"],
    "пряжка": ["аграф"],
    "пряля": ["прядильниця"],
    "прям": ["прямо", "ага", "ну да", "конечно", "а как же", "впрямь", "совершенно", "просто"],
    "прямая": ["прямая линия", "геодезическая линия"],
    "прямая линия": ["прямая"],
    "прямая трансляция": ["прямой эфир"],
    "прямив": ["прямивши"],
    "прямивши": ["прямив"],
    "прямик": ["прямье"],
    "прямиком": ["прямо", "напрямик", "напрямую", "впрямую", "прямичком", "прямки", "напрямки", "напролом", "открыто", "явно", "не", "скрывать", "без обиняков", "честно"],
    "прямить": ["выпрямлять"],
    "прямо-таки": ["истинно", "именно", "подлинно", "прямо", "точно", "действительно", "совсем"],
    "прямодушествовав": ["прямодушествовавши"],
    "прямодушествовавши": ["прямодушествовав"],
    "прямодушествовать": ["откровенничать"],
    "прямодушие": ["бесхитростность", "простодушие", "простосердечие"],
    "прямодушничать": ["простодушничать"],
    "прямодушно": ["откровенно", "чистосердечно"],
    "прямодушный": ["бесхитростный", "искренний", "откровенный"],
    "прямодушье": ["прямодушие"],
    "прямой": ["ровный", "вытянутый", "неискривлённый", "непосредственный", "буквальный", "откровенный", "настоящий"],
    "прямой порядок слов": ["порядок членов предложения"],
    "прямой эфир": ["прямой", "трансляция", "вещание"],
    "прямолинейно": ["прямо"],
    "прямота": ["прямизна", "искренность", "откровенность"],
    "прямые руки": ["рукастость", "умелость"],
    "прямёшенько": ["прямёхонько", "прямо-прямёшенько"],
    "пряно": ["терпко"],
    "пряность": ["пикантность", "терпкость", "острота", "специя"],
    "прянув": ["прянувши"],
    "прянувши": ["прянув"],
    "прянь парондома": ["шнама"],
    "прянь паронфты": ["мялень ваны"],
    "прянь шаракофты": ["прянь шарфты"],
    "прянь шарфты": ["прянь шаракофты"],
    "пряпорец": ["знаме", "хоръгва"],
    "пряслень": ["пряслице"],
    "пряслице": ["донце", "прясло", "пряслень"],
    "прясть": ["прядать"],
    "прясть на семь деревень": ["прясть на седьмое село"],
    "прятав": ["прятавши"],
    "прятавши": ["прятав"],
    "прятать": ["скрывать", "ховать"],
    "прятать голову в песок": ["прятать голову под крыло"],
    "прятать голову под крыло": ["прятать голову в песок"],
    "прятать концы в воду": ["хоронить концы в воду", "заметать следы"],
    "прятаться": ["укрываться", "скрываться", "затаиваться"],
    "прятки": ["прятушки", "пряталки"],
    "прятывав": ["прятывавши"],
    "прятывавши": ["прятывав"],
    "пряха": ["прядильщица"],
    "прячась": ["скрываясь"],
    "псака": ["катка"],
    "псалмист": ["псалмопевец"],
    "псалмопенье": ["псалмопение"],
    "псалом": ["спиричуэл", "госпел"],
    "псаломщик": ["дьячок", "чтец"],
    "псалтырь": ["псалтирь"],
    "псарь": ["собачар"],
    "псевдо-": ["квази-", "лже-", "ложно-"],
    "псевдоамилоидность": ["декстриноидность"],
    "псевдобульба": ["туберидий"],
    "псевдовектор": ["аксиальный вектор"],
    "псевдогалоген": ["галогеноид"],
    "псевдогапакс": ["мнимое слово", "лексикографическая фикция"],
    "псевдогосударственность": ["псевдогосударство"],
    "псевдогосударство": ["квазигосударство"],
    "псевдогражданственность": ["лжегражданственность"],
    "псевдоевклидов": ["псевдоэвклидов"],
    "псевдоинтеллектуализм": ["псевдоинтеллектуальность"],
    "псевдоискусство": ["лжеискусство"],
    "псевдоисторик": ["псевдоисторичка"],
    "псевдоклассицизм": ["ложноклассицизм"],
    "псевдокод": ["байт-код"],
    "псевдолитература": ["паралитература", "полулитература", "чтиво"],
    "псевдомузыка": ["антимузыка", "немузыка"],
    "псевдомыслитель": ["квазиучёный"],
    "псевдонаука": ["квазинаука", "лженаука", "паранаука"],
    "псевдонаучный": ["квазинаучный", "лженаучный", "ненаучный", "паранаучный"],
    "псевдоневрастенический": ["псевдоневрастения"],
    "псевдоним": ["аллоним", "астроним", "гетероним", "криптоним", "матроним", "ник", "никнейм", "сикона"],
    "псевдопаренхима": ["плектенхима"],
    "псевдопластичный": ["тиксотропный"],
    "псевдопоэзия": ["непоэзия"],
    "псевдопсихопатический": ["психопатоподобный"],
    "псевдопсихопатия": ["характеропатия"],
    "псевдоромб": ["ложноромб"],
    "псевдорусский": ["ложнорусский", "неорусский"],
    "псевдотеррорист": ["лжетеррорист"],
    "псевдотрахея": ["трахея"],
    "псевдоцерковь": ["лжецерковь"],
    "псевдоцикл": ["квазицикл"],
    "псевдоцилиндр": ["цилиндроид"],
    "псефит": ["псефолит", "псефитолит", "рудит"],
    "псефитология": ["псефитолитология"],
    "псив": ["псивши"],
    "псивши": ["псив"],
    "псидиум": ["гуава"],
    "псили": ["звательце", "тонкое придыхание"],
    "псина": ["собачища", "собачище", "псятина", "собачатина"],
    "псиный": ["собачий"],
    "псих": ["психопат", "нервнобольной", "душевнобольной"],
    "психанув": ["психанувши"],
    "психанувши": ["психанув"],
    "психбольной": ["душевнобольной", "псих"],
    "психиатор": ["психиатр"],
    "психиатр": ["мозговед"],
    "психическое здоровье": ["ментальное здоровье"],
    "психическое расстройство": ["психическая болезнь", "психическое заболевание"],
    "психичка": ["нервнобольная", "душевнобольная", "безумная", "маньячка", "садистка"],
    "психоаналептик": ["психостимулятор"],
    "психовав": ["психовавши"],
    "психовавши": ["психовав"],
    "психогенный": ["реактивный"],
    "психогностика": ["физиономика", "физиогномика", "человекознание"],
    "психодел": ["психоделика", "психоделия"],
    "психоделический рок": ["психоделик-рок"],
    "психоделический транс": ["пси-транс", "психоделик-транс"],
    "психоделичный": ["психоделический"],
    "психоз": ["нервотрёпка"],
    "психозить": ["психовать"],
    "психоизолятор": ["больница"],
    "психокинез": ["телекинез"],
    "психокодирование": ["психопрограммирование"],
    "психолог": ["мозгоправ", "душевед"],
    "психологизировав": ["психологизировавши"],
    "психологизировавши": ["психологизировав"],
    "психологиня": ["психологесса"],
    "психологическое насилие": ["моральное насилие"],
    "психология масс": ["массовая психология"],
    "психометрия": ["психометрика"],
    "психоневроз": ["невроз"],
    "психоневротический": ["невротический"],
    "психопат": ["псих"],
    "психопатический": ["психопатичный"],
    "психопатичный": ["психопатический"],
    "психопатия": ["социопатия", "диссоциальное расстройство личности", "антисоциальное расстройство личности", "конституциональная психопатия"],
    "психопатка": ["повреждённый", "ум", "скорбный", "голова"],
    "психопатоподобный": ["псевдопсихопатический"],
    "психопрограммирование": ["психокодирование"],
    "психорасстройство": ["психическое расстройство"],
    "психосоматический": ["психогенный"],
    "психотомиметик": ["психоделик", "психодислептик", "галлюциноген"],
    "психотренинг": ["психогимнастика"],
    "психотропное средство": ["психоактивное вещество"],
    "психотропный": ["психоактивный"],
    "психпомощь": ["психологическая помощь"],
    "психрометр": ["влагомер", "гигрометр"],
    "психрофил": ["криофил"],
    "псица": ["сука", "сучка"],
    "псковитянин": ["скобарь"],
    "пскович": ["псковитянин", "псковичанин"],
    "псковская область": ["псковщина"],
    "псковский": ["пскопской"],
    "псоас": ["поясничная мышца"],
    "псовев": ["псовевши"],
    "псовевши": ["псовев"],
    "псовство": ["свинство"],
    "псовый": ["собачий", "пёсий"],
    "псоглавец": ["кинокефал", "киноцефал", "песьеглавец", "песиголовец"],
    "псувня": ["ругатня", "попържня"],
    "псхъа": ["хъвади"],
    "псяра": ["песина", "песища", "псище"],
    "пта": ["птах"],
    "птах": ["пта"],
    "птаха": ["зануда"],
    "птв": ["пв"],
    "птенец": ["воспитанник", "ученик", "юнец", "писклёнок"],
    "птенчик": ["птенец"],
    "птеридофит": ["криптогам"],
    "птиалин": ["слюнное вещество", "амилаза"],
    "птица": ["птичка", "пичуга", "пичужка", "птаха", "пташка", "птичка божья", "птичка божия", "пернатые", "мясо", "дичь"],
    "птица обломинго": ["обломинго"],
    "птицеед": ["птицеяд"],
    "птиця": ["птах"],
    "птичий язык": ["заумь", "тарабарщина", "свистящий язык"],
    "птичка": ["птица", "птаха", "галочка", "птичий рынок", "самолёт", "вертолёт", "беспилотник", "бпла"],
    "птичку жалко": ["какая жалость"],
    "птичье молоко": ["зобное молоко", "голубиное молоко", "конфета"],
    "пту": ["пу"],
    "птушка": ["пташка"],
    "птушник": ["пэтэушник"],
    "птушница": ["пэтэушница"],
    "пуаз": ["пз"],
    "пуансеттия": ["молочай красивейший"],
    "пуансон": ["пунсон"],
    "пуант": ["пуанта", "панчлайн"],
    "пуантилизм": ["дивизионизм", "точечная музыка", "пунктуализм"],
    "пуантилистический": ["пуантилистский"],
    "пуантилистский": ["пуантилистический", "точечный"],
    "пуантировав": ["пуантировавши"],
    "пуантировавши": ["пуантировав"],
    "пуаре": ["перри"],
    "пуассардка": ["базарная баба"],
    "пубертат": ["половое созревание", "пубертатный период", "период полового созревания"],
    "пубертатный": ["пубертальный", "половозрелый"],
    "публикация": ["опубликование", "объявление", "статья", "доклад", "отчёт"],
    "публиковав": ["публиковавши"],
    "публиковавши": ["публиковав"],
    "публиковать": ["опубликовывать", "издавать"],
    "публиковаться": ["издаваться"],
    "публичив": ["публичивши"],
    "публичивши": ["публичив"],
    "публичная женщина": ["проститутка", "женщина лёгкого поведения", "блудница"],
    "публично": ["открыто", "гласно"],
    "публичный": ["открытый", "гласный", "официальный", "явный", "общественный"],
    "публичный дом": ["бордель", "бардак", "дом терпимости", "лупанарий", "дом свиданий"],
    "пувордамс": ["шаркстамс", "пяльдемс", "мувотьфтемс"],
    "пугав": ["пугавши"],
    "пугавши": ["пугав"],
    "пугало": ["страшило", "страшилище", "пугалище", "шугай", "пужало", "пужалище", "чудище", "чудовище", "жупел", "пистолет", "револьвер"],
    "пугало болотное": ["пугало огородное"],
    "пуганув": ["пуганувши"],
    "пуганувши": ["пуганув"],
    "пуганье": ["пугание"],
    "пугать": ["шугать", "запугивать", "стращать", "нагонять страх", "тревожить", "беспокоить", "страшить", "вызывать опасения", "устрашать", "ужасать", "предостерегать", "угрожать"],
    "пугать белого друга": ["рвать", "беседовать с белым другом", "дружить с белым другом", "дружиться с белым другом", "кормить белого друга", "кричать на белого друга", "обниматься с белым другом", "целоваться с белым другом", "жаловаться белому телефону"],
    "пугачёвщина": ["пугачёвское восстание", "пугачёвский бунт", "восстание пугачёва"],
    "пугивав": ["пугивавши"],
    "пугивавши": ["пугивав"],
    "пугливый": ["боязливый", "боящийся", "нерешительный", "несмелый", "опасливый", "пужливый", "робкий", "трусливый"],
    "пугнув": ["пугнувши"],
    "пугнувши": ["пугнув"],
    "пуговичка": ["пуговка"],
    "пугуданьдьэ": ["шар"],
    "пудель": ["курчавка", "кудрявка"],
    "пуделяв": ["пуделявши"],
    "пуделявши": ["пуделяв"],
    "пуделять": ["мазать", "промахиваться"],
    "пудермантель": ["пеньюар", "пудромант", "пудремантель", "пудромантель"],
    "пудив": ["пудивши"],
    "пудивши": ["пудив"],
    "пудлинговав": ["пудлинговавши"],
    "пудлинговавши": ["пудлинговав"],
    "пудлингование": ["пудлинговка"],
    "пудло": ["пуделко"],
    "пудовый": ["пудовой"],
    "пудрив": ["пудривши"],
    "пудривав": ["пудривавши"],
    "пудривавши": ["пудривав"],
    "пудривши": ["пудрив"],
    "пудрить мозги": ["парить"],
    "пудромантель": ["пеньюар", "пудромант", "пудремантель", "пудермантель", "нагоняй", "разнос", "нахлобучка", "выволочка", "взбучка", "вздрючка", "головомойка"],
    "пужав": ["пужавши"],
    "пужавши": ["пужав"],
    "пужално": ["батожилно"],
    "пужанув": ["пужанувши"],
    "пужанувши": ["пужанув"],
    "пужаться": ["пугаться"],
    "пузан": ["карапуз"],
    "пузанив": ["пузанивши"],
    "пузанивши": ["пузанив"],
    "пузанина": ["пузонина"],
    "пузастый": ["брюхатый", "брюхастый", "пузатый"],
    "пузатый": ["брюхатый", "брюхастый", "пузастый"],
    "пузико": ["животик"],
    "пузо": ["брюхо", "пузянка", "пузяка"],
    "пузожитель": ["эмбрион", "зародыш"],
    "пузомерка": ["фаллометрия"],
    "пузонина": ["пузанина"],
    "пузырив": ["пузыривши"],
    "пузыривши": ["пузырив"],
    "пузыристый": ["пузырчатый"],
    "пузырник": ["нут", "бараний горох", "двузерный горох"],
    "пузырёк": ["флакончик", "бутылёк"],
    "пузырёчек": ["пузырёк"],
    "пук": ["пучок"],
    "пукав": ["пукавши"],
    "пукавши": ["пукав"],
    "пукание": ["пуканье"],
    "пуканье": ["пукание"],
    "пукать": ["бздеть", "пердеть"],
    "пукина": ["тиуанако"],
    "пуклевав": ["пуклевавши"],
    "пуклевавши": ["пуклевав"],
    "пукло куд пукло": ["било шта било"],
    "пукля": ["букля", "завиток"],
    "пукнув": ["пукнувши"],
    "пукнувши": ["пукнув"],
    "пулакча": ["фалс"],
    "пулевое ранение": ["пулевая рана"],
    "пулей": ["молнией", "мухой", "на всех парах", "мгновенно"],
    "пули лить": ["заливать", "вешать лапшу на уши", "лить пули", "отливать пули", "лапшу на уши вешать", "пули отливать"],
    "пуловер": ["свитер", "пулловер"],
    "пульверизатор": ["брызгалка", "пшикалка", "опрыскиватель", "краскораспылитель"],
    "пульверизировав": ["пульверизировавши"],
    "пульверизировавши": ["пульверизировав"],
    "пульверизовав": ["пульверизовавши"],
    "пульверизовавши": ["пульверизовав"],
    "пулька": ["пуля", "преферанс"],
    "пульмонология": ["пневмология", "респираторная медицина", "грудная медицина"],
    "пульнув": ["пульнувши"],
    "пульнувши": ["пульнув"],
    "пульнуть": ["стрельнуть", "выстрелить", "пальнуть", "бросить", "запулить", "швырнуть"],
    "пульпировав": ["пульпировавши"],
    "пульпировавши": ["пульпировав"],
    "пульс": ["пульсация", "биение", "сердечный ритм", "частота пульса", "ритм", "темп"],
    "пульсация": ["толчки"],
    "пульсиметр": ["пульсометр", "пульсотахометр"],
    "пульсировав": ["пульсировавши"],
    "пульсировавши": ["пульсировав"],
    "пульсировать": ["вибрировать"],
    "пульсовое давление": ["пульсовое артериальное давление", "кровяное пульсовое давление"],
    "пульсовой": ["пульсовый"],
    "пульсовый": ["пульсовой"],
    "пульсоксиметрия": ["оксигемометрия", "гемоксиметрия"],
    "пульт": ["пюпитр", "штатив", "панель управления"],
    "пульт дистанционного управления": ["пду", "пульт", "дистанционка", "дистанционник", "ленивка", "лентяйка", "рулилка"],
    "пульхерия": ["пулькерия"],
    "пульхеррима": ["мирак", "мерах", "мерер", "мезен", "мезер", "ицар"],
    "пуля": ["пулька"],
    "пуляв": ["пулявши"],
    "пулявши": ["пуляв"],
    "пулярда": ["пулярка"],
    "пулярдка": ["пулярка", "пулярда"],
    "пулярка": ["пулярда", "пулярдка"],
    "пулять": ["шмалять", "посылать", "отправлять", "пересылать"],
    "пума": ["кугуар", "горный лев"],
    "пунец": ["кумач"],
    "пункт": ["точка"],
    "пунктировав": ["пунктировавши"],
    "пунктировавши": ["пунктировав"],
    "пунктуальность": ["точность"],
    "пунктуальный": ["тщательный", "педантичный", "скрупулёзный"],
    "пунктуация": ["интерпункция"],
    "пункция": ["прокол"],
    "пуночка": ["снежный подорожник"],
    "пунсон": ["пуансон"],
    "пунт": ["та-нечер"],
    "пунтер": ["понтёр"],
    "пунцевав": ["пунцевавши"],
    "пунцевавши": ["пунцевав"],
    "пунцевать": ["пуншевать"],
    "пунцевев": ["пунцевевши"],
    "пунцевевши": ["пунцевев"],
    "пунцовев": ["пунцовевши"],
    "пунцовевши": ["пунцовев"],
    "пунцоветь": ["краснеть", "алеть"],
    "пунцовиться": ["пунцоветь"],
    "пунцовый": ["тёмно-алый", "тёмно-багряный", "багровый", "кровавый"],
    "пуншевав": ["пуншевавши"],
    "пуншевавши": ["пуншевав"],
    "пуп": ["пупок", "пупырь"],
    "пупавка": ["антемис"],
    "пупарий": ["ложнококон"],
    "пупартовый": ["пупартов"],
    "пупкин": ["вася пупкин", "иванов"],
    "пуповина": ["связь"],
    "пупочка": ["шишечка", "пупырышек"],
    "пупс": ["пупсик"],
    "пупсик": ["пупс", "куколка"],
    "пупыристый": ["пупырчатый"],
    "пупырчатый": ["пупыристый"],
    "пупырышек": ["прыщик"],
    "пупырь": ["прыщ"],
    "пургатив": ["пюргатив", "пургатива", "слабительное"],
    "пургаторий": ["чистилище"],
    "пургаториус": ["пургаторий"],
    "пурген": ["фенолфталеин"],
    "пургенчик": ["фенолфталеинчик"],
    "пурговав": ["пурговавши"],
    "пурговавши": ["пурговав"],
    "пурда": ["парда"],
    "пуржив": ["пурживши"],
    "пурживши": ["пуржив"],
    "пуржить": ["вьюжить", "буранить", "мести", "гнать пургу", "обманывать", "врать", "лгать", "гнать", "втирать"],
    "пуризм": ["ригоризм", "пуританство"],
    "пурист": ["ригорист", "пуристка"],
    "пуританизм": ["пуританство"],
    "пурпур": ["багряный", "цвет"],
    "пурпурный": ["пурпуровый", "кумачовый", "сольферино", "пунцовый", "порфирный", "багряный", "алый"],
    "пурпурово-фиолетовый": ["фиолетово-пурпурный"],
    "пурпуровый": ["багряный", "червлёный", "пурпурный"],
    "пурсиш": ["суол"],
    "пусия": ["засада"],
    "пуск": ["запуск", "включение"],
    "пускав": ["пускавши"],
    "пускавши": ["пускав"],
    "пускай": ["пусть", "допустим", "положим", "нехай", "пущай"],
    "пусканье": ["пускание"],
    "пускать в трубу": ["разорять", "пускать по ветру", "бросать на ветер"],
    "пускать пыль в глаза": ["набивать себе цену", "хвастаться", "морочить", "надувать"],
    "пускаться": ["отправляться", "бросаться"],
    "пускач": ["пусковой двигатель"],
    "пусковая установка": ["пу"],
    "пустев": ["пустевши"],
    "пустевши": ["пустев"],
    "пустельга": ["обыкновенная пустельга", "пустышка", "пустячок", "вещица"],
    "пустив": ["пустивши"],
    "пустивши": ["пустив"],
    "пустир": ["пустирище"],
    "пустить": ["отпустить", "пропустить", "впустить", "запустить", "направить", "бросить", "выпустить", "подпустить", "распространить"],
    "пустить в расход": ["пристрелить", "шлёпнуть", "укокошить", "списать", "списать в расход", "пустить в распыл", "пустить на распыл", "вывести в расход", "поставить к стенке", "дать вышака", "отправить на луну", "отправить в штаб духонина", "отправить в штаб к духонину"],
    "пустить корни": ["укорениться", "обосноваться", "прижиться"],
    "пустить красного петуха": ["поджечь"],
    "пустить по миру": ["разорить"],
    "пустить под откос": ["угробить"],
    "пустить рыбу ловить": ["отправить рыб кормить"],
    "пуститься во все тяжкие": ["удариться во все тяжкие"],
    "пусто": ["пустынно", "одиноко"],
    "пустобрёх": ["пустолайка", "пустобрёшка", "пустомеля", "пустозвон", "пустослов", "враль", "врун"],
    "пустовав": ["пустовавши"],
    "пустовавши": ["пустовав"],
    "пустодомничав": ["пустодомничавши"],
    "пустодомничавши": ["пустодомничав"],
    "пустозвонив": ["пустозвонивши"],
    "пустозвонивши": ["пустозвонив"],
    "пустозвонничав": ["пустозвонничавши"],
    "пустозвонничавши": ["пустозвонничав"],
    "пустозвонничать": ["пустозвонить"],
    "пустой": ["пустующий", "опустевший", "опустелый", "порожний", "полый", "незаполненный", "необитаемый", "нежилой", "незаселённый", "ненаселённый"],
    "пустой номер": ["дохлый номер", "тщетно", "бесполезно"],
    "пустой чай": ["голый чай", "гольный чай"],
    "пустоколосый": ["бесколосый", "бесколосный"],
    "пустолаяв": ["пустолаявши"],
    "пустолаявши": ["пустолаяв"],
    "пустомелив": ["пустомеливши"],
    "пустомеливши": ["пустомелив"],
    "пустопляс": ["гуляка"],
    "пустопорожний": ["бессмысленный", "бесполезный"],
    "пустословив": ["пустословивши"],
    "пустословивши": ["пустословив"],
    "пустословие": ["болтовня", "пустобрёхство", "пустозвонство", "празднословие", "словоблудие", "пустая болтовня", "пустословье"],
    "пустословить": ["ветер гонять"],
    "пустословье": ["пустословие"],
    "пустота": ["вакуум", "ничто"],
    "пустотелость": ["полость"],
    "пустотелый": ["полый"],
    "пустотный": ["пустынный", "полый"],
    "пустошив": ["пустошивши"],
    "пустошивши": ["пустошив"],
    "пустушка": ["удод", "потатуйка"],
    "пустующий": ["пустой", "опустевший", "опустелый", "порожний"],
    "пустынник": ["пустынножитель", "анахорет", "отшельник", "скитник", "затворник"],
    "пустынница": ["затворница", "скитница", "пустынножительница", "отшельница", "анахоретка"],
    "пустынничав": ["пустынничавши"],
    "пустынничавши": ["пустынничав"],
    "пустынничий": ["пустыннический"],
    "пустынно": ["безлюдно", "пусто"],
    "пустынножитель": ["пустынник"],
    "пустынножительствовав": ["пустынножительствовавши"],
    "пустынножительствовавши": ["пустынножительствовав"],
    "пустынность": ["необитаемость", "малолюдность", "глушь"],
    "пустынный": ["безлюдный", "глухой"],
    "пустынный сорокопут": ["южный серый сорокопут"],
    "пустынь": ["скит"],
    "пустыня": ["пустошь", "пустынь"],
    "пустырник": ["глухая крапива", "сердечная трава", "сердечник", "собачья крапива", "пустырь", "пустошь"],
    "пустышка": ["оболочка", "пустой", "обманка", "видимость", "иллюзия", "фикция", "шиш", "ерунда", "бессодержательный", "незначимый", "соска"],
    "пусть": ["да", "пускай", "незомь", "хотя", "несмотря на"],
    "пустяк": ["легкотня"],
    "пустяковый": ["ничтожный", "малозначимый", "пустячный", "небольшой", "незначительный", "нетрудный", "несложный", "простой"],
    "пустячный": ["пустяковый", "незначительный", "ерундовый"],
    "пут": ["пут-опцион"],
    "путав": ["путавши"],
    "путавши": ["путав"],
    "путамен": ["скорлупа"],
    "путана": ["проститутка"],
    "путанив": ["путанивши"],
    "путанивши": ["путанив"],
    "путанье": ["путание"],
    "путать": ["запутывать", "перепутывать", "путаться", "сбивать с толку", "сбивать с панталыку", "вмешивать", "вовлекать", "связывать", "плутать", "блудить", "сбиться", "бродить"],
    "путаться": ["запутываться", "спутываться"],
    "путевод": ["проводник", "путеводитель", "путевождь", "путеводец", "путевожатый"],
    "путеводив": ["путеводивши"],
    "путеводивши": ["путеводив"],
    "путеводитель": ["проводник", "бедекер"],
    "путеводный": ["путеводительный", "ведущий", "направляющий", "руководящий", "указывающий"],
    "путевой": ["дорожный", "путейский"],
    "путеочиститель": ["скотоотбрасыватель"],
    "путешественник": ["странник", "скиталец"],
    "путешественница": ["странница"],
    "путешествие": ["поездка", "странствие", "вояж", "хождение"],
    "путешествовав": ["путешествовавши"],
    "путешествовавши": ["путешествовав"],
    "путешествовать": ["странствовать"],
    "путин": ["пуцин"],
    "путина": ["лов", "путь", "дорога"],
    "путинец": ["путинист", "запутинец", "путиноид", "путлеровец"],
    "путинист": ["путинец"],
    "путиноид": ["путлеровец", "запутинец"],
    "путинофобия": ["антипутинизм"],
    "путинские каникулы": ["карантикулы"],
    "путлеровец": ["путиноид", "запутинец"],
    "путлище": ["путло", "путля", "путы"],
    "путло": ["путы", "путлище", "путля"],
    "путля": ["путлище", "путло"],
    "путляв": ["путлявши"],
    "путлявши": ["путляв"],
    "путник": ["странник", "шественник"],
    "путно": ["путёво"],
    "путный": ["путёвый", "толковый"],
    "путо": ["бабка"],
    "путомс пиле": ["кулхцондозевомс", "кулхцондомс"],
    "путомс эряфцень": ["тумс прянек"],
    "путперестлик": ["ширк"],
    "путридный": ["гнилостный", "гниющий", "гнойный"],
    "путч": ["мятеж", "переворот", "революция", "заговор", "восстание"],
    "путчист": ["мятежник", "бунтарь", "революционер"],
    "путы": ["тенёта"],
    "путывав": ["путывавши"],
    "путывавши": ["путывав"],
    "путь": ["дорога", "путь к файлу", "полное имя файла", "имя файла"],
    "путёвый": ["дельный", "путный", "толковый", "пригодный"],
    "путём": ["нормально", "в порядке"],
    "пуукко": ["финский нож"],
    "пуфнув": ["пуфнувши"],
    "пуфнувши": ["пуфнув"],
    "пух": ["пушок"],
    "пухленький": ["пухлый", "толстенький"],
    "пухлый": ["располневший", "одутловатый"],
    "пухлявый": ["пухлый"],
    "пухляк": ["уброд", "опухоль", "пухота", "волчеягодник обыкновенный", "волчеягодник смертельный", "волчник обыкновенный", "волчье лыко", "волчий перец", "волчьи ягоды", "плоховец"],
    "пухляш": ["пухляк", "толстяк"],
    "пухнастий": ["пухнатий"],
    "пухнув": ["пухнувши"],
    "пухнувши": ["пухнув"],
    "пухнуть": ["округляться", "вздуваться"],
    "пуховик": ["перина", "пуховник", "пуховка", "пухан"],
    "пуховка": ["пуховик"],
    "пухоед": ["вошь"],
    "пухто": ["мусорный", "контейнер"],
    "пуцин": ["путин"],
    "пучел": ["пучела"],
    "пучение": ["метеоризм", "вздутие"],
    "пученье": ["пучение"],
    "пучив": ["пучивши"],
    "пучивши": ["пучив"],
    "пучить": ["вздувать", "выпячивать"],
    "пуш-уведомление": ["пуш"],
    "пушив": ["пушивши"],
    "пушивши": ["пушив"],
    "пушистик": ["фуррь"],
    "пушистый": ["мохнатый", "ворсистый", "махровый"],
    "пушиться": ["распушаться"],
    "пушка": ["артиллерийское орудие", "волына", "огнестрел"],
    "пушкарский": ["канонирский"],
    "пушкарь": ["канонир", "бомбардир", "артиллерист"],
    "пушкинизм": ["пушкинистика", "пушкиноведение"],
    "пушкинист": ["пушкиновед"],
    "пушкинистика": ["пушкиноведение"],
    "пушкиновед": ["пушкинист"],
    "пушкиноведение": ["пушкинистика", "пушкинизм", "пушкинианство"],
    "пушонка": ["гидроксид кальция", "гашёная известь", "едкая известь"],
    "пуштун": ["пухтун"],
    "пуща": ["чаща", "чащоба"],
    "пущав": ["пущавши"],
    "пущавши": ["пущав"],
    "пуще": ["больше", "сильнее", "шибче"],
    "пущий": ["больший"],
    "пущинак": ["пустош", "пустота"],
    "пуэбла": ["свободный и суверенный штат пуэбла"],
    "пуэрперальный": ["послеродовой"],
    "пф": ["пенсионный фонд"],
    "пфальцграф": ["граф-палатин", "палатин", "граф дворца"],
    "пфенниг": ["пфенинг", "пфеннинг"],
    "пфропфшизофрения": ["олигошизофрения"],
    "пхав": ["пхавши"],
    "пхавши": ["пхав"],
    "пхати": ["штовхати", "запихати"],
    "пхаться": ["толкаться", "пихаться"],
    "пхд": ["парково-хозяйственный день", "пиздец хорошему дню", "пункт хозяйственного довольствия"],
    "пхеньян": ["рюгён"],
    "пхнув": ["пхнувши"],
    "пхнувши": ["пхнув"],
    "пхнуть": ["толкнуть", "пихнуть"],
    "пхнуться": ["пихнуться"],
    "пхув": ["строна", "свэто"],
    "пхурт": ["подо", "пато", "мосто"],
    "пчак": ["печак"],
    "пчалярства": ["пчалаводства"],
    "пчела": ["пчёлка"],
    "пчела-убийца": ["африканизированная пчела"],
    "пчелиный клей": ["прополис", "уза"],
    "пчеловод": ["пчеловодец", "пчелинец", "пчеляк", "пасечник"],
    "пчеловодец": ["пчеловод", "пчелинец", "пчеляк", "пасечник"],
    "пчеловодный": ["пчеловодческий"],
    "пчеловодство": ["бортничество", "пасека"],
    "пчелоед": ["осоед", "орёл-пчелоед", "коршун-пчелоед", "щурка", "щур-пчелоед", "пчелоедка", "пчелиный волк", "филант"],
    "пчельник": ["пасека"],
    "пчихати": ["чхати"],
    "пчёлонька": ["пчёлочка"],
    "пшав": ["пшавел", "пшавец"],
    "пшат": ["лох", "джидда"],
    "пшек": ["поляк", "лях"],
    "пшекав": ["пшекавши"],
    "пшекавши": ["пшекав"],
    "пшекнув": ["пшекнувши"],
    "пшекнувши": ["пшекнув"],
    "пшекнуть": ["пискнуть"],
    "пшеница": ["пшено"],
    "пшеничный": ["золотистый"],
    "пшено": ["ерунда", "лабуда", "фигня"],
    "пшикав": ["пшикавши"],
    "пшикавши": ["пшикав"],
    "пшикалка": ["пульверизатор", "распылитель", "спрей", "брызгалка", "сикалка"],
    "пшикаться": ["душиться"],
    "пшикнув": ["пшикнувши"],
    "пшикнувши": ["пшикнув"],
    "пшют": ["пошляк", "фат", "хлыщ"],
    "пшёнка": ["пшено"],
    "пщащэ": ["хъыджэбз"],
    "пъдар": ["пазач"],
    "пън": ["дънер", "дърво", "дръвник", "кютюк", "недодялан", "простак", "тъп", "тъпоумен", "тъпак", "дебелак", "глупак"],
    "пъпеш": ["пипон", "диня"],
    "първолак": ["първокласник"],
    "пъстрина": ["пъстрота"],
    "път": ["друм", "друмище", "пътека", "шосе", "улица"],
    "пътник": ["пасажер", "странник", "друмник", "пътешественик", "турист", "скитник", "чуждестранец"],
    "пыд": ["кук"],
    "пыжив": ["пыживши"],
    "пыживши": ["пыжив"],
    "пыжиться": ["тужиться", "горбатиться", "потеть", "биться", "выкладываться", "жилиться", "ловчиться", "надрываться", "силиться", "тщиться", "усердствовать", "корпеть", "чваниться", "кичиться", "ерепениться"],
    "пыл": ["жар", "горячность", "пылкость", "энтузиазм", "рвение"],
    "пылавши": ["пылав"],
    "пыланье": ["пылание"],
    "пылатыны": ["миськыны"],
    "пылать": ["гореть", "краснеть"],
    "пылевидный": ["пылеобразный", "порошковидный", "порошкообразный"],
    "пылегазовый": ["газопылевой"],
    "пылеобразный": ["пылевидный", "порошковидный"],
    "пылесосив": ["пылесосивши"],
    "пылесосивши": ["пылесосив"],
    "пылив": ["пыливши"],
    "пыливши": ["пылив"],
    "пылить": ["порошить"],
    "пылко": ["ярко", "жарко", "пламенно", "страстно", "горячо"],
    "пылкость": ["страстность", "горячность", "пламенность"],
    "пыль": ["прах"],
    "пыльная буря": ["самум"],
    "пыльцевход": ["микропиле"],
    "пыр": ["пырь"],
    "пыриться": ["уставиться", "разглядывать", "смотреть"],
    "пырнув": ["пырнувши"],
    "пырнувши": ["пырнув"],
    "пырнуться": ["упороться"],
    "пырскав": ["пырскавши"],
    "пырскавши": ["пырскав"],
    "пырскать": ["прыскать"],
    "пырснув": ["пырснувши"],
    "пырснувши": ["пырснув"],
    "пырхав": ["пырхавши"],
    "пырхавши": ["пырхав"],
    "пыряв": ["пырявши"],
    "пырявши": ["пыряв"],
    "пырять": ["вонзать", "колоть", "толкать", "ударять", "швырять"],
    "пысав": ["пысавши"],
    "пысавши": ["пысав"],
    "пытав": ["пытавши"],
    "пытавши": ["пытав"],
    "пытать": ["истязать", "мучить", "расспрашивать", "спрашивать", "дознаваться", "проверять", "испытывать"],
    "пытаться": ["стараться", "силиться", "тужиться", "стремиться"],
    "пытка": ["истязание", "мучение", "терзание"],
    "пытливо": ["дотошно"],
    "пытливый": ["любознательный"],
    "пых": ["курево", "пыхово"],
    "пыхав": ["пыхавши"],
    "пыхавши": ["пыхав"],
    "пыхать": ["вспыхивать", "пыхтеть", "попыхивать", "курить"],
    "пыхнув": ["пыхнувши"],
    "пыхнувши": ["пыхнув"],
    "пыхтенье": ["пыхтение"],
    "пыхтеть": ["отдуваться", "кряхтеть", "вкалывать", "стараться", "напрягаться", "корячиться"],
    "пычрак": ["кер"],
    "пышав": ["пышавши"],
    "пышавши": ["пышав"],
    "пышать": ["пыхать"],
    "пышка": ["пампушка", "пончик"],
    "пышнев": ["пышневши"],
    "пышневши": ["пышнев"],
    "пышноволосый": ["шевелюристый"],
    "пышногрудый": ["грудастый"],
    "пышный": ["взбитый", "пухлый", "роскошный", "нарядный", "помпезный", "великолепный", "напыщенный", "высокопарный", "высокий"],
    "пье": ["фут"],
    "пьедестал": ["постамент", "возвышение", "основание", "подножие", "подножье", "стояло", "подстой", "подставка", "подстава", "пьедестал почёта", "авторитет"],
    "пьедестал почёта": ["пьедестал"],
    "пьезодатчик": ["пьезоэлектрический датчик"],
    "пьезофил": ["барофил"],
    "пьемонтский": ["пьемонтский язык"],
    "пьер": ["пётр"],
    "пьеро": ["плакса", "меланхолик"],
    "пьеса": ["стихотворение"],
    "пьютер": ["посудное олово"],
    "пьянев": ["пьяневши"],
    "пьяневши": ["пьянев"],
    "пьянее": ["пьяней", "хмельнее", "хмельней"],
    "пьяней": ["хмельней", "хмельнее"],
    "пьянеть": ["хмелеть"],
    "пьянив": ["пьянивши"],
    "пьянивши": ["пьянив"],
    "пьяника": ["голубика", "голубица", "гоноболь", "гонобобель", "дурника", "сизый", "синеватый"],
    "пьянист": ["пианист"],
    "пьянистка": ["пианистка"],
    "пьяниться": ["опьяняться"],
    "пьяница": ["фараон"],
    "пьянственный": ["алкоголический", "забулдыжный"],
    "пьянство": ["алкоголизм"],
    "пьянствовав": ["пьянствовавши"],
    "пьянствовавши": ["пьянствовав"],
    "пьянчуга": ["алкаш", "пропойца", "пьяница", "пьянюга"],
    "пьянчужка": ["пьяница"],
    "пьяный-распьяный": ["пьянющий"],
    "пьянь": ["пьянчуга", "алкаш", "бухарик", "синяк"],
    "пьянющий": ["пьяный-распьяный", "распьяный"],
    "пэдди": ["пэтти", "пэт", "пат"],
    "пэмэн": ["фэмэн"],
    "пэна": ["пойна"],
    "пэтти": ["пэдди", "пэт", "пат"],
    "пэтэушница": ["птушница"],
    "пюпитр": ["пульт", "штатив"],
    "пюрировав": ["пюрировавши"],
    "пюрировавши": ["пюрировав"],
    "пюрировать": ["блендерить"],
    "пядень": ["пядь"],
    "пяла": ["пялка", "распялка", "пяло"],
    "пяле": ["шире"],
    "пялемс": ["сялгомс", "карамс", "шувомс"],
    "пялив": ["пяливши"],
    "пяливши": ["пялив"],
    "пялиться": ["тянуться", "жилиться", "глазеть", "таращиться"],
    "пяло": ["пялка", "распялка", "пяла"],
    "пяльде": ["ширде", "кядьста"],
    "пянсе": ["пегодя", "пигоди"],
    "пярну": ["пернов", "пернава"],
    "пястка": ["горсть"],
    "пята": ["пятка"],
    "пятак": ["пять копеек", "полугривенный", "полугривенник", "пятачок", "пятикопеечная монета", "десять денег", "морда", "рубильник"],
    "пятачок": ["пятак", "пятикопеечник", "рыло", "закуток", "нос", "плешка"],
    "пятая власть": ["мафия"],
    "пятая графа": ["пятый пункт"],
    "пятая колонна": ["засланный казачок"],
    "пятая точка": ["задница", "мягкое место", "жопа", "зад", "попа", "багажник"],
    "пятерик": ["пятак"],
    "пятерной": ["пятикратный"],
    "пятерня": ["ладонь", "кисть"],
    "пятеро": ["пять"],
    "пятиалтынник": ["пятиалтынный", "пятиалтынничек"],
    "пятиалтынный": ["пятиалтынник", "пятиалтынничек"],
    "пятиборец": ["рыцарь пяти качеств"],
    "пятиборье": ["пентатлон"],
    "пятив": ["пятивши"],
    "пятивершинный": ["пятиглавый"],
    "пятивши": ["пятив"],
    "пятигорец": ["пятигорчанин"],
    "пятигорск": ["всесоюзная здравница", "горячеводск"],
    "пятигорчанин": ["пятигорец"],
    "пятигорчанка": ["пятигорец"],
    "пятигорье": ["пятигория"],
    "пятигранник": ["пентаэдр"],
    "пятидесятикопеечный": ["полтинный"],
    "пятидесятница": ["троица"],
    "пятизвёздный": ["пятизвёздочный"],
    "пятикнижие": ["тора", "пятикнижие моисеево", "пятокнижие"],
    "пятиконечный": ["пятиугольный"],
    "пятикратно": ["в пять раз", "впятеро", "пять раз"],
    "пятикрылый шестихуй": ["спиртоносец"],
    "пятилетка": ["пятилетие"],
    "пятилетье": ["пятилетие"],
    "пятипальцы": ["мокасин", "пальцы"],
    "пятирублёвый": ["синенькая", "синяя", "синюга"],
    "пятисложный": ["многосложный"],
    "пятисотрублёвка": ["пятисотка", "пятихатка"],
    "пятистенка": ["изба-пятистенка", "пятистенок"],
    "пятистенок": ["дом-пятистенок", "пятистенная изба", "изба-пятистенка", "пятистенка"],
    "пятистишие": ["пятистишье", "кинтилья"],
    "пятиточечник": ["поджопник"],
    "пятихатка": ["пятисотка"],
    "пятиэтажный": ["в пять этажей"],
    "пятиячейник": ["пентахор"],
    "пятка": ["пята"],
    "пятнав": ["пятнавши"],
    "пятнавши": ["пятнав"],
    "пятнадцатиминутный": ["четвертьчасовой"],
    "пятнадцатисекундный": ["четвертьминутный"],
    "пятнадцатый": ["номер пятнадцать", "маловажный", "незначительный", "несущественный", "десятый"],
    "пятнадцать": ["полтора десятка"],
    "пятнаха": ["пятнашка"],
    "пятнашки": ["догоняшки", "догонялки", "салки", "салочки", "гали", "квач", "квачик", "ляпки", "сиф", "сифа", "сифак"],
    "пятнив": ["пятнивши"],
    "пятнивши": ["пятнив"],
    "пятнистый": ["пёстрый", "крапчатый"],
    "пятновыводитель": ["пятноочиститель"],
    "пятный конец": ["пятной конец"],
    "пятовый": ["пятный"],
    "пятый": ["номер пять", "девяносто пятый"],
    "пять": ["пятёрка"],
    "пятьдесят": ["полсотни", "полтинник", "полста"],
    "пятьдесят на пятьдесят": ["фифти-фифти"],
    "пятьдесят один": ["полста один"],
    "пятёрка": ["пять", "отлично", "пять баллов"],
    "пятёрочник": ["отличник"],
    "пяцьдзесят": ["пяцьдзясят"],
    "пёкло": ["пекло", "огонь", "жар", "садник"],
    "пёрднув": ["пёрднувши"],
    "пёрднувши": ["пёрднув"],
    "пёрднуть": ["пёрнуть"],
    "пёркёлт": ["гуляш", "пёркёльт"],
    "пёрнув": ["пёрнувши"],
    "пёрнувши": ["пёрнув"],
    "пёрнуть": ["пёрднуть", "бзднуть", "взбзднуть", "пукнуть"],
    "пёс": ["собака", "кобель", "пёсель", "мерзавец"],
    "пёс войны": ["легионер", "солдат удачи"],
    "пёс его знает": ["а кто его знает", "бог его знает", "господь его знает", "хрен его знает", "чёрт его знает", "неизвестно", "хз"],
    "пёсель": ["собакен"],
    "пёсий": ["собачий"],
    "пёсик": ["собачка"],
    "пёстрый": ["цветастый", "разноцветный", "пятнистый", "неоднородный", "витиеватый", "вычурный"],
    "пёсья смерть": ["дремка"],
    "пётр": ["петро", "петя"],
    "пёхом": ["пешим ходом", "на своих ногах", "на своих двоих", "пешкодралом", "пешкодрапом", "одиннадцатый маршрут"],
    "раан": ["ранвын"],
    "раб": ["илот", "холоп", "невольник"],
    "раба": ["рабыня"],
    "рабатывав": ["рабатывавши"],
    "рабатывавши": ["рабатывав"],
    "рабби": ["танъры", "алла", "ярадан", "худа", "мевля", "илях", "чалап"],
    "раббы": ["алла"],
    "рабдаканта": ["рабдакант"],
    "рабдомиолиз": ["миоглобинурия"],
    "рабиня": ["раба"],
    "рабица": ["сетка-рабица"],
    "рабкор": ["журналист", "корреспондент"],
    "рабкорка": ["корреспондентка", "журналистка"],
    "рабкорствовав": ["рабкорствовавши"],
    "рабкорствовавши": ["рабкорствовав"],
    "раблезианец": ["жизнелюб", "жуир", "эпикуреец"],
    "раблезианство": ["жизнелюбие"],
    "рабовладелец": ["хозяин", "повелитель"],
    "рабовладельческий строй": ["рабовладельческое общество"],
    "рабовладение": ["рабовладельчество", "рабство"],
    "раболепие": ["раболепство", "раболепствование", "лакейство", "льстивость", "подобострастие", "подобострастность", "угодливость", "угодничество", "униженность", "уничиженность", "холуйство", "низкопоклонство", "пресмыкательство", "сервильность", "раболепье"],
    "раболепно": ["подобострастно"],
    "раболепность": ["раболепие", "лакейство", "льстивость", "подобострастность", "угодливость", "униженность", "уничиженность", "холуйство", "сервильность"],
    "раболепство": ["раболепие", "раболепствование", "низкопоклонство", "сервилизм"],
    "раболепствовав": ["раболепствовавши"],
    "раболепствовавши": ["раболепствовав"],
    "раболепствовать": ["угодничать"],
    "раболепье": ["раболепие", "раболепство", "раболепствование", "лакейство", "льстивость", "подобострастие", "подобострастность", "угодливость", "угодничество", "униженность", "уничиженность", "холуйство", "низкопоклонство", "пресмыкательство", "сервильность"],
    "работа": ["занятие", "труд", "служба", "пост", "творение", "изделие", "публикация", "статья", "энергия"],
    "работав": ["работавши"],
    "работавши": ["работав"],
    "работать": ["пользоваться", "обслуживать", "служить", "действовать", "функционировать", "фурычить", "пыхтеть", "пахать", "фунциклировать"],
    "работая": ["робя"],
    "работник": ["труженик", "сотрудник", "служащий"],
    "работник связи": ["связист"],
    "работница": ["труженица", "сотрудница", "рабочая"],
    "работнув": ["работнувши"],
    "работнувши": ["работнув"],
    "работнуть": ["уработать"],
    "работоголик": ["трудоголик"],
    "работодатель": ["наниматель"],
    "работывав": ["работывавши"],
    "работывавши": ["работывав"],
    "работяга": ["труженик", "трудяга", "рабочий"],
    "работящесть": ["трудолюбие"],
    "работящий": ["трудолюбивый"],
    "работёнка": ["работёшка", "работишка"],
    "рабочая": ["работница"],
    "рабочие губы": ["рабочий рот"],
    "рабочий": ["трудовой", "предварительный", "пробный", "черновой", "работающий", "работоспособный", "функционирующий"],
    "рабочий класс": ["пролетариат"],
    "рабочий корреспондент": ["рабкор", "рабкорка"],
    "рабочий стол": ["десктоп"],
    "рабочком": ["рабочий", "комитет"],
    "рабство": ["кабала", "плен", "рабовладение", "зависимость", "несвобода"],
    "рабствовав": ["рабствовавши"],
    "рабствовавши": ["рабствовав"],
    "рабыня": ["раба", "невольница"],
    "рав": ["раф"],
    "равви": ["рабби"],
    "раввин": ["ребе", "рабби", "хахам"],
    "равенство": ["одинаковость", "тождество", "тождественность", "равноправие"],
    "равжаши": ["равжа"],
    "равиль": ["равильчик"],
    "равиш": ["рафтор"],
    "равнение": ["выравнивание", "уравнивание"],
    "равненье": ["равнение"],
    "равнинный": ["плоский"],
    "равноангельский": ["монашеский", "святой"],
    "равнобедренная трапеция": ["равнобокая трапеция"],
    "равнобокая трапеция": ["равнобедренная трапеция"],
    "равновеликость": ["равенство"],
    "равновероятный": ["равновероятностный"],
    "равновесие": ["баланс", "уравновешивание", "балансировка", "гармония", "покой", "спокойствие", "уравновешенность", "безмятежность", "душевное равновесие", "психическое равновесие", "самообладание", "умиротворённость", "уверенность", "душевный покой", "паритет"],
    "равновесье": ["равновесие"],
    "равнодействие": ["равнодействующая"],
    "равнодействующая": ["равнодействие", "результирующая"],
    "равнодушие": ["безучастность", "пассивность", "апатия"],
    "равнодушничав": ["равнодушничавши"],
    "равнодушничавши": ["равнодушничав"],
    "равнодушно": ["безразлично", "апатично", "индифферентно"],
    "равнодушный": ["апатичный", "безразличный", "безучастный", "бесстрастный", "индифферентный"],
    "равнодушье": ["равнодушие"],
    "равнозначно": ["эквивалентно", "адекватно", "равносильно", "равноценно"],
    "равнозначный": ["равнозначительный"],
    "равномерно": ["единообразно", "однородно"],
    "равноотстоящий": ["эквидистантный"],
    "равнопеременный": ["равноускоренный"],
    "равноправие": ["равноправность", "равенство", "полноправие", "паритет", "паритетность", "эгалитарность"],
    "равноправье": ["равноправие"],
    "равносильно": ["равнозначно", "равноценно", "эквивалентно"],
    "равноспоровость": ["изоспория"],
    "равностойност": ["равноценност", "еквивалентност"],
    "равносторонний треугольник": ["правильный треугольник"],
    "равноускоренный": ["равнопеременный"],
    "равноценно": ["адекватно", "равнозначно", "эквивалентно", "равносильно", "одинаково"],
    "равноценный": ["эквивалентный"],
    "равный": ["одинаковый", "идентичный", "совпадающий", "равноценный"],
    "равняв": ["равнявши"],
    "равнявши": ["равняв"],
    "равнять": ["уравнивать", "приравнивать", "выравнивать"],
    "равшан": ["мубин"],
    "равшанзамир": ["равшандил"],
    "рагга": ["раггамаффин"],
    "раггамаффин": ["рагга"],
    "рагуль": ["западенец", "деревенщина"],
    "рагъв": ["рагъулвал"],
    "рад": ["доволен", "счастлив"],
    "рада": ["помощь", "совет"],
    "радар": ["радиолокатор"],
    "радев": ["радевши"],
    "радевши": ["радев"],
    "радейтны": ["любитны", "мусавны"],
    "радение": ["трудолюбие", "старание", "усердие"],
    "радетельный": ["порядочный", "старательный", "усердный", "заботливый", "внимательный"],
    "радеть": ["заботиться", "печься"],
    "радеющий": ["заботящийся"],
    "раджа": ["князь", "государь"],
    "ради бога": ["пожалуйста", "христа ради", "конечно", "разумеется"],
    "ради прекрасных глаз": ["из любви к искусству", "за здорово живешь", "бесплатно", "за спасибо", "за одно спасибо", "бескорыстно", "даром", "просто так", "за так"],
    "радиально": ["лучеобразно"],
    "радиальный": ["нормальный"],
    "радиативный": ["излучательный", "лучистый", "электромагнитный"],
    "радиатор": ["батарея"],
    "радиационный": ["радиоактивный"],
    "радиация": ["излучение", "ионизирующее излучение"],
    "радиво": ["радио"],
    "радивый": ["усердный", "старательный"],
    "радиировав": ["радиировавши"],
    "радиировавши": ["радиировав"],
    "радийный": ["эфирный"],
    "радикал": ["корень"],
    "радикализировав": ["радикализировавши"],
    "радикализировавши": ["радикализировав"],
    "радикализировать": ["радикализовать"],
    "радикализовав": ["радикализовавши"],
    "радикализовавши": ["радикализовав"],
    "радикализовать": ["радикализировать"],
    "радикалист": ["радикал"],
    "радикальничав": ["радикальничавши"],
    "радикальничавши": ["радикальничав"],
    "радикально": ["кардинально", "коренным образом"],
    "радикальствовав": ["радикальствовавши"],
    "радикальствовавши": ["радикальствовав"],
    "радиккьо": ["итальянский цикорий"],
    "радикотомия": ["ризотомия"],
    "радикс": ["корень"],
    "радиксоид": ["связанный корень"],
    "радикюль": ["ридикюль"],
    "радио-диск-жокей": ["радиодиджей"],
    "радиоавтография": ["авторадиография"],
    "радиоактивный": ["излучающий"],
    "радиобиология": ["радиационная биология"],
    "радиовариант": ["радиоверсия"],
    "радиоверсия": ["радиовариант"],
    "радиоволновой": ["радиоволновый"],
    "радиоголос": ["голос"],
    "радиограммофон": ["радиола"],
    "радиодиджей": ["радио-диск-жокей"],
    "радиозакладка": ["жучок"],
    "радиозаяц": ["радиохулиган"],
    "радиозонд": ["радиометеорограф"],
    "радиоизотоп": ["радионуклид"],
    "радиоиндикатор": ["радиофармпрепарат"],
    "радиокарбон": ["радиоуглерод"],
    "радиола": ["радиограммофон"],
    "радиолокатор": ["радар"],
    "радиолярия": ["лучевик"],
    "радиомачта": ["радиовышка"],
    "радиомаяк": ["радиомаячок"],
    "радиомаячок": ["маячок"],
    "радиометка": ["метка", "маркер", "тег", "идентификатор", "транспондер", "ответчик"],
    "радиопилюля": ["радиокапсула", "эндорадиозонд"],
    "радиоподавление": ["радиоэлектронное подавление", "рэп"],
    "радиоподслушивание": ["радиоперехват"],
    "радиоприёмник": ["транзистор", "радиоточка", "радио"],
    "радиопульмонография": ["пульмонорадиография", "радиопневмография", "радиоспирография", "радиоторакография", "спирорадиография"],
    "радиопьеса": ["радиодрама"],
    "радиорезистентность": ["радиоустойчивость"],
    "радиорупор": ["громкоговоритель"],
    "радиосекстан": ["радиосекстант"],
    "радиосекстант": ["радиосекстан"],
    "радиоспермический": ["радиально-симметричный"],
    "радиотрансляционная точка": ["радиоточка"],
    "радиоуглерод": ["радиокарбон"],
    "радиоуглеродный": ["радиокарбоновый"],
    "радиофицировав": ["радиофицировавши"],
    "радиофицировавши": ["радиофицировав"],
    "радиохулиган": ["радиозаяц"],
    "радиоэлектронная борьба": ["рэб"],
    "радиоэстезия": ["лозоходство", "биолокация", "доузинг", "эниология"],
    "радировав": ["радировавши"],
    "радировавши": ["радировав"],
    "радировать": ["передать", "передавать"],
    "радиус": ["полудиаметр", "дальность", "охват"],
    "радовав": ["радовавши"],
    "радовавши": ["радовав"],
    "радование": ["наслаждение", "радость"],
    "радоваться": ["ликовать", "торжествовать"],
    "радон": ["эманация", "нитон", "эманация радия"],
    "радоница": ["радуница"],
    "радостно": ["весело", "счастливо"],
    "радостный": ["счастливый", "весёлый", "отрадный"],
    "радостотворец": ["радующий"],
    "радость": ["милый", "любимый"],
    "радуга": ["спектр"],
    "радужка": ["радужная оболочка"],
    "радужная оболочка": ["радужка", "радужина", "раёк", "ирис"],
    "радужник": ["морской юнкер"],
    "радужность": ["иризация", "переливчатость", "красочность"],
    "радужный": ["разноцветный", "пёстрый", "радостный", "лгбт", "гомосексуал"],
    "радуница": ["радоница"],
    "радуничный": ["радуницкий", "радоницкий"],
    "радушие": ["приветливость", "хлебосольство", "гостеприимность", "сердечность", "радушный прием", "гостеприимство", "ласковость"],
    "радушно": ["радостно", "сердечно", "приветливо", "ласково"],
    "радушный": ["благосердый", "благостынный", "всеохотный", "гостеприимный", "хлебосольный", "сердечный", "ласковый", "приветливый", "участливый"],
    "радушье": ["радушие"],
    "радця": ["радник"],
    "радянський союз": ["срср"],
    "радёхонек": ["радёшенек"],
    "радёшенек": ["радёхонек"],
    "раж": ["неистовство", "азарт", "пыл", "пылкость", "горячность"],
    "раживаться": ["рождаться"],
    "раз и навсегда": ["окончательно"],
    "раз на раз не приходится": ["всякое бывает", "такова жизнь"],
    "раз плюнуть": ["легче лёгкого", "как два пальца обоссать", "как нечего делать", "ничего не стоит", "проще простого"],
    "раз-": ["роз-", "рос-"],
    "раз-два": ["ать-два"],
    "разагитировав": ["разагитировавши"],
    "разагитировавши": ["разагитировав"],
    "разанатомировав": ["разанатомировавши"],
    "разанатомировавши": ["разанатомировав"],
    "разарретирование": ["расстопоривание"],
    "разархивация": ["распаковывание"],
    "разархивировав": ["разархивировавши"],
    "разархивировавши": ["разархивировав"],
    "разархивирование": ["разархивация", "распаковка"],
    "разассигновав": ["разассигновавши"],
    "разассигновавши": ["разассигновав"],
    "разассигновывав": ["разассигновывавши"],
    "разассигновывавши": ["разассигновывав"],
    "разафишировав": ["разафишировавши"],
    "разафишировавши": ["разафишировав"],
    "разбавив": ["разбавивши"],
    "разбавивши": ["разбавив"],
    "разбавляв": ["разбавлявши"],
    "разбавлявши": ["разбавляв"],
    "разбавлять": ["разводить"],
    "разбазарив": ["разбазаривши"],
    "разбазаривав": ["разбазаривавши"],
    "разбазаривавши": ["разбазаривав"],
    "разбазаривание": ["растранжиривание"],
    "разбазаривать": ["растранжиривать", "транжирить", "проматывать", "расходовать", "тратить"],
    "разбазаривши": ["разбазарив"],
    "разбазарить": ["растранжирить", "промотать", "израсходовать", "ухнуть", "истратить"],
    "разбалакаться": ["разболтаться"],
    "разбаланс": ["разбалансирование", "разбалансированность", "разбалансировка"],
    "разбалансировав": ["разбалансировавши"],
    "разбалансировавши": ["разбалансировав"],
    "разбалансирование": ["разбалансировка"],
    "разбалансированность": ["дисбаланс", "разбаланс"],
    "разбаловав": ["разбаловавши"],
    "разбаловавши": ["разбаловав"],
    "разбаловать": ["развратить"],
    "разбаловывав": ["разбаловывавши"],
    "разбаловывавши": ["разбаловывав"],
    "разбаловывать": ["избаловывать", "забаловывать"],
    "разбалтывав": ["разбалтывавши"],
    "разбалтывавши": ["разбалтывав"],
    "разбалтывание": ["расшатывание", "взбалтывание", "перебалтывание", "разглашение"],
    "разбалтывать": ["взбалтывать", "болтать"],
    "разбан": ["анбан", "унбан", "разбанивание", "разблокирование", "разблокировка"],
    "разбанив": ["разбанивши"],
    "разбанивши": ["разбанив"],
    "разбег": ["разгон", "ускорение", "подготовка"],
    "разбеганье": ["разбегание"],
    "разбежность": ["расхождение", "разброс", "разница"],
    "разбелив": ["разбеливши"],
    "разбеливав": ["разбеливавши"],
    "разбеливавши": ["разбеливав"],
    "разбеливши": ["разбелив"],
    "разбеляв": ["разбелявши"],
    "разбелявши": ["разбеляв"],
    "разбередив": ["разбередивши"],
    "разбередивши": ["разбередив"],
    "разбередить": ["развередить"],
    "разбереживав": ["разбереживавши"],
    "разбереживавши": ["разбереживав"],
    "разбесив": ["разбесивши"],
    "разбесивши": ["разбесив"],
    "разбив": ["разбивши"],
    "разбивав": ["разбивавши"],
    "разбивавши": ["разбивав"],
    "разбивать лёд": ["растапливать лёд"],
    "разбивка": ["разбиение"],
    "разбивши": ["разбив"],
    "разбиение": ["разделение"],
    "разбинтовав": ["разбинтовавши"],
    "разбинтовавши": ["разбинтовав"],
    "разбинтовывав": ["разбинтовывавши"],
    "разбинтовывавши": ["разбинтовывав"],
    "разбирав": ["разбиравши"],
    "разбиравши": ["разбирав"],
    "разбирать": ["разнимать", "разъединять", "растаскивать", "расхватывать", "упорядочивать", "приводить в порядок", "рассматривать", "анализировать", "распознавать", "различать", "выделять"],
    "разбитие": ["разбивание", "разбиение", "распределение"],
    "разбитной": ["бойкий", "бодрый", "живой", "расторопный", "ловкий", "лихой", "проворный", "резвый"],
    "разбито": ["надтреснуто"],
    "разбитый": ["расколотый", "дребезжащий", "надтреснутый", "расстроенный", "разрозненный", "нетвёрдый", "вялый", "обессиленный", "усталый", "измученный", "опустошённый", "сломленный", "растрёпанный"],
    "разбить": ["разломать", "расколоть", "поранить", "побить", "избить", "разрушить", "погубить", "опровергнуть", "рассеять", "отвлечь", "разогнать"],
    "разбиться": ["расколоться"],
    "разблаговестив": ["разблаговестивши"],
    "разблаговестивши": ["разблаговестив"],
    "разблокировав": ["разблокировавши"],
    "разблокировавши": ["разблокировав"],
    "разблокирование": ["разблокировка"],
    "разблокироваться": ["деблокироваться"],
    "разблокировка": ["разблокирование"],
    "разблочив": ["разблочивши"],
    "разблочивши": ["разблочив"],
    "разблюдовка": ["разблюдник"],
    "разбогатев": ["разбогатевши"],
    "разбогатевши": ["разбогатев"],
    "разбогатеть": ["обогатиться"],
    "разбой": ["бандитизм"],
    "разбойник": ["бандит", "грабитель", "бандюга", "баловник", "шалун", "негодник", "проказник"],
    "разбойница": ["грабительница", "шалунья", "хулиганка"],
    "разбойницкий": ["разбойный", "разбойнический"],
    "разбойничав": ["разбойничавши"],
    "разбойничавши": ["разбойничав"],
    "разбойный": ["разбойницкий", "разбойнический", "уголовный"],
    "разболеться": ["расхвораться"],
    "разболтав": ["разболтавши"],
    "разболтавши": ["разболтав"],
    "разболтанный": ["расхлябанный"],
    "разболтаться": ["расшататься", "распуститься", "распоясаться", "отбиться от рук"],
    "разболтив": ["разболтивши"],
    "разболтивши": ["разболтив"],
    "разболтовав": ["разболтовавши"],
    "разболтовавши": ["разболтовав"],
    "разболтовывав": ["разболтовывавши"],
    "разболтовывавши": ["разболтовывав"],
    "разболчивав": ["разболчивавши"],
    "разболчивавши": ["разболчивав"],
    "разбомбив": ["разбомбивши"],
    "разбомбивши": ["разбомбив"],
    "разбор": ["разборка", "разгребание", "растаскивание", "анализ", "обсуждение", "исследование"],
    "разбор полётов": ["головомойка"],
    "разборка": ["разъединение"],
    "разборонив": ["разборонивши"],
    "разборонивши": ["разборонив"],
    "разбороновав": ["разбороновавши"],
    "разбороновавши": ["разбороновав"],
    "разбороновывав": ["разбороновывавши"],
    "разбороновывавши": ["разбороновывав"],
    "разбортовав": ["разбортовавши"],
    "разбортовавши": ["разбортовав"],
    "разбортовывав": ["разбортовывавши"],
    "разбортовывавши": ["разбортовывав"],
    "разбортовывать": ["разбортировать"],
    "разбраковав": ["разбраковавши"],
    "разбраковавши": ["разбраковав"],
    "разбраковывав": ["разбраковывавши"],
    "разбраковывавши": ["разбраковывав"],
    "разбранив": ["разбранивши"],
    "разбранивши": ["разбранив"],
    "разбрасывав": ["разбрасывавши"],
    "разбрасывавши": ["разбрасывав"],
    "разбрасывать": ["раскидывать"],
    "разбредаться": ["сходиться", "собираться"],
    "разбрестись": ["разойтись", "разъехаться", "рассеяться"],
    "разброд": ["разбредание", "разрозненность", "разобщённость", "рассеяние", "разбросанность", "разлад"],
    "разбронировав": ["разбронировавши"],
    "разбронировавши": ["разбронировав"],
    "разбросав": ["разбросавши"],
    "разбросавши": ["разбросав"],
    "разбросаться": ["раскидаться"],
    "разбросив": ["разбросивши"],
    "разбросивши": ["разбросив"],
    "разбросить": ["разбросать"],
    "разбрызгав": ["разбрызгавши"],
    "разбрызгавши": ["разбрызгав"],
    "разбрызгивав": ["разбрызгивавши"],
    "разбрызгивавши": ["разбрызгивав"],
    "разбрызгиватель": ["спринклер", "ороситель", "поливалка"],
    "разбрызгивать": ["распрыскивать", "распылять", "разметать", "расплёскивать"],
    "разбрызнув": ["разбрызнувши"],
    "разбрызнувши": ["разбрызнув"],
    "разбудив": ["разбудивши"],
    "разбудивши": ["разбудив"],
    "разбудоражив": ["разбудораживши"],
    "разбудораживши": ["разбудоражив"],
    "разбуравив": ["разбуравивши"],
    "разбуравивши": ["разбуравив"],
    "разбуравливав": ["разбуравливавши"],
    "разбуравливавши": ["разбуравливав"],
    "разбурив": ["разбуривши"],
    "разбуривав": ["разбуривавши"],
    "разбуривавши": ["разбуривав"],
    "разбуривать": ["разбуравливать"],
    "разбуривши": ["разбурив"],
    "разбухав": ["разбухавши"],
    "разбухавши": ["разбухав"],
    "разбухнув": ["разбухнувши"],
    "разбухнувши": ["разбухнув"],
    "разбухнуть": ["набухнуть", "опухнуть"],
    "разбушеваться": ["разъяриться", "взбушеваться", "разбуяниться"],
    "разбюрократив": ["разбюрокративши"],
    "разбюрокративши": ["разбюрократив"],
    "разбюрокрачивав": ["разбюрокрачивавши"],
    "разбюрокрачивавши": ["разбюрокрачивав"],
    "разважживав": ["разважживавши"],
    "разважживавши": ["разважживав"],
    "разваживав": ["разваживавши"],
    "разваживавши": ["разваживав"],
    "развазживав": ["развазживавши"],
    "развазживавши": ["развазживав"],
    "развал": ["разваливание", "разрушение", "разделение", "разрубание", "расстройство", "упадок", "разлад", "разруха", "распад", "разложение", "беспорядок", "хаос", "кавардак", "бардак", "разгар"],
    "развал-схождение": ["сход-развал"],
    "развалив": ["разваливши"],
    "разваливав": ["разваливавши"],
    "разваливавши": ["разваливав"],
    "разваливши": ["развалив"],
    "развалиться": ["разрушиться", "сломаться", "расстроиться", "расслабиться"],
    "развальцевав": ["развальцевавши"],
    "развальцевавши": ["развальцевав"],
    "развальцовывав": ["развальцовывавши"],
    "развальцовывавши": ["развальцовывав"],
    "развалюха": ["развалина", "рухлядь", "драндулет"],
    "разваляв": ["развалявши"],
    "развалявши": ["разваляв"],
    "развар": ["разваривание"],
    "разварив": ["разваривши"],
    "разваривав": ["разваривавши"],
    "разваривавши": ["разваривав"],
    "разваривать": ["размаривать"],
    "разваривши": ["разварив"],
    "развевав": ["развевавши"],
    "развевавши": ["развевав"],
    "развеваться": ["виться", "веять", "реять", "трепетать", "колыхаться", "полоскаться", "развеиваться"],
    "разведав": ["разведавши"],
    "разведавши": ["разведав"],
    "разведбат": ["разведбатальон"],
    "разведенье": ["разведение"],
    "разведка": ["сторожа"],
    "разведочный": ["разведывательный"],
    "разведрив": ["разведривши"],
    "разведривав": ["разведривавши"],
    "разведривавши": ["разведривав"],
    "разведривши": ["разведрив"],
    "разведчик": ["выглядчик", "шпион", "поисковик"],
    "разведчица": ["лазутчица", "шпионка"],
    "разведывав": ["разведывавши"],
    "разведывавши": ["разведывав"],
    "разведывание": ["разведание", "разведанье"],
    "разведывательно-ударный": ["ударно-разведывательный"],
    "разведывать": ["исследовать", "выпытывать"],
    "разведёнка": ["брошенка"],
    "развезя": ["развёзши"],
    "развеивав": ["развеивавши"],
    "развеивавши": ["развеивав"],
    "развенчав": ["развенчавши"],
    "развенчавши": ["развенчав"],
    "развенчание": ["развенчивание", "развенчанье"],
    "развенчать": ["разоблачить", "свергнуть"],
    "развенчивав": ["развенчивавши"],
    "развенчивавши": ["развенчивав"],
    "развенчивать": ["разоблачать", "свергать"],
    "развергав": ["развергавши"],
    "развергавши": ["развергав"],
    "развергнув": ["развергнувши"],
    "развергнувши": ["развергнув"],
    "развергнуться": ["разверзнуться"],
    "развередив": ["развередивши"],
    "развередивши": ["развередив"],
    "развереживав": ["развереживавши"],
    "развереживавши": ["развереживав"],
    "развереживать": ["разбереживать"],
    "разверзав": ["разверзавши"],
    "разверзавши": ["разверзав"],
    "разверзающий ложесна": ["первенец"],
    "разверзнув": ["разверзнувши"],
    "разверзнувши": ["разверзнув"],
    "разверзнуться": ["развергнуться"],
    "разверзтый": ["открытый", "раскрытый"],
    "развернув": ["развернувши"],
    "развернувши": ["развернув"],
    "развернуть": ["воспользоваться", "проявить", "изложить", "распространить", "учредить", "предпринять", "внедрить", "организовать", "развертеть", "развинтить", "вывинтить", "повернуть", "обратить", "установить", "устроить"],
    "развернуться": ["открыться", "раскрыться", "распаковаться", "развязаться", "переформироваться", "показать себя", "разгуляться", "разойтись", "расшириться", "разрастись", "повернуть", "повернуться", "замахнуться", "размахнуться", "развертеться"],
    "разверстав": ["разверставши"],
    "разверставши": ["разверстав"],
    "разверстать": ["распределить"],
    "разверстый": ["открытый", "раскрытый"],
    "развертев": ["развертевши"],
    "развертевши": ["развертев"],
    "развертеться": ["раскрутиться", "развинтиться"],
    "разверчивав": ["разверчивавши"],
    "разверчивавши": ["разверчивав"],
    "разверчиваться": ["раскручиваться"],
    "развес": ["развеска", "развешивание"],
    "развеселив": ["развеселивши"],
    "развеселивши": ["развеселив"],
    "развеселиться": ["оживиться", "повеселеть", "взыграть", "взвеселиться", "возвеселиться"],
    "развеселяв": ["развеселявши"],
    "развеселявши": ["развеселяв"],
    "развесив": ["развесивши"],
    "развесивши": ["развесив"],
    "развесистая клюква": ["клюква", "римский огурец"],
    "развесистый": ["раскидистый", "ветвистый", "разлапистый", "навесистый"],
    "развесить уши": ["хлопать ушами"],
    "развести": ["растворить"],
    "развестись": ["расплодиться"],
    "разветвив": ["разветвивши"],
    "разветвивши": ["разветвив"],
    "разветвление": ["ветвление", "ответвление", "направление"],
    "разветвляв": ["разветвлявши"],
    "разветвлявши": ["разветвляв"],
    "разветвляться": ["развиливаться"],
    "разветриваться": ["развеиваться"],
    "развешав": ["развешавши"],
    "развешавши": ["развешав"],
    "развешивав": ["развешивавши"],
    "развешивавши": ["развешивав"],
    "развешивание": ["развеска"],
    "развеяв": ["развеявши"],
    "развеявши": ["развеяв"],
    "развеять": ["раздуть", "разогнать"],
    "развив": ["развивши"],
    "развивав": ["развивавши"],
    "развивавши": ["развивав"],
    "развиваться": ["раскручиваться", "распрямляться", "разматываться"],
    "развивши": ["развив"],
    "развидев": ["развидевши"],
    "развидевши": ["развидев"],
    "развидеть": ["рассмотреть", "разглядеть"],
    "развиднев": ["развидневши"],
    "развидневши": ["развиднев"],
    "развидняв": ["развиднявши"],
    "развиднявши": ["развидняв"],
    "развиднять": ["рассветать", "проясняться"],
    "развилистый": ["разветвлённый", "раздвоенный", "вилообразный"],
    "развилка": ["развилина"],
    "развилок": ["развилка", "развилина"],
    "развинтив": ["развинтивши"],
    "развинтивши": ["развинтив"],
    "развинчивав": ["развинчивавши"],
    "развинчивавши": ["развинчивав"],
    "развинчивать": ["отвинчивать"],
    "развисав": ["развисавши"],
    "развисавши": ["развисав"],
    "развиснув": ["развиснувши"],
    "развиснувши": ["развиснув"],
    "развитой": ["образованный"],
    "развитость": ["зрелость", "образованность", "сформированность", "цивилизованность", "культурность", "натренированность", "просвещённость"],
    "развитье": ["развитие"],
    "развихляться": ["расшататься", "расстроиться"],
    "развихрив": ["развихривши"],
    "развихривши": ["развихрив"],
    "развлекав": ["развлекавши"],
    "развлекавши": ["развлекав"],
    "развлекаловка": ["развлекалово", "развлекуха"],
    "развлекалово": ["развлекаловка", "развлекуха"],
    "развлекаться": ["забавляться", "веселиться", "отвлекаться"],
    "развлекуха": ["развлекаловка", "развлекалово"],
    "развлечение": ["увеселение", "потеха", "забава"],
    "развлеченье": ["развлечение"],
    "развод": ["разводка"],
    "разводив": ["разводивши"],
    "разводивши": ["разводив"],
    "разводилово": ["развод", "обиралово", "лохотрон", "обираловка"],
    "разводить": ["уводить", "разъединять", "обманывать", "кидать", "втюхивать", "впаривать", "выращивать", "размножать", "культивировать", "разбавлять", "разжижать", "разжигать", "заводить", "создавать"],
    "разводиться": ["расходиться"],
    "разводняв": ["разводнявши"],
    "разводнявши": ["разводняв"],
    "разводье": ["майна", "полынья"],
    "разводящий": ["разжижающий", "муколитический"],
    "развоеваться": ["разбушеваться"],
    "развожжав": ["развожжавши"],
    "развожжавши": ["развожжав"],
    "развозжав": ["развозжавши"],
    "развозжавши": ["развозжав"],
    "развозив": ["развозивши"],
    "развозивши": ["развозив"],
    "разволакивав": ["разволакивавши"],
    "разволакивавши": ["разволакивав"],
    "разволновав": ["разволновавши"],
    "разволновавши": ["разволновав"],
    "разволноваться": ["взволноваться", "растревожиться", "обеспокоиться"],
    "развоплотив": ["развоплотивши"],
    "развоплотивши": ["развоплотив"],
    "развоплотить": ["дематериализовать"],
    "развоплощав": ["развоплощавши"],
    "развоплощавши": ["развоплощав"],
    "развоплощенье": ["развоплощение"],
    "разворачивав": ["разворачивавши"],
    "разворачивавши": ["разворачивав"],
    "разворачивание": ["разворачиванье"],
    "разворачивать": ["развёртывать"],
    "разворачиваться": ["развёртываться"],
    "разворашивав": ["разворашивавши"],
    "разворашивавши": ["разворашивав"],
    "разворовав": ["разворовавши"],
    "разворовавши": ["разворовав"],
    "разворовывав": ["разворовывавши"],
    "разворовывавши": ["разворовывав"],
    "разворовывание": ["разворовыванье"],
    "разворовывать": ["расхищать", "раскрадывать"],
    "разворот": ["перелом", "изгиб"],
    "разворотив": ["разворотивши"],
    "разворотивши": ["разворотив"],
    "разворотливый": ["разворотистый", "деятельный", "предприимчивый"],
    "разворочав": ["разворочавши"],
    "разворочавши": ["разворочав"],
    "разворошив": ["разворошивши"],
    "разворошивши": ["разворошив"],
    "развратив": ["развративши"],
    "развративши": ["развратив"],
    "развратительница": ["растлительница"],
    "развратник": ["распутник", "непотребник", "срамник"],
    "развратница": ["распутница", "блудница", "потаскунья", "потаскуха", "шлюха"],
    "развратничав": ["развратничавши"],
    "развратничавши": ["развратничав"],
    "развратность": ["распущенность", "порочность", "деправация"],
    "развращав": ["развращавши"],
    "развращавши": ["развращав"],
    "развращать": ["растлевать", "совращать"],
    "развращенье": ["развращение"],
    "развращённость": ["испорченность", "развратность"],
    "развръзка": ["завършек", "заключение"],
    "развьючив": ["развьючивши"],
    "развьючивав": ["развьючивавши"],
    "развьючивавши": ["развьючивав"],
    "развьючивши": ["развьючив"],
    "развязав": ["развязавши"],
    "развязавши": ["развязав"],
    "развязанность": ["развязность"],
    "развязничав": ["развязничавши"],
    "развязничавши": ["развязничав"],
    "развязность": ["фамильярность", "панибратство"],
    "развязывав": ["развязывавши"],
    "развязывавши": ["развязывав"],
    "развёзши": ["развезя"],
    "развёрстывав": ["развёрстывавши"],
    "развёрстывавши": ["развёрстывав"],
    "развёрстывать": ["распределять"],
    "развёртывав": ["развёртывавши"],
    "развёртывавши": ["развёртывав"],
    "развёртывать": ["разворачивать"],
    "разгадав": ["разгадавши"],
    "разгадавши": ["разгадав"],
    "разгадка": ["отгадка"],
    "разгадывав": ["разгадывавши"],
    "разгадывавши": ["разгадывав"],
    "разгадыванье": ["разгадывание"],
    "разгазировав": ["разгазировавши"],
    "разгазировавши": ["разгазировав"],
    "разгазирование": ["дегазация"],
    "разгащеност": ["палавост", "разпуснатост", "слободия", "разпасаност"],
    "разгерметизировав": ["разгерметизировавши"],
    "разгерметизировавши": ["разгерметизировав"],
    "разгибав": ["разгибавши"],
    "разгибавши": ["разгибав"],
    "разгибание": ["разгиб", "выпрямление", "распрямление"],
    "разгибаться": ["выпрямляться", "распрямляться"],
    "разгильдяйничав": ["разгильдяйничавши"],
    "разгильдяйничавши": ["разгильдяйничав"],
    "разгильдяйство": ["раздолбайство", "безалаберность"],
    "разгинав": ["разгинавши"],
    "разгинавши": ["разгинав"],
    "разглагольствовав": ["разглагольствовавши"],
    "разглагольствовавши": ["разглагольствовав"],
    "разглагольствование": ["разглагольствие", "пустословие"],
    "разглагольствованье": ["разглагольствование"],
    "разглагольствовать": ["болтать"],
    "разгладив": ["разгладивши"],
    "разгладивши": ["разгладив"],
    "разглаживав": ["разглаживавши"],
    "разглаживавши": ["разглаживав"],
    "разглаживать": ["погладить", "распрямить", "разровнять", "сгладить", "расправить", "смягчить"],
    "разгласа": ["обявление", "обява", "публикация", "оповестяване", "съобщение", "обнародване"],
    "разгласив": ["разгласивши"],
    "разгласивши": ["разгласив"],
    "разглашав": ["разглашавши"],
    "разглашавши": ["разглашав"],
    "разглашать": ["разбалтывать", "афишировать"],
    "разглашенье": ["разглашение"],
    "разглядев": ["разглядевши"],
    "разглядевши": ["разглядев"],
    "разглядывав": ["разглядывавши"],
    "разглядывавши": ["разглядывав"],
    "разглядыванье": ["разглядывание"],
    "разглядывать": ["рассматривать"],
    "разгнать": ["разогнать"],
    "разгневав": ["разгневавши"],
    "разгневавши": ["разгневав"],
    "разгневанно": ["гневно"],
    "разгневать": ["разгневить", "прогневать", "разозлить"],
    "разгневаться": ["рассердиться"],
    "разгневив": ["разгневивши"],
    "разгневивши": ["разгневив"],
    "разговаривав": ["разговаривавши"],
    "разговаривавши": ["разговаривав"],
    "разговаривать": ["говорить", "общаться", "беседовать"],
    "разговение": ["разговенье"],
    "разговень": ["разговенье", "разговение"],
    "разговенье": ["разговение"],
    "разговляв": ["разговлявши"],
    "разговлявши": ["разговляв"],
    "разговор": ["беседа", "диалог", "сплетня", "толк", "слух"],
    "разговор окончен": ["всё", "хватит", "довольно"],
    "разговорив": ["разговоривши"],
    "разговоривши": ["разговорив"],
    "разговорный": ["устный", "просторечный"],
    "разговорчивый": ["беседливый", "словоохотливый"],
    "разгоняв": ["разгонявши"],
    "разгонявши": ["разгоняв"],
    "разгонять": ["форсить", "навязывать", "проталкивать"],
    "разгораживав": ["разгораживавши"],
    "разгораживавши": ["разгораживав"],
    "разгораться": ["загораться"],
    "разгородив": ["разгородивши"],
    "разгородивши": ["разгородив"],
    "разгородить": ["перегородить"],
    "разгорячав": ["разгорячавши"],
    "разгорячавши": ["разгорячав"],
    "разгорячаться": ["горячиться"],
    "разгорячив": ["разгорячивши"],
    "разгорячивши": ["разгорячив"],
    "разгорячиться": ["раскипятиться", "рассердиться"],
    "разгорячённость": ["жар", "воодушевление", "страстность"],
    "разгосударствив": ["разгосударствивши"],
    "разгосударствивши": ["разгосударствив"],
    "разгосударствить": ["приватизировать"],
    "разгосударствление": ["приватизация", "денационализация"],
    "разгосударствливав": ["разгосударствливавши"],
    "разгосударствливавши": ["разгосударствливав"],
    "разгосударствливать": ["приватизировать"],
    "разгосударствляв": ["разгосударствлявши"],
    "разгосударствлявши": ["разгосударствляв"],
    "разгосударствлять": ["приватизировать"],
    "разграбив": ["разграбивши"],
    "разграбивши": ["разграбив"],
    "разграбить": ["расхитить"],
    "разграбление": ["разграбленье"],
    "разграбленье": ["разграбление"],
    "разграбляв": ["разграблявши"],
    "разграблявши": ["разграбляв"],
    "разгравировав": ["разгравировавши"],
    "разгравировавши": ["разгравировав"],
    "разгравировывав": ["разгравировывавши"],
    "разгравировывавши": ["разгравировывав"],
    "разградив": ["разградивши"],
    "разградивши": ["разградив"],
    "разграждав": ["разграждавши"],
    "разграждавши": ["разграждав"],
    "разграничив": ["разграничивши"],
    "разграничивав": ["разграничивавши"],
    "разграничивавши": ["разграничивав"],
    "разграничивать": ["размежёвывать"],
    "разграничивши": ["разграничив"],
    "разграфив": ["разграфивши"],
    "разграфивши": ["разграфив"],
    "разграфляв": ["разграфлявши"],
    "разграфлявши": ["разграфляв"],
    "разгребав": ["разгребавши"],
    "разгребавши": ["разгребав"],
    "разгримировав": ["разгримировавши"],
    "разгримировавши": ["разгримировав"],
    "разгримировывав": ["разгримировывавши"],
    "разгримировывавши": ["разгримировывав"],
    "разгромив": ["разгромивши"],
    "разгромивши": ["разгромив"],
    "разгромить": ["разбить", "разрушить", "сокрушить"],
    "разгрохав": ["разгрохавши"],
    "разгрохавши": ["разгрохав"],
    "разгружав": ["разгружавши"],
    "разгружавши": ["разгружав"],
    "разгрузив": ["разгрузивши"],
    "разгрузивши": ["разгрузив"],
    "разгрузка": ["выгрузка", "отдых", "релаксация", "рпс"],
    "разгруппировав": ["разгруппировавши"],
    "разгруппировавши": ["разгруппировав"],
    "разгруппировывав": ["разгруппировывавши"],
    "разгруппировывавши": ["разгруппировывав"],
    "разгрызав": ["разгрызавши"],
    "разгрызавши": ["разгрызав"],
    "разгул": ["разгулье"],
    "разгуливав": ["разгуливавши"],
    "разгуливавши": ["разгуливав"],
    "разгуляв": ["разгулявши"],
    "разгулявши": ["разгуляв"],
    "разгуляться": ["развернуться", "разойтись", "проясниться"],
    "раздабривав": ["раздабривавши"],
    "раздабривавши": ["раздабривав"],
    "раздабривать": ["раздобрять"],
    "раздав": ["раздавши"],
    "раздавав": ["раздававши"],
    "раздававши": ["раздавав"],
    "раздавать": ["выдавать", "распределять", "расширять", "расшаривать", "сидить", "предоставлять", "открывать"],
    "раздавать смехуёчки": ["смехуёчки раздавать"],
    "раздаваться": ["звучать", "слышаться", "расступаться", "раздвигаться", "растягиваться", "толстеть", "полнеть", "распределяться", "выдаваться"],
    "раздавив": ["раздавивши"],
    "раздавивши": ["раздавив"],
    "раздавливав": ["раздавливавши"],
    "раздавливавши": ["раздавливав"],
    "раздавши": ["раздав"],
    "раздаивав": ["раздаивавши"],
    "раздаивавши": ["раздаивав"],
    "раздаивание": ["раздой"],
    "раздалбливав": ["раздалбливавши"],
    "раздалбливавши": ["раздалбливав"],
    "раздарив": ["раздаривши"],
    "раздаривав": ["раздаривавши"],
    "раздаривавши": ["раздаривав"],
    "раздаривши": ["раздарив"],
    "раздатка": ["раздаточная коробка"],
    "раздаточный": ["раздаваемый", "раздающийся", "выдаваемый"],
    "раздаться": ["послышаться", "зазвучать", "прозвучать", "раздвинуться", "расступиться", "потолстеть", "расшириться"],
    "раздача": ["распределение", "распространение", "расширение"],
    "раздваивав": ["раздваивавши"],
    "раздваивавши": ["раздваивав"],
    "раздваиваться": ["двоиться", "разветвляться"],
    "раздвигав": ["раздвигавши"],
    "раздвигавши": ["раздвигав"],
    "раздвигание": ["раздвижение"],
    "раздвинув": ["раздвинувши"],
    "раздвинувши": ["раздвинув"],
    "раздвинутый": ["разошедшийся", "разведённый", "расставленный"],
    "раздвоение личности": ["диссоциативное расстройство идентичности", "расстройство множественной личности"],
    "раздвоенье": ["раздвоение"],
    "раздвоив": ["раздвоивши"],
    "раздвоивши": ["раздвоив"],
    "раздвояв": ["раздвоявши"],
    "раздвоявши": ["раздвояв"],
    "раздев": ["раздевши"],
    "раздевав": ["раздевавши"],
    "раздевавши": ["раздевав"],
    "раздевалка": ["раздевальня", "гардероб"],
    "раздевальня": ["гардероб", "раздевалка"],
    "раздевать": ["обнажать"],
    "раздевши": ["раздев"],
    "раздел": ["рассечение", "разделение", "часть", "рубрика", "отдел", "секция"],
    "разделав": ["разделавши"],
    "разделавши": ["разделав"],
    "разделегировав": ["разделегировавши"],
    "разделегировавши": ["разделегировав"],
    "разделение": ["раздел", "деление", "разъятие", "расчленение", "членение"],
    "разделив": ["разделивши"],
    "разделивши": ["разделив"],
    "разделимость": ["раздробляемость", "расчленяемость", "членимость"],
    "разделительная": ["разделительная полоса"],
    "разделительный": ["партитивный"],
    "разделительный падеж": ["второй родительный падеж", "количественно-отделительный падеж"],
    "разделить": ["поделить", "разъединить", "раздробить"],
    "разделывав": ["разделывавши"],
    "разделывавши": ["разделывав"],
    "раздельно": ["порознь", "обособленно", "отдельно"],
    "раздельнополый": ["двуполый", "разнополый"],
    "раздельноречие": ["хомония"],
    "раздельность": ["отдельность", "разделённость"],
    "раздельный": ["отдельный", "сепаратный"],
    "разделяв": ["разделявши"],
    "разделявши": ["разделяв"],
    "разделять": ["делить", "разъединять", "расчленять", "распределять"],
    "разделённость": ["разобщённость", "разрозненность"],
    "разделённый": ["поделённый", "раздробленный", "расчленённый", "разбитый", "ответный"],
    "раздербанив": ["раздербанивши"],
    "раздербанивши": ["раздербанив"],
    "раздербанить": ["разделать", "расчленить", "разделить", "раскромсать", "растерзать", "раздёргать", "разодрать", "разбить", "угробить", "избить", "раздырбанить", "растащить", "разворовать", "разрушить", "развалить"],
    "раздирав": ["раздиравши"],
    "раздиравши": ["раздирав"],
    "раздобары": ["болтовня"],
    "раздобарывав": ["раздобарывавши"],
    "раздобарывавши": ["раздобарывав"],
    "раздобарывать": ["растабарывать"],
    "раздобрев": ["раздобревши"],
    "раздобревши": ["раздобрев"],
    "раздобреть": ["подобреть", "раздаться", "потолстеть", "растолстеть"],
    "раздобрив": ["раздобривши"],
    "раздобривши": ["раздобрив"],
    "раздобряв": ["раздобрявши"],
    "раздобрявши": ["раздобряв"],
    "раздобрять": ["раздабривать"],
    "раздобыв": ["раздобывши"],
    "раздобывав": ["раздобывавши"],
    "раздобывавши": ["раздобывав"],
    "раздобывши": ["раздобыв"],
    "раздоив": ["раздоивши"],
    "раздоивши": ["раздоив"],
    "раздой": ["раздаивание"],
    "раздолбав": ["раздолбавши"],
    "раздолбавши": ["раздолбав"],
    "раздолбаистый": ["раздолбайский"],
    "раздолбай": ["мудак", "мудозвон", "идиот", "разгильдяй", "распиздяй", "разъебай"],
    "раздолбайство": ["разгильдяйство"],
    "раздолбив": ["раздолбивши"],
    "раздолбивши": ["раздолбив"],
    "раздолье": ["простор", "даль", "ширь", "приволье"],
    "раздорожье": ["распутье", "развилка"],
    "раздосадовав": ["раздосадовавши"],
    "раздосадовавши": ["раздосадовав"],
    "раздостав": ["раздоставши"],
    "раздоставши": ["раздостав"],
    "раздражав": ["раздражавши"],
    "раздражавши": ["раздражав"],
    "раздражающий": ["надоедающий"],
    "раздражение": ["возбуждение", "взволнованность"],
    "раздражив": ["раздраживши"],
    "раздраживши": ["раздражив"],
    "раздражённо": ["сердито", "зло", "злобно", "агрессивно", "нервно", "нервически"],
    "раздражённость": ["озлобленность", "ожесточённость", "раздражение"],
    "раздразнив": ["раздразнивши"],
    "раздразнивав": ["раздразнивавши"],
    "раздразнивавши": ["раздразнивав"],
    "раздразнивать": ["сердить"],
    "раздразнивши": ["раздразнив"],
    "раздрай": ["раздрызг", "разброд", "раздор", "разлад", "разнобой", "путаница", "неразбериха", "сумбур"],
    "раздраконив": ["раздраконивши"],
    "раздраконивав": ["раздраконивавши"],
    "раздраконивавши": ["раздраконивав"],
    "раздраконивши": ["раздраконив"],
    "раздраконить": ["разворотить", "разломать", "разодрать", "разнести", "разъярить"],
    "раздребезжив": ["раздребезживши"],
    "раздребезживши": ["раздребезжив"],
    "раздробеност": ["разпокъсаност"],
    "раздробив": ["раздробивши"],
    "раздробивши": ["раздробив"],
    "раздробляв": ["раздроблявши"],
    "раздроблявши": ["раздробляв"],
    "раздружив": ["раздруживши"],
    "раздруживши": ["раздружив"],
    "раздрызгав": ["раздрызгавши"],
    "раздрызгавши": ["раздрызгав"],
    "раздрябнув": ["раздрябнувши"],
    "раздрябнувши": ["раздрябнув"],
    "раздував": ["раздувавши"],
    "раздувавши": ["раздував"],
    "раздуванье": ["раздувание"],
    "раздувать": ["развеивать", "раскочегаривать", "надувать"],
    "раздуваться": ["надуваться"],
    "раздувши": ["раздув"],
    "раздумав": ["раздумавши"],
    "раздумавши": ["раздумав"],
    "раздумать": ["передумать"],
    "раздуматься": ["задуматься"],
    "раздумие": ["раздумье", "задумчивость", "размышление", "размышленье", "неуверенность", "сомнение", "сомненье"],
    "раздумчивый": ["нерешительный", "задумчивый"],
    "раздумывав": ["раздумывавши"],
    "раздумывавши": ["раздумывав"],
    "раздумывать": ["размышлять", "колебаться"],
    "раздумье": ["раздумие", "задумчивость", "размышление", "размышленье", "неуверенность", "сомнение"],
    "раздуплиться": ["отдуплиться", "раскачаться", "разобраться"],
    "раздутый": ["надутый", "вздутый", "преувеличенный", "завышенный"],
    "раздухариться": ["развеселиться", "взбушеваться", "разыграться", "разойтись", "развоеваться", "разъерепениться", "разбуяниться", "раскочевряжиться", "разбушеваться"],
    "раздушив": ["раздушивши"],
    "раздушивши": ["раздушив"],
    "раздырбанив": ["раздырбанивши"],
    "раздырбанивши": ["раздырбанив"],
    "раздяла": ["разлъка", "сбогуване", "прощаване"],
    "раздёргав": ["раздёргавши"],
    "раздёргавши": ["раздёргав"],
    "раздёргивав": ["раздёргивавши"],
    "раздёргивавши": ["раздёргивав"],
    "раздёрнув": ["раздёрнувши"],
    "раздёрнувши": ["раздёрнув"],
    "разевав": ["разевавши"],
    "разевавши": ["разевав"],
    "разжав": ["разжавши"],
    "разжавши": ["разжав"],
    "разжалобив": ["разжалобивши"],
    "разжалобивши": ["разжалобив"],
    "разжалобливав": ["разжалобливавши"],
    "разжалобливавши": ["разжалобливав"],
    "разжаловав": ["разжаловавши"],
    "разжаловавши": ["разжаловав"],
    "разжаловывав": ["разжаловывавши"],
    "разжаловывавши": ["разжаловывав"],
    "разжаловывать": ["разжалывать"],
    "разжалывав": ["разжалывавши"],
    "разжалывавши": ["разжалывав"],
    "разжарев": ["разжаревши"],
    "разжаревши": ["разжарев"],
    "разжарив": ["разжаривши"],
    "разжаривав": ["разжаривавши"],
    "разжаривавши": ["разжаривав"],
    "разжаривши": ["разжарив"],
    "разжевав": ["разжевавши"],
    "разжевавши": ["разжевав"],
    "разжевать": ["растолковать", "объяснить"],
    "разженив": ["разженивши"],
    "разженивав": ["разженивавши"],
    "разженивавши": ["разженивав"],
    "разженивши": ["разженив"],
    "разжечь": ["зажечь", "запалить", "воспламенить", "распалить"],
    "разжечься": ["разгореться", "разгорячиться", "распалиться"],
    "разживив": ["разжививши"],
    "разжививши": ["разживив"],
    "разживляв": ["разживлявши"],
    "разживлявши": ["разживляв"],
    "разжигав": ["разжигавши"],
    "разжигавши": ["разжигав"],
    "разжигание": ["розжиг", "воспламенение", "активизация", "возбуждение", "раздувание"],
    "разжиганье": ["разжигание"],
    "разжигатель": ["поджигатель"],
    "разжидив": ["разжидивши"],
    "разжидивши": ["разжидив"],
    "разжидитель": ["разжижитель", "разбавитель"],
    "разжидить": ["развести", "разбавить"],
    "разжижав": ["разжижавши"],
    "разжижавши": ["разжижав"],
    "разжижать": ["разбавлять", "разводить"],
    "разжижитель": ["разжидитель", "разбавитель"],
    "разжимав": ["разжимавши"],
    "разжимавши": ["разжимав"],
    "разжирев": ["разжиревши"],
    "разжиревши": ["разжирев"],
    "разжмурив": ["разжмуривши"],
    "разжмуривав": ["разжмуривавши"],
    "разжмуривавши": ["разжмуривав"],
    "разжмуривши": ["разжмурив"],
    "разжёвывав": ["разжёвывавши"],
    "разжёвывавши": ["разжёвывав"],
    "разжёвывание": ["пережёвывание"],
    "раззадорив": ["раззадоривши"],
    "раззадоривав": ["раззадоривавши"],
    "раззадоривавши": ["раззадоривав"],
    "раззадоривать": ["распалять", "заводить"],
    "раззадоривши": ["раззадорив"],
    "раззванивав": ["раззванивавши"],
    "раззванивавши": ["раззванивав"],
    "раззвонив": ["раззвонивши"],
    "раззвонивши": ["раззвонив"],
    "раззенковав": ["раззенковавши"],
    "раззенковавши": ["раззенковав"],
    "раззнакомив": ["раззнакомивши"],
    "раззнакомивши": ["раззнакомив"],
    "раззнакомливав": ["раззнакомливавши"],
    "раззнакомливавши": ["раззнакомливав"],
    "раззолачивав": ["раззолачивавши"],
    "раззолачивавши": ["раззолачивав"],
    "раззолотив": ["раззолотивши"],
    "раззолотивши": ["раззолотив"],
    "раззуделася пизда": ["чешется манда", "горит пизда", "чешется пиздища", "чешется пиздище", "пизда чешется", "пизда горит"],
    "раззудив": ["раззудивши"],
    "раззудивши": ["раззудив"],
    "раззуживав": ["раззуживавши"],
    "раззуживавши": ["раззуживав"],
    "раззявив": ["раззявивши"],
    "раззявивши": ["раззявив"],
    "раззявить": ["разинуть"],
    "разив": ["разивши"],
    "разивши": ["разив"],
    "разик": ["разок", "единожды"],
    "разинув": ["разинувши"],
    "разинувши": ["разинув"],
    "разиня": ["раззява", "растяпа", "ротозей", "олух"],
    "разительный": ["поражающий", "впечатляющий", "изумляющий"],
    "разить": ["поражать", "сокрушать", "сражать", "громить", "уничтожать", "разносить"],
    "разкош": ["великолепие"],
    "разкривеност": ["изкривеност"],
    "разкъсаност": ["раздробеност"],
    "разлагав": ["разлагавши"],
    "разлагавши": ["разлагав"],
    "разлагаться": ["разделяться", "распадаться", "раздробляться", "гнить", "тлеть", "истлевать", "преть", "сгнивать", "деградировать", "развращаться", "разобщаться"],
    "разладив": ["разладивши"],
    "разладивши": ["разладив"],
    "разладить": ["расстроить"],
    "разлаживав": ["разлаживавши"],
    "разлаживавши": ["разлаживав"],
    "разлаживать": ["расстраивать"],
    "разлакомив": ["разлакомивши"],
    "разлакомивши": ["разлакомив"],
    "разламывав": ["разламывавши"],
    "разламывавши": ["разламывав"],
    "разлапистый": ["разлапый"],
    "разлепив": ["разлепивши"],
    "разлепивши": ["разлепив"],
    "разлепливав": ["разлепливавши"],
    "разлепливавши": ["разлепливав"],
    "разлепляв": ["разлеплявши"],
    "разлеплявши": ["разлепляв"],
    "разлетаться": ["разноситься", "рассеиваться", "рассыпаться"],
    "разлив": ["сестрорецкий разлив"],
    "разливав": ["разливавши"],
    "разливавши": ["разливав"],
    "разливанное море": ["обилие", "пирушка", "попойка", "возлияние"],
    "разливанный": ["разливной", "разливный"],
    "разливать": ["расплёскивать"],
    "разливаться": ["проливаться", "расплёскиваться"],
    "разливши": ["разлив"],
    "разлизав": ["разлизавши"],
    "разлизавши": ["разлизав"],
    "разлизывав": ["разлизывавши"],
    "разлизывавши": ["разлизывав"],
    "разлимонив": ["разлимонивши"],
    "разлимонивав": ["разлимонивавши"],
    "разлимонивавши": ["разлимонивав"],
    "разлимонивши": ["разлимонив"],
    "разлиневав": ["разлиневавши"],
    "разлиневавши": ["разлиневав"],
    "разлиновав": ["разлиновавши"],
    "разлиновавши": ["разлиновав"],
    "разлиновать": ["разграфить"],
    "разлиновывав": ["разлиновывавши"],
    "разлиновывавши": ["разлиновывав"],
    "разлинёвывав": ["разлинёвывавши"],
    "разлинёвывавши": ["разлинёвывав"],
    "разлипав": ["разлипавши"],
    "разлипавши": ["разлипав"],
    "разлипнув": ["разлипнувши"],
    "разлипнувши": ["разлипнув"],
    "разлипнуть": ["отлипнуть", "отойти"],
    "разлипнуться": ["разлепиться"],
    "разлитие": ["разливание"],
    "разлитье": ["разлитие"],
    "различав": ["различавши"],
    "различавши": ["различав"],
    "различение": ["различенье"],
    "различенье": ["различение"],
    "различествовав": ["различествовавши"],
    "различествовавши": ["различествовав"],
    "различествовать": ["различаться"],
    "различив": ["различивши"],
    "различивши": ["различив"],
    "различие": ["непохожесть", "несовпадение", "разница", "отличие", "несхожесть", "несходство", "расхождение", "несоответствие", "неэквивалентность", "несовпаденье", "отличье", "расхожденье", "различье"],
    "различимый": ["заметный"],
    "различить": ["уловить", "заметить", "разобрать", "распознать", "разграничить", "размежевать", "отличить"],
    "различный": ["разный", "разнообразный", "всякий"],
    "различье": ["различие"],
    "разложение": ["декомпозиция", "дезинтеграция", "диссоциация", "разбиение", "расщепление", "разделение", "распад", "разложенье", "гниение", "тление", "деморализация", "упадок", "падение", "развращение"],
    "разложенье": ["разложение"],
    "разложив": ["разложивши"],
    "разложивши": ["разложив"],
    "разложимый": ["разделяемый", "разъединяемый", "расчленяемый"],
    "разложить": ["разбить", "набрать полный рот земли"],
    "разлом": ["разламывание", "разломка", "разлад", "трещина"],
    "разломав": ["разломавши"],
    "разломавши": ["разломав"],
    "разломаться": ["сломаться"],
    "разломив": ["разломивши"],
    "разломивши": ["разломив"],
    "разлопушив": ["разлопушивши"],
    "разлопушивши": ["разлопушив"],
    "разлохматив": ["разлохмативши"],
    "разлохмативши": ["разлохматив"],
    "разлохмачивав": ["разлохмачивавши"],
    "разлохмачивавши": ["разлохмачивав"],
    "разлохмачивать": ["лохматить", "взлохмачивать"],
    "разлочив": ["разлочивши"],
    "разлочивши": ["разлочив"],
    "разлочить": ["разблокировать"],
    "разлука": ["расставание", "разлучённость"],
    "разлучав": ["разлучавши"],
    "разлучавши": ["разлучав"],
    "разлученье": ["разлучение"],
    "разлучив": ["разлучивши"],
    "разлучивши": ["разлучив"],
    "разлучиться": ["расстаться", "разойтись", "распрощаться", "распроститься"],
    "разлюбив": ["разлюбивши"],
    "разлюбивши": ["разлюбив"],
    "разлюбливав": ["разлюбливавши"],
    "разлюбливавши": ["разлюбливав"],
    "разлюбляв": ["разлюблявши"],
    "разлюблявши": ["разлюбляв"],
    "разлютев": ["разлютевши"],
    "разлютевши": ["разлютев"],
    "разлютеть": ["рассвирепеть"],
    "разляпав": ["разляпавши"],
    "разляпавши": ["разляпав"],
    "разляпывав": ["разляпывавши"],
    "разляпывавши": ["разляпывав"],
    "разлёживав": ["разлёживавши"],
    "разлёживавши": ["разлёживав"],
    "размагнитив": ["размагнитивши"],
    "размагнитивши": ["размагнитив"],
    "размагничивав": ["размагничивавши"],
    "размагничивавши": ["размагничивав"],
    "размагничивание": ["размагничиванье"],
    "размазав": ["размазавши"],
    "размазавши": ["размазав"],
    "размазывав": ["размазывавши"],
    "размазывавши": ["размазывав"],
    "размаивав": ["размаивавши"],
    "размаивавши": ["размаивав"],
    "размалевав": ["размалевавши"],
    "размалевавши": ["размалевав"],
    "размалывав": ["размалывавши"],
    "размалывавши": ["размалывав"],
    "размалёвывав": ["размалёвывавши"],
    "размалёвывавши": ["размалёвывав"],
    "разманив": ["разманивши"],
    "разманивав": ["разманивавши"],
    "разманивавши": ["разманивав"],
    "разманивши": ["разманив"],
    "размарать": ["размазать", "растереть", "распачкать", "вымарать", "вымазать", "исписать", "исчертить"],
    "размараться": ["размазаться", "растереться"],
    "размаривав": ["размаривавши"],
    "размаривавши": ["размаривав"],
    "размаривать": ["разваривать"],
    "размаслив": ["размасливши"],
    "размасливав": ["размасливавши"],
    "размасливавши": ["размасливав"],
    "размасливши": ["размаслив"],
    "разматывав": ["разматывавши"],
    "разматывавши": ["разматывав"],
    "размахав": ["размахавши"],
    "размахавши": ["размахав"],
    "размахивав": ["размахивавши"],
    "размахивавши": ["размахивав"],
    "размахивать": ["махать"],
    "размахнув": ["размахнувши"],
    "размахнувши": ["размахнув"],
    "размахнуться": ["замахнуться"],
    "размахрив": ["размахривши"],
    "размахривши": ["размахрив"],
    "размачивав": ["размачивавши"],
    "размачивавши": ["размачивав"],
    "размачтовав": ["размачтовавши"],
    "размачтовавши": ["размачтовав"],
    "размачтовывав": ["размачтовывавши"],
    "размачтовывавши": ["размачтовывав"],
    "размаяв": ["размаявши"],
    "размаявши": ["размаяв"],
    "размежевав": ["размежевавши"],
    "размежевавши": ["размежевав"],
    "размежевание": ["разграничение", "разделение", "разграниченье", "разделенье", "размежеванье"],
    "размежеванье": ["размежевание"],
    "размежевать": ["разграничить"],
    "размежив": ["размеживши"],
    "размеживши": ["размежив"],
    "размежёвывав": ["размежёвывавши"],
    "размежёвывавши": ["размежёвывав"],
    "размежёвывать": ["межевать", "разграничивать"],
    "размельчав": ["размельчавши"],
    "размельчавши": ["размельчав"],
    "размельчать": ["измельчать", "раздроблять"],
    "размельчив": ["размельчивши"],
    "размельчивши": ["размельчив"],
    "размен": ["разбиение", "дробление"],
    "разменивав": ["разменивавши"],
    "разменивавши": ["разменивав"],
    "разменяв": ["разменявши"],
    "разменявши": ["разменяв"],
    "размер": ["величина", "габарит", "масштаб", "объём", "размах"],
    "размеренность": ["неторопливость", "плавность", "ритмичность", "упорядоченность", "регулярность"],
    "размеренный": ["упорядоченный"],
    "размерив": ["размеривши"],
    "размеривав": ["размеривавши"],
    "размеривавши": ["размеривав"],
    "размеривши": ["размерив"],
    "размерная величина": ["именованная величина"],
    "размеряв": ["размерявши"],
    "размерявши": ["размеряв"],
    "размесив": ["размесивши"],
    "размесивши": ["размесив"],
    "разместив": ["разместивши"],
    "разместивши": ["разместив"],
    "разметав": ["разметавши"],
    "разметавши": ["разметав"],
    "разметать": ["мести", "развевать", "рассеивать"],
    "разметив": ["разметивши"],
    "разметивши": ["разметив"],
    "разметочный": ["намёточный"],
    "размечав": ["размечавши"],
    "размечавши": ["размечав"],
    "размечивав": ["размечивавши"],
    "размечивавши": ["размечивав"],
    "размешав": ["размешавши"],
    "размешавши": ["размешав"],
    "размешивав": ["размешивавши"],
    "размешивавши": ["размешивав"],
    "размещав": ["размещавши"],
    "размещавши": ["размещав"],
    "размещалово": ["джинса", "заказуха"],
    "размещаться": ["располагаться", "устраиваться", "поселяться", "расселяться", "находиться", "помещаться"],
    "размещение": ["помещение", "распределение", "позиционирование", "расположение", "расстановка"],
    "размещенье": ["размещение"],
    "размещённый": ["дислоцированный"],
    "разминав": ["разминавши"],
    "разминавши": ["разминав"],
    "разминание": ["разминка"],
    "разминировав": ["разминировавши"],
    "разминировавши": ["разминировав"],
    "разминёр": ["сапёр"],
    "размирица": ["бунт", "смут", "безредица", "метеж", "междуособица"],
    "размирник": ["бунтовник", "метежник", "въстаник"],
    "размножав": ["размножавши"],
    "размножавши": ["размножав"],
    "размножаться": ["множиться", "плодиться"],
    "размноженье": ["размножение"],
    "размножив": ["размноживши"],
    "размноживши": ["размножив"],
    "размножиться": ["умножиться", "расплодиться"],
    "размозжав": ["размозжавши"],
    "размозжавши": ["размозжав"],
    "размозжив": ["размозживши"],
    "размозживши": ["размозжив"],
    "размозжить": ["раздробить"],
    "размокав": ["размокавши"],
    "размокавши": ["размокав"],
    "размокнув": ["размокнувши"],
    "размокнувши": ["размокнув"],
    "размокропогодив": ["размокропогодивши"],
    "размокропогодивши": ["размокропогодив"],
    "размокропогодиться": ["занепогодиться", "размокропогодить"],
    "размолаживав": ["размолаживавши"],
    "размолаживавши": ["размолаживав"],
    "размолачивав": ["размолачивавши"],
    "размолачивавши": ["размолачивав"],
    "размолвив": ["размолвивши"],
    "размолвивши": ["размолвив"],
    "размолвливав": ["размолвливавши"],
    "размолвливавши": ["размолвливав"],
    "размолвливать": ["размолвлять"],
    "размолвляв": ["размолвлявши"],
    "размолвлявши": ["размолвляв"],
    "размолвлять": ["размолвливать"],
    "размолов": ["размоловши"],
    "размоловши": ["размолов"],
    "размолодив": ["размолодивши"],
    "размолодивши": ["размолодив"],
    "размолотив": ["размолотивши"],
    "размолотивши": ["размолотив"],
    "размолочный": ["размольный", "размолевочный", "измельчительный", "дробильный", "молотильный", "перемалывающий", "раздробительный", "подрывной", "измельчающий", "перетирательный", "перемолочный"],
    "размольный": ["размолочный", "измельчительный", "размолевочный", "углеразмольный"],
    "размонтировав": ["размонтировавши"],
    "размонтировавши": ["размонтировав"],
    "размонтироваться": ["демонтироваться"],
    "размораживав": ["размораживавши"],
    "размораживавши": ["размораживав"],
    "размораживание": ["разморозка"],
    "размораживать": ["оттаивать"],
    "размораживаться": ["оттаивать"],
    "размордев": ["размордевши"],
    "размордевши": ["размордев"],
    "разморив": ["разморивши"],
    "разморивши": ["разморив"],
    "разморить": ["развезти"],
    "разморозив": ["разморозивши"],
    "разморозивши": ["разморозив"],
    "разморозиться": ["оттаять"],
    "разморозка": ["размораживание"],
    "размотав": ["размотавши"],
    "размотавши": ["размотав"],
    "размотать": ["раскрутить", "развить"],
    "размотыжив": ["размотыживши"],
    "размотыживав": ["размотыживавши"],
    "размотыживавши": ["размотыживав"],
    "размотыживши": ["размотыжив"],
    "размохнатив": ["размохнативши"],
    "размохнативши": ["размохнатив"],
    "размохначивав": ["размохначивавши"],
    "размохначивавши": ["размохначивав"],
    "размочаленный": ["растрёпанный", "разбитый"],
    "размочалив": ["размочаливши"],
    "размочаливав": ["размочаливавши"],
    "размочаливавши": ["размочаливав"],
    "размочаливши": ["размочалив"],
    "размочалить": ["растрепать"],
    "размочив": ["размочивши"],
    "размочивши": ["размочив"],
    "размундирив": ["размундиривши"],
    "размундиривав": ["размундиривавши"],
    "размундиривавши": ["размундиривав"],
    "размундиривать": ["раздевать"],
    "размундиривши": ["размундирив"],
    "размундирить": ["раздеть"],
    "размундштучив": ["размундштучивши"],
    "размундштучивав": ["размундштучивавши"],
    "размундштучивавши": ["размундштучивав"],
    "размундштучивши": ["размундштучив"],
    "размуровав": ["размуровавши"],
    "размуровавши": ["размуровав"],
    "размуровывав": ["размуровывавши"],
    "размуровывавши": ["размуровывав"],
    "размусолив": ["размусоливши"],
    "размусоливав": ["размусоливавши"],
    "размусоливавши": ["размусоливав"],
    "размусоливши": ["размусолив"],
    "размучав": ["размучавши"],
    "размучавши": ["размучав"],
    "размучив": ["размучивши"],
    "размучивав": ["размучивавши"],
    "размучивавши": ["размучивав"],
    "размучивши": ["размучив"],
    "размывав": ["размывавши"],
    "размывавши": ["размывав"],
    "размывание": ["размыв", "размытость", "стирание", "разбавление", "разводнение"],
    "размывать": ["сглаживать", "умалять"],
    "размывши": ["размыв"],
    "размыкав": ["размыкавши"],
    "размыкавши": ["размыкав"],
    "размыкивав": ["размыкивавши"],
    "размыкивавши": ["размыкивав"],
    "размыслив": ["размысливши"],
    "размысливши": ["размыслив"],
    "размытарив": ["размытаривши"],
    "размытаривши": ["размытарив"],
    "размытый": ["разрушенный", "изрытый", "нечёткий", "расплывчатый", "неясный", "размазанный"],
    "размышленье": ["размышление"],
    "размышляв": ["размышлявши"],
    "размышлявши": ["размышляв"],
    "размышлять": ["обмозговывать", "обдумывать", "думать"],
    "размяв": ["размявши"],
    "размявши": ["размяв"],
    "размягчав": ["размягчавши"],
    "размягчавши": ["размягчав"],
    "размягченье": ["размягчение"],
    "размягчив": ["размягчивши"],
    "размягчивши": ["размягчив"],
    "размякав": ["размякавши"],
    "размякавши": ["размякав"],
    "размякнув": ["размякнувши"],
    "размякнувши": ["размякнув"],
    "размяна": ["обмяна", "обмен"],
    "размёт": ["разлёт", "размах"],
    "размётывав": ["размётывавши"],
    "размётывавши": ["размётывав"],
    "разнайтовив": ["разнайтовивши"],
    "разнайтовивши": ["разнайтовив"],
    "разнайтовливав": ["разнайтовливавши"],
    "разнайтовливавши": ["разнайтовливав"],
    "разнашивав": ["разнашивавши"],
    "разнашивавши": ["разнашивав"],
    "разнебитеност": ["разстройство", "повреда"],
    "разнежив": ["разнеживши"],
    "разнеживав": ["разнеживавши"],
    "разнеживавши": ["разнеживав"],
    "разнеживши": ["разнежив"],
    "разнесённость": ["удалённость", "несмежность"],
    "разнив": ["разнивши"],
    "разнивши": ["разнив"],
    "разнизав": ["разнизавши"],
    "разнизавши": ["разнизав"],
    "разнизывав": ["разнизывавши"],
    "разнизывавши": ["разнизывав"],
    "разнимав": ["разнимавши"],
    "разнимавши": ["разнимав"],
    "разнить": ["делить", "отделять", "выделять"],
    "разниться": ["отличаться", "различаться", "розниться"],
    "разница": ["несходство", "различие", "отличие", "непохожесть", "несхожесть", "расхождение"],
    "разно": ["по-разному", "различно", "разнообразно", "когда как"],
    "разнобойный": ["разнотипный", "неоднородный", "разнокалиберный"],
    "разновес": ["разновеска", "разновесок"],
    "разновозрастный": ["разновозрастной"],
    "разновременно": ["асинхронно"],
    "разновременность": ["асинхронизм"],
    "разногласив": ["разногласивши"],
    "разногласивши": ["разногласив"],
    "разногласье": ["разногласие"],
    "разноголосив": ["разноголосивши"],
    "разноголосивши": ["разноголосив"],
    "разнодомный": ["гетероталличный"],
    "разножопица": ["разнобой"],
    "разнозначный": ["разнозначащий", "разнозначительный", "многозначный", "двусмысленный"],
    "разномыслив": ["разномысливши"],
    "разномысливши": ["разномыслив"],
    "разнообразив": ["разнообразивши"],
    "разнообразивши": ["разнообразив"],
    "разнообразие": ["разнообразность"],
    "разнообразить": ["вносить разнообразие"],
    "разнообразно": ["по-разному", "неоднородно"],
    "разнообразье": ["разнообразие"],
    "разноообразив": ["разноообразивши"],
    "разноообразивши": ["разноообразив"],
    "разноплановый": ["многообразный", "многоплановый", "разнообразный", "разнородный"],
    "разноречив": ["разноречивши"],
    "разноречивши": ["разноречив"],
    "разноречье": ["разноречие"],
    "разнородность": ["неоднородность"],
    "разнородный": ["разношёрстный", "неоднородный"],
    "разнос": ["разнесение"],
    "разносив": ["разносивши"],
    "разносивши": ["разносив"],
    "разносословный": ["разночинный"],
    "разноспоровый": ["гетероспоровый"],
    "разносторонне": ["многосторонне"],
    "разносторонность": ["многосторонность", "многогранность"],
    "разность": ["остаток", "различие", "разница", "несходство"],
    "разносчик": ["доставщик", "коробейник", "коммивояжёр", "распространитель"],
    "разносчица": ["курьерша"],
    "разнотонный": ["разношёрстный"],
    "разнотык": ["недопонимание", "разногласие", "расхождение", "недопониманье", "разногласье", "расхожденье", "беспорядочность"],
    "разноцветный": ["многоцветный", "пёстрый"],
    "разноцветье": ["разноцвет", "пестрота"],
    "разнствовав": ["разнствовавши"],
    "разнствовавши": ["разнствовав"],
    "разнствовать": ["различаться", "разниться", "розниться", "отличаться"],
    "разнуздав": ["разнуздавши"],
    "разнуздавши": ["разнуздав"],
    "разнузданность": ["наглость", "своеволие"],
    "разнузданный": ["распоясавшийся", "распущенный", "оголтелый", "беззастенчивый", "безудержный", "необузданный"],
    "разнуздывав": ["разнуздывавши"],
    "разнуздывавши": ["разнуздывав"],
    "разный": ["непохожий", "несхожий", "иной", "отличный", "уникальный", "другой", "многообразный", "разнообразный", "разнородный", "всякий"],
    "разнюхав": ["разнюхавши"],
    "разнюхавши": ["разнюхав"],
    "разнюхивав": ["разнюхивавши"],
    "разнюхивавши": ["разнюхивав"],
    "разняв": ["разнявши"],
    "разнявши": ["разняв"],
    "разняться": ["разделиться", "разъединиться", "расцепиться", "разомкнуться"],
    "разобидев": ["разобидевши"],
    "разобидевши": ["разобидев"],
    "разобижав": ["разобижавши"],
    "разобижавши": ["разобижав"],
    "разоблачав": ["разоблачавши"],
    "разоблачавши": ["разоблачав"],
    "разоблачать": ["раздевать", "раскрывать", "уличать", "изобличать", "развенчивать", "выводить на чистую воду"],
    "разоблаченье": ["разоблачение"],
    "разоблачив": ["разоблачивши"],
    "разоблачивши": ["разоблачив"],
    "разоблачитель": ["уличитель"],
    "разоблачить": ["раздеть"],
    "разобличител": ["изобличител", "критик", "обвинител", "порицател"],
    "разобрав": ["разобравши"],
    "разобравши": ["разобрав"],
    "разобраться": ["устроиться", "выяснить", "понять", "уяснить"],
    "разобщав": ["разобщавши"],
    "разобщавши": ["разобщав"],
    "разобществляв": ["разобществлявши"],
    "разобществлявши": ["разобществляв"],
    "разобщив": ["разобщивши"],
    "разобщивши": ["разобщив"],
    "разогнав": ["разогнавши"],
    "разогнавши": ["разогнав"],
    "разогнув": ["разогнувши"],
    "разогнувши": ["разогнув"],
    "разогнуться": ["выпрямиться", "распрямиться"],
    "разогорчав": ["разогорчавши"],
    "разогорчавши": ["разогорчав"],
    "разогорчив": ["разогорчивши"],
    "разогорчивши": ["разогорчив"],
    "разогревав": ["разогревавши"],
    "разогревавши": ["разогревав"],
    "разогревать": ["греть"],
    "разогревочный": ["разогревательный"],
    "разогревши": ["разогрев"],
    "разогреть": ["нагреть", "греть", "подогреть", "согреть", "обогреть"],
    "разодев": ["разодевши"],
    "разодевав": ["разодевавши"],
    "разодевавши": ["разодевав"],
    "разодеваться": ["наряжаться"],
    "разодевши": ["разодев"],
    "разодолжав": ["разодолжавши"],
    "разодолжавши": ["разодолжав"],
    "разодолжив": ["разодолживши"],
    "разодолживши": ["разодолжив"],
    "разодрав": ["разодравши"],
    "разодравши": ["разодрав"],
    "разозлив": ["разозливши"],
    "разозливши": ["разозлив"],
    "разозлить": ["рассердить", "разъярить", "взорвать"],
    "разойтись": ["рассредоточиться", "разминуться", "рассеяться", "расстаться", "разлучиться", "распрощаться", "распроститься", "развестись", "раздвоиться", "разветвиться", "разъединиться"],
    "разок": ["разочек"],
    "разом": ["сразу", "зараз", "мгновенно"],
    "разомкнув": ["разомкнувши"],
    "разомкнувши": ["разомкнув"],
    "разомкнуть": ["разъединить", "развести"],
    "разомлев": ["разомлевши"],
    "разомлевав": ["разомлевавши"],
    "разомлевавши": ["разомлевав"],
    "разомлевши": ["разомлев"],
    "разопрев": ["разопревши"],
    "разопревав": ["разопревавши"],
    "разопревавши": ["разопревав"],
    "разопревши": ["разопрев"],
    "разорав": ["разоравши"],
    "разоравши": ["разорав"],
    "разорвав": ["разорвавши"],
    "разорвавши": ["разорвав"],
    "разордеться": ["раскраснеться"],
    "разоренье": ["разорение"],
    "разорив": ["разоривши"],
    "разоривши": ["разорив"],
    "разоружав": ["разоружавши"],
    "разоружавши": ["разоружав"],
    "разоружать": ["обезоруживать"],
    "разоружаться": ["обезоруживаться", "демилитаризоваться"],
    "разоруженье": ["разоружение"],
    "разоружив": ["разоруживши"],
    "разоруживши": ["разоружив"],
    "разоружить": ["обезоружить", "демилитаризовать"],
    "разоряв": ["разорявши"],
    "разорявши": ["разоряв"],
    "разоряться": ["беднеть", "нищать", "прогорать", "банкротиться", "транжирить"],
    "разорённость": ["разор", "разорение"],
    "разослав": ["разославши"],
    "разославши": ["разослав"],
    "разоспаться": ["заспаться"],
    "разосраться": ["разругаться", "рассориться"],
    "разостлав": ["разостлавши"],
    "разостлавши": ["разостлав"],
    "разостлать": ["расстелить"],
    "разоткав": ["разоткавши"],
    "разоткавши": ["разоткав"],
    "разохотив": ["разохотивши"],
    "разохотивши": ["разохотив"],
    "разохочивав": ["разохочивавши"],
    "разохочивавши": ["разохочивав"],
    "разочаровав": ["разочаровавши"],
    "разочаровавши": ["разочаровав"],
    "разочарованность": ["байронизм", "пессимизм"],
    "разочарованье": ["разочарование"],
    "разочаровывав": ["разочаровывавши"],
    "разочаровывавши": ["разочаровывав"],
    "разпасаност": ["разпуснатост", "недисциплинираност"],
    "разпис": ["списък", "каталог", "опис"],
    "разпит": ["следствие", "дознание", "анкета", "разследване"],
    "разпокъсаност": ["раздробеност", "разкъсаност"],
    "разпоредник": ["разпоредител", "ръководител"],
    "разпра": ["раздор", "вражда", "кавга"],
    "разпръсквач": ["пулверизатор"],
    "разраб": ["разработчик"],
    "разрабатывав": ["разрабатывавши"],
    "разрабатывавши": ["разрабатывав"],
    "разработав": ["разработавши"],
    "разработавши": ["разработав"],
    "разработка": ["подготовка", "дизайн", "эксплуатация"],
    "разработчик": ["разраб", "программист", "программер", "кодер", "девелопер"],
    "разработывав": ["разработывавши"],
    "разработывавши": ["разработывав"],
    "разравнивав": ["разравнивавши"],
    "разравнивавши": ["разравнивав"],
    "разразив": ["разразивши"],
    "разразивши": ["разразив"],
    "разразнивав": ["разразнивавши"],
    "разразнивавши": ["разразнивав"],
    "разразнивать": ["разрознивать"],
    "разразниваться": ["разрозниваться"],
    "разрастав": ["разраставши"],
    "разраставши": ["разрастав"],
    "разрастание": ["разрастанье"],
    "разрастанье": ["разрастание"],
    "разрастив": ["разрастивши"],
    "разрастивши": ["разрастив"],
    "разращав": ["разращавши"],
    "разращавши": ["разращав"],
    "разращивав": ["разращивавши"],
    "разращивавши": ["разращивав"],
    "разреветься": ["зареветь", "расплакаться"],
    "разрегулировав": ["разрегулировавши"],
    "разрегулировавши": ["разрегулировав"],
    "разред": ["категория", "група"],
    "разредев": ["разредевши"],
    "разредевши": ["разредев"],
    "разредив": ["разредивши"],
    "разредивши": ["разредив"],
    "разредить": ["проредить"],
    "разрежав": ["разрежавши"],
    "разрежавши": ["разрежав"],
    "разрежать": ["разреживать", "прореживать"],
    "разреженность": ["разжижение", "разрежение", "прозрачность", "истончённость"],
    "разреживав": ["разреживавши"],
    "разреживавши": ["разреживав"],
    "разреживать": ["разрежать"],
    "разрежённый": ["разреженный"],
    "разрез": ["разрезание"],
    "разрезав": ["разрезавши"],
    "разрезавши": ["разрезав"],
    "разрезывав": ["разрезывавши"],
    "разрезывавши": ["разрезывав"],
    "разрезывать": ["разрезать"],
    "разрезываться": ["разрезаться"],
    "разрекламировав": ["разрекламировавши"],
    "разрекламировавши": ["разрекламировав"],
    "разрешав": ["разрешавши"],
    "разрешавши": ["разрешав"],
    "разрешать": ["позволять", "решать"],
    "разрешение": ["разрешенье", "позволение", "позволенье", "лицензия"],
    "разрешение на временное проживание": ["рвп"],
    "разрешенье": ["разрешение"],
    "разрешив": ["разрешивши"],
    "разрешивши": ["разрешив"],
    "разрешить": ["позволить", "дозволить", "санкционировать", "допустить", "решить", "распутать", "уладить"],
    "разрисовав": ["разрисовавши"],
    "разрисовавши": ["разрисовав"],
    "разрисовывав": ["разрисовывавши"],
    "разрисовывавши": ["разрисовывав"],
    "разровняв": ["разровнявши"],
    "разровнявши": ["разровняв"],
    "разрозненность": ["разобщённость"],
    "разрознив": ["разрознивши"],
    "разрознивав": ["разрознивавши"],
    "разрознивавши": ["разрознивав"],
    "разрознивши": ["разрознив"],
    "разрознить": ["разъединить", "разобщить"],
    "разроив": ["разроивши"],
    "разроивши": ["разроив"],
    "разроняв": ["разронявши"],
    "разронявши": ["разроняв"],
    "разрубав": ["разрубавши"],
    "разрубавши": ["разрубав"],
    "разрубив": ["разрубивши"],
    "разрубивши": ["разрубив"],
    "разругав": ["разругавши"],
    "разругавши": ["разругав"],
    "разругивав": ["разругивавши"],
    "разругивавши": ["разругивав"],
    "разрулив": ["разруливши"],
    "разруливав": ["разруливавши"],
    "разруливавши": ["разруливав"],
    "разруливать": ["улаживать", "разбираться"],
    "разруливши": ["разрулив"],
    "разрумянив": ["разрумянивши"],
    "разрумянивав": ["разрумянивавши"],
    "разрумянивавши": ["разрумянивав"],
    "разрумянивши": ["разрумянив"],
    "разрустовав": ["разрустовавши"],
    "разрустовавши": ["разрустовав"],
    "разруха": ["раздор", "смута", "развал"],
    "разрушав": ["разрушавши"],
    "разрушавши": ["разрушав"],
    "разрушать": ["уничтожать", "разламывать", "ломать", "рушить", "крушить", "сокрушать"],
    "разрушаться": ["рушиться", "разваливаться"],
    "разрушение": ["ломка", "уничтожение", "разламывание", "распад", "разваливание", "развалины", "руины", "обломки"],
    "разрушенье": ["разрушение"],
    "разрушив": ["разрушивши"],
    "разрушивши": ["разрушив"],
    "разрушитель": ["уничтожитель", "сокрушитель", "победитель"],
    "разрушительно": ["сокрушительно", "вредно", "гибельно", "уничтожающе", "пагубно", "тлетворно", "губительно"],
    "разрушительный": ["деструктивный"],
    "разрушить": ["разломать", "развалить"],
    "разрыв": ["разрывание", "разлом", "взрыв", "промежуток", "просвет", "несоответствие", "ссора", "разлад", "раскол"],
    "разрыв шаблона": ["когнитивный диссонанс"],
    "разрыв-трава": ["камнеломка"],
    "разрывав": ["разрывавши"],
    "разрывавши": ["разрывав"],
    "разрывание": ["задирание", "обрывание", "лопанье", "раздирание", "растерзание", "прекращение", "прерывание", "взрывание", "обрыв", "порывание", "вспарывание", "разгребание", "разрытие", "раскапывание", "перерывание"],
    "разрывной": ["взрывной", "смешной"],
    "разрывши": ["разрыв"],
    "разрыхлев": ["разрыхлевши"],
    "разрыхлевши": ["разрыхлев"],
    "разрыхлив": ["разрыхливши"],
    "разрыхливши": ["разрыхлив"],
    "разрыхляв": ["разрыхлявши"],
    "разрыхлявши": ["разрыхляв"],
    "разрюмиться": ["расплакаться", "разнюниться", "расхныкаться"],
    "разрядив": ["разрядивши"],
    "разрядивши": ["разрядив"],
    "разрядность": ["битность"],
    "разряжав": ["разряжавши"],
    "разряжавши": ["разряжав"],
    "разряженный": ["нарядный", "приукрашенный", "вырядившийся"],
    "разряживав": ["разряживавши"],
    "разряживавши": ["разряживав"],
    "разсказать": ["изложить", "изъяснить"],
    "разсъдливост": ["разсъдителност"],
    "разсъдък": ["разум", "интелект"],
    "разтривка": ["масаж", "разтриване"],
    "разубедив": ["разубедивши"],
    "разубедивши": ["разубедив"],
    "разубедить": ["отговорить"],
    "разубеждав": ["разубеждавши"],
    "разубеждавши": ["разубеждав"],
    "разубеждать": ["отговаривать"],
    "разубирав": ["разубиравши"],
    "разубиравши": ["разубирав"],
    "разубрав": ["разубравши"],
    "разубравши": ["разубрав"],
    "разув": ["разувши"],
    "разував": ["разувавши"],
    "разувавши": ["разував"],
    "разуважав": ["разуважавши"],
    "разуважавши": ["разуважав"],
    "разуважив": ["разуваживши"],
    "разуваживши": ["разуважив"],
    "разуверенье": ["разуверение"],
    "разуверив": ["разуверивши"],
    "разуверивши": ["разуверив"],
    "разуверить": ["разубедить", "отговорить"],
    "разуверяв": ["разуверявши"],
    "разуверявши": ["разуверяв"],
    "разуверять": ["разубеждать", "отговаривать"],
    "разувши": ["разув"],
    "разугостив": ["разугостивши"],
    "разугостивши": ["разугостив"],
    "разузнав": ["разузнавши"],
    "разузнавав": ["разузнававши"],
    "разузнававши": ["разузнавав"],
    "разузнавать": ["узнавать", "выведывать", "разведывать"],
    "разузнавши": ["разузнав"],
    "разузнать": ["узнать", "выведать", "разведать", "расспросить", "разыскать", "пронюхать"],
    "разузорив": ["разузоривши"],
    "разузоривши": ["разузорив"],
    "разукомплектовав": ["разукомплектовавши"],
    "разукомплектовавши": ["разукомплектовав"],
    "разукомплектовать": ["раскомплектовать"],
    "разукомплектовка": ["разукомплектование"],
    "разукомплектовывав": ["разукомплектовывавши"],
    "разукомплектовывавши": ["разукомплектовывав"],
    "разукрасив": ["разукрасивши"],
    "разукрасивши": ["разукрасив"],
    "разукрашав": ["разукрашавши"],
    "разукрашавши": ["разукрашав"],
    "разукрашенный": ["разубранный"],
    "разукрашивав": ["разукрашивавши"],
    "разукрашивавши": ["разукрашивав"],
    "разукрепив": ["разукрепивши"],
    "разукрепивши": ["разукрепив"],
    "разукрепить": ["дезагрегировать"],
    "разукрепляв": ["разукреплявши"],
    "разукреплявши": ["разукрепляв"],
    "разукреплять": ["дезагрегировать"],
    "разукрупнив": ["разукрупнивши"],
    "разукрупнивши": ["разукрупнив"],
    "разукрупняв": ["разукрупнявши"],
    "разукрупнявши": ["разукрупняв"],
    "разум": ["интеллект", "ум", "рассудок", "смысл"],
    "разумев": ["разумевши"],
    "разумевши": ["разумев"],
    "разумеется": ["безусловно", "бесспорно", "естественно", "конечно", "несомненно"],
    "разуметь": ["понимать", "постигать"],
    "разуметься": ["подразумеваться", "иметься в виду", "конечно", "само собой", "естественно"],
    "разумненький": ["умненький"],
    "разумник": ["синезий", "синесий"],
    "разумника": ["синезия", "синесия"],
    "разумность": ["ум", "разум", "правильность"],
    "разумный": ["мыслящий", "умный", "мудрый", "понимающий", "здравый", "рациональный"],
    "разуплотнив": ["разуплотнивши"],
    "разуплотнивши": ["разуплотнив"],
    "разуплотнить": ["разредить", "проредить"],
    "разуплотниться": ["разредиться", "протечь"],
    "разуплотняв": ["разуплотнявши"],
    "разуплотнявши": ["разуплотняв"],
    "разуплотняться": ["разрежаться", "протекать"],
    "разупорядоченный": ["неупорядоченный", "хаотичный", "аморфный"],
    "разупорядочив": ["разупорядочивши"],
    "разупорядочивание": ["разупорядочение", "разупорядоченность"],
    "разупорядочивши": ["разупорядочив"],
    "разусердствоваться": ["расстараться"],
    "разутешив": ["разутешивши"],
    "разутешивши": ["разутешив"],
    "разутый": ["босой", "босоногий", "необутый", "голый"],
    "разуть глаза": ["протереть очки", "протереть линзы", "разуть гляделки", "протереть гляделки"],
    "разутюжив": ["разутюживши"],
    "разутюживав": ["разутюживавши"],
    "разутюживавши": ["разутюживав"],
    "разутюживание": ["разутюжка"],
    "разутюживать": ["гладить", "проглаживать", "дубасить"],
    "разутюживши": ["разутюжив"],
    "разутюжить": ["прогладить", "выгладить", "отмочалить", "отдубасить"],
    "разухабисто": ["лихо", "залихватски"],
    "разухабистый": ["залихватский", "задорный", "лихой", "разбитной", "развязный"],
    "разучив": ["разучивши"],
    "разучивав": ["разучивавши"],
    "разучивавши": ["разучивав"],
    "разучивать": ["выучивать"],
    "разучиваться": ["разучаться", "отучиваться", "отвыкать"],
    "разучивши": ["разучив"],
    "разцепник": ["разколник", "отцепник", "сектант", "фракционер"],
    "разъебав": ["разъебавши"],
    "разъебавши": ["разъебав"],
    "разъебай": ["недотёпа", "неумеха", "раздолбай", "растяпа", "разъёба", "пофигист", "мудак", "разгильдяй", "долбоёб", "распиздяй", "подлюка", "волчара", "блядина", "блядюга", "блядь"],
    "разъебайский": ["распиздяйский"],
    "разъебать": ["разъебти"],
    "разъебон": ["нагоняй", "разнос", "разъёб", "разъебончик"],
    "разъебончик": ["нагоняй", "разнос", "разъебон", "разъёб"],
    "разъебти": ["разъебать", "расколошматить", "разъебошить", "разъебашить"],
    "разъебуха": ["раздолбай", "разъёба", "разъебай", "долбоёб", "распиздяй"],
    "разъедав": ["разъедавши"],
    "разъедавши": ["разъедав"],
    "разъединенье": ["разъединение"],
    "разъединив": ["разъединивши"],
    "разъединивши": ["разъединив"],
    "разъединить": ["разделить", "разлучить", "разобщить", "отключить"],
    "разъединяв": ["разъединявши"],
    "разъединявши": ["разъединяв"],
    "разъединять": ["разделять", "разлучать", "разобщать", "отключать"],
    "разъединённость": ["разрозненность", "разобщённость"],
    "разъездив": ["разъездивши"],
    "разъездивши": ["разъездив"],
    "разъезжав": ["разъезжавши"],
    "разъезжавши": ["разъезжав"],
    "разъезживав": ["разъезживавши"],
    "разъезживавши": ["разъезживав"],
    "разъерепениться": ["разбушеваться"],
    "разъяв": ["разъявши"],
    "разъявши": ["разъяв"],
    "разъярив": ["разъяривши"],
    "разъяривши": ["разъярив"],
    "разъярить": ["рассердить", "разозлить", "взорвать"],
    "разъяриться": ["рассвирепеть"],
    "разъяряв": ["разъярявши"],
    "разъярявши": ["разъяряв"],
    "разъярять": ["приводить в ярость", "злить", "бесить"],
    "разъярённо": ["озлобленно", "яростно"],
    "разъярённый": ["гневный", "сердитый"],
    "разъяснев": ["разъясневши"],
    "разъясневши": ["разъяснев"],
    "разъяснение": ["объяснение"],
    "разъясненный": ["прояснившийся", "разъяснившийся"],
    "разъяснив": ["разъяснивши"],
    "разъяснивав": ["разъяснивавши"],
    "разъяснивавши": ["разъяснивав"],
    "разъяснивши": ["разъяснив"],
    "разъяснить": ["разведреть"],
    "разъясняв": ["разъяснявши"],
    "разъяснявши": ["разъясняв"],
    "разъяснять": ["объяснять", "растолковывать"],
    "разъять": ["разделить"],
    "разъятье": ["разъятие"],
    "разъёб": ["нагоняй", "разнос", "разъебон"],
    "разъём": ["разъятие"],
    "разъёмистый": ["опьяняющий", "забористый", "крепкий", "объёмный", "широкий"],
    "разыграв": ["разыгравши"],
    "разыгравши": ["разыграв"],
    "разыграть лишнего": ["реализовать лишнего"],
    "разыгрывав": ["разыгрывавши"],
    "разыгрывавши": ["разыгрывав"],
    "разымав": ["разымавши"],
    "разымавши": ["разымав"],
    "разымать": ["разнимать"],
    "разыменовав": ["разыменовавши"],
    "разыменовавши": ["разыменовав"],
    "разыменовывав": ["разыменовывавши"],
    "разыменовывавши": ["разыменовывав"],
    "разыскав": ["разыскавши"],
    "разыскавши": ["разыскав"],
    "разыскание": ["поиск", "исследование", "дознание", "следствие"],
    "разысканье": ["разыскание"],
    "разыскатель": ["исследователь"],
    "разыскать": ["отыскать"],
    "разыскивав": ["разыскивавши"],
    "разыскивавши": ["разыскивав"],
    "разыскивать": ["искать", "выискивать", "обыскивать"],
    "разыскной": ["сыскной", "поисковый", "поисковой", "розыскной"],
    "разэтовать": ["разэтывать"],
    "рай земной": ["земной рай", "прямой порядок слов"],
    "райагропромснаб": ["райагроснаб"],
    "райагроснаб": ["райагропромснаб"],
    "райвоенкомат": ["районный военный комиссариат"],
    "райда": ["рада", "олений поезд"],
    "райдужний": ["веселковий"],
    "райдшеринг": ["карпулинг"],
    "райзо": ["райземотдел"],
    "райисполком": ["районный исполнительный комитет"],
    "райком": ["районный комитет"],
    "раймина": ["ройминка"],
    "райна": ["рея", "рей"],
    "район": ["область", "округа", "окрестность"],
    "район имени лазо": ["веринский район"],
    "район имени полины осипенко": ["кербинский район"],
    "районировав": ["районировавши"],
    "районировавши": ["районировав"],
    "районирование": ["зонирование"],
    "районы республиканского подчинения": ["ррп"],
    "райский": ["небесный"],
    "райтер": ["писатель", "граффер", "граффитист", "граффитчик", "художник", "граффити"],
    "райттерапия": ["иппотерапия"],
    "райфинотдел": ["райфо"],
    "райфо": ["райфинотдел"],
    "райх": ["рейх"],
    "райхсталер": ["специесталер", "специесрейхсталер"],
    "райчиха": ["ора"],
    "райя": ["райят"],
    "рак": ["раком", "нуб", "дно", "краб"],
    "рак-отшельник": ["отшельник", "затворник", "одиночка", "нелюдим", "интроверт"],
    "рака": ["крипта"],
    "ракалия": ["ракалья"],
    "ракалья": ["негодяй", "мерзавец", "бестия", "каналья"],
    "ракамакафо": ["фристайло"],
    "раквере": ["раковор", "везенберг"],
    "ракель": ["рахиль", "рашель"],
    "ракета конгрива": ["конгревова ракета", "конгривова ракета"],
    "ракета-носитель": ["ракета космического назначения"],
    "ракетка": ["игрок"],
    "ракетный комплекс": ["рк"],
    "ракетоноситель": ["ракетоносец", "ракета-носитель"],
    "ракетоплан": ["ракетный", "планер", "ракета", "космический корабль"],
    "ракетостроитель": ["ракетчик"],
    "ракетчик": ["ракетостроитель"],
    "раки": ["ракъы"],
    "ракита": ["ива"],
    "ракия": ["палинка"],
    "ракка": ["эр-ракка"],
    "раклы": ["романы чяй", "чяй", "гаджи", "лубны"],
    "ракля": ["ракель"],
    "раковая опухоль": ["карцинома", "рак"],
    "раковина": ["ракушка", "умывальник", "каверна"],
    "раковые жерновки": ["раковые глазки", "рачьи жерновки"],
    "раковый": ["рачий", "карциномный"],
    "раком": ["задом наперёд"],
    "ракоскорпион": ["эвриптерид", "морской скорпион"],
    "ракурс": ["перспектива"],
    "ракушечник": ["ракушник", "ракушняк"],
    "ракушка": ["раковина", "моллюск"],
    "ракша": ["сизоворонка"],
    "ракъы": ["раки"],
    "раллийщик": ["раллист"],
    "раллист": ["раллийщик"],
    "раллистский": ["раллийный"],
    "рало": ["орало"],
    "ральник": ["сошник", "омеш"],
    "рама": ["рамалла", "рамаллах"],
    "рамадан": ["рамазан", "рамзан"],
    "рамаз": ["рэмэз"],
    "рамазан": ["рамадан", "рамзан"],
    "рамалла": ["рамаллах", "рама"],
    "рамаллах": ["рамалла"],
    "рамбурсировав": ["рамбурсировавши"],
    "рамбурсировавши": ["рамбурсировав"],
    "рамекин": ["кокотница"],
    "рамень": ["раменье"],
    "раменье": ["рамень", "деревня", "селенье"],
    "рамз": ["киноя"],
    "рамзаит": ["лоренценит"],
    "рами": ["крапива китайская", "бомерия белоснежная"],
    "рамификация": ["ответвление", "ветвление"],
    "рамка": ["рама", "обрамление", "границы", "пределы"],
    "рамл": ["рег"],
    "рамоли": ["рамолик"],
    "рамолик": ["рамоли", "слабак"],
    "рамонак": ["рамон", "румынка"],
    "рампа": ["пандус"],
    "рамсить": ["быковать", "бычить", "буянить"],
    "рамя": ["плечо"],
    "рана": ["ранение", "боль", "ущерб", "урон"],
    "ранг": ["категория", "разряд", "класс", "уровень"],
    "рангинкамон": ["тирукамон"],
    "рангоут": ["ронгоут"],
    "рангун": ["янгон"],
    "рангунский": ["янгонский"],
    "ранд": ["рэнд"],
    "ранд-балка": ["рандбалка", "балка-обвязка"],
    "ранданг": ["ренданг"],
    "рандеву": ["встреча", "свидание"],
    "рандолф": ["рэндольф", "рэндолф", "рендольф"],
    "рандом": ["случайность"],
    "рандомайзер": ["рандомизатор", "генератор случайных чисел"],
    "рандомизатор": ["рандомайзер", "генератор случайных чисел"],
    "рандомизировав": ["рандомизировавши"],
    "рандомизировавши": ["рандомизировав"],
    "рандомизированный": ["хаотизированный"],
    "рандомный": ["случайный", "произвольный"],
    "ранее": ["раньше", "прежде"],
    "ранение": ["поранение", "рана"],
    "раненый": ["травмированный", "искалеченный", "изуродованный", "пораненный", "повреждённый", "поражённый"],
    "раненье": ["ранение"],
    "ранепа": ["ранхигс", "президентская академия"],
    "ранет": ["ранетка"],
    "ранжировав": ["ранжировавши"],
    "ранжировавши": ["ранжировав"],
    "ранжировать": ["упорядочивать", "выстраивать"],
    "ранив": ["ранивши"],
    "ранивши": ["ранив"],
    "ранитомия": ["древолаз", "древесница", "квакша"],
    "ранить": ["изранить", "поранить", "уязвить"],
    "ранка": ["рана", "ранение"],
    "ранконтр": ["столкновение", "схватка", "стычка", "сшибка", "встреча"],
    "раннее слабоумие": ["деменция прекокс", "схизофрения", "шизофрения"],
    "раннесть": ["рань"],
    "раннеюрский": ["нижнеюрский"],
    "ранний": ["начальный"],
    "ранний кус": ["завтрак", "перехваток", "снеданье"],
    "рано": ["загодя", "заранее", "раньше времени", "преждевременно", "рановато", "досрочно", "в начале"],
    "рановато": ["преждевременно", "рано", "раньше времени", "досрочно"],
    "ранок": ["порання", "поранок", "рання"],
    "рант": ["край", "кромка", "кайма"],
    "рантье": ["откупщик"],
    "ранхигс": ["президентская академия", "ранепа"],
    "рань": ["раньё"],
    "раньше": ["ранее", "прежде", "сперва", "сначала", "поначалу"],
    "раньше времени": ["преждевременно", "рано", "рановато", "досрочно"],
    "раньше или позже": ["рано или поздно"],
    "ранёхонько": ["ранёшенько"],
    "рапан": ["рапана"],
    "рапана": ["рапан"],
    "рапануйский": ["пасхальский", "рапануйский язык", "рапануи"],
    "рапид": ["быстрые шахматы", "активные шахматы", "болид"],
    "рапонтикум": ["левзея", "стеммаканта", "большеголовник", "горчак"],
    "рапорт": ["донесение", "доклад"],
    "рапортовав": ["рапортовавши"],
    "рапортовавши": ["рапортовав"],
    "рапортовать": ["докладывать", "отчитываться"],
    "рапс": ["кольза"],
    "раритет": ["редкость", "диковина", "чудо"],
    "раритетность": ["редкость"],
    "раритетный": ["редкий", "редкостный"],
    "рарог": ["рарашек", "рариг"],
    "рас": ["расстройство аутистического спектра"],
    "расейский": ["российский"],
    "расея": ["рассеюшка", "мать-расея"],
    "раскабалив": ["раскабаливши"],
    "раскабаливши": ["раскабалив"],
    "раскабаляв": ["раскабалявши"],
    "раскабалявши": ["раскабаляв"],
    "раскабанев": ["раскабаневши"],
    "раскабаневши": ["раскабанев"],
    "раскабаневший": ["закабаневший"],
    "раскабанеть": ["закабанеть"],
    "раскавычив": ["раскавычивши"],
    "раскавычивав": ["раскавычивавши"],
    "раскавычивавши": ["раскавычивав"],
    "раскавычивши": ["раскавычив"],
    "раскадрировав": ["раскадрировавши"],
    "раскадрировавши": ["раскадрировав"],
    "раскадровав": ["раскадровавши"],
    "раскадровавши": ["раскадровав"],
    "раскадровывав": ["раскадровывавши"],
    "раскадровывавши": ["раскадровывав"],
    "расказачив": ["расказачивши"],
    "расказачивав": ["расказачивавши"],
    "расказачивавши": ["расказачивав"],
    "расказачивание": ["расказачиванье"],
    "расказачиванье": ["расказачивание"],
    "расказачивши": ["расказачив"],
    "расказнив": ["расказнивши"],
    "расказнивши": ["расказнив"],
    "раскалив": ["раскаливши"],
    "раскаливав": ["раскаливавши"],
    "раскаливавши": ["раскаливав"],
    "раскаливши": ["раскалив"],
    "раскалиться": ["накалиться"],
    "раскалывав": ["раскалывавши"],
    "раскалывавши": ["раскалывав"],
    "раскалывание": ["расколка", "раскол", "расколотье", "расщепление", "разбивание", "раскалыванье"],
    "раскалывать": ["колоть"],
    "раскаляв": ["раскалявши"],
    "раскалявши": ["раскаляв"],
    "раскалять": ["накалить"],
    "раскаляться": ["накаляться"],
    "раскантовав": ["раскантовавши"],
    "раскантовавши": ["раскантовав"],
    "раскантовывав": ["раскантовывавши"],
    "раскантовывавши": ["раскантовывав"],
    "раскапав": ["раскапавши"],
    "раскапавши": ["раскапав"],
    "раскапиталист": ["капиталист"],
    "раскапывав": ["раскапывавши"],
    "раскапывавши": ["раскапывав"],
    "раскапывание": ["раскапыванье"],
    "раскапыванье": ["раскапывание"],
    "раскардаш": ["бедлам", "бардак", "неразбериха", "ералаш"],
    "раскармливав": ["раскармливавши"],
    "раскармливавши": ["раскармливав"],
    "раскарябав": ["раскарябавши"],
    "раскарябавши": ["раскарябав"],
    "раскассировав": ["раскассировавши"],
    "раскассировавши": ["раскассировав"],
    "раскассировать": ["расформировать", "кассировать", "ликвидировать", "разогнать", "распустить"],
    "раскатав": ["раскатавши"],
    "раскатавши": ["раскатав"],
    "раскатать": ["развернуть", "укатать"],
    "раскатив": ["раскативши"],
    "раскативши": ["раскатив"],
    "раскатка": ["раскатывание"],
    "раскатный": ["громкий", "длительный", "грохотный", "гулкий"],
    "раскатывав": ["раскатывавши"],
    "раскатывавши": ["раскатывав"],
    "раскатывание": ["раскатка"],
    "раскатывать": ["разворачивать", "раскручивать"],
    "раскатывать губу": ["раскатывать губу до гастронома", "раскатывать губу до пола"],
    "раскачав": ["раскачавши"],
    "раскачавши": ["раскачав"],
    "раскачивав": ["раскачивавши"],
    "раскачивавши": ["раскачивав"],
    "раскачиванье": ["раскачивание"],
    "раскачиваться": ["раскочегариваться"],
    "раскачка": ["раскачивание", "расшатывание", "активизация", "пробуждение", "подготовка", "построение"],
    "раскашивав": ["раскашивавши"],
    "раскашивавши": ["раскашивав"],
    "расквартировав": ["расквартировавши"],
    "расквартировавши": ["расквартировав"],
    "расквартировывав": ["расквартировывавши"],
    "расквартировывавши": ["расквартировывав"],
    "расквасив": ["расквасивши"],
    "расквасивши": ["расквасив"],
    "расквасить": ["разжидить"],
    "расквашивав": ["расквашивавши"],
    "расквашивавши": ["расквашивав"],
    "расквитаться": ["рассчитаться", "расплатиться", "отомстить", "поквитаться", "отплатить"],
    "раскидав": ["раскидавши"],
    "раскидавши": ["раскидав"],
    "раскиданный": ["разбросанный"],
    "раскидка": ["раскидывание"],
    "раскидывав": ["раскидывавши"],
    "раскидывавши": ["раскидывав"],
    "раскидываться": ["разбрасываться", "разваливаться"],
    "раскинув": ["раскинувши"],
    "раскинувши": ["раскинув"],
    "раскипятив": ["раскипятивши"],
    "раскипятивши": ["раскипятив"],
    "раскисав": ["раскисавши"],
    "раскисавши": ["раскисав"],
    "раскиселив": ["раскиселивши"],
    "раскиселивши": ["раскиселив"],
    "раскислив": ["раскисливши"],
    "раскисливши": ["раскислив"],
    "раскисляв": ["раскислявши"],
    "раскислявши": ["раскисляв"],
    "раскиснув": ["раскиснувши"],
    "раскиснувши": ["раскиснув"],
    "расклад": ["раскладывание", "распределение"],
    "раскладной": ["складной", "раскидной", "разборный"],
    "раскладушка": ["книжка-раскладушка", "штендер"],
    "раскладывав": ["раскладывавши"],
    "раскладывавши": ["раскладывав"],
    "раскладыванье": ["раскладывание"],
    "раскланиваться": ["расшаркиваться", "здороваться"],
    "раскланяться": ["поклониться", "распрощаться"],
    "расклассифицировав": ["расклассифицировавши"],
    "расклассифицировавши": ["расклассифицировав"],
    "расклевав": ["расклевавши"],
    "расклевавши": ["расклевав"],
    "расклевать": ["склевать"],
    "расклеив": ["расклеивши"],
    "расклеивав": ["расклеивавши"],
    "расклеивавши": ["расклеивав"],
    "расклеивши": ["расклеив"],
    "расклеить": ["разлепить"],
    "расклепав": ["расклепавши"],
    "расклепавши": ["расклепав"],
    "расклинив": ["расклинивши"],
    "расклинивав": ["расклинивавши"],
    "расклинивавши": ["расклинивав"],
    "расклинивши": ["расклинив"],
    "расклиняв": ["расклинявши"],
    "расклинявши": ["расклиняв"],
    "расклинять": ["расклинивать"],
    "расклячив": ["расклячивши"],
    "расклячивши": ["расклячив"],
    "расклёвывав": ["расклёвывавши"],
    "расклёвывавши": ["расклёвывав"],
    "расклёпывав": ["расклёпывавши"],
    "расклёпывавши": ["расклёпывав"],
    "расклёшив": ["расклёшивши"],
    "расклёшивав": ["расклёшивавши"],
    "расклёшивавши": ["расклёшивав"],
    "расклёшивши": ["расклёшив"],
    "расковав": ["расковавши"],
    "расковавши": ["расковав"],
    "раскованно": ["раскрепощённо"],
    "раскованность": ["раскрепощённость"],
    "расковывав": ["расковывавши"],
    "расковывавши": ["расковывав"],
    "расковыривав": ["расковыривавши"],
    "расковыривавши": ["расковыривав"],
    "расковыряв": ["расковырявши"],
    "расковырявши": ["расковыряв"],
    "раскодировав": ["раскодировавши"],
    "раскодировавши": ["раскодировав"],
    "раскодировать": ["декодировать"],
    "раскокав": ["раскокавши"],
    "раскокавши": ["раскокав"],
    "раскоксовка": ["очистка"],
    "расколачивав": ["расколачивавши"],
    "расколачивавши": ["расколачивав"],
    "расколдовав": ["расколдовавши"],
    "расколдовавши": ["расколдовав"],
    "расколдовывав": ["расколдовывавши"],
    "расколдовывавши": ["расколдовывав"],
    "расколебав": ["расколебавши"],
    "расколебавши": ["расколебав"],
    "расколов": ["расколовши"],
    "расколовши": ["расколов"],
    "расколотив": ["расколотивши"],
    "расколотивши": ["расколотив"],
    "расколотость": ["разъединённость", "раздробленность", "раздельность", "отдельность", "разобщенность", "неполнота", "несогласованность", "некомплектность", "бессвязность"],
    "расколотый": ["разломанный", "разбитый"],
    "расколошматив": ["расколошмативши"],
    "расколошмативши": ["расколошматив"],
    "расколтунив": ["расколтунивши"],
    "расколтунивши": ["расколтунив"],
    "расколупав": ["расколупавши"],
    "расколупавши": ["расколупав"],
    "расколупать": ["расковырять"],
    "расколупывав": ["расколупывавши"],
    "расколупывавши": ["расколупывав"],
    "расколупывать": ["расковыривать", "облупливать"],
    "расколыхав": ["расколыхавши"],
    "расколыхавши": ["расколыхав"],
    "расколыхивав": ["расколыхивавши"],
    "расколыхивавши": ["расколыхивав"],
    "расколыхнув": ["расколыхнувши"],
    "расколыхнувши": ["расколыхнув"],
    "раскольник": ["смутьян", "саботажник"],
    "раскомандировав": ["раскомандировавши"],
    "раскомандировавши": ["раскомандировав"],
    "раскомандировывав": ["раскомандировывавши"],
    "раскомандировывавши": ["раскомандировывав"],
    "раскомплексовав": ["раскомплексовавши"],
    "раскомплексовавши": ["раскомплексовав"],
    "раскомплексовывав": ["раскомплексовывавши"],
    "раскомплексовывавши": ["раскомплексовывав"],
    "раскомплектовав": ["раскомплектовавши"],
    "раскомплектовавши": ["раскомплектовав"],
    "раскомплектовывав": ["раскомплектовывавши"],
    "раскомплектовывавши": ["раскомплектовывав"],
    "расконвоировав": ["расконвоировавши"],
    "расконвоировавши": ["расконвоировав"],
    "расконопатив": ["расконопативши"],
    "расконопативши": ["расконопатив"],
    "расконопачивав": ["расконопачивавши"],
    "расконопачивавши": ["расконопачивав"],
    "расконсервация": ["деконсервация", "расконсервирование"],
    "расконсервировав": ["расконсервировавши"],
    "расконсервировавши": ["расконсервировав"],
    "расконспирировав": ["расконспирировавши"],
    "расконспирировавши": ["расконспирировав"],
    "расконтрив": ["расконтривши"],
    "расконтривши": ["расконтрив"],
    "расконтроплешив": ["расконтроплешивши"],
    "расконтроплешивши": ["расконтроплешив"],
    "раскоординировав": ["раскоординировавши"],
    "раскоординировавши": ["раскоординировав"],
    "раскоп": ["раскопки"],
    "раскопав": ["раскопавши"],
    "раскопавши": ["раскопав"],
    "раскопать": ["разрыть", "отрыть", "найти", "отыскать", "разыскать"],
    "раскопка": ["раскопки"],
    "раскормив": ["раскормивши"],
    "раскормивши": ["раскормив"],
    "раскормиться": ["разжиреть"],
    "раскороновав": ["раскороновавши"],
    "раскороновавши": ["раскороновав"],
    "раскорчевав": ["раскорчевавши"],
    "раскорчевавши": ["раскорчевав"],
    "раскорчёвка": ["раскорчёвывание", "корчевание"],
    "раскорчёвывав": ["раскорчёвывавши"],
    "раскорчёвывавши": ["раскорчёвывав"],
    "раскорябав": ["раскорябавши"],
    "раскорябавши": ["раскорябав"],
    "раскорябывав": ["раскорябывавши"],
    "раскорябывавши": ["раскорябывав"],
    "раскоряка": ["раскаряка", "растопыря", "шаперя", "щеперя"],
    "раскорячив": ["раскорячивши"],
    "раскорячивав": ["раскорячивавши"],
    "раскорячивавши": ["раскорячивав"],
    "раскорячивши": ["раскорячив"],
    "раскорячиться": ["растопыриться"],
    "раскорёжив": ["раскорёживши"],
    "раскорёживши": ["раскорёжив"],
    "раскос": ["подкос", "укосина"],
    "раскосив": ["раскосивши"],
    "раскосивши": ["раскосив"],
    "раскосматив": ["раскосмативши"],
    "раскосмативши": ["раскосматив"],
    "раскосматить": ["разлохматить"],
    "раскосмачивав": ["раскосмачивавши"],
    "раскосмачивавши": ["раскосмачивав"],
    "раскосый": ["косоглазый", "косой"],
    "раскочегарив": ["раскочегаривши"],
    "раскочегаривав": ["раскочегаривавши"],
    "раскочегаривавши": ["раскочегаривав"],
    "раскочегаривши": ["раскочегарив"],
    "раскошелив": ["раскошеливши"],
    "раскошеливав": ["раскошеливавши"],
    "раскошеливавши": ["раскошеливав"],
    "раскошеливши": ["раскошелив"],
    "раскрадывав": ["раскрадывавши"],
    "раскрадывавши": ["раскрадывав"],
    "раскрадывать": ["разворовывать"],
    "раскраивав": ["раскраивавши"],
    "раскраивавши": ["раскраивав"],
    "раскрамсывав": ["раскрамсывавши"],
    "раскрамсывавши": ["раскрамсывав"],
    "раскрас": ["раскраска"],
    "раскрасив": ["раскрасивши"],
    "раскрасивши": ["раскрасив"],
    "раскрасить": ["разукрасить"],
    "раскрашенный": ["разукрашенный", "размалёванный"],
    "раскрашивав": ["раскрашивавши"],
    "раскрашивавши": ["раскрашивав"],
    "раскрашивание": ["раскраска"],
    "раскрашивать": ["размалёвывать", "разукрашивать", "расписывать"],
    "раскрепив": ["раскрепивши"],
    "раскрепивши": ["раскрепив"],
    "раскрепляв": ["раскреплявши"],
    "раскреплявши": ["раскрепляв"],
    "раскреповав": ["раскреповавши"],
    "раскреповавши": ["раскреповав"],
    "раскреповывав": ["раскреповывавши"],
    "раскреповывавши": ["раскреповывав"],
    "раскрепостив": ["раскрепостивши"],
    "раскрепостивши": ["раскрепостив"],
    "раскрепостить": ["дать вольную", "освободить"],
    "раскрепощав": ["раскрепощавши"],
    "раскрепощавши": ["раскрепощав"],
    "раскрепощение": ["освобождение", "раскрепощённость"],
    "раскрепощенье": ["раскрепощение"],
    "раскрепощённость": ["раскованность", "непринуждённость"],
    "раскрестьянив": ["раскрестьянивши"],
    "раскрестьянивав": ["раскрестьянивавши"],
    "раскрестьянивавши": ["раскрестьянивав"],
    "раскрестьянивши": ["раскрестьянив"],
    "раскристаллизовав": ["раскристаллизовавши"],
    "раскристаллизовавши": ["раскристаллизовав"],
    "раскритиковав": ["раскритиковавши"],
    "раскритиковавши": ["раскритиковав"],
    "раскритиковать": ["расчихвостить", "разделать под орех", "разругать"],
    "раскритиковывав": ["раскритиковывавши"],
    "раскритиковывавши": ["раскритиковывав"],
    "раскричав": ["раскричавши"],
    "раскричавши": ["раскричав"],
    "раскровавить": ["раскровянить"],
    "раскровенив": ["раскровенивши"],
    "раскровенивши": ["раскровенив"],
    "раскровянив": ["раскровянивши"],
    "раскровянивши": ["раскровянив"],
    "раскровянить": ["раскровавить"],
    "раскроив": ["раскроивши"],
    "раскроивши": ["раскроив"],
    "раскромсав": ["раскромсавши"],
    "раскромсавши": ["раскромсав"],
    "раскрошив": ["раскрошивши"],
    "раскрошивши": ["раскрошив"],
    "раскружалив": ["раскружаливши"],
    "раскружаливав": ["раскружаливавши"],
    "раскружаливавши": ["раскружаливав"],
    "раскружаливши": ["раскружалив"],
    "раскружив": ["раскруживши"],
    "раскруживши": ["раскружив"],
    "раскрутив": ["раскрутивши"],
    "раскрутивши": ["раскрутив"],
    "раскрутить": ["размотать", "развинтить", "открутить"],
    "раскрутка": ["раскручивание", "промоушн"],
    "раскручивав": ["раскручивавши"],
    "раскручивавши": ["раскручивав"],
    "раскручивать": ["разматывать", "расплетать", "распутывать", "крутить", "вращать", "раскочегаривать", "развивать"],
    "раскрывав": ["раскрывавши"],
    "раскрывавши": ["раскрывав"],
    "раскрывши": ["раскрыв"],
    "раскрылатив": ["раскрылативши"],
    "раскрылативши": ["раскрылатив"],
    "раскрылив": ["раскрыливши"],
    "раскрыливав": ["раскрыливавши"],
    "раскрыливавши": ["раскрыливав"],
    "раскрыливши": ["раскрылив"],
    "раскрытие": ["открывание", "отворение", "раскрывание", "раскрытость", "рассекречивание", "обнаружение", "выявление"],
    "раскрытый": ["разверстый"],
    "раскрыть": ["открыть", "расследовать", "обнаружить", "выявить", "вскрыть"],
    "раскрытье": ["раскрытие"],
    "раскрыться": ["открыться", "отвориться"],
    "раскряжевав": ["раскряжевавши"],
    "раскряжевавши": ["раскряжевав"],
    "раскряжёвывав": ["раскряжёвывавши"],
    "раскряжёвывавши": ["раскряжёвывав"],
    "раскудлатив": ["раскудлативши"],
    "раскудлативши": ["раскудлатив"],
    "раскудрявив": ["раскудрявивши"],
    "раскудрявивши": ["раскудрявив"],
    "раскулачив": ["раскулачивши"],
    "раскулачивав": ["раскулачивавши"],
    "раскулачивавши": ["раскулачивав"],
    "раскулачивание": ["раскулачка"],
    "раскулачиванье": ["раскулачивание"],
    "раскулачивши": ["раскулачив"],
    "раскумекав": ["раскумекавши"],
    "раскумекавши": ["раскумекав"],
    "раскупав": ["раскупавши"],
    "раскупавши": ["раскупав"],
    "раскупать": ["расхватывать", "разбирать", "выкупать", "скупать"],
    "раскупив": ["раскупивши"],
    "раскупивши": ["раскупив"],
    "раскупорив": ["раскупоривши"],
    "раскупоривав": ["раскупоривавши"],
    "раскупоривавши": ["раскупоривав"],
    "раскупоривание": ["откупоривание", "раскупорка"],
    "раскупоривать": ["откупоривать"],
    "раскупориваться": ["откупориваться"],
    "раскупоривши": ["раскупорив"],
    "раскупорить": ["откупорить"],
    "раскупориться": ["откупориться"],
    "раскупорка": ["раскупоривание", "откупорка"],
    "раскуражив": ["раскураживши"],
    "раскураживав": ["раскураживавши"],
    "раскураживавши": ["раскураживав"],
    "раскураживши": ["раскуражив"],
    "раскурив": ["раскуривши"],
    "раскуривав": ["раскуривавши"],
    "раскуривавши": ["раскуривав"],
    "раскуривши": ["раскурив"],
    "раскуркулив": ["раскуркуливши"],
    "раскуркуливав": ["раскуркуливавши"],
    "раскуркуливавши": ["раскуркуливав"],
    "раскуркуливши": ["раскуркулив"],
    "раскурочив": ["раскурочивши"],
    "раскурочивав": ["раскурочивавши"],
    "раскурочивавши": ["раскурочивав"],
    "раскурочивать": ["курочить"],
    "раскурочивши": ["раскурочив"],
    "раскурочить": ["разломать", "разорить"],
    "раскусав": ["раскусавши"],
    "раскусавши": ["раскусав"],
    "раскусив": ["раскусивши"],
    "раскусивши": ["раскусив"],
    "раскусывав": ["раскусывавши"],
    "раскусывавши": ["раскусывав"],
    "раскутав": ["раскутавши"],
    "раскутавши": ["раскутав"],
    "раскутаться": ["откутаться"],
    "раскутывав": ["раскутывавши"],
    "раскутывавши": ["раскутывав"],
    "раскутывать": ["откутывать"],
    "раскутываться": ["откутываться"],
    "раскушав": ["раскушавши"],
    "раскушавши": ["раскушав"],
    "расм": ["сурат"],
    "расондан": ["расонидан"],
    "распад": ["дробление", "разделение", "разъединение", "дезинтеграция"],
    "распадаться": ["разваливаться", "разрушаться", "рассыпаться"],
    "распаденье": ["распадение"],
    "распадина": ["распадок"],
    "распадок": ["балка", "лог", "буерак", "яр", "яруга"],
    "распаивав": ["распаивавши"],
    "распаивавши": ["распаивав"],
    "распаковав": ["распаковавши"],
    "распаковавши": ["распаковав"],
    "распаковывав": ["распаковывавши"],
    "распаковывавши": ["распаковывав"],
    "распалив": ["распаливши"],
    "распаливав": ["распаливавши"],
    "распаливавши": ["распаливав"],
    "распаливши": ["распалив"],
    "распалубив": ["распалубивши"],
    "распалубивши": ["распалубив"],
    "распальцовка": ["пальцовка", "гонор"],
    "распальцовочный": ["распальцованный"],
    "распаляв": ["распалявши"],
    "распалявши": ["распаляв"],
    "распараллелив": ["распараллеливши"],
    "распараллеливав": ["распараллеливавши"],
    "распараллеливавши": ["распараллеливав"],
    "распараллеливши": ["распараллелив"],
    "распарив": ["распаривши"],
    "распаривав": ["распаривавши"],
    "распаривавши": ["распаривав"],
    "распаривши": ["распарив"],
    "распарывав": ["распарывавши"],
    "распарывавши": ["распарывав"],
    "распасовав": ["распасовавши"],
    "распасовавши": ["распасовав"],
    "распасовывав": ["распасовывавши"],
    "распасовывавши": ["распасовывав"],
    "распатлав": ["распатлавши"],
    "распатлавши": ["распатлав"],
    "распатронив": ["распатронивши"],
    "распатронивав": ["распатронивавши"],
    "распатронивавши": ["распатронивав"],
    "распатронивать": ["распистонивать"],
    "распатронивши": ["распатронив"],
    "распатронить": ["распотрошить", "раскурочить", "разругать", "распечь"],
    "распауживав": ["распауживавши"],
    "распауживавши": ["распауживав"],
    "распаузив": ["распаузивши"],
    "распаузивши": ["распаузив"],
    "распахав": ["распахавши"],
    "распахавши": ["распахав"],
    "распахивав": ["распахивавши"],
    "распахивавши": ["распахивав"],
    "распахнув": ["распахнувши"],
    "распахнувши": ["распахнув"],
    "распаяв": ["распаявши"],
    "распаявши": ["распаяв"],
    "распевав": ["распевавши"],
    "распевавши": ["распевав"],
    "распевание": ["распевка"],
    "распевка": ["распевание"],
    "распевный": ["протяжный", "певучий", "напевный"],
    "распевши": ["распев"],
    "распекав": ["распекавши"],
    "распекавши": ["распекав"],
    "распеканье": ["распекание"],
    "распекать": ["выговаривать", "пробирать", "разносить", "греть", "жучить", "отделывать", "песочить", "пушить", "утюжить", "шерстить", "шпиговать", "строжить"],
    "распеленав": ["распеленавши"],
    "распеленавши": ["распеленав"],
    "распелёнывав": ["распелёнывавши"],
    "распелёнывавши": ["распелёнывав"],
    "расперев": ["распёрши"],
    "распестрив": ["распестривши"],
    "распестривши": ["распестрив"],
    "распестряв": ["распестрявши"],
    "распестрявши": ["распестряв"],
    "распетушиться": ["раззадориться"],
    "распечатав": ["распечатавши"],
    "распечатавши": ["распечатав"],
    "распечатка": ["распечатывание"],
    "распечатывав": ["распечатывавши"],
    "распечатывавши": ["распечатывав"],
    "распиарив": ["распиаривши"],
    "распиаривши": ["распиарив"],
    "распив": ["распивши"],
    "распивав": ["распивавши"],
    "распивавши": ["распивав"],
    "распивши": ["распив"],
    "распидорасив": ["распидорасивши"],
    "распидорасивши": ["распидорасив"],
    "распидорасить": ["расхуярить", "расхуячить", "разъебать", "разъебенить", "разъебашить"],
    "распиздев": ["распиздевши"],
    "распиздевши": ["распиздев"],
    "распиздеть": ["разболтать", "разнести", "перетолковать"],
    "распиздеться": ["разгутариться", "разбакланиться", "заругаться", "забраниться"],
    "распиздун": ["распиздяй", "распиздос", "распездал"],
    "распиздяй": ["разгильдяй", "раздолбай", "раззвездяй", "размандуй", "разъебай"],
    "распиздяйка": ["неумеха", "растяпа", "разгильдяйка"],
    "распиздяйничав": ["распиздяйничавши"],
    "распиздяйничавши": ["распиздяйничав"],
    "распиздяйский": ["разъебайский"],
    "распиздяйство": ["разгильдяйство"],
    "распиздяйствовав": ["распиздяйствовавши"],
    "распиздяйствовавши": ["распиздяйствовав"],
    "распиздяйствовать": ["распиздяйничать"],
    "распикировав": ["распикировавши"],
    "распикировавши": ["распикировав"],
    "распикировывав": ["распикировывавши"],
    "распикировывавши": ["распикировывав"],
    "распил": ["распиливание", "распилдос"],
    "распилив": ["распиливши"],
    "распиливав": ["распиливавши"],
    "распиливавши": ["распиливав"],
    "распиливши": ["распилив"],
    "распиловщик": ["пильщик"],
    "распинав": ["распинавши"],
    "распинавши": ["распинав"],
    "распинывав": ["распинывавши"],
    "распинывавши": ["распинывав"],
    "распирав": ["распиравши"],
    "распиравши": ["распирав"],
    "расписав": ["расписавши"],
    "расписавши": ["расписав"],
    "расписаться": ["подписаться"],
    "расписной": ["писаный", "раскрашенный"],
    "расписной единорог": ["тропическая осбекия"],
    "распистонив": ["распистонивши"],
    "распистонивши": ["распистонив"],
    "расписчик": ["расписыватель"],
    "расписывав": ["расписывавши"],
    "расписывавши": ["расписывав"],
    "расписыватель": ["расписчик"],
    "распихав": ["распихавши"],
    "распихавши": ["распихав"],
    "распихивав": ["распихивавши"],
    "распихивавши": ["распихивав"],
    "распихивать": ["размещать", "раскладывать"],
    "распихнув": ["распихнувши"],
    "распихнувши": ["распихнув"],
    "расплавив": ["расплавивши"],
    "расплавивши": ["расплавив"],
    "расплавление": ["расплавливание", "плавление"],
    "расплавляв": ["расплавлявши"],
    "расплавлявши": ["расплавляв"],
    "расплавлять": ["плавить", "растапливать"],
    "распланировав": ["распланировавши"],
    "распланировавши": ["распланировав"],
    "распланировывав": ["распланировывавши"],
    "распланировывавши": ["распланировывав"],
    "расплановав": ["расплановавши"],
    "расплановавши": ["расплановав"],
    "распластав": ["распластавши"],
    "распластавши": ["распластав"],
    "распластаться": ["растянуться"],
    "распластовав": ["распластовавши"],
    "распластовавши": ["распластовав"],
    "распластовывав": ["распластовывавши"],
    "распластовывавши": ["распластовывав"],
    "распластывав": ["распластывавши"],
    "распластывавши": ["распластывав"],
    "распластывать": ["пластать", "расправлять"],
    "расплатив": ["расплативши"],
    "расплативши": ["расплатив"],
    "расплатить": ["уплатить"],
    "расплевав": ["расплевавши"],
    "расплевавши": ["расплевав"],
    "расплескав": ["расплескавши"],
    "расплескавши": ["расплескав"],
    "расплеснув": ["расплеснувши"],
    "расплеснувши": ["расплеснув"],
    "расплетав": ["расплетавши"],
    "расплетавши": ["расплетав"],
    "расплетаться": ["развиваться"],
    "расплодив": ["расплодивши"],
    "расплодивши": ["расплодив"],
    "распложав": ["распложавши"],
    "распложавши": ["распложав"],
    "распложая": ["множа"],
    "распломбировав": ["распломбировавши"],
    "распломбировавши": ["распломбировав"],
    "распломбировывав": ["распломбировывавши"],
    "распломбировывавши": ["распломбировывав"],
    "расплываться": ["растекаться", "разливаться", "расходиться", "распространяться", "наполнять", "рассеиваться", "редеть", "лыбиться", "толстеть"],
    "расплывчато": ["неопределённо"],
    "расплывчатый": ["размытый"],
    "расплюснув": ["расплюснувши"],
    "расплюснувши": ["расплюснув"],
    "расплющив": ["расплющивши"],
    "расплющивав": ["расплющивавши"],
    "расплющивавши": ["расплющивав"],
    "расплющивши": ["расплющив"],
    "расплющить": ["раздавить", "сплющить", "расплюснуть"],
    "расплёвывав": ["расплёвывавши"],
    "расплёвывавши": ["расплёвывав"],
    "расплёскивав": ["расплёскивавши"],
    "расплёскивавши": ["расплёскивав"],
    "распнув": ["распнувши"],
    "распнувши": ["распнув"],
    "распогодив": ["распогодивши"],
    "распогодивши": ["распогодив"],
    "расподобляв": ["расподоблявши"],
    "расподоблявши": ["расподобляв"],
    "распознав": ["распознавши"],
    "распознавав": ["распознававши"],
    "распознававши": ["распознавав"],
    "распознаванье": ["распознавание"],
    "распознавши": ["распознав"],
    "распознать": ["узнать", "разглядеть", "различить"],
    "располагав": ["располагавши"],
    "располагавши": ["располагав"],
    "располагать": ["обладать"],
    "располагаться": ["размещаться", "находиться", "устраиваться"],
    "располаскивав": ["располаскивавши"],
    "располаскивавши": ["располаскивав"],
    "расползаться": ["сползаться"],
    "располировав": ["располировавши"],
    "располировавши": ["располировав"],
    "располировывав": ["располировывавши"],
    "располировывавши": ["располировывав"],
    "располнев": ["располневши"],
    "располневши": ["располнев"],
    "располневший": ["растолстевший", "пополневший", "потолстевший", "огрузневший"],
    "располнеть": ["растолстеть"],
    "располовинив": ["располовинивши"],
    "располовинивши": ["располовинив"],
    "располовинить": ["раздвоить"],
    "расположение": ["размещение", "позиционирование", "помещение", "расстановка", "территория", "симпатия", "склонность", "желание", "настроение"],
    "расположенный": ["находящийся"],
    "расположив": ["расположивши"],
    "расположивши": ["расположив"],
    "располоскав": ["располоскавши"],
    "располоскавши": ["располоскав"],
    "располоснув": ["располоснувши"],
    "располоснувши": ["располоснув"],
    "располосовав": ["располосовавши"],
    "располосовавши": ["располосовав"],
    "располосовывав": ["располосовывавши"],
    "располосовывавши": ["располосовывав"],
    "распомадив": ["распомадивши"],
    "распомадивши": ["распомадив"],
    "распополамить": ["располовинить"],
    "распоров": ["распоровши"],
    "распоровши": ["распоров"],
    "распорошив": ["распорошивши"],
    "распорошивши": ["распорошив"],
    "распорядив": ["распорядивши"],
    "распорядивши": ["распорядив"],
    "распорядитель": ["руководитель", "управляющий"],
    "распорядительница": ["командирша", "капитанша"],
    "распорядиться": ["велеть", "приказать"],
    "распоряжав": ["распоряжавши"],
    "распоряжавши": ["распоряжав"],
    "распоряжаться": ["приказывать", "хозяйствовать", "хозяйничать", "управлять", "применять", "задействовать"],
    "распоряжение": ["подчинение", "управление", "постановление", "приказ", "приказание", "указ", "указание"],
    "распоследний": ["последний"],
    "распотев": ["распотевши"],
    "распотевши": ["распотев"],
    "распотешив": ["распотешивши"],
    "распотешивав": ["распотешивавши"],
    "распотешивавши": ["распотешивав"],
    "распотешивши": ["распотешив"],
    "распотрошив": ["распотрошивши"],
    "распотрошивши": ["распотрошив"],
    "распотякивав": ["распотякивавши"],
    "распотякивавши": ["распотякивав"],
    "распочав": ["распочавши"],
    "распочавши": ["распочав"],
    "распочинав": ["распочинавши"],
    "распочинавши": ["распочинав"],
    "распошивальная машина": ["распошивалка", "плоскошовка", "плоскошовная машина"],
    "распошивальный шов": ["плоский шов"],
    "распоясав": ["распоясавши"],
    "распоясавши": ["распоясав"],
    "распоясаться": ["распуститься", "разболтаться"],
    "распоясывав": ["распоясывавши"],
    "распоясывавши": ["распоясывав"],
    "расправив": ["расправивши"],
    "расправивши": ["расправив"],
    "расправить": ["разгладить", "разровнять", "потянуть", "вытянуть"],
    "расправить крылья": ["распрямить крылья"],
    "расправляв": ["расправлявши"],
    "расправлявши": ["расправляв"],
    "расправляться": ["разглаживаться", "сглаживаться", "изглаживаться"],
    "распрастывав": ["распрастывавши"],
    "распрастывавши": ["распрастывав"],
    "распредбат": ["распредбатальон"],
    "распредбатальон": ["распредбат"],
    "распределенье": ["распределение"],
    "распределив": ["распределивши", "разделив", "раздав", "разверстав"],
    "распределивши": ["распределив"],
    "распределяв": ["распределявши"],
    "распределявши": ["распределяв"],
    "распределённость": ["децентрализованность"],
    "распредметив": ["распредметивши"],
    "распредметивши": ["распредметив"],
    "распредмечивав": ["распредмечивавши"],
    "распредмечивавши": ["распредмечивав"],
    "распрекрасный": ["прекрасный", "расчудесный"],
    "распреснив": ["распреснивши"],
    "распреснивши": ["распреснив"],
    "распресняв": ["распреснявши"],
    "распреснявши": ["распресняв"],
    "расприватизация": ["деприватизация"],
    "расприватизировав": ["расприватизировавши"],
    "расприватизировавши": ["расприватизировав"],
    "расприватизировать": ["деприватизировать"],
    "распробовав": ["распробовавши"],
    "распробовавши": ["распробовав"],
    "распрограммировав": ["распрограммировавши"],
    "распрограммировавши": ["распрограммировав"],
    "распродав": ["распродавши"],
    "распродавав": ["распродававши"],
    "распродававши": ["распродавав"],
    "распродавши": ["распродав"],
    "распроебав": ["распроебавши"],
    "распроебавши": ["распроебав"],
    "распроебать": ["изъебать", "изъебти", "изъебсти", "уебать", "уеть", "уебти", "уебсти"],
    "распропагандировав": ["распропагандировавши"],
    "распропагандировавши": ["распропагандировав"],
    "распропагандировать": ["разрекламировать"],
    "распропадав": ["распропадавши"],
    "распропадавши": ["распропадав"],
    "распростав": ["распроставши"],
    "распроставши": ["распростав"],
    "распростерев": ["распростёрши"],
    "распростереть": ["развести", "раскинуть"],
    "распростирав": ["распростиравши"],
    "распростиравши": ["распростирав"],
    "распростирание": ["распространение"],
    "распростирать": ["разводить", "раскидывать", "распространять"],
    "распроститься": ["расстаться", "разлучиться", "разойтись", "распрощаться"],
    "распространение": ["распространённость"],
    "распространенье": ["распространение"],
    "распространив": ["распространивши"],
    "распространивши": ["распространив"],
    "распространяв": ["распространявши"],
    "распространявши": ["распространяв"],
    "распространяться": ["расширяться"],
    "распростудив": ["распростудивши"],
    "распростудивши": ["распростудив"],
    "распростужав": ["распростужавши"],
    "распростужавши": ["распростужав"],
    "распростёртый": ["раскинутый"],
    "распростёрши": ["распростерев"],
    "распросукин": ["рассукин"],
    "распрощавшись": ["расставшись", "распростившись"],
    "распрощаться": ["расстаться", "разлучиться", "разойтись", "распроститься"],
    "распрудив": ["распрудивши"],
    "распрудивши": ["распрудив"],
    "распружав": ["распружавши"],
    "распружавши": ["распружав"],
    "распрыжка": ["распрыг", "банни-хоп", "б-хоп"],
    "распрыскав": ["распрыскавши"],
    "распрыскавши": ["распрыскав"],
    "распрыскивав": ["распрыскивавши"],
    "распрыскивавши": ["распрыскивав"],
    "распрыскивать": ["разбрызгивать", "прыскать", "опылять"],
    "распря": ["ссора", "раздор", "вражда"],
    "распрягав": ["распрягавши"],
    "распрягавши": ["распрягав"],
    "распрягать": ["выпрягать"],
    "распрямив": ["распрямивши"],
    "распрямивши": ["распрямив"],
    "распрямить": ["выпрямить"],
    "распрямить крылья": ["освободиться"],
    "распрямиться": ["выпрямиться", "разогнуться"],
    "распрямляв": ["распрямлявши"],
    "распрямлявши": ["распрямляв"],
    "распрямлять": ["выпрямлять"],
    "распрямляться": ["выпрямляться", "разгибаться"],
    "распсиховаться": ["разнервничаться"],
    "распубликовав": ["распубликовавши"],
    "распубликовавши": ["распубликовав"],
    "распубликовывав": ["распубликовывавши"],
    "распубликовывавши": ["распубликовывав"],
    "распугав": ["распугавши"],
    "распугавши": ["распугав"],
    "распугивав": ["распугивавши"],
    "распугивавши": ["распугивав"],
    "распугнув": ["распугнувши"],
    "распугнувши": ["распугнув"],
    "распугнуть": ["распугать"],
    "распудрив": ["распудривши"],
    "распудривав": ["распудривавши"],
    "распудривавши": ["распудривав"],
    "распудривши": ["распудрив"],
    "распузырив": ["распузыривши"],
    "распузыривши": ["распузырив"],
    "распуколка": ["бутон"],
    "распускав": ["распускавши"],
    "распускавши": ["распускав"],
    "распусканье": ["распускание"],
    "распускаться": ["раскрываться", "расцветать", "расформировываться", "растворяться", "распространяться"],
    "распустив": ["распустивши"],
    "распустивши": ["распустив"],
    "распустить кадык": ["драть кадык", "кадычать", "орать", "драть глотку"],
    "распуститься": ["расцвести", "ослабнуть", "развязаться", "распоясаться", "разболтаться"],
    "распустёха": ["неряха"],
    "распутав": ["распутавши"],
    "распутавши": ["распутав"],
    "распутие": ["распутье", "росстань", "перепутье", "перекрёсток", "распутица"],
    "распутица": ["распутье", "бездорожье", "слякоть"],
    "распутник": ["гуляка", "развратник"],
    "распутница": ["развратница", "блудница", "шалава", "потаскуха", "блядь"],
    "распутничав": ["распутничавши"],
    "распутничавши": ["распутничав"],
    "распутный": ["разгульный", "развратный"],
    "распутство": ["разврат", "беспутство", "блуд"],
    "распутствовав": ["распутствовавши"],
    "распутствовавши": ["распутствовав"],
    "распутывав": ["распутывавши"],
    "распутывавши": ["распутывав"],
    "распутье": ["росстань", "перепутье", "перекрёсток", "распутица"],
    "распухав": ["распухавши"],
    "распухавши": ["распухав"],
    "распухлый": ["вспухлый", "вспухнувший", "вспухший", "набухлый", "распухнувший", "распухший", "отёчный", "опухший", "вздутый", "набухший"],
    "распухнув": ["распухнувши"],
    "распухнувши": ["распухнув"],
    "распухнуть": ["вспухнуть"],
    "распучив": ["распучивши"],
    "распучивав": ["распучивавши"],
    "распучивавши": ["распучивав"],
    "распучивши": ["распучив"],
    "распучить": ["вспучить"],
    "распушав": ["распушавши"],
    "распушавши": ["распушав"],
    "распушив": ["распушивши"],
    "распушивав": ["распушивавши"],
    "распушивавши": ["распушивав"],
    "распушивши": ["распушив"],
    "распущенность": ["развратность", "порочность", "деправация"],
    "распыленье": ["распыление"],
    "распылив": ["распыливши"],
    "распыливав": ["распыливавши"],
    "распыливавши": ["распыливав"],
    "распыливши": ["распылив"],
    "распылить": ["диспергировать", "разбрызгать", "рассеять"],
    "распыляв": ["распылявши"],
    "распылявши": ["распыляв"],
    "распылять": ["распыливать", "распыляться"],
    "распыляться": ["распалять"],
    "распытав": ["распытавши"],
    "распытавши": ["распытав"],
    "распытывав": ["распытывавши"],
    "распытывавши": ["распытывав"],
    "распытывать": ["разузнавать", "расспрашивать"],
    "распьяный": ["пьяный-распьяный", "пьянющий", "распьяной", "пьяным-распьяной"],
    "распяв": ["распявши"],
    "распявши": ["распяв"],
    "распялив": ["распяливши"],
    "распяливав": ["распяливавши"],
    "распяливавши": ["распяливав"],
    "распяливать": ["пялить", "таращить", "вылуплять"],
    "распяливши": ["распялив"],
    "распялить": ["растянуть"],
    "распятерив": ["распятеривши"],
    "распятеривши": ["распятерив"],
    "распятие": ["крест"],
    "распятье": ["распятие"],
    "распёрши": ["расперев"],
    "рассадив": ["рассадивши"],
    "рассадивши": ["рассадив"],
    "рассадник": ["питомник"],
    "рассаживав": ["рассаживавши"],
    "рассаживавши": ["рассаживав"],
    "рассаживать": ["усаживать", "сажать"],
    "рассаривав": ["рассаривавши"],
    "рассаривавши": ["рассаривав"],
    "рассасывав": ["рассасывавши"],
    "рассасывавши": ["рассасывав"],
    "рассверлив": ["рассверливши"],
    "рассверливав": ["рассверливавши"],
    "рассверливавши": ["рассверливав"],
    "рассверливши": ["рассверлив"],
    "рассвести": ["развиднеть", "ободнять"],
    "рассвет": ["восход"],
    "рассветав": ["рассветавши"],
    "рассветавши": ["рассветав"],
    "рассветать": ["светать", "светлеть"],
    "рассветив": ["рассветивши"],
    "рассветивши": ["рассветив"],
    "рассвечивав": ["рассвечивавши"],
    "рассвечивавши": ["рассвечивав"],
    "рассвирепев": ["рассвирепевши"],
    "рассвирепевши": ["рассвирепев"],
    "рассвистаться": ["рассвистеться"],
    "рассвистеться": ["рассвистаться"],
    "рассвободив": ["рассвободивши"],
    "рассвободивши": ["рассвободив"],
    "рассевав": ["рассевавши"],
    "рассевавши": ["рассевав"],
    "рассевать": ["сеять"],
    "расседлав": ["расседлавши"],
    "расседлавши": ["расседлав"],
    "рассеивав": ["рассеивавши"],
    "рассеивавши": ["рассеивав"],
    "рассеивать": ["рассевать"],
    "рассекав": ["рассекавши"],
    "рассекавши": ["рассекав"],
    "рассекать": ["чесать"],
    "рассекретив": ["рассекретивши"],
    "рассекретивши": ["рассекретив"],
    "рассекреченный": ["несекретный"],
    "рассекречивав": ["рассекречивавши"],
    "рассекречивавши": ["рассекречивав"],
    "расселив": ["расселивши"],
    "расселивши": ["расселив"],
    "расселина": ["расщелина", "ущелье", "трещина"],
    "расселяв": ["расселявши"],
    "расселявши": ["расселяв"],
    "рассердив": ["рассердивши"],
    "рассердивши": ["рассердив"],
    "рассердить": ["разозлить", "разъярить"],
    "рассердиться": ["разгневаться", "разозлиться"],
    "рассерженность": ["разгневанность"],
    "рассерженный": ["разгневанный"],
    "рассерчав": ["рассерчавши"],
    "рассерчавши": ["рассерчав"],
    "рассечение": ["рассекание", "рассечка", "рана"],
    "рассея": ["рассеяв", "рассеявши"],
    "рассеяв": ["рассеявши", "рассея"],
    "рассеявши": ["рассеяв"],
    "рассеяние": ["разбрасывание", "развеивание", "раздробление", "разнесение", "развлечение", "рассеянность"],
    "рассеянное звёздное скопление": ["рассеянное скопление"],
    "рассеянность": ["невнимание", "невнимательность", "ротозейство"],
    "рассеянье": ["рассеяние"],
    "рассиживав": ["рассиживавши"],
    "рассиживавши": ["рассиживав"],
    "рассиживать": ["рассиживаться"],
    "рассиживаться": ["рассиживать"],
    "рассинхрон": ["рассинхронизация"],
    "рассинхронизировав": ["рассинхронизировавши"],
    "рассинхронизировавши": ["рассинхронизировав"],
    "рассиропив": ["рассиропивши"],
    "рассиропивши": ["рассиропив"],
    "рассиропить": ["разбавить", "разжидить", "разгустить", "смягчить", "приукрасить"],
    "рассиропиться": ["расчувствоваться", "разнежиться", "раскиснуть"],
    "рассиропливав": ["рассиропливавши"],
    "рассиропливавши": ["рассиропливав"],
    "рассияв": ["рассиявши"],
    "рассиявши": ["рассияв"],
    "рассказ": ["новелла", "повествование"],
    "рассказав": ["рассказавши"],
    "рассказавши": ["рассказав"],
    "рассказать": ["поведать", "изложить", "изъяснить"],
    "рассказный": ["повествовательный"],
    "рассказывав": ["рассказывавши"],
    "рассказывавши": ["рассказывав"],
    "рассказыванье": ["рассказывание"],
    "рассказывать": ["повествовать", "излагать"],
    "расслабев": ["расслабевши"],
    "расслабевав": ["расслабевавши"],
    "расслабевавши": ["расслабевав"],
    "расслабевши": ["расслабев"],
    "расслабив": ["расслабивши"],
    "расслабивши": ["расслабив"],
    "расслабление": ["расслабон", "расслабуха"],
    "расслабленье": ["расслабление"],
    "расслабляв": ["расслаблявши"],
    "расслаблявши": ["расслабляв"],
    "расслабнув": ["расслабнувши"],
    "расслабнувши": ["расслабнув"],
    "расслабон": ["расслабуха"],
    "расслабуха": ["расслабон"],
    "расславив": ["расславивши"],
    "расславивши": ["расславив"],
    "расславляв": ["расславлявши"],
    "расславлявши": ["расславляв"],
    "расслаивав": ["расслаивавши"],
    "расслаивавши": ["расслаивав"],
    "расследовав": ["расследовавши"],
    "расследовавши": ["расследовав"],
    "расследование": ["расследованье"],
    "расследованье": ["расследование"],
    "расслоив": ["расслоивши"],
    "расслоивши": ["расслоив"],
    "расслушав": ["расслушавши"],
    "расслушавши": ["расслушав"],
    "расслушать": ["расслыхать", "расслышать"],
    "расслыхав": ["расслыхавши"],
    "расслыхавши": ["расслыхав"],
    "расслышав": ["расслышавши"],
    "расслышавши": ["расслышав"],
    "расслышивав": ["расслышивавши"],
    "расслышивавши": ["расслышивав"],
    "расслюнявив": ["расслюнявивши"],
    "расслюнявивши": ["расслюнявив"],
    "рассматривав": ["рассматривавши"],
    "рассматривавши": ["рассматривав"],
    "рассматривание": ["разглядывание", "рассмотрение"],
    "рассматриванье": ["рассматривание"],
    "рассматривать": ["разглядывать", "осматривать", "смотреть", "считать", "думать", "полагать", "находить", "усматривать", "видеть"],
    "рассмеивав": ["рассмеивавши"],
    "рассмеивавши": ["рассмеивав"],
    "рассмешив": ["рассмешивши"],
    "рассмешивши": ["рассмешив"],
    "рассмешить": ["насмешить"],
    "рассмеяться": ["засмеяться"],
    "рассмотрев": ["рассмотревши"],
    "рассмотревши": ["рассмотрев"],
    "рассмотренье": ["рассмотрение"],
    "рассмотреть": ["разглядеть"],
    "расснастив": ["расснастивши"],
    "расснастивши": ["расснастив"],
    "расснащав": ["расснащавши"],
    "расснащавши": ["расснащав"],
    "расснащивав": ["расснащивавши"],
    "расснащивавши": ["расснащивав"],
    "рассовав": ["рассовавши"],
    "рассовавши": ["рассовав"],
    "рассоветовав": ["рассоветовавши"],
    "рассоветовавши": ["рассоветовав"],
    "рассоветовать": ["отсоветовать"],
    "рассовывав": ["рассовывавши"],
    "рассовывавши": ["рассовывав"],
    "рассогласовав": ["рассогласовавши"],
    "рассогласовавши": ["рассогласовав"],
    "рассогласовывав": ["рассогласовывавши"],
    "рассогласовывавши": ["рассогласовывав"],
    "рассоединив": ["рассоединивши"],
    "рассоединивши": ["рассоединив"],
    "рассоединить": ["отсоединить", "разъединить"],
    "рассоединяв": ["рассоединявши"],
    "рассоединявши": ["рассоединяв"],
    "рассоединять": ["отсоединять", "разъединять"],
    "рассоединённый": ["разъединённый"],
    "рассолив": ["рассоливши"],
    "рассоливши": ["рассолив"],
    "рассоловев": ["рассоловевши"],
    "рассоловевши": ["рассоловев"],
    "рассолодев": ["рассолодевши"],
    "рассолодевши": ["рассолодев"],
    "рассолодив": ["рассолодивши"],
    "рассолодивши": ["рассолодив"],
    "рассольник": ["рассольничек"],
    "рассоляв": ["рассолявши"],
    "рассолявши": ["рассоляв"],
    "рассомаха": ["росомаха"],
    "рассорив": ["рассоривши"],
    "рассоривав": ["рассоривавши"],
    "рассоривавши": ["рассоривав"],
    "рассоривши": ["рассорив"],
    "рассорить": ["поссорить"],
    "рассориться": ["разругаться", "поссориться"],
    "рассортировав": ["рассортировавши"],
    "рассортировавши": ["рассортировав"],
    "рассортировывав": ["рассортировывавши"],
    "рассортировывавши": ["рассортировывав"],
    "рассос": ["расслабон", "чилл"],
    "рассосав": ["рассосавши"],
    "рассосавши": ["рассосав"],
    "рассосредоточив": ["рассосредоточивши"],
    "рассосредоточивши": ["рассосредоточив"],
    "расспрашивав": ["расспрашивавши"],
    "расспрашивавши": ["расспрашивав"],
    "расспрашивание": ["расспрашиванье"],
    "расспрашивать": ["выспрашивать", "допрашивать", "выяснять"],
    "расспросив": ["расспросивши"],
    "расспросивши": ["расспросив"],
    "расспросы": ["расспрашивание"],
    "рассредотачивав": ["рассредотачивавши"],
    "рассредотачивавши": ["рассредотачивав"],
    "рассредотачиваться": ["размещаться"],
    "рассредоточив": ["рассредоточивши"],
    "рассредоточивав": ["рассредоточивавши"],
    "рассредоточивавши": ["рассредоточивав"],
    "рассредоточивши": ["рассредоточив"],
    "рассрочив": ["рассрочивши"],
    "рассрочивав": ["рассрочивавши"],
    "рассрочивавши": ["рассрочивав"],
    "рассрочивши": ["рассрочив"],
    "рассрочка": ["кредит"],
    "расставание": ["прощание", "разлука"],
    "расставанье": ["расставание"],
    "расставаться": ["расходиться", "разлучаться"],
    "расставив": ["расставивши"],
    "расставивши": ["расставив"],
    "расставить": ["разместить", "расположить", "распределить", "назначить"],
    "расставляв": ["расставлявши"],
    "расставлявши": ["расставляв"],
    "расставлять": ["размещать", "располагать", "распределять", "назначать"],
    "расстаивав": ["расстаивавши"],
    "расстаивавши": ["расстаивав"],
    "расстанавливав": ["расстанавливавши"],
    "расстанавливавши": ["расстанавливав"],
    "расстанавливать": ["расставлять"],
    "расстановив": ["расстановивши"],
    "расстановивши": ["расстановив"],
    "расстанье": ["расстание"],
    "расстаться": ["разлучиться", "разойтись", "распрощаться", "распроститься"],
    "расстворяв": ["расстворявши"],
    "расстворявши": ["расстворяв"],
    "расстегав": ["расстегавши"],
    "расстегавши": ["расстегав"],
    "расстегнув": ["расстегнувши"],
    "расстегнувши": ["расстегнув"],
    "расстеклив": ["расстекливши"],
    "расстекливши": ["расстеклив"],
    "расстелив": ["расстеливши"],
    "расстеливши": ["расстелив"],
    "расстелить": ["разостлать"],
    "расстилав": ["расстилавши"],
    "расстилавши": ["расстилав"],
    "расстилать": ["стелить"],
    "расстопорить": ["отпустить"],
    "расстояв": ["расстоявши"],
    "расстоявши": ["расстояв"],
    "расстояние": ["дистанция", "промежуток", "дальность", "удалённость"],
    "расстоянье": ["расстояние", "удаление"],
    "расстраивав": ["расстраивавши"],
    "расстраивавши": ["расстраивав"],
    "расстраивать": ["нарушать", "ухудшать", "расшатывать", "огорчать", "удручать", "печалить"],
    "расстраиваться": ["разлаживаться", "огорчаться"],
    "расстрачивав": ["расстрачивавши"],
    "расстрачивавши": ["расстрачивав"],
    "расстрел": ["расстреляние", "расстреливание", "смертная казнь", "высшая мера"],
    "расстреливав": ["расстреливавши"],
    "расстреливавши": ["расстреливав"],
    "расстреляв": ["расстрелявши"],
    "расстрелявши": ["расстреляв"],
    "расстреляние": ["расстрел"],
    "расстрелянье": ["расстреляние"],
    "расстрелять": ["обстрелять", "пристрелить"],
    "расстрига": ["поп-расстрига", "монах-расстрига"],
    "расстригав": ["расстригавши"],
    "расстригавши": ["расстригав"],
    "расстроенно": ["огорчённо"],
    "расстроенный": ["огорчённый", "опечаленный"],
    "расстроив": ["расстроивши"],
    "расстроивав": ["расстроивавши"],
    "расстроивавши": ["расстроивав"],
    "расстроивши": ["расстроив"],
    "расстройство аутистического спектра": ["рас"],
    "расстройство личности": ["конституциональный", "психопатия"],
    "расстрочив": ["расстрочивши"],
    "расстрочивши": ["расстрочив"],
    "расступаться": ["раздаваться", "раздвигаться"],
    "расстыковав": ["расстыковавши"],
    "расстыковавши": ["расстыковав"],
    "расстыковывав": ["расстыковывавши"],
    "расстыковывавши": ["расстыковывав"],
    "расстёгивав": ["расстёгивавши"],
    "расстёгивавши": ["расстёгивав"],
    "рассудив": ["рассудивши"],
    "рассудивши": ["рассудив"],
    "рассудительность": ["благоразумие"],
    "рассудительный": ["осмотрительно-благоразумный", "здравосмысленный", "здравомысленный", "вдумчивый"],
    "рассудок": ["ум", "разум", "интеллект", "смысл"],
    "рассуждав": ["рассуждавши"],
    "рассуждавши": ["рассуждав"],
    "рассужденье": ["рассуждение"],
    "рассуживав": ["рассуживавши"],
    "рассуживавши": ["рассуживав"],
    "рассукин": ["распросукин"],
    "рассупоненный": ["растрёпанный", "растерзанный", "расхристанный"],
    "рассупонив": ["рассупонивши"],
    "рассупонивав": ["рассупонивавши"],
    "рассупонивавши": ["рассупонивав"],
    "рассупонивание": ["рассупонка", "рассупониванье"],
    "рассупонивши": ["рассупонив"],
    "рассусолив": ["рассусоливши"],
    "рассусоливав": ["рассусоливавши"],
    "рассусоливавши": ["рассусоливав"],
    "рассусоливать": ["мямлить", "медлить", "телиться"],
    "рассусоливши": ["рассусолив"],
    "рассусолить": ["размусолить"],
    "рассучив": ["рассучивши"],
    "рассучивав": ["рассучивавши"],
    "рассучивавши": ["рассучивав"],
    "рассучивши": ["рассучив"],
    "рассушив": ["рассушивши"],
    "рассушивав": ["рассушивавши"],
    "рассушивавши": ["рассушивав"],
    "рассушивание": ["рассушка"],
    "рассушивши": ["рассушив"],
    "рассчитав": ["рассчитавши"],
    "рассчитавши": ["рассчитав"],
    "рассчитаться": ["расплатиться"],
    "рассчитывав": ["рассчитывавши"],
    "рассчитывавши": ["рассчитывав"],
    "рассчитывать": ["считать", "вычислять", "обсчитывать", "просчитывать", "оценивать", "взвешивать", "прикидывать", "увольнять"],
    "рассылав": ["рассылавши"],
    "рассылавши": ["рассылав"],
    "рассылка": ["реклама", "спам"],
    "рассыльный": ["курьер", "посыльный", "хожалый"],
    "рассыпав": ["рассыпавши"],
    "рассыпавши": ["рассыпав"],
    "рассыпающийся": ["разрушающийся", "распадающийся", "разлетающийся", "раскатывающийся"],
    "рассёдлывав": ["рассёдлывавши"],
    "рассёдлывавши": ["рассёдлывав"],
    "растабаривав": ["растабаривавши"],
    "растабаривавши": ["растабаривав"],
    "растабарывав": ["растабарывавши"],
    "растабарывавши": ["растабарывав"],
    "растабарывать": ["раздобарывать", "болтать"],
    "растабуировав": ["растабуировавши"],
    "растабуировавши": ["растабуировав"],
    "растаивав": ["растаивавши"],
    "растаивавши": ["растаивав"],
    "расталкивав": ["расталкивавши"],
    "расталкивавши": ["расталкивав"],
    "растаман": ["растафари", "растафарианец", "растафарианин", "растафарий"],
    "растаманка": ["растафари"],
    "растаманство": ["растафарианизм", "растафарианство"],
    "растаможив": ["растаможивши"],
    "растаможивав": ["растаможивавши"],
    "растаможивавши": ["растаможивав"],
    "растаможивание": ["растаможка"],
    "растаможивши": ["растаможив"],
    "растаможка": ["растаможивание"],
    "растанцевав": ["растанцевавши"],
    "растанцевавши": ["растанцевав"],
    "растапливав": ["растапливавши"],
    "растапливавши": ["растапливав"],
    "растапливание": ["растопка", "топка", "плавка", "плавление", "расплавка", "расплавление", "расплавливание"],
    "растапливать": ["затапливать", "разжигать"],
    "растаптывав": ["растаптывавши"],
    "растаптывавши": ["растаптывав"],
    "растаптывать": ["топтать"],
    "растаращив": ["растаращивши"],
    "растаращивав": ["растаращивавши"],
    "растаращивавши": ["растаращивав"],
    "растаращивши": ["растаращив"],
    "растарив": ["растаривши"],
    "растаривав": ["растаривавши"],
    "растаривавши": ["растаривав"],
    "растаривши": ["растарив"],
    "растаскав": ["растаскавши"],
    "растаскавши": ["растаскав"],
    "растаскивав": ["растаскивавши"],
    "растаскивавши": ["растаскивав"],
    "растасовав": ["растасовавши"],
    "растасовавши": ["растасовав"],
    "растасовывав": ["растасовывавши"],
    "растасовывавши": ["растасовывав"],
    "растасовывать": ["перетасовывать"],
    "растатуировав": ["растатуировавши"],
    "растатуировавши": ["растатуировав"],
    "растафари": ["раста", "растаман", "растафарианец", "растафарианин", "растафарий"],
    "растафарианец": ["растаман", "растафари", "растафарианин", "растафарий"],
    "растафарианизм": ["растаманство", "растафарианство"],
    "растафарианин": ["растаман", "растафари", "растафарианец", "растафарий"],
    "растафарианство": ["растаманство", "растафарианизм"],
    "растафарий": ["растаман", "растафари", "растафарианец", "растафарианин"],
    "растачав": ["растачавши"],
    "растачавши": ["растачав"],
    "растачивав": ["растачивавши"],
    "растачивавши": ["растачивав"],
    "растащив": ["растащивши"],
    "растащивши": ["растащив"],
    "растаяв": ["растаявши"],
    "растаявши": ["растаяв"],
    "растаять": ["расплавиться", "улетучиться", "подобреть"],
    "раствор": ["раздвигание", "раскрытие", "распахивание", "угол", "отверстие"],
    "растворив": ["растворивши"],
    "растворивши": ["растворив"],
    "растворить": ["раскрыть", "распахнуть", "раздвинуть", "развести"],
    "раствориться": ["раскрыться", "распахнуться"],
    "растворожив": ["раствороживши"],
    "раствороживши": ["растворожив"],
    "растворяв": ["растворявши"],
    "растворявши": ["растворяв"],
    "растворяться": ["раскрываться", "открываться"],
    "растеж": ["развитие", "прираст", "разрастък", "разрастване"],
    "растекаться мыслью по древу": ["растекаться мысью по древу", "рассуждать пространно", "трепаться", "бла-бла-бла", "разглагольствовать"],
    "растелешив": ["растелешивши"],
    "растелешивав": ["растелешивавши"],
    "растелешивавши": ["растелешивав"],
    "растелешивать": ["раздевать", "оголять"],
    "растелешивши": ["растелешив"],
    "растелешить": ["раздеть", "оголить"],
    "растелешиться": ["раздеться", "оголиться"],
    "растемнив": ["растемнивши"],
    "растемнивши": ["растемнив"],
    "растениеядный": ["травоядный"],
    "растенье": ["растение"],
    "растеплев": ["растеплевши"],
    "растеплевши": ["растеплев"],
    "растеплив": ["растепливши"],
    "растепливши": ["растеплив"],
    "растепляв": ["растеплявши"],
    "растеплявши": ["растепляв"],
    "растеребив": ["растеребивши"],
    "растеребивши": ["растеребив"],
    "растеребливав": ["растеребливавши"],
    "растеребливавши": ["растеребливав"],
    "растеребливать": ["раздёргивать"],
    "растерев": ["растёрши"],
    "растереть по переборке": ["вытряхнуть из кителя", "матку наизнанку вывернуть", "из кителя вытряхнуть", "по переборке растереть"],
    "растерзав": ["растерзавши"],
    "растерзавши": ["растерзав"],
    "растерзанье": ["растерзание"],
    "растерзать": ["разодрать", "разорвать"],
    "растерзывав": ["растерзывавши"],
    "растерзывавши": ["растерзывав"],
    "растеривав": ["растеривавши"],
    "растеривавши": ["растеривав"],
    "растеризация": ["растрирование"],
    "растеряв": ["растерявши"],
    "растерявши": ["растеряв"],
    "растерянно": ["беспомощно", "неуверенно", "потерянно"],
    "растерянный": ["обескураженный"],
    "растерять": ["потерять", "утратить"],
    "растеряться": ["потеряться", "затеряться", "прийти в растерянность"],
    "растеряха": ["растеряша"],
    "растеряша": ["растеряха"],
    "растесав": ["растесавши"],
    "растесавши": ["растесав"],
    "расти": ["увеличиваться", "нарастать", "возрастать"],
    "растив": ["растивши"],
    "растивши": ["растив"],
    "растирав": ["растиравши"],
    "растиравши": ["растирав"],
    "растиражировав": ["растиражировавши"],
    "растиражировавши": ["растиражировав"],
    "растискав": ["растискавши"],
    "растискавши": ["растискав"],
    "растискивав": ["растискивавши"],
    "растискивавши": ["растискивав"],
    "растиснув": ["растиснувши"],
    "растиснувши": ["растиснув"],
    "растительное масло": ["постное масло", "олей", "олея"],
    "растительноживотный": ["растительно-животный"],
    "растительность": ["зелень", "флора", "волосы"],
    "растительный корм": ["корм растительного происхождения"],
    "растить": ["выращивать", "воспитывать"],
    "растлев": ["растлевши"],
    "растлевав": ["растлевавши"],
    "растлевавши": ["растлевав"],
    "растлевши": ["растлев"],
    "растленье": ["растление"],
    "растлив": ["растливши"],
    "растливши": ["растлив"],
    "растлительница": ["совратительница"],
    "растлить": ["совратить"],
    "растождествляв": ["растождествлявши"],
    "растождествлявши": ["растождествляв"],
    "растолкав": ["растолкавши"],
    "растолкавши": ["растолкав"],
    "растолкнув": ["растолкнувши"],
    "растолкнувши": ["растолкнув"],
    "растолковав": ["растолковавши"],
    "растолковавши": ["растолковав"],
    "растолковать": ["объяснить", "разъяснить"],
    "растолковывав": ["растолковывавши"],
    "растолковывавши": ["растолковывав"],
    "растолмачив": ["растолмачивши"],
    "растолмачивав": ["растолмачивавши"],
    "растолмачивавши": ["растолмачивав"],
    "растолмачивши": ["растолмачив"],
    "растолстев": ["растолстевши"],
    "растолстевши": ["растолстев"],
    "растолстеть": ["располнеть"],
    "растомив": ["растомивши"],
    "растомивши": ["растомив"],
    "растомляв": ["растомлявши"],
    "растомлявши": ["растомляв"],
    "растопив": ["растопивши"],
    "растопивши": ["растопив"],
    "растопить": ["затопить", "расплавить"],
    "растопляв": ["растоплявши"],
    "растоплявши": ["растопляв"],
    "растоплять": ["растапливать"],
    "растопорщив": ["растопорщивши"],
    "растопорщивши": ["растопорщив"],
    "растопорщить": ["растопырить"],
    "растопорщиться": ["растопыриться"],
    "растопочный": ["зажигательный", "разжигательный"],
    "растоптав": ["растоптавши"],
    "растоптавши": ["растоптав"],
    "растоптанный": ["расхоженный"],
    "растоптать": ["разрушить", "размазать", "уничтожить", "разносить"],
    "растопыренный": ["раскрытый"],
    "растопырив": ["растопыривши"],
    "растопыривав": ["растопыривавши"],
    "растопыривавши": ["растопыривав"],
    "растопыривши": ["растопырив"],
    "растопырить": ["раскинуть"],
    "расторгав": ["расторгавши"],
    "расторгавши": ["расторгав"],
    "расторгать": ["разрывать", "раздирать", "денонсировать"],
    "расторгнув": ["расторгнувши"],
    "расторгнувши": ["расторгнув"],
    "расторгнувшийся": ["расторгшийся"],
    "расторговав": ["расторговавши"],
    "расторговавши": ["расторговав"],
    "расторговаться": ["распродаться"],
    "расторговывав": ["расторговывавши"],
    "расторговывавши": ["расторговывав"],
    "расторгшийся": ["расторгнувшийся"],
    "расторжение": ["разрыв", "прекращение"],
    "расторженье": ["расторжение"],
    "растормаживав": ["растормаживавши"],
    "растормаживавши": ["растормаживав"],
    "растормозив": ["растормозивши"],
    "растормозивши": ["растормозив"],
    "растормошив": ["растормошивши"],
    "растормошивши": ["растормошив"],
    "расторопность": ["проворство", "прыть", "прыткость", "сноровистость", "проворность", "шустрость", "разворотливость", "быстрота", "бойкость", "проворье", "ловкость", "поворотливость"],
    "расторопный": ["шустрый"],
    "растосковав": ["растосковавши"],
    "растосковавши": ["растосковав"],
    "расточав": ["расточавши"],
    "расточавши": ["расточав"],
    "расточаться": ["растрачиваться"],
    "расточенье": ["расточение"],
    "расточив": ["расточивши"],
    "расточивши": ["расточив"],
    "расточитель": ["растратчик", "мот"],
    "расточительность": ["щедрость", "расточительство"],
    "расточительный": ["мотоватый"],
    "расточительство": ["расточение", "расточительность", "мотовство"],
    "расточительствовав": ["расточительствовавши"],
    "расточительствовавши": ["расточительствовав"],
    "расточной": ["расточный"],
    "расточный": ["расточной"],
    "расточный станок": ["расточной станок"],
    "растравив": ["растравивши"],
    "растравивши": ["растравив"],
    "растравливав": ["растравливавши"],
    "растравливавши": ["растравливав"],
    "растравливать": ["растравлять"],
    "растравляв": ["растравлявши"],
    "растравлявши": ["растравляв"],
    "растранжирив": ["растранжиривши"],
    "растранжиривав": ["растранжиривавши"],
    "растранжиривавши": ["растранжиривав"],
    "растранжиривши": ["растранжирив"],
    "растрата": ["растрачивание"],
    "растратив": ["растративши"],
    "растративши": ["растратив"],
    "растратить": ["профукать", "разбазарить", "разменять", "промотать", "размотать", "расточить", "спустить", "выпустить в трубу", "убить"],
    "растратчик": ["расхититель", "транжира", "расточитель"],
    "растрачивав": ["растрачивавши"],
    "растрачивавши": ["растрачивав"],
    "растрачивание": ["растрата", "расходование"],
    "растревожив": ["растревоживши"],
    "растревоживав": ["растревоживавши"],
    "растревоживавши": ["растревоживав"],
    "растревоживши": ["растревожив"],
    "растрезвонив": ["растрезвонивши"],
    "растрезвонивав": ["растрезвонивавши"],
    "растрезвонивавши": ["растрезвонивав"],
    "растрезвонивши": ["растрезвонив"],
    "растреклятый": ["распроклятый", "проклятый", "треклятый"],
    "растренировав": ["растренировавши"],
    "растренировавши": ["растренировав"],
    "растренировывав": ["растренировывавши"],
    "растренировывавши": ["растренировывав"],
    "растреножив": ["растреноживши"],
    "растреноживши": ["растреножив"],
    "растрепав": ["растрепавши"],
    "растрепавши": ["растрепав"],
    "растрепаться": ["спутаться", "взъерошиться", "взлохматиться"],
    "растрескав": ["растрескавши"],
    "растрескавши": ["растрескав"],
    "растрескивав": ["растрескивавши"],
    "растрескивавши": ["растрескивав"],
    "растреснув": ["растреснувши"],
    "растреснувши": ["растреснув"],
    "растрировав": ["растрировавши"],
    "растрировавши": ["растрировав"],
    "растрирование": ["растеризация"],
    "растровый электронный микроскоп": ["сканирующий электронный микроскоп"],
    "растрогав": ["растрогавши"],
    "растрогавши": ["растрогав"],
    "растроганно": ["взволнованно"],
    "растрогать": ["умилить"],
    "растрогаться": ["расчувствоваться", "умилиться"],
    "растрогивав": ["растрогивавши"],
    "растрогивавши": ["растрогивав"],
    "растроив": ["растроивши"],
    "растроивши": ["растроив"],
    "растроиться": ["строиться"],
    "раструбив": ["раструбивши"],
    "раструбивши": ["раструбив"],
    "раструсив": ["раструсивши"],
    "раструсивши": ["раструсив"],
    "раструсить": ["растрясти"],
    "раструшивав": ["раструшивавши"],
    "раструшивавши": ["раструшивав"],
    "растрясав": ["растрясавши"],
    "растрясавши": ["растрясав"],
    "растрясти": ["раструсить", "растранжирить", "растолкать", "растормошить", "расшевелить", "взбудоражить"],
    "растрясывав": ["растрясывавши"],
    "растрясывавши": ["растрясывав"],
    "растряхав": ["растряхавши"],
    "растряхавши": ["растряхав"],
    "растряхивав": ["растряхивавши"],
    "растряхивавши": ["растряхивав"],
    "растряхнув": ["растряхнувши"],
    "растряхнувши": ["растряхнув"],
    "растрёпа": ["неряха", "разиня", "ротозей"],
    "растрёпывав": ["растрёпывавши"],
    "растрёпывавши": ["растрёпывав"],
    "растрёпываться": ["спутываться", "взъерошиваться", "взлохмачиваться"],
    "растуды": ["растудыть"],
    "растудыть": ["тудыть", "перетудыть", "растуда", "растуды", "растак", "разэтак", "разэдак"],
    "растушевав": ["растушевавши"],
    "растушевавши": ["растушевав"],
    "растушёвка": ["тушёвка", "растушёвывание"],
    "растушёвывав": ["растушёвывавши"],
    "растушёвывавши": ["растушёвывав"],
    "растушёвывание": ["растушёвка"],
    "растыкав": ["растыкавши"],
    "растыкавши": ["растыкав"],
    "растыкивав": ["растыкивавши"],
    "растыкивавши": ["растыкивав"],
    "растюковав": ["растюковавши"],
    "растюковавши": ["растюковав"],
    "растюковывав": ["растюковывавши"],
    "растюковывавши": ["растюковывав"],
    "растя": ["выращивая"],
    "растягивав": ["растягивавши"],
    "растягивавши": ["растягивав"],
    "растягивание": ["растягиванье"],
    "растяжение": ["растяженье"],
    "растяженье": ["растяжение"],
    "растяжимый": ["эластичный"],
    "растяжка": ["растягивание", "расчалка", "тяга", "стретчинг", "стрия"],
    "растянув": ["растянувши"],
    "растянувши": ["растянув"],
    "растянуться": ["вытянуться"],
    "растяпа": ["недотёпа", "олух", "простофиля", "путаник", "раззява", "разиня", "растеряха", "растрёпа", "растрёпка", "ротозей", "ротозейка", "тёха", "тюха", "фетюк", "вахлак"],
    "растяпав": ["растяпавши"],
    "растяпавши": ["растяпав"],
    "растяпистость": ["недотёпистость"],
    "растяпывав": ["растяпывавши"],
    "растяпывавши": ["растяпывав"],
    "растёл": ["отёл"],
    "растёрши": ["растерев"],
    "растёсывав": ["растёсывавши"],
    "растёсывавши": ["растёсывав"],
    "расфальцевав": ["расфальцевавши"],
    "расфальцевавши": ["расфальцевав"],
    "расфальцовывав": ["расфальцовывавши"],
    "расфальцовывавши": ["расфальцовывав"],
    "расфасовав": ["расфасовавши"],
    "расфасовавши": ["расфасовав"],
    "расфасованный": ["упакованный"],
    "расфасовщик": ["фасовщик", "развесчик"],
    "расфасовывав": ["расфасовывавши"],
    "расфасовывавши": ["расфасовывав"],
    "расфасовывать": ["фасовать"],
    "расфигачив": ["расфигачивши"],
    "расфигачивав": ["расфигачивавши"],
    "расфигачивавши": ["расфигачивав"],
    "расфигачивши": ["расфигачив"],
    "расфокусировав": ["расфокусировавши"],
    "расфокусировавши": ["расфокусировав"],
    "расформатировав": ["расформатировавши"],
    "расформатировавши": ["расформатировав"],
    "расформировав": ["расформировавши"],
    "расформировавши": ["расформировав"],
    "расформировывав": ["расформировывавши"],
    "расформировывавши": ["расформировывав"],
    "расформировывание": ["расформирование", "расформировка"],
    "расформировывать": ["распускать"],
    "расфрантив": ["расфрантивши"],
    "расфрантивши": ["расфрантив"],
    "расфутболив": ["расфутболивши"],
    "расфутболивав": ["расфутболивавши"],
    "расфутболивавши": ["расфутболивав"],
    "расфутболивши": ["расфутболив"],
    "расфуфыренный": ["разодетый"],
    "расфуфырив": ["расфуфыривши"],
    "расфуфыривав": ["расфуфыривавши"],
    "расфуфыривавши": ["расфуфыривав"],
    "расфуфыривши": ["расфуфырив"],
    "расфуфырить": ["разодеть"],
    "расфуфыриться": ["разодеться", "разгорячиться"],
    "расхабарив": ["расхабаривши"],
    "расхабаривши": ["расхабарив"],
    "расхаживав": ["расхаживавши"],
    "расхаживавши": ["расхаживав"],
    "расхаживать": ["похаживать", "прохаживаться", "мотаться", "таскаться", "трепаться", "шастать", "шлёндать", "шлёндрать", "шляться", "бродить", "болтаться", "слоняться", "шататься", "гранить мостовую", "слоны слонять"],
    "расхаивав": ["расхаивавши"],
    "расхаивавши": ["расхаивав"],
    "расхаяв": ["расхаявши"],
    "расхаявши": ["расхаяв"],
    "расхвалив": ["расхваливши"],
    "расхваливав": ["расхваливавши"],
    "расхваливавши": ["расхваливав"],
    "расхваливши": ["расхвалив"],
    "расхвастав": ["расхваставши"],
    "расхваставши": ["расхвастав"],
    "расхватав": ["расхватавши"],
    "расхватавши": ["расхватав"],
    "расхватив": ["расхвативши"],
    "расхвативши": ["расхватив"],
    "расхватывав": ["расхватывавши"],
    "расхватывавши": ["расхватывав"],
    "расхватывать": ["раскупать"],
    "расхитив": ["расхитивши"],
    "расхитивши": ["расхитив"],
    "расхищав": ["расхищавши"],
    "расхищавши": ["расхищав"],
    "расхищенье": ["расхищение"],
    "расхламив": ["расхламивши"],
    "расхламивши": ["расхламив"],
    "расхламляв": ["расхламлявши"],
    "расхламлявши": ["расхламляв"],
    "расхлебав": ["расхлебавши"],
    "расхлебавши": ["расхлебав"],
    "расхлебенить": ["распахнуть", "раскрыть", "отворить"],
    "расхлеснув": ["расхлеснувши"],
    "расхлеснувши": ["расхлеснув"],
    "расхлестав": ["расхлеставши"],
    "расхлеставши": ["расхлестав"],
    "расхлестнув": ["расхлестнувши"],
    "расхлестнувши": ["расхлестнув"],
    "расхлобыстнув": ["расхлобыстнувши"],
    "расхлобыстнувши": ["расхлобыстнув"],
    "расхлопав": ["расхлопавши"],
    "расхлопавши": ["расхлопав"],
    "расхлюпав": ["расхлюпавши"],
    "расхлюпавши": ["расхлюпав"],
    "расхлюпывав": ["расхлюпывавши"],
    "расхлюпывавши": ["расхлюпывав"],
    "расхлюстанный": ["растрёпанный"],
    "расхлябав": ["расхлябавши"],
    "расхлябавши": ["расхлябав"],
    "расхлябанность": ["ослабленность", "расшатанность"],
    "расхлябив": ["расхлябивши"],
    "расхлябивши": ["расхлябив"],
    "расхлябывав": ["расхлябывавши"],
    "расхлябывавши": ["расхлябывав"],
    "расхлёбывав": ["расхлёбывавши"],
    "расхлёбывавши": ["расхлёбывав"],
    "расхлёбывать": ["хлебать", "улаживать", "отдуваться"],
    "расхлёстывав": ["расхлёстывавши"],
    "расхлёстывавши": ["расхлёстывав"],
    "расход": ["утрачивание", "поток", "потребность"],
    "расход сырья": ["удельный расход сырья"],
    "расходив": ["расходивши"],
    "расходивши": ["расходив"],
    "расходимость": ["дивергенция"],
    "расходиться": ["раздвигаться", "распространяться"],
    "расходный": ["затратный", "потребляемый", "расходуемый"],
    "расходовав": ["расходовавши"],
    "расходовавши": ["расходовав"],
    "расходование": ["расход", "трата"],
    "расходовать": ["тратить", "растрачивать"],
    "расходоваться": ["тратиться"],
    "расхождение": ["отклонение", "несовпадение"],
    "расхожденье": ["расхождение"],
    "расхоженный": ["растоптанный"],
    "расхожий": ["общественный", "распространенный", "широко употребляемый"],
    "расхолаживав": ["расхолаживавши"],
    "расхолаживавши": ["расхолаживав"],
    "расхолаживать": ["обескураживать", "разочаровывать", "остужать", "охлаждать"],
    "расхолодив": ["расхолодивши"],
    "расхолодивши": ["расхолодив"],
    "расхолодить": ["разочаровать", "охладить"],
    "расхомутав": ["расхомутавши"],
    "расхомутавши": ["расхомутав"],
    "расхотев": ["расхотевши"],
    "расхотевши": ["расхотев"],
    "расхохатывав": ["расхохатывавши"],
    "расхохатывавши": ["расхохатывав"],
    "расхреначив": ["расхреначивши"],
    "расхреначивав": ["расхреначивавши"],
    "расхреначивавши": ["расхреначивав"],
    "расхреначивши": ["расхреначив"],
    "расхристанность": ["растрёпанность", "небрежность"],
    "расхристанный": ["растрёпанный"],
    "расхулив": ["расхуливши"],
    "расхуливши": ["расхулив"],
    "расхуюжив": ["расхуюживши"],
    "расхуюживши": ["расхуюжив"],
    "расхуюжить": ["разнести", "разнести в пух и прах"],
    "расхуярив": ["расхуяривши"],
    "расхуяривав": ["расхуяривавши"],
    "расхуяривавши": ["расхуяривав"],
    "расхуяривать": ["расхерачивать"],
    "расхуяривши": ["расхуярив"],
    "расхуярить": ["расхерачить"],
    "расхуячив": ["расхуячивши"],
    "расхуячивши": ["расхуячив"],
    "расхуячить": ["разбить", "разломать", "размозжить", "расхерачить", "расхуярить", "расхуяшить", "разъебенить", "разъебошить", "распидячить", "распиздошить"],
    "расцарапав": ["расцарапавши"],
    "расцарапавши": ["расцарапав"],
    "расцарапнув": ["расцарапнувши"],
    "расцарапнувши": ["расцарапнув"],
    "расцарапывав": ["расцарапывавши"],
    "расцарапывавши": ["расцарапывав"],
    "расцвести": ["зацвести", "распуститься", "похорошеть", "повеселеть"],
    "расцветав": ["расцветавши"],
    "расцветавши": ["расцветав"],
    "расцветанье": ["расцветание"],
    "расцветать": ["зацветать", "цвести"],
    "расцветив": ["расцветивши"],
    "расцветивши": ["расцветив"],
    "расцвечав": ["расцвечавши"],
    "расцвечавши": ["расцвечав"],
    "расцвечать": ["расцвечивать"],
    "расцвечаться": ["расцвечиваться"],
    "расцвеченный": ["яркий", "пёстрый", "разноцветный", "цветастый", "приукрашенный"],
    "расцвечивав": ["расцвечивавши"],
    "расцвечивавши": ["расцвечивав"],
    "расцвечиваться": ["расцвечаться"],
    "расцедив": ["расцедивши"],
    "расцедивши": ["расцедив"],
    "расцеживав": ["расцеживавши"],
    "расцеживавши": ["расцеживав"],
    "расцеловав": ["расцеловавши"],
    "расцеловавши": ["расцеловав"],
    "расцеловывав": ["расцеловывавши"],
    "расцеловывавши": ["расцеловывав"],
    "расценив": ["расценивши"],
    "расценивав": ["расценивавши"],
    "расценивавши": ["расценивав"],
    "расценивать": ["осуждать", "порицать"],
    "расценивши": ["расценив"],
    "расценка": ["расценивание", "расценок", "цена", "тариф"],
    "расцентровывав": ["расцентровывавши"],
    "расцентровывавши": ["расцентровывав"],
    "расценяв": ["расценявши"],
    "расценявши": ["расценяв"],
    "расцепив": ["расцепивши"],
    "расцепивши": ["расцепив"],
    "расцепиться": ["отцепиться"],
    "расцепляв": ["расцеплявши"],
    "расцеплявши": ["расцепляв"],
    "расцепляться": ["отцепляться"],
    "расцерковив": ["расцерковивши"],
    "расцерковивши": ["расцерковив"],
    "расцеховав": ["расцеховавши"],
    "расцеховавши": ["расцеховав"],
    "расчав": ["расчавши"],
    "расчавши": ["расчав"],
    "расчалив": ["расчаливши"],
    "расчаливав": ["расчаливавши"],
    "расчаливавши": ["расчаливав"],
    "расчаливание": ["расчаление"],
    "расчаливши": ["расчалив"],
    "расчалка": ["расчаливание", "ванта"],
    "расчеканив": ["расчеканивши"],
    "расчеканивав": ["расчеканивавши"],
    "расчеканивавши": ["расчеканивав"],
    "расчеканивши": ["расчеканив"],
    "расчеловечение": ["расчеловечивание", "обесчеловечение", "обесчеловечивание", "дегуманизация", "озверение"],
    "расчеловечив": ["расчеловечивши"],
    "расчеловечивав": ["расчеловечивавши"],
    "расчеловечивавши": ["расчеловечивав"],
    "расчеловечивание": ["расчеловечение", "дегуманизация", "озверение"],
    "расчеловечивать": ["дегуманизировать", "обесчеловечивать"],
    "расчеловечивши": ["расчеловечив"],
    "расчеловечить": ["дегуманизировать", "обесчеловечить"],
    "расчеренковав": ["расчеренковавши"],
    "расчеренковавши": ["расчеренковав"],
    "расчеренковывав": ["расчеренковывавши"],
    "расчеренковывавши": ["расчеренковывав"],
    "расчеркнув": ["расчеркнувши"],
    "расчеркнувши": ["расчеркнув"],
    "расчерпав": ["расчерпавши"],
    "расчерпавши": ["расчерпав"],
    "расчерпывав": ["расчерпывавши"],
    "расчерпывавши": ["расчерпывав"],
    "расчертив": ["расчертивши"],
    "расчертивши": ["расчертив"],
    "расчерчивав": ["расчерчивавши"],
    "расчерчивавши": ["расчерчивав"],
    "расчесав": ["расчесавши"],
    "расчесавши": ["расчесав"],
    "расчесать": ["причесать"],
    "расчесать головку": ["расчесать голову"],
    "расчесаться": ["причесаться"],
    "расчетверив": ["расчетверивши"],
    "расчетверивши": ["расчетверив"],
    "расчехвостив": ["расчехвостивши"],
    "расчехвостивши": ["расчехвостив"],
    "расчехлив": ["расчехливши"],
    "расчехливши": ["расчехлив"],
    "расчехляв": ["расчехлявши"],
    "расчехлявши": ["расчехляв"],
    "расчинав": ["расчинавши"],
    "расчинавши": ["расчинав"],
    "расчислив": ["расчисливши"],
    "расчисливши": ["расчислив"],
    "расчисляв": ["расчислявши"],
    "расчислявши": ["расчисляв"],
    "расчистив": ["расчистивши"],
    "расчистивши": ["расчистив"],
    "расчистить": ["прочистить"],
    "расчихвостив": ["расчихвостивши"],
    "расчихвостивши": ["расчихвостив"],
    "расчихвостить": ["отругать", "выбранить", "обкостерить", "обхаять"],
    "расчищав": ["расчищавши"],
    "расчищавши": ["расчищав"],
    "расчленив": ["расчленивши"],
    "расчленивши": ["расчленив"],
    "расчленяв": ["расчленявши"],
    "расчленявши": ["расчленяв"],
    "расчувствовав": ["расчувствовавши"],
    "расчувствовавши": ["расчувствовав"],
    "расчувствоваться": ["растрогаться", "умилиться"],
    "расчухав": ["расчухавши"],
    "расчухавши": ["расчухав"],
    "расчуяв": ["расчуявши"],
    "расчуявши": ["расчуяв"],
    "расчёркивав": ["расчёркивавши"],
    "расчёркивавши": ["расчёркивав"],
    "расчёркивать": ["расчерчивать"],
    "расчёска": ["расчёсывание", "гребень", "гребёнка"],
    "расчёсывав": ["расчёсывавши"],
    "расчёсывавши": ["расчёсывав"],
    "расчёсывать": ["причёсывать", "чесать", "приглаживать", "укладывать", "разравнивать", "раздирать"],
    "расчёт": ["вычисление", "обсчитывание", "намерение", "предположение", "выгода", "польза", "интерес", "корысть", "уплата"],
    "расчётка": ["расчётный лист", "расчётный листок", "табулька"],
    "расчётный узел": ["узел расчёта"],
    "расшарив": ["расшаривши"],
    "расшаривши": ["расшарив"],
    "расшаркиванье": ["расшаркивание"],
    "расшатав": ["расшатавши"],
    "расшатавши": ["расшатав"],
    "расшатывав": ["расшатывавши"],
    "расшатывавши": ["расшатывав"],
    "расшвыривав": ["расшвыривавши"],
    "расшвыривавши": ["расшвыривав"],
    "расшвыривать": ["разбрасывать"],
    "расшвырнув": ["расшвырнувши"],
    "расшвырнувши": ["расшвырнув"],
    "расшвыряв": ["расшвырявши"],
    "расшвырявши": ["расшвыряв"],
    "расшевелив": ["расшевеливши"],
    "расшевеливав": ["расшевеливавши"],
    "расшевеливавши": ["расшевеливав"],
    "расшевеливши": ["расшевелив"],
    "расшеперив": ["расшеперивши"],
    "расшеперивав": ["расшеперивавши"],
    "расшеперивавши": ["расшеперивав"],
    "расшеперивши": ["расшеперив"],
    "расшибав": ["расшибавши"],
    "расшибавши": ["расшибав"],
    "расшибалка": ["расшибаловка", "расшибалочка", "расшиши", "чика"],
    "расшибив": ["расшибивши"],
    "расшибивши": ["расшибив"],
    "расшив": ["расшивши"],
    "расшивав": ["расшивавши"],
    "расшивавши": ["расшивав"],
    "расшиватель": ["антистеплер"],
    "расшивши": ["расшив"],
    "расширение": ["дополнение"],
    "расширив": ["расширивши"],
    "расширивши": ["расширив"],
    "расширяв": ["расширявши"],
    "расширявши": ["расширяв"],
    "расширять": ["наращивать", "развёртывать"],
    "расшифровав": ["расшифровавши"],
    "расшифровавши": ["расшифровав"],
    "расшифрование": ["расшифровка", "расшифровывание", "дешифрование", "дешифровка"],
    "расшифровать": ["закодировать"],
    "расшифровка": ["дешифровка", "декодирование"],
    "расшифровывав": ["расшифровывавши"],
    "расшифровывавши": ["расшифровывав"],
    "расшлаковав": ["расшлаковавши"],
    "расшлаковавши": ["расшлаковав"],
    "расшлаковывав": ["расшлаковывавши"],
    "расшлаковывавши": ["расшлаковывав"],
    "расшлихтовав": ["расшлихтовавши"],
    "расшлихтовавши": ["расшлихтовав"],
    "расшлихтовщик": ["текстильщик"],
    "расшлихтовывав": ["расшлихтовывавши"],
    "расшлихтовывавши": ["расшлихтовывав"],
    "расшлёпав": ["расшлёпавши"],
    "расшлёпавши": ["расшлёпав"],
    "расшлёпывав": ["расшлёпывавши"],
    "расшлёпывавши": ["расшлёпывав"],
    "расшматовав": ["расшматовавши"],
    "расшматовавши": ["расшматовав"],
    "расшнуровав": ["расшнуровавши"],
    "расшнуровавши": ["расшнуровав"],
    "расшнуровывав": ["расшнуровывавши"],
    "расшнуровывавши": ["расшнуровывав"],
    "расшпилив": ["расшпиливши"],
    "расшпиливав": ["расшпиливавши"],
    "расшпиливавши": ["расшпиливав"],
    "расшпиливши": ["расшпилив"],
    "расшторив": ["расшторивши"],
    "расшторивав": ["расшторивавши"],
    "расшторивавши": ["расшторивав"],
    "расшторивши": ["расшторив"],
    "расштробив": ["расштробивши"],
    "расштробивши": ["расштробив"],
    "расшугав": ["расшугавши"],
    "расшугавши": ["расшугав"],
    "расшугать": ["распугать"],
    "расшугивав": ["расшугивавши"],
    "расшугивавши": ["расшугивав"],
    "расшумев": ["расшумевши"],
    "расшумевши": ["расшумев"],
    "расшуровав": ["расшуровавши"],
    "расшуровавши": ["расшуровав"],
    "расшуровывав": ["расшуровывавши"],
    "расшуровывавши": ["расшуровывав"],
    "расщебенив": ["расщебенивши"],
    "расщебенивав": ["расщебенивавши"],
    "расщебенивавши": ["расщебенивав"],
    "расщебенивши": ["расщебенив"],
    "расщекотав": ["расщекотавши"],
    "расщекотавши": ["расщекотав"],
    "расщекотив": ["расщекотивши"],
    "расщекотивши": ["расщекотив"],
    "расщелив": ["расщеливши"],
    "расщеливши": ["расщелив"],
    "расщелина": ["ущелье", "расселина", "щель", "трещина"],
    "расщелкнув": ["расщелкнувши"],
    "расщелкнувши": ["расщелкнув"],
    "расщеляв": ["расщелявши"],
    "расщелявши": ["расщеляв"],
    "расщемив": ["расщемивши"],
    "расщемивши": ["расщемив"],
    "расщемляв": ["расщемлявши"],
    "расщемлявши": ["расщемляв"],
    "расщеп": ["расщепление"],
    "расщепав": ["расщепавши"],
    "расщепавши": ["расщепав"],
    "расщеперив": ["расщеперивши"],
    "расщеперивав": ["расщеперивавши"],
    "расщеперивавши": ["расщеперивав"],
    "расщеперивши": ["расщеперив"],
    "расщепив": ["расщепивши"],
    "расщепивши": ["расщепив"],
    "расщепить": ["расколоть"],
    "расщепление": ["разделение", "деление"],
    "расщепляв": ["расщеплявши"],
    "расщеплявши": ["расщепляв"],
    "расщерив": ["расщеривши"],
    "расщеривши": ["расщерив"],
    "расщипав": ["расщипавши"],
    "расщипавши": ["расщипав"],
    "расщипнув": ["расщипнувши"],
    "расщипнувши": ["расщипнув"],
    "расщипывав": ["расщипывавши"],
    "расщипывавши": ["расщипывав"],
    "расщипыванье": ["расщипывание"],
    "расщупав": ["расщупавши"],
    "расщупавши": ["расщупав"],
    "расщёлкав": ["расщёлкавши"],
    "расщёлкавши": ["расщёлкав"],
    "расщёлкать": ["расщёлкнуть"],
    "расщёлкивав": ["расщёлкивавши"],
    "расщёлкивавши": ["расщёлкивав"],
    "расщёлкнув": ["расщёлкнувши"],
    "расщёлкнувши": ["расщёлкнув"],
    "рата": ["рст"],
    "ратай": ["оратай", "пахарь", "землероб", "земледелец", "хлебопашец"],
    "рататуй": ["овощное рагу"],
    "ратин": ["бостон", "габардин", "диагональ", "драп", "камлот", "кастор", "коверкот", "твид", "шевиот"],
    "ратинировав": ["ратинировавши"],
    "ратинировавши": ["ратинировав"],
    "ратификация": ["ратифицирование", "ратификационная грамота"],
    "ратификовав": ["ратификовавши"],
    "ратификовавши": ["ратификовав"],
    "ратифицировав": ["ратифицировавши"],
    "ратифицировавши": ["ратифицировав"],
    "ратифицирование": ["ратификация"],
    "ратифицировать": ["парафировать"],
    "ратиця": ["копито"],
    "ратник": ["солдат", "воин", "доброволец", "армеец", "фронтовик", "ополченец"],
    "ратницкий": ["ратничий"],
    "ратничий": ["ратницкий"],
    "ратный": ["военный", "боевой", "воинский"],
    "ратоборец": ["боец", "воин", "воитель", "ратник", "сын марса", "борец"],
    "ратоборство": ["сражение", "битва"],
    "ратоборствовав": ["ратоборствовавши"],
    "ратоборствовавши": ["ратоборствовав"],
    "ратовав": ["ратовавши"],
    "ратовавши": ["ратовав"],
    "ратовать": ["сражаться", "воевать", "выступать"],
    "ратовище": ["оскепище", "ратовье"],
    "ратти": ["сорх"],
    "ратуша": ["ратгауз"],
    "ратующий": ["защищающий", "борющийся"],
    "рать": ["дружина", "войско", "армия", "воинство", "ополчение", "ополченье", "битва", "бой", "сражение", "баталия", "война", "брань", "пря", "ссора", "реть с побоищем"],
    "раунд": ["этап", "тур", "цикл"],
    "рауп": ["рауф"],
    "раут": ["приём"],
    "раф": ["рафик"],
    "раф-кофе": ["раф"],
    "рафа": ["рафаель", "рафаэл", "рафаил", "рафик"],
    "рафаель": ["рафаэл", "рафаил", "рафа", "рафик"],
    "рафаил": ["рафил", "рафаэл", "рафаэль", "раффаэле", "раффаэлло", "рафа", "рафик", "рафал"],
    "рафаила": ["рафила", "рафаэла", "рафаэля", "раффаэла", "раффаэлла", "рафа", "рафика", "рафала"],
    "рафидит": ["шиит"],
    "рафик": ["рафаель", "рафаэл", "рафаил", "рафа"],
    "рафинация": ["рафинирование"],
    "рафинировав": ["рафинировавши"],
    "рафинировавши": ["рафинировав"],
    "рафинирование": ["рафинация"],
    "рафинированность": ["утончённость", "изысканность"],
    "рафиноза": ["мелитоза", "мелицитоза"],
    "рафия": ["рафах"],
    "рафтер": ["рафтингист", "рафтсмен"],
    "рафтингист": ["рафтер", "рафтсмен"],
    "рафтор": ["равиш"],
    "рафтсмен": ["рафтер", "рафтингист"],
    "раффиноза": ["рафиноза"],
    "рахамс": ["рахсемс", "пеедемс"],
    "рахат-лукум": ["лукум"],
    "рахиль": ["рахель"],
    "рахиотомия": ["ламинэктомия"],
    "рахис": ["черешок"],
    "рахитичный": ["рахитический"],
    "рахманний": ["смирний", "сумирний", "тихий"],
    "рахманный": ["чудной", "странный", "блаженный", "тихий", "кроткий", "смирный", "вялый", "задумчивый", "неуклюжий", "простодушный", "воздержанный", "нерасчётливый", "нерасторопный", "бесхозяйственный", "благоденствующий"],
    "рахсемс": ["рахамс", "пеедькшнемс"],
    "рацемическая модификация": ["рацемическая форма"],
    "рацея": ["речь", "слово", "спич", "аллокуция", "диатриба", "тирада", "филиппика", "рассуждение", "наставление", "проповедь", "поучение", "нотация"],
    "рацио": ["разум", "интеллект", "разумность", "рациональность"],
    "рацион": ["доза", "порция", "часть", "паёк"],
    "рационализатор": ["новатор"],
    "рационализировав": ["рационализировавши"],
    "рационализировавши": ["рационализировав"],
    "рационализировать": ["рационализовать"],
    "рационализовав": ["рационализовавши"],
    "рационализовавши": ["рационализовав"],
    "рационализовать": ["рационализировать"],
    "рационально": ["разумно", "рассудочно", "целесообразно"],
    "рациональность": ["рационализм", "рассудочность", "разумность", "целесообразность"],
    "рациональный": ["разумный", "логичный", "логический", "целесообразный", "рассудочный", "расчётливый", "рационалистический"],
    "рационировав": ["рационировавши"],
    "рационировавши": ["рационировав"],
    "рация": ["радиостанция"],
    "рацуха": ["рацпредложение"],
    "рача-лечхуми и квемо-сванети": ["рача-лечхуми и нижняя сванетия"],
    "рача-лечхуми и нижняя сванетия": ["рача-лечхуми и квемо-сванети"],
    "рачение": ["старание", "усердие", "забота"],
    "раченье": ["рачение"],
    "рачив": ["рачивши"],
    "рачивши": ["рачив"],
    "рачительность": ["заботливость"],
    "рачительный": ["домовитый", "старательный", "усердный", "заботливый"],
    "рачунар": ["рачунало"],
    "рашагейт": ["руссьягейт", "кремлингейт"],
    "рашель": ["ракель", "рахиль"],
    "рашизм": ["русизм"],
    "рашкуль": ["рашманок", "вилка", "рогатка", "рогач", "рогулька"],
    "ращение": ["выращивание", "взращивание", "выращиванье", "взращиванье", "ращенье"],
    "ращивав": ["ращивавши"],
    "ращивавши": ["ращивав"],
    "раъд": ["тундар"],
    "раёк": ["кукольный театр", "галёрка", "радужина", "радужка"],
    "рб": ["башкирия", "башкортостан", "республика башкортостан", "беларусь", "белоруссия", "республика беларусь", "бурятия", "республика бурятия", "болгария", "республика болгария"],
    "рвав": ["рвавши"],
    "рвавши": ["рвав"],
    "рванина": ["рвань"],
    "рванув": ["рванувши"],
    "рванувши": ["рванув"],
    "рвануть": ["дёрнуть", "рвануться", "метнуться", "махнуть", "взорвать", "взорваться", "грохнуть", "грохотнуть"],
    "рвануться": ["ринуться", "броситься", "подорваться", "взорваться"],
    "рваный": ["разорванный", "зазубренный", "неровный", "ломаный", "рубль"],
    "рвань": ["рванина", "рваньё"],
    "рваньё": ["разрывание", "рвань", "рванина"],
    "рвать": ["блевать", "тошнить"],
    "рвать жопу": ["жопу рвать"],
    "рвать и метать": ["неистовствовать", "буйствовать"],
    "рвать на жопе волоса": ["досадовать", "злиться"],
    "рвать на ходу подмётки": ["срезать на ходу подмётки", "на ходу подмётки рвать", "на ходу подмётки резать", "на ходу подметки срезать"],
    "рваться": ["разрываться", "прекращаться", "нарушаться", "прерываться", "взрываться", "вырываться", "стремиться"],
    "рвачество": ["корыстолюбие", "хапужничество"],
    "рвд": ["гидрорукав", "рукав высокого давления", "шланг высокого давления", "гидравлический шланг"],
    "рвение": ["усердие", "пыл", "энтузиазм", "тщание", "тщанье", "старанье", "усердье", "рвенье", "энтузазизм"],
    "рвенье": ["рвение"],
    "рвота": ["блевание", "блевота", "тошнота", "блевотина"],
    "рвотное": ["эметик", "харчегонное"],
    "рвотный орех": ["чилибуха"],
    "рвс": ["революционный военный совет", "реввоенсовет", "резервуар вертикальный стальной", "радиовещательная станция"],
    "рдев": ["рдевши"],
    "рдевши": ["рдев"],
    "рденье": ["рдение"],
    "рдеть": ["краснеть", "покраснеть", "вспыхнуть", "гореть", "алеть", "зреть", "дозревать", "наливаться", "наливаться соком"],
    "рдеться": ["рдеть"],
    "рдяный": ["алый", "багряный", "пунцовый"],
    "ре": ["ми дубль-бемоль", "до дубль-диез"],
    "ре-": ["пере-"],
    "ре-бемоль": ["до-диез"],
    "ре-диез": ["ми-бемоль"],
    "реабилитировав": ["реабилитировавши"],
    "реабилитировавши": ["реабилитировав"],
    "реабилитироваться": ["оправдаться"],
    "реабсорбировать": ["резорбировать", "ресорбировать"],
    "реагент": ["реактив"],
    "реагин": ["атопическое антитело"],
    "реагировав": ["реагировавши"],
    "реагировавши": ["реагировав"],
    "реагирование": ["реакция"],
    "реагнув": ["реагнувши"],
    "реагнувши": ["реагнув"],
    "реадаптировав": ["реадаптировавши"],
    "реадаптировавши": ["реадаптировав"],
    "реакклиматизировав": ["реакклиматизировавши"],
    "реакклиматизировавши": ["реакклиматизировав"],
    "реактант": ["реагент"],
    "реактив": ["химический реактив"],
    "реактивация": ["активизация"],
    "реактивировав": ["реактивировавши"],
    "реактивировавши": ["реактивировав"],
    "реактивная артиллерия": ["ра"],
    "реактивная система залпового огня": ["рсзо"],
    "реактивная тяга": ["реактивная сила"],
    "реактивный": ["шустрый", "энергичный", "психогенный"],
    "реактивный ранец": ["ракетный ранец", "джетпак"],
    "реакционер": ["ретроград", "обскурант"],
    "реакционный": ["охранительный", "консервативный", "мракобесный", "обскурантистский", "обскурантский"],
    "реакция": ["ответ", "раздражимость", "химическая реакция"],
    "реализация": ["осуществление"],
    "реализировав": ["реализировавши"],
    "реализировавши": ["реализировав"],
    "реализировать": ["реализовать"],
    "реализм": ["реалистичность"],
    "реализовав": ["реализовавши"],
    "реализовавши": ["реализовав"],
    "реализовать": ["осуществлять", "осуществить", "продавать", "продать", "сбывать", "сбыть"],
    "реализовывав": ["реализовывавши"],
    "реализовывавши": ["реализовывав"],
    "реализовывать": ["реализовать", "осуществлять", "продавать", "сбывать"],
    "реалистичность": ["жизненность", "правдивость"],
    "реалити": ["реалити-шоу"],
    "реалия": ["реальность", "этнолексема", "алиенизм"],
    "реально": ["по-настоящему", "действительно"],
    "реальность": ["действительность"],
    "реальный": ["настоящий", "подлинный", "действительный", "вещественный", "существующий", "возможный", "вероятный", "выполнимый", "осуществимый", "практичный", "трезвый", "реалистичный"],
    "реанимация": ["реанимирование", "реанимобиль", "восстановление", "возвращение", "оживление"],
    "реанимировав": ["реанимировавши"],
    "реанимировавши": ["реанимировав"],
    "реанимировать": ["оживлять", "оживить"],
    "реанимобиль": ["реанимация", "неотложка"],
    "ребалансировав": ["ребалансировавши"],
    "ребалансировавши": ["ребалансировав"],
    "ребе": ["раввин"],
    "ребелия": ["мятеж", "бунт"],
    "ребзя": ["ребята", "пацанва", "братва"],
    "реболлинг": ["реболл"],
    "ребрастый": ["ребристый"],
    "ребровик": ["щётки"],
    "ребут": ["перезапуск"],
    "ребштихель": ["шатирштихель"],
    "ребята": ["парень", "мальчик", "робята"],
    "ребятишки": ["детишки", "дети", "ребята"],
    "ребятки": ["ребята", "ребятишки"],
    "ребятня": ["ребята", "дети"],
    "ребятьё": ["ребятня"],
    "ребятёнок": ["ребёнок"],
    "ребяческий": ["детский", "ребячий", "несерьёзный", "непубертатный", "дурашливый", "безответственный"],
    "ребячество": ["мальчишество", "озорство", "детство"],
    "ревакцинировав": ["ревакцинировавши"],
    "ревакцинировавши": ["ревакцинировав"],
    "ревалоризировав": ["ревалоризировавши"],
    "ревалоризировавши": ["ревалоризировав"],
    "ревалоризовав": ["ревалоризовавши"],
    "ревалоризовавши": ["ревалоризовав"],
    "ревальвировав": ["ревальвировавши"],
    "ревальвировавши": ["ревальвировав"],
    "реванув": ["реванувши"],
    "реванувши": ["реванув"],
    "реваншировав": ["реваншировавши"],
    "реваншировавши": ["реваншировав"],
    "реввоенсовет": ["революционный военный совет", "рвс"],
    "ревев": ["ревевши"],
    "ревевши": ["ревев"],
    "ревенный": ["ревеневый"],
    "реверанс": ["книксен"],
    "реверс": ["решка", "решётка"],
    "реверсивность": ["обратимость"],
    "реверсировав": ["реверсировавши"],
    "реверсировавши": ["реверсировав"],
    "реверсировать": ["обращать"],
    "реветь": ["выть", "вопить"],
    "ревизионизм": ["реформизм"],
    "ревизионист": ["реформист"],
    "ревизировав": ["ревизировавши"],
    "ревизировавши": ["ревизировав"],
    "ревизировать": ["ревизовать"],
    "ревизия": ["осмотр", "обследование"],
    "ревизовав": ["ревизовавши"],
    "ревизовавши": ["ревизовав"],
    "ревизовать": ["ревизировать"],
    "ревизор": ["контролёр"],
    "ревматизм": ["ревматисм", "рюматизм", "раматис"],
    "ревнивость": ["ревность"],
    "ревнитель": ["поборник", "сторонник"],
    "ревнительница": ["поборница"],
    "ревновав": ["ревновавши"],
    "ревновавши": ["ревновав"],
    "ревновать": ["завидовать", "стараться"],
    "ревностно": ["старательно", "усердно", "рьяно"],
    "ревностный": ["усердный", "радетельный", "ретивый"],
    "ревность": ["зависть", "усердие", "рвение", "старание"],
    "ревнув": ["ревнувши"],
    "ревнувши": ["ревнув"],
    "револьвер": ["пистолет-револьвер", "пистолет"],
    "революционизировав": ["революционизировавши"],
    "революционизировавши": ["революционизировав"],
    "революционный": ["мятежный"],
    "революционный трибунал": ["ревтрибунал"],
    "революция": ["переворот"],
    "революция вторых секретарей": ["бунт вторых секретарей"],
    "революция тюльпанов": ["тюльпановая революция"],
    "ревю": ["обозрение"],
    "регазифицировав": ["регазифицировавши"],
    "регазифицировавши": ["регазифицировав"],
    "реган": ["базилик"],
    "регаться": ["регистрироваться"],
    "регги": ["реггей"],
    "регенерация": ["восстановление", "воссоздание"],
    "регенерировав": ["регенерировавши"],
    "регенерировавши": ["регенерировав"],
    "регентовав": ["регентовавши"],
    "регентовавши": ["регентовав"],
    "регентствовав": ["регентствовавши"],
    "регентствовавши": ["регентствовав"],
    "регик": ["видеорегистратор"],
    "регион": ["область", "район", "провинция", "периферия"],
    "регионал": ["региональщик", "регионщик", "рыга"],
    "регионализировав": ["регионализировавши"],
    "регионализировавши": ["регионализировав"],
    "регионализм": ["диалектизм"],
    "региональный": ["областной", "поместный"],
    "региональный ярус": ["региоярус", "горизонт"],
    "региональщик": ["регионал", "регионщик"],
    "регионарный": ["местный", "локальный"],
    "регионщик": ["регионал", "региональщик"],
    "региоярус": ["горизонт"],
    "регистр": ["реестр", "кадастр", "стиль"],
    "регистраторствовав": ["регистраторствовавши"],
    "регистраторствовавши": ["регистраторствовав"],
    "регистрация": ["авторизация"],
    "регистрировав": ["регистрировавши"],
    "регистрировавши": ["регистрировав"],
    "регистрировать": ["брать на учёт"],
    "регламент": ["устав"],
    "регламентация": ["регламентирование"],
    "регламентировав": ["регламентировавши"],
    "регламентировавши": ["регламентировав"],
    "регламентирование": ["регламентация"],
    "реготав": ["реготавши"],
    "реготавши": ["реготав"],
    "реготать": ["ржать", "гоготать"],
    "реградация": ["проградация"],
    "регредиентный": ["регрессирующий"],
    "регрес": ["занепад"],
    "регресс": ["упадок", "одичание", "деградация"],
    "регрессант": ["регредиент"],
    "регрессивная деривация": ["дезаффиксация", "редеривация"],
    "регрессировав": ["регрессировавши"],
    "регрессировавши": ["регрессировав"],
    "регулировав": ["регулировавши"],
    "регулировавши": ["регулировав"],
    "регулирование": ["упорядочение"],
    "регулировать": ["упорядочивать", "налаживать", "управлять", "контролировать", "юстировать"],
    "регулируемость": ["управляемость", "контролируемость"],
    "регуляр": ["рег"],
    "регулярная армия": ["регулярные вооружённые силы"],
    "регулярно": ["систематически", "постоянно", "размеренно", "упорядоченно"],
    "регулярное выражение": ["регэксп", "регулярка"],
    "регулярный сезон": ["регуляр", "регулярка"],
    "регуляция": ["упорядочивание", "упорядочение", "нормализация"],
    "редактировав": ["редактировавши"],
    "редактировавши": ["редактировав"],
    "редактор связей": ["компоновщик", "линковщик"],
    "редакторствовав": ["редакторствовавши"],
    "редакторствовавши": ["редакторствовав"],
    "редакторша": ["редакторка", "редактриса"],
    "редакционная коллегия": ["редколлегия"],
    "редакционно-издательская группа": ["редакционный отдел", "издательская группа"],
    "редакция": ["правка", "версия"],
    "редан": ["редант"],
    "редант": ["редан"],
    "редач": ["сортировач"],
    "редев": ["редевши"],
    "редевши": ["редев"],
    "редеривация": ["обратное словообразование", "регрессивная деривация"],
    "редив": ["редивши"],
    "редивши": ["редив"],
    "редижировав": ["редижировавши"],
    "редижировавши": ["редижировав"],
    "редис": ["редиска"],
    "редиска": ["редис"],
    "редить": ["прорежать", "прореживать"],
    "редкий": ["нечастый"],
    "редко": ["нечасто", "изредка", "в кои веки", "время от времени", "наредко", "негусто", "жидко"],
    "редковолосый": ["жидковолосый"],
    "редколлегия": ["редакционная коллегия"],
    "редкостный": ["редкий", "исключительный"],
    "редкостойный": ["редкий"],
    "реднековский": ["деревенский"],
    "редник": ["редови"],
    "редомицилировать": ["перерегистрировать", "релоцировать"],
    "редомициляция": ["редомицилирование", "релокация", "перерегистрация", "перевод"],
    "редстокист": ["шашковец", "прохановец", "пашковец"],
    "редуктор": ["механический редуктор", "мотор-редуктор", "демультипликатор", "газовый редуктор"],
    "редупликация": ["повторение", "репликация", "ауторепродукция", "аутосинтез"],
    "редуцент": ["сапротроф"],
    "редуцировав": ["редуцировавши"],
    "редуцировавши": ["редуцировав"],
    "редуцирование": ["редукция"],
    "редуцированный": ["сокращённый", "стеснённый", "сжатый"],
    "редуцировать": ["сокращать", "сократить"],
    "реестр": ["регистр", "опись"],
    "режик": ["ножик"],
    "режим": ["государственный строй", "порядок", "распорядок"],
    "режимив": ["режимивши"],
    "режимивши": ["режимив"],
    "режиссерствовав": ["режиссерствовавши"],
    "режиссерствовавши": ["режиссерствовав"],
    "режиссировав": ["режиссировавши"],
    "режиссировавши": ["режиссировав"],
    "режиссура": ["режиссирование"],
    "режиссёрски": ["по-режиссёрски"],
    "режиссёрствовав": ["режиссёрствовавши"],
    "режиссёрствовавши": ["режиссёрствовав"],
    "режопер": ["режиссёр", "оператор"],
    "режоперный": ["режоперский"],
    "режоперский": ["режоперный"],
    "режущий": ["резательный"],
    "рез": ["резание", "разрезание"],
    "резав": ["резавши"],
    "резавши": ["резав"],
    "резаная бумага": ["рублёвик", "рублёвка", "рубель", "рупь", "рваный", "деревянный", "рубас", "хруст"],
    "резанец": ["скорода", "шнитт-лук"],
    "резанув": ["резанувши"],
    "резанувши": ["резанув"],
    "резанье": ["резание"],
    "резательный": ["режущий"],
    "резать": ["зарезывать", "оперировать", "раздражать", "коробить"],
    "резать правду-матку": ["говорить начистоту", "резать правду в глаза"],
    "резбин": ["заррабин"],
    "резвление": ["веселье", "куролесица", "озорство", "озорничание"],
    "резвун": ["чертёнок", "шалун"],
    "резвуха": ["резвунья", "резвушка"],
    "резвушка": ["резвунья"],
    "резвый": ["быстрый", "стремительный", "быстроходный", "скоростной", "ходкий", "быстроногий", "проворный"],
    "резерв": ["запас"],
    "резерват": ["заповедник"],
    "резервировав": ["резервировавши"],
    "резервировавши": ["резервировав"],
    "резервировать": ["зарезервировать"],
    "резервное копирование": ["резервное дублирование"],
    "резервуар": ["ёмкость"],
    "резец": ["резак"],
    "резецировав": ["резецировавши"],
    "резецировавши": ["резецировав"],
    "резидентура": ["ординатура"],
    "резиденция": ["дом", "жилище", "жильё", "жилплощадь"],
    "резидировав": ["резидировавши"],
    "резидировавши": ["резидировав"],
    "резил": ["срам", "посрамяване", "позор"],
    "резина": ["смола", "камедь", "шина", "покрышка", "тяга", "ластик", "гуммиэластик", "демократизатор"],
    "резинив": ["резинивши"],
    "резинивши": ["резинив"],
    "резинить": ["прорезинивать"],
    "резинковый": ["резиновый"],
    "резинокордный": ["резинокордовый"],
    "резистентность": ["сопротивляемость"],
    "резистентный": ["упрямый", "неуправляемый", "нечувствительный"],
    "резистор": ["сопротивление"],
    "резка": ["резание"],
    "резкий": ["мощный", "крутой", "пронзительный", "сильный", "внезапный", "значительный", "неожиданный", "яркий", "интенсивный", "чёткий", "отрывистый", "грубый", "дерзкий", "обидный", "беспощадный"],
    "резко": ["внезапно", "сильно"],
    "резкость": ["отрывистость", "грубость", "бестактность", "прямота", "порывистость", "сфокусированность", "чёткость"],
    "резник": ["мясник", "забойщик"],
    "резнув": ["резнувши"],
    "резнувши": ["резнув"],
    "резня": ["бойня", "избиение", "побоище", "кровавая баня", "варфоломеевская ночь", "буча", "рубка", "мясорубка"],
    "резня в буче": ["буча"],
    "резолв": ["разрешение"],
    "резон": ["причина", "повод", "основание", "смысл", "мотив", "предлог", "оправдание", "резонт", "аргумент", "доказательство", "довод", "соображение"],
    "резонабельность": ["благоразумие"],
    "резонанс": ["отклик"],
    "резонив": ["резонивши"],
    "резонивши": ["резонив"],
    "резонировав": ["резонировавши"],
    "резонировавши": ["резонировав"],
    "резонность": ["обоснованность", "справедливость", "логичность"],
    "резонный": ["разумный", "обоснованный", "оправданный", "законный", "логичный", "справедливый", "уместный"],
    "резонт": ["резон", "причина", "повод", "основание", "предлог", "оправдание"],
    "резонёр": ["моралист"],
    "резонёрство": ["назидательность", "поучительность", "резонёрствование"],
    "резонёрствовав": ["резонёрствовавши"],
    "резонёрствовавши": ["резонёрствовав"],
    "резорбировав": ["резорбировавши"],
    "резорбировавши": ["резорбировав"],
    "результат": ["итог", "следствие", "плод", "последствие", "продукт", "развязка", "конец", "исход", "эффект", "выхлоп", "показатель", "достижение"],
    "результат интеллектуальной деятельности": ["рид"],
    "результатив": ["статив"],
    "результативность": ["действенность", "производительность", "эффективность"],
    "результативный": ["эффективный", "небезрезультативный", "успешный", "плодотворный"],
    "результировав": ["результировавши"],
    "результировавши": ["результировав"],
    "результирующий": ["обобщающий", "окончательный", "итоговый"],
    "резус-конфликт": ["резус-несовместимость"],
    "резус-несовместимость": ["резус-конфликт"],
    "резывав": ["резывавши"],
    "резывавши": ["резывав"],
    "резь": ["колика"],
    "резюме": ["конспект", "реферат", "аннотация", "экспозе", "компендиум", "заключение", "итог", "подитог", "анкета", "биография", "послужной список"],
    "резюмировав": ["резюмировавши"],
    "резюмировавши": ["резюмировав"],
    "резюмировать": ["подытоживать", "подытожить"],
    "реиммигрировав": ["реиммигрировавши"],
    "реиммигрировавши": ["реиммигрировав"],
    "реимпортировав": ["реимпортировавши"],
    "реимпортировавши": ["реимпортировав"],
    "реинвестировав": ["реинвестировавши"],
    "реинвестировавши": ["реинвестировав"],
    "реинкарнация": ["метемпсихоз", "перевоплощение", "переселение душ"],
    "реинкарнировав": ["реинкарнировавши"],
    "реинкарнировавши": ["реинкарнировав"],
    "реинсталлировав": ["реинсталлировавши"],
    "реинсталлировавши": ["реинсталлировав"],
    "реинтеграция": ["воссоединение", "реинтегрирование", "реабилитация"],
    "реинтегрировав": ["реинтегрировавши"],
    "реинтегрировавши": ["реинтегрировав"],
    "реинтегрирование": ["реинтеграция"],
    "реинтегрироваться": ["воссоединяться", "воссоединиться"],
    "реинтерпретировав": ["реинтерпретировавши"],
    "реинтерпретировавши": ["реинтерпретировав"],
    "реинфицировав": ["реинфицировавши"],
    "реинфицировавши": ["реинфицировав"],
    "рей": ["рея"],
    "рейв": ["рэйв", "рейв-акция", "рейв-вечеринка", "рейв-дискотека", "рейв-пати", "рейв-музыка"],
    "рейв-акция": ["рейв", "рейв-вечеринка", "рейв-дискотека", "рейв-пати"],
    "рейв-вечеринка": ["рейв", "рейв-акция", "рейв-пати"],
    "рейв-дискотека": ["рейв", "рейв-акция", "рейв-вечеринка", "рейв-пати"],
    "рейв-музыка": ["рейв"],
    "рейв-пати": ["рейв", "рейв-акция", "рейв-вечеринка", "рейв-дискотека"],
    "рейганист": ["рейгановец"],
    "рейгановец": ["рейганист"],
    "рейджив": ["рейдживши"],
    "рейдживши": ["рейджив"],
    "рейдировав": ["рейдировавши"],
    "рейдировавши": ["рейдировав"],
    "рейзив": ["рейзивши"],
    "рейзивши": ["рейзив"],
    "рейлинг": ["релинг"],
    "рейлфан": ["ферроэквинолог", "трейнспоттер"],
    "рейнгольд": ["рональд", "рагнвальд", "рейнхольд", "рейнольд", "рено", "роналду"],
    "рейс": ["поездка", "перелёт", "поход", "вылазка", "путешествие"],
    "рейсировав": ["рейсировавши"],
    "рейсировавши": ["рейсировав"],
    "рейсмас": ["рейсмус"],
    "рейсмус": ["рейсмас", "рейсмусовый станок"],
    "рейсфедер": ["расфедер"],
    "рейсшина": ["наугольник"],
    "рейтар": ["наёмник"],
    "рейтер": ["гусарик"],
    "рейтинг компании": ["кредитный рейтинг компании"],
    "рейтинг кредитоспособности": ["кредитный рейтинг"],
    "рейтинговав": ["рейтинговавши"],
    "рейтинговавши": ["рейтинговав"],
    "рейтинговое агентство": ["ра"],
    "рейтузы": ["чикчиры", "лосины", "панталоны", "легинсы"],
    "рейфуга": ["бомбоубежище", "капонир", "блиндаж", "землянка"],
    "рейх": ["райх", "третий рейх"],
    "рейхан": ["базилик"],
    "рейхсталер": ["ригсдалер"],
    "рейчел": ["рэйчел"],
    "рек": ["рекомендация"],
    "река": ["поток", "водная артерия", "фонтан"],
    "рекалибровка": ["перекалибровка"],
    "рекапитулировав": ["рекапитулировавши"],
    "рекапитулировавши": ["рекапитулировав"],
    "реквизировав": ["реквизировавши"],
    "реквизировавши": ["реквизировав"],
    "реквизиционный": ["конфискационный", "реквизированный"],
    "реквизиция": ["изъятие", "реквизит"],
    "реклайнер": ["кресло", "диван"],
    "реклама": ["рекламирование", "пропаганда", "популяризация"],
    "рекламация": ["претензия"],
    "рекламив": ["рекламивши"],
    "рекламивши": ["рекламив"],
    "рекламировав": ["рекламировавши"],
    "рекламировавши": ["рекламировав"],
    "рекламист": ["рекламщик"],
    "рекламомобиль": ["рекламобиль"],
    "рекламоноситель": ["медианоситель"],
    "рекламопользователь": ["рекламопотребитель"],
    "рекламопотребитель": ["рекламопользователь"],
    "рекламщик": ["рекламист"],
    "реклассифицировав": ["реклассифицировавши"],
    "реклассифицировавши": ["реклассифицировав"],
    "реклассифицировать": ["переклассифицировать"],
    "рекогносцировав": ["рекогносцировавши"],
    "рекогносцировавши": ["рекогносцировав"],
    "реколта": ["жътва", "урожай", "добив", "плодородие"],
    "рекомбинировать": ["пересобирать"],
    "рекомендация": ["характеристика", "отзыв", "совет", "пожелание", "наставление"],
    "рекомендовав": ["рекомендовавши"],
    "рекомендовавши": ["рекомендовав"],
    "рекомендовать": ["советовать", "порекомендовать"],
    "рекомендоваться": ["представляться"],
    "рекомпенсация": ["антанагога", "паромология"],
    "реконвертировав": ["реконвертировавши"],
    "реконвертировавши": ["реконвертировав"],
    "реконструировав": ["реконструировавши"],
    "реконструировавши": ["реконструировав"],
    "реконструировать": ["перестраивать", "перестроить", "переоборудовать"],
    "реконструироваться": ["восстанавливаться", "возобновляться"],
    "реконструкция": ["переустройство", "перестройка", "восстановление", "воссоздание"],
    "реконфигурация": ["реконфигурирование", "перенастройка"],
    "реконфигурировав": ["реконфигурировавши"],
    "реконфигурировавши": ["реконфигурировав"],
    "рекорд-лейбл": ["лейбл", "фирма грамзаписи"],
    "рекордно": ["беспрецедентно"],
    "рекордный": ["наибольший", "наивысший"],
    "рекредитив": ["отзывная грамота"],
    "рекриминация": ["обвинение", "упрёк"],
    "рекриминировать": ["упрекать", "обвинять"],
    "рекристаллизация": ["перекристаллизация"],
    "рекрут": ["выбранец", "годник", "кантонист", "лобовик", "наймист", "новобранец", "первобранец", "некрут", "рекрутик", "некрутик", "рекрутишка", "рекрутища"],
    "рекрутер": ["кадровик"],
    "рекрутинг": ["рекрутмент"],
    "рекрутировав": ["рекрутировавши"],
    "рекрутировавши": ["рекрутировав"],
    "рекрутировать": ["вербовать", "завербовать", "призывать", "призвать", "нанимать", "нанять"],
    "рекрутмент": ["рекрутинг"],
    "рекрутство": ["рекрутчина"],
    "рекрутчина": ["рекрутство"],
    "ректальный": ["анальный"],
    "ректи": ["промовляти"],
    "ректификатор": ["очиститель"],
    "ректификация": ["поправка", "уточнение", "фракционирование"],
    "ректификовав": ["ректификовавши"],
    "ректификовавши": ["ректификовав"],
    "ректификовать": ["ректифицировать"],
    "ректифицировав": ["ректифицировавши"],
    "ректифицировавши": ["ректифицировав"],
    "ректифицировать": ["ректификовать"],
    "ректорствовав": ["ректорствовавши"],
    "ректорствовавши": ["ректорствовав"],
    "ректорша": ["начальница", "управительница", "заведующая", "директриса"],
    "рекультивировав": ["рекультивировавши"],
    "рекультивировавши": ["рекультивировав"],
    "рекуперативный": ["регенерация", "возвращение", "восстановление"],
    "рекуперационный": ["рекуперативный"],
    "рекуперация": ["регенерация", "восстановление"],
    "рекуперировав": ["рекуперировавши"],
    "рекуперировавши": ["рекуперировав"],
    "рекуррентный": ["рекурсивный"],
    "рекурсивный": ["самоподобный"],
    "рекурсия": ["самовызов", "отступ"],
    "релакс-массаж": ["эромассаж"],
    "релаксация": ["расслабление", "затухание", "ослабление"],
    "релаксировав": ["релаксировавши"],
    "релаксировавши": ["релаксировав"],
    "релакснув": ["релакснувши"],
    "релакснувши": ["релакснув"],
    "релевантность": ["существенность", "важность", "актуальность", "уместность", "востребованность"],
    "релевантный": ["уместный", "подходящий", "соответствующий", "связанный", "актуальный", "важный", "существенный", "различительный", "дистинктивный"],
    "рели": ["виселица", "качели"],
    "религиеведение": ["религиоведение"],
    "религиоведение": ["религиеведение"],
    "религиоведческий": ["религоведческий"],
    "религиозный": ["духовный", "набожный", "богомольный", "благочестивый", "церковный", "верующий"],
    "религия": ["теизм", "вероисповедание", "вероучение", "верование"],
    "религоведческий": ["религиоведческий"],
    "релиз": ["пресс-релиз"],
    "реликвия": ["святыня"],
    "реликт": ["рудимент", "атавизм"],
    "релинг": ["рейлинг"],
    "релокант": ["переселенец"],
    "релокация": ["перевод", "перенос", "перемещение"],
    "релоцировать": ["переселять", "переселить"],
    "рельбус": ["автомотриса"],
    "рельефно": ["выпукло"],
    "рельефный": ["выпуклый", "неровный"],
    "рельс": ["рельса", "рельсина", "подколёсник", "колесопровод", "лад", "строй", "уклад", "жердь"],
    "рельса": ["рельс"],
    "рельсобус": ["рельсовый автобус", "автомотриса"],
    "рельсовый автобус": ["рельбус"],
    "рельсопрокатчик": ["металлург", "рабочий"],
    "релятивизировав": ["релятивизировавши"],
    "релятивизировавши": ["релятивизировав"],
    "релятивизировать": ["релятивизовать"],
    "релятивизовав": ["релятивизовавши"],
    "релятивизовавши": ["релятивизовав"],
    "релятивный": ["относительный"],
    "реляционность": ["релятивность"],
    "рема": ["фокус"],
    "ремантадин": ["римантадин"],
    "ремастер": ["ремастеринг", "переиздание", "реставрация"],
    "ремастеринг": ["переиздание", "реставрация", "ремастер"],
    "ремастировав": ["ремастировавши"],
    "ремастировавши": ["ремастировав"],
    "ремедиация": ["рекультивация"],
    "ремень": ["пояс", "поясной ремень"],
    "ремень-рыба": ["сельдяной король", "ремнетел"],
    "ремесленник": ["кустарь"],
    "ремесленничав": ["ремесленничавши"],
    "ремесленничавши": ["ремесленничав"],
    "ремесло": ["рутина"],
    "ремеслуха": ["ремесленное училище", "хмызня", "ремесло", "халтура"],
    "ремешок": ["поясок"],
    "ремизив": ["ремизивши"],
    "ремизивши": ["ремизив"],
    "ремиксировав": ["ремиксировавши"],
    "ремиксировавши": ["ремиксировав"],
    "ремиксировать": ["ремиксовать", "ремикшировать"],
    "ремиксовав": ["ремиксовавши"],
    "ремиксовавши": ["ремиксовав"],
    "ремиксовать": ["ремиксировать", "ремикшировать"],
    "ремикшировав": ["ремикшировавши"],
    "ремикшировавши": ["ремикшировав"],
    "ремикшировать": ["ремиксировать", "ремиксовать"],
    "ремилитаризировав": ["ремилитаризировавши"],
    "ремилитаризировавши": ["ремилитаризировав"],
    "ремилитаризовав": ["ремилитаризовавши"],
    "ремилитаризовавши": ["ремилитаризовав"],
    "ремилитаризовать": ["ремилитаризировать"],
    "реминерализовав": ["реминерализовавши"],
    "реминерализовавши": ["реминерализовав"],
    "ремиссия": ["улучшение"],
    "ремитировав": ["ремитировавши"],
    "ремитировавши": ["ремитировав"],
    "ремкомплект": ["ремонтный комплект", "зип"],
    "ремнантный": ["остаточный"],
    "ремнеобразный": ["ремневидный"],
    "ремовыделитель": ["ремоиндикатор"],
    "ремоделировав": ["ремоделировавши"],
    "ремоделировавши": ["ремоделировав"],
    "ремонстрант": ["протестер"],
    "ремонстрация": ["протест", "протестация"],
    "ремонт": ["починка", "наладка", "исправление"],
    "ремонтада": ["камбэк"],
    "ремонтировав": ["ремонтировавши"],
    "ремонтировавши": ["ремонтировав"],
    "ремонтировать": ["чинить", "починять"],
    "ремонтник": ["починщик", "чинила"],
    "ремстройконтора": ["ремонтно-строительный", "контора"],
    "ремунерация": ["вознаграждение"],
    "ремък": ["каиш"],
    "ренат": ["ринат", "рене", "ренато"],
    "рената": ["рината", "ренате", "рене"],
    "ренатурализовав": ["ренатурализовавши"],
    "ренатурализовавши": ["ренатурализовав"],
    "ренационализировав": ["ренационализировавши"],
    "ренационализировавши": ["ренационализировав"],
    "ренданг": ["ранданг"],
    "рендер": ["рендерер"],
    "рендерер": ["рендер"],
    "рендерив": ["рендеривши"],
    "рендеривши": ["рендерив"],
    "рендеринг": ["визуализация", "отрисовка"],
    "рендериться": ["отрисовываться"],
    "рендольф": ["рэндольф", "рандолф", "рэндолф"],
    "ренегат": ["отступник", "изменник"],
    "ренегатство": ["отступничество"],
    "ренегатствовав": ["ренегатствовавши"],
    "ренегатствовавши": ["ренегатствовав"],
    "ренессанс": ["возрождение"],
    "ренессансный": ["возрожденческий"],
    "реникса": ["ошибка", "путаница", "чепуха", "ерунда", "глупость", "оплошность", "промах", "промашка", "просчёт"],
    "ренифлекс": ["озолагния", "осфрезиофилия"],
    "реновационный": ["реноваторский"],
    "реновировав": ["реновировавши"],
    "реновировавши": ["реновировав"],
    "реноме": ["репутация", "имя", "слава"],
    "ренский погреб": ["ренсковый погреб"],
    "рентабельно": ["выгодно"],
    "рентабельность": ["окупаемость"],
    "рентабельный": ["окупающийся", "прибыльный", "доходный"],
    "рентген-диагностика": ["рентгенодиагностика"],
    "рентген-эквивалент": ["бэр", "биологический эквивалент рентгена", "фэр", "физиологический эквивалент рентгена"],
    "рентгенизировав": ["рентгенизировавши"],
    "рентгенизировавши": ["рентгенизировав"],
    "рентгений": ["унунуний", "эка-золото"],
    "рентгеновская кристаллография": ["рентгеноструктурный анализ"],
    "рентгеновский лазер": ["разер"],
    "рентгеновское излучение": ["рентгеновские лучи"],
    "рентгенография": ["рентгеносъёмка", "скиаграфия"],
    "рентгенодиагностика": ["рентген-диагностика"],
    "рентгенокинематография": ["кинорентгенография", "кинофлюорография", "кинофлюороскопия"],
    "рентгеноскопия": ["флуороскопия", "флюороскопия"],
    "реография": ["электрореография"],
    "реомойка": ["реожёлоб", "реолавер"],
    "реоплетизмограф": ["импедансный плетизмограф", "реовазограф", "реоэнцефалограф", "реокардиограф"],
    "реорганизовав": ["реорганизовавши"],
    "реорганизовавши": ["реорганизовав"],
    "реорганизовать": ["реформировать"],
    "реорганизовывав": ["реорганизовывавши"],
    "реорганизовывавши": ["реорганизовывав"],
    "реохорд": ["вольтагометр"],
    "репа": ["тыква", "кочан", "бубен", "башка", "котелок"],
    "репартиция": ["распределение"],
    "репатриировав": ["репатриировавши"],
    "репатриировавши": ["репатриировав"],
    "реперкусса": ["тон речитации", "тенор"],
    "реперная точка": ["репер"],
    "репетир": ["репетиция"],
    "репетировав": ["репетировавши"],
    "репетировавши": ["репетировав"],
    "репетировать": ["разучивать", "репетиторствовать"],
    "репетитор": ["учитель", "преподаватель"],
    "репетиторствовав": ["репетиторствовавши"],
    "репетиторствовавши": ["репетиторствовав"],
    "репетиторствовать": ["репетировать"],
    "репетиция": ["репетир"],
    "репетичный": ["повторяемый", "репетиционный"],
    "репетовав": ["репетовавши"],
    "репетовавши": ["репетовав"],
    "репетование": ["повторение", "репетирование"],
    "репетувати": ["верещати"],
    "репешок": ["репейничек"],
    "репит": ["повтор"],
    "репитер": ["ретранслятор"],
    "репка": ["репочка"],
    "реплаить": ["реплить"],
    "реплантировав": ["реплантировавши"],
    "реплантировавши": ["реплантировав"],
    "реплика": ["замечание", "ответ", "возражение"],
    "репликатор": ["ген-репликатор", "размножитель"],
    "реплить": ["реплаить"],
    "реплицировав": ["реплицировавши"],
    "реплицировавши": ["реплицировав"],
    "реплицировать": ["дублировать"],
    "репнути": ["репнутися"],
    "репнутися": ["репнути"],
    "репный": ["реповый"],
    "реповый": ["репный"],
    "репозитарий": ["репозиторий", "хранилище"],
    "репозиторий": ["репозитарий"],
    "реполов": ["коноплянка"],
    "репорт": ["рапорт"],
    "репортиция": ["распределение"],
    "репортёр": ["корреспондент"],
    "репортёрствовав": ["репортёрствовавши"],
    "репортёрствовавши": ["репортёрствовав"],
    "репост": ["перепост"],
    "репостив": ["репостивши"],
    "репостивши": ["репостив"],
    "репостнув": ["репостнувши"],
    "репостнувши": ["репостнув"],
    "репрезентант": ["представитель"],
    "репрезентативность": ["представительность", "адекватность"],
    "репрезентативный": ["представительный", "типичный"],
    "репрезентировав": ["репрезентировавши"],
    "репрезентировавши": ["репрезентировав"],
    "репрезентовав": ["репрезентовавши"],
    "репрезентовавши": ["репрезентовав"],
    "репрессивный": ["карательный", "насильственный"],
    "репрессировав": ["репрессировавши"],
    "репрессировавши": ["репрессировав"],
    "реприватизировав": ["реприватизировавши"],
    "реприватизировавши": ["реприватизировав"],
    "реприза": ["вольта"],
    "реприманд": ["выговор", "упрёк", "пассаж", "репримант"],
    "репродуктивность": ["фертильность"],
    "репродуктор": ["громкоговоритель"],
    "репродукционный": ["репродукторный"],
    "репродуцировав": ["репродуцировавши"],
    "репродуцировавши": ["репродуцировав"],
    "репропорционирование": ["конпропорционирование"],
    "рептилаза": ["батроксобин"],
    "рептилия": ["пресмыкающееся", "гад"],
    "рептилоид": ["рептоид"],
    "република българия": ["българия"],
    "репутация": ["реноме"],
    "репчатый лук": ["репка"],
    "репшик": ["рублис"],
    "рерайтер": ["переписчик", "редактор"],
    "рерайтинг": ["переписывание"],
    "ререйзив": ["ререйзивши"],
    "ререйзивши": ["ререйзив"],
    "ресайклинг": ["рециклинг", "рециклирование"],
    "реселлер": ["перепродавец"],
    "ресентимент": ["озлобленность", "озлобление", "враждебность", "неприязнь", "нелюбовь", "антипатия", "вражда", "антагонизм"],
    "ресепшен": ["рецепция"],
    "ресепшионист": ["администратор", "регистратор"],
    "ресепшн": ["рецепция"],
    "ресинтезировав": ["ресинтезировавши"],
    "ресинтезировавши": ["ресинтезировав"],
    "ресконтро": ["расчетная книжка", "книга личных счетов"],
    "ресмон": ["нах"],
    "реснитчатый": ["ресничатый"],
    "ресница": ["ресничка"],
    "ресничатый": ["реснитчатый"],
    "респект": ["почтение", "уважение", "почитание", "респектос"],
    "респектабельность": ["солидность", "почтенность"],
    "респектабельный": ["почтенный", "представительный", "достойный", "солидный", "уважаемый"],
    "респираторный": ["дыхательный"],
    "респирация": ["дыхание"],
    "респондент": ["информант"],
    "республика абхазия": ["абхазия", "ра"],
    "республика адыгея": ["адыгея", "ра"],
    "республика алтай": ["алтай", "горный алтай", "ра", "республика горный алтай"],
    "республика армения": ["армения", "ра"],
    "республика баден": ["баден"],
    "республика башкортостан": ["башкортостан", "рб", "башкирия"],
    "республика беларусь": ["беларусь", "рб"],
    "республика болгария": ["болгария"],
    "республика бурятия": ["бурятия"],
    "республика дагестан": ["дагестан", "рд"],
    "республика зимбабве": ["зимбабве", "южная родезия"],
    "республика ингушетия": ["ингушетия", "ри"],
    "республика индонезия": ["индонезия"],
    "республика казахстан": ["казахстан", "рк"],
    "республика калмыкия": ["калмыкия", "рк"],
    "республика каракалпакстан": ["каракалпакстан", "каракалпакия"],
    "республика карелия": ["карелия", "рк"],
    "республика кипр": ["кипр", "рк"],
    "республика коми": ["коми", "рк"],
    "республика конго": ["конго", "рк", "народная республика конго", "нрк", "демократическая республика конго", "заир", "республика заир"],
    "республика корея": ["южная корея", "корейская республика", "рк"],
    "республика косово": ["косово", "рк"],
    "республика крым": ["крым", "рк"],
    "республика куба": ["куба", "остров свободы"],
    "республика либерия": ["либерия"],
    "республика македония": ["республика северная македония"],
    "республика мальта": ["мальта", "мальтийская республика"],
    "республика марий эл": ["марий эл", "рмэ"],
    "республика молдова": ["молдавия", "молдова"],
    "республика мордовия": ["мордовия", "рм"],
    "республика польша": ["польша", "польская республика"],
    "республика северная осетия-алания": ["северная осетия", "северная осетия-алания", "рсоа"],
    "республика словения": ["словения"],
    "республика таджикистан": ["таджикистан", "таджикия", "рт"],
    "республика татарстан": ["татарстан", "татария", "рт"],
    "республика тыва": ["тыва", "тува", "рт", "танну-тува", "тувинская народная республика", "тнр"],
    "республика узбекистан": ["узбекистан"],
    "республика хакасия": ["хакасия", "рх"],
    "республика хорватия": ["хорватия", "рх"],
    "реставрация": ["восстановление"],
    "реставрировав": ["реставрировавши"],
    "реставрировавши": ["реставрировав"],
    "рестадинг": ["дошиповка"],
    "рестайлинг": ["переоформление", "ребрендинг", "редизайн"],
    "рестарт": ["перезапуск"],
    "рестобар": ["ресторан-бар"],
    "ресторан": ["ресторация", "кафе", "закусочная"],
    "ресторан быстрого питания": ["фастфуд-ресторан"],
    "ресторация": ["ресторан"],
    "ресторировав": ["ресторировавши"],
    "ресторировавши": ["ресторировав"],
    "реструктуризировав": ["реструктуризировавши"],
    "реструктуризировавши": ["реструктуризировав"],
    "реструктуризировать": ["реструктуризовать"],
    "реструктуризовав": ["реструктуризовавши"],
    "реструктуризовавши": ["реструктуризовав"],
    "реструктуризовать": ["реструктуризировать"],
    "реструктурировав": ["реструктурировавши"],
    "реструктурировавши": ["реструктурировав"],
    "ресурс": ["запас", "источник", "прибежище"],
    "ресурсное состояние": ["ресурсность"],
    "ресурсоснабжающий": ["ресурсопоставляющий"],
    "ресуспендировав": ["ресуспендировавши"],
    "ресуспендировавши": ["ресуспендировав"],
    "ресёч": ["ресёрч"],
    "ретаргетинг": ["ремаркетинг"],
    "ретвит": ["репост"],
    "ретвитив": ["ретвитивши"],
    "ретвитивши": ["ретвитив"],
    "ретвитнув": ["ретвитнувши"],
    "ретвитнувши": ["ретвитнув"],
    "ретейлер": ["ритейлер"],
    "ретельний": ["дбайливий", "дбалий"],
    "ретентат": ["концентрат"],
    "ретенция": ["атавизм"],
    "ретиво": ["усердно", "старательно", "прилежно", "бойко", "живо", "прытко"],
    "ретивый": ["рьяный", "старательный", "прилежный", "усердный", "живой", "резвый", "бойкий", "пылкий", "горячий", "страстный"],
    "ретина": ["сетчатка"],
    "ретиноскопия": ["скиаскопия"],
    "ретирада": ["отступление", "отход", "ретирад", "отхожее место", "уборная"],
    "ретировав": ["ретировавши"],
    "ретировавши": ["ретировав"],
    "ретироваться": ["отступать", "отступить"],
    "ретороманский": ["граубюнденский", "руманшский"],
    "ретранслировав": ["ретранслировавши"],
    "ретранслировавши": ["ретранслировав"],
    "ретрансплантировав": ["ретрансплантировавши"],
    "ретрансплантировавши": ["ретрансплантировав"],
    "ретраншемент": ["абшнит", "ретраншамент"],
    "ретро": ["ретростиль", "антиквариат", "винтаж", "классика", "раритет"],
    "ретроавтомобиль": ["ретромобиль"],
    "ретровейв": ["синтвейв"],
    "ретроград": ["реакционер"],
    "ретроградство": ["отсталость", "реакционность", "обскурантизм"],
    "ретролобковый": ["позадилобковый"],
    "ретроспектива": ["ретроспекция"],
    "ретрофлексировав": ["ретрофлексировавши"],
    "ретрофлексировавши": ["ретрофлексировав"],
    "ретроцедировав": ["ретроцедировавши"],
    "ретроцедировавши": ["ретроцедировав"],
    "ретушевальный": ["ретушёрный"],
    "ретушировав": ["ретушировавши"],
    "ретушировавши": ["ретушировав"],
    "ретушировать": ["лакировать", "залакировывать", "подлакировывать"],
    "ретушь": ["ретуширование", "ретушёвка"],
    "ретэш": ["ретеш"],
    "рефаим": ["анакит", "авим", "эмимам", "замзумим", "рофеим"],
    "рефанд": ["возврат", "возвращение", "возмещение"],
    "референдум": ["плебисцит"],
    "референс": ["реф", "оригинал", "исходник", "норма"],
    "референциальный": ["ссылочный", "указательный", "денотативный"],
    "рефери": ["судья", "арбитр"],
    "реферировав": ["реферировавши"],
    "реферировавши": ["реферировав"],
    "рефинансировав": ["рефинансировавши"],
    "рефинансировавши": ["рефинансировав"],
    "рефлексировав": ["рефлексировавши"],
    "рефлексировавши": ["рефлексировав"],
    "рефлексировать": ["рефлектировать", "размышлять", "анализировать"],
    "рефлексия": ["самоанализ"],
    "рефлексорный": ["инстинктивный"],
    "рефлексотерапевт": ["иглоукалыватель"],
    "рефлектировав": ["рефлектировавши"],
    "рефлектировавши": ["рефлектировав"],
    "рефлектор": ["зеркало"],
    "рефлюксат": ["рефлюктат"],
    "рефмеханик": ["реф"],
    "реформа": ["преобразование"],
    "реформатор": ["преобразователь", "реформист"],
    "реформаторский": ["преобразовательский"],
    "реформировав": ["реформировавши"],
    "реформировавши": ["реформировав"],
    "реформирование": ["реформа", "преобразование"],
    "реформировать": ["преобразовывать", "преобразовать"],
    "рефрактерный период": ["рефрактерность"],
    "рефрактометрия": ["рефракция"],
    "рефракция": ["преломление"],
    "рефрен": ["припев"],
    "рефрижератор": ["контейнеровоз"],
    "рефузник": ["отказник", "невыездной"],
    "рефулировав": ["рефулировавши"],
    "рефулировавши": ["рефулировав"],
    "рефутация": ["опровержение"],
    "рефьюзник": ["отказник", "невыездной"],
    "рехоботер": ["бастер"],
    "рецензировав": ["рецензировавши"],
    "рецензировавши": ["рецензировав"],
    "рецензия": ["реца", "рецуха"],
    "рецептивность": ["восприимчивость"],
    "рецепторный потенциал": ["генераторный потенциал"],
    "рецидив": ["повтор"],
    "рецидивировав": ["рецидивировавши"],
    "рецидивировавши": ["рецидивировав"],
    "рециклинг": ["ресайклинг"],
    "рециклировав": ["рециклировавши"],
    "рециклировавши": ["рециклировав"],
    "рециклирование": ["переработка"],
    "реципиент": ["получатель", "адресат"],
    "реципиентка": ["получательница"],
    "реципировав": ["реципировавши"],
    "реципировавши": ["реципировав"],
    "реципрокность": ["взаимность", "реципрокация"],
    "реципрокный": ["реципрокальный"],
    "рециркулировав": ["рециркулировавши"],
    "рециркулировавши": ["рециркулировав"],
    "рециркулировать": ["рециклировать"],
    "рецитировав": ["рецитировавши"],
    "рецитировавши": ["рецитировав"],
    "рецитировать": ["декламировать"],
    "речевой аппарат": ["артикуляционный аппарат"],
    "речел": ["рахиль", "ракель"],
    "речение": ["реченье", "изречение", "произношение", "выговор", "говор", "прононс", "акцент"],
    "реченье": ["речение", "изречение"],
    "реченька": ["речушка"],
    "речисто": ["красноречиво"],
    "речистый": ["красноречивый", "словоохотливый", "разговорчивый", "болтливый", "говорливый"],
    "речитатив": ["музыкальная декламация"],
    "речка": ["речушка"],
    "речной": ["флювиальный"],
    "речовина": ["сполука"],
    "речовка": ["речёвка", "кричалка"],
    "речонка": ["речушка"],
    "речушка": ["речка", "ручей"],
    "речь посполитая": ["польша"],
    "речёвка": ["речовка", "кричалка"],
    "решав": ["решавши"],
    "решавши": ["решав"],
    "решала": ["решало", "решальщик"],
    "решать": ["определять"],
    "решение": ["поиск", "выяснение", "разрешение", "постановление", "ответ", "разгадка", "выбор", "идея"],
    "решенье": ["решение"],
    "решетив": ["решетивши"],
    "решетивши": ["решетив"],
    "решетник": ["решетина"],
    "решетников": ["ситников"],
    "решето": ["сито"],
    "решив": ["решивши"],
    "решивши": ["решив"],
    "решимость": ["решительность"],
    "решительно": ["твёрдо", "смело", "вовсе", "категорически", "совершенно", "конечно", "окончательно", "бесповоротно"],
    "решительный": ["твёрдый", "крайний", "энергичный", "жёсткий", "окончательный", "определённый", "категорический", "решающий", "несомненный", "явный"],
    "решить": ["найти решение", "разрешить", "подумать", "заключить"],
    "решка": ["решётка"],
    "решённый": ["урегулированный", "определённый", "окончательный"],
    "решётка": ["аверс", "октоторп", "хеш", "диез", "шарп", "гарда"],
    "решётчатый руль": ["решётчатое крыло"],
    "рещи": ["изрекать", "изречь", "говорить", "сказать", "возвещать", "возвестить", "возглашать", "возгласить"],
    "реэвакуировав": ["реэвакуировавши"],
    "реэвакуировавши": ["реэвакуировав"],
    "реэкспортировав": ["реэкспортировавши"],
    "реэкспортировавши": ["реэкспортировав"],
    "реэкстрагировав": ["реэкстрагировавши"],
    "реэкстрагировавши": ["реэкстрагировав"],
    "реэмигрировав": ["реэмигрировавши"],
    "реэмигрировавши": ["реэмигрировав"],
    "реющий": ["летающий", "парящий", "витающий"],
    "рея": ["ре"],
    "реяв": ["реявши"],
    "реявши": ["реяв"],
    "реяние": ["трепыхание", "плескание", "развевание", "парение", "висение"],
    "реянье": ["реяние"],
    "реять": ["парить", "колебаться", "развеваться", "витать"],
    "ржа": ["ржавчина", "аржа", "иржа"],
    "ржав": ["ржавши"],
    "ржавев": ["ржавевши"],
    "ржавевши": ["ржавев"],
    "ржавение": ["ржавление", "ржавенье"],
    "ржавив": ["ржавивши"],
    "ржавивши": ["ржавив"],
    "ржавление": ["ржа"],
    "ржаво-жёлтый": ["жёлто-ржавый"],
    "ржавши": ["ржав"],
    "ржавый пояс": ["фабричный пояс"],
    "ржавь": ["ржавчина"],
    "ржака": ["ржак", "ржач", "ржачка"],
    "ржанец": ["спорынья"],
    "ржание": ["ржанье", "хохот", "гогот"],
    "ржаница": ["ржица", "полудница"],
    "ржанье": ["ржание"],
    "ржать": ["гоготать", "хохотать"],
    "ржать как лошадь": ["хохотать как безумный", "хохотать как сумасшедший"],
    "ржач": ["ржак", "ржака", "ржачка"],
    "ржачный": ["смешной", "смехотворный", "потешный", "забавный"],
    "ржица": ["ржаница"],
    "ржу не могу": ["лол"],
    "ржунимагу": ["лол"],
    "ри": ["ли"],
    "риа": ["апн"],
    "риал": ["риял"],
    "рибонуклеаза": ["рнк-аза"],
    "рибонуклеиновая кислота": ["рнк"],
    "рибосомная рибонуклеиновая кислота": ["ррнк", "рибосомная рнк"],
    "рибофлавин": ["лактофлавин"],
    "рибулозобисфосфаткарбоксилаза": ["рубиско"],
    "рибуша": ["ремок", "шобол", "шобан"],
    "ривализировав": ["ривализировавши"],
    "ривализировавши": ["ривализировав"],
    "ривоят": ["достон"],
    "рига": ["столица советской прибалтики"],
    "ригель": ["балка", "засов", "задвижка", "оправка"],
    "ригидность": ["инертность"],
    "ригидный": ["оцепенелый", "твёрдый"],
    "ригоризм": ["ригористичность", "строгость"],
    "ригористический": ["ригористичный", "суровый", "непреклонный", "бескомпромиссный"],
    "ригористичный": ["ригористический", "строгий", "суровый", "непреклонный", "бескомпромиссный"],
    "ридикюль": ["радикюль", "клатч"],
    "ридо": ["миътаф"],
    "риелтер": ["риэлтер", "риэлтор", "риелтор"],
    "риелтерский": ["маклерский"],
    "рижий": ["рудий"],
    "рижобородий": ["рудобородий"],
    "риза": ["фелонь"],
    "ризик": ["риск"],
    "ризк": ["пропитание", "хлеб насущный"],
    "ризка": ["окладик"],
    "ризница": ["ризохранилище"],
    "ризограф": ["дупликатор", "копипринтер"],
    "ризодерма": ["эпиблема"],
    "ризони": ["орзо"],
    "ризопод": ["корненожка"],
    "ризотто": ["ризот"],
    "ризохранилище": ["ризница"],
    "рикамбент": ["лигерад"],
    "рикошетив": ["рикошетивши"],
    "рикошетивши": ["рикошетив"],
    "рикошетировав": ["рикошетировавши"],
    "рикошетировавши": ["рикошетировав"],
    "рикошетировать": ["отскакивать", "отскочить", "рикошетить", "срикошетить"],
    "рикошетирующий": ["рикошетящий"],
    "рикошетом": ["отскок", "отбой"],
    "рикошетящий": ["рикошетирующий"],
    "риксдаг": ["ригсдаг"],
    "рилевание": ["рилёвка", "биговка", "бигование"],
    "рилизинг-гормон": ["либерин", "статин", "рилизинг-фактор"],
    "рилин": ["реелин"],
    "рим": ["васах"],
    "ример": ["фаскосниматель"],
    "римминг": ["анилингус"],
    "римская империя": ["рим"],
    "римский кориандр": ["чёрный тмин", "чернушка посевная", "нигелла"],
    "римский огурец": ["клюква", "развесистая клюква", "арапа заправлять", "высасывать из пальца", "лапшу на уши вешать", "пускать пыль в глаза", "пудрить мозги", "втирать очки", "водить за нос", "компостировать мозги"],
    "рингав": ["рингавши"],
    "рингавши": ["рингав"],
    "ринганув": ["ринганувши"],
    "ринганувши": ["ринганув"],
    "ринггит": ["рингит"],
    "рингит": ["ринггит"],
    "ринглиш": ["рунглиш"],
    "ринит": ["насморк"],
    "ринк": ["каток", "скетинг-ринк"],
    "ринкбол": ["ринк-бенди"],
    "риноскоп": ["назоскоп"],
    "ринув": ["ринувши"],
    "ринувши": ["ринув"],
    "ринуть": ["кинуть"],
    "рио": ["рио-де-жанейро"],
    "рио-де-бодайбо": ["бодайбо"],
    "рио-де-жанейро": ["рио"],
    "риолит": ["липарит"],
    "рипост": ["ответный", "удар", "ответ", "реплика"],
    "рипс": ["репс"],
    "рипус": ["репус"],
    "рис": ["сарацинское пшено", "сарачинское пшено", "салтык"],
    "риск": ["рискованность", "математическое ожидание"],
    "риск-менеджмент": ["управление рисками"],
    "риск-профиль": ["инвестпрофиль"],
    "риска": ["чёрточка", "каёмочка"],
    "рискаль": ["заступ", "лопата"],
    "рискнув": ["рискнувши"],
    "рискнувши": ["рискнув"],
    "рисковав": ["рисковавши"],
    "рисковавши": ["рисковав"],
    "рискованно": ["рисково", "небезопасно"],
    "рискователь": ["смельчак", "сорви-голова", "авантюрист"],
    "рисковать": ["идти на риск"],
    "рисковый": ["рискованный", "отчаянный", "авантюрный"],
    "рисовав": ["рисовавши"],
    "рисовавши": ["рисовав"],
    "рисовальщик": ["график"],
    "рисование": ["рисованье", "рисунок"],
    "рисовать": ["чертить", "черкать", "зарисовывать", "писать", "малевать", "воображать"],
    "рисоваться": ["вырисовываться", "виднеться", "представляться", "видеться"],
    "рисовая каша": ["рис", "рисовый пудинг"],
    "рисоочистительный": ["рисообдирочный"],
    "ристав": ["риставши"],
    "риставши": ["ристав"],
    "ристалище": ["ипподром", "поприще", "скачки", "ристание", "прение", "полемика"],
    "ристанье": ["ристание"],
    "ристатель": ["состязатель"],
    "ристать": ["скакать"],
    "ристретто": ["шранк", "литерэлли", "шот"],
    "рисувати": ["малювати"],
    "ритидом": ["корка"],
    "ритидэктомия": ["лифтинг", "подтяжка"],
    "ритм": ["такт", "пульс", "размер"],
    "ритм-н-блюз": ["ритм-энд-блюз"],
    "ритм-н-блюзовый": ["ритм-энд-блюзовый"],
    "ритм-энд-блюз": ["ритм-н-блюз"],
    "ритм-энд-блюзовый": ["ритм-н-блюзовый"],
    "ритмизировав": ["ритмизировавши"],
    "ритмизировавши": ["ритмизировав"],
    "ритмизировать": ["ритмизовать"],
    "ритмизовав": ["ритмизовавши"],
    "ритмизовавши": ["ритмизовав"],
    "ритмизовать": ["ритмизировать"],
    "ритмическая гимнастика": ["аэробика"],
    "ритмический": ["ритмовый", "ритмичный", "равномерный"],
    "ритмичный": ["размеренный"],
    "ритмовав": ["ритмовавши"],
    "ритмовавши": ["ритмовав"],
    "ритор": ["ответственный"],
    "риторизм": ["краснобайство", "фразёрство"],
    "риторика": ["фразёрство", "пустословие"],
    "риторическая фигура": ["фигура риторическая", "фигура стилистическая"],
    "риторический": ["фразистый", "напыщенный", "велеречивый", "надутый", "высокопарный", "пышный", "стилистический"],
    "риторствовав": ["риторствовавши"],
    "риторствовавши": ["риторствовав"],
    "риттбергер": ["прыжок петлёй"],
    "ритуал": ["обряд", "церемониал"],
    "ритуально": ["церемониально"],
    "ритурнель": ["риторнелло"],
    "рифив": ["рифивши"],
    "рифивши": ["рифив"],
    "рифить": ["брать риф", "зарифливать", "рифить парус"],
    "рифлевать": ["рифлить"],
    "рифлив": ["рифливши"],
    "рифливши": ["рифлив"],
    "рифлить": ["рифлевать"],
    "рифмач": ["рифмоплёт"],
    "рифмовав": ["рифмовавши"],
    "рифмовавши": ["рифмовав"],
    "рифмовка": ["рифмование"],
    "рифмовник": ["рифмарь", "рифменник"],
    "рифмоплёт": ["виршеплёт", "поэтишка", "стихоплёт", "версификатор"],
    "рифмоплётство": ["рифмачество", "версификация", "стихоплётство", "виршеплётство"],
    "рихтовав": ["рихтовавши"],
    "рихтовавши": ["рихтовав"],
    "рихтование": ["рихтовка"],
    "рихтовка": ["рихтование"],
    "рихтовочный": ["рихтовальный"],
    "ришат": ["риша"],
    "ришта": ["дракункулёз"],
    "риштарошак": ["ришгирак"],
    "риштовання": ["риштування"],
    "риштування": ["риштовання"],
    "риэлтер": ["риелтер", "риэлтор", "риелтор"],
    "риэлтерский": ["риелтерский", "риэлторский", "риелторский"],
    "риэлторский": ["риелторский"],
    "ркка": ["рабоче-крестьянская красная армия", "красная армия"],
    "ркн": ["ракета космического назначения", "ракета-носитель", "роскомнадзор"],
    "рксм": ["влксм"],
    "рнк": ["рибонуклеиновая кислота"],
    "ро": ["но"],
    "робас": ["рувас"],
    "робастный": ["устойчивый", "выбросоустойчивый"],
    "робев": ["робевши"],
    "робевши": ["робев"],
    "робеть": ["бояться", "пугаться", "страшиться", "опасаться", "трусить", "дрейфить", "трепетать", "дрожать", "трястись", "теряться"],
    "робив": ["робивши"],
    "робивши": ["робив"],
    "робинзон": ["отшельник"],
    "робинзонадный": ["приключенческий", "коллизийный"],
    "робить": ["работать"],
    "робия": ["робство", "робуване"],
    "робкий": ["нерешительный", "несмелый", "боязливый", "трусливый", "застенчивый"],
    "робко": ["боязливо", "трусливо", "застенчиво", "нерешительно"],
    "робость": ["боязливость"],
    "робот": ["бот", "роботизированная коробка передач"],
    "роботехника": ["робототехника"],
    "роботизировав": ["роботизировавши"],
    "роботизировавши": ["роботизировав"],
    "роботизировать": ["автоматизировать"],
    "роботик": ["робот"],
    "роботообразный": ["роботоподобный"],
    "роботоподобный": ["роботообразный"],
    "робототехника": ["роботехника"],
    "роботофобия": ["робофобия"],
    "робофобия": ["роботофобия"],
    "робя": ["работая"],
    "робята": ["парень", "ребята", "дети", "мальчик", "ребятки"],
    "ров": ["канава", "траншея"],
    "ровер": ["внедорожник"],
    "ровесник": ["сверстник", "одногодок", "однолеток"],
    "ровесница": ["один", "возраст", "сверстница"],
    "ровненская область": ["ровненщина"],
    "ровненько": ["ровнёхонько"],
    "ровно": ["гладко", "точно"],
    "ровный": ["гладкий", "плоский", "размеренный", "спокойный"],
    "ровным счётом": ["совершенно", "абсолютно", "совсем", "ровно"],
    "ровняв": ["ровнявши"],
    "ровнявши": ["ровняв"],
    "ровнять": ["выравнивать"],
    "ровнёхонько": ["ровнёшенько"],
    "рога и копыта": ["шарашкина контора", "фирма-однодневка"],
    "рогалик": ["рожок"],
    "рогань": ["большая рогань", "южные пятихатки"],
    "рогатев": ["рогатевши"],
    "рогатевши": ["рогатев"],
    "рогатив": ["рогативши"],
    "рогативши": ["рогатив"],
    "рогатый": ["рогастый", "дьявол", "сатана", "чёрт", "бес", "демон", "падший ангел", "нечисть", "шайтан", "лукавый", "окаянный"],
    "рогейн": ["рогейнинг"],
    "роглайк": ["рогалик"],
    "роговая музыка": ["роговой оркестр"],
    "роговев": ["роговевши"],
    "роговевши": ["роговев"],
    "роговик": ["роговой камень", "шмакфук"],
    "роговица": ["роговая оболочка"],
    "рогожа": ["рогоза", "рогозина", "рогожка"],
    "рогоз": ["куга", "ситник", "чакан", "рагоз", "рагоза", "рогоза"],
    "рогоза": ["рогоз"],
    "рогозуб": ["баррамунда"],
    "рогоносец": ["куколд", "олень"],
    "рогоношество": ["рогоношение"],
    "рогуль": ["селюк"],
    "рогуля": ["рогулина"],
    "родак": ["родитель"],
    "родан": ["рона"],
    "роданид": ["тиоцианат", "тиоцианид", "сульфоцианид"],
    "роддом": ["родильный дом", "родильная", "родилка"],
    "родезиец": ["зимбабвиец", "родезийский риджбек"],
    "родезия": ["республика родезия"],
    "роден език": ["майчин език"],
    "родив": ["родивши"],
    "родивши": ["родив"],
    "родившийся": ["рождённый"],
    "родилка": ["роддом"],
    "родильница": ["роженица"],
    "родильный": ["натальный", "перинатальный"],
    "родименький": ["родимый", "родненький", "родной"],
    "родиминка": ["родинка", "родимое пятно", "невус"],
    "родимый": ["родной", "дорогой", "любимый", "беленькая", "водочка"],
    "родина": ["отчизна", "отечество", "родной", "страна", "колыбель"],
    "родина ильича": ["ульяновск", "симбирск", "синбирск"],
    "родина китов и самолётов": ["хабаровский край", "хк"],
    "родина-мать": ["родина"],
    "родинка": ["родимое пятно", "невус", "родиминка"],
    "родины": ["разрешение от бремени", "день рождения"],
    "родион": ["родивон"],
    "родитель": ["отец"],
    "родительница": ["мать"],
    "родительный": ["генитив", "родительный падеж"],
    "родительный падеж": ["генитив"],
    "родить": ["разрешиться от бремени"],
    "родиться": ["появиться на свет", "возникнуть", "появиться", "уродиться"],
    "родиться в рубашке": ["родиться в сорочке", "родиться в счастливой рубашке"],
    "родиться в сорочке": ["родиться в рубашке", "родиться под счастливой звездой"],
    "родиться под счастливой звездой": ["родиться в сорочке"],
    "роднив": ["роднивши"],
    "роднивши": ["роднив"],
    "родник": ["источник", "ключ"],
    "роднина": ["родственик"],
    "родничок": ["источник"],
    "родноверие": ["родоверие", "родолюбие", "родобожие"],
    "родной": ["родственный", "родимый", "близкий", "родственник"],
    "родной язык": ["родная речь"],
    "роднуля": ["родимый", "родненький"],
    "родные": ["близкие", "родственники"],
    "родный": ["родной", "рождённый"],
    "родня": ["родственники", "семья", "родные", "сродник", "сродница", "сродственник", "сродственница", "плоть от плоти", "родич", "родной", "родственник", "родственница"],
    "родо-племенной": ["родоплеменной"],
    "родовитость": ["знатность"],
    "родовитый": ["благородный", "аристократический", "знатный", "степенный"],
    "родовой дворянин": ["столбовой дворянин"],
    "родовой знак": ["тамга"],
    "родовой строй": ["первобытно-общинный строй", "первобытное общество", "общинно-родовой строй"],
    "родовспомогательный": ["акушерский"],
    "рододендровый": ["рододендроновый"],
    "рододендрон": ["рододендр", "индийская азалия"],
    "родоначальник": ["предок"],
    "родонит": ["орлец"],
    "родопсин": ["зрительный пурпур"],
    "родос": ["богат", "мэнос", "плодник", "родитор", "ынбелшугат", "ынфлоритор", "копт", "ынродит"],
    "родословец": ["родословная книга"],
    "родословие": ["родословная", "родословное дерево", "родословец", "генеалогия", "преемственность", "преемство"],
    "родословная": ["генеалогическое древо"],
    "родословный": ["генеалогический", "родовитый"],
    "родословье": ["родословие"],
    "родригес": ["родригеш"],
    "родственник": ["родич", "сородич", "родня", "родной", "кровник", "сродственник", "сродник"],
    "родственный": ["кровный", "семейный", "семейственный"],
    "роды": ["разрешение от бремени", "рождение"],
    "родясь": ["отроду", "отродясь"],
    "роевня": ["роёвня"],
    "роевой": ["ройный", "роистый"],
    "роенье": ["роение"],
    "рожав": ["рожавши"],
    "рожавши": ["рожав"],
    "рожай": ["сосновка"],
    "рожалка": ["родилка", "женская репродуктивная система", "роддом"],
    "рожать": ["рождать", "разрешаться от бремени"],
    "рождав": ["рождавши"],
    "рождавши": ["рождав"],
    "рождать": ["рожать", "производить на свет", "порождать"],
    "рождаться": ["нарождаться"],
    "рождение": ["роды", "разрешение от бремени", "появление на свет", "день рождения", "возникновение", "появление"],
    "рождественный": ["рождественский"],
    "рождественская хава": ["хава"],
    "рождество": ["рождение", "рожество"],
    "рождество христово": ["рождество"],
    "рожевий": ["вишневий", "трояндовий"],
    "роженица": ["родильница"],
    "рожество": ["рождество"],
    "рожистое воспаление": ["рожа"],
    "рожок": ["горн", "клаксон", "магазин", "обойма", "лопатка", "рогалик", "кэроб"],
    "рожон": ["пика"],
    "рожоный": ["роженый"],
    "рожь": ["жито", "озимина", "озимь"],
    "роз-": ["раз-", "рас-", "разо-"],
    "роза": ["розочка"],
    "розан": ["гибискус"],
    "розарий": ["молитва"],
    "розацеа": ["розовые угри"],
    "розбавляння": ["розбавлення", "розбавлювання"],
    "розвальни": ["сани"],
    "розга": ["батог", "шпицрутен"],
    "розгляд": ["розглядання"],
    "розголосник": ["розголошувач"],
    "роздав": ["роздавши"],
    "роздавши": ["роздав"],
    "роздовбати": ["роздовбувати"],
    "роздых": ["отдых", "передышка"],
    "розеин": ["фуксин", "диамант-фуксин", "азалеин", "рубин", "маджент"],
    "розеиновый": ["фуксиновый"],
    "розетка": ["электророзетка", "гнездо", "мама"],
    "роззява": ["лопух"],
    "розкормити": ["розгодувати"],
    "розлив": ["разлив"],
    "розлитый": ["разлитый"],
    "розмысл": ["инженер", "размышление", "ум", "умелец", "конструктор", "проектировщик"],
    "розмыть": ["розмыт"],
    "рознив": ["рознивши"],
    "рознивши": ["рознив"],
    "розничная торговля": ["розница"],
    "рознь": ["вражда", "раздор", "розь", "не чета"],
    "розовато-жёлтый": ["жёлто-розоватый", "розово-желтоватый", "розовато-желтоватый", "желтовато-розоватый", "жёлто-розовый"],
    "розоватый": ["бледно-розовый"],
    "розовев": ["розовевши"],
    "розовевши": ["розовев"],
    "розово-жёлтый": ["жёлто-розовый"],
    "розово-красно-дымчатый": ["дымчато-розово-красный"],
    "розовое золото": ["красное золото", "русское золото"],
    "розоволикий": ["розоволицый"],
    "розоволицый": ["розоволикий"],
    "розовощёкий": ["румяный", "разрумянившийся", "розоволицый", "краснощёкий", "как маков цвет", "кровь с молоком"],
    "розочка": ["роза"],
    "розпалювати": ["розпаляти"],
    "розпаляти": ["розпалювати"],
    "розповсюдник": ["розповсюджувач"],
    "розпушування": ["розпушення"],
    "розшматовувати": ["шматувати"],
    "розыгрыш лишнего": ["реализация лишнего"],
    "розыск": ["разыскивание"],
    "розыскной": ["разыскной", "сыскной", "поисковый", "поисковой"],
    "розь": ["рознь", "не чета"],
    "роив": ["роивши"],
    "роивши": ["роив"],
    "роистый": ["ройный"],
    "рой": ["стая", "вереница", "ряд"],
    "ройбуш": ["ройбос"],
    "ройгон": ["бемузд", "муфт", "бепул", "беподош"],
    "ройный": ["роевой", "роистый"],
    "рок": ["участь", "доля", "судьбина", "фатум"],
    "рок-генерация": ["рок-поколение"],
    "рок-герой": ["рок-идол", "рок-кумир"],
    "рок-группа": ["рок-коллектив", "рок-команда"],
    "рок-идол": ["рок-герой", "рок-кумир"],
    "рок-коллектив": ["рок-группа", "рок-команда"],
    "рок-команда": ["рок-группа", "рок-коллектив"],
    "рок-кумир": ["рок-герой", "рок-идол"],
    "рок-мир": ["рок-среда"],
    "рок-н-роллер": ["рок-н-ролльщик"],
    "рок-н-ролльщик": ["рок-н-роллер"],
    "рок-поколение": ["рок-генерация"],
    "рок-среда": ["рок-мир"],
    "рок-фан": ["рокер", "рокмен", "рокоман", "рок-фанат"],
    "рок-фанат": ["рокер", "рокмен", "рокоман", "рок-фан"],
    "рокабилл": ["рокабилльщик"],
    "рокабилльщик": ["рокабилл"],
    "рокада": ["объездная дорога"],
    "рокадный": ["прифронтовой", "объездной", "объезжий"],
    "рокайль": ["рококо"],
    "рокер": ["рокмен", "рокоман", "рок-фан", "рок-фанат", "байкер", "моторокер"],
    "рокировав": ["рокировавши"],
    "рокировавши": ["рокировав"],
    "рокировать": ["рокироваться", "заменять", "заменить", "переставлять", "переставить"],
    "рокироваться": ["рокировать"],
    "рокировка": ["перестановка", "переброска"],
    "рокк-н-ролл": ["рок-н-ролл"],
    "рокмен": ["рокер", "рокоман", "рок-фан", "рок-фанат"],
    "роковой": ["неотвратимый", "неизбежный", "фатальный"],
    "рококо": ["рокайль", "музыкальный рокайль"],
    "рокоман": ["рокер", "рокмен", "рок-фан", "рок-фанат"],
    "рокопопс": ["поп-рок"],
    "рокот": ["рокотание", "гул", "рёв"],
    "рокотав": ["рокотавши"],
    "рокотавши": ["рокотав"],
    "рокотанье": ["рокотание"],
    "ролевая игра": ["ролёвка", "ролевуха", "ролевушка", "ролка", "рп"],
    "ролевуха": ["ролевушка", "ролёвка"],
    "ролевушка": ["ролевая игра", "ролевуха", "ролёвка"],
    "роликовые коньки": ["ролик"],
    "ролкер": ["ро-ро"],
    "ролл": ["макидзуси", "маки"],
    "роллердром": ["роликодром"],
    "роллеродром": ["роллердром", "роликодром"],
    "роль": ["назначение", "предназначение", "функция", "миссия"],
    "рольганг": ["роликовый", "конвейер"],
    "роля": ["роль"],
    "ролёвка": ["ролевая игра", "ролевуха", "ролевушка"],
    "ром": ["ромок"],
    "ром романо": ["ром чячё"],
    "роман": ["рома"],
    "романизировав": ["романизировавши"],
    "романизировавши": ["романизировав"],
    "романизировать": ["латинизировать"],
    "романизовав": ["романизовавши"],
    "романизовавши": ["романизовав"],
    "романо кхам": ["чён", "рувано кхам", "чёрэнгро кхам"],
    "романо чяво": ["чяво"],
    "романов-на-мурмане": ["мурманск"],
    "романоязычный": ["романскоязычный"],
    "романскоязычный": ["романоязычный"],
    "романсовый": ["романсный"],
    "романтизировав": ["романтизировавши"],
    "романтизировавши": ["романтизировав"],
    "романтизм": ["романтичность"],
    "романтик": ["мечтатель", "идеалист"],
    "романтика": ["романтизм"],
    "романтически": ["романтично"],
    "романтическое влечение": ["романтическая ориентация"],
    "романтичность": ["романтизм"],
    "романтичный": ["романтический", "романический"],
    "романшский язык": ["руманшский", "швейцарский ретороманский", "граубюндер", "курваль"],
    "романыпэн": ["романо ило", "романо ди", "романо законо"],
    "ромашка аптечная": ["ромашка лекарственная", "лекарственная ромашка", "немецкая ромашка"],
    "ромб": ["ромбик"],
    "ромбовидно": ["ромбически"],
    "ромбовый": ["ромбический"],
    "ромбододекаэдр": ["гранатоэдр"],
    "ромбоид": ["параллелограмм"],
    "ромбоидальный": ["ромбоидный"],
    "ромбокубооктаэдр": ["ромбокубоктаэдр"],
    "ромей": ["румей"],
    "ромец": ["ромок", "ромчик"],
    "ромны": ["романы чяй", "чяй", "джювлы"],
    "ромок": ["ромец"],
    "ромчик": ["ромец"],
    "роналду": ["роналдинью"],
    "ронга": ["понда", "ронга-понда"],
    "ронга-понда": ["ронга"],
    "ронив": ["ронивши"],
    "ронивши": ["ронив"],
    "ронить": ["валить", "ронять"],
    "ронни": ["рональд"],
    "роня": ["ронечка", "роняша"],
    "роняв": ["ронявши"],
    "ронявши": ["роняв"],
    "ропать": ["ропата"],
    "ропот": ["роптание", "гомон"],
    "роптав": ["роптавши"],
    "роптавши": ["роптав"],
    "роптание": ["негодование", "ропот"],
    "роптанье": ["роптание"],
    "роптать": ["негодовать", "жаловаться", "сетовать", "плакаться", "ныть", "хныкать", "скулить", "бормотать"],
    "рос-": ["раз-", "рас-", "разо-"],
    "росив": ["росивши"],
    "росивши": ["росив"],
    "роскомнадзор": ["ркн", "роскомпозор", "роспозорнадзор"],
    "роскомнадзорнуться": ["выпилиться", "курткобейнуться", "самовыпилиться"],
    "роскомпозор": ["ркн", "роспозорнадзор"],
    "роскошествовав": ["роскошествовавши"],
    "роскошествовавши": ["роскошествовав"],
    "роскошничав": ["роскошничавши"],
    "роскошничавши": ["роскошничав"],
    "роскошничать": ["роскошествовать"],
    "роскошно": ["шикарно", "превосходно"],
    "роскошный": ["великолепный", "расточительный"],
    "роскошь": ["роскошество", "шик", "излишество", "расточительство"],
    "рослый": ["высокий", "длинный", "высокорослый"],
    "росомаха": ["рассомаха"],
    "роспуск": ["распускание", "расформирование"],
    "росрегистрация": ["росреестр"],
    "росреестр": ["росрегистрация", "егрн"],
    "россиеведение": ["отечествоведение"],
    "россиец": ["россиянин"],
    "российская империя": ["россия"],
    "российская сфср": ["рсфср"],
    "российская федерация": ["россия", "рф", "рсфср", "советская россия"],
    "российский": ["русский"],
    "российско-австралийский": ["австралийско-российский"],
    "российско-азербайджанский": ["азербайджано-российский"],
    "российско-албанский": ["албано-российский"],
    "российско-американский": ["американо-российский"],
    "российско-армянский": ["армяно-российский"],
    "российско-белорусский": ["белорусско-российский"],
    "российско-болгарский": ["болгаро-российский"],
    "российско-вьетнамский": ["вьетнамско-российский"],
    "российско-германский": ["германо-российский"],
    "российско-грузинский": ["грузино-российский"],
    "российско-донецкий": ["донецко-российский"],
    "российско-израильский": ["израильско-российский"],
    "российско-индийский": ["индийско-российский"],
    "российско-итальянский": ["итальяно-российский", "итальянско-российский"],
    "российско-казахский": ["казахско-российский", "казахстано-российский", "казахстанско-российский", "российско-казахстанский"],
    "российско-казахстанский": ["казахско-российский", "казахстано-российский", "казахстанско-российский", "российско-казахский"],
    "российско-канадский": ["канадско-российский"],
    "российско-киргизский": ["киргизско-российский"],
    "российско-китайский": ["китайско-российский"],
    "российско-латвийский": ["латвийско-российский"],
    "российско-луганский": ["луганско-российский"],
    "российско-молдавский": ["молдавско-российский"],
    "российско-палестинский": ["палестино-российский"],
    "российско-северомакедонский": ["российско-македонский", "македонско-российский"],
    "российско-словацкий": ["словацко-российский"],
    "российско-советский": ["советско-российский"],
    "российско-таджикский": ["таджикско-российский"],
    "российско-турецкий": ["турецко-российский"],
    "российско-туркменский": ["туркменско-российский"],
    "российско-узбекский": ["узбекско-российский"],
    "российско-украинский": ["украинско-российский", "украино-российский"],
    "российско-чеченский": ["чеченско-российский"],
    "российско-чешский": ["чешско-российский"],
    "российско-югославский": ["югославско-российский"],
    "российско-японский": ["японско-российский", "японо-российский"],
    "российское царство": ["россия"],
    "россиюшка": ["россия", "русь", "российская федерация", "рф", "рашка", "эрэфия"],
    "россия": ["российская федерация", "рф", "россиюшка", "россияне"],
    "россказни": ["небылица", "выдумка", "измышление"],
    "росстань": ["перекрёсток", "перепутье"],
    "россыпью": ["вразброд", "разбродно", "вольницей", "молем"],
    "рост": ["развитие", "удлинение", "повышение", "увеличение", "высота", "процент"],
    "ростанка": ["руднячка"],
    "ростбиф": ["розбиф"],
    "ростепель": ["оттепель"],
    "ростер": ["гриль"],
    "ростерит": ["берилл", "воробьевит"],
    "ростив": ["ростивши"],
    "ростивши": ["ростив"],
    "ростов": ["ростов великий"],
    "ростов-на-дону": ["ростов-папа", "столица дона", "южная столица"],
    "ростовка": ["ростовчанка"],
    "ростовчанин": ["ростовец"],
    "ростовщик": ["процентщик", "финансист"],
    "ростовщица": ["процентщица"],
    "ростовщический": ["ростовщичий"],
    "ростовщичий": ["ростовщический"],
    "ростопель": ["ростепель", "оттепель"],
    "росточек": ["росток", "рост"],
    "ростральный": ["капитальный", "краниальный"],
    "рот": ["уста", "губы", "пасть", "зев", "едок", "едун", "жрун"],
    "ротамер": ["конформер"],
    "ротаплан": ["автожир", "гирокоптер", "гироплан"],
    "ротари-движение": ["ротарианство"],
    "ротарианство": ["ротари-движение"],
    "ротатор": ["мимеограф"],
    "ротацизм": ["параротацизм"],
    "ротационная машина": ["ротационка"],
    "ротация": ["чередование", "смена"],
    "ротвейлер": ["ротвик"],
    "ротик": ["роток"],
    "ротировав": ["ротировавши"],
    "ротировавши": ["ротировав"],
    "ротище": ["ртище"],
    "ротоглотка": ["мезофаринкс"],
    "ротозев": ["ротозевши"],
    "ротозевши": ["ротозев"],
    "ротозеив": ["ротозеивши"],
    "ротозеивши": ["ротозеив"],
    "ротозей": ["зевака", "разиня"],
    "ротозейничав": ["ротозейничавши"],
    "ротозейничавши": ["ротозейничав"],
    "ротозействовав": ["ротозействовавши"],
    "ротозействовавши": ["ротозействовав"],
    "ротор": ["вихрь"],
    "роторный траншеекопатель": ["роторный экскаватор"],
    "ротоскопирование": ["фотоперекладка", "ротоскопинг"],
    "роуд-менеджер": ["роуди"],
    "роуп-джампинг": ["роуп"],
    "роутер": ["маршрутизатор", "рутер"],
    "рофлив": ["рофливши"],
    "рофливши": ["рофлив"],
    "рофлить": ["смеяться", "веселиться", "шутить"],
    "рохинджа": ["рохинья"],
    "рохинья": ["рохинджа"],
    "рохля": ["губошлеп", "размазня", "шляпа", "телепень", "тюфяк", "мямля"],
    "рочму федерация": ["россия федерация", "рочму"],
    "рош ха-шана": ["еврейский новый год"],
    "роща": ["лесок"],
    "рощица": ["лесок", "лесочек"],
    "роэ": ["соэ"],
    "роялти": ["ройялти", "отчисление"],
    "рпа": ["вгую"],
    "рпуд": ["рпд"],
    "рпц": ["русская православная церковь", "московский патриархат", "мп", "рпц мп"],
    "рст": ["рата"],
    "ртище": ["ротище"],
    "ртом и жопой хавать": ["хавать ртом и жопой"],
    "ртутив": ["ртутивши"],
    "ртутивши": ["ртутив"],
    "ртуть": ["меркурий", "живое серебро", "живой металл"],
    "руанда": ["киньяруанда"],
    "рубав": ["рубавши"],
    "рубавши": ["рубав"],
    "рубанець": ["цурпалок"],
    "рубанок": ["струг", "электрорубанок", "электрический рубанок"],
    "рубанув": ["рубанувши"],
    "рубанувши": ["рубанув"],
    "рубать": ["рубить", "наворачивать", "уплетать"],
    "рубаха": ["рубашка", "сорочка"],
    "рубаха-парень": ["рубаха", "рубашка", "парень-рубаха", "рубашка-парень", "человек-рубаха", "человек-рубашка"],
    "рубашечка": ["рубашка", "сорочечка"],
    "рубашонка": ["рубашка"],
    "рубеж": ["граница", "предел", "веха", "этап", "линия"],
    "рубеллит": ["красный турмалин", "малиновый шерл", "апирит", "даурит", "сибирит"],
    "рубероид": ["пергамин", "толь"],
    "рубец": ["шрам", "зарубка"],
    "рубив": ["рубивши"],
    "рубивши": ["рубив"],
    "рубилово": ["замес", "месилово", "мочилово"],
    "рубильный": ["рубительный"],
    "рубильщик": ["рубитель", "рубщик"],
    "рубин": ["лал"],
    "рубиновая слюдка": ["гидрогётит", "лепидокрокит", "пирросидерит"],
    "рубиновый": ["лаловый"],
    "рубитель": ["рубильщик", "рубщик"],
    "рубить": ["рассекать", "отсекать", "шинковать"],
    "рубить капусту": ["варить капусту", "окучивать капусту", "много", "стричь капусту"],
    "рубить сплеча": ["резать правду-матку"],
    "рубиться": ["сечься", "играть"],
    "рубище": ["вретище", "лохмотья", "гуна", "обносок", "отрепье", "рваньё"],
    "рубленый": ["бревенчатый"],
    "рублис": ["репшик"],
    "рублишко": ["рубль", "рублик", "рубличек", "рубчик", "рупчик", "рублёвка", "рупь", "деревянный", "рваный", "наркорубль", "нефтерубль", "рэ", "целковый", "рублёвик", "целкач"],
    "рубль": ["рублёвик", "рублёвка", "рубель", "рупь", "рваный", "деревянный", "резаная бумага", "рубас", "хруст", "копейка", "лепта", "тыр", "килорубль"],
    "рублёвик": ["рублёвка"],
    "рублёвка": ["рублёвик"],
    "рубнув": ["рубнувши"],
    "рубнувши": ["рубнув"],
    "рубнуть": ["рубануть"],
    "рубоп": ["руоп"],
    "рубрикация": ["рубрицирование", "классификация"],
    "рубрицировав": ["рубрицировавши"],
    "рубрицировавши": ["рубрицировав"],
    "руброфития": ["рубромикоз", "руброфитоз"],
    "рубцевав": ["рубцевавши"],
    "рубцевавши": ["рубцевав"],
    "рубцевать": ["рассекать", "зарубцовывать"],
    "рубцеваться": ["затягиваться", "зарубцовываться"],
    "рубщик": ["рубильщик", "рубитель"],
    "рубёж": ["рубка"],
    "рувас": ["робас"],
    "ругав": ["ругавши"],
    "ругавши": ["ругав"],
    "ругань": ["брань", "ругня", "руготня"],
    "руганье": ["ругание"],
    "ругательный": ["хулительный", "бранный"],
    "ругательство": ["брань"],
    "ругать": ["бранить", "взгревать", "выговаривать", "журить", "клясть", "корить", "костерить", "обзывать", "облаивать", "обругивать", "обхаивать", "песочить", "поносить", "поругивать", "пропесочивать"],
    "ругаться": ["браниться", "нецензурно выражаться", "ссориться", "упрекать", "ругать"],
    "ругачка": ["ссора", "брань", "ругань"],
    "ругивав": ["ругивавши"],
    "ругивавши": ["ругивав"],
    "ругнув": ["ругнувши"],
    "ругнувши": ["ругнув"],
    "ругня": ["руготня", "брань"],
    "руготня": ["ругань", "брань", "ругня"],
    "рудбекия": ["золотой шар"],
    "руди": ["рудольф"],
    "рудий": ["рижий"],
    "рудимент": ["пережиток"],
    "рудиментарный": ["недоразвитый"],
    "рудист": ["гиппурит"],
    "рудник": ["копь"],
    "рудо-жёлтый": ["оранжевый", "красновато-жёлтый"],
    "рудобородий": ["рижобородий"],
    "рудогенез": ["рудогенезис"],
    "рудокопский": ["шахтерский", "рудокопный", "горняцкий"],
    "рудопромывочный": ["рудопромывальный"],
    "рудстойка": ["пропс"],
    "рудый": ["красный", "рыжий"],
    "ружбайка": ["пушка", "пестик"],
    "ружейничав": ["ружейничавши"],
    "ружейничавши": ["ружейничав"],
    "ружьишко": ["ружьё", "ружьище", "ружьецо", "ружьишечко"],
    "ружьё": ["ружжо"],
    "рузгяр": ["йэль"],
    "рузонь кель": ["рузонь"],
    "руина": ["развалина", "обломок", "останки", "инвалид"],
    "руинизация": ["распад", "руинирование"],
    "руинизировать": ["руинировать"],
    "руинировав": ["руинировавши"],
    "руинировавши": ["руинировав"],
    "руинирование": ["распад", "руинизация"],
    "руинировать": ["руинизировать", "руинизироваться", "руинироваться", "прийти в упадок", "приходить в упадок"],
    "рука": ["кисть", "длань", "протез", "манипулятор", "почерк"],
    "рука об руку": ["рука в руку"],
    "рукав": ["шланг", "трубка", "труба", "полоса"],
    "рукавица": ["варежка"],
    "рукавичка": ["рукавица", "варежка"],
    "рукавичник": ["перчаточник"],
    "рукавичный": ["варежечный"],
    "рукалицо": ["фейспалм", "рука-лицо"],
    "руками": ["вручную", "ручками"],
    "рукастый": ["большерукий", "длиннорукий", "толсторукий", "умелый", "мастеровитый", "ловкий", "сноровистый", "золотые руки", "деловой", "предприимчивый", "распорядительный", "хваткий", "хозяйственный", "вороватый"],
    "руки в брюки": ["ручки в брючки", "руки в карман", "руки в укладке"],
    "руки чешутся": ["так и хочется"],
    "рукоблуд": ["рукоблудец"],
    "рукоблудница": ["онанистка"],
    "рукоблудничав": ["рукоблудничавши"],
    "рукоблудничавши": ["рукоблудничав"],
    "рукоблудство": ["рукоблудие", "онанизм", "мастурбация"],
    "рукоборец": ["армрестлер"],
    "рукоборье": ["армрестлинг", "армспорт"],
    "руководив": ["руководивши"],
    "руководивши": ["руководив"],
    "руководимый": ["управляемый"],
    "руководитель": ["начальник", "командир", "глава", "лидер", "главный"],
    "руководительница": ["глава", "начальница"],
    "руководительствовав": ["руководительствовавши"],
    "руководительствовавши": ["руководительствовав"],
    "руководить": ["возглавлять", "главенствовать", "командовать", "начальствовать", "управлять"],
    "руководство": ["управление", "начальствование", "установка", "наставление", "пособие", "начальство"],
    "руководствовав": ["руководствовавши"],
    "руководствовавши": ["руководствовав"],
    "руководствоваться": ["опираться"],
    "рукоделье": ["рукоделие"],
    "рукодельник": ["рукодел", "рукоделец", "умелец"],
    "рукодельница": ["мастерица"],
    "рукодельничав": ["рукодельничавши"],
    "рукодельничавши": ["рукодельничав"],
    "рукожоп": ["жопорук"],
    "рукожопость": ["жопорукость"],
    "рукожопство": ["криворукость", "неумелость"],
    "рукожопый": ["неумелый", "неловкий", "криворукий", "косорукий", "жопорукий", "некачественный"],
    "рукола": ["гусеничник посевной", "индау посевной"],
    "рукомесло": ["промысел", "мастерство", "ремесло"],
    "рукомойка": ["рукомойник", "умывальник"],
    "рукомойник": ["умывальник"],
    "руконожка": ["айе-айе"],
    "рукопашка": ["рукопашный бой", "рукопашная"],
    "рукопашная": ["рукопашный бой", "рукопашка"],
    "рукопашник": ["милишник", "ближник"],
    "рукопашный бой": ["рукопашная", "рукопашка", "ближний бой"],
    "рукопис": ["манускрипт"],
    "рукописанье": ["рукописание"],
    "рукопись": ["манускрипт"],
    "рукоплескав": ["рукоплескавши"],
    "рукоплескавши": ["рукоплескав"],
    "рукоплескание": ["аплодисменты", "рукоплескания"],
    "рукоплесканье": ["рукоплескание"],
    "рукоплескать": ["аплодировать", "хлопать"],
    "рукопожатие": ["рукопожатье", "рукожатие"],
    "рукопожатый": ["рукопожатный", "рукоподаваемый", "порядочный", "приличный", "свой"],
    "рукопожатье": ["рукопожатие"],
    "рукополагав": ["рукополагавши"],
    "рукополагавши": ["рукополагав"],
    "рукоположение": ["хиротония"],
    "рукоположенье": ["рукоположение"],
    "рукоположив": ["рукоположивши"],
    "рукоположивши": ["рукоположив"],
    "рукоположить": ["посвятить"],
    "рукоположённый": ["поставленный", "хиротонисанный", "возведённый", "сан"],
    "рукоприкладство": ["побои", "подпись"],
    "рукоприкладствовав": ["рукоприкладствовавши"],
    "рукоприкладствовавши": ["рукоприкладствовав"],
    "рукотворный": ["искусственный"],
    "рукоятка": ["рукоять", "ручка", "хватка", "руковятка", "руковять", "древко", "рычаг", "стяг", "черен"],
    "рукоять": ["рукоятка"],
    "рулада": ["трель"],
    "рулевое колесо": ["руль"],
    "рулез": ["крутизна", "крутость"],
    "руление": ["вождение", "рулёжка"],
    "рулетта": ["циклоида"],
    "рулив": ["руливши"],
    "руливав": ["руливавши"],
    "руливавши": ["руливав"],
    "руливши": ["рулив"],
    "рулить": ["управлять", "вести", "катиться", "ехать", "руководить", "командовать", "распоряжаться", "править", "повелевать", "заправлять"],
    "руль": ["баранка", "правило"],
    "рулёжка": ["руление"],
    "рум": ["рим", "византия"],
    "рум гун": ["эцягъун"],
    "руммон": ["анор"],
    "румский султанат": ["конийский султанат", "сельджукский рум"],
    "румыния": ["соединённые княжества молдавии и валахии", "королевство румыния", "румынская народная республика", "рнр", "социалистическая республика румыния", "срр"],
    "румынский": ["румынский язык"],
    "румынский язык": ["румынский"],
    "румянев": ["румяневши"],
    "румяневши": ["румянев"],
    "румянец": ["краска"],
    "румянив": ["румянивши"],
    "румянивши": ["румянив"],
    "румянолицый": ["румяноликий", "розоволицый", "краснолицый"],
    "румяный": ["румянощёкий", "краснощёкий", "поалевший", "зардевшийся", "зарделый", "подрумянившийся"],
    "рунди": ["бурунди", "варунди", "кирунди"],
    "руниверсалис": ["руни"],
    "руно": ["шерсть", "шкура", "овчина", "косяк", "стая"],
    "рупь": ["рубль"],
    "рурализация": ["деурбанизация", "дезурбанизация"],
    "рус": ["русь"],
    "русалка": ["ундина", "мавка", "вила", "очаровательница"],
    "русе": ["рущук"],
    "русев": ["русевши"],
    "русевши": ["русев"],
    "русенлия": ["русенец"],
    "русизм": ["рашизм"],
    "русик": ["русификатор"],
    "русификатор": ["русик"],
    "русификаторство": ["русификация"],
    "русификация": ["русификаторство"],
    "русифицировав": ["русифицировавши"],
    "русифицировавши": ["русифицировав"],
    "русифицирование": ["русификация"],
    "русица": ["русичка"],
    "русич": ["росс"],
    "русичка": ["русистка", "русица"],
    "русия федерациясе": ["россия федерациясе"],
    "руслан": ["рус", "русланчик", "руся", "русик", "рустик"],
    "русло": ["ложе", "направление", "сосуд"],
    "русловой": ["русловый"],
    "русловый": ["русловой"],
    "руснак": ["русин"],
    "русоволосый": ["русоголовый", "русый"],
    "русоголовый": ["русоволосый", "русый"],
    "русоненавистник": ["русофоб"],
    "русопят": ["русак", "русский", "ватник", "ватан", "ватриот", "путриот", "москаль", "рашкован", "скрепоносец"],
    "русофильствовав": ["русофильствовавши"],
    "русофильствовавши": ["русофильствовав"],
    "русофоб": ["русоненавистник"],
    "русофобия": ["антирусизм"],
    "русофобство": ["русофобия"],
    "русофобствовав": ["русофобствовавши"],
    "русофобствовавши": ["русофобствовав"],
    "русофон": ["русскоговорящий"],
    "русс": ["росс"],
    "руссифицировав": ["руссифицировавши"],
    "руссифицировавши": ["руссифицировав"],
    "русская": ["великоруска", "великоросска", "россиянка", "кацапка", "москалька"],
    "русская освободительная армия": ["роа", "власовец"],
    "русская православная армия": ["рпа"],
    "русская православная церковь": ["рпц", "московский патриархат", "московская патриархия", "мп"],
    "русская равнина": ["восточно-европейская равнина"],
    "русский": ["российский", "русский язык", "великий и могучий", "великорус", "великоросс", "россиянин", "русак", "русич", "кацап", "москаль", "шурави", "русня"],
    "русский иван": ["русский"],
    "русский шансон": ["блатняк", "блатнятина"],
    "русский язык": ["русский"],
    "русским языком": ["чёрным по белому"],
    "русско-национальный": ["национально-русский"],
    "русскоговорящий": ["русскоязычный"],
    "русское море": ["чёрное море", "баренцево море"],
    "русское царство": ["российское царство", "русское государство", "русь", "россия"],
    "русскоязычный": ["русскоговорящий", "русский"],
    "руссьягейт": ["рашагейт", "кремлингейт"],
    "рустика": ["рустовка"],
    "рустикальный": ["деревенский", "фольклорный", "мужицкий"],
    "рустировав": ["рустировавши"],
    "рустировавши": ["рустировав"],
    "рустовав": ["рустовавши"],
    "рустовавши": ["рустовав"],
    "рустовка": ["рустование", "рустика"],
    "русый": ["русоволосый", "шатен", "блондин"],
    "русь": ["русич"],
    "рутаб": ["хурмо"],
    "рутбир": ["корневое пиво"],
    "рутвяний": ["рутовий"],
    "рутер": ["маршрутизатор", "роутер"],
    "рутин": ["рутозид"],
    "рутина": ["однообразие"],
    "рутинизировав": ["рутинизировавши"],
    "рутинизировавши": ["рутинизировав"],
    "рутинный": ["нетворческий", "однообразный", "рутинёрский", "шаблонный", "скучный", "монотонный", "утомительный", "консервативный"],
    "рутинёр": ["консерватор", "ретроград", "старого покроя"],
    "рутинёрствовав": ["рутинёрствовавши"],
    "рутинёрствовавши": ["рутинёрствовав"],
    "рутировав": ["рутировавши"],
    "рутировавши": ["рутировав"],
    "рутозид": ["рутин", "софорин"],
    "рутульский": ["рутульский язык"],
    "рутульский язык": ["рутульский"],
    "руу": ["луу"],
    "руферство": ["руфинг"],
    "руфинг": ["руферство"],
    "рухати": ["пересувати"],
    "рухлый": ["неустойчивый", "шаткий", "ветхий"],
    "рухлядь": ["старьё", "хлам", "барахло", "ветошь", "старичьё", "скарб", "пожитки"],
    "рухляк": ["мергель"],
    "рухманный": ["рахманный"],
    "рухнув": ["рухнувши"],
    "рухнувши": ["рухнув"],
    "рухнуть": ["обрушиться"],
    "рухсора": ["симо", "башара"],
    "ручав": ["ручавши"],
    "ручавши": ["ручав"],
    "ручательство": ["гарантия"],
    "ручать": ["поручаться"],
    "ручаться": ["гарантировать", "обеспечивать", "отвечать", "быть порукой", "брать на свою ответственность"],
    "ручейный": ["ручьевой"],
    "ручища": ["лапа"],
    "ручка": ["рука", "рукоятка", "рукоять", "маховик", "перо", "авторучка", "механика", "мкпп", "кочерга", "мешалка"],
    "ручками": ["вручную", "руками"],
    "ручнев": ["ручневши"],
    "ручневши": ["ручнев"],
    "ручник": ["рушник"],
    "ручной": ["рукодельный", "приручённый"],
    "ручной мяч": ["гандбол"],
    "ручной противотанковый гранатомёт": ["рпг"],
    "ручнув": ["ручнувши"],
    "ручнувши": ["ручнув"],
    "ручонка": ["ручка"],
    "ручьевой": ["ручейный"],
    "ручьёвый": ["ручейный", "ручьевой", "ручейковый"],
    "рушав": ["рушавши"],
    "рушавши": ["рушав"],
    "рушати": ["рушити"],
    "рушащий": ["разрушающий"],
    "рушенье": ["рушение"],
    "рушив": ["рушивши"],
    "рушивши": ["рушив"],
    "рушити": ["пересунути", "рухати"],
    "рушить": ["обрушивать", "разваливать"],
    "рушка": ["дробилка", "молотилка", "мельница", "сечка"],
    "рущук": ["русе"],
    "рф": ["россия", "российская федерация"],
    "ръдръ": ["рьдръ"],
    "ръкохватка": ["дръжка"],
    "рът": ["рътлина"],
    "рыба-ворон": ["формио"],
    "рыба-лоцман": ["лоцман"],
    "рыба-молот": ["молотоголовая акула"],
    "рыба-пеликан": ["пеликановидный большерот"],
    "рыба-прилипала": ["присос", "держилодья", "прилипала"],
    "рыбак": ["рыболов"],
    "рыбаковав": ["рыбаковавши"],
    "рыбаковавши": ["рыбаковав"],
    "рыбалив": ["рыбаливши"],
    "рыбаливши": ["рыбалив"],
    "рыбалить": ["рыбачить"],
    "рыбарь": ["рыбак"],
    "рыбацкий": ["рыболовецкий", "рыбачий"],
    "рыбачив": ["рыбачивши"],
    "рыбачивши": ["рыбачив"],
    "рыбачий": ["рыбацкий"],
    "рыбачить": ["рыбалить"],
    "рыбец": ["сырть"],
    "рыбзавод": ["рыбозавод"],
    "рыбий глаз": ["фишай", "апофиллит"],
    "рыбий зуб": ["заморский зуб"],
    "рыбий клей": ["осетровый клей"],
    "рыбий хвост": ["кариота охландровидная"],
    "рыбинск": ["щербаков", "андропов"],
    "рыбица": ["рыба"],
    "рыбоглазый": ["светлоглазый"],
    "рыбозавод": ["рыбзавод"],
    "рыболов": ["рыбак"],
    "рыболовный": ["рыболовецкий", "рыбацкий"],
    "рыболовство": ["рыбная ловля", "рыбарство", "рыбачение", "рыбачничание", "рыболовничание"],
    "рыбоподобный": ["рыбовидный", "рыбообразный"],
    "рыбопромысел": ["рыболовство"],
    "рыбочка": ["рыбка"],
    "рыбоящер": ["ихтиозавр"],
    "рыбчонка": ["рыбёшка", "рыбка"],
    "рыбёха": ["рыбёшка"],
    "рыбёшечка": ["рыбонька"],
    "рыбёшка": ["рыбчонка", "рыбка"],
    "рыв": ["рывши"],
    "рывав": ["рывавши"],
    "рывавши": ["рывав"],
    "рывок": ["спурт", "скачок"],
    "рывши": ["рыв"],
    "рыга": ["регионал"],
    "рыгав": ["рыгавши"],
    "рыгавши": ["рыгав"],
    "рыгать": ["отрыгивать", "срыгивать", "блевать"],
    "рыгнув": ["рыгнувши"],
    "рыгнувши": ["рыгнув"],
    "рыготав": ["рыготавши"],
    "рыготавши": ["рыготав"],
    "рыдав": ["рыдавши"],
    "рыдавши": ["рыдав"],
    "рыдание": ["плач", "рёв", "слёзы", "рыдалово"],
    "рыдать": ["плакать", "реветь"],
    "рыдван": ["драндулет", "тарантас", "колымага", "развалюха", "шушлайка", "ведро гайками", "ведро с болтами", "раритет", "сноповозка"],
    "рыжев": ["рыжевши"],
    "рыжеватый": ["каурый", "рудоватый", "рыжий", "светло-каштановый", "рыжавый"],
    "рыжевласый": ["рыжеволосый", "рыжий"],
    "рыжеволосый": ["рыжеголовый"],
    "рыжевши": ["рыжев"],
    "рыжеголовый": ["рыжеволосый"],
    "рыжий": ["морковный", "медный", "красновато-бурый", "ржавый"],
    "рыжик": ["рыжей"],
    "рыжко": ["рыжка", "рижка"],
    "рык": ["рычание"],
    "рыкав": ["рыкавши"],
    "рыкавши": ["рыкав"],
    "рыканье": ["рыкание"],
    "рыкать": ["рычать"],
    "рыкнув": ["рыкнувши"],
    "рыкнувши": ["рыкнув"],
    "рыкнуть": ["рявкнуть", "зарычать"],
    "рылашка": ["горшок", "рыльник", "рыльничек"],
    "рыло": ["морда"],
    "рыло вырву": ["вырву рыло"],
    "рыльце": ["морда", "рожа"],
    "рыльце в пуху": ["рыльце в пушку"],
    "рым-болт": ["ухо"],
    "рынок": ["базар", "торжище", "торг", "ярмарка", "галдёж", "шум-гам"],
    "рыночно-базарный": ["базарно-рыночный"],
    "рыночный": ["нерыночный", "безрыночный"],
    "рыпаться": ["дёргаться", "встревать", "суетиться"],
    "рысив": ["рысивши"],
    "рысивши": ["рысив"],
    "рыск": ["рыскание", "рысканье"],
    "рыскав": ["рыскавши"],
    "рыскавши": ["рыскав"],
    "рыскание": ["рысканье"],
    "рысканье": ["рыскание"],
    "рыскать": ["искать"],
    "рыскнув": ["рыскнувши"],
    "рыскнувши": ["рыскнув"],
    "рыскучий": ["бегучий"],
    "рысцой": ["рысцою"],
    "рысцою": ["рысцой"],
    "рысью": ["вскачь"],
    "рытвина": ["выбоина", "промоина", "яма"],
    "рыть": ["копать"],
    "рыхлев": ["рыхлевши"],
    "рыхлевши": ["рыхлев"],
    "рыхлив": ["рыхливши"],
    "рыхливши": ["рыхлив"],
    "рыхлый": ["неплотный", "расплывчатый", "вялый", "дряблый"],
    "рыцарственно": ["по-рыцарски"],
    "рыцарствовав": ["рыцарствовавши"],
    "рыцарствовавши": ["рыцарствовав"],
    "рыцарь": ["кабальеро", "кавалер", "паладин", "шевалье"],
    "рыцарь плаща и кинжала": ["разведчик", "шпион"],
    "рыцарь революции": ["пролетарский якобинец", "страж революции", "железный феликс", "астроном", "дзержинчик"],
    "рычав": ["рычавши"],
    "рычавши": ["рычав"],
    "рычаг": ["рукоятка"],
    "рычание": ["рыканье", "рык", "рёв"],
    "рычанье": ["рычание"],
    "рычать": ["рыкать"],
    "рыща": ["рыщущи"],
    "рыюльын": ["чавчыв"],
    "рьдръ": ["ръдръ"],
    "рьяно": ["усердно", "яро", "увлечённо"],
    "рьяный": ["усердный", "ретивый", "страстный", "горячий"],
    "рэа": ["радиоэлектронная аппаратура", "раково-эмбриональный антиген"],
    "рэгтайм": ["регтайм"],
    "рэзультат": ["здабытак", "падрахунак", "дасягненне"],
    "рэйки": ["рейки"],
    "рэйчел": ["рейчел"],
    "рэкетир": ["вымогатель", "шантажист"],
    "рэкетировав": ["рэкетировавши"],
    "рэкетировавши": ["рэкетировав"],
    "рэкетирствовав": ["рэкетирствовавши"],
    "рэкетирствовавши": ["рэкетирствовав"],
    "рэмэз": ["рамаз"],
    "рэндолф": ["рэндольф", "рандолф", "рендольф"],
    "рэндольф": ["рандолф", "рэндолф", "рендольф"],
    "рэнесанс": ["адраджэнне"],
    "рэп-баттл": ["хип-хоп-баттл"],
    "рэп-исполнитель": ["рэпер", "рэп-музыкант", "рэп-певец"],
    "рэп-исполнительница": ["рэперша"],
    "рэпер": ["рэп-исполнитель", "рэп-музыкант", "рэп-певец"],
    "рэперша": ["рэп-исполнительница"],
    "рэповав": ["рэповавши"],
    "рэповавши": ["рэповав"],
    "рэпчик": ["рэп", "рэпчина"],
    "рэпчина": ["рэп", "рэпчик"],
    "рюинь": ["хмурень", "вересень"],
    "рюкзак": ["ранец"],
    "рюкзачишко": ["рюкзак", "рюкзачок"],
    "рюкюсец": ["ликеец"],
    "рюмив": ["рюмивши"],
    "рюмивши": ["рюмив"],
    "рюмиться": ["рюмить"],
    "рюмка": ["бокал", "келюх", "лафитник", "рюмаха", "рюмашка", "рюмочка", "стопка", "стопочка", "чарка", "чарочка", "шкалик", "шлюмка"],
    "рюмса": ["рюма"],
    "рюо": ["южная осетия", "республика южная осетия", "государство алания"],
    "рюха": ["городок"],
    "рюхав": ["рюхавши"],
    "рюхавши": ["рюхав"],
    "рябев": ["рябевши"],
    "рябевши": ["рябев"],
    "рябив": ["рябивши"],
    "рябивши": ["рябив"],
    "рябиновая ночь": ["воробьиная ночь"],
    "рябковав": ["рябковавши"],
    "рябковавши": ["рябковав"],
    "рябоватый": ["рябенький", "рябоватенький"],
    "рябок": ["рябчик"],
    "рябчик": ["рябец"],
    "рябь": ["зыбь", "дрожь", "мерцание", "мелькание"],
    "рявкав": ["рявкавши"],
    "рявкавши": ["рявкав"],
    "рявкнув": ["рявкнувши"],
    "рявкнувши": ["рявкнув"],
    "рявкнуть": ["гаркнуть"],
    "рядив": ["рядивши"],
    "рядивши": ["рядив"],
    "рядиться в тогу": ["притворяться", "перекрашиваться", "изображать", "изображать из себя", "корчить", "корчить из себя", "надевать тогу"],
    "рядовка": ["трихолома"],
    "рядовой": ["обычный", "заурядный", "низовой"],
    "рядок": ["ряд"],
    "рядом": ["близко", "около", "неподалёку", "поблизости", "бок о бок"],
    "рядом с": ["близ", "вблизи"],
    "рядчик": ["подрядчик"],
    "ряж": ["опалубка"],
    "ряженка": ["варенец", "ряженец", "переряженный", "окрутник", "святочник"],
    "ряженый": ["ряженный", "нарядный"],
    "ряженье": ["ряжение"],
    "рязанская область": ["рязанщина"],
    "ряпаться": ["репаться"],
    "ряса": ["сутана"],
    "рясный": ["рясный-рясный", "рясный-прерясный"],
    "рясофор": ["рясофорный монах"],
    "рясофорный": ["рясоносный"],
    "ряфцодомс": ["толхмадемс", "тостядемс", "тутмадемс"],
    "ряшка": ["морда", "рыло", "ряха", "физиономия", "харя"],
    "рёдановец": ["рёдан", "паук"],
    "рёдрый": ["рыжий", "красный"],
    "с боку на бок": ["беспокойно"],
    "с бочиной": ["с брюхом"],
    "с брюха спасть": ["схуднуть"],
    "с брюхом": ["с бочиной"],
    "с бухты-барахты": ["внезапно", "ни с того ни с сего", "с дуру"],
    "с вашего разрешения": ["с вашего позволения", "позволить", "разрешить"],
    "с верхом": ["доверху", "сполна", "с горкой"],
    "с ветерком": ["лихо", "быстро", "залихватски"],
    "с высоты птичьего полёта": ["с птичьего полёта", "с высокой колокольни"],
    "с глазу на глаз": ["лицом к лицу", "тет-а-тет"],
    "с головы до пят": ["целиком", "полностью", "с ног до головы", "от головы до пят", "до кончиков ногтей", "до мозга костей", "до корней волос", "душой и телом"],
    "с градом": ["с шумом", "с треском", "со стуком"],
    "с грехом пополам": ["с горем пополам"],
    "с гулькин нос": ["кот наплакал", "всего ничего"],
    "с днём рождения": ["с днём варенья"],
    "с добрым утром": ["доброе утро", "здравствуй", "здравствуйте", "привет"],
    "с души воротит": ["душу мутит", "с души тянет", "противно", "отвратительно"],
    "с жиру беситься": ["привередничать"],
    "с заёбами": ["с придурью", "с заскоком", "с тараканами", "с припиздью"],
    "с иголочки": ["ново"],
    "с изнанки": ["с лица", "изнутри"],
    "с каких пор": ["с которых пор"],
    "с коломенскую версту": ["верзила", "каланча", "дылда", "жердяй", "в коломенскую версту"],
    "с кондачка": ["фамильярно", "панибратски", "бесцеремонно", "снисходительно", "свысока", "высокомерно", "амикошонски", "легкомысленно", "несерьёзно", "поверхностно", "неосновательно", "необдуманно", "непродуманно", "неосмотрительно", "поспешно"],
    "с концами": ["бесследно"],
    "с корабля на бал": ["из огня да в полымя"],
    "с лихвой": ["с лишним", "с избытком"],
    "с лихуем": ["с гаком", "с лишним", "с лишком"],
    "с лишком": ["с небольшим", "с хвостиком"],
    "с малых лет": ["с пелёнок", "с пелён"],
    "с места в карьер": ["тотчас", "сразу"],
    "с мизинец": ["в мизинец"],
    "с недосыпа": ["с недосыпу"],
    "с недосыпу": ["с недосыпа"],
    "с нихуя": ["с ничего", "из ниоткуда"],
    "с новым годом": ["говно с дымом"],
    "с ног до головы": ["с головы до пят"],
    "с ног на голову": ["наоборот", "шиворот на выворот"],
    "с ноги": ["ногой"],
    "с нуля": ["с чистого листа", "заново"],
    "с облаков": ["из ниоткуда", "откуда ни возьмись"],
    "с оглоблю": ["в оглоблю"],
    "с одним ртом на два обеда": ["убить двух зайцев"],
    "с открытым сердцем": ["честно", "откровенно", "бесхитростно", "искренне", "искренно", "от всего сердца"],
    "с охотой": ["охотно"],
    "с паршивой овцы хоть шерсти клок": ["с драной овцы хоть шерсти клок", "с паршивой собаки хоть шерсти клок", "от худого должника хоть мякиною бери", "от худого должника хоть мешок мякины"],
    "с паршивой собаки хоть шерсти клок": ["с паршивой овцы хоть шерсти клок"],
    "с пелён": ["с малых лет", "с пелёнок"],
    "с пелёнок": ["с малых лет", "с пелён"],
    "с первого абцуга": ["по первому абцугу"],
    "с пиздий волос": ["с волос", "с волосок", "с пиздий волосок"],
    "с поличным": ["на месте преступления"],
    "с помощью": ["при помощи", "через"],
    "с помпой": ["помпезно", "парадно", "пышно", "эффектно", "роскошно", "церемониально"],
    "с походом": ["с довеском", "с превышением"],
    "с превышением": ["с походом"],
    "с приветом": ["с большим приветом", "не в себе", "не все дома", "прибабахнутый", "с прибабахом", "с придурью"],
    "с пристрастием": ["придирчиво", "тщательно", "внимательно"],
    "с прицелом на": ["с целью"],
    "с птичьего полёта": ["с высоты птичьего полёта", "с колокольни"],
    "с пустыми руками": ["без ничего", "не солоно хлебавши"],
    "с пьяных шар": ["спьяну", "спьяна", "по пьяни", "с пьяных глаз", "по пьяной лавочке", "под пьяную руку", "под мухой"],
    "с радостью": ["с удовольствием", "охотно", "да", "конечно", "легко"],
    "с рождеством": ["с рождеством христовым", "весёлого рождества", "счастливого рождества"],
    "с рыла": ["с носа"],
    "с сердцов": ["в сердцах"],
    "с три короба": ["целый короб"],
    "с трудом": ["насилу", "еле", "едва", "чуть"],
    "с удовольствием": ["охотно", "с радостью"],
    "с утра": ["утром"],
    "с утреца": ["с утра пораньше", "спозаранку", "спозаранок"],
    "с утречка": ["утром", "утречком", "с утра", "с утреца", "наутро", "поутру", "под утро"],
    "с ходу": ["сразу", "с лёту", "на ходу", "с разгона", "с разбега"],
    "с хоккейным счётом": ["крупный", "счёт"],
    "с хуёчка капает": ["капает с конца"],
    "с целью": ["для", "ради", "из-за", "на", "за", "во имя", "в целях"],
    "саадак": ["сагайдак", "сайдак"],
    "саам": ["саами", "лапландец", "лопарь"],
    "сабаб": ["боис"],
    "сабадбоф": ["занбилбоф"],
    "сабака": ["хорт"],
    "сабаль": ["капустная пальма"],
    "сабвуфер": ["полоса"],
    "сабей": ["сабеец", "сабеянин", "савеянин"],
    "саберфайтинг": ["фрифайт"],
    "сабеянин": ["сабеец", "сабей", "савеянин"],
    "сабин": ["сабинянин"],
    "сабирабад": ["петропавловка"],
    "сабля": ["шашка", "кавалерист"],
    "саботажник": ["бойкотист", "отказник"],
    "саботажничав": ["саботажничавши"],
    "саботажничавши": ["саботажничав"],
    "саботировав": ["саботировавши"],
    "саботировавши": ["саботировав"],
    "саван": ["кафан", "покрывало", "покров"],
    "савантизм": ["синдром саванта"],
    "саваоф": ["бог отец"],
    "сават": ["шоссон"],
    "савва": ["савка"],
    "саводнок": ["босавод", "хату саводдор"],
    "савол": ["пурсиш", "суол"],
    "саврас": ["савраска"],
    "савромат": ["сармат"],
    "сага": ["сказание", "эпопея"],
    "сагайдак": ["налучь", "налуч", "налучник", "налучие", "лубье", "саадак", "сайдак", "горит", "лук"],
    "сагбача": ["кучукбача"],
    "сагиб": ["саиб", "сахиб"],
    "сагитировав": ["сагитировавши"],
    "сагитировавши": ["сагитировав"],
    "сагиттария": ["стелолист"],
    "саговник": ["цикас"],
    "сагрегатировав": ["сагрегатировавши"],
    "сагрегатировавши": ["сагрегатировав"],
    "сагуин": ["тамарин"],
    "сагыну": ["сагыш"],
    "сагыш": ["сагыну"],
    "сад": ["парк", "сквер", "огород", "снт", "сот"],
    "сада": ["сад"],
    "саданув": ["саданувши"],
    "саданувши": ["саданув"],
    "садаптироваться": ["приспособиться"],
    "саджа": ["булдурук", "бюльдерюк", "бульдрюк", "копытка"],
    "садив": ["садивши"],
    "садивши": ["садив"],
    "садилка": ["сажалка"],
    "садистический": ["садистский"],
    "садистка": ["вредительница"],
    "садистский": ["садистический"],
    "садить": ["сажать", "пускать на ветер", "транжирить", "спускать", "наяривать", "пулять", "лупить"],
    "саднев": ["садневши"],
    "садневши": ["саднев"],
    "саднив": ["саднивши"],
    "саднивши": ["саднив"],
    "саднить": ["царапать", "раздражать", "першить", "зудеть"],
    "садовничав": ["садовничавши"],
    "садовничавши": ["садовничав"],
    "садовое кольцо": ["ск"],
    "садр": ["кази"],
    "садху": ["факир"],
    "садюга": ["садист"],
    "саентолог": ["хаббардист"],
    "саентология": ["сциентология", "сайентология"],
    "саечка": ["сайка"],
    "сажа": ["копоть", "налёт", "гарь"],
    "сажав": ["сажавши"],
    "сажавши": ["сажав"],
    "сажальщик": ["садильщик", "садитель", "садчик"],
    "сажанье": ["сажание"],
    "сажать": ["усаживать"],
    "саженец": ["посадочный материал"],
    "саживав": ["саживавши"],
    "саживавши": ["саживав"],
    "сажотрус": ["коминар", "коминяр"],
    "саз": ["сааз"],
    "сай-фай": ["сайенс-фикшен", "научная фантастика"],
    "сайба": ["арангас"],
    "сайга": ["сайгак"],
    "сайгак": ["сайга"],
    "сайда": ["сидон"],
    "сайдинг": ["вагонка"],
    "сайдстик": ["брус"],
    "сайенс-фикшен": ["сай-фай", "научная фантастика"],
    "сайентолог": ["хаббардист"],
    "сайентологический": ["сциентологический"],
    "сайка": ["булка", "саечка"],
    "сайкобилли": ["психобилли"],
    "сайлентблок": ["сайлент-блок"],
    "сайт": ["веб-сайт", "узел сети", "веб-узел"],
    "сайт-специфичный мутагенез": ["направленный мутагенез", "сайт-направленный мутагенез"],
    "сайф": ["шамшер"],
    "сайыс": ["жарыс"],
    "сак": ["баул"],
    "сакарья": ["сангариус"],
    "сакатекас": ["закатекас"],
    "саки": ["чёртов", "обезьяна"],
    "саккомпанировав": ["саккомпанировавши"],
    "саккомпанировавши": ["саккомпанировав"],
    "саккулюс": ["саккулус"],
    "саккумулировав": ["саккумулировавши"],
    "саккумулировавши": ["саккумулировав"],
    "саклавчу": ["сакълавчы"],
    "саклак": ["бруслина"],
    "сакма": ["след", "шлях", "тропа", "колея"],
    "сакрализовав": ["сакрализовавши"],
    "сакрализовавши": ["сакрализовав"],
    "сакрализовать": ["освящать", "освятить"],
    "сакральность": ["священность"],
    "сакральный": ["священный", "ритуальный", "сакраментальный"],
    "сакрамент": ["залог", "потир"],
    "сакраментальный": ["сакральный", "заветный", "традиционный"],
    "саксофонист": ["саксист"],
    "сактировав": ["сактировавши"],
    "сактировавши": ["сактировав"],
    "сакура": ["вишня мелкопильчатая"],
    "салага": ["салака", "уклея", "уклейка", "елец", "плотва", "молокосос"],
    "салажонок": ["салага"],
    "салака": ["салага", "новичок", "слабак", "неумеха"],
    "салам": ["салам-пополам"],
    "салат": ["латук"],
    "салатник": ["салатница"],
    "салатница": ["салатник"],
    "салатовий": ["салатний"],
    "салатовый": ["светло-зелёный"],
    "салбар": ["ыштан"],
    "салдат": ["змагар", "баец", "ваеннаслужачы"],
    "салехард": ["обдорск"],
    "салив": ["саливши"],
    "салива": ["плевок"],
    "саливав": ["саливавши"],
    "саливавши": ["саливав"],
    "саливация": ["слюноотделение"],
    "саливши": ["салив"],
    "салинометр": ["солемер"],
    "салить": ["зажиривать", "пачкать", "марать"],
    "салицилка": ["салициловый натрий"],
    "салициловая кислота": ["орто-гидроксибензойная кислота"],
    "салки": ["пятнашки", "догонялки", "салочки", "гали", "сифа"],
    "салкъм": ["акация"],
    "салкын": ["суык"],
    "салла": ["аммома"],
    "салмукссалы": ["салмуксонь салы"],
    "сало": ["мазнина", "тлъстина", "лой", "масти"],
    "сало-": ["укро-", "хохло-", "свино-"],
    "саловермахт": ["хохловермахт", "укровермахт"],
    "салол": ["мусол", "фенилсалицилат"],
    "салолюфтваффе": ["хохлолюфтваффе", "укролюфтваффе"],
    "саломас": ["салолин"],
    "салон-вагон": ["вагон-салон"],
    "салоники": ["солунь", "фессалоники"],
    "салоп": ["накидка", "клок", "пальто", "одежда", "салопец", "салопик", "салопишко", "салопчик"],
    "салопатриот": ["укропатриот", "хохлопатриот", "свинопатриот"],
    "салотопный": ["салотопенный"],
    "салофюрер": ["хохлофюрер", "укрофюрер"],
    "салочки": ["пятнашки", "салки", "гали", "сифа", "сиф"],
    "салсол": ["гил"],
    "салтов": ["старый салтов", "верхний салтов"],
    "салтык": ["вкус", "лад", "манер", "образец"],
    "салун": ["бар", "кабак", "трактир"],
    "сальварсан": ["арсфенамин"],
    "сальдировав": ["сальдировавши"],
    "сальдировавши": ["сальдировав"],
    "сальза": ["грязевой вулкан"],
    "сальник": ["крепина", "здор"],
    "сальпингоофорит": ["аднексит"],
    "сальсолоидный": ["сальзолоидный"],
    "сальтанув": ["сальтанувши"],
    "сальтанувши": ["сальтанув"],
    "сальтировав": ["сальтировавши"],
    "сальтировавши": ["сальтировав"],
    "сальтисон": ["сальцесон"],
    "сальце": ["сальцо"],
    "сальцо": ["сальце"],
    "салют": ["фейерверк", "салютование", "салютирование", "салютация", "салютовка", "воинский салют", "отдание чести", "фехтовальный салют", "фехтовальная салютация", "пионерский салют"],
    "салютация": ["салютование", "салют", "салютовка"],
    "салютировав": ["салютировавши"],
    "салютировавши": ["салютировав"],
    "салютовав": ["салютовавши"],
    "салютовавши": ["салютовав"],
    "салютование": ["салют", "салютация", "салютовка"],
    "салютовать": ["отдавать честь", "козырять", "приветствовать", "встречать"],
    "салютовка": ["салютование", "салют"],
    "салят": ["намаз", "салат"],
    "сам бог велел": ["само собой"],
    "сам себе хозяин": ["сам себе голова"],
    "сам чёрт не брат": ["чёрту не брат", "чёрту брат", "сломает чёрту рога", "рос чёрту на семена"],
    "сам-двадцать": ["вдвадцатером"],
    "сам-сём": ["сам-семь", "всемером"],
    "сам-третей": ["втроём"],
    "саман": ["адоба", "сечка"],
    "самандаори": ["яяори"],
    "самандеми": ["сэвэнчэдеми"],
    "самара": ["самур", "ой су", "хой су"],
    "самарбахш": ["боровар"],
    "самаритянка": ["добрая душа"],
    "самарская область": ["самарщина", "самарский край"],
    "самарянин": ["самаритянин"],
    "самаэль": ["сатана", "азазель", "дьявол", "люцифер", "мефистофель"],
    "самбур": ["самур", "самура"],
    "самгинство": ["самгинщина"],
    "самгинщина": ["самгинство"],
    "самец": ["мужлан", "мачо"],
    "самиздатский": ["самиздатный", "самиздатовский"],
    "самиздатчик": ["самиздатовец"],
    "самимият": ["ихлос"],
    "саммур": ["самур"],
    "самний": ["самниум"],
    "само собой": ["непроизвольно", "сам по себе", "нечаянно", "безусловно", "разумеется", "конечно", "естественно", "понятное дело", "понятно дело", "очевидно"],
    "само собой разумеется": ["само собой"],
    "само-": ["авто-"],
    "самоактивация": ["автоактивация"],
    "самоактуализация": ["самореализация"],
    "самоанализ": ["самооценка", "интроспекция"],
    "самобичевание": ["флагеллация", "самокритика"],
    "самобичеванье": ["самобичевание", "флагеллация", "флагелляция"],
    "самобичування": ["самокатування"],
    "самобытность": ["оригинальность", "своеобразие", "особенность", "нестандартность"],
    "самобытный": ["самостоятельный", "оригинальный", "своеобразный"],
    "самовар": ["самогрей"],
    "самоварив": ["самоваривши"],
    "самоваривши": ["самоварив"],
    "самоварничав": ["самоварничавши"],
    "самоварничавши": ["самоварничав"],
    "самоварничать": ["чайничать", "чаёвничать"],
    "самовбивство": ["самогубство"],
    "самовидец": ["очевидец"],
    "самовираз": ["самовираження"],
    "самовладник": ["самодержець"],
    "самовластвовав": ["самовластвовавши"],
    "самовластвовавши": ["самовластвовав"],
    "самовластец": ["самодержец", "самовластитель"],
    "самовластие": ["самодержавие", "единодержавие", "единовластие", "монархия", "деспотизм", "тирания", "насилие", "самосуд", "суд линча", "самовольство", "самоволие", "самоуправство", "своеволие", "своевольство", "своевластие"],
    "самовластье": ["самовластие"],
    "самовнушение": ["автосуггестия", "самогипноз"],
    "самовнушенье": ["самовнушение"],
    "самовозвеличение": ["самовозвышение"],
    "самовозвеличивание": ["самовозвеличение"],
    "самовозгорание": ["самовоспламенение"],
    "самовозгораться": ["самовоспламеняться"],
    "самовозгорающийся": ["самовоспламеняющийся"],
    "самовозгореться": ["самовоспламениться"],
    "самоволие": ["своеволие", "самоволье"],
    "самоволка": ["самоход"],
    "самоволочка": ["самоволка", "самоход"],
    "самоволье": ["самоволие"],
    "самовольничав": ["самовольничавши"],
    "самовольничавши": ["самовольничав"],
    "самовольничанье": ["самовольничание"],
    "самовольно": ["добровольно", "своевольно"],
    "самовольный": ["своевольный", "несанкционированный"],
    "самовольствовав": ["самовольствовавши"],
    "самовольствовавши": ["самовольствовав"],
    "самовольствовать": ["самовольничать", "самоуправствовать", "своевольничать"],
    "самовоспитание": ["самообразование"],
    "самовоспламенение": ["самовозгорание"],
    "самовоспламеняемость": ["самовозгораемость"],
    "самовоспламеняться": ["самовозгораться"],
    "самовоспламеняющийся": ["самовозгорающийся"],
    "самовоспроизводив": ["самовоспроизводивши"],
    "самовоспроизводивши": ["самовоспроизводив"],
    "самовосхваление": ["самопрославление", "бахвальство", "хвастовство", "самохвальство"],
    "самовот": ["осмон"],
    "самовращение": ["авторотация"],
    "самовыдвиженец": ["независимый кандидат"],
    "самовызов": ["рекурсия"],
    "самовыпилиться": ["покончить с собой"],
    "самовыражение": ["самореализация"],
    "самовыраженье": ["самовыражение", "самореализация"],
    "самогипноз": ["автогипноз", "самовнушение"],
    "самогон": ["самогонка", "сивуха", "дымка", "аржановка", "самосидка"],
    "самогонка": ["горелка"],
    "самогонный": ["сивушный", "винокуренный"],
    "самогоноварильщик": ["самогонщик"],
    "самогонщик": ["самогоноварильщик"],
    "самогранный": ["кристаллический"],
    "самогубець": ["самогубця", "самовбивця", "самовбивець"],
    "самогубство": ["самовбивство"],
    "самодельничав": ["самодельничавши"],
    "самодельничавши": ["самодельничав"],
    "самодельный": ["кустарный"],
    "самодержавие": ["автократия", "абсолютизм", "единовластие", "монархия", "самовластие", "царизм"],
    "самодержавье": ["самодержавие"],
    "самодержец": ["монарх", "деспот"],
    "самодержець": ["самодержавець"],
    "самодеятельность": ["инициатива"],
    "самодива": ["елф", "фея", "самовила"],
    "самодистика": ["самоедология"],
    "самодисциплина": ["самоконтроль"],
    "самодифференциация": ["аутодифференциация"],
    "самодовлев": ["самодовлевши"],
    "самодовлевши": ["самодовлев"],
    "самодовольно": ["самоудовлетворённо"],
    "самодовольный": ["напыщенный"],
    "самодокументируемый": ["наглядный"],
    "самодостаточный": ["самодовлеющий"],
    "самодур": ["тиран"],
    "самодурив": ["самодуривши"],
    "самодуривши": ["самодурив"],
    "самодурка": ["самодура"],
    "самодурничав": ["самодурничавши"],
    "самодурничавши": ["самодурничав"],
    "самодурство": ["своенравие", "самоуправство", "своеволие"],
    "самодурствовав": ["самодурствовавши"],
    "самодурствовавши": ["самодурствовав"],
    "самодурствовать": ["своенравничать"],
    "самое оно": ["в самый раз"],
    "самоед": ["ненец", "самодиец", "лапландец", "лопарь", "саам"],
    "самоедствовав": ["самоедствовавши"],
    "самоедствовавши": ["самоедствовав"],
    "самоезд": ["автомобиль", "машина"],
    "самозабвенье": ["самозабвение"],
    "самозагораться": ["самовозгараться"],
    "самозанятой": ["самозанятый"],
    "самозаражение": ["аутоинфекция"],
    "самозасевание": ["самосев"],
    "самозащита": ["самозащищение", "самооборона"],
    "самозванец": ["мошенник", "аферист"],
    "самозванный": ["авантюристический", "авантюристичный", "взявшийся", "за", "дело", "без", "назначения", "по", "своей", "инициативе", "присвоивший", "себе", "незаконно", "чужое", "звание"],
    "самозванствовав": ["самозванствовавши"],
    "самозванствовавши": ["самозванствовав"],
    "самозваный": ["авантюристический", "взявший", "на", "себя", "обязанности", "самовольно", "самозванный", "самозванческий", "являющийся", "самозванец"],
    "самозвинувачування": ["самообвинувачування"],
    "самоидентификация": ["автоидентификация", "самоотождествление"],
    "самоидентичность": ["самотождественность", "аутоидентичность", "самобытность"],
    "самоизмама": ["самоизлъгване", "илюзия"],
    "самоизолирование": ["самоизоляция"],
    "самоизоляция": ["изоляционизм"],
    "самоирония": ["автоирония", "самостёб"],
    "самоиспытание": ["испытание"],
    "самоистязание": ["самобичевание"],
    "самоистязанье": ["самоистязание"],
    "самокалибровав": ["самокалибровавши"],
    "самокалибровавши": ["самокалибровав"],
    "самокарантин": ["самоизоляция"],
    "самокат": ["велосипед"],
    "самоконтроль": ["самообладание"],
    "самокопание": ["самоанализ"],
    "самокопанье": ["самокопание"],
    "самокормушка": ["автокормушка"],
    "самокритика": ["самобичевание"],
    "самокрутка": ["козья ножка", "блант", "косяк", "джойнт", "сплиф"],
    "самолетъ": ["аэропланъ"],
    "самолечение": ["самоисцеление"],
    "самоликвидация": ["самоуничтожение", "самороспуск"],
    "самоликвидироваться": ["самоуничтожаться", "самоуничтожиться"],
    "самолов": ["самоловка"],
    "самолюб": ["самолюбец", "себялюб", "себялюбец"],
    "самолюбивий": ["самолюбний"],
    "самолюбие": ["чувство собственного достоинства", "своекорыстие", "самовлюблённость", "претенциозность", "гордость", "амбициозность", "самоуважение", "амбиция"],
    "самолюбование": ["самолюбованье", "нарциссизм", "самодовольство"],
    "самолюбованье": ["самолюбование"],
    "самолюбье": ["самолюбие"],
    "самолёт": ["аэроплан"],
    "самолёт-снаряд": ["крылатая ракета"],
    "самолётостроенье": ["самолётостроение"],
    "самолётъ": ["аэропланъ"],
    "самомассаж": ["самомассажирование"],
    "самомассажировав": ["самомассажировавши"],
    "самомассажировавши": ["самомассажировав"],
    "самомассажирование": ["самомассаж"],
    "самоменеджмент": ["селф-менеджмент"],
    "самомнение": ["гонор", "амбиция", "самодовольствие", "самовлюблённость", "самодовольство", "эготизм"],
    "самомненье": ["самомнение"],
    "самомобилизоваться": ["собраться", "сила", "поднатужиться"],
    "самонаблюдение": ["интроспекция"],
    "самонаводящаяся головка": ["ловелас", "бабник"],
    "самонадеянно": ["самоуверенно", "дерзко"],
    "самонадеянность": ["самоуверенность"],
    "самонадеянный": ["самоуверенный"],
    "самоназвание": ["самоназванье", "эндоэтноним"],
    "самоназванье": ["самоназвание", "эндоэтноним"],
    "самонаклад": ["самонакладчик", "самонакладывающий", "аппарат"],
    "самонастройка": ["автонастройка"],
    "самоновейший": ["наиновейший"],
    "самонравный": ["своенравный", "строптивый", "упрямый", "блажной", "взбалмошный", "капризный", "затейливый", "норовистый", "привередливый", "прихотливый", "причудливый", "своевольный", "шальной", "непослушный"],
    "самообвинувачування": ["самозвинувачування"],
    "самообладание": ["выдержка", "хладнокровие"],
    "самообладанье": ["самообладание"],
    "самообличение": ["самообличенье"],
    "самообольщаться": ["самообманываться"],
    "самообольщенье": ["самообольщение"],
    "самооборона": ["самозащита", "самозащищение"],
    "самообучение": ["самообразование"],
    "самоограничение": ["самоограниченье", "самосдерживание"],
    "самоограниченье": ["самоограничение"],
    "самоокисление": ["автоокисление", "аутооксидация", "автооксидация"],
    "самоокупаемость": ["рентабельность", "прибыльность"],
    "самоомана": ["самообман"],
    "самооплевание": ["самооплёвывание"],
    "самооплёвывание": ["самооплевание"],
    "самооправданье": ["самооправдание"],
    "самоопыление": ["автогамия"],
    "самоорганизовывающийся": ["самоорганизующийся"],
    "самооскорбление": ["самооскорбленье"],
    "самоосознание": ["самоосознанье"],
    "самоосуждение": ["самокритика"],
    "самоотбрана": ["самозащита"],
    "самоотверженность": ["жертвенность", "альтруизм"],
    "самоотверженье": ["самоотвержение"],
    "самоотреченье": ["самоотречение"],
    "самоотсос": ["аутофелляция"],
    "самоочевидный": ["неоспоримый"],
    "самопал": ["пищаль", "поджига", "самоструй"],
    "самопальный": ["самодельный"],
    "самоперевод": ["автоперевод"],
    "самопиар": ["автопиар", "самореклама"],
    "самописец": ["видеосамописец", "регистратор", "флайт-рекордер", "чёрный ящик"],
    "самопишущий": ["саморегистрирующий", "регистрирующий"],
    "самоповреждающее поведение": ["аутодеструктивное поведение"],
    "самоповреждающий": ["аутодеструктивный"],
    "самоповреждение": ["селфхарм"],
    "самоподжог": ["самосожжение"],
    "самопожертва": ["самопожертвування"],
    "самопожертвование": ["самоотречение", "жертва", "жертвенность"],
    "самопожертвованье": ["самопожертвование"],
    "самопожертвувателност": ["себепожертвувателност"],
    "самопознанье": ["самопознание"],
    "самопринуждение": ["самоприказ"],
    "самопровозгласив": ["самопровозгласивши"],
    "самопровозгласивши": ["самопровозгласив"],
    "самопровозглашав": ["самопровозглашавши"],
    "самопровозглашавши": ["самопровозглашав"],
    "самопроизвольно": ["спонтанно", "стихийно", "самотёком"],
    "самопроизвольный аборт": ["выкидыш"],
    "самопубликация": ["селф-паблишинг"],
    "саморазвал": ["самораспад"],
    "саморазвитие": ["совершенствование"],
    "саморазумеющийся": ["элементарный", "простейший", "наипростейший", "естественный"],
    "саморастворение": ["автолиз"],
    "самореализация": ["самоактуализация"],
    "саморегулировав": ["саморегулировавши"],
    "саморегулировавши": ["саморегулировав"],
    "саморегуляция": ["авторегуляция"],
    "саморез": ["самонарезающий", "винт"],
    "самореклама": ["самовосхваление", "самопиар", "саморекламирование"],
    "саморефлексия": ["самоотражение", "самовосприятие", "самоосмысление", "интроспекция", "самонаблюдение", "самоощущение", "самооценка", "самокопание"],
    "саморефракция": ["самопреломление"],
    "самортизировав": ["самортизировавши"],
    "самортизировавши": ["самортизировав"],
    "самосбор": ["самосборка"],
    "самосборка": ["самосбор"],
    "самосвал": ["автосамосвал", "грузовой самосвал", "автомобиль-самосвал"],
    "самосев": ["самозасевание", "самосей", "самосевка", "самосейка"],
    "самосей": ["самосейка", "самосев"],
    "самосидка": ["самогон", "горючка"],
    "самосинхронизация": ["автосинхронизация"],
    "самоскрепление": ["автоскрепление", "автофретаж"],
    "самосовершенствование": ["саморазвитие", "самоусовершенствование"],
    "самосожжение": ["самосожженье"],
    "самосожженье": ["самосожжение"],
    "самосозерцанье": ["самосозерцание"],
    "самосознанье": ["самосознание"],
    "самосохраненье": ["самосохранение"],
    "самосплайсинг": ["автокатализ"],
    "самостийник": ["самостийщик"],
    "самостийничав": ["самостийничавши"],
    "самостийничавши": ["самостийничав"],
    "самостийность": ["независимость", "самостоятельность"],
    "самостийщик": ["самостийник"],
    "самостоялка": ["самостоятельная работа"],
    "самостоятельность": ["независимость"],
    "самостоятельный": ["независимый", "отдельный", "сепаратный", "автономный", "инициативный", "решительный", "активный", "самодостаточный"],
    "самострел": ["арбалет"],
    "самострок": ["самопал"],
    "самосуд": ["самосудство"],
    "самосёл": ["самопоселенец"],
    "самотник": ["уединен", "усамотен", "самотен"],
    "самотык": ["дилдо", "фаллоимитатор", "годмише", "дилдак"],
    "самотёком": ["стихийно", "самопроизвольно", "неорганизованно"],
    "самотёчный": ["безнапорный"],
    "самоубиение": ["самоубийство", "суицид", "самоумерщвление"],
    "самоубийство": ["суицид", "самоумерщвление", "самоубиение", "самовыпил"],
    "самоубийца": ["самоубойца"],
    "самоубиться": ["выпилиться", "самовыпилиться", "свести счёты с жизнью", "покончить с собой", "наложить на себя руки", "убиться"],
    "самоуважение": ["самоуваженье"],
    "самоуваженье": ["самоуважение"],
    "самоуверенно": ["самонадеянно"],
    "самоуверенность": ["самонадеянность"],
    "самоуверенный": ["самонадеянный"],
    "самоуглубление": ["интроспекция", "углубление", "самого", "себя"],
    "самоудвоение": ["авторедупликация"],
    "самоудовлетворение": ["мастурбация", "онанизм", "рукоблудие"],
    "самоумерщвление": ["самоумерщвленье", "самоубийство", "суицид", "самоубиение"],
    "самоуничижаться": ["уничижаться"],
    "самоуничижение": ["самоумаление", "самоуничиженье", "самоумаленье", "самоунижение", "самоуниженье"],
    "самоуничиженье": ["самоуничижение"],
    "самоуничтожаться": ["самоликвидироваться"],
    "самоуничтоженье": ["самоуничтожение"],
    "самоуничтожиться": ["самоликвидироваться"],
    "самоупорядочивав": ["самоупорядочивавши"],
    "самоупорядочивавши": ["самоупорядочивав"],
    "самоуправничав": ["самоуправничавши"],
    "самоуправничавши": ["самоуправничав"],
    "самоуправствовав": ["самоуправствовавши"],
    "самоуправствовавши": ["самоуправствовав"],
    "самоуслаждение": ["самоуслажденье"],
    "самоусовершенствование": ["самосовершенствование"],
    "самоуспокоение": ["самоуспокоенность"],
    "самоуспокоенность": ["самоуверенность"],
    "самоутвержденье": ["самоутверждение"],
    "самоучка": ["автодидакт"],
    "самоучкой": ["самоучкою", "самоуком"],
    "самохвал": ["хвастун"],
    "самохвальничав": ["самохвальничавши"],
    "самохвальничавши": ["самохвальничав"],
    "самохвальство": ["бахвальство", "хвастовство"],
    "самохвальствовав": ["самохвальствовавши"],
    "самохвальствовавши": ["самохвальствовав"],
    "самоход": ["самоволка"],
    "самоходная артиллерийская установка": ["сау", "самоходка"],
    "самоходный пассажирский трап": ["спт"],
    "самоцвет": ["драгоценный камень"],
    "самоцентрировав": ["самоцентрировавши"],
    "самоцентрировавши": ["самоцентрировав"],
    "самочерпка": ["самочерпалка"],
    "самочинный": ["самовольный", "самоуправный", "добровольческий", "волонтёрский", "инициативный", "самохотный"],
    "самочинствовав": ["самочинствовавши"],
    "самочинствовавши": ["самочинствовав"],
    "самочувствие": ["самоощущение", "сенестезия"],
    "самс": ["пачкодемс", "сангамс", "ушедомс"],
    "самсара": ["сансара"],
    "самум": ["песчаная буря"],
    "самура": ["самур", "самбур"],
    "самух": ["набиагалы"],
    "самый": ["этот", "тот", "сей", "прямо", "как раз", "сам", "даже", "сам по себе"],
    "самый что ни на есть": ["истинный", "самый-самый", "самый-пресамый", "типичный", "отъявленный", "отпетый"],
    "сан-": ["санитарный"],
    "сан-марино": ["республика сан-марино"],
    "санад": ["далел", "асос"],
    "санам": ["бут"],
    "санампараст": ["бутпараст"],
    "санаторий": ["здравница"],
    "санаторный": ["санаторский"],
    "санаторский": ["санаторный"],
    "санау": ["есептеу"],
    "санбат": ["санитарный батальон"],
    "санврач": ["санитарный врач"],
    "сангариус": ["сакарья"],
    "сангвина": ["сангина", "мелок"],
    "сангвиновый": ["красный", "бурый", "рыжий"],
    "сангина": ["сангвин", "сангвина"],
    "сангпушт": ["кашаф"],
    "сандал": ["сандаловое дерево"],
    "сандалив": ["сандаливши"],
    "сандаливши": ["сандалив"],
    "сандалить": ["насандаливать"],
    "сандаль": ["сандалия"],
    "сандвич": ["сэндвич"],
    "сандвичевы острова": ["сэндвичевы острова", "гавайские острова"],
    "сандей": ["санди"],
    "сандугач": ["былбыл"],
    "сандък": ["кутия", "кутийка", "сандъче"],
    "сани": ["салазки", "санки"],
    "санировав": ["санировавши"],
    "санировавши": ["санировав"],
    "санирование": ["санация", "оздоровление"],
    "санитайзер": ["антисептик"],
    "санитарив": ["санитаривши"],
    "санитаривши": ["санитарив"],
    "санитарка": ["медичка", "сестра милосердия", "милосердная сестра", "санитарочка"],
    "санитарная обработка": ["санобработка"],
    "санитарно-эпидемиологический": ["санэпидемиологический"],
    "санитарный узел": ["санузел", "туалет"],
    "санитарочка": ["санитарка"],
    "санктировать": ["узаконивать", "узаконить", "утверждать", "утвердить"],
    "санктъ-петербургъ": ["петербургъ", "петроградъ"],
    "санкха": ["шанкха"],
    "санкционировав": ["санкционировавши"],
    "санкционировавши": ["санкционировав"],
    "санкционировать": ["дозволять", "дозволить", "позволять", "позволить", "разрешать", "разрешить"],
    "санкционка": ["запрещёнка"],
    "санкюлот": ["бесштанник", "голоштанник", "бунтарь"],
    "санный": ["саночный"],
    "санобработка": ["санитарная обработка"],
    "сановник": ["вельможа"],
    "сановный": ["сановничий"],
    "саночный": ["санный"],
    "санпросвет": ["санпросвещение", "санпросвещенье"],
    "сансара": ["реинкарнация", "трансмиграция", "метемпсихоз"],
    "сансевиерия": ["тёщин язык", "щучий хвост", "змеиная кожа"],
    "санскрит": ["санскритский язык"],
    "санскритоязычный": ["санскритский"],
    "санта": ["санта-клаус", "рождественский дед", "дед мороз"],
    "санта-клаус": ["санта", "рождественский дед", "дед мороз"],
    "сантал": ["сандаловое дерево", "сандал"],
    "сантали": ["санталы", "сантальский язык"],
    "сантехник": ["слесарь-сантехник", "водопроводчик"],
    "сантиментальничав": ["сантиментальничавши"],
    "сантиментальничавши": ["сантиментальничав"],
    "сантиметр": ["центиметр", "метр", "статфарад", "абгенри"],
    "сантомиец": ["сан-томиец"],
    "сантуринское": ["сантуринское вино"],
    "сантуринское вино": ["сантуринское"],
    "сантый": ["акылсыз", "ахмак", "тиле"],
    "сантьяго-де-куба": ["сантьяго"],
    "санузел": ["санитарный узел"],
    "санчасть": ["санитарная часть"],
    "санъ-стефано": ["ешилькёй"],
    "саныя": ["секунда"],
    "санька": ["сашка", "сашок", "саня", "александр", "александра"],
    "саньяси": ["бхикшу"],
    "санэпидемстанция": ["санэпидстанция"],
    "санёк": ["александр", "санька", "санечка", "санко", "сашка", "сашко", "сашок", "саня", "сашенция", "сашенька", "сашечка", "сашуля", "саша", "сашик", "шурочка"],
    "сао": ["северный административный округ", "советский административный округ"],
    "саодат": ["бахт", "саъд"],
    "сапа": ["белоглазка", "сопа", "клепец", "глазач"],
    "сапатев": ["сапатевши"],
    "сапатевши": ["сапатев"],
    "сапеда": ["сафеда"],
    "сапка": ["тяпка", "мотыга"],
    "сапожишко": ["сапог"],
    "сапожник": ["обувщик", "башмачник", "чеботарь", "чеботной", "неумеха"],
    "сапожница": ["башмачница"],
    "сапожничав": ["сапожничавши"],
    "сапожничавши": ["сапожничав"],
    "сапожничий": ["сапожнический"],
    "сапожок": ["сапог"],
    "сапонария": ["мыльнянка"],
    "сапонификация": ["омыление"],
    "сапота": ["сапотовое дерево"],
    "сапробионт": ["сапроб"],
    "сапротроф": ["сапрофаг", "деструктор"],
    "сапрофаг": ["детритофаг"],
    "сапрофагия": ["детритофагия"],
    "сапсёрфер": ["сапсёрфингист"],
    "сапсёрфингист": ["сапсёрфер"],
    "сапфир": ["синий корунд", "саламштейн"],
    "сапфирный": ["сапфировый"],
    "сапфический": ["сафический", "лесбийский"],
    "сапёрный": ["пионерный"],
    "сар": ["сирия", "специальный административный район"],
    "сараево": ["босна-сарай"],
    "сараишко": ["сараюшко", "сараюшка"],
    "сарай": ["свинарник"],
    "саран": ["шаран", "саранец"],
    "сарана": ["саранка", "маслянка"],
    "саранча": ["акрид"],
    "саратовец": ["саратовчанин"],
    "саратовская область": ["саратовщина"],
    "саратовчанин": ["саратовец"],
    "сарафанив": ["сарафанивши"],
    "сарафанивши": ["сарафанив"],
    "сарафанное радио": ["обс"],
    "сарацин": ["араб", "мусульманин"],
    "сарачинский": ["сарацинский"],
    "сараюха": ["сараюшко"],
    "сараюшка": ["сараюшко", "сараишко"],
    "сараюшко": ["сараюшка"],
    "сарвастивада": ["вайбхашика"],
    "сарватманд": ["давлатманд", "доро", "бой", "сероб"],
    "сард": ["сардинец"],
    "сардак": ["сердак"],
    "сардар": ["сердар"],
    "сардель": ["сарделька"],
    "сардина": ["сарделька", "сардель"],
    "сардинец": ["сард"],
    "сардинный": ["сардиновый"],
    "сардонически": ["саркастически", "саркастично", "язвительно", "сардонично"],
    "сардонический": ["сардоничный", "язвительный", "саркастический", "саркастичный"],
    "сари": ["туника"],
    "сарир": ["серир"],
    "сарказм": ["ёрничество"],
    "сарканив": ["сарканивши"],
    "сарканивши": ["сарканив"],
    "сарканить": ["заарканить"],
    "саркастичен": ["саркастички"],
    "саркастически": ["саркастично", "язвительно", "едко"],
    "саркастический": ["саркастичный"],
    "саркастички": ["саркастичен"],
    "саркастично": ["саркастически"],
    "саркастичный": ["саркастический"],
    "саркози": ["шаркёзи"],
    "саркома": ["рак"],
    "саркомер": ["инокомма"],
    "саркоплазма": ["миоплазма"],
    "саркоптеригия": ["лопастепёрые", "хоановые"],
    "сарлык": ["горный як"],
    "сармат": ["савромат", "аорс", "языг", "сирак", "алан", "роксолан", "сай", "сарматский ярус"],
    "сарматские горы": ["карпаты"],
    "сарнасл": ["салаф"],
    "саров": ["сарув"],
    "сароникос": ["саронический залив", "афинский залив"],
    "саронская долина": ["сарон", "шарон"],
    "сарсапарель": ["сассапариль"],
    "сарув": ["саров"],
    "сарык": ["куй"],
    "сарымсак": ["сарымсах"],
    "сарынь": ["толпа", "ватага", "сброд"],
    "сарынь на кичку": ["прочь", "пшёл вон"],
    "сарыч": ["канюк", "настоящий канюк"],
    "сас": ["сасный"],
    "сасими": ["сашими"],
    "сасный": ["милый", "привлекательный", "красивый", "приятный"],
    "сассапариль": ["сарсапариль", "сарсапарель", "смилакс"],
    "сатана": ["дьявол", "лукавый", "владыка ада", "повелитель тьмы"],
    "сатанаил": ["самаэль"],
    "сатанев": ["сатаневши"],
    "сатаневши": ["сатанев"],
    "сатаней": ["сати"],
    "сатанизировав": ["сатанизировавши"],
    "сатанизировавши": ["сатанизировав"],
    "сатанизм": ["сатанинство", "дьяволизм", "дьяволопоклонство", "дьяволопоклонничество", "дьяволомания"],
    "сатанински": ["дьявольски"],
    "сатват": ["вришни"],
    "сателлит": ["приспешник", "последователь"],
    "сатил": ["далв"],
    "сатинировав": ["сатинировавши"],
    "сатинировавши": ["сатинировав"],
    "сатириаз": ["сатириазис"],
    "сатириазис": ["сатириаз", "айдойомания", "приапизм"],
    "сатирик": ["высмеиватель"],
    "сатирический": ["сатиричный"],
    "сатирично": ["сатирически"],
    "сатис": ["сатет"],
    "сатисфакция": ["дуэль", "поединок"],
    "сатлых": ["сатлыкъ"],
    "сатори": ["кэнсё"],
    "сатрап": ["наместник", "деспот", "самодур", "тиран"],
    "сатрапия": ["тирания", "деспотия"],
    "сатрапствовав": ["сатрапствовавши"],
    "сатрапствовавши": ["сатрапствовав"],
    "сатурировав": ["сатурировавши"],
    "сатурировавши": ["сатурировав"],
    "сатурн": ["кронос", "крон"],
    "сатучы": ["кибетче"],
    "сау": ["самоходка"],
    "сау бул": ["хуш"],
    "сау булыгыз": ["хушыгыз"],
    "саудиец": ["саудит", "саудоаравиец", "саудовец"],
    "саудит": ["саудид"],
    "саудитский": ["саудидский"],
    "саудоаравиец": ["саудиец", "саудит", "саудовец"],
    "саудовец": ["саудиец", "саудит", "саудоаравиец"],
    "саудовская аравия": ["королевство саудовская аравия"],
    "саук": ["морянка", "алейка", "аллейка"],
    "сауна": ["финская баня"],
    "саунд": ["звучание"],
    "саундтрек": ["звуковая дорожка"],
    "саф бастан": ["саф оростан"],
    "саф оростан": ["саф бастан"],
    "сафат": ["сабад"],
    "сафира": ["сафирка", "сафирушка"],
    "сафический": ["сапфический", "лесбийский"],
    "сафлор": ["сафлор красильный", "американский шафран", "дикий шафран"],
    "сафсата": ["ёва", "музахраф"],
    "сафтомс": ["маштомс", "тумс мяльс"],
    "саффолк": ["суффолк"],
    "сафьянный": ["сафьяновый"],
    "сах": ["орион"],
    "сахаджия": ["сахаджа"],
    "сахалинская область": ["сахалин"],
    "сахар": ["сахароза", "углевод"],
    "сахарив": ["сахаривши"],
    "сахаривши": ["сахарив"],
    "сахарид": ["углевод"],
    "сахарная вата": ["сладкая вата"],
    "сахарная свёкла": ["сладкий корень"],
    "сахарно-рафинадный": ["сахарорафинадный"],
    "сахарный": ["сладкий"],
    "сахарный песок": ["сахар-песок"],
    "сахарозаменитель": ["сахзам"],
    "сахарок": ["сахарец"],
    "сахаролитик": ["целлюлозоразрушитель", "целлюлозолитик"],
    "сахаропаточный": ["сахаро-паточный"],
    "сахарорафинадный": ["сахарно-рафинадный"],
    "сахъат": ["аипп"],
    "сачив": ["сачивши"],
    "сачивши": ["сачив"],
    "сачканув": ["сачканувши"],
    "сачканувши": ["сачканув"],
    "сачковав": ["сачковавши"],
    "сачковавши": ["сачковав"],
    "сачкун": ["прогульщик"],
    "саша": ["саня", "санечка", "сашенька", "сашка", "сашуля", "сашуня", "шурочка", "шура", "шурик"],
    "сашендомс": ["ушеткшнемс", "шангсемс", "пачкотькшнемс"],
    "сашими": ["сасими"],
    "сашка": ["саша", "шура", "шурка"],
    "сашок": ["санёк"],
    "саъд": ["саодат", "бахт"],
    "саяны": ["саянские горы"],
    "саёра": ["сая"],
    "сб": ["совбез"],
    "сбавив": ["сбавивши"],
    "сбавивши": ["сбавив"],
    "сбавление": ["снижение", "уменьшение"],
    "сбавляв": ["сбавлявши"],
    "сбавлявши": ["сбавляв"],
    "сбагрив": ["сбагривши"],
    "сбагривав": ["сбагривавши"],
    "сбагривавши": ["сбагривав"],
    "сбагривать": ["избавляться", "отделываться", "сплавлять"],
    "сбагривши": ["сбагрив"],
    "сбагрить": ["избавиться", "отделаться", "стянуть", "стащить"],
    "сбалагурив": ["сбалагуривши"],
    "сбалагуривши": ["сбалагурив"],
    "сбаламутив": ["сбаламутивши"],
    "сбаламутивши": ["сбаламутив"],
    "сбалансировав": ["сбалансировавши"],
    "сбалансировавши": ["сбалансировав"],
    "сбалансированно": ["уравновешенно"],
    "сбалансированность": ["уравновешенность", "согласованность", "взаимообусловленность"],
    "сбаловав": ["сбаловавши"],
    "сбаловавши": ["сбаловав"],
    "сбалтывав": ["сбалтывавши"],
    "сбалтывавши": ["сбалтывав"],
    "сбалчивав": ["сбалчивавши"],
    "сбалчивавши": ["сбалчивав"],
    "сбалчивать": ["сболчивать"],
    "сбалчиваться": ["сболчиваться"],
    "сбарышничав": ["сбарышничавши"],
    "сбарышничавши": ["сбарышничав"],
    "сбахав": ["сбахавши"],
    "сбахавши": ["сбахав"],
    "сбацав": ["сбацавши"],
    "сбацавши": ["сбацав"],
    "сбегав": ["сбегавши"],
    "сбегавши": ["сбегав"],
    "сбежав": ["сбежавши"],
    "сбежавши": ["сбежав"],
    "сбежаться": ["сойтись", "сесть"],
    "сбежистый": ["покатый"],
    "сбербанк": ["сберкасса"],
    "сберегав": ["сберегавши"],
    "сберегавши": ["сберегав"],
    "сберегательный банк": ["ссудо-сберегательный банк", "сбербанк", "сберегательная касса", "сберкасса"],
    "сбережение": ["сохранение"],
    "сберечь": ["сохранить", "уберечь", "защитить", "сэкономить"],
    "сберкасса": ["сберегательная касса"],
    "сбесив": ["сбесивши"],
    "сбесивши": ["сбесив"],
    "сбеситься": ["взбеситься", "одуреть", "охренеть"],
    "сбивав": ["сбивавши"],
    "сбивавши": ["сбивав"],
    "сбивальный": ["сбивательный"],
    "сбивательный": ["сбивальный"],
    "сбивать": ["сшибать", "подбивать"],
    "сбивать с пути": ["запутывать", "сбивать с толку"],
    "сбивать с толку": ["запутывать", "конфузить", "сбивать с пути"],
    "сбивчиво": ["бессвязно", "путано", "сумбурно"],
    "сбивчивый": ["путаный", "беспорядочный", "неровный"],
    "сбивши": ["сбив"],
    "сбирав": ["сбиравши"],
    "сбиравши": ["сбирав"],
    "сбираться": ["собираться"],
    "сбирка": ["колекция", "подбор", "антология", "христоматия"],
    "сбитень": ["збитень"],
    "сбитый лётчик": ["неудачник"],
    "сбить": ["сшибить"],
    "сбить с панталыку": ["привести в замешательство", "запутать", "смутить", "обескуражить", "сбить с толку"],
    "сбить с толку": ["сбить с панталыку"],
    "сбить спесь": ["успокоить", "усмирить", "одёрнуть", "приструнить", "осадить", "призвать к порядку", "привести к порядку", "поставить на место", "поставить на своё место", "указать место", "указать своё место", "указать на своё место", "сократить", "окоротить", "укоротить"],
    "сбиться с пути": ["сбиваться с панталыку"],
    "сблатовав": ["сблатовавши"],
    "сблатовавши": ["сблатовав"],
    "сблатовать": ["украсть"],
    "сблевав": ["сблевавши"],
    "сблевавши": ["сблевав"],
    "сбледнув": ["сбледнувши"],
    "сбледнувши": ["сбледнув"],
    "сблефовав": ["сблефовавши"],
    "сблефовавши": ["сблефовав"],
    "сближав": ["сближавши"],
    "сближавши": ["сближав"],
    "сближенье": ["сближение"],
    "сблизив": ["сблизивши"],
    "сблизивши": ["сблизив"],
    "сблокировав": ["сблокировавши"],
    "сблокировавши": ["сблокировав"],
    "сблудив": ["сблудивши"],
    "сблудивши": ["сблудив"],
    "сблъсък": ["стълкновение", "сблъскване", "схватка", "битка", "колизия", "конфликт"],
    "сблёвывав": ["сблёвывавши"],
    "сблёвывавши": ["сблёвывав"],
    "сбоив": ["сбоивши"],
    "сбоивши": ["сбоив"],
    "сбой": ["сбивание", "перебой", "нарушение"],
    "сбоку припёка": ["лишний", "ненужный", "посторонний", "чужой", "прикрутень", "пришей-пристебай", "сбоку припёку", "ни сват ни брат", "ни сват ни кум", "не пришей рукав", "не пришей кобыле хвост", "пришей кобыле хвост"],
    "сболтав": ["сболтавши"],
    "сболтавши": ["сболтав"],
    "сболтив": ["сболтивши"],
    "сболтивши": ["сболтив"],
    "сболтнув": ["сболтнувши"],
    "сболтнувши": ["сболтнув"],
    "сболтнуть": ["проговориться"],
    "сболчивав": ["сболчивавши"],
    "сболчивавши": ["сболчивав"],
    "сболчивать": ["сбалчивать"],
    "сболчиваться": ["сбалчиваться"],
    "сбондив": ["сбондивши"],
    "сбондивши": ["сбондив"],
    "сбор": ["собирание", "урожай", "поборы", "налог", "дань", "оброк", "платёж", "повинность", "подать", "пошлина", "тягота", "мыто", "мыт", "акциз", "контрибуция"],
    "сборив": ["сборивши"],
    "сборивши": ["сборив"],
    "сбориться": ["собираться"],
    "сборная изба": ["сборня"],
    "сборный": ["отборный", "разнородный", "смешанный", "разборный"],
    "сборов": ["сборовши"],
    "сборовши": ["сборов"],
    "сборщик": ["монтёр"],
    "сборщица": ["собирательница", "попрошайка"],
    "сбочениться": ["сбочиться"],
    "сбочив": ["сбочивши"],
    "сбочивши": ["сбочив"],
    "сбочиться": ["сбочениться"],
    "сбраживав": ["сбраживавши"],
    "сбраживавши": ["сбраживав"],
    "сбраживаться": ["бродить", "ферментироваться"],
    "сбраковав": ["сбраковавши"],
    "сбраковавши": ["сбраковав"],
    "сбрасывав": ["сбрасывавши"],
    "сбрасывавши": ["сбрасывав"],
    "сбредав": ["сбредавши"],
    "сбредавши": ["сбредав"],
    "сбредив": ["сбредивши"],
    "сбредивши": ["сбредив"],
    "сбредиться": ["пригрезиться", "померещиться"],
    "сбрендив": ["сбрендивши"],
    "сбрендивши": ["сбрендив"],
    "сбрехав": ["сбрехавши"],
    "сбрехавши": ["сбрехав"],
    "сбрехать": ["соврать"],
    "сбрехнув": ["сбрехнувши"],
    "сбрехнувши": ["сбрехнув"],
    "сбрив": ["сбривши"],
    "сбривав": ["сбривавши"],
    "сбривавши": ["сбривав"],
    "сбривши": ["сбрив"],
    "сбрикетировав": ["сбрикетировавши"],
    "сбрикетировавши": ["сбрикетировав"],
    "сброд": ["подонок"],
    "сбродив": ["сбродивши"],
    "сбродивши": ["сбродив"],
    "сброс": ["сбрасывание"],
    "сбросав": ["сбросавши"],
    "сбросавши": ["сбросав"],
    "сбросать": ["побросать"],
    "сбросив": ["сбросивши"],
    "сбросивши": ["сбросив"],
    "сбросить": ["скинуть"],
    "сбросить маску": ["открыться"],
    "сбросный": ["сбросовый"],
    "сбросовый": ["сбросный"],
    "сброшюровав": ["сброшюровавши"],
    "сброшюровавши": ["сброшюровав"],
    "сбрызгивав": ["сбрызгивавши"],
    "сбрызгивавши": ["сбрызгивав"],
    "сбрызнув": ["сбрызнувши"],
    "сбрызнувши": ["сбрызнув"],
    "сбрякав": ["сбрякавши"],
    "сбрякавши": ["сбрякав"],
    "сбрякнув": ["сбрякнувши"],
    "сбрякнувши": ["сбрякнув"],
    "сбудив": ["сбудивши"],
    "сбудивши": ["сбудив"],
    "сбуксовав": ["сбуксовавши"],
    "сбуксовавши": ["сбуксовав"],
    "сбулгачив": ["сбулгачивши"],
    "сбулгачивши": ["сбулгачив"],
    "сбуруздив": ["сбуруздивши"],
    "сбуруздивши": ["сбуруздив"],
    "сбуруздить": ["стащить"],
    "сбыв": ["сбывши"],
    "сбывав": ["сбывавши"],
    "сбывавши": ["сбывав"],
    "сбывать": ["продавать", "сплавлять", "всучивать", "спадать", "убывать"],
    "сбывши": ["сбыв"],
    "сбыт": ["продажа", "торговля", "распространение"],
    "сбытовой": ["сбытовый"],
    "сбытовый": ["сбытовой"],
    "сбыточный": ["осуществимый"],
    "сбыхав": ["сбыхавши"],
    "сбыхавши": ["сбыхав"],
    "сбычив": ["сбычивши"],
    "сбычивши": ["сбычив"],
    "свабив": ["свабивши"],
    "свабивши": ["свабив"],
    "свадебный генерал": ["кондитерский генерал", "зицпредседатель"],
    "свадьба": ["бракосочетание", "годовщина свадьбы", "годовщина"],
    "свази": ["ама-свази", "свати", "сисвати"],
    "свазиленд": ["эсватини"],
    "свазилендец": ["эсватиниец"],
    "свайка": ["тыканка", "вафля", "банан", "болт", "костыль", "палка", "пистон", "аппарат", "штуцер", "щекотунчик"],
    "свайпать": ["свайпить"],
    "свайпить": ["свайпать"],
    "свайпнув": ["свайпнувши"],
    "свайпнувши": ["свайпнув"],
    "свалив": ["сваливши"],
    "сваливав": ["сваливавши"],
    "сваливавши": ["сваливав"],
    "сваливание": ["слёживание"],
    "сваливши": ["свалив"],
    "свалить": ["навалить", "сбросить", "повалить", "свергнуть", "низвергнуть", "переложить", "подставить", "обвинить"],
    "свалка": ["свал", "сваливание", "помойка", "куча", "груда", "драка", "побоище", "потасовка"],
    "свальный": ["свалочный"],
    "свальцевав": ["свальцевавши"],
    "свальцевавши": ["свальцевав"],
    "сваляв": ["свалявши"],
    "свалявши": ["сваляв"],
    "свалять дурака": ["сглупить", "сплошать"],
    "сваншотив": ["сваншотивши"],
    "сваншотивши": ["сваншотив"],
    "свао": ["северо-восточный административный округ"],
    "свап": ["своп"],
    "свара": ["раздор", "ссора", "распря"],
    "сварганив": ["сварганивши"],
    "сварганивши": ["сварганив"],
    "сварганить": ["соорудить", "сделать", "изготовить"],
    "сварение": ["переваривание", "самосварение"],
    "сваренье": ["сварение"],
    "сварив": ["сваривши"],
    "сваривав": ["сваривавши"],
    "сваривавши": ["сваривав"],
    "сваривши": ["сварив"],
    "сварливый": ["склочный", "вздорный", "ворчливый", "брюзгливый"],
    "сварня": ["сварка"],
    "сварьировав": ["сварьировавши"],
    "сварьировавши": ["сварьировав"],
    "свастика": ["солнцеворот", "ярга", "крюковидный крест", "крюковой крест", "крючковатый крест", "молот тора", "гаммадион", "гаммированный крест", "гамма-крест", "крест крампоне", "паучий крест", "свастон"],
    "свастон": ["свастика"],
    "сватав": ["сватавши"],
    "сватавши": ["сватав"],
    "сватание": ["сватовство"],
    "сватанье": ["сватовство", "сватание"],
    "свати": ["сисвати", "свази"],
    "сватовство": ["сватание", "сватанье"],
    "свах": ["сас", "сахв"],
    "сваха": ["сводня", "сватья"],
    "свевав": ["свевавши"],
    "свевавши": ["свевав"],
    "сведав": ["сведавши"],
    "сведавши": ["сведав"],
    "сведущий": ["компетентный", "осведомлённый", "знающий", "опытный"],
    "сведывав": ["сведывавши"],
    "сведывавши": ["сведывав"],
    "сведывать": ["осведомляться"],
    "свежанина": ["свеженина", "свежатина", "свежина", "свежак"],
    "свежатина": ["свежанина", "свеженина"],
    "свежев": ["свежевши"],
    "свежевав": ["свежевавши"],
    "свежевавши": ["свежевав"],
    "свежевать": ["разделывать"],
    "свежевши": ["свежев"],
    "свежевыкопанный": ["свежевырытый"],
    "свежевырытый": ["свежевыкопанный"],
    "свежезабитый": ["свежезарезанный"],
    "свежезарезанный": ["свежезабитый"],
    "свеженина": ["свежатина", "свежина"],
    "свежеотжатый": ["свежевыжатый"],
    "свежесварганенный": ["свеженаписанный"],
    "свежив": ["свеживши"],
    "свеживши": ["свежив"],
    "свежий": ["новый", "нележалый", "чистый", "бодрящий", "здоровый", "прохладный", "холодный", "незамутнённый", "бодрый", "восстановленный", "обновлённый"],
    "свезя": ["свёзши"],
    "свезясь": ["свёзшись"],
    "свеивав": ["свеивавши"],
    "свеивавши": ["свеивав"],
    "свеивать": ["сдувать"],
    "свейский": ["шведский"],
    "свекла": ["свёкла"],
    "свекловица": ["сахарная свёкла"],
    "свековав": ["свековавши"],
    "свековавши": ["свековав"],
    "свекольник": ["ботвинья"],
    "свекрушенька": ["свекруха"],
    "свеликодушничав": ["свеликодушничавши"],
    "свеликодушничавши": ["свеликодушничав"],
    "свенчав": ["свенчавши"],
    "свенчавши": ["свенчав"],
    "свербев": ["свербевши"],
    "свербевши": ["свербев"],
    "свербение": ["свербёж", "зуд"],
    "свербеть": ["чесаться", "зудеть", "подмывать", "не терпится", "беспокоить", "раздражать"],
    "свербив": ["свербивши"],
    "свербивши": ["свербив"],
    "свербёж": ["зуд", "свербение", "свербёжка", "свербячка", "чесотка", "свербёжь"],
    "свергав": ["свергавши"],
    "свергавши": ["свергав"],
    "свергать": ["низвергать", "низлагать", "ниспровергать", "отстранять", "сбрасывать", "скидывать"],
    "свергнув": ["свергнувши"],
    "свергнувши": ["свергнув"],
    "свердлильник": ["свердляр", "свердлувальник"],
    "свердло": ["свердел"],
    "свердловск": ["должанск"],
    "свердловская область": ["свердловщина"],
    "свердлувальник": ["свердлильник", "свердляр"],
    "свердляр": ["свердлильник", "свердлувальник"],
    "свержение": ["опрокидывание", "сбрасывание", "скидывание", "низвержение", "низложение", "ниспровержение"],
    "сверженье": ["свержение"],
    "сверзив": ["сверзивши"],
    "сверзивши": ["сверзив"],
    "сверив": ["сверивши"],
    "сверивши": ["сверив"],
    "сверк": ["блеск"],
    "сверка": ["проверка", "сличение", "сопоставление"],
    "сверкав": ["сверкавши"],
    "сверкавши": ["сверкав"],
    "сверкание": ["сверканье", "блеск", "сияние"],
    "сверкать": ["блистать", "вспыхивать", "блестеть", "лучиться", "сиять"],
    "сверкнув": ["сверкнувши"],
    "сверкнувши": ["сверкнув"],
    "сверкнуть": ["блеснуть", "вспыхнуть", "мелькнуть", "пролететь", "загореться"],
    "сверление": ["сверленье", "сверловка", "просверливание", "просверливанье"],
    "сверлив": ["сверливши"],
    "сверливав": ["сверливавши"],
    "сверливавши": ["сверливав"],
    "сверливши": ["сверлив"],
    "сверлильный": ["буровой"],
    "сверлильщик": ["сверловщик"],
    "сверло": ["бурав"],
    "сверловка": ["сверление"],
    "сверловщик": ["сверлильщик"],
    "свернув": ["свернувши"],
    "свернувши": ["свернув"],
    "свернуть": ["скрутить", "смотать"],
    "свернуться": ["скататься", "закрыться", "свалиться", "опрокинуться"],
    "сверстав": ["сверставши"],
    "сверставши": ["сверстав"],
    "сверстник": ["однолеток", "ровесник", "одногодок", "товарищ"],
    "сверстница": ["ровесница"],
    "свертев": ["свертевши"],
    "свертевши": ["свертев"],
    "сверх": ["поверх", "сверху", "помимо", "более", "вопреки"],
    "сверх абонемента": ["с превышением"],
    "сверх меры": ["слишком", "сильно", "очень", "чересчур", "чрезмерно", "излишне", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно", "в значительной мере", "зело", "шибко"],
    "сверх-": ["ультра-", "гипер-", "супер-", "экстра-", "архи-"],
    "сверх-я": ["супер-эго"],
    "сверхбогатый": ["богатейший", "супербогатый"],
    "сверхбогач": ["супербогач", "ультрабогач"],
    "сверхвысокий": ["высоченный", "заоблачный", "огромадный", "огроменный", "сверхсильный", "сверхмощный", "сверхзатратный"],
    "сверхгород": ["мегаполис", "супергород"],
    "сверхдержава": ["супердержава", "великая держава"],
    "сверхдешёвый": ["ультрадешёвый", "недорогой", "доступный"],
    "сверхдоход": ["сверхприбыль"],
    "сверхзатратный": ["высокозатратный"],
    "сверхзащищённый": ["суперзащищённый"],
    "сверхидея": ["суперидея"],
    "сверхкапитализация": ["перекапитализация"],
    "сверхкорпорация": ["мегакорпорация"],
    "сверхмарафон": ["супермарафон"],
    "сверхмассивный": ["сверхтяжёлый"],
    "сверхмодный": ["супермодный"],
    "сверхнагрузка": ["супернагрузка"],
    "сверхнадёжный": ["супернадёжный"],
    "сверхновая звезда": ["сверхновая"],
    "сверхобычный": ["сверхординарный", "необычайный", "сверхъестественный", "заурядный"],
    "сверхоплодотворение": ["суперфекундация"],
    "сверхоптимистический": ["сверхоптимистичный"],
    "сверхоптимистичный": ["сверхоптимистический"],
    "сверхопытный": ["трансцендентный"],
    "сверхоружие": ["супероружие"],
    "сверхпамять": ["гипермнезия"],
    "сверхранний": ["ранний", "сверхбыстрый"],
    "сверхраспространитель": ["суперраспространитель", "суперспредер"],
    "сверхсамка": ["суперсамка", "метасамка"],
    "сверхсема": ["архисема"],
    "сверхскоростной": ["гиперскоростной"],
    "сверхспособность": ["талант"],
    "сверхсрочник": ["сверхсрочнослужащий"],
    "сверхценный": ["высокоценный", "многоценный", "важный", "неоценимый", "ценнейший"],
    "сверхцентрализация": ["суперцентрализация"],
    "сверхчеловек": ["юберменш", "белокурая бестия", "ариец"],
    "сверхчувствительность": ["гиперэстезия", "гиперестезия"],
    "сверхширокий": ["сверхширокоугольный"],
    "сверхширокоугольный": ["сверхширокий"],
    "сверхшпион": ["супершпион"],
    "сверхъестественный": ["чудесный", "божественный", "исключительный", "невероятный", "необычайный"],
    "сверчав": ["сверчавши"],
    "сверчавши": ["сверчав"],
    "сверчивав": ["сверчивавши"],
    "сверчивавши": ["сверчивав"],
    "сверчок": ["блоха", "тля", "вошь"],
    "свершав": ["свершавши"],
    "свершавши": ["свершав"],
    "свершатель": ["свершитель", "свершительница", "совершатель", "совершательница", "свершательница"],
    "свершательница": ["свершительница", "совершательница", "совершительница"],
    "свершать": ["совершать", "производить", "делать"],
    "свершенье": ["содеванье", "содеянье", "соделыванье", "соделанье", "сделанье"],
    "свершив": ["свершивши"],
    "свершивши": ["свершив"],
    "свершительница": ["свершитель", "совершатель", "совершательница", "свершатель", "свершательница"],
    "свершиться": ["произойти", "случиться"],
    "сверяв": ["сверявши"],
    "сверявши": ["сверяв"],
    "свесив": ["свесивши"],
    "свесивши": ["свесив"],
    "свеситься": ["взвеситься"],
    "свести счёты с жизнью": ["покончить с собой", "наложить на себя руки"],
    "свет": ["сияние"],
    "светав": ["светавши"],
    "светавши": ["светав"],
    "светать": ["рассветать", "светлеть"],
    "светив": ["светивши"],
    "светивши": ["светив"],
    "светик": ["радость", "душа"],
    "светило": ["звезда", "талант", "корифей"],
    "светильный": ["светиленный", "светильничный"],
    "светить": ["сиять", "гореть", "показывать"],
    "светиться": ["блистать", "сиять", "сверкать"],
    "светия": ["светец"],
    "светкавица": ["мълния"],
    "светлев": ["светлевши"],
    "светлевши": ["светлев"],
    "светлейший": ["наисветлейший"],
    "светлив": ["светливши"],
    "светливши": ["светлив"],
    "светлить": ["осветлять"],
    "светлица": ["горница", "светёлка"],
    "светло-жёлтый": ["нежно-жёлтый", "бледно-жёлтый", "блекло-жёлтый", "блёкло-жёлтый", "слабо-жёлтый", "бело-жёлтый", "светложёлтый"],
    "светло-коричневый": ["светло-бежевый", "светло-ореховый"],
    "светло-серый": ["светло-пепельный", "пепельный"],
    "светлобородый": ["белобородый", "седобородый"],
    "светлобровый": ["белобровый", "седобровый"],
    "светловав": ["светловавши"],
    "светловавши": ["светловав"],
    "светловолосый": ["белокурый", "светлоголовый", "белоголовый", "блондинистый", "белобрысый"],
    "светлоглазый": ["светлоокий"],
    "светлоголовый": ["светловолосый", "белокурый"],
    "светлодарск": ["светлодарское"],
    "светложёлтый": ["светло-жёлтый", "нежно-жёлтый", "бледно-жёлтый", "блекло-жёлтый", "блёкло-жёлтый", "слабо-жёлтый", "бело-жёлтый"],
    "светлоклеточный": ["гипернефроидный"],
    "светлоликий": ["светлолицый"],
    "светлолицый": ["светлоликий"],
    "светлоокий": ["светлоглазый"],
    "светлота": ["светлость", "яркость", "свет", "освещённость"],
    "светлый": ["освещённый", "яркий", "ясный", "прозрачный", "бледный", "тусклый", "ненасыщенный", "радостный", "счастливый", "весёлый", "приятный", "отчётливый", "пасхальный"],
    "светляк": ["светлячок"],
    "светлячок": ["светляк"],
    "светобоязнь": ["гелиофобия"],
    "световозвращатель": ["катафот"],
    "светодиод": ["светоизлучающий диод", "сид"],
    "светозарность": ["сияние", "блистание", "ясность"],
    "светозарный": ["лучезарный", "лучистый", "светоносный", "сияющий", "сверкающий", "радостный", "радужный"],
    "светозвуковой": ["светошумовой"],
    "светоносный эфир": ["эфир"],
    "светоотражатель": ["катафот"],
    "светопись": ["фотография"],
    "светопреставление": ["конец света", "беспорядок", "суматоха", "неразбериха"],
    "светопрозрачный": ["светопроницаемый"],
    "светопрочный": ["светостойкий"],
    "светорегулятор": ["диммер"],
    "светостойкий": ["светоустойчивый", "светопрочный"],
    "светофильтр": ["цветофильтр"],
    "светофор": ["калейдоскоп", "попугай"],
    "светоч": ["свеча", "факел", "светило"],
    "светошумовой": ["светозвуковой"],
    "светски": ["по-светски"],
    "светский": ["комильфотный", "бонтонный", "изысканный", "галантный", "мирской", "гражданский", "секулярный"],
    "светёлка": ["светлица"],
    "свеча": ["кандела", "свеча зажигания", "суппозиторий", "свечка", "берёзка", "сарвангасана", "випарита-карани", "братчина", "канун"],
    "свечение": ["свет", "сияние"],
    "свеченье": ["свечение"],
    "свечерев": ["свечеревши"],
    "свечеревши": ["свечерев"],
    "свечечка": ["свечка"],
    "свечка": ["суппозиторий", "свеча", "башня", "столбик", "коробка"],
    "свешав": ["свешавши"],
    "свешавши": ["свешав"],
    "свешивав": ["свешивавши"],
    "свешивавши": ["свешивав"],
    "свешиваться": ["свисать", "опускаться", "склоняться", "нависать"],
    "свеяв": ["свеявши"],
    "свеявши": ["свеяв"],
    "свив": ["свивши"],
    "свивав": ["свивавши"],
    "свивавши": ["свивав"],
    "свиваться": ["сворачиваться", "свёртываться", "сплетаться"],
    "свивши": ["свив"],
    "свидание": ["свиданье"],
    "свиданка": ["свидание", "свиданье", "свиданочка"],
    "свиданье": ["свидание"],
    "свидетельствовав": ["свидетельствовавши"],
    "свидетельствовавши": ["свидетельствовав"],
    "свидетельствование": ["демонстрирование", "знаменование", "констатирование", "подтверждение", "свидетельство", "удостоверение", "указывание"],
    "свидеться": ["встретиться", "повидаться", "увидеться"],
    "свидомый": ["ответственный", "свидомит"],
    "свизировав": ["свизировавши"],
    "свизировавши": ["свизировав"],
    "свилеватость": ["косослойность"],
    "свилеватый": ["косослойный"],
    "свиливав": ["свиливавши"],
    "свиливавши": ["свиливав"],
    "свильнув": ["свильнувши"],
    "свильнувши": ["свильнув"],
    "свинарня": ["свинарник"],
    "свиная рожа": ["поросячья рожа"],
    "свинговав": ["свинговавши"],
    "свинговавши": ["свинговав"],
    "свинец": ["плюмбум", "рейхблей", "церуссит", "алтаит", "веркблей", "пуля"],
    "свинець": ["плюмбум", "куля"],
    "свинка": ["поросёнок", "свинюшка", "свинёнок", "хрюшка"],
    "свиновод": ["свинарь", "бездарь"],
    "свиноголовый": ["свинорылый"],
    "свиное рыло": ["свинячье рыло", "собачье рыло", "суконное рыло", "немытое рыло", "неумытое рыло"],
    "свиной": ["свинячий"],
    "свинолюфтваффе": ["укролюфтваффе", "салолюфтваффе", "хохлолюфтваффе"],
    "свинорылый": ["свиноголовый"],
    "свинособака": ["ватник", "колорад", "орк", "рашист"],
    "свиноукреп": ["укроукреп", "хохлоукреп"],
    "свинский": ["низменный", "гадкий", "противный", "свиноподобный"],
    "свинство": ["срач", "невежество", "бескультурье", "подлость"],
    "свинтив": ["свинтивши"],
    "свинтивши": ["свинтив"],
    "свинтить": ["скрутить", "отвинтить", "открутить", "свалить", "смыться", "убежать", "бежать", "схватить", "арестовать", "задержать"],
    "свинтус": ["свинья", "негодник"],
    "свинуха": ["свинушка", "свинарь", "голубец", "синюха", "дуплянка"],
    "свинцевав": ["свинцевавши"],
    "свинцевавши": ["свинцевав"],
    "свинцовев": ["свинцовевши"],
    "свинцовевши": ["свинцовев"],
    "свинцовистый": ["свинцовосодержащий"],
    "свинчатка": ["налиток"],
    "свинченный": ["привинченный", "завинченный", "отвинченный"],
    "свинчивав": ["свинчивавши"],
    "свинчивавши": ["свинчивав"],
    "свинщина": ["свинство", "скотщина"],
    "свинья": ["хрюшка", "хавронья", "свинина"],
    "свинячив": ["свинячивши"],
    "свинячивши": ["свинячив"],
    "свинячий": ["свиной"],
    "свинёнок": ["поросёнок"],
    "свиповав": ["свиповавши"],
    "свиповавши": ["свиповав"],
    "свирелка": ["свирелька"],
    "свирель": ["цевница"],
    "свирель пана": ["пан-флейта", "флейта пана"],
    "свирепев": ["свирепевши"],
    "свирепевши": ["свирепев"],
    "свирепеть": ["сатанеть"],
    "свирепо": ["люто", "яростно"],
    "свирепость": ["дикость", "жестокость", "кровожадность"],
    "свирепство": ["свирепость", "жестокость"],
    "свирепствовав": ["свирепствовавши"],
    "свирепствовавши": ["свирепствовав"],
    "свирепствовать": ["неистовствовать", "буянить", "яриться", "злобствовать", "зверствовать", "бушевать", "буйствовать"],
    "свиристев": ["свиристевши"],
    "свиристевши": ["свиристев"],
    "свиристеть": ["щебетать", "трещать", "скворчать", "свистеть", "насвистывать"],
    "свисав": ["свисавши"],
    "свисавши": ["свисав"],
    "свисающий": ["свешивающийся"],
    "свиснув": ["свиснувши"],
    "свиснувши": ["свиснув"],
    "свистав": ["свиставши"],
    "свиставши": ["свистав"],
    "свистев": ["свистевши"],
    "свистевши": ["свистев"],
    "свистеть": ["лгать"],
    "свистнув": ["свистнувши"],
    "свистнувши": ["свистнув"],
    "свистопляс": ["свистопляска"],
    "свистулька": ["окарина"],
    "свистун": ["пустозвон"],
    "свистящий": ["свищущий", "насвистывающий", "подсвистывающий", "посвистывающий", "присвистывающий"],
    "свистящий согласный": ["сибилянт", "сибилянтный звук", "сибилянтный согласный"],
    "свитер": ["джемпер", "пуловер", "кофта"],
    "свитка": ["свита"],
    "свитч": ["свич", "коммутатор"],
    "свить": ["сплести"],
    "свихивав": ["свихивавши"],
    "свихивавши": ["свихивав"],
    "свихнув": ["свихнувши"],
    "свихнувши": ["свихнув"],
    "свихнуться": ["помешаться", "сойти с ума", "рехнуться", "сбрендить", "спятить", "тронуться", "тронуться рассудком", "чокнуться", "повернуться"],
    "свищ": ["раковина", "фистула", "хлыщ", "свистуха", "волосатик"],
    "свияга": ["свиязь"],
    "свиязь": ["свияга", "свистун"],
    "свобода": ["выбор", "воля", "суверенитет"],
    "свободив": ["свободивши"],
    "свободивши": ["свободив"],
    "свободная вода": ["гравитационная вода"],
    "свободная лицензия": ["публичная лицензия"],
    "свободно": ["вольно", "независимо", "беспрепятственно", "легко", "непринуждённо"],
    "свободно конвертируемая валюта": ["твёрдая конвертируемая валюта", "конвертируемая валюта", "обратимая валюта", "скв"],
    "свободнорождённый": ["свободный"],
    "свободные отношения": ["полигамия"],
    "свободный": ["вольный", "неограниченный", "беспрепятственный", "вакантный"],
    "свободомыслие": ["вольнодумие", "вольнодумство"],
    "свободомыслящий": ["либеральный", "вольнодумный"],
    "свобождав": ["свобождавши"],
    "свобождавши": ["свобождав"],
    "свод": ["сведение", "корпус", "собрание", "арка"],
    "сводив": ["сводивши"],
    "сводивши": ["сводив"],
    "сводник": ["сводня"],
    "сводничав": ["сводничавши"],
    "сводничавши": ["сводничав"],
    "сводничать": ["сутенёрить"],
    "сводной": ["переводной"],
    "сводня": ["сводница"],
    "сводчатый": ["арочный"],
    "своеволив": ["своеволивши"],
    "своеволивши": ["своеволив"],
    "своеволие": ["самодурство", "своевластность", "упрямство"],
    "своеволье": ["своеволие"],
    "своевольничав": ["своевольничавши"],
    "своевольничавши": ["своевольничав"],
    "своевольный": ["своенравный", "самовольный"],
    "своевольствовав": ["своевольствовавши"],
    "своевольствовавши": ["своевольствовав"],
    "своевременно": ["вовремя"],
    "своевременный": ["оперативный"],
    "своекорыстие": ["корыстолюбие"],
    "своекорыстье": ["своекорыстие"],
    "своенравие": ["своенравность"],
    "своенравничав": ["своенравничавши"],
    "своенравничавши": ["своенравничав"],
    "своенравничать": ["блажить", "дурить", "глупить", "нервничать", "капризничать", "привередничать", "причудничать", "самодурствовать", "своевольничать", "сумасбродить", "чудить"],
    "своенравный": ["норовистый", "своевольный", "взбалмошный"],
    "своеобразный": ["необычный", "оригинальный", "своеобычный", "на особину", "на особинку"],
    "своеобразье": ["своеобразие"],
    "своеобычливый": ["своенравный", "своеобычный"],
    "своеобычность": ["своеобычие", "индивидуальность", "неординарность", "неповторимость", "непохожесть", "самобытность", "своеобразие", "своеобразность"],
    "своеобычный": ["самобытный", "своеобразный", "своенравный", "своеобычливый"],
    "свозив": ["свозивши"],
    "свозивши": ["свозив"],
    "свои пять копеек": ["внести свою лепту"],
    "своим ходом": ["самостоятельно"],
    "своим чередом": ["той же чередой"],
    "свой": ["собственный", "некий", "определённый", "наш"],
    "свой парень": ["свой в доску парень", "свой парень в доску", "свой в доску", "вот такой  чувак", "наш человек", "пацанка"],
    "свойлачивав": ["свойлачивавши"],
    "свойлачивавши": ["свойлачивав"],
    "свойский": ["свой", "родной", "близкий"],
    "свойственник": ["свояк"],
    "свойственница": ["своячница", "свояченица"],
    "свойственно": ["присуще", "характерно"],
    "свойственный": ["присущий", "характерный"],
    "свойство": ["черта", "особенность", "качество", "природа", "натура", "характер", "порядок", "план", "атрибут"],
    "сволакивав": ["сволакивавши"],
    "сволакивавши": ["сволакивав"],
    "сволок": ["матница"],
    "сволота": ["сволочь", "сброд"],
    "сволочив": ["сволочивши"],
    "сволочивши": ["сволочив"],
    "сволочь": ["сволота", "сброд", "мерзавец", "скотина", "подлец", "подонок", "тварь", "мразь", "мразота", "падло"],
    "свон": ["суон"],
    "свора": ["стая"],
    "сворачивав": ["сворачивавши"],
    "сворачивавши": ["сворачивав"],
    "сворачивание": ["поворачивание"],
    "сворачивать": ["закруглять"],
    "сворачиваться": ["свёртываться", "скручиваться", "свиваться"],
    "сворив": ["своривши"],
    "своривши": ["сворив"],
    "сворка": ["поводок"],
    "своровав": ["своровавши"],
    "своровавши": ["своровав"],
    "своротив": ["своротивши"],
    "своротивши": ["своротив"],
    "своротка": ["отворот", "отворотка", "свёрток"],
    "сворочав": ["сворочавши"],
    "сворочавши": ["сворочав"],
    "свояк": ["свой шар", "своя игра"],
    "свояченица": ["свестка", "свесть", "свестья", "свесь", "свойка", "своякиня", "своячина", "своячница", "ятровь", "ятровья"],
    "своячница": ["свояченица", "своячена"],
    "свредел": ["бургия"],
    "свч-печь": ["микроволновая печь", "микроволновка", "мв-печь"],
    "свыв": ["свывши"],
    "свывши": ["свыв"],
    "свыкнуться": ["сжиться", "привыкнуть", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "прижиться", "освоиться"],
    "свысока": ["сверху"],
    "свыть": ["провыть"],
    "свычай": ["свычка"],
    "связав": ["связавши"],
    "связавши": ["связав"],
    "связанный": ["свободный"],
    "связать": ["скрутить"],
    "связист": ["телекоммуникационщик"],
    "связка": ["связывание", "пучок", "вязанка", "копула"],
    "связно": ["толком", "складно"],
    "связный": ["складный"],
    "связывав": ["связывавши"],
    "связывавши": ["связывав"],
    "связыванье": ["связывание"],
    "связывать": ["скручивать", "объяснять", "увязывать", "соединять", "объединять", "сковывать"],
    "связь": ["союз", "альянс", "коалиция", "партнёрство", "объединение", "соединение", "роман", "любовь", "рука", "телекоммуникация"],
    "свянув": ["свянувши"],
    "свянувши": ["свянув"],
    "свясло": ["перевясло"],
    "свяст": ["съзнание", "разум", "съвест"],
    "свят": ["земята", "планетата", "вселената", "планета", "звезда", "мир", "народ", "общество"],
    "святая вода": ["освящённый", "вода", "живая вода", "мёртвая вода"],
    "святая святых": ["святилище"],
    "святив": ["святивши"],
    "святивши": ["святив"],
    "святилище": ["санктуарий"],
    "святительствовав": ["святительствовавши"],
    "святительствовавши": ["святительствовав"],
    "святить": ["освящать"],
    "святки": ["святые дни", "святые вечера"],
    "свято место пусто не бывает": ["не терпит пустоты", "незаменимых нет"],
    "святогорск": ["банное", "славяногорск"],
    "святой грааль": ["чаша", "кубок"],
    "святой престол": ["ватикан"],
    "святослав": ["свят"],
    "святотатец": ["богохульник"],
    "святотатственно": ["святотатно", "кощунственно"],
    "святотатство": ["кощунство"],
    "святотатствовав": ["святотатствовавши"],
    "святотатствовавши": ["святотатствовав"],
    "святотатствовать": ["кошунствовать"],
    "святочний": ["святковий"],
    "святцы": ["месяцеслов"],
    "святыня": ["реликвия"],
    "священная корова": ["святыня"],
    "священная римская империя": ["первый рейх", "сри"],
    "священник": ["священнослужитель", "клирик", "поп"],
    "священнодействовав": ["священнодействовавши"],
    "священнодействовавши": ["священнодействовав"],
    "священнослужитель": ["клирик"],
    "священный": ["культовый", "сакральный", "святой", "почтительный", "благоговейный"],
    "священство": ["благодать", "помазание", "духовенство", "священничество", "жречество"],
    "священствовав": ["священствовавши"],
    "священствовавши": ["священствовав"],
    "свёзши": ["свезя"],
    "свёзшись": ["свезясь"],
    "свёкла": ["бурак"],
    "свёрстывав": ["свёрстывавши"],
    "свёрстывавши": ["свёрстывав"],
    "свёртка": ["конволюция"],
    "свёрток": ["рулон", "свиток", "трубочка", "бумага", "кулёк", "обёртка", "пакет", "пачка", "упаковка", "отворот", "отворотка", "своротка", "сгусток"],
    "свёрточная нейронная сеть": ["снс"],
    "свёрточный": ["конволюционный"],
    "свёртывав": ["свёртывавши"],
    "свёртывавши": ["свёртывав"],
    "свёртывать": ["сворачивать", "скатывать"],
    "сгадав": ["сгадавши"],
    "сгадавши": ["сгадав"],
    "сгадывав": ["сгадывавши"],
    "сгадывавши": ["сгадывав"],
    "сгарав": ["сгаравши"],
    "сгаравши": ["сгарав"],
    "сгаснув": ["сгаснувши"],
    "сгаснувши": ["сгаснув"],
    "сгенерировав": ["сгенерировавши"],
    "сгенерировавши": ["сгенерировав"],
    "сгенерировать": ["породить", "произвести", "создать"],
    "сгибав": ["сгибавши"],
    "сгибавши": ["сгибав"],
    "сгибаемость": ["изгибаемость", "гибкость"],
    "сгибание": ["согнутие"],
    "сгибать": ["гнуть", "изгибать", "искривлять"],
    "сгибаться": ["гнуться", "изгибаться"],
    "сгибнув": ["сгибнувши"],
    "сгибнувши": ["сгибнув"],
    "сгибнуть": ["погибнуть", "пропасть"],
    "сгинать": ["погибать", "умирать"],
    "сгинув": ["сгинувши"],
    "сгинувши": ["сгинув"],
    "сгинуть": ["сгибнуть", "исчезнуть", "пропасть"],
    "сгладив": ["сгладивши"],
    "сгладивши": ["сгладив"],
    "сгладывав": ["сгладывавши"],
    "сгладывавши": ["сгладывав"],
    "сглаживав": ["сглаживавши"],
    "сглаживавши": ["сглаживав"],
    "сглаз": ["дурной глаз", "глаз"],
    "сглазив": ["сглазивши"],
    "сглазивши": ["сглазив"],
    "сглатывав": ["сглатывавши"],
    "сглатывавши": ["сглатывав"],
    "сглатывать": ["проглатывать"],
    "сглодав": ["сглодавши"],
    "сглодавши": ["сглодав"],
    "сглонув": ["сглонувши"],
    "сглонувши": ["сглонув"],
    "сглотав": ["сглотавши"],
    "сглотавши": ["сглотав"],
    "сглотать": ["сожрать"],
    "сглотнув": ["сглотнувши"],
    "сглотнувши": ["сглотнув"],
    "сглупив": ["сглупивши"],
    "сглупивши": ["сглупив"],
    "сглуповав": ["сглуповавши"],
    "сглуповавши": ["сглуповав"],
    "сглуповать": ["сглупить"],
    "сгнаивав": ["сгнаивавши"],
    "сгнаивавши": ["сгнаивав"],
    "сгнетав": ["сгнетавши"],
    "сгнетавши": ["сгнетав"],
    "сгнив": ["сгнивши"],
    "сгнивав": ["сгнивавши"],
    "сгнивавши": ["сгнивав"],
    "сгнивши": ["сгнив"],
    "сгнить": ["изгнить", "сгинуть"],
    "сгноив": ["сгноивши"],
    "сгноивши": ["сгноив"],
    "сговаривав": ["сговаривавши"],
    "сговаривавши": ["сговаривав"],
    "сговариваться": ["договариваться", "уславливаться"],
    "сговняв": ["сговнявши"],
    "сговнявши": ["сговняв"],
    "сговнять": ["сговнякать", "изговнякать"],
    "сговорив": ["сговоривши"],
    "сговоривши": ["сговорив"],
    "сговорить": ["уговорить"],
    "сговориться": ["договориться", "условиться", "прийти к соглашению"],
    "сговорност": ["съгласие"],
    "сговорчиво": ["уступчиво"],
    "сговорчивость": ["договороспособность"],
    "сговорчивый": ["покладистый", "уступчивый"],
    "сгодиться": ["пригодиться"],
    "сголографировав": ["сголографировавши"],
    "сголографировавши": ["сголографировав"],
    "сгон": ["сгонка"],
    "сгондобив": ["сгондобивши"],
    "сгондобивши": ["сгондобив"],
    "сгондобить": ["сварганить", "свалить"],
    "сгоношив": ["сгоношивши"],
    "сгоношивши": ["сгоношив"],
    "сгоношить": ["сгошить", "сгонодобить"],
    "сгоняв": ["сгонявши"],
    "сгонявши": ["сгоняв"],
    "сгорав": ["сгоравши"],
    "сгоравши": ["сгорав"],
    "сгоранье": ["сгорание"],
    "сгорбатив": ["сгорбативши"],
    "сгорбативши": ["сгорбатив"],
    "сгорбив": ["сгорбивши"],
    "сгорбивши": ["сгорбив"],
    "сгорбиться": ["согнуться", "ссутулиться", "в три погибели", "искривиться", "покоситься"],
    "сгорев": ["сгоревши"],
    "сгоревши": ["сгорев"],
    "сгородив": ["сгородивши"],
    "сгородивши": ["сгородив"],
    "сгоряча": ["вгорячах", "вспылив", "погорячившись", "запальчивость"],
    "сготовив": ["сготовивши"],
    "сготовивши": ["сготовив"],
    "сграбастав": ["сграбаставши"],
    "сграбаставши": ["сграбастав"],
    "сграбив": ["сграбивши"],
    "сграбивши": ["сграбив"],
    "сграда": ["здание"],
    "сграффито": ["граффито"],
    "сгребав": ["сгребавши"],
    "сгребавши": ["сгребав"],
    "сгримасничав": ["сгримасничавши"],
    "сгримасничавши": ["сгримасничав"],
    "сгромоздив": ["сгромоздивши"],
    "сгромоздивши": ["сгромоздив"],
    "сгрохав": ["сгрохавши"],
    "сгрохавши": ["сгрохав"],
    "сгрохать": ["отгрохать"],
    "сгрубив": ["сгрубивши"],
    "сгрубивши": ["сгрубив"],
    "сгрубить": ["нагрубить"],
    "сгрудив": ["сгрудивши"],
    "сгрудивши": ["сгрудив"],
    "сгрудиться": ["столпиться"],
    "сгружав": ["сгружавши"],
    "сгружавши": ["сгружав"],
    "сгруживав": ["сгруживавши"],
    "сгруживавши": ["сгруживав"],
    "сгрузив": ["сгрузивши"],
    "сгрузивши": ["сгрузив"],
    "сгруппировав": ["сгруппировавши"],
    "сгруппировавши": ["сгруппировав"],
    "сгруппировывав": ["сгруппировывавши"],
    "сгруппировывавши": ["сгруппировывав"],
    "сгруппировывать": ["группировать"],
    "сгрустнув": ["сгрустнувши"],
    "сгрустнувши": ["сгрустнув"],
    "сгрустнуть": ["взгрустнуть"],
    "сгрызав": ["сгрызавши"],
    "сгрызавши": ["сгрызав"],
    "сгрызть": ["съесть"],
    "сгубив": ["сгубивши"],
    "сгубивши": ["сгубив"],
    "сгубить": ["погубить"],
    "сгустив": ["сгустивши"],
    "сгустивши": ["сгустив"],
    "сгуститься": ["загустеть"],
    "сгусток": ["комок"],
    "сгущав": ["сгущавши"],
    "сгущавши": ["сгущав"],
    "сгущенье": ["сгущение"],
    "сгущёнка": ["сгущённое молоко", "спущёнка"],
    "сгущённое молоко": ["сгущёнка"],
    "сд-проигрыватель": ["компакт-диск-проигрыватель", "компакт-проигрыватель"],
    "сдабривав": ["сдабривавши"],
    "сдабривавши": ["сдабривав"],
    "сдабривать": ["приправлять", "скрашивать"],
    "сдав": ["сдавши"],
    "сдавав": ["сдававши"],
    "сдававши": ["сдавав"],
    "сдавать": ["раздавать", "выдавать"],
    "сдаваться": ["арендоваться"],
    "сдавив": ["сдавивши"],
    "сдавивши": ["сдавив"],
    "сдавливав": ["сдавливавши"],
    "сдавливавши": ["сдавливав"],
    "сдавливание": ["сжимание", "стискивание"],
    "сдавливать": ["сжимать", "стискивать"],
    "сдавши": ["сдав"],
    "сдаивав": ["сдаивавши"],
    "сдаивавши": ["сдаивав"],
    "сдать": ["выдать"],
    "сдаться": ["поддаться", "подчиниться", "спасовать", "капитулировать", "пасть", "уступить", "отдаться", "предлагаться"],
    "сдваивав": ["сдваивавши"],
    "сдваивавши": ["сдваивав"],
    "сдваивание": ["спаривание"],
    "сдвиг": ["сдвигание", "улучшение"],
    "сдвигав": ["сдвигавши"],
    "сдвигавши": ["сдвигав"],
    "сдвигать": ["двигать", "сближать"],
    "сдвигаться": ["смещаться", "трогаться"],
    "сдвиженье": ["сдвижение"],
    "сдвинув": ["сдвинувши"],
    "сдвинувши": ["сдвинув"],
    "сдвинуться": ["сместиться", "стронуться", "тронуться", "сойтись"],
    "сдвоенье": ["сдвоение"],
    "сдвоив": ["сдвоивши"],
    "сдвоивши": ["сдвоив"],
    "сдвурушничав": ["сдвурушничавши"],
    "сдвурушничавши": ["сдвурушничав"],
    "сдев": ["сдевши"],
    "сдевав": ["сдевавши"],
    "сдевавши": ["сдевав"],
    "сдевши": ["сдев"],
    "сдезертировав": ["сдезертировавши"],
    "сдезертировавши": ["сдезертировав"],
    "сдействовав": ["сдействовавши"],
    "сдействовавши": ["сдействовав"],
    "сделав": ["сделавши"],
    "сделавши": ["сделав"],
    "сделанный": ["созданный", "изготовленный", "произведённый", "совершённый"],
    "сделать": ["сработать", "состряпать", "управиться", "сладить", "покончить", "соделать", "осуществить", "произвести", "выработать", "изготовить", "соорудить"],
    "сделать брюхо": ["сделать брюхатой", "обрюхатить", "замастерить брюхо", "навертеть брюхо", "намять брюхо", "натереть брюхо"],
    "сделать милость": ["пожалуйста"],
    "сделать предложение": ["попросить руки", "предложить руку и сердце", "присвататься", "посвататься"],
    "сделать ручкой": ["поприветствовать", "поздороваться", "попрощаться"],
    "сделаться": ["стать", "превратиться", "произойти", "случиться", "совершиться", "возникнуть", "образоваться", "появиться", "стать сделанным", "рассчитаться", "договориться", "отомстить", "наказать", "поквитаться", "посчитаться"],
    "сделка": ["сговор"],
    "сделковый": ["сделочный", "транзакционный"],
    "сделочный": ["сделковый"],
    "сдержав": ["сдержавши"],
    "сдержавши": ["сдержав"],
    "сдержанность": ["скромность", "кротость", "модестия"],
    "сдержать": ["удержать"],
    "сдерживав": ["сдерживавши"],
    "сдерживавши": ["сдерживав"],
    "сдерживаться": ["владеть собой", "сохранять самообладание", "удерживаться", "ограничиваться"],
    "сдерзив": ["сдерзивши"],
    "сдерзивши": ["сдерзив"],
    "сдетонировав": ["сдетонировавши"],
    "сдетонировавши": ["сдетонировав"],
    "сдивиться": ["сдивоваться"],
    "сдирав": ["сдиравши"],
    "сдиравши": ["сдирав"],
    "сдоба": ["сдобные изделия"],
    "сдобив": ["сдобивши"],
    "сдобивши": ["сдобив"],
    "сдобрив": ["сдобривши"],
    "сдобривши": ["сдобрив"],
    "сдобровав": ["сдобровавши"],
    "сдобровавши": ["сдобровав"],
    "сдодав": ["сдодавши"],
    "сдодавши": ["сдодав"],
    "сдозировав": ["сдозировавши"],
    "сдозировавши": ["сдозировав"],
    "сдоив": ["сдоивши"],
    "сдоивши": ["сдоив"],
    "сдолбив": ["сдолбивши"],
    "сдолбивши": ["сдолбив"],
    "сдохнув": ["сдохнувши"],
    "сдохнувши": ["сдохнув"],
    "сдохнуть": ["пасть", "подохнуть"],
    "сдр": ["специальные права заимствования", "спз", "сомалийская демократическая республика", "сомали"],
    "сдрейфив": ["сдрейфивши"],
    "сдрейфивши": ["сдрейфив"],
    "сдрейфить": ["струсить", "испугаться"],
    "сдрейфовав": ["сдрейфовавши"],
    "сдрейфовавши": ["сдрейфовав"],
    "сдристнув": ["сдристнувши"],
    "сдристнувши": ["сдристнув"],
    "сдристнуть": ["чухнуть", "слинять", "врубить съебаторы", "съебаться", "свалить"],
    "сдружав": ["сдружавши"],
    "сдружавши": ["сдружав"],
    "сдружив": ["сдруживши"],
    "сдруживав": ["сдруживавши"],
    "сдруживавши": ["сдруживав"],
    "сдруживши": ["сдружив"],
    "сдружить": ["подружить"],
    "сдублировав": ["сдублировавши"],
    "сдублировавши": ["сдублировав"],
    "сдував": ["сдувавши"],
    "сдувавши": ["сдував"],
    "сдувать": ["списывать", "скатывать"],
    "сдувши": ["сдув"],
    "сдунув": ["сдунувши"],
    "сдунувши": ["сдунув"],
    "сдуплетив": ["сдуплетивши"],
    "сдуплетивши": ["сдуплетив"],
    "сдурев": ["сдуревши"],
    "сдуревши": ["сдурев"],
    "сдурив": ["сдуривши"],
    "сдуривши": ["сдурив"],
    "сдуру": ["по глупости", "тупо"],
    "сдуру можно и хуй сломать": ["сдуру можно и хрен сломать"],
    "сдуть": ["списать", "скатать"],
    "сдыхав": ["сдыхавши"],
    "сдыхавши": ["сдыхав"],
    "сдыхать": ["дохнуть", "подыхать", "издыхать", "околевать", "умирать", "помирать"],
    "сдюжав": ["сдюжавши"],
    "сдюжавши": ["сдюжав"],
    "сдюжив": ["сдюживши"],
    "сдюживши": ["сдюжив"],
    "сдюжить": ["смочь", "суметь", "одолеть", "справиться", "совладать", "выдержать", "вытерпеть"],
    "сдюсшор": ["дюсш", "сдюшор"],
    "сдёргав": ["сдёргавши"],
    "сдёргавши": ["сдёргав"],
    "сдёргивав": ["сдёргивавши"],
    "сдёргивавши": ["сдёргивав"],
    "сдёргивание": ["сдёргиванье"],
    "сдёрнув": ["сдёрнувши"],
    "сдёрнувши": ["сдёрнув"],
    "сдёрнуть": ["сорвать", "стащить"],
    "се": ["вот"],
    "сеанс": ["сессия"],
    "сеансировав": ["сеансировавши"],
    "сеансировавши": ["сеансировав"],
    "себе на уме": ["хитрый", "расчётливый", "лукавый", "плутоватый", "продумчивый", "с хитринкой", "с хитрецой", "хитрый как лиса", "хитрожопый", "скрытный", "неискренний"],
    "себек": ["собек", "собк", "сохет", "собки", "сокнопаис", "сухос"],
    "себеннит": ["севеннит", "саманнуд"],
    "себепожертвувателност": ["самопожертвувателност"],
    "себичност": ["себелюбие", "егоизъм"],
    "себорея": ["дерматит"],
    "себуано": ["себуанский язык"],
    "себялюб": ["себялюбец", "эгоист", "самолюб", "самолюбец"],
    "себялюбец": ["себялюб", "самолюб", "самолюбец", "эгоист"],
    "себялюбиво": ["самолюбиво", "эгоистично"],
    "себялюбивый": ["эгоистичный"],
    "себялюбие": ["эгоизм", "эгоистичность"],
    "себялюбица": ["эгоистка"],
    "себялюбье": ["себялюбие"],
    "себятник": ["эгоист", "себялюбец", "себялюб"],
    "себятничав": ["себятничавши"],
    "себятничавши": ["себятничав"],
    "себятничать": ["эгоизировать"],
    "себятнически": ["эгоистически", "эгоистично"],
    "себятнический": ["эгоистический", "эгоистичный"],
    "себятничество": ["эгоизм", "себялюбие"],
    "себяшка": ["селфи"],
    "сев": ["посев"],
    "севав": ["севавши"],
    "севавши": ["севав"],
    "севастополь": ["ахтиар", "севас"],
    "севдалых": ["севда"],
    "севджур": ["мецамор", "карасу"],
    "север": ["полночь"],
    "севера": ["заполярье", "северная надбавка", "северные", "полярка"],
    "северик": ["северняк", "северяк"],
    "северная ирландия": ["ольстер"],
    "северная корея": ["кндр"],
    "северная македония": ["македония", "республика македония"],
    "северная надбавка": ["севера", "северные", "полярка"],
    "северная осетия": ["алания", "северная осетия-алания"],
    "северное море": ["немецкое море", "белое море"],
    "северное сияние": ["северное сиянье", "полярное сияние", "полярное сиянье"],
    "севернорусский": ["северорусский", "северновеликорусский"],
    "северносаамский": ["севернолапландский", "севернолопарский", "северносаамский язык"],
    "северносемитский": ["северосемитский"],
    "севернофризский": ["севернофризский язык"],
    "северный административный округ": ["сао"],
    "северный кипр": ["турецкая республика северного кипра", "трск"],
    "северный ледовитый океан": ["арктический океан", "ледовитый океан"],
    "северный олень": ["карибу"],
    "северняк": ["северик", "северяк"],
    "северо-восток": ["полночь"],
    "северо-восточный административный округ": ["сзао"],
    "северо-запад": ["норд-вест"],
    "северо-западные территории": ["сзт"],
    "северо-западный административный округ": ["сзао"],
    "северо-кавказский": ["северокавказский"],
    "северо-казахстанская область": ["ско"],
    "северо-северо-западный": ["норд-норд-вестовый"],
    "североатлантический альянс": ["североатлантический договор", "североатлантический блок", "североатлантический пакт", "нато"],
    "северовьетнамец": ["вьетконговец"],
    "северовьетнамский": ["вьетконговский"],
    "северодвинск": ["севск", "молотовск"],
    "северокавказский": ["северо-кавказский"],
    "северорусский": ["севернорусский"],
    "северосемитский": ["северносемитский"],
    "северск": ["берёзки", "яма"],
    "северский донец": ["танаид", "танаис", "сиргис", "тан", "великий дон", "донель", "дон"],
    "северяк": ["северик", "северняк"],
    "северянин": ["северянка", "древляне", "поляне", "древлянин", "полянин"],
    "севилец": ["севильянец", "севильянин"],
    "севильянец": ["севилец"],
    "севок": ["лук-севок", "арбажейка", "арпачик", "овсюжка", "овсюжок", "сенчик", "сеянка"],
    "севооборот": ["многополье"],
    "севрюга": ["севрюжина"],
    "севск": ["северодвинск"],
    "сегеста": ["эгеста", "акеста"],
    "сегестика": ["сисция"],
    "сегмент": ["часть", "сектор", "сегмент рынка", "сегмент сети", "сегмент памяти"],
    "сегментация": ["сегментирование", "сегментированность"],
    "сегментировав": ["сегментировавши"],
    "сегментировавши": ["сегментировав"],
    "сегментирование": ["сегментация"],
    "сегментировать": ["распределить", "распределять"],
    "сегнетоэластик": ["ферроэластик"],
    "сегнетоэлектрик": ["ферроэлектрик"],
    "сегнетоэлектрический релаксор": ["релаксорный сегнетоэлектрик"],
    "сегодняшний": ["свежий", "новый", "нынешний", "современный", "теперешний"],
    "сеголетка": ["сеголеток"],
    "сегрегация": ["разделение"],
    "сегрегировав": ["сегрегировавши"],
    "сегрегировавши": ["сегрегировав"],
    "сегрегироваться": ["обособляться"],
    "седав": ["седавши"],
    "седавши": ["седав"],
    "седалище": ["афедрон", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея", "гузло"],
    "седан": ["паланкин"],
    "седатив": ["седативное"],
    "седативное": ["седатив"],
    "седация": ["анксиолиз"],
    "седев": ["седевши"],
    "седевши": ["седев"],
    "седее": ["седей"],
    "седей": ["седее"],
    "седельник": ["седельщик"],
    "седельщик": ["седельник"],
    "седемнадесет": ["седемнайсет"],
    "седение": ["поседение", "посерение", "побеление"],
    "седентарность": ["малоподвижность"],
    "седентарный": ["прикреплённый", "сидячий"],
    "седенье": ["седение"],
    "седиментационный цикл": ["осадочный цикл"],
    "седина": ["проседь"],
    "седлав": ["седлавши"],
    "седлавши": ["седлав"],
    "седло-узел": ["седлоузел"],
    "седловидный": ["седлообразный"],
    "седлообразный": ["седловидный"],
    "седлоузел": ["седло-узел"],
    "седлоузловой": ["седло-узловой"],
    "седмижды": ["седмищи"],
    "седмица": ["неделя"],
    "седмищи": ["седмижды"],
    "седобородый": ["светлобородый", "белобородый"],
    "седоволосый": ["седовласый"],
    "седой": ["древний", "серебристый"],
    "седок": ["ездок", "пассажир", "вершник", "велосипедист", "мотоциклист"],
    "седьмина": ["седьмушка"],
    "сезам": ["кунжут", "сим-сим"],
    "сезон": ["время года", "пора"],
    "сезональность": ["сезонность"],
    "сезонничав": ["сезонничавши"],
    "сезонничавши": ["сезонничав"],
    "сезонность": ["сезональность"],
    "сеид": ["шериф"],
    "сей": ["этот", "данный"],
    "сейба": ["цейба"],
    "сейв": ["сейв-файл"],
    "сейл": ["распродажа"],
    "сейлз-промоушен": ["стимулирование", "сбыт"],
    "сейм": ["совет", "дума", "эдускунта"],
    "сеймовский": ["сеймовый"],
    "сеймовый": ["сеймовский"],
    "сейсмическая активность": ["сейсмоактивность", "сейсмичность"],
    "сейсмическая изоляция": ["сейсмоизоляция"],
    "сейсмоактивность": ["сейсмическая активность"],
    "сейсмоактивный": ["сейсмичный"],
    "сейсмодатчик": ["сейсмограф"],
    "сейсмоплатформа": ["вибростол"],
    "сейсмособытие": ["землетрясение"],
    "сейсмостойкость": ["сейсмоустойчивость"],
    "сейф": ["несгораемый шкаф"],
    "сейфти-кар": ["машина безопасности"],
    "сейчашний": ["сейчасный"],
    "сейшелы": ["сейшельские острова"],
    "секав": ["секавши"],
    "секавши": ["секав"],
    "секанув": ["секанувши"],
    "секанувши": ["секанув"],
    "секас": ["секис"],
    "секвенатор": ["секвенсор"],
    "секвенировав": ["секвенировавши"],
    "секвенировавши": ["секвенировав"],
    "секвенирование": ["сиквенс"],
    "секвенсор": ["секвенсер"],
    "секвенциальный": ["последовательный"],
    "секвенция": ["прогрессия"],
    "секвестировав": ["секвестировавши"],
    "секвестировавши": ["секвестировав"],
    "секвестирование": ["урезание", "урезывание", "усекание", "сокращение"],
    "секвестировать": ["секвестрировать", "секвестровать", "удалить", "удалять"],
    "секвестрация": ["секвестрование", "секвестр"],
    "секвестрировав": ["секвестрировавши"],
    "секвестрировавши": ["секвестрировав"],
    "секвестрирование": ["секвестрование"],
    "секвестрировать": ["секвестировать"],
    "секвестровав": ["секвестровавши"],
    "секвестровавши": ["секвестровав"],
    "секвестрование": ["секвестр", "секвестрирование"],
    "секвойя": ["мамонтово дерево"],
    "секельда": ["худышка"],
    "секельный": ["клиторный"],
    "секелёчек": ["сикелёчек"],
    "секешфехервар": ["белград", "истолни белград", "штульвайсенбург"],
    "секиль": ["секель", "сикель", "сикиль", "клитор", "похотник", "курок"],
    "секис": ["секс", "секас"],
    "секондарный": ["вторичный", "второстепенный", "неглавный"],
    "секретарив": ["секретаривши"],
    "секретаривши": ["секретарив"],
    "секретарить": ["секретарствовать"],
    "секретарка": ["секретарша", "секретарь"],
    "секретарствовав": ["секретарствовавши"],
    "секретарствовавши": ["секретарствовав"],
    "секретарша": ["секретарка"],
    "секретер": ["бюро"],
    "секретив": ["секретивши"],
    "секретивши": ["секретив"],
    "секретировав": ["секретировавши"],
    "секретировавши": ["секретировав"],
    "секретировать": ["выделять"],
    "секретничав": ["секретничавши"],
    "секретничавши": ["секретничав"],
    "секреторный": ["секреционный"],
    "секс": ["близость", "сексуальный"],
    "секс-инструктор": ["секс-коуч", "секс-тренер"],
    "секс-коуч": ["секс-инструктор", "секс-тренер"],
    "секс-меньшинство": ["квир", "сексуальное меньшинство"],
    "секс-просвещение": ["секспросвет"],
    "секс-тренер": ["секс-инструктор", "секс-коуч"],
    "сексапильность": ["сексапил"],
    "сексапильный": ["привлекательный", "сексуальный", "секси", "эротичный", "пикантный", "заводящий", "зовущий", "распаляющий", "аппетитный"],
    "секси": ["сексапильный", "сексуальный", "секси-шмекси"],
    "секси-шмекси": ["секси"],
    "сексизм": ["половщина", "шовинизм"],
    "сексистка": ["феминистка"],
    "сексовав": ["сексовавши"],
    "сексовавши": ["сексовав"],
    "сексоголик": ["сексоман"],
    "сексодром": ["траходром"],
    "сексоман": ["сексоголик"],
    "сексот": ["секретный сотрудник", "подсадная утка", "сыскной", "легавый", "сыщик", "филёр", "стукач", "осведомитель", "доносчик", "информатор", "изветчик", "наушник", "соглядатай", "предатель", "провокатор"],
    "сексотив": ["сексотивши"],
    "сексотивши": ["сексотив"],
    "сексофобия": ["эротофобия"],
    "секспросвет": ["секс-просвещение", "половое просвещение"],
    "секстет": ["шестёрка"],
    "секстиллион": ["секстильон"],
    "секстильон": ["секстиллион"],
    "сексуализировав": ["сексуализировавши"],
    "сексуализировавши": ["сексуализировав"],
    "сексуализм": ["сексуальность"],
    "сексуальная абстиненция": ["сексуальное воздержание", "сексуальная депривация"],
    "сексуальная аверсия": ["половая аверсия"],
    "сексуальная девиация": ["парафилия", "парапатия", "парэрозия", "сексуальная парастезия", "перверситет"],
    "сексуальная депривация": ["сексуальная абстиненция"],
    "сексуальная ориентация": ["половая направленность"],
    "сексуальная перверсия": ["половое извращение", "парафилия"],
    "сексуальничав": ["сексуальничавши"],
    "сексуальничавши": ["сексуальничав"],
    "сексуальное влечение": ["половое влечение"],
    "сексуальное меньшинство": ["квир", "секс-меньшинство"],
    "сексуальный": ["половой", "эротичный", "чувственный"],
    "сексуальный скандал": ["секс-скандал"],
    "секта": ["харизматический культ"],
    "сектоведение": ["сектология"],
    "сектор газа": ["газа"],
    "секторальный": ["секторный"],
    "секторный": ["секторальный"],
    "секуляризировав": ["секуляризировавши"],
    "секуляризировавши": ["секуляризировав"],
    "секуляризировать": ["секуляризовать"],
    "секуляризовав": ["секуляризовавши"],
    "секуляризовавши": ["секуляризовав"],
    "секуляризовать": ["секуляризировать"],
    "секундантствовав": ["секундантствовавши"],
    "секундантствовавши": ["секундантствовав"],
    "секундировав": ["секундировавши"],
    "секундировавши": ["секундировав"],
    "секундомер": ["таймер"],
    "секундочка": ["секунда"],
    "секционировав": ["секционировавши"],
    "секционировавши": ["секционировав"],
    "секция": ["отдел", "подразделение", "подгруппа", "модуль", "группа", "вскрытие", "рассечение"],
    "секьюрити": ["охрана", "охранник"],
    "селадонничав": ["селадонничавши"],
    "селадонничавши": ["селадонничав"],
    "селадонничать": ["селадонствовать"],
    "селадонство": ["волокитство", "донжуанство"],
    "селадонствовав": ["селадонствовавши"],
    "селадонствовавши": ["селадонствовав"],
    "селадонствовать": ["селадонничать"],
    "селеба": ["селеб"],
    "селебрити": ["знаменитость"],
    "селевиния": ["боялычная соня"],
    "селевой": ["селевый"],
    "селевый": ["селевой"],
    "селективно": ["избирательно"],
    "селективность": ["избирательность"],
    "селективный": ["выборочный", "избирательный"],
    "селектировав": ["селектировавши"],
    "селектировавши": ["селектировав"],
    "селекционировав": ["селекционировавши"],
    "селекционировавши": ["селекционировав"],
    "селена": ["луна"],
    "селеноводород": ["селенистый водород", "селан", "селенид водорода"],
    "селеноцентрический": ["окололунный"],
    "селенье": ["селение"],
    "селепровод": ["селесброс"],
    "селерей": ["селлерей", "сельдерей"],
    "селесао": ["пентакампеон"],
    "селеста": ["селестия"],
    "селив": ["селивши"],
    "селивши": ["селив"],
    "селигер": ["серегер"],
    "селина": ["целина", "келина"],
    "селитра": ["ямчуга", "ямчуг", "нитрат"],
    "селитровав": ["селитровавши"],
    "селитровавши": ["селитровав"],
    "селитряная кислота": ["азотная кислота"],
    "селитряный": ["селитренный", "селитровый"],
    "селкет": ["селкис", "селкхит", "селкит", "серкет-хетит"],
    "селлеис": ["ладон", "челеби"],
    "село": ["посёлок", "селение", "деревня"],
    "село имени полины осипенко": ["керби"],
    "селф-мейд": ["селфмейдмен"],
    "селфи": ["себяшка", "селка", "селфак", "селфач"],
    "селфи-боец": ["инста-воин"],
    "селфив": ["селфивши"],
    "селфивши": ["селфив"],
    "селфист": ["селфер"],
    "селфиться": ["селфить"],
    "селфмейдмен": ["селф-мейд"],
    "селфхарм": ["самоповреждение", "аутоагрессия", "автоагрессия", "аутодеструкция"],
    "сельва": ["сельвасы"],
    "сельвасы": ["сельва"],
    "сельгомс": ["тюхадемс"],
    "сельдеобразный": ["сельдевидный"],
    "сельдерей": ["сельдерюшка"],
    "сельдерюшка": ["сельдерей"],
    "сельдь": ["селёдка"],
    "сельдяной": ["сельдевый", "селёдочный"],
    "селькорив": ["селькоривши"],
    "селькоривши": ["селькорив"],
    "селькорить": ["селькорствовать"],
    "селькорствовав": ["селькорствовавши"],
    "селькорствовавши": ["селькорствовав"],
    "селькорствовать": ["селькорить"],
    "сельмаг": ["сельпо"],
    "сельмованф": ["сельмованфкс", "ванф", "сельмоваржафкс", "варжафкс"],
    "сельмованфкс": ["сельмованф", "ванф", "сельмоваржафкс", "варжафкс"],
    "сельмоваржафкс": ["шама", "варжафкс", "сельмованф", "сельмованфкс", "ванф"],
    "сельмоса ванозь": ["малава"],
    "сельница": ["миска"],
    "сельсин": ["автосин", "самосин"],
    "сельский": ["деревенский", "аграрный"],
    "сельскохозяйственный": ["фермерский", "сельхоз-", "аграрный"],
    "сельтерская": ["зельтерская", "минералка", "сельтерская вода"],
    "сельтерская вода": ["сельтерская", "зельцерская", "минеральная вода", "минералка"],
    "сельхозбизнес": ["агробизнес"],
    "сельхозгод": ["сельхозсезон", "сельскохозяйственный год"],
    "сельхозживотное": ["скот", "скотина"],
    "сельхозсезон": ["сельхозгод"],
    "сельхозстрахование": ["агрострахование"],
    "сельхозтехникум": ["агротехникум"],
    "сельхозугодие": ["сельхозугодье"],
    "сельхозугодье": ["сельхозугодие"],
    "сельхозфирма": ["агрофирма"],
    "селюк": ["рогуль", "рагуль"],
    "селям": ["салам", "салям"],
    "селящина": ["простащина", "грубост", "простотия"],
    "селёдка": ["сельдь", "сельга", "сельдина"],
    "селёдка в корсете": ["астраханская селёдка"],
    "селёдочный": ["сельдевый", "сельдяной"],
    "семантема": ["семема", "семантическая единица"],
    "семантизировав": ["семантизировавши"],
    "семантизировавши": ["семантизировав"],
    "семантика": ["семасиология"],
    "семантический": ["смысловой", "семасиологический"],
    "семантическое отношение": ["смысловое отношение"],
    "семантичный": ["семантический"],
    "семасиология": ["семантика"],
    "семафорив": ["семафоривши"],
    "семафоривши": ["семафорив"],
    "семафорщик": ["сигнальник", "сигнальщик", "железнодорожник"],
    "сембе сяка": ["сякокс"],
    "сембода": ["инь"],
    "семейники": ["семейные трусы", "пятьдесят лет советскому футболу"],
    "семейно": ["по-семейному"],
    "семейный очаг": ["домашний очаг"],
    "семейственность": ["непотизм", "кумовство", "блат"],
    "семейственный": ["семейный"],
    "семейство": ["семья", "фамилия", "серия", "линейка"],
    "семема": ["семантема", "лексико-семантический вариант"],
    "семенив": ["семенивши"],
    "семенивши": ["семенив"],
    "семенная жидкость": ["сперма", "эякулят"],
    "семенодоля": ["семядоля"],
    "семеро": ["семь"],
    "семечко": ["зёрнышко", "семя", "семячко", "семушко", "пшено", "шелуха"],
    "семиаридный": ["степной"],
    "семигалия": ["земгалия"],
    "семигранник": ["гептаэдр"],
    "семидневный": ["недельный", "однонедельный"],
    "семидюймовка": ["миньон"],
    "семижды": ["семикратно", "семью"],
    "семижильный": ["выносливый", "сильный", "крепкий", "стойкий", "закалённый", "двужильный", "стожильный"],
    "семизвездье": ["семизвездие"],
    "семиинвариант": ["полуинвариант", "кумулянт"],
    "семикарбазид": ["карбамоилгидразин"],
    "семикратно": ["седмерицею"],
    "семилетка": ["семилетний", "школа", "музыкалка", "план"],
    "семилетняя школа": ["семилетка"],
    "семилетье": ["семилетие"],
    "семильон": ["семийон"],
    "семиография": ["семейография"],
    "семиология": ["семиотика"],
    "семиотика": ["семиология"],
    "семиотический": ["семиотичный", "знаковый"],
    "семипалатинск": ["семей"],
    "семиразрядный": ["семибитный", "семибитовый"],
    "семис": ["семисс", "семиссис"],
    "семисвечник": ["менора"],
    "семиструнка": ["цыганская гитара", "русская гитара"],
    "семитензор": ["полутензор"],
    "семитка": ["семак", "семёшник", "семишник"],
    "семитрейлер": ["семи-трейлер"],
    "семиугольник": ["гептагон"],
    "семишник": ["семак", "семёшник"],
    "семка": ["семечко"],
    "семочка": ["семечка", "семка", "семечко"],
    "семплер": ["сэмплер"],
    "семплировав": ["семплировавши"],
    "семплировавши": ["семплировав"],
    "семхоз": ["семсовхоз"],
    "семъйяза": ["семъяза"],
    "семъяза": ["харут", "шемхазай", "семъйяза"],
    "семь": ["семёрка"],
    "семь аршин говядины да три фунта лент": ["семь аршин говядины и три фунта лент"],
    "семьдесят": ["семь десятков"],
    "семья": ["семейство", "клан", "фамилия", "группировка"],
    "семьянин": ["семейный человек", "отец семейства", "член семьи"],
    "семявыводящий": ["семявыносящий"],
    "семявыводящий проток": ["семявыносящий проток"],
    "семявыносящий": ["семявыводящий"],
    "семявыносящий проток": ["семявыводящий проток"],
    "семязачаток": ["семяпочка"],
    "семяизвержение": ["семяизлияние", "эякуляция", "семяизверженье", "кончалово", "конч", "кончи", "кончухи"],
    "семяизлияние": ["семяизвержение", "эякуляция"],
    "семяпочка": ["семязачаток"],
    "семячко": ["семечко"],
    "семёнович": ["семёныч"],
    "сен": ["сена", "сэн"],
    "сена": ["сен"],
    "сенажировав": ["сенажировавши"],
    "сенажировавши": ["сенажировав"],
    "сенесценция": ["старение"],
    "сенечки": ["сенцы"],
    "сензитивный": ["сенситивный", "чувствительный"],
    "сени": ["сенцы", "тамбур"],
    "сенив": ["сенивши"],
    "сенивши": ["сенив"],
    "сенная девушка": ["горничная"],
    "сено": ["сенцо", "сенишко"],
    "сено-солома": ["левой-правой", "раз-два", "ать-два"],
    "сеновал": ["сенник"],
    "сенокос": ["косовица", "покос", "уборка", "угодье", "косьба", "зеленая страда", "сенокошение", "скашивание", "сезон", "пожня", "зеленая жатва"],
    "сенокосец": ["сенокос"],
    "сенокосив": ["сенокосивши"],
    "сенокосивши": ["сенокосив"],
    "сенокосник": ["сенокосчик"],
    "сенокосничав": ["сенокосничавши"],
    "сенокосничавши": ["сенокосничав"],
    "сенокосчик": ["сенокосник"],
    "сенполия": ["фиалка"],
    "сенсация": ["шок"],
    "сенсибилизация": ["очувствление"],
    "сенсибилизировав": ["сенсибилизировавши"],
    "сенсибилизировавши": ["сенсибилизировав"],
    "сенситивность": ["чувствительность", "сензитивность"],
    "сенситивный": ["сензитивный", "чувствительный"],
    "сентаво": ["центаво"],
    "сентенциозно": ["назидательно", "нравоучительно"],
    "сентенциозность": ["нравоучительность"],
    "сентенциозный": ["нравоучительный", "назидательный"],
    "сентенция": ["афоризм", "максима"],
    "сентиментальничав": ["сентиментальничавши"],
    "сентиментальничавши": ["сентиментальничав"],
    "сентиментальничание": ["либеральничание"],
    "сентиментальничанье": ["сентиментальничание"],
    "сентиментальность": ["чувствительность", "восприимчивость", "мечтательность"],
    "сентябрив": ["сентябривши"],
    "сентябривши": ["сентябрив"],
    "сентябрь": ["вересень"],
    "сену": ["нану"],
    "сень": ["сина"],
    "сенька": ["сеня", "семён", "арсений"],
    "сеньор": ["землевладелец", "феодал", "владетель", "господин", "сударь"],
    "сеньорита": ["синьорина"],
    "сепаратность": ["обособленность"],
    "сепаратный": ["отдельный", "обособленный", "особый", "специальный", "раздельный"],
    "сепарация": ["сепарирование", "сецессия"],
    "сепарировав": ["сепарировавши"],
    "сепарировавши": ["сепарировав"],
    "сепарировать": ["отделять", "отделить"],
    "сепарироваться": ["отделяться", "отделиться"],
    "сепетивши": ["сепетив"],
    "септет": ["семёрка"],
    "септик": ["отстойник"],
    "септиктанк": ["септик", "септиктенк"],
    "септиктенк": ["септик", "септиктанк"],
    "септиллион": ["септильон"],
    "септированный": ["перегородчатый"],
    "септуагинта": ["перевод семидесяти"],
    "сер": ["жун", "сэр"],
    "сераль": ["дворец", "гарем"],
    "серанув": ["серанувши"],
    "серанувши": ["серанув"],
    "серануть": ["пукнуть", "пердануть", "высрать"],
    "серапис": ["сарапис", "сарапо"],
    "серафима": ["сима", "симочка"],
    "серафический": ["ангельский"],
    "серб": ["сорб"],
    "сербия": ["республика сербия"],
    "сербка": ["сербиянка", "сербияночка"],
    "сербохорватский": ["сербскохорватский"],
    "сербохорватский язык": ["сербскохорватский язык", "сербо-хорватский язык", "сербско-хорватский язык", "хорватскосербский язык", "хорватско-сербский язык"],
    "сербский язык": ["сербский"],
    "сербскохорватский": ["сербохорватский"],
    "серва": ["сервомашинка"],
    "сервак": ["сервер"],
    "сервер": ["сервак"],
    "сервилизм": ["низкопоклонство", "угодливость"],
    "сервильнейший": ["наисервильнейший"],
    "сервильничав": ["сервильничавши"],
    "сервильничавши": ["сервильничав"],
    "сервильность": ["подхалимаж", "низкопоклонничество", "холопство", "холуйство", "раболепство"],
    "сервильный": ["раболепный", "угодливый"],
    "сервировав": ["сервировавши"],
    "сервировавши": ["сервировав"],
    "сервисмен": ["сервисёр"],
    "сервисный": ["обслуживающий", "ремонтный"],
    "сервисёр": ["сервисмен"],
    "сервитьор": ["келнер"],
    "серворегулирование": ["серворегулировка"],
    "сервоузел": ["сервак"],
    "сергеевна": ["сергевна"],
    "сергей": ["сергий", "серёжа", "серёженька", "серый", "серёга", "сергейка", "сергуня", "сержик", "серж", "серхио"],
    "сергиев посад": ["загорск", "сергиев", "сергиевский посад"],
    "сергий": ["сергей"],
    "сергия": ["щанд", "барака", "палатка", "дюкянче"],
    "сердак": ["сардак"],
    "сердар": ["туркменбаши"],
    "сердечико": ["сердце", "сердечушко", "сердеченько"],
    "сердечко": ["сердце", "сердцевина"],
    "сердечно-лёгочный": ["кардиопульмональный"],
    "сердечный": ["душевный", "близкий", "добрый", "задушевный", "дружеский", "отзывчивый", "чуткий", "участливый", "добросердечный", "искренний", "неподдельный", "от всего сердца", "любовный", "романический", "амурный"],
    "сердив": ["сердивши"],
    "сердивши": ["сердив"],
    "сердито": ["гневно", "рассерженно"],
    "сердитовав": ["сердитовавши"],
    "сердитовавши": ["сердитовав"],
    "сердитый": ["гневливый", "раздражительный", "гневный", "озлобленный"],
    "сердить": ["возмущать", "гневить", "бесить", "злить"],
    "сердиться": ["гневаться", "злиться", "серчать"],
    "сердоболие": ["сострадание"],
    "сердобольничав": ["сердобольничавши"],
    "сердобольничавши": ["сердобольничав"],
    "сердобольность": ["жалостливость", "жалостность", "жалость", "милосердие", "сердоболие", "сострадание", "сострадательность"],
    "сердобольный": ["жалостливый"],
    "сердолик": ["карнеол"],
    "сердце": ["душа", "сердечко", "пульс"],
    "сердце кровью обливается": ["жаль", "неприятно", "больно"],
    "сердцебиение": ["пульс", "тахикардия"],
    "сердцебиенье": ["сердцебиение"],
    "сердцевина": ["ядро", "середина", "сердечник"],
    "сердцеед": ["бабник", "ловелас"],
    "сердцеедка": ["львица"],
    "сердцещипательный": ["душещипательный"],
    "сердяга": ["сердешный", "бедолага"],
    "серебрение": ["осеребрение"],
    "серебрив": ["серебривши"],
    "серебривши": ["серебрив"],
    "серебро": ["сребро"],
    "серебрянка": ["лапчатка"],
    "серебряный": ["серебристый", "аргентный", "седой", "звонкий"],
    "серебрёный": ["посеребренный"],
    "серев": ["серевши"],
    "серево": ["афедрон", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея"],
    "серевши": ["серев"],
    "середа": ["среда", "середина", "сердцевина", "серёдка", "центр"],
    "середина": ["серёдка", "половина", "центр"],
    "серендипность": ["интуиция"],
    "сержантствовав": ["сержантствовавши"],
    "сержантствовавши": ["сержантствовав"],
    "сериал": ["многосерийный", "фильм"],
    "серив": ["серивши"],
    "серивши": ["серив"],
    "серийник": ["серийный убийца"],
    "серийный убийца": ["серийник"],
    "сериозно": ["серьёзно"],
    "сериф": ["отсечка"],
    "серия": ["последовательность"],
    "серка": ["мастика"],
    "сермяга": ["сермяжина"],
    "сермяжная броня": ["солдатчина"],
    "сермяжная правда": ["великая сермяжная правда", "мужицкая правда"],
    "сермяжный": ["суконный", "домотканный", "посконный", "крестьянский", "бедняцкий", "нищенский", "грубый", "простой", "народный"],
    "серна": ["чёрный козёл"],
    "серник": ["спичка"],
    "сернистая кислота": ["триоксосернистая кислота"],
    "серо-жёлтый": ["желтовато-серый", "жёлто-серый"],
    "серо-коричневый": ["коричнево-серый", "тауп", "тауповый"],
    "сероб": ["давлатманд", "доро", "сарватманд", "бой"],
    "серобактерия": ["тиобактерия"],
    "серовар": ["серотип"],
    "серовато-жёлтый": ["желтовато-серый", "серо-жёлтый", "гороховый", "дикенький"],
    "серовато-мутный": ["мутно-серый", "мутновато-серый", "мутновато-сероватый"],
    "сероватый": ["невыразительный"],
    "сероводород": ["сульфид водорода"],
    "серозная жидкость": ["серозный экссудат"],
    "серосодержащий": ["серусодержащий"],
    "серость": ["унылость", "будничность", "необразованность"],
    "серотип": ["серовар"],
    "серотонин": ["гормон счастья"],
    "сероуглерод": ["дисульфид углерода"],
    "серп": ["полумесяц"],
    "серпантинный": ["серпантиновый"],
    "серпастый": ["серповидный", "месяцевидный", "изогнутый"],
    "серпентарий": ["змеепитомник", "змееферма", "гадючник", "гадюшник", "змеюшник"],
    "серпентин": ["змеевик"],
    "серпентина": ["серпантин"],
    "серпентинит": ["змеевик", "офиолит"],
    "серпентология": ["офиология"],
    "серпник": ["цикорий"],
    "серповидно": ["серпообразно"],
    "серповидно-клеточная анемия": ["серповидноклеточная анемия"],
    "серповидно-клеточный": ["серповидноклеточный"],
    "серповидноклеточная анемия": ["серповидно-клеточная анемия"],
    "серповидноклеточный": ["серповидно-клеточный"],
    "серповидность": ["серпообразность"],
    "серповидный": ["серпообразный"],
    "серпообразно": ["серповидно"],
    "серпообразность": ["серповидность"],
    "серпообразный": ["серповидный"],
    "серсем": ["серсемин", "глупав", "будала", "ахмак", "абдал", "зяпльо", "хапльо"],
    "сертификат": ["удостоверение", "свидетельство", "диплом", "справка", "цифровое удостоверение"],
    "сертифицировав": ["сертифицировавши"],
    "сертифицировавши": ["сертифицировав"],
    "сертук": ["суртук", "суртюк", "сюртук"],
    "сертучок": ["сюртучок"],
    "серун": ["срун", "засранец", "пердун", "грязнуля", "неряха", "говнюк", "паршивец", "поганец", "пакостник", "каганер"],
    "серунья": ["пердунья"],
    "серунячив": ["серунячивши"],
    "серунячивши": ["серунячив"],
    "серусодержащий": ["серосодержащий"],
    "серчав": ["серчавши"],
    "серчавши": ["серчав"],
    "серый": ["неприметный", "сумрачный", "безрадостный", "необразованный", "невежественный", "непросвещённый", "малокультурный", "вспомогательный локомотив", "резервный локомотив"],
    "серь": ["серость"],
    "серьга": ["урпаланйоки"],
    "серьёзнев": ["серьёзневши"],
    "серьёзневши": ["серьёзнев"],
    "серьёзничав": ["серьёзничавши"],
    "серьёзничавши": ["серьёзничав"],
    "серьёзно": ["на серьёзе", "по серьёзу"],
    "серьёзность": ["важность", "значительность", "существенность"],
    "серьёзный": ["строгий", "глубокомысленный", "деловой", "сурьёзный", "существенный", "важный", "опасный"],
    "серёга": ["серёжа", "серёжка", "серж", "серый"],
    "серёдка на половинку": ["серединка на половинку", "ни рыба ни мясо"],
    "серёдка на половину": ["серединка на половинку", "ни рыба ни мясо"],
    "серёжа": ["серж", "серёжка", "серёга"],
    "серёжка": ["серьга"],
    "сесилия": ["цецилия"],
    "сесквитерпен": ["полуторатерпен"],
    "сесото": ["южный сото"],
    "сестра": ["сестрица", "медсестра", "сестра милосердия", "подруга", "монашка"],
    "сестра милосердия": ["медицинская сестра", "медсестра", "сестра", "медичка"],
    "сестринский": ["сестрин", "сестрицын"],
    "сестрорецк": ["систербек"],
    "сеструня": ["сестронька", "сестричка"],
    "сестрёнка": ["сестричка"],
    "сесть": ["усесться", "получить срок", "приземлиться"],
    "сесуриту": ["охранник", "секьюрити"],
    "сеське": ["сяське"],
    "сет": ["сетх", "сутех", "сута", "сети"],
    "сет-лист": ["концертная программа", "программа выступления"],
    "сета": ["скорбь", "печаль"],
    "сетевое полотно": ["сетеполотно"],
    "сетевой": ["электрический"],
    "сетевой концентратор": ["хаб"],
    "сетеголизм": ["интернетомания"],
    "сетеполотно": ["дель"],
    "сетецентрический": ["сетецентричный"],
    "сетовав": ["сетовавши"],
    "сетовавши": ["сетовав"],
    "сетование": ["ропот", "жалоба"],
    "сетованье": ["сетование"],
    "сетовать": ["жаловаться", "роптать", "плакаться", "ныть", "хныкать", "скулить"],
    "сетх": ["сет", "сутах"],
    "сетчатка": ["ретина"],
    "сеть": ["путы", "сетка", "сплетение"],
    "сетянин": ["интернетчик", "нетизен"],
    "сефирота": ["сфирота", "сефирот"],
    "сеча": ["бой", "битва", "сражение", "драка", "просека"],
    "сечень": ["снежень", "бокогрей"],
    "сеченье": ["сечение"],
    "сечка": ["рубка", "секач", "тяпка"],
    "сечь": ["хлестать", "лупцевать", "пороть", "шинковать", "нарезать", "срубать", "вырубать", "петрить", "кумекать", "просекать", "врубаться", "рубить", "понимать", "шарить"],
    "сеяв": ["сеявши"],
    "сеявши": ["сеяв"],
    "сеяние": ["сев"],
    "сеянье": ["сеяние"],
    "сеятель": ["сеяльщик"],
    "сжав": ["сжавши"],
    "сжавши": ["сжав"],
    "сжадничав": ["сжадничавши"],
    "сжадничавши": ["сжадничав"],
    "сжалиться": ["смилостивиться", "смилосердоваться"],
    "сжамкав": ["сжамкавши"],
    "сжамкавши": ["сжамкав"],
    "сжарив": ["сжаривши"],
    "сжаривши": ["сжарив"],
    "сжатие": ["сжатье", "сдавливание", "сжимание", "компрессия", "ужимание", "упаковка", "архивация", "минимизация"],
    "сжатие данных": ["компрессия", "минимизация"],
    "сжатый": ["краткий", "непродолжительный", "архивированный"],
    "сжатье": ["сжатие"],
    "сжевав": ["сжевавши"],
    "сжевавши": ["сжевав"],
    "сжив": ["сживши"],
    "сживав": ["сживавши"],
    "сживавши": ["сживав"],
    "сживляв": ["сживлявши"],
    "сживлявши": ["сживляв"],
    "сживши": ["сжив"],
    "сжигав": ["сжигавши"],
    "сжигавши": ["сжигав"],
    "сжигание": ["сожжение"],
    "сжиганье": ["сжигание"],
    "сжигать": ["палить", "иссушать"],
    "сжидив": ["сжидивши"],
    "сжидивши": ["сжидив"],
    "сжижав": ["сжижавши"],
    "сжижавши": ["сжижав"],
    "сжижать": ["ожижать"],
    "сжиженный природный газ": ["спг"],
    "сжимав": ["сжимавши"],
    "сжимавши": ["сжимав"],
    "сжиманье": ["сжимание"],
    "сжимать": ["стискивать", "сдавливать", "держать"],
    "сжинав": ["сжинавши"],
    "сжинавши": ["сжинав"],
    "сжирав": ["сжиравши"],
    "сжиравши": ["сжирав"],
    "сжирать": ["пожирать", "лопать"],
    "сжиться": ["привыкнуть", "свыкнуться", "притерпеться", "приспособиться", "адаптироваться", "акклиматизироваться", "приноровиться", "приладиться", "притереться", "примениться", "вжиться", "прижиться", "освоиться"],
    "сжм": ["северный"],
    "сжулив": ["сжуливши"],
    "сжуливши": ["сжулив"],
    "сжульничав": ["сжульничавши"],
    "сжульничавши": ["сжульничав"],
    "сжёвывав": ["сжёвывавши"],
    "сжёвывавши": ["сжёвывав"],
    "сзади": ["позади", "назади", "сзаду"],
    "сзао": ["северо-западный административный округ", "совместное закрытое акционерное общество"],
    "сзвонив": ["сзвонивши"],
    "сзвонивши": ["сзвонив"],
    "сзт": ["северо-западные территории"],
    "сзывав": ["сзывавши"],
    "сзывавши": ["сзывав"],
    "сзывание": ["созывание", "созыв"],
    "си": ["ля дубль-диез", "до-бемоль"],
    "си-бемоль": ["ля-диез"],
    "си-диез": ["до"],
    "сиазань": ["кызыл-бурун"],
    "сиалидаза": ["нейраминидаза"],
    "сиалический": ["литосферный"],
    "сиалоаденит": ["сиаладенит"],
    "сиаль": ["саль", "литосфера"],
    "сиам": ["таиланд"],
    "сиба": ["сива"],
    "сибарис": ["сибарида"],
    "сибарит": ["гедонист", "эпикуреец", "бездельник"],
    "сибаритничав": ["сибаритничавши"],
    "сибаритничавши": ["сибаритничав"],
    "сибаритничать": ["сибаритствовать"],
    "сибаритствовав": ["сибаритствовавши"],
    "сибаритствовавши": ["сибаритствовав"],
    "сибаритствование": ["сибаритство"],
    "сибаритствовать": ["сибаритничать"],
    "сибас": ["морской волк", "морской окунь", "морской судак", "обыкновенный лаврак"],
    "сибилянт": ["свистящий согласный"],
    "сибирадогъон": ["сибиртки"],
    "сибирец": ["сибиряк", "чалдон", "челдон"],
    "сибирит": ["сиберит", "рубеллит"],
    "сибирка": ["шапка", "шапка-сибирка", "шапка-ушанка", "кафтан", "сюртук"],
    "сибирская язва": ["карбункул", "злокачественный", "антракс"],
    "сибирский женьшень": ["элеутерококк", "дикий перец", "чёртов куст"],
    "сибирщина": ["каторга", "тюрьма", "ссылка", "сторона", "край", "местность", "страна"],
    "сибирь": ["ссылка", "каторга", "сибирщина"],
    "сибирячка": ["сибирочка", "братчоха"],
    "сибирячок": ["сибиряк"],
    "сибиу": ["германштадт", "надьсебен"],
    "сиблинг": ["сибс"],
    "сибс": ["сиблинг"],
    "сив": ["сиф"],
    "сива": ["жива", "сиба"],
    "сивев": ["сивевши"],
    "сивевши": ["сивев"],
    "сивер": ["сиверка", "сиверко", "северный ветер"],
    "сиверка": ["сивер", "сиверко", "норд"],
    "сиверко": ["сивер", "сиверка", "северный ветер", "норд"],
    "сивилла": ["сибилла"],
    "сивоворонка": ["сиворонка", "сизоворонка"],
    "сиволапый": ["неуклюжий", "неловкий", "неотёсанный", "грубый", "невоспитанный"],
    "сиволапый лох": ["провинциал", "провинция", "деревня", "сельпо", "конюшня", "дярёвня", "колхозан", "колхозанин", "деревенщина"],
    "сивушный": ["перегорелый", "безрассудный"],
    "сивый": ["серый", "невзрачный"],
    "сиг": ["сиговина"],
    "сигав": ["сигавши"],
    "сигавши": ["сигав"],
    "сиганув": ["сиганувши"],
    "сиганувши": ["сиганув"],
    "сигарета": ["раковая палочка", "папироса", "цигарка"],
    "сигарница": ["сигарочница"],
    "сигарообразный": ["сигаровидный", "сигароподобный"],
    "сигароподобный": ["сигарообразный"],
    "сигарочка": ["сигарка"],
    "сигил": ["сигилла", "сигила"],
    "сигиллография": ["сфрагистика"],
    "сигишоара": ["шессбург", "шегешвар"],
    "сигма": ["сигма-самец"],
    "сигматизм": ["шепелявение"],
    "сигмовидный": ["сигмоидный", "сигмообразный"],
    "сигмоид": ["сигмоида"],
    "сигмоидный": ["сигмообразный", "сигмовидный"],
    "сигмообразный": ["сигмоидный", "сигмовидный"],
    "сигнал": ["знак"],
    "сигналив": ["сигналивши"],
    "сигналивши": ["сигналив"],
    "сигнализация": ["сигналка"],
    "сигнализировав": ["сигнализировавши"],
    "сигнализировавши": ["сигнализировав"],
    "сигнализировать": ["оповещать", "информировать", "жаловаться", "нажаловаться", "наушничать", "ябедничать", "кляузничать", "доносить", "стучать", "капать", "заявлять", "фискалить"],
    "сигнализовав": ["сигнализовавши"],
    "сигнализовавши": ["сигнализовав"],
    "сигналик": ["сигнальчик"],
    "сигналист": ["сигнальщик"],
    "сигналить": ["сигнализировать"],
    "сигналка": ["автосигнализация"],
    "сигнальчик": ["сигналик"],
    "сигнашка": ["автосигнализация", "сигналка"],
    "сигнификат": ["обозначение", "десигнат"],
    "сигнификативное значение": ["сигнификат"],
    "сигнифицировав": ["сигнифицировавши"],
    "сигнифицировавши": ["сигнифицировав"],
    "сигнув": ["сигнувши"],
    "сигнувши": ["сигнув"],
    "сиговина": ["сиг"],
    "сид": ["сидер"],
    "сидев": ["сидевши"],
    "сидевши": ["сидев"],
    "сиделец": ["приказчик", "продавец", "арестант", "заключенный", "зека", "стул", "кресло", "сиденье"],
    "сидение": ["сиденье"],
    "сидень": ["лежебока"],
    "сиденье": ["зад", "ягодицы", "место пониже спины", "мягкое место", "багажник", "филейная часть", "жопа", "задница", "гузно", "седалище", "усест", "мадам сижу"],
    "сидеральный": ["сидерический"],
    "сидерий": ["барий"],
    "сидерит": ["железный шпат", "бурый шпат", "октаэдрит"],
    "сидеритис": ["железница"],
    "сидерический": ["звёздный"],
    "сидерический лунный месяц": ["звёздный лунный месяц", "сидерический месяц"],
    "сидерический месяц": ["сидерический лунный месяц"],
    "сидеть на биче": ["жить на биче", "жить на бичике", "сидеть на бичике"],
    "сидеть на бичике": ["жить на бичике", "жить на биче", "сидеть на биче"],
    "сидеть на игле": ["быть на игле"],
    "сиди-плеер": ["сд-плеер", "сиди-проигрыватель"],
    "сидик": ["сийдик"],
    "сидить": ["раздавать"],
    "сидмя": ["сиднем"],
    "сидмя сидеть": ["сиднем сидеть"],
    "сиднем": ["сидмя"],
    "сиднем сидеть": ["сидмя сидеть"],
    "сидон": ["сайда"],
    "сидор": ["вещевой мешок", "вещмешок"],
    "сидорович": ["сидорыч"],
    "сидр": ["яблочный сок", "буза"],
    "сиенна": ["сиена"],
    "сиенская земля": ["сиена"],
    "сиживав": ["сиживавши"],
    "сиживавши": ["сиживав"],
    "сижка": ["сигарета"],
    "сизев": ["сизевши"],
    "сизевши": ["сизев"],
    "сизифов труд": ["мартышкин труд", "работа данаид", "сизифова работа"],
    "сизифова работа": ["сизифов труд", "работа данаид", "мартышкин труд"],
    "сизовев": ["сизовевши"],
    "сизовевши": ["сизовев"],
    "сизоворонка": ["ракша", "сивоворонка", "сиворонка"],
    "сий": ["сей"],
    "сикав": ["сикавши"],
    "сикавши": ["сикав"],
    "сикара": ["сикхара", "шикхара"],
    "сикарашка": ["букашка"],
    "сикать": ["писать", "мочиться", "ссать"],
    "сиквенс": ["синтема", "цикл"],
    "сикера": ["сикер"],
    "сикка": ["танга"],
    "сикль": ["шекель"],
    "сикомор": ["сикомора", "библейская смоковница"],
    "сикомора": ["сикомор"],
    "сикофант": ["обвинитель", "доносчик", "шпион", "клеветник", "стукач"],
    "сикул": ["сикел"],
    "сикурс": ["подкрепление", "подмога"],
    "сикхара": ["сикара", "шикхара"],
    "сила": ["мощь", "тяга", "фактор", "энергия", "влиятельность", "принуждение", "правомочность"],
    "сила архимеда": ["архимедова сила", "закон архимеда"],
    "сила притяжения": ["сила гравитации", "сила тяготения"],
    "сила тяжести": ["вес"],
    "силанол": ["силикол"],
    "силач": ["богатырь", "крепыш", "амбал", "здоровяк"],
    "силенд": ["княжество силенд"],
    "силив": ["силивши"],
    "силивши": ["силив"],
    "силикатизация": ["окремнение"],
    "силикатизировав": ["силикатизировавши"],
    "силикатизировавши": ["силикатизировав"],
    "силикатировав": ["силикатировавши"],
    "силикатировавши": ["силикатировав"],
    "силикомарганец": ["ферросиликомарганец"],
    "силикон": ["полиорганосилоксан"],
    "силиконовая долина": ["кремниевая долина"],
    "силиконовый": ["силоксановый"],
    "силистра": ["доростол", "дристр", "дуростор", "силистрия"],
    "силистрия": ["силистра"],
    "силиться": ["тужиться", "пытаться", "тщиться", "стараться"],
    "силиций": ["силициум"],
    "силицировав": ["силицировавши"],
    "силицировавши": ["силицировав"],
    "силл": ["пластовая интрузия", "интрузивная залежь"],
    "силлабический": ["слоговый"],
    "силлабо-тонический": ["силлаботонический"],
    "силлабус": ["каталог"],
    "силлепс": ["зевгма"],
    "силлиманит": ["фибролит"],
    "силовик": ["силовичок", "швабровик", "слабовик", "насиловик", "слаггер"],
    "силой": ["силком", "насильно", "против", "воли"],
    "силомер": ["динамометр"],
    "силосовав": ["силосовавши"],
    "силосовавши": ["силосовав"],
    "силур": ["силурийский период"],
    "силы": ["энергия", "фактор"],
    "сильвестр": ["селивёрст", "сильвёрст", "силвестр"],
    "сильвестрович": ["сильвестрыч"],
    "сильвия": ["силвия", "сильва"],
    "сильнев": ["сильневши"],
    "сильневши": ["сильнев"],
    "сильничав": ["сильничавши"],
    "сильничавши": ["сильничав"],
    "сильно": ["крепко", "очень", "ощутимо", "впечатляюще", "убедительно", "зело", "дюже", "вельми", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно", "в значительной мере"],
    "сильнодействующее ядовитое вещество": ["сдяв", "аварийно химически опасные вещества", "ахов"],
    "сильной": ["сильный"],
    "сильнолегированный": ["высоколегированный"],
    "сильнорадиоактивный": ["высокорадиоактивный"],
    "сильноупорядоченный": ["высокоупорядоченный"],
    "сильные мира сего": ["великие мира сего"],
    "сильный": ["мощный", "могучий", "крепкий", "мускулистый", "жилистый"],
    "сильфида": ["нимфа"],
    "силявка": ["уклейка"],
    "сим-карта": ["симка"],
    "сима": ["мазу"],
    "симбиоз": ["сосуществование"],
    "симбиотировав": ["симбиотировавши"],
    "симбиотировавши": ["симбиотировав"],
    "симбирск": ["ульяновск", "синбирск"],
    "символ": ["знак", "обозначение", "графема"],
    "символ веры": ["кредо", "доктрина", "принцип"],
    "символизировав": ["символизировавши"],
    "символизировавши": ["символизировав"],
    "символизм": ["символика"],
    "символически": ["формально", "для вида", "внешне", "мало", "незначительно"],
    "символический": ["символичный"],
    "симистор": ["триак"],
    "симка": ["сим-карта"],
    "симметрировав": ["симметрировавши"],
    "симметрировавши": ["симметрировав"],
    "симметрировать": ["уравновешивать", "балансировать"],
    "симметрический": ["симметричный"],
    "симметричная матрица": ["симметрическая матрица"],
    "симметричность": ["симметрия"],
    "симметричный": ["симметрический", "равносильный", "равнозначный", "соответствующий", "соответственный", "адекватный"],
    "симметрия": ["сбалансированность", "уравновешенность"],
    "симо": ["рухсора", "башара"],
    "симомс": ["нилемс", "копордамс", "анамс", "шокшемс"],
    "симомс-ярхцамс": ["ярхцамс-симомс"],
    "симония": ["святокупство"],
    "симочка": ["симка", "сим-карта"],
    "симп": ["подкаблучник"],
    "симпатизант": ["сторонник"],
    "симпатизировав": ["симпатизировавши"],
    "симпатизировавши": ["симпатизировав"],
    "симпатический": ["симпатичный", "сочувственный", "невидимый", "скрытый", "секретный"],
    "симпатичность": ["привлекательность", "приятность"],
    "симпатичный": ["приятный", "привлекательный", "смазливый", "миловидный", "пригожий"],
    "симпатия": ["расположение", "благосклонность", "любовь"],
    "симпатяга": ["миляга"],
    "симпатяжка": ["симпатяга"],
    "симплифицировать": ["упрощать"],
    "симплока": ["анаэпифора", "эпанафора"],
    "симпозиум": ["конференция"],
    "симпотно": ["симпатично"],
    "симпотный": ["симпатичный", "клёвый"],
    "симпровизировав": ["симпровизировавши"],
    "симпровизировавши": ["симпровизировав"],
    "симптом": ["признак", "проявление", "свидетельство"],
    "симптоматика": ["симптоматология"],
    "симптоматология": ["симптоматика", "медицинская семиотика", "семиология"],
    "симптомокомплекс": ["синдром"],
    "симпус": ["сиреномелия"],
    "симулировав": ["симулировавши"],
    "симулировавши": ["симулировав"],
    "симулировать": ["притворяться", "прикидываться"],
    "симультанный": ["одновременный", "синхронный", "единовременный", "параллельный"],
    "симулякр": ["подобие", "копия копии", "тень тени", "видимость", "иллюзия", "симуляция", "копия", "пародия", "издевательство", "тень", "отвлекающий манёвр", "ложная атака"],
    "симулянт": ["притворщик"],
    "симуляция": ["симулирование", "притворство"],
    "симфиз": ["гемиартроз"],
    "симфонизировав": ["симфонизировавши"],
    "симфонизировавши": ["симфонизировав"],
    "симфония": ["созвучие", "конкорданс", "конкорданция"],
    "симын": ["кафын"],
    "сина": ["пистон"],
    "синаксарь": ["синаксарий", "пролог"],
    "синапизм": ["горчичник"],
    "синапсид": ["тероморф", "звероящер"],
    "синартроз": ["синдесмоз", "синостоз", "синхондроз"],
    "сингал": ["сингалец", "сингалез"],
    "сингалец": ["сингал"],
    "сингамия": ["амфимиксис", "оплодотворение"],
    "сингапур": ["город льва", "азиатский нью-йорк"],
    "сингенетический": ["сингенетичный"],
    "сингенетичный": ["сингенетический"],
    "сингл": ["миньон"],
    "синглет": ["сингулет"],
    "сингулярность": ["особенность", "особая точка", "гравитационная сингулярность"],
    "сингулярный": ["исключительный"],
    "синдесмоз": ["синартроз"],
    "синдик": ["защитник"],
    "синдикат": ["профсоюз"],
    "синдинское": ["озеро маяк"],
    "синдицировав": ["синдицировавши"],
    "синдицировавши": ["синдицировав"],
    "синдошь": ["синдоша", "синдошка"],
    "синдром": ["симптомокомплекс"],
    "синдром высокомерия": ["гибрис-синдром"],
    "синдром отмены": ["абстинентный синдром"],
    "синдром системной воспалительной реакции": ["ссвр"],
    "синдэн": ["хондэн"],
    "сине": ["лазурно"],
    "сине-гранатовые": ["блауграна", "блаугранас"],
    "сине-зелёный": ["циановый", "зеленоватый", "синеватый"],
    "синебот": ["алкаш", "алкоголик", "алконавт", "выпивоха", "пьяница", "пьянчуга", "пьянчужка", "пьянь"],
    "синев": ["синевши"],
    "синева": ["синь"],
    "синевато-чёрный": ["аспидный", "иссиня-чёрный", "синевато-черноватый", "чёрно-синеватый", "сине-черноватый", "сине-чёрный", "чёрно-синий"],
    "синевев": ["синевевши"],
    "синевевши": ["синевев"],
    "синевица": ["синявка"],
    "синевши": ["синев"],
    "синеглазый": ["синеокий"],
    "синек": ["чибин"],
    "синекура": ["тёплое место"],
    "синель": ["шениль"],
    "синема": ["кинематограф", "кино"],
    "синематограф": ["кинематограф", "электробиограф", "кинотеатр", "киноаппарат"],
    "синематографический": ["кинематографический"],
    "синенькая": ["пятёрка", "пятирублёвка", "синица", "синичка", "синюха"],
    "синенький": ["синий", "баклажан"],
    "синеокий": ["синеглазый"],
    "синерама": ["синема", "кинематограф"],
    "синергия": ["синергизм", "резонанс"],
    "синерод": ["циан"],
    "синеродистый": ["цианистый"],
    "синеродный": ["цианистый"],
    "синеться": ["виднеться", "показываться", "открываться"],
    "синефил": ["киноман", "кинолюбитель", "кинолюб", "киношник"],
    "синефилия": ["киномания"],
    "синехия": ["спайка"],
    "синешейка": ["варакушка"],
    "синив": ["синивши"],
    "синивши": ["синив"],
    "синий": ["синеватый", "сизый", "синяк", "пьяный"],
    "синий кит": ["голубой кит", "синий полосатик", "голубой полосатик", "блювал"],
    "синий чулок": ["педантка", "сухарь", "зануда", "надоеда"],
    "синий экран смерти": ["синий экран"],
    "синильный": ["цианистый"],
    "синить": ["подсинивать"],
    "синица": ["синица в руке"],
    "синклиналь": ["синклинальная складка", "синформа"],
    "синкопа": ["обморок"],
    "синкопировав": ["синкопировавши"],
    "синкопировавши": ["синкопировав"],
    "синкопический": ["синкопированный", "синкопный"],
    "синкретичный": ["эклектичный"],
    "синоби": ["ниндзя"],
    "синовия": ["синовиальная жидкость"],
    "синодик": ["помянник", "поминальник"],
    "синолог": ["китаист", "китаевед"],
    "синология": ["китаеведение", "китаистика"],
    "синоним": ["аналог"],
    "синонимический": ["синонимичный"],
    "синонимический ряд": ["синонимическая парадигма"],
    "синонимичный": ["синонимический"],
    "синопсис": ["обзор"],
    "синор": ["предел", "граница", "преграда"],
    "синостоз": ["синартроз"],
    "синофобия": ["чайнафобия", "китаефобия"],
    "синтаза": ["лиаза"],
    "синтвейв": ["ретровейв"],
    "синтез": ["объединение", "соединение", "слияние"],
    "синтезировав": ["синтезировавши"],
    "синтезировавши": ["синтезировав"],
    "синтема": ["литмостратон", "циклит", "сиквенс"],
    "синтетаза": ["лигаза"],
    "синтетический": ["синтетичный"],
    "синтетический детергент": ["синдет"],
    "синтетичный": ["синтетический"],
    "синти-поп": ["технопоп"],
    "синто": ["синтоизм"],
    "синтоизм": ["синто"],
    "синуит": ["синусит"],
    "синусит": ["синуит"],
    "синусоид": ["синусоидный капилляр"],
    "синхондроз": ["синартроз"],
    "синхронизировав": ["синхронизировавши"],
    "синхронизировавши": ["синхронизировав"],
    "синхронизм": ["синхрония"],
    "синхронизовав": ["синхронизовавши"],
    "синхронизовавши": ["синхронизовав"],
    "синхроничность": ["синхронистичность"],
    "синхрония": ["синхронизация"],
    "синхронник": ["синхронный электродвигатель", "синхронный двигатель"],
    "синхронно": ["одновременно"],
    "синхронное вращение": ["приливный захват"],
    "синхронность": ["одновременность", "синхроничность", "синхронизм"],
    "синхронный": ["одновременный"],
    "синхроскоп": ["синхроноскоп"],
    "синхроциклотрон": ["фазотрон"],
    "синь": ["синева"],
    "синь порох": ["ничто", "капелька", "волосок", "пылинка"],
    "синь порох в глазу": ["синь-порох в глазу", "как синь-порох в глазу", "что синь-порох в глазу"],
    "синьга": ["чёрный турпан"],
    "синьорина": ["сеньорита"],
    "синьцзян-уйгурский автономный район": ["суар"],
    "синюха": ["цианоз"],
    "синюшный": ["цианотичный"],
    "синяк": ["гематома", "кровоподтёк", "синячок", "синевица", "синявка"],
    "синячив": ["синячивши"],
    "синячивши": ["синячив"],
    "синяя птица": ["лиловый дрозд", "птица счастья", "удача", "мечта", "курица"],
    "сион": ["иерусалим"],
    "сипак": ["невежа", "деревенщина"],
    "сипаница": ["едра шарка", "вариола"],
    "сипатый": ["сиплый", "осиплый", "осипший", "сиповатый", "сиповатенький", "остуженный", "охрипший", "хриплый", "хрипящий", "хрипучий", "хрипатый", "хрипастый", "хриповатый", "хриповатенький", "хриповастый"],
    "сипев": ["сипевши"],
    "сипевши": ["сипев"],
    "сипловатый": ["сиповатый"],
    "сиплый": ["сипатый", "сиповатый"],
    "сипнув": ["сипнувши"],
    "сипнувши": ["сипнув"],
    "сиповатый": ["сипловатый"],
    "сиповка": ["жалейка", "свирёлка", "сопелка", "сопель", "сопилка", "бирюля", "бирюлька", "бирюлечка", "бурулька", "чебысга", "чебызга", "чибыза", "дудочка", "свирель", "флейта"],
    "сипучий": ["сипкий"],
    "сир": ["сер"],
    "сирав": ["сиравши"],
    "сиравши": ["сирав"],
    "сирвента": ["сирвент"],
    "сирга": ["толгоки", "тэгэк"],
    "сиргис": ["гиргис", "иргис", "северский донец"],
    "сире": ["кизу", "эряфкшу", "сире пингонь", "кунардонь"],
    "сирена": ["русалка"],
    "сиреневый": ["лиловый", "светло-лиловый", "тёмно-лиловый"],
    "сиреномелия": ["уромелия"],
    "сиренька": ["сирень"],
    "сиречь": ["то есть", "то бишь", "а именно", "словом", "силечь", "сильчь"],
    "сирийская арабская республика": ["сирия", "сар"],
    "сиринкс": ["сиринга"],
    "сириус": ["собачья звезда", "сотис", "сопдет", "псица"],
    "сирия": ["сирийская арабская республика", "сар", "сирийская республика"],
    "сирк гын": ["сир гын"],
    "сирконстант": ["адъюнкт"],
    "сиромах": ["бедняк", "голтак", "просяк"],
    "сиромашия": ["бедност", "нищета", "мизерия", "нужда"],
    "сиропив": ["сиропивши"],
    "сиропивши": ["сиропив"],
    "сирота": ["беспризорник"],
    "сиротев": ["сиротевши"],
    "сиротевши": ["сиротев"],
    "сиротив": ["сиротивши"],
    "сиротивши": ["сиротив"],
    "сиротина": ["сирота", "сиротинушка", "сиротка"],
    "сиротинушка": ["сиротина", "сиротка"],
    "сиротливо": ["одиноко"],
    "сиротствовав": ["сиротствовавши"],
    "сиротствовавши": ["сиротствовав"],
    "сирпиёз": ["сир"],
    "сирраг": ["альферац"],
    "сиррах": ["альферац"],
    "сирфида": ["журчалка"],
    "сирывав": ["сирывавши"],
    "сирывавши": ["сирывав"],
    "сирый": ["осиротевший", "сиротливый", "беспомощный", "убогий", "несчастный", "одинокий"],
    "сисадмин": ["системный  администратор"],
    "сисак": ["сегестика"],
    "сисечка": ["титечка"],
    "сисоп": ["системный администратор", "сисадмин", "администратор", "админ"],
    "система": ["систематичность", "закономерность", "система счисления", "геологическая система"],
    "система координат": ["координаты"],
    "система управления версиями": ["система контроля версий"],
    "система управления содержимым": ["сус"],
    "систематизировав": ["систематизировавши"],
    "систематизировавши": ["систематизировав"],
    "систематика": ["систематизация", "систематизирование"],
    "систематически": ["систематично"],
    "систематичность": ["системность", "регулярность"],
    "систематичный": ["регулярный"],
    "системки": ["системные требования", "технические требования", "технические характеристики"],
    "системно": ["комплексно"],
    "системный администратор": ["администратор", "админ", "сисадмин", "сисоп", "суперпользователь", "рут"],
    "системный блок": ["процессор"],
    "системный эффект": ["нелинейность", "синергия"],
    "систер": ["сис"],
    "систербек": ["сестрорецк"],
    "сиська": ["грудь", "сися", "титя", "титька", "сисечка", "титечка", "бидон", "дойка", "сисяндра", "доечка"],
    "сиськастый": ["сисястый", "грудастый", "жирный"],
    "сися": ["грудь", "титя", "сиська", "титька"],
    "сисястый": ["грудастый", "грудистый", "большегрудый", "пышногрудый", "полногрудый", "тительный", "титькастый", "буферастый"],
    "ситам": ["зулм"],
    "ситар": ["ситара"],
    "ситара": ["ситар"],
    "ситец": ["миткаль", "бязь"],
    "ситком": ["ситуационная комедия"],
    "ситник": ["рогоз"],
    "ситников": ["решетников"],
    "сито": ["решето"],
    "ситовщик": ["просевщик", "просевальщик"],
    "ситора": ["ахтар"],
    "ситорашинос": ["ситорашумор"],
    "ситорашумор": ["ситорашинос"],
    "ситр": ["парда"],
    "ситро": ["лимонад"],
    "ситуативный": ["вариативный"],
    "ситуация": ["положение", "ситуёвина", "ситуэйшн"],
    "ситудан": ["сутудан", "таъриф кардан"],
    "ситцевый": ["хлопковый", "бязевый", "миткалевый"],
    "сиф": ["сив", "шет", "шит", "сет"],
    "сифианин": ["сифит", "сетианин"],
    "сифилис": ["люэс", "перелой", "сиф", "сифак", "сифачок", "сифон", "сифилюжник", "сифилюга", "сифилюжка"],
    "сифилитический": ["люэтический"],
    "сифон": ["сифонофор"],
    "сифонив": ["сифонивши"],
    "сифонивши": ["сифонив"],
    "сифонировав": ["сифонировавши"],
    "сифонировавши": ["сифонировав"],
    "сихиртя": ["сиртя", "сииртя"],
    "сицевой": ["таковой"],
    "сицилианец": ["сицилиец"],
    "сицилианка": ["сицилийка"],
    "сицилиец": ["сицилианец"],
    "сициликус": ["сицилик"],
    "сию се": ["сиву се"],
    "сию секунду": ["сию минуту", "сей момент", "сразу", "немедленно", "тотчас"],
    "сияв": ["сиявши"],
    "сиявши": ["сияв"],
    "сиянье": ["сияние"],
    "сиять": ["сверкать", "лучиться", "блистать", "светиться"],
    "ска": ["блю бит"],
    "скабливав": ["скабливавши"],
    "скабливавши": ["скабливав"],
    "скабрёзник": ["охальник", "пошляк"],
    "скабрёзничав": ["скабрёзничавши"],
    "скабрёзничавши": ["скабрёзничав"],
    "скабрёзничать": ["сквернословить"],
    "скабрёзность": ["неприличность", "непристойность", "пошлость"],
    "скабрёзный": ["неприличный", "непристойный", "обсценный", "пошлый", "сальный", "солёный", "вольный", "площадной"],
    "скав": ["скавши"],
    "скаверзив": ["скаверзивши"],
    "скаверзивши": ["скаверзив"],
    "скаверзничав": ["скаверзничавши"],
    "скаверзничавши": ["скаверзничав"],
    "скаверзничать": ["скаверзить"],
    "скавчання": ["скавучання"],
    "скавши": ["скав"],
    "скадарское озеро": ["шкодер"],
    "скадрировав": ["скадрировавши"],
    "скадрировавши": ["скадрировав"],
    "скажем": ["например", "к примеру", "допустим", "предположим", "пусть"],
    "скажите на милость": ["вот ещё", "сейчас", "разбежаться"],
    "сказав": ["сказавши"],
    "сказавши": ["сказав"],
    "сказание": ["сказанье", "легенда", "предание", "преданье", "сага"],
    "сказанув": ["сказанувши"],
    "сказанувши": ["сказанув"],
    "сказанье": ["сказание", "предание", "преданье", "легенда", "сага"],
    "сказать": ["молвить", "промолвить", "вымолвить", "произнести", "изречь", "сообщить", "изложить", "передать", "объявить", "приказать", "распорядиться", "решить", "предположить", "подумать", "заключить"],
    "сказитель": ["сказатель"],
    "сказка": ["фантастика", "чудо"],
    "сказка про белого бычка": ["тем же салом да по тем же ранам", "бить в одну точку", "набить оскомину"],
    "сказнив": ["сказнивши"],
    "сказнивши": ["сказнив"],
    "сказочно": ["феерично", "фантастично", "баснословно", "фантастически", "феерически"],
    "сказочность": ["фантастичность", "фееричность"],
    "сказочный": ["феерический"],
    "сказуемое": ["предикат"],
    "сказуемость": ["предикативность"],
    "сказывав": ["сказывавши"],
    "сказывавши": ["сказывав"],
    "сказывание": ["сказыванье"],
    "сказывать": ["говорить", "рассказывать"],
    "скайдайвер": ["парашютист"],
    "скайлер": ["скейлер"],
    "скайпив": ["скайпивши"],
    "скайпивши": ["скайпив"],
    "скайсёрфер": ["скайсёрфингист"],
    "скакав": ["скакавши"],
    "скакавши": ["скакав"],
    "скакалка": ["прыгалка", "прыгалки"],
    "скакание": ["скаканье"],
    "скаканув": ["скаканувши"],
    "скаканувши": ["скаканув"],
    "скаканье": ["скакание"],
    "скакать": ["прыгать", "дёргаться"],
    "скакнув": ["скакнувши"],
    "скакнувши": ["скакнув"],
    "скакнуть": ["скакануть"],
    "скакол": ["скакуас"],
    "скакуас": ["скакол"],
    "скакун": ["конь", "скакол", "скакло", "скакуас"],
    "скакунья": ["попрыгунья"],
    "скакушка": ["поскакушка", "квакушка"],
    "скала": ["шкала"],
    "скаламбурив": ["скаламбуривши"],
    "скаламбуривши": ["скаламбурив"],
    "скалдырничав": ["скалдырничавши"],
    "скалдырничавши": ["скалдырничав"],
    "скалдырничать": ["скупиться", "сквалыжничать"],
    "скалдырничество": ["жадность", "скупость", "сквалыжничество", "скряжничество"],
    "скалив": ["скаливши"],
    "скаливши": ["скалив"],
    "скалить": ["оскаливать", "щерить"],
    "скалиться": ["щериться", "ощериваться"],
    "скалка": ["поршень"],
    "скаловый": ["весовой"],
    "скалозубив": ["скалозубивши"],
    "скалозубивши": ["скалозубив"],
    "скалозубство": ["зубоскальство"],
    "скалолазание": ["альпинизм"],
    "скалолазанье": ["скалолазание"],
    "скалолазка": ["женщина-скалолаз", "скалолаз"],
    "скалы": ["скалвы"],
    "скалывав": ["скалывавши"],
    "скалывавши": ["скалывав"],
    "скалывание": ["срез"],
    "скалькировав": ["скалькировавши"],
    "скалькировавши": ["скалькировав"],
    "скалькулировав": ["скалькулировавши"],
    "скалькулировавши": ["скалькулировав"],
    "скальпель": ["ланцет"],
    "скальпер": ["скальпосниматель"],
    "скальпинг": ["пипсовка"],
    "скальпировав": ["скальпировавши"],
    "скальпировавши": ["скальпировав"],
    "скальпосниматель": ["скальпер"],
    "скальчатый": ["плунжерный"],
    "скам": ["мошенничество"],
    "скамандр": ["карамендерес", "мендерессу", "ксанф"],
    "скамейка": ["скамья", "лавочка"],
    "скамер": ["аферист", "мошенник", "жулик"],
    "скамить": ["мошенничать", "обманывать"],
    "скампавея": ["сконпавея"],
    "скамья": ["скамейка"],
    "скан": ["скан-копия"],
    "скандал": ["конфуз"],
    "скандалив": ["скандаливши"],
    "скандаливши": ["скандалив"],
    "скандализировав": ["скандализировавши"],
    "скандализировавши": ["скандализировав"],
    "скандализовав": ["скандализовавши"],
    "скандализовавши": ["скандализовав"],
    "скандалист": ["буян", "бузила", "бузотёр", "дебошир", "драчун"],
    "скандальничав": ["скандальничавши"],
    "скандальничавши": ["скандальничав"],
    "скандальный": ["конфликтный", "склочный", "вздорный"],
    "скандалёзный": ["скандальный"],
    "скандинавизм": ["панскандинавизм"],
    "скандинавия": ["скандинавский полуостров", "скандинавские страны"],
    "скандинавский полуостров": ["скандинавия"],
    "скандировав": ["скандировавши"],
    "скандировавши": ["скандировав"],
    "скандировать": ["выкрикивать"],
    "скандовав": ["скандовавши"],
    "скандовавши": ["скандовав"],
    "сканив": ["сканивши"],
    "сканивши": ["сканив"],
    "сканировав": ["сканировавши"],
    "сканировавши": ["сканировав"],
    "сканирование": ["оцифровка", "просмотр"],
    "скань": ["филигрань"],
    "скапав": ["скапавши"],
    "скапавши": ["скапав"],
    "скапалгия": ["скапулалгия"],
    "скапливав": ["скапливавши"],
    "скапливавши": ["скапливав"],
    "скапливать": ["копить", "накапливать", "собирать", "сосредоточивать"],
    "скапливаться": ["скопляться", "копиться", "накапливаться"],
    "скапнув": ["скапнувши"],
    "скапнувши": ["скапнув"],
    "скаполит": ["мариалит", "главколит", "мейонит", "вернерит"],
    "скапотировав": ["скапотировавши"],
    "скапотировавши": ["скапотировав"],
    "скапутив": ["скапутивши"],
    "скапутивши": ["скапутив"],
    "скапывав": ["скапывавши"],
    "скапывавши": ["скапывав"],
    "скарб": ["пожитки", "барахло"],
    "скарбник": ["казначей"],
    "скаредничав": ["скаредничавши"],
    "скаредничавши": ["скаредничав"],
    "скаредничание": ["жмотничание", "жмотство"],
    "скаредничать": ["жадничать", "жилиться", "жмотствовать", "скупиться", "скопидомствовать", "скупердяйничать", "скопидомничать", "скряжничать"],
    "скаредность": ["скупость", "прижимистость", "скряжничество", "сквалыжничество", "жадность"],
    "скаредный": ["скупой", "жадный", "прижимистый"],
    "скарификация": ["процарапывание", "шрамирование"],
    "скарифицировав": ["скарифицировавши"],
    "скарифицировавши": ["скарифицировав"],
    "скарлатинный": ["скарлатинозный"],
    "скарлатинозный": ["скарлатинный"],
    "скармливав": ["скармливавши"],
    "скармливавши": ["скармливав"],
    "скарёжив": ["скарёживши"],
    "скарёживши": ["скарёжив"],
    "скат": ["спуск", "шина", "уклон"],
    "скатав": ["скатавши"],
    "скатавши": ["скатав"],
    "скатапультировав": ["скатапультировавши"],
    "скатапультировавши": ["скатапультировав"],
    "скатив": ["скативши"],
    "скативши": ["скатив"],
    "скатывав": ["скатывавши"],
    "скатывавши": ["скатывав"],
    "скать": ["сукать", "сучить", "ссучать"],
    "скаутизм": ["бойскаутизм", "скаутинг"],
    "скачав": ["скачавши"],
    "скачавши": ["скачав"],
    "скачати": ["завантажити"],
    "скачать": ["загрузить", "слить"],
    "скачивав": ["скачивавши"],
    "скачивавши": ["скачивав"],
    "скачивалка": ["качалка"],
    "скачивание": ["скачка"],
    "скачивать": ["сливать", "окатывать", "смывать", "переписывать"],
    "скачок": ["прыжок", "функция-ступенька", "функция хевисайда", "разрыв первого рода"],
    "скачь": ["скачка"],
    "скашивав": ["скашивавши"],
    "скашивавши": ["скашивав"],
    "скашивать": ["косить"],
    "скащивав": ["скащивавши"],
    "скащивавши": ["скащивав"],
    "скв": ["свободно конвертируемая валюта", "системная красная волчанка", "секция коротких волн", "система кондиционирования воздуха"],
    "скважина": ["отверстие", "дырочка"],
    "скважистость": ["пористость"],
    "сквайр": ["эсквайр"],
    "сквалыжив": ["сквалыживши"],
    "сквалыживши": ["сквалыжив"],
    "сквалыжить": ["сквалыжничать", "скряжничать"],
    "сквалыжничав": ["сквалыжничавши"],
    "сквалыжничавши": ["сквалыжничав"],
    "сквалыжничество": ["скаредность", "жадность", "скряжничество"],
    "сквапливий": ["квапливий"],
    "скварк": ["с-кварк"],
    "сквасив": ["сквасивши"],
    "сквасивши": ["сквасив"],
    "сквашивав": ["сквашивавши"],
    "сквашивавши": ["сквашивав"],
    "сквашивание": ["квашение", "заквашивание", "брожение"],
    "скверна": ["нечистота"],
    "скверная болезнь": ["сифилис", "льюис", "французская болезнь", "дурная болезнь", "стыдная болезнь", "сиф", "сифак", "сифачина"],
    "сквернев": ["скверневши"],
    "скверневши": ["сквернев"],
    "сквернив": ["сквернивши"],
    "сквернивши": ["сквернив"],
    "сквернослов": ["сквернословец", "матерщинник"],
    "сквернословив": ["сквернословивши"],
    "сквернословивши": ["сквернословив"],
    "сквернословие": ["матерщина", "ненормативная лексика", "обсценная лексика"],
    "сквернословье": ["сквернословие", "ненормативная лексика", "обсценная лексика", "матерщина", "мат"],
    "скверность": ["гадость", "мерзость", "омерзительность", "дрянь"],
    "сквернохульничав": ["сквернохульничавши"],
    "сквернохульничавши": ["сквернохульничав"],
    "скверный": ["гадкий", "мерзкий", "омерзительный", "отвратный", "отвратительный", "дурной", "плохой"],
    "сквизив": ["сквизивши"],
    "сквизивши": ["сквизив"],
    "сквирт": ["сквиртинг", "струйный оргазм"],
    "сквитав": ["сквитавши"],
    "сквитавши": ["сквитав"],
    "сквитывав": ["сквитывавши"],
    "сквитывавши": ["сквитывав"],
    "сквиш": ["антистресс"],
    "сквозив": ["сквозивши"],
    "сквозивши": ["сквозив"],
    "сквозистый": ["просвечивающий", "прозрачный", "полупрозрачный"],
    "сквозный": ["сквозной", "наливной"],
    "сквозь": ["насквозь", "через"],
    "скворец": ["шпак"],
    "скворечий": ["скворцовый"],
    "скворечник": ["скворечня", "скворечница"],
    "скворечня": ["скворечник"],
    "скворцовый": ["скворечий"],
    "скворчав": ["скворчавши"],
    "скворчавши": ["скворчав"],
    "скворчать": ["шкварчать"],
    "сквоттинг": ["сквотирование"],
    "скейлер": ["скайлер"],
    "скейт": ["скейтборд"],
    "скейт-парк": ["скейтодром"],
    "скейтборд": ["скейтбординг", "роликовая доска", "роллинг", "рула", "скейт"],
    "скейтбордер": ["скейтбордист", "скейтер", "скейтист"],
    "скейтбордив": ["скейтбордивши"],
    "скейтбордивши": ["скейтбордив"],
    "скейтбордист": ["скейтбордер", "скейтер", "скейтист"],
    "скейтер": ["скейтбордист", "скейтбордер", "скейтист"],
    "скейтист": ["скейтбордер", "скейтбордист", "скейтер"],
    "скелет": ["кости", "остов", "основа", "каркас"],
    "скелетизация": ["скелетирование"],
    "скелетировав": ["скелетировавши"],
    "скелетировавши": ["скелетировав"],
    "скелетирование": ["мумифицирование"],
    "скелетированный": ["мумифицированный"],
    "скеннировав": ["скеннировавши"],
    "скеннировавши": ["скеннировав"],
    "скепсис": ["скептицизм"],
    "скептик": ["фома неверующий"],
    "скептически": ["скептично", "недоверчиво"],
    "скептический": ["критический", "критичный", "недоверчивый", "подозрительный", "скептичный"],
    "скептично": ["недоверчиво", "скептически"],
    "скептичность": ["критичность", "маловерие", "недоверчивость", "скепсис", "скептицизм"],
    "скептичный": ["критический", "критичный", "недоверчивый", "подозрительный"],
    "скес": ["чёрт", "бес", "сатана", "дьявол", "диавол", "нечистая сила", "окаянный", "суккуб", "демон", "шайтан", "веельзевул", "аггел", "лукавый", "иблис", "люцифер"],
    "скетинг-ринк": ["ринк"],
    "скетч": ["пьеска", "набросок"],
    "скиаграфия": ["рентгенография"],
    "скиатлон": ["дуатлон"],
    "скибина": ["скиба"],
    "скибка": ["скиба", "кусок", "ломтик", "связка", "отрез"],
    "скиглив": ["скигливши"],
    "скигливши": ["скиглив"],
    "скидав": ["скидавши"],
    "скидавав": ["скидававши"],
    "скидававши": ["скидавав"],
    "скидавать": ["скидывать"],
    "скидавши": ["скидав"],
    "скидать": ["сбросать", "покидать"],
    "скиддер": ["трелёвочный трактор"],
    "скиджоринг": ["скийоринг"],
    "скидка": ["сбрасывание", "сброс", "скидывание", "послабление"],
    "скидывав": ["скидывавши"],
    "скидывавши": ["скидывав"],
    "скидывать": ["сбрасывать", "опускать", "свергать"],
    "скиксовав": ["скиксовавши"],
    "скиксовавши": ["скиксовав"],
    "скилл": ["мастерство", "умение", "навык", "сноровка", "эрудиция"],
    "скин": ["тема", "облик", "обложка", "шкура", "шкурка", "внешность"],
    "скиния": ["мишкан", "куща", "скиния собрания"],
    "скинув": ["скинувши"],
    "скинувши": ["скинув"],
    "скинуть": ["сбросить", "свергнуть", "снять", "освободиться", "сбавить", "отправить", "выслать", "родить", "выкинуть"],
    "скинуть бомжа": ["скинуть попрошайку"],
    "скинхед": ["скин", "скиноголовый", "бритоголовый", "бонхед", "неофашист"],
    "скип": ["вагонетка"],
    "скипев": ["скипевши"],
    "скипевши": ["скипев"],
    "скипидар": ["терпентинное масло", "терпентин"],
    "скипидарив": ["скипидаривши"],
    "скипидаривши": ["скипидарив"],
    "скипятив": ["скипятивши"],
    "скипятивши": ["скипятив"],
    "скипятить": ["вскипятить"],
    "скирд": ["скирда"],
    "скирдовав": ["скирдовавши"],
    "скирдовавши": ["скирдовав"],
    "скиркав": ["скиркавши"],
    "скиркавши": ["скиркав"],
    "скисав": ["скисавши"],
    "скисавши": ["скисав"],
    "скиснув": ["скиснувши"],
    "скиснувши": ["скиснув"],
    "скиталец": ["бродяга", "странник", "путешественник"],
    "скитание": ["странствование", "блуждание"],
    "скитанье": ["скитание"],
    "скитаться": ["странствовать"],
    "скитничав": ["скитничавши"],
    "скитничавши": ["скитничав"],
    "скитский": ["уединённый"],
    "скифос": ["кубок геракла"],
    "скицировав": ["скицировавши"],
    "скицировавши": ["скицировав"],
    "скицировать": ["скиццировать", "эскизировать"],
    "скиццировав": ["скиццировавши"],
    "скиццировавши": ["скиццировав"],
    "скиццировать": ["скицировать"],
    "склабиться": ["осклабляться"],
    "склаваж": ["эсклаваж", "бант-сквалаж", "браслет-сквалаж"],
    "склавин": ["склавен"],
    "склад": ["хранилище", "репозитарий", "депозитарий", "кладовая", "запас", "тип", "сложение", "слог"],
    "складав": ["складавши"],
    "складавши": ["складав"],
    "складати": ["класти"],
    "складировав": ["складировавши"],
    "складировавши": ["складировав"],
    "складка": ["морщина", "склад", "жилка"],
    "складно": ["нескладно"],
    "складной": ["складывающийся", "раскладной"],
    "складчатость": ["тектогенез"],
    "складывав": ["складывавши"],
    "складывавши": ["складывав"],
    "складыванье": ["складывание"],
    "складывать": ["класть", "составлять", "фальцевать", "сгибать", "прибавлять", "суммировать", "слагать", "сочинять"],
    "складываться": ["составляться"],
    "складывающийся": ["складной"],
    "склевав": ["склевавши"],
    "склевавши": ["склевав"],
    "склеив": ["склеивши"],
    "склеивав": ["склеивавши"],
    "склеивавши": ["склеивав"],
    "склеивающий": ["соединяющий", "налаживающий", "связующий", "скрепляющий"],
    "склеивши": ["склеив"],
    "склеп": ["усыпальница"],
    "склепав": ["склепавши"],
    "склепавши": ["склепав"],
    "склера": ["белковая оболочка", "белочная оболочка"],
    "склероглюкан": ["политран"],
    "склерозировав": ["склерозировавши"],
    "склерозировавши": ["склерозировав"],
    "склеротика": ["склера"],
    "склещивание": ["сцепка"],
    "склиз": ["сгон"],
    "склизкий": ["скользкий"],
    "склизнув": ["склизнувши"],
    "склизнувши": ["склизнув"],
    "склизок": ["шкура"],
    "скликав": ["скликавши"],
    "скликавши": ["скликав"],
    "скликивав": ["скликивавши"],
    "скликивавши": ["скликивав"],
    "скликивать": ["скликать"],
    "скликнув": ["скликнувши"],
    "скликнувши": ["скликнув"],
    "склока": ["дрязги"],
    "склонение": ["сгибание", "наклон"],
    "склоненье": ["склонение"],
    "склонив": ["склонивши"],
    "склонивши": ["склонив"],
    "склонить": ["наклонить", "нагнуть", "опустить", "убедить", "уговорить"],
    "склонить на свою сторону": ["завербовать"],
    "склонность": ["влечение", "стремление", "расположение", "симпатия"],
    "склоняв": ["склонявши"],
    "склонявши": ["склоняв"],
    "склонять": ["нагибать", "наклонять"],
    "склочив": ["склочивши"],
    "склочивав": ["склочивавши"],
    "склочивавши": ["склочивав"],
    "склочиваться": ["всклочиваться"],
    "склочивши": ["склочив"],
    "склочничав": ["склочничавши"],
    "склочничавши": ["склочничав"],
    "склочный": ["конфликтный", "скандальный", "вздорный"],
    "склюнув": ["склюнувши"],
    "склюнувши": ["склюнув"],
    "склянка": ["скляница"],
    "склянки": ["скляницы"],
    "склёвывав": ["склёвывавши"],
    "склёвывавши": ["склёвывав"],
    "склёпка": ["склёпывание", "клёпка"],
    "склёпывав": ["склёпывавши"],
    "склёпывавши": ["склёпывав"],
    "скобарь": ["скобовщик", "вахлак", "скупердяй", "псковитянин", "пскович"],
    "скобенив": ["скобенивши"],
    "скобенивши": ["скобенив"],
    "скобив": ["скобивши"],
    "скобивши": ["скобив"],
    "скоблив": ["скобливши"],
    "скобливши": ["скоблив"],
    "скоблить": ["скрести", "брить"],
    "скоблянка": ["скоблёнка"],
    "скобочник": ["скобовщик"],
    "сковав": ["сковавши"],
    "сковавши": ["сковав"],
    "сковорода": ["сковородка", "сковородочка", "сковородища"],
    "сковородив": ["сковородивши"],
    "сковородивши": ["сковородив"],
    "сковородка": ["сковорода"],
    "сковородник": ["чапельник", "чепела", "гримаса", "рожа"],
    "сковывав": ["сковывавши"],
    "сковывавши": ["сковывав"],
    "сковыривав": ["сковыривавши"],
    "сковыривавши": ["сковыривав"],
    "сковырнув": ["сковырнувши"],
    "сковырнувши": ["сковырнув"],
    "сковырнуть": ["сместить", "содрать", "сорвать"],
    "сковыряв": ["сковырявши"],
    "сковырявши": ["сковыряв"],
    "скок": ["прыганье", "скакание", "скачка", "прыжок", "скачок", "прыг", "ограбление", "грабёж", "кража"],
    "скок-поскок": ["прыг-скок"],
    "скокарь": ["медвежатник"],
    "скоктание": ["прелюдия", "петтинг", "фроттеризм"],
    "скол": ["скалывание", "осколок"],
    "сколачивав": ["сколачивавши"],
    "сколачивавши": ["сколачивав"],
    "сколдырничав": ["сколдырничавши"],
    "сколдырничавши": ["сколдырничав"],
    "сколиоз": ["искривление позвоночника", "идиопатический сколиоз", "сколиотическая болезнь", "сутулость"],
    "сколка": ["скалывание"],
    "сколково": ["российская кремниевая долина"],
    "сколлапсировав": ["сколлапсировавши"],
    "сколлапсировавши": ["сколлапсировав"],
    "сколов": ["сколовши"],
    "сколовши": ["сколов"],
    "сколотив": ["сколотивши"],
    "сколотивши": ["сколотив"],
    "сколупав": ["сколупавши"],
    "сколупавши": ["сколупав"],
    "сколупнув": ["сколупнувши"],
    "сколупнувши": ["сколупнув"],
    "сколупывав": ["сколупывавши"],
    "сколупывавши": ["сколупывав"],
    "сколхозив": ["сколхозивши"],
    "сколхозивши": ["сколхозив"],
    "сколхозить": ["смастерить"],
    "сколь": ["насколько", "кольми", "в какой мере", "в какой степени", "до чего"],
    "сколь-либо": ["сколько-нибудь", "сколь-нибудь"],
    "скользив": ["скользивши"],
    "скользивши": ["скользив"],
    "скользкая дорожка": ["скользкий путь"],
    "скользкий": ["склизкий", "ненадёжный", "двусмысленный", "сомнительный", "увёртливый", "хитрый"],
    "скользкий путь": ["скользкая дорожка"],
    "скользнув": ["скользнувши"],
    "скользнувши": ["скользнув"],
    "скользнуть": ["проскользить"],
    "сколько времени": ["который час"],
    "сколько душе угодно": ["вдоволь"],
    "сколько-нибудь": ["сколько-либо", "сколько-то", "в какой-то мере", "сколь-нибудь", "как-то", "несколько"],
    "сколько-то": ["сколько-нибудь", "сколько-либо", "в какой-то мере", "сколь-нибудь", "как-то", "несколько"],
    "скольт": ["колтт"],
    "скомандовав": ["скомандовавши"],
    "скомандовавши": ["скомандовав"],
    "скомбинировав": ["скомбинировавши"],
    "скомбинировавши": ["скомбинировав"],
    "скомкавши": ["скомкав"],
    "скомкать": ["измять", "сморщить"],
    "скомкивав": ["скомкивавши"],
    "скомкивавши": ["скомкивав"],
    "скоммуниздив": ["скоммуниздивши"],
    "скоммуниздивши": ["скоммуниздив"],
    "скоморох": ["потешник", "медвежатник", "комедиант", "артист с погорелого театра", "шут", "шут гороховый", "ломака", "гаер", "фигляр", "актёр", "артист"],
    "скоморошеский": ["насмешнический", "шутовской", "хохмаческий", "зубоскальский"],
    "скоморошество": ["скоморошничество"],
    "скоморошествовав": ["скоморошествовавши"],
    "скоморошествовавши": ["скоморошествовав"],
    "скоморошив": ["скоморошивши"],
    "скоморошивши": ["скоморошив"],
    "скоморошничав": ["скоморошничавши"],
    "скоморошничавши": ["скоморошничав"],
    "скоморошничество": ["скоморошество"],
    "скомпенсировав": ["скомпенсировавши"],
    "скомпенсировавши": ["скомпенсировав"],
    "скомпилировав": ["скомпилировавши"],
    "скомпилировавши": ["скомпилировав"],
    "скомплектовав": ["скомплектовавши"],
    "скомплектовавши": ["скомплектовав"],
    "скомпонировав": ["скомпонировавши"],
    "скомпонировавши": ["скомпонировав"],
    "скомпоновав": ["скомпоновавши"],
    "скомпоновавши": ["скомпоновав"],
    "скомпрометировав": ["скомпрометировавши"],
    "скомпрометировавши": ["скомпрометировав"],
    "скомпрометировать": ["опорочить", "опозорить"],
    "скомсомолить": ["скоммуниздить"],
    "сконвертировав": ["сконвертировавши"],
    "сконвертировавши": ["сконвертировав"],
    "сконденсировав": ["сконденсировавши"],
    "сконденсировавши": ["сконденсировав"],
    "сконсолидировав": ["сконсолидировавши"],
    "сконсолидировавши": ["сконсолидировав"],
    "сконструировав": ["сконструировавши"],
    "сконструировавши": ["сконструировав"],
    "сконструировать": ["проектировать", "строить"],
    "сконтактировав": ["сконтактировавши"],
    "сконтактировавши": ["сконтактировав"],
    "сконфигурировав": ["сконфигурировавши"],
    "сконфигурировавши": ["сконфигурировав"],
    "сконфуженно": ["смущённо"],
    "сконфуженный": ["смущённый"],
    "сконфузив": ["сконфузивши"],
    "сконфузивши": ["сконфузив"],
    "сконцентрировав": ["сконцентрировавши"],
    "сконцентрировавши": ["сконцентрировав"],
    "сконцентрированность": ["направленность", "собранность", "фиксированность", "устремлённость", "сосредоточенность"],
    "скончав": ["скончавши"],
    "скончавши": ["скончав"],
    "скончанье": ["скончание"],
    "скончаться": ["завершиться", "закончиться", "окончиться", "истечь", "кончаться", "прекратиться"],
    "скончевать": ["заканчивать"],
    "скончевающий": ["заканчивающий"],
    "скооперировав": ["скооперировавши"],
    "скооперировавши": ["скооперировав"],
    "скоординировав": ["скоординировавши"],
    "скоординировавши": ["скоординировав"],
    "скоординированность": ["согласованность", "слаженность"],
    "скоп": ["скопление", "орава", "запас", "соучастие"],
    "скопа": ["водяной орёл"],
    "скопав": ["скопавши"],
    "скопавши": ["скопав"],
    "скопец": ["евнух", "кастрат"],
    "скопив": ["скопивши"],
    "скопивши": ["скопив"],
    "скопидомничав": ["скопидомничавши"],
    "скопидомничавши": ["скопидомничав"],
    "скопидомничать": ["жмотствовать", "крохоборствовать", "крохоборничать", "скаредничать", "скупердяйничать"],
    "скопидомный": ["скряжистый", "сквалыжный", "скупой"],
    "скопидомство": ["скряжничество"],
    "скопидомствовав": ["скопидомствовавши"],
    "скопидомствовавши": ["скопидомствовав"],
    "скопипащенный": ["скопированный"],
    "скопировав": ["скопировавши"],
    "скопировавши": ["скопировав"],
    "скопиться": ["накопиться", "собраться"],
    "скопище": ["толпа", "сборище", "куча"],
    "скопление": ["концентрация", "накопление", "скопище", "собрание"],
    "скопленье": ["скопление"],
    "скопляв": ["скоплявши"],
    "скоплявши": ["скопляв"],
    "скоплять": ["скапливать", "копить"],
    "скопнив": ["скопнивши"],
    "скопнивши": ["скопнив"],
    "скопниться": ["сгруппироваться"],
    "скопнув": ["скопнувши"],
    "скопнувши": ["скопнув"],
    "скопом": ["сообща", "гуртом"],
    "скопытив": ["скопытивши"],
    "скопытивши": ["скопытив"],
    "скопытиться": ["свалиться с ног"],
    "скорая": ["скорая помощь", "медленная медицинская помощь", "скоряк", "клизмовозка", "карета скорой помощи"],
    "скорая помощь": ["скорая медицинская помощь", "скорая", "неотложка", "скоряк"],
    "скорбев": ["скорбевши"],
    "скорбевши": ["скорбев"],
    "скорбеть": ["скорбить", "горевать"],
    "скорбив": ["скорбивши"],
    "скорбивши": ["скорбив"],
    "скорбило": ["крахмал"],
    "скорбить": ["скорбеть", "горевать"],
    "скорбнув": ["скорбнувши"],
    "скорбнувши": ["скорбнув"],
    "скорбный": ["трагичный", "печальный", "горестный"],
    "скорбут": ["цинга", "цынга"],
    "скорбутный": ["цинготный"],
    "скорбь": ["горе", "несчастье"],
    "скорее": ["быстрее", "проворнее", "раньше", "вернее", "точнее", "лучше"],
    "скорее всего": ["должно быть", "наверное", "наверно", "наверняка", "по всей видимости", "по всей вероятности", "судя по всему", "по-видимому", "видимо", "как видно", "похоже", "кажется", "по всему вероятию", "вернее всего", "вероятно"],
    "скорефаниться": ["закорефаниться"],
    "скоринг": ["оценка", "шкала"],
    "скорлупа": ["скорлупка", "панцирь", "шелуха", "выеденное яйцо", "лжереальность", "посудина", "путамен"],
    "скорлупив": ["скорлупивши"],
    "скорлупивши": ["скорлупив"],
    "скормив": ["скормивши"],
    "скормивши": ["скормив"],
    "скорняжив": ["скорняживши"],
    "скорняживши": ["скорняжив"],
    "скорняжничав": ["скорняжничавши"],
    "скорняжничавши": ["скорняжничав"],
    "скорняк": ["меховщик"],
    "скорнячив": ["скорнячивши"],
    "скорнячивши": ["скорнячив"],
    "скоро": ["вскоре", "споро"],
    "скоро-наскоро": ["торопливо", "наспех"],
    "скоробив": ["скоробивши"],
    "скоробивши": ["скоробив"],
    "скоробогатев": ["скоробогатевши"],
    "скоробогатевши": ["скоробогатев"],
    "скоробогатый": ["разбогатевший"],
    "скородив": ["скородивши"],
    "скородивши": ["скородив"],
    "скородить": ["бороновать", "боронить"],
    "скородиться": ["бороноваться"],
    "скородум": ["соображающий", "решительный", "находчивый"],
    "скоролётка": ["ежемуха"],
    "скором": ["скоромное", "скоромь", "скоромятина", "скоромщина"],
    "скоромив": ["скоромивши"],
    "скоромивши": ["скоромив"],
    "скоромничав": ["скоромничавши"],
    "скоромничавши": ["скоромничав"],
    "скоромное": ["скором", "скоромь", "скоромятина", "скоромщина"],
    "скоромный": ["жирный", "мясной", "молочный", "неприличный", "непристойный", "нескромный", "сальный", "скабрёзный", "фривольный", "плотский", "похотливый", "чувственный"],
    "скоромь": ["скоромное", "скором", "скоромятина", "скоромщина", "сквернословие", "срамословие", "соромщина"],
    "скоропалительно": ["поспешно", "очертя голову"],
    "скоропалительный": ["поспешный"],
    "скоропись": ["курсив", "стенография"],
    "скоропостижная смерть": ["без смерти смерть"],
    "скоропостижно": ["внезапно", "неожиданно"],
    "скоропостижный": ["преждевременный", "скоропалительный"],
    "скоропреходящий": ["эфемерный", "мимолётный", "быстротечный", "краткотечный", "скоротечный", "кратковременный", "недолговечный", "непродолжительный"],
    "скоропротечный": ["скоротечный", "быстротечный", "кратковременный"],
    "скоростной": ["быстрый", "стремительный", "быстроходный", "ходкий", "быстроногий", "резвый", "проворный"],
    "скорострельнее": ["скорострельней"],
    "скорострельней": ["скорострельнее"],
    "скорость": ["быстрота", "темп", "передача", "поспешность", "торопливость"],
    "скоросшиватель": ["папка-скоросшиватель"],
    "скоротав": ["скоротавши"],
    "скоротавши": ["скоротав"],
    "скоротечно": ["быстротечно", "мимолётно", "стремительно"],
    "скоротечный": ["быстротечный", "кратковременный"],
    "скороёбишка": ["ивашка", "ебишка"],
    "скорпионница": ["скорпионовая муха"],
    "скорректировав": ["скорректировавши"],
    "скорректировавши": ["скорректировав"],
    "скорцонера": ["козелец"],
    "скорчив": ["скорчивши"],
    "скорчивав": ["скорчивавши"],
    "скорчивавши": ["скорчивав"],
    "скорчивши": ["скорчив"],
    "скорчить": ["искривить", "согнуть", "исказить", "скривить"],
    "скорый": ["быстрый", "стремительный", "скоростной", "поспешный", "нетерпеливый", "резвый", "близкий", "ближайший", "грядущий", "наступающий", "скорый поезд"],
    "скорый поезд": ["экспресс"],
    "скоряе": ["скорей"],
    "скорёжив": ["скорёживши"],
    "скорёживав": ["скорёживавши"],
    "скорёживавши": ["скорёживав"],
    "скорёживши": ["скорёжив"],
    "скосив": ["скосивши"],
    "скосивши": ["скосив"],
    "скособочив": ["скособочивши"],
    "скособочивав": ["скособочивавши"],
    "скособочивавши": ["скособочивав"],
    "скособочивши": ["скособочив"],
    "скосолапив": ["скосолапивши"],
    "скосолапивши": ["скосолапив"],
    "скосоротив": ["скосоротивши"],
    "скосоротивши": ["скосоротив"],
    "скостив": ["скостивши"],
    "скостивши": ["скостив"],
    "скосырь": ["щёголь", "франт", "спесивец"],
    "скотарня": ["скотарник"],
    "скотина": ["скот", "животное", "быдло", "гад", "негодяй"],
    "скотланд-ярд": ["полиция лондона"],
    "скотобаза": ["скотина"],
    "скотоводничав": ["скотоводничавши"],
    "скотоводничавши": ["скотоводничав"],
    "скотоложество": ["зоофилия", "скотоложство", "содомия"],
    "скотоложец": ["зоофил"],
    "скотоложство": ["скотоложество", "зоофилия"],
    "скотоотбрасыватель": ["путеочиститель", "метельник", "скотосбрасыватель", "скотоотбойник"],
    "скотопрогон": ["зверопроход"],
    "скотосбрасыватель": ["путеочиститель", "метельник", "скотоотбрасыватель", "скотоотбойник", "наметельник"],
    "скотский": ["брутальный", "животноводческий", "мерзкий", "некультурный", "скотоподобный"],
    "скотство": ["свинство"],
    "скотч": ["клейкая лента"],
    "скочив": ["скочивши"],
    "скочивши": ["скочив"],
    "скощав": ["скощавши"],
    "скощавши": ["скощав"],
    "скощать": ["скащивать"],
    "скр": ["скрф", "следственный комитет россии"],
    "скраб": ["скрэб"],
    "скраббл": ["скрабл", "скрэбл", "эрудит"],
    "скрабив": ["скрабивши"],
    "скрабивши": ["скрабив"],
    "скрабировав": ["скрабировавши"],
    "скрабировавши": ["скрабировав"],
    "скрабировать": ["отшелушивать"],
    "скрадок": ["заседка", "караулка", "сидьба"],
    "скрадывав": ["скрадывавши"],
    "скрадывавши": ["скрадывав"],
    "скрадывать": ["выкрадывать", "воровать"],
    "скракля": ["скраколь"],
    "скрап": ["металлолом"],
    "скрасив": ["скрасивши"],
    "скрасивши": ["скрасив"],
    "скрашивав": ["скрашивавши"],
    "скрашивавши": ["скрашивав"],
    "скребанув": ["скребанувши"],
    "скребанувши": ["скребанув"],
    "скребень": ["акантоцефал"],
    "скребнув": ["скребнувши"],
    "скребнувши": ["скребнув"],
    "скрежет": ["скрежетание"],
    "скрежетав": ["скрежетавши"],
    "скрежетавши": ["скрежетав"],
    "скрежетание": ["скрежет"],
    "скрежетанье": ["скрежетание"],
    "скрежетать": ["скрипеть"],
    "скрежетнув": ["скрежетнувши"],
    "скрежетнувши": ["скрежетнув"],
    "скрейпи": ["скрэйпи", "почесуха"],
    "скрепа": ["скрепление", "скрепка"],
    "скрепи": ["скрейпи", "почесуха"],
    "скрепив": ["скрепивши"],
    "скрепивши": ["скрепив"],
    "скрепка": ["крепёж"],
    "скрепляв": ["скреплявши"],
    "скреплявши": ["скрепляв"],
    "скрепляющий": ["соединяющий", "закрепляющий", "завязывающий", "стягивающий", "удостоверяющий", "заверяющий", "крепящий", "застёгивающий", "схватывающий", "сковывающий", "консолидирующий", "склеивающий"],
    "скреплённый": ["прикреплённый"],
    "скрепной": ["скрепочный"],
    "скрепоносец": ["ханжа"],
    "скрепочный": ["соединительный", "двухскрепочный", "закрепочный", "односкрепочный", "скрепляющий"],
    "скрепя сердце": ["из-под палки", "скрипя зубами", "стиснув зубы", "с тяжёлым сердцем", "через силу", "со скрежетом зубовным"],
    "скрестив": ["скрестивши"],
    "скрестивши": ["скрестив"],
    "скрещение": ["скрещивание"],
    "скрещенье": ["скрещение"],
    "скрещивав": ["скрещивавши"],
    "скрещивавши": ["скрещивав"],
    "скрещивание": ["гибридизация"],
    "скрещиванье": ["скрещивание"],
    "скривив": ["скрививши"],
    "скрививши": ["скривив"],
    "скривиться": ["искривиться"],
    "скривление": ["искривление", "перекривление", "изгибание"],
    "скример": ["скримак"],
    "скримить": ["скримовать"],
    "скринер": ["просмотровка"],
    "скринив": ["скринивши"],
    "скринивши": ["скринив"],
    "скринкаст": ["скринкастинг"],
    "скринкастинг": ["скринкаст"],
    "скринлайф": ["скринлайф-формат", "десктоп-фильм", "скринлайф-сериал", "скринлайф-фильм"],
    "скринлайф-фильм": ["десктоп-фильм", "скринлайф"],
    "скринсейвер": ["хранитель экрана"],
    "скриншот": ["скрин"],
    "скриншотив": ["скриншотивши"],
    "скриншотивши": ["скриншотив"],
    "скрип": ["скрипение"],
    "скрипаль": ["скрипник"],
    "скрипев": ["скрипевши"],
    "скрипевши": ["скрипев"],
    "скрипенье": ["скрипение"],
    "скрипеть": ["скрежетать"],
    "скрипица": ["скрипка"],
    "скрипка": ["скрипица", "скрыпица"],
    "скрипник": ["скрипаль"],
    "скрипнув": ["скрипнувши"],
    "скрипнувши": ["скрипнув"],
    "скрипт": ["сценарий"],
    "скриптовый": ["сценарный"],
    "скрипя зубами": ["со скрежетом зубовным", "скрежеща зубами", "через силу"],
    "скрипя сердцем": ["скрепя сердце"],
    "скришом": ["крадешком"],
    "скроив": ["скроивши"],
    "скроивши": ["скроив"],
    "скроллив": ["скролливши"],
    "скролливши": ["скроллив"],
    "скроллинг": ["скролл"],
    "скроллировав": ["скроллировавши"],
    "скроллировавши": ["скроллировав"],
    "скроллировать": ["скроллить"],
    "скроллить": ["прокручивать"],
    "скромничав": ["скромничавши"],
    "скромничавши": ["скромничав"],
    "скромничать": ["прибедняться"],
    "скромно": ["сдержанно"],
    "скромность": ["непритязательность", "неприхотливость", "простота", "кротость", "модестия"],
    "скромный": ["беспафосный", "беспритязательный", "кроткий", "неброский", "простецкий", "простой", "незначительный"],
    "скромняга": ["скромник", "скромница"],
    "скропав": ["скропавши"],
    "скропавши": ["скропав"],
    "скропать": ["накропать"],
    "скроссировав": ["скроссировавши"],
    "скроссировавши": ["скроссировав"],
    "скротальный": ["мошоночный"],
    "скрофулюс": ["золотуха"],
    "скрофулёз": ["золотуха"],
    "скрошив": ["скрошивши"],
    "скрошивши": ["скрошив"],
    "скруббировав": ["скруббировавши"],
    "скруббировавши": ["скруббировав"],
    "скругление": ["закругление", "округлость"],
    "скруглив": ["скругливши"],
    "скругливши": ["скруглив"],
    "скругляв": ["скруглявши"],
    "скруглявши": ["скругляв"],
    "скружив": ["скруживши"],
    "скруживши": ["скружив"],
    "скрупулёзно": ["дотошно", "подробно", "тщательно", "педантично", "пунктуально"],
    "скрупулёзность": ["тщательность"],
    "скрупулёзный": ["дотошный", "въедливый", "дотошливый"],
    "скрутив": ["скрутивши"],
    "скрутивши": ["скрутив"],
    "скрутка": ["скручивание", "самокрутка", "цигарка"],
    "скручивав": ["скручивавши"],
    "скручивавши": ["скручивав"],
    "скръндза": ["скъперник", "сребролюбец", "вариклечко", "стипца", "циция"],
    "скрыв": ["скрывши"],
    "скрывав": ["скрывавши"],
    "скрывавши": ["скрывав"],
    "скрыванье": ["скрывание"],
    "скрывать": ["прятать", "таить", "умалчивать", "утаивать"],
    "скрываться": ["исчезать", "пропадать", "прятаться", "таиться", "укорять", "упрекать", "порицать"],
    "скрываясь": ["прячась", "укрываясь"],
    "скрывши": ["скрыв"],
    "скрыня": ["сундук", "ларец", "шкатулка"],
    "скрыпев": ["скрыпевши"],
    "скрыпевши": ["скрыпев"],
    "скрыпнув": ["скрыпнувши"],
    "скрыпнувши": ["скрыпнув"],
    "скрысив": ["скрысивши"],
    "скрысивши": ["скрысив"],
    "скрысить": ["слямзить"],
    "скрытая сеть": ["даркнет", "тёмная сеть", "теневая сеть"],
    "скрытие": ["сокрытие", "оставление", "побег"],
    "скрытник": ["потаёник", "странник", "бегунок"],
    "скрытничав": ["скрытничавши"],
    "скрытничавши": ["скрытничав"],
    "скрытнический": ["затворнический", "бегунский", "страннический"],
    "скрытничество": ["странничество"],
    "скрытно": ["тайком"],
    "скрытнокристаллический": ["скрытокристаллический", "криптокристаллический"],
    "скрытность": ["закрытость", "секретность"],
    "скрыто": ["невидимо", "скрытно", "тайно", "подспудно", "потаённо"],
    "скрытокристаллический": ["скрытнокристаллический", "криптокристаллический"],
    "скрытость": ["неявность"],
    "скрыть": ["спрятать", "укрыть"],
    "скрыться": ["исчезнуть", "бежать", "удалиться", "уйти"],
    "скрючив": ["скрючивши"],
    "скрючивав": ["скрючивавши"],
    "скрючивавши": ["скрючивав"],
    "скрючивать": ["скорчивать", "корчить"],
    "скрючиваться": ["сгибаться", "скорчиваться"],
    "скрючивши": ["скрючив"],
    "скрючиться": ["согнуться", "скорчиться"],
    "скряжничав": ["скряжничавши"],
    "скряжничавши": ["скряжничав"],
    "скрянуть": ["сдвинуть", "тронуть", "надсадиться", "надорваться"],
    "скуба": ["акваланг"],
    "скубати": ["скубти", "смикати"],
    "скубить": ["скубти", "скубсти", "скубать"],
    "скубнути": ["скубонути"],
    "скубти": ["скубсти", "скубать"],
    "скудев": ["скудевши"],
    "скудевши": ["скудев"],
    "скудель": ["глина"],
    "скудельник": ["горшечник", "гончар", "могильщик", "гробокопатель", "мортус"],
    "скудельница": ["скудельня", "братская могила", "общая могила", "погост", "гончарка", "горшечница"],
    "скудельничий": ["гончарный", "могильный", "кладбищенский", "мертвецкий", "погостный"],
    "скудельный": ["глиняный", "хрупкий", "непрочный", "слабый", "недолговечный", "смертный", "бренный", "тленный", "убогий", "жалкий", "бедный", "скудный"],
    "скудельня": ["кладбище", "погост"],
    "скудеть": ["нищать", "иссякать"],
    "скудеющий": ["оскудевающий"],
    "скуднев": ["скудневши"],
    "скудневши": ["скуднев"],
    "скудно": ["мало", "маловато", "недостаточно", "недовольно", "бедно"],
    "скудный": ["бедный", "недостаточный"],
    "скудость": ["скудность", "недостаточность", "бедность"],
    "скудоумие": ["глупость"],
    "скука": ["скукота", "томление"],
    "скукоживаться": ["кукожиться"],
    "скукожиться": ["съёжиться", "сникнуть"],
    "скукотища": ["скучища", "скукота", "скукотень"],
    "скуленье": ["скуление"],
    "скулив": ["скуливши"],
    "скуливши": ["скулив"],
    "скулить": ["выть", "жаловаться", "сетовать", "роптать", "плакаться", "ныть", "хныкать"],
    "скульптор": ["ваятель"],
    "скульпторство": ["ваятельство"],
    "скульпторша": ["скульптор"],
    "скульптура": ["ваяние", "пластика", "скульпторство", "изваяние", "статуя"],
    "скулёж": ["нытьё"],
    "скумбрия": ["макрель"],
    "скумекав": ["скумекавши"],
    "скумекавши": ["скумекав"],
    "скуммьп": ["пальтэсь"],
    "скумпия": ["желтинник"],
    "скунс": ["вонючка"],
    "скупав": ["скупавши"],
    "скупавши": ["скупав"],
    "скупать": ["выкупать"],
    "скупердяй": ["скряга", "скупец", "скаред", "сквалыга", "жид"],
    "скупердяйка": ["скряга"],
    "скупердяйничав": ["скупердяйничавши"],
    "скупердяйничавши": ["скупердяйничав"],
    "скупердяйничать": ["жмотиться", "жмотничать", "жилиться", "жлобствовать", "сквалыжничать", "скупердяйствовать", "жадничать"],
    "скупердяйство": ["жадность", "скаредность", "скупость"],
    "скупердяйствовав": ["скупердяйствовавши"],
    "скупердяйствовавши": ["скупердяйствовав"],
    "скупердяйствовать": ["жмотиться", "жмотничать", "жилиться", "жлобствовать", "сквалыжничать", "скупердяйничать", "жадничать"],
    "скупив": ["скупивши"],
    "скупивши": ["скупив"],
    "скупий": ["скнарий", "скнаристий", "приглушений", "слабий", "хирлявий", "кволий", "легкий"],
    "скупить": ["выкупить"],
    "скупиться": ["жадничать", "скаредничать", "жилиться", "скряжничать", "сквалыжничать"],
    "скупка": ["покупка"],
    "скупой": ["прижимистый", "скаредный", "жадный", "сдержанный", "умеренный", "редкий", "неяркий", "тусклый", "неброский", "бедный", "скудный", "лаконичный", "немногословный", "краткий"],
    "скупость": ["жадность", "прижимистость", "скаредность", "бедность", "скудость", "сдержанность", "умеренность"],
    "скупщик краденного": ["барыга"],
    "скупщицкий": ["скупщический"],
    "скурив": ["скуривши"],
    "скуривав": ["скуривавши"],
    "скуривавши": ["скуривав"],
    "скуривши": ["скурив"],
    "скурпулёзность": ["тщательность"],
    "скуряжничав": ["скуряжничавши"],
    "скуряжничавши": ["скуряжничав"],
    "скусив": ["скусивши"],
    "скусивши": ["скусив"],
    "скусывав": ["скусывавши"],
    "скусывавши": ["скусывав"],
    "скутав": ["скутавши"],
    "скутавши": ["скутав"],
    "скутари": ["шкодра", "шкодер"],
    "скутеллум": ["скутеллюм"],
    "скутер": ["мотороллер", "кикборд", "аквабайк", "водный мотоцикл", "гидроцикл"],
    "скутывав": ["скутывавши"],
    "скутывавши": ["скутывав"],
    "скуф": ["скуфидон", "скуфяндра"],
    "скуфеечка": ["скуфейка"],
    "скучав": ["скучавши"],
    "скучавши": ["скучав"],
    "скучать": ["испытывать скуку", "тосковать", "грустить", "печалиться", "горевать", "кручиниться", "сокрушаться", "горюниться", "тяготиться", "докучать", "надоедать"],
    "скучив": ["скучивши"],
    "скучивав": ["скучивавши"],
    "скучивавши": ["скучивав"],
    "скучивание": ["скопление"],
    "скучиваться": ["сталпливаться"],
    "скучивши": ["скучив"],
    "скучища": ["скука", "скукота", "скукотища", "тоска"],
    "скучковаться": ["столпиться", "скучиться"],
    "скучнев": ["скучневши"],
    "скучневши": ["скучнев"],
    "скучно": ["безотрадно", "тоскливо", "неинтересно", "грустно", "безрадостно"],
    "скучный": ["неинтересный", "нудный", "грустный", "невесёлый", "печальный", "смурной", "расстроенный", "огорчённый", "скучающий"],
    "скушав": ["скушавши"],
    "скушавши": ["скушав"],
    "скъперник": ["сребролюбец", "вариклечко", "стипца", "циция", "пинтия", "скръндза"],
    "слаба на передок": ["мозги на передке", "передним местом думает", "на передок слаба", "хуестрадалица", "с хуя на хуй без передышки"],
    "слабав": ["слабавши"],
    "слабавши": ["слабав"],
    "слабак": ["хиляк", "дистрофик", "неудачник", "дистрофан"],
    "слабев": ["слабевши"],
    "слабевши": ["слабев"],
    "слабение": ["ослабление", "ослабевание"],
    "слабеть": ["ослабевать", "спадать"],
    "слабив": ["слабивши"],
    "слабивши": ["слабив"],
    "слабинка": ["слабина", "слабое место", "слабость", "недостаток", "уязвимость"],
    "слабительное": ["пургатив"],
    "слабнув": ["слабнувши"],
    "слабнувши": ["слабнув"],
    "слабнути": ["слабшати"],
    "слабнуть": ["слабеть", "хилеть"],
    "слабо": ["несильно", "хило", "неудачно", "плохо"],
    "слабо-жёлтый": ["нежно-жёлтый", "светло-жёлтый", "бледно-жёлтый", "блекло-жёлтый", "блёкло-жёлтый"],
    "слабовидящий": ["слеподыр"],
    "слабовик": ["силовик", "силовичок", "насиловик"],
    "слабоволие": ["мягкотелость", "бесхарактерность", "слабохарактерность", "слабодушие"],
    "слабовольный": ["безвольный", "малодушный", "слабодушный", "слабохарактерный"],
    "слабовыраженный": ["маловыраженный"],
    "слабодействующий": ["слабый"],
    "слабодушие": ["слабоволие", "малодушие"],
    "слабодушный": ["слабовольный", "малодушный"],
    "слабодушье": ["слабодушие"],
    "слабоизвестный": ["малоизвестный"],
    "слабонервный": ["нервный"],
    "слаборастворимый": ["малорастворимый"],
    "слабосилие": ["немощность", "слабость", "бессилие"],
    "слабосилье": ["слабосилие"],
    "слабосильный": ["слабый", "хилый"],
    "слабосолёный": ["малосольный"],
    "слабоструктурированный": ["полуструктурированный"],
    "слаботоксичный": ["низкотоксичный", "малотоксичный"],
    "слабоумный": ["дурак"],
    "слабоумье": ["слабоумие"],
    "слабохарактерный": ["безвольный", "бесхарактерный", "слабовольный", "мягкотелый"],
    "слабшати": ["слабнути"],
    "слабый пол": ["нежный пол", "прекрасный пол"],
    "слав": ["славши"],
    "слава": ["боря", "славка", "броня", "бряча", "вена", "веня", "владиславка", "влад", "владя", "вада", "вадя", "лада", "ладя", "славуня", "славуся"],
    "славив": ["славивши"],
    "славивши": ["славив"],
    "славизм": ["славянизм"],
    "славировав": ["славировавши"],
    "славировавши": ["славировав"],
    "славистика": ["славяноведение"],
    "славистический": ["славистский"],
    "славить": ["прославлять", "порочить"],
    "славка-завирушка": ["славка-мельничек"],
    "славленье": ["славление"],
    "славный": ["белый"],
    "славолюбие": ["тщеславие"],
    "славословив": ["славословивши"],
    "славословивши": ["славословив"],
    "славословить": ["воспевать", "восхвалять"],
    "славословный": ["доксологический"],
    "славословье": ["славословие"],
    "славутич": ["днепр"],
    "славши": ["слав"],
    "славянизация": ["славизация"],
    "славянизировав": ["славянизировавши"],
    "славянизировавши": ["славянизировав"],
    "славянизировать": ["ославянивать"],
    "славяноведение": ["славистика"],
    "славянолюб": ["славянолюбец"],
    "славянолюбец": ["славянолюб"],
    "славянофил": ["панславянист"],
    "славянофильствовав": ["славянофильствовавши"],
    "славянофильствовавши": ["славянофильствовав"],
    "славянофобия": ["славянофобство"],
    "славянофобствовав": ["славянофобствовавши"],
    "славянофобствовавши": ["славянофобствовав"],
    "славянск": ["тор"],
    "славянск-на-кубани": ["славянск"],
    "славянствовав": ["славянствовавши"],
    "славянствовавши": ["славянствовав"],
    "слагав": ["слагавши"],
    "слагавши": ["слагав"],
    "слагатель": ["сочинитель"],
    "слагать": ["складывать", "сочинять", "прибавлять"],
    "слаггер": ["силовик"],
    "сладж-метал": ["сладж"],
    "сладив": ["сладивши", "сделав", "совладавши", "смастерив", "смастеривши", "настроив", "настроивши", "подобрав", "подобравши", "устроив", "устроивши", "уладив", "уладивши", "совладав", "одолев"],
    "сладкая парочка": ["голубки", "парочка", "шерочка с машерочкой"],
    "сладкий": ["подслащённый", "свежий", "сырой", "приятный", "приторный"],
    "сладких снов": ["спокойной ночи"],
    "сладкое вино": ["десертное вино"],
    "сладкоежка": ["сластоежка", "сластёна"],
    "сладкоминдальный": ["сладко-миндальный"],
    "сладкопевно": ["сладкоголосо", "сладкоречиво"],
    "сладкопевность": ["сладкогласие"],
    "сладкопевный": ["сладкоголосый", "сладкогласный"],
    "сладкопение": ["сладкопенье"],
    "сладкопенье": ["сладкопение"],
    "сладкоречивость": ["сладкоречие"],
    "сладкоречие": ["сладкоречивость"],
    "сладостный": ["сладкий"],
    "сладострастие": ["похоть", "вожделение"],
    "сладострастник": ["блудник", "прелюбодей", "беспутник", "бабник", "похотник", "сатир", "любодей"],
    "сладострастно": ["сластолюбиво"],
    "сладострастье": ["сладострастие"],
    "сладость": ["сласть", "наслаждение", "услада"],
    "сладурана": ["хубавица"],
    "слаженно": ["согласованно", "дружно"],
    "слаженность": ["согласованность", "сработанность", "дружность", "согласность", "гармония", "гармоничность"],
    "слаживав": ["слаживавши"],
    "слаживавши": ["слаживав"],
    "слазав": ["слазавши"],
    "слазавши": ["слазав"],
    "слазив": ["слазивши"],
    "слазивши": ["слазив"],
    "слайд": ["диапозитив"],
    "слайд-шоу": ["презентация"],
    "слайм": ["лизун"],
    "слайсер": ["ломтерезка"],
    "сламывав": ["сламывавши"],
    "сламывавши": ["сламывав"],
    "сламывать": ["побеждать", "ослаблять", "ломать"],
    "сламываться": ["ломаться"],
    "сланцы": ["столица горючего камня"],
    "сластив": ["сластивши"],
    "сластивши": ["сластив"],
    "сластоежка": ["сладкоежка", "сластёна"],
    "сластолюбец": ["сладострастник"],
    "сластолюбивый": ["сладострастный"],
    "сластолюбие": ["сладострастие"],
    "сластолюбица": ["сладострастница"],
    "сласть": ["сладость", "яства", "лакомство", "удовольствие", "наслаждение", "приятность"],
    "сластёна": ["сладкоежка"],
    "слать": ["посылать", "отсылать", "отправлять", "направлять"],
    "слащавый": ["приторный"],
    "слева": ["ошую", "ошуюю", "по левую руку"],
    "слевачив": ["слевачивши"],
    "слевачивши": ["слевачив"],
    "слевачить": ["подхалтурить", "подработать", "подкалымить"],
    "слега": ["жердь", "слежка"],
    "слегав": ["слегавши"],
    "слегавши": ["слегав"],
    "слегонца": ["слегка", "маленько", "немного", "чуть-чуть", "чуток", "чутка"],
    "след": ["отпечаток", "шпур"],
    "след простыл": ["только и видели"],
    "следак": ["следователь"],
    "следачка": ["следовательница"],
    "следив": ["следивши"],
    "следивши": ["следив"],
    "следить": ["оставлять", "след"],
    "следовав": ["следовавши"],
    "следовавши": ["следовав"],
    "следование": ["следованье"],
    "следованье": ["следование"],
    "следователь": ["дознаватель"],
    "следователь-сыщик": ["сыскарь"],
    "следовательница": ["следовательша", "следачка"],
    "следовательно": ["следственно", "поэтому", "посему", "из этого видно", "из этого вытекает", "из этого выходит", "из этого следует", "из этого усматривается", "из этого явствует", "из этого можно вывести", "из этого можно заключить", "из этого можно  усмотреть", "значит", "знать", "видно"],
    "следовательша": ["следовательница"],
    "следовник": ["последовател", "привърженик", "сподвижник"],
    "следом за": ["вслед за", "после"],
    "следопыт": ["охотник", "поисковик"],
    "следственный изолятор": ["сизо"],
    "следствие": ["последствие", "результат", "итог", "плод", "продукт", "развязка", "конец", "исход", "эффект", "заключение"],
    "следующий": ["идущий", "последующий", "очередной", "нижеследующий", "нижеперечисленный"],
    "слежение": ["надзор"],
    "слеженье": ["слежение"],
    "слежка": ["слежение", "наблюдение"],
    "слеза": ["слезинка"],
    "слезав": ["слезавши"],
    "слезавши": ["слезав"],
    "слезать": ["выходить", "сходить"],
    "слезив": ["слезивши"],
    "слезивши": ["слезив"],
    "слезливость": ["плаксивость"],
    "слезливый": ["плаксивый"],
    "слезник": ["слезница", "слёзный мешок", "желобок", "выступ"],
    "слезоистечение": ["слёзоистечение", "слезотечение"],
    "слезоотделение": ["слезовыделение", "слезотечение"],
    "слезотечение": ["слёзоистечение", "слезоистечение"],
    "слезоточив": ["слезоточивши"],
    "слезоточивши": ["слезоточив"],
    "слезоточивый": ["слезящийся"],
    "слем": ["поэтический слем"],
    "слемиться": ["слэмовать"],
    "сленг": ["арго", "жаргон"],
    "сленгизм": ["арготизм"],
    "сленговость": ["жаргонность"],
    "сленговый": ["арготический", "жаргонный"],
    "слепая": ["незрячая"],
    "слепив": ["слепивши"],
    "слепивши": ["слепив"],
    "слепить": ["ослеплять"],
    "слепливав": ["слепливавши"],
    "слепливавши": ["слепливав"],
    "слепляв": ["слеплявши"],
    "слеплявши": ["слепляв"],
    "слепнув": ["слепнувши"],
    "слепнувши": ["слепнув"],
    "слеподыр": ["слабовидящий", "слепая дыра"],
    "слепозмейка": ["слепун", "червеобразная змея"],
    "слепой": ["незрячий", "слепец", "неразумный", "безрассудный", "случайный", "стихийный"],
    "слепошарый": ["близорукий"],
    "слепыш": ["макетка"],
    "слесарив": ["слесаривши"],
    "слесаривши": ["слесарив"],
    "слесарить": ["слесарничать"],
    "слесарка": ["слесарня", "слесарная"],
    "слесарная": ["слесарка", "слесарня"],
    "слесарничав": ["слесарничавши"],
    "слесарничавши": ["слесарничав"],
    "слесарничать": ["слесарить"],
    "слесарня": ["слесарка", "слесарная"],
    "слесарь-газовщик": ["слесарь-газовик"],
    "слесарь-сантехник": ["сантехник"],
    "слесаря": ["слесарничая"],
    "слесарёк": ["слесарёнок"],
    "слесарёнок": ["слесарёк"],
    "слетав": ["слетавши"],
    "слетавши": ["слетав"],
    "слетев": ["слетевши"],
    "слетевши": ["слетев"],
    "слеш": ["косая черта", "слэш"],
    "слиберальничав": ["слиберальничавши"],
    "слиберальничавши": ["слиберальничав"],
    "слив": ["сливание", "сток", "сгон"],
    "сливав": ["сливавши"],
    "сливавши": ["сливав"],
    "сливать": ["объединять", "выдавать", "уступать", "проигрывать", "сдавать", "списывать со счетов"],
    "сливки": ["бомонд", "элита", "остатки"],
    "сливной бачок": ["смывной бачок"],
    "сливовица": ["сливянка"],
    "сливочное масло": ["масло", "животное масло", "коровье масло"],
    "сливши": ["слив"],
    "слизав": ["слизавши"],
    "слизавши": ["слизав"],
    "слизевая кислота": ["галактаровая кислота", "муциновая кислота"],
    "слизевик": ["миксомицет"],
    "слизевой": ["слизистый"],
    "слизень": ["слизняк"],
    "слизистая": ["мукоза", "слизистая оболочка"],
    "слизнув": ["слизнувши"],
    "слизнувши": ["слизнув"],
    "слизняк": ["слизень", "ничтожество"],
    "слизывав": ["слизывавши"],
    "слизывавши": ["слизывав"],
    "слизывать": ["уничтожать", "убирать", "устранять", "копировать"],
    "слизький": ["ковзкий", "сковзкий"],
    "слимак": ["слизун"],
    "слимонив": ["слимонивши"],
    "слимонивши": ["слимонив"],
    "слинг": ["беби-слинг", "кенгуру"],
    "слиняв": ["слинявши"],
    "слинявши": ["слиняв"],
    "слипав": ["слипавши"],
    "слипавши": ["слипав"],
    "слипаться": ["склеиваться"],
    "слипнув": ["слипнувши"],
    "слипнувши": ["слипнув"],
    "слиповав": ["слиповавши"],
    "слиповавши": ["слиповав"],
    "слитковый": ["слиточный"],
    "слитно": ["плавно", "вместе"],
    "слиток": ["чушка", "самородок"],
    "слиточный": ["слитковый"],
    "слить": ["отлить", "вылить", "стечь", "сойти", "мочиться", "проиграть", "скачать", "загрузить"],
    "слицемерничав": ["слицемерничавши"],
    "слицемерничавши": ["слицемерничав"],
    "сличав": ["сличавши"],
    "сличавши": ["сличав"],
    "сличать": ["сравнивать", "сопоставлять"],
    "сличение": ["сличенье", "сравнение", "сопоставление"],
    "сличенье": ["сличение", "сравнение", "сравненье"],
    "сличив": ["сличивши"],
    "сличивши": ["сличив"],
    "сличить": ["сравнить", "сопоставить"],
    "слишком": ["чересчур", "чрезмерно", "излишне", "очень", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно", "чрезвычайно"],
    "слияв": ["слиявши"],
    "слиявши": ["слияв"],
    "слияние": ["объединение"],
    "слобода": ["посёлок"],
    "слободъчанинъ": ["слобожанинъ"],
    "слобожанинъ": ["слободъчанинъ"],
    "слова": ["высказывание", "текст", "разглагольствование"],
    "словакия": ["словацкая республика"],
    "словарист": ["лексикограф"],
    "словарная статья": ["словарный вход"],
    "словарник": ["лексикограф"],
    "словарный запас": ["лексика", "лексикон", "вокабулярий"],
    "словарь": ["лексикон", "словник"],
    "словацкая республика": ["словакия"],
    "словацкий": ["словацкий язык"],
    "словацкий язык": ["словацкий"],
    "словенин": ["славянин"],
    "словения": ["республика словения"],
    "словенск": ["великий новгород"],
    "словенский": ["словенский язык"],
    "словенский язык": ["словенский"],
    "словеса": ["речь", "разговор"],
    "словесная окрошка": ["словесный салат", "инкогеренция", "инкогерентность"],
    "словесно": ["словами", "вербально"],
    "словесный": ["вербальный"],
    "словив": ["словивши"],
    "словивши": ["словив"],
    "словить": ["поймать", "впоймать"],
    "словиться": ["пересечься"],
    "словникар": ["лексикограф"],
    "словно": ["будто", "как", "как будто", "точно", "кажется", "кажись", "подобно"],
    "словно ключевая вода": ["на вес золота"],
    "слово": ["дума", "реч", "обръщение", "проповед"],
    "слово в слово": ["буквально", "дословно"],
    "слово за слово": ["постепенно", "мало-помалу", "словом по слову"],
    "слово и дело": ["слово и дело государево"],
    "слово и дело государево": ["слово и дело"],
    "словоблуд": ["пустобрёх", "демагог", "пустослов", "пиздобол"],
    "словоблуддя": ["словоблудство"],
    "словоблудив": ["словоблудивши"],
    "словоблудивши": ["словоблудив"],
    "словоблудие": ["блядословие", "болтовня", "пустозвонство"],
    "словоблудствовав": ["словоблудствовавши"],
    "словоблудствовавши": ["словоблудствовав"],
    "словоблудствовать": ["пустословить"],
    "словолитец": ["словолитчик"],
    "словолитня": ["словолитная"],
    "словолитчик": ["словолитец"],
    "словом": ["устно", "итак", "короче", "короче говоря", "одним словом", "в общем", "стало быть"],
    "словом по слову": ["постепенно", "мало-помалу", "слово за слово"],
    "словообразование": ["дериватология"],
    "словообразовательный": ["деривационный", "словопроизводственный", "словопроизводный"],
    "словообразовательный формант": ["дериватор"],
    "словообразующий": ["словообразовательный"],
    "словоохотливо": ["болтливо", "многословно"],
    "словоохотливость": ["разговорчивость"],
    "словоохотливый": ["разговорчивый", "болтливый", "беседливый"],
    "словоохотный": ["словоохотливый"],
    "словопорядок": ["порядок слов"],
    "словопрение": ["спор", "препирательство"],
    "словопренье": ["словопрение"],
    "словопроизведение": ["словообразование", "словопроизводство", "деривация"],
    "словопроизводственный": ["деривационный", "словообразовательный"],
    "словопроизводство": ["деривация", "словообразование", "словопроизведение", "этимология"],
    "словослияние": ["словостяжение"],
    "словосочетанье": ["словосочетание"],
    "словосполука": ["словосполучення"],
    "словостяжение": ["словослияние"],
    "словотолкователь": ["толковый словарь"],
    "словоформа": ["аллолекс"],
    "словчив": ["словчивши"],
    "словчивши": ["словчив"],
    "слог": ["стиль", "язык", "речь"],
    "слоган": ["лозунг"],
    "слогановый": ["лозунговый"],
    "слоговой": ["силлабический", "слогообразующий"],
    "слоговый": ["силлабический"],
    "слогоморфема": ["тонированная силлабема", "морфосиллабема", "силлабоморфема"],
    "слогообразующий": ["слоговой"],
    "слоевище": ["таллом"],
    "слоечка": ["слойка", "слоёнка"],
    "сложа": ["сложив"],
    "сложенье": ["сложение"],
    "сложив": ["сложа", "сложивши"],
    "сложивши": ["сложив"],
    "сложить": ["уложить", "просуммировать"],
    "сложить руки": ["опустить руки"],
    "сложно": ["непросто", "нелегко"],
    "сложносоставной": ["разнокомпонентный", "сложный", "многофакторный", "многокомпонентный", "разнородный", "сложнопроизводный"],
    "сложность": ["трудность"],
    "сложные щи": ["трудные щи"],
    "сложный": ["составной", "комплексный", "трудный", "запутанный", "непростой", "нелёгкий"],
    "слоив": ["слоивши"],
    "слоивши": ["слоив"],
    "слоистое дерево": ["клеёный брус", "клеёная древесина", "клеёный массив"],
    "слой": ["страта"],
    "слойка": ["слоение", "слоёнка", "слоечка"],
    "слойчатый": ["слоистый"],
    "слом": ["разрушение"],
    "сломав": ["сломавши"],
    "сломавши": ["сломав"],
    "сломать": ["поломать", "разломать", "угробить", "сломить", "подавить"],
    "сломать целку": ["поломать целку", "заломить целку", "проломить целку", "порвать целку", "разорвать целку", "нарушить целку", "целку сломать", "целку поломать", "целку заломить", "целку проломить", "целку порвать", "целку разорвать", "целку нарушить", "ломануть целку", "целку ломануть"],
    "сломаться": ["выйти из строя", "поломаться", "гикнуться", "полететь"],
    "сломив": ["сломивши"],
    "сломивши": ["сломив"],
    "сломя голову": ["стремительно", "поспешно", "аллюром три креста", "на аллюре три креста", "стремглав", "опрометью", "резво", "бегом", "стрелой", "как стрела", "будто стрела", "словно стрела", "точно стрела", "молнией", "как молния"],
    "слон": ["офицер", "боров", "кабан"],
    "слонница": ["элефантерия"],
    "слоновий": ["слоновый"],
    "слоновость": ["элефантиаз"],
    "слоновый": ["слоновий"],
    "слонопотам": ["слон"],
    "слоняв": ["слонявши"],
    "слонявши": ["слоняв"],
    "слоняться": ["болтаться", "околачиваться", "таскаться", "шататься", "шляться", "чкаться"],
    "слонёнок": ["слоник", "слонёночек"],
    "слопав": ["слопавши"],
    "слопавши": ["слопав"],
    "слопать": ["сожрать", "уничтожить", "истребить", "поглотить"],
    "слопать труса": ["перетрухать"],
    "слот": ["разъём", "гнездо", "слот расширения"],
    "слотив": ["слотивши"],
    "слотивши": ["слотив"],
    "слоумо": ["слоумоушен"],
    "слоумоушен": ["рапид"],
    "слоуплеив": ["слоуплеивши"],
    "слоуплеивши": ["слоуплеив"],
    "слоупок": ["тормоз", "тугодум"],
    "слоёнка": ["слойка", "слоечка"],
    "слуга": ["прислуга", "прислужник"],
    "слуга народа": ["депутат", "зелёный"],
    "служанка": ["прислужница", "прислуга"],
    "служаночка": ["служанка"],
    "служащая": ["работница", "сотрудница"],
    "служащий": ["предназначенный", "применяемый", "используемый", "клерк"],
    "служба": ["служение", "работа", "повинность", "богослужение", "сервис", "резидентная программа", "резидент"],
    "служебник": ["литургиарий"],
    "служив": ["служивши"],
    "служивав": ["служивавши"],
    "служивавши": ["служивав"],
    "служивши": ["служив"],
    "служитель": ["слуга"],
    "служить": ["работать", "состоять", "подчиняться", "помогать", "угождать", "содействовать", "прислуживать", "повиноваться", "использоваться", "являться", "предназначаться", "годиться", "действовать", "фурычить"],
    "служниця": ["прислужниця", "служка"],
    "слузгав": ["слузгавши"],
    "слузгавши": ["слузгав"],
    "слукавив": ["слукавивши"],
    "слукавивши": ["слукавив"],
    "слукавить": ["схитрить", "обмануть", "соврать"],
    "слупив": ["слупивши"],
    "слупивши": ["слупив"],
    "слупить": ["состричь"],
    "слупливав": ["слупливавши"],
    "слупливавши": ["слупливав"],
    "слупливать": ["слуплять"],
    "слупляв": ["слуплявши"],
    "слуплявши": ["слупляв"],
    "слуплять": ["слупливать", "драть"],
    "слух": ["музыкальный слух", "молва", "сплетня"],
    "слухав": ["слухавши"],
    "слухавши": ["слухав"],
    "слуховой барабан": ["барабан"],
    "случав": ["случавши"],
    "случавши": ["случав"],
    "случайно": ["непредвиденно", "ненароком", "нечаянно", "непредумышленно", "как раз", "волею судеб", "нерегулярно", "беспорядочно", "как попало", "случаем"],
    "случайность": ["стохастичность", "случай", "шанс", "проигрыш"],
    "случайный": ["рандомный", "казуальный", "непредсказуемый"],
    "случайный человек": ["любимец", "временщик"],
    "случать": ["спаривать"],
    "случив": ["случивши"],
    "случивши": ["случив"],
    "случившийся": ["произошедший"],
    "случить": ["спарить"],
    "случиться": ["произойти", "проистечь", "совершиться", "довестись"],
    "случка": ["вязка", "спаривание"],
    "слушав": ["слушавши"],
    "слушавши": ["слушав"],
    "слушанье": ["слушание"],
    "слушать пиздой": ["пиздой слушать"],
    "слушивав": ["слушивавши"],
    "слушивавши": ["слушивав"],
    "слушок": ["сплетенка", "сплетня"],
    "слущив": ["слущивши"],
    "слущивши": ["слущив"],
    "слыв": ["слывши"],
    "слывущий": ["считающийся", "почитающийся"],
    "слывши": ["слыв"],
    "слыть": ["считаться", "числиться"],
    "слыхав": ["слыхавши"],
    "слыхавши": ["слыхав"],
    "слыхать": ["слышать"],
    "слыхивав": ["слыхивавши"],
    "слыхивавши": ["слыхивав"],
    "слышав": ["слышавши"],
    "слышавши": ["слышав"],
    "слышание": ["слышанье"],
    "слышаться": ["звучать", "раздаваться", "доноситься", "чувствоваться"],
    "слышь": ["эй", "гей"],
    "слэк": ["слэклайн"],
    "слэмовав": ["слэмовавши"],
    "слэмовавши": ["слэмовав"],
    "слэмовать": ["слэмиться"],
    "слэш": ["косая черта", "слеш"],
    "слюбезничав": ["слюбезничавши"],
    "слюбезничавши": ["слюбезничав"],
    "слюда": ["плёнка"],
    "слюнив": ["слюнивши"],
    "слюнивши": ["слюнив"],
    "слюногон": ["анациклус"],
    "слюнтяйничав": ["слюнтяйничавши"],
    "слюнтяйничавши": ["слюнтяйничав"],
    "слюнявив": ["слюнявивши"],
    "слюнявивши": ["слюнявив"],
    "слюняй": ["слюнтяй"],
    "слюсарний": ["слюсарський"],
    "слякотный": ["хлябистый"],
    "слякоть": ["слота", "слоть"],
    "слямзив": ["слямзивши"],
    "слямзивши": ["слямзив"],
    "слямзить": ["стибрить"],
    "сляпав": ["сляпавши"],
    "сляпавши": ["сляпав"],
    "сляпсив": ["сляпсивши"],
    "сляпсивши": ["сляпсив"],
    "сляпсить": ["слямзить"],
    "сляпы": ["безразважны"],
    "слёзка": ["слезинка"],
    "слёзник": ["адлай", "бусенник", "бусенник обыкновенный", "иовлевы слёзы", "иовы слёзы", "коикс слёзы иовы", "богородицыны слёзы", "богородицыны слёзки"],
    "слёзный": ["жалобный"],
    "слёзовыжималка": ["слёзодавилка"],
    "слёзодавилка": ["слёзовыжималка"],
    "слёток": ["птенец", "выскочка"],
    "смаглий": ["смаглявий"],
    "смаглявий": ["смаглий"],
    "смаглястий": ["смаглюватий"],
    "смаз": ["шевелёнка"],
    "смазав": ["смазавши"],
    "смазавши": ["смазав"],
    "смазать": ["помазать", "намазать"],
    "смазка": ["смазывание"],
    "смазливый": ["миловидный", "хорошенький"],
    "смазывав": ["смазывавши"],
    "смазывавши": ["смазывав"],
    "смазыванье": ["смазывание"],
    "смаивав": ["смаивавши"],
    "смаивавши": ["смаивав"],
    "смайл": ["смайлик", "эмотикон"],
    "смайлик": ["смайл", "эмотикон", "эмограмма", "эмотиконка", "эмоцион"],
    "смайнать": ["смайновать"],
    "смайновать": ["смайнать"],
    "смакетировав": ["смакетировавши"],
    "смакетировавши": ["смакетировав"],
    "смаклачив": ["смаклачивши"],
    "смаклачивши": ["смаклачив"],
    "смаклерив": ["смаклеривши"],
    "смаклеривши": ["смаклерив"],
    "смаклеровав": ["смаклеровавши"],
    "смаклеровавши": ["смаклеровав"],
    "смаклеровать": ["смаклерить"],
    "смаковав": ["смаковавши"],
    "смаковавши": ["смаковав"],
    "смакованье": ["смакование"],
    "смаковница": ["смоковница", "инжир", "фиговое дерево", "смоква", "винная ягода"],
    "смактаць": ["ссаць"],
    "смалвливав": ["смалвливавши"],
    "смалвливавши": ["смалвливав"],
    "смалец": ["смальц", "лярд", "шмальц"],
    "смалив": ["смаливши"],
    "смаливши": ["смалив"],
    "смалить": ["опалять", "шмалять", "палить", "стрелять", "бить", "смолить", "курить", "дымить"],
    "смалодушествовав": ["смалодушествовавши"],
    "смалодушествовавши": ["смалодушествовав"],
    "смалодушничав": ["смалодушничавши"],
    "смалодушничавши": ["смалодушничав"],
    "смалчивав": ["смалчивавши"],
    "смалчивавши": ["смалчивав"],
    "смалывав": ["смалывавши"],
    "смалывавши": ["смалывав"],
    "смальства": ["сызмальства"],
    "смальта": ["шмальта"],
    "смальтин": ["шмальтин", "шпейсовый кобальт"],
    "смальц": ["смалец", "лярд", "шмальц"],
    "сманеврировав": ["сманеврировавши"],
    "сманеврировавши": ["сманеврировав"],
    "сманеврировать": ["славировать", "схитрить"],
    "сманив": ["сманивши"],
    "сманивав": ["сманивавши"],
    "сманивавши": ["сманивав"],
    "сманивши": ["сманив"],
    "сманув": ["сманувши"],
    "сманувши": ["сманув"],
    "смарав": ["смаравши"],
    "смаравши": ["смарав"],
    "смарагд": ["изумруд"],
    "смарагдовый": ["изумрудный"],
    "смаргивав": ["смаргивавши"],
    "смаргивавши": ["смаргивав"],
    "смаривав": ["смаривавши"],
    "смаривавши": ["смаривав"],
    "смаривать": ["размаривать", "утомлять"],
    "смарк": ["шмарок"],
    "смарт-часы": ["умные часы", "часофон"],
    "смартфон": ["смарт-телефон", "смартофон", "коммуникатор", "смарт"],
    "смарывав": ["смарывавши"],
    "смарывавши": ["смарывав"],
    "смастаченный": ["смастерённый"],
    "смастачив": ["смастачивши"],
    "смастачивши": ["смастачив"],
    "смастачить": ["смастерить"],
    "смастерив": ["смастеривши"],
    "смастеривши": ["смастерив"],
    "смастерить": ["сделать", "сладить", "изготовить", "произвести", "изладить", "соорудить", "сработать", "смастачить", "выдать"],
    "смастрячить": ["смастерить"],
    "сматрати": ["мислити"],
    "сматривав": ["сматривавши"],
    "сматривавши": ["сматривав"],
    "сматывав": ["сматывавши"],
    "сматывавши": ["сматывав"],
    "сматывать": ["мотать"],
    "сматываться": ["скручиваться"],
    "смахав": ["смахавши"],
    "смахавши": ["смахав"],
    "смахивав": ["смахивавши"],
    "смахивавши": ["смахивав"],
    "смахнув": ["смахнувши"],
    "смахнувши": ["смахнув"],
    "смачивав": ["смачивавши"],
    "смачивавши": ["смачивав"],
    "смачна": ["нясмачна"],
    "смаяв": ["смаявши"],
    "смаявши": ["смаяв"],
    "смаять": ["измучить", "истомить", "сморить", "изнурить"],
    "смев": ["смевши"],
    "смевши": ["смев"],
    "смежав": ["смежавши"],
    "смежавши": ["смежав"],
    "смежать": ["смыкать", "закрывать", "сближать"],
    "смежив": ["смеживши"],
    "смеживав": ["смеживавши"],
    "смеживавши": ["смеживав"],
    "смеживши": ["смежив"],
    "смежить": ["сомкнуть", "закрыть"],
    "смежить очи": ["заснуть", "уснуть"],
    "смежность": ["сопредельность", "соседство"],
    "смежный": ["прилегающий", "примыкающий", "ближайший", "соседний"],
    "смекав": ["смекавши"],
    "смекавши": ["смекав"],
    "смекалистый": ["сметливый", "сообразительный"],
    "смекалка": ["сообразительность", "догадливость", "сметливость", "смекалистость"],
    "смекать": ["соображать"],
    "смекнув": ["смекнувши"],
    "смекнувши": ["смекнув"],
    "смелев": ["смелевши"],
    "смелевши": ["смелев"],
    "смелеть": ["храбреть"],
    "смело": ["храбро", "мужественно", "доблестно", "отважно", "бесстрашно"],
    "смелость": ["мужество", "храбрость", "отвага", "доблесть", "бесстрашие"],
    "смелый": ["храбрый", "мужественный", "отважный", "бесстрашный", "неустрашимый", "новаторский"],
    "смельчак": ["храбрец"],
    "смена": ["замена", "изменение"],
    "сменивав": ["сменивавши"],
    "сменивавши": ["сменивав"],
    "сменивши": ["сменив"],
    "сменить": ["заменить", "сместить", "заместить", "прийти на смену", "вытеснить"],
    "сменить пластинку": ["переменить пластинку"],
    "сменка": ["смена", "сменная обувь"],
    "сменная обувь": ["сменка"],
    "сменяв": ["сменявши"],
    "сменявши": ["сменяв"],
    "сменяемость": ["смена", "сменность"],
    "смердев": ["смердевши"],
    "смердевши": ["смердев"],
    "смердение": ["смерденье"],
    "смерденье": ["смердение"],
    "смердеть": ["вонять"],
    "смердив": ["смердивши"],
    "смердивши": ["смердив"],
    "смердить": ["смердеть", "вонять"],
    "смердящий": ["вонючий", "зловонный", "смрадный"],
    "смерека": ["ялина"],
    "смерековий": ["ялиновий"],
    "смерзав": ["смерзавши"],
    "смерзавши": ["смерзав"],
    "смерив": ["смеривши"],
    "смеривание": ["мерение", "измерение", "замеривание", "обмер", "вымеривание", "обмеривание", "перемеривание"],
    "смеривши": ["смерив"],
    "смерить": ["измерить"],
    "смеркав": ["смеркавши"],
    "смеркавши": ["смеркав"],
    "смеркаться": ["вечереть"],
    "смеркнув": ["смеркнувши"],
    "смеркнувши": ["смеркнув"],
    "смертельный": ["летальный", "смертоносный", "убийственный", "последний", "мертвящий", "гибельный", "смерти подобный", "разрушительный", "губительный", "смертный"],
    "смерти не выпросишь": ["снега зимой не выпросишь"],
    "смертная": ["костлявая", "безносая", "курносая", "старуха с клюкой", "старуха с косой"],
    "смертная казнь": ["высшая мера социальной защиты", "высшая мера", "высшая мера наказания"],
    "смертная память": ["памятование смерти"],
    "смертник": ["самоубийца"],
    "смертный": ["смертельный"],
    "смертный час": ["последний час"],
    "смертоносность": ["летальность"],
    "смертоубийство": ["убийство", "убиение", "умерщвление"],
    "смерть": ["конец", "кончина", "преставление", "уход из жизни", "агония", "умирание", "финал"],
    "смерть как": ["до смерти", "смертельно", "очень", "в крайней степени", "чрезвычайно", "ужасно", "жутко"],
    "смерть не берёт": ["смерть потеряла"],
    "смерть потеряла": ["смерть не берёт"],
    "смерч": ["торнадо"],
    "смерчевой": ["торнадный"],
    "смеряв": ["смерявши"],
    "смерявши": ["смеряв"],
    "смерёточка": ["смерёдушка", "смерётка", "смерётушка", "смертонька", "смерточка", "смертушка", "смёртушка"],
    "смесевый": ["смесовый"],
    "смесив": ["смесивши"],
    "смесивши": ["смесив"],
    "смесительный": ["смешивающий"],
    "смесовый": ["смесевый"],
    "смести с лица земли": ["стереть с лица земли"],
    "сместив": ["сместивши"],
    "сместивши": ["сместив"],
    "сместить": ["переместить", "сдвинуть"],
    "смесь": ["мешанина", "помесь", "гибрид"],
    "смесь бульдога с носорогом": ["помесь негра с мотоциклом"],
    "сметав": ["сметавши"],
    "сметавши": ["сметав"],
    "сметанник": ["сметанница"],
    "сметанообразный": ["сметаноподобный"],
    "сметив": ["сметивши"],
    "сметивши": ["сметив"],
    "сметливость": ["смётка", "смекалистость", "смекалка", "находчивость", "сообразительность", "догадливость"],
    "сметливый": ["сообразительный", "догадливый", "находчивый"],
    "сметнув": ["сметнувши"],
    "сметнувши": ["сметнув"],
    "сметнуть": ["сметнуться"],
    "сметнуться": ["сметнуть"],
    "сметь": ["осмеливаться", "дерзать"],
    "сметься": ["осмеливаться"],
    "смех": ["хохот"],
    "смехоподобный": ["смехотворный", "смешной"],
    "смехотворный": ["потешный", "анекдотичный", "комический", "курьёзный"],
    "смехуёчки": ["смешки", "шуточки", "хаханьки", "хухоньки", "хаханьки да хухоньки", "пиздихаханьки", "пиздохаханьки", "пиздихухоньки", "пиздохухоньки"],
    "смехуёчки раздавать": ["раздавать смехуёчки"],
    "смечав": ["смечавши"],
    "смечавши": ["смечав"],
    "смешав": ["смешавши"],
    "смешавши": ["смешав"],
    "смешанное возбуждение": ["компаундирование", "компаундное возбуждение"],
    "смешанный": ["смущенный", "растерянный"],
    "смешаться": ["перепутаться", "смутиться"],
    "смешение": ["смешивание", "смесь", "сочетание", "помесь"],
    "смешенье": ["смешение"],
    "смешив": ["смешивши"],
    "смешивав": ["смешивавши"],
    "смешивавши": ["смешивав"],
    "смешивание": ["смешение", "смешиванье"],
    "смешивать": ["перемешивать", "мешать", "расстраивать", "путать"],
    "смешиваться": ["перемешиваться", "перепутываться"],
    "смешивши": ["смешив"],
    "смешинка в рот попала": ["смешинка на брюхо попала"],
    "смешить пизду": ["пизду смешить"],
    "смешливец": ["весельчак"],
    "смешно": ["забавно", "ржачно", "поржательно", "угарно", "весело", "нелепо", "странно"],
    "смешной": ["смехотворный", "потешный", "забавный"],
    "смещав": ["смещавши"],
    "смещавши": ["смещав"],
    "смещать": ["перемещать", "сдвигать", "ломать", "увольнять", "отстранять"],
    "смещаться": ["сдвигаться", "перемещаться"],
    "смещение": ["сдвиг", "подвижка"],
    "смещенье": ["смещение"],
    "смеючись": ["смеясь", "посмеиваясь"],
    "смеяться": ["насмехаться", "вышучивать", "подшучивать", "подтрунивать", "прикалываться", "засмеивать", "подкалывать", "поддевать", "надсмехаться", "потешаться", "издеваться", "зубоскалить", "зубоскальничать", "ёрничать", "высмеивать"],
    "смеяться до усрачки": ["смеяться до усёра", "смеяться до усёру"],
    "сми": ["средство массовой информации", "пресса", "медиа", "масс-медиа", "четвёртая власть"],
    "смигивав": ["смигивавши"],
    "смигивавши": ["смигивав"],
    "смигнув": ["смигнувши"],
    "смигнувши": ["смигнув"],
    "смизюрив": ["смизюривши"],
    "смизюривши": ["смизюрив"],
    "смикитив": ["смикитивши"],
    "смикитивши": ["смикитив"],
    "смикшировав": ["смикшировавши"],
    "смикшировавши": ["смикшировав"],
    "смикшировать": ["затушевать"],
    "смилакс": ["сарсапарель"],
    "сминав": ["сминавши"],
    "сминавши": ["сминав"],
    "сминать": ["мять", "комкать", "опрокидывать", "подавлять", "громить", "оттеснять", "побеждать"],
    "сминусовав": ["сминусовавши"],
    "сминусовавши": ["сминусовав"],
    "смирение": ["усмирение", "укрощение", "смиренье", "примирение", "кротость", "покорность", "покора"],
    "смиренничав": ["смиренничавши"],
    "смиренничавши": ["смиренничав"],
    "смиренно": ["покорно", "послушно"],
    "смиренномудрие": ["непрекословие", "покорность"],
    "смиренность": ["кротость", "смирение", "покорность"],
    "смиренный": ["покорный"],
    "смирення": ["покора"],
    "смиренье": ["смирение"],
    "смирив": ["смиривши"],
    "смиривши": ["смирив"],
    "смирить": ["укротить", "усмирить", "утихомирить", "сдержать", "подавить"],
    "смириться": ["покориться"],
    "смирна": ["мирра", "мирр", "мирро"],
    "смирнев": ["смирневши"],
    "смирневши": ["смирнев"],
    "смирненько": ["смирнёхонько"],
    "смирный": ["спокойный", "тихий", "кроткий"],
    "смирнёхонький": ["смирнёшенький", "смирный", "спокойный", "кроткий"],
    "смирнёхонько": ["смирнёшенько", "смирёхонько"],
    "смирнёшенький": ["смирнёхонький"],
    "смирнёшенько": ["смирнёхонько"],
    "смиряв": ["смирявши"],
    "смирявши": ["смиряв"],
    "смирять": ["укрощать", "усмирять", "сдерживать", "подавлять"],
    "смиряться": ["примиряться"],
    "смирёхонько": ["смирнёшенько", "смирнёхонько"],
    "смисл": ["сенс"],
    "смлада": ["смладу", "смолоду"],
    "смладу": ["смлада", "смолоду"],
    "смогав": ["смогавши"],
    "смогавши": ["смогав"],
    "смогши": ["сумев", "сумевши"],
    "смогший": ["сумевший"],
    "смоделировав": ["смоделировавши"],
    "смоделировавши": ["смоделировав"],
    "смодулировав": ["смодулировавши"],
    "смодулировавши": ["смодулировав"],
    "смозговав": ["смозговавши"],
    "смозговавши": ["смозговав"],
    "смозговать": ["обмозговать"],
    "смокав": ["смокавши"],
    "смокавши": ["смокав"],
    "смоква": ["инжир", "фига", "смоковница", "фиговое дерево"],
    "смоки": ["стрелка"],
    "смоки айс": ["смоки"],
    "смокнув": ["смокнувши"],
    "смокнувши": ["смокнув"],
    "смоковница": ["инжир", "фиговое дерево", "смоква", "винная ягода"],
    "смоктати": ["ссати"],
    "смола": ["смоль", "синтетическая смола"],
    "смолачивав": ["смолачивавши"],
    "смолачивавши": ["смолачивав"],
    "смолвив": ["смолвивши"],
    "смолвивши": ["смолвив"],
    "смолвливав": ["смолвливавши"],
    "смолвливавши": ["смолвливав"],
    "смолвливать": ["смалвливать", "смолвлять"],
    "смолвляв": ["смолвлявши"],
    "смолвлявши": ["смолвляв"],
    "смоленская область": ["смоленщина"],
    "смолив": ["смоливши"],
    "смоливши": ["смолив"],
    "смолистый": ["смолевой", "смолянистый", "смоляной", "угольный"],
    "смолить": ["смалить"],
    "смолка": ["зорька"],
    "смолкав": ["смолкавши"],
    "смолкавши": ["смолкав"],
    "смолкать": ["замолкать", "умолкать"],
    "смолкнув": ["смолкнувши"],
    "смолкнувши": ["смолкнув"],
    "смолов": ["смоловши"],
    "смоловши": ["смолов"],
    "смолоду": ["смлада", "смладу"],
    "смолокур": ["смоловар", "смоляр"],
    "смолокурня": ["смоловарня"],
    "смолотив": ["смолотивши"],
    "смолотивши": ["смолотив"],
    "смолотить": ["обмолотить", "стрескать", "слопать", "сожрать"],
    "смолчав": ["смолчавши"],
    "смолчавши": ["смолчав"],
    "смоль": ["смола", "дёготь", "нефть", "горное масло", "чернь", "чернота", "воронь"],
    "смольняк": ["смольё"],
    "смоляной": ["просмоленный"],
    "смоляной карман": ["смоляной кармашек"],
    "смоляной кармашек": ["смоляной карман"],
    "смонтировав": ["смонтировавши"],
    "смонтировавши": ["смонтировав"],
    "смораживав": ["смораживавши"],
    "смораживавши": ["смораживав"],
    "сморгнув": ["сморгнувши"],
    "сморгнувши": ["сморгнув"],
    "сморгонская академия": ["сморгондия"],
    "сморив": ["сморивши"],
    "сморивши": ["сморив"],
    "сморить": ["притомить", "разморить"],
    "сморкав": ["сморкавши"],
    "сморкавши": ["сморкав"],
    "сморканье": ["сморкание"],
    "сморкач": ["сморкун"],
    "сморкнув": ["сморкнувши"],
    "сморкнувши": ["сморкнув"],
    "смород": ["смрад", "вонь", "запах"],
    "смородина": ["смородинка", "огненная река", "пучай-река", "стикс"],
    "сморозив": ["сморозивши"],
    "сморозивши": ["сморозив"],
    "сморозить": ["брякнуть", "ляпнуть"],
    "сморщив": ["сморщивши"],
    "сморщивав": ["сморщивавши"],
    "сморщивавши": ["сморщивав"],
    "сморщивать": ["морщить"],
    "сморщиваться": ["морщиться", "кривиться"],
    "сморщивши": ["сморщив"],
    "смотав": ["смотавши"],
    "смотавши": ["смотав"],
    "смотаться": ["размотаться", "свалить", "слинять", "смыться", "сделать ноги", "сходить", "сбегать"],
    "смотивировав": ["смотивировавши"],
    "смотивировавши": ["смотивировав"],
    "смотр-конкурс": ["конкурс-смотр"],
    "смотрев": ["смотревши"],
    "смотревши": ["смотрев"],
    "смотренье": ["смотрение"],
    "смотреть": ["взирать", "глядеть", "рассматривать", "просматривать", "считать", "думать", "полагать", "находить", "усматривать", "видеть", "следить"],
    "смотреть в оба": ["держать ухо востро", "быть начеку"],
    "смотреть в рот": ["заискивать", "слушаться"],
    "смотреть волком": ["смотреть зверем", "волком смотреть", "зверем смотреть"],
    "смотреть зверем": ["смотреть волком", "волком смотреть", "зверем смотреть"],
    "смотреть как баран на новые ворота": ["хлопать глазами", "лупать глазами", "втыкать"],
    "смотреть как пизда на лимон": ["смотреть зверем", "смотреть волком", "смотреть как ленин на буржуазию", "волком смотреть", "зверем смотреть", "как ленин на буржуазию смотреть", "смотреть как пизда на электробритву", "щериться как пизда на лимон", "щериться как пизда на электробритву", "как пизда на лимон смотреть", "как пизда на электробритву смотреть", "как пизда на лимон щериться", "как пизда на электробритву щериться"],
    "смотреть орлом": ["чваниться"],
    "смотреть сентябрём": ["кукситься", "хандрить"],
    "смотреть сквозь пальцы": ["попустительствовать", "глядеть сквозь пальцы"],
    "смотреться": ["глядеться", "выглядеть"],
    "смотритель": ["надзиратель", "попечитель"],
    "смотрительствовав": ["смотрительствовавши"],
    "смотрительствовавши": ["смотрительствовав"],
    "смотрительствующий": ["присматривающий", "надзирающий"],
    "смотрительша": ["смотрительница"],
    "смотрящий": ["глядящий"],
    "смочив": ["намочив"],
    "смочивши": ["смочив"],
    "смочить": ["намочить", "увлажнить"],
    "смочь": ["суметь", "осилить", "справиться"],
    "смошенничав": ["смошенничавши"],
    "смошенничавши": ["смошенничав"],
    "смрад": ["зловоние", "вонь"],
    "смрадив": ["смрадивши"],
    "смрадивши": ["смрадив"],
    "смрадный": ["вонючий", "зловонный", "смердящий", "чадный", "дымный"],
    "смска": ["эсемесочка"],
    "смугастий": ["смугнастий"],
    "смуглев": ["смуглевши"],
    "смуглевши": ["смуглев"],
    "смуглокожий": ["смуглый", "темнокожий"],
    "смуглолицый": ["темнолицый"],
    "смуглота": ["смуглость"],
    "смуглый": ["смуглокожий", "смуглолицый", "загорелый"],
    "смуглявый": ["смуглявенький", "смуглястенький", "смуглеватый", "смуглевастый", "смуглястый"],
    "смуглянка": ["чернавка", "чернушка", "чернява"],
    "смудрив": ["смудривши"],
    "смудривши": ["смудрив"],
    "смудровав": ["смудровавши"],
    "смудровавши": ["смудровав"],
    "смудрствовав": ["смудрствовавши"],
    "смудрствовавши": ["смудрствовав"],
    "смунить": ["сморгать", "сморготать", "смунивать", "смурыгать", "смурыжить", "смыгать"],
    "смурной": ["хмурый", "мрачный"],
    "смурыгав": ["смурыгавши"],
    "смурыгавши": ["смурыгав"],
    "смурыжив": ["смурыживши"],
    "смурыживши": ["смурыжив"],
    "смурыжить": ["смурыгать", "шмурыгать"],
    "смут": ["тревога", "суматоха", "смущение", "смутня", "безпокойство", "уплаха", "аларма", "безредие", "безредица", "размирица", "размирие", "бунт", "вълнение", "метеж"],
    "смутив": ["смутивши"],
    "смутивши": ["смутив"],
    "смутить": ["возмутить", "взбунтовать", "сбить с панталыгу", "взволновать", "привести в смущение"],
    "смутиться": ["взволноваться", "встревожиться", "смешаться", "заколебаться"],
    "смутний": ["сумний"],
    "смутно": ["неясно", "неотчётливо", "нечётко"],
    "смутьян": ["зачинщик", "затейщик", "заговорщик", "интриган", "раскольник", "подстрекатель"],
    "смутьянив": ["смутьянивши"],
    "смутьянивши": ["смутьянив"],
    "смутьянничав": ["смутьянничавши"],
    "смутьянничавши": ["смутьянничав"],
    "смухлевав": ["смухлевавши"],
    "смухлевавши": ["смухлевав"],
    "смучив": ["смучивши"],
    "смучивав": ["смучивавши"],
    "смучивавши": ["смучивав"],
    "смучивши": ["смучив"],
    "смушка": ["смушек"],
    "смушковий": ["смушевий"],
    "смушковый": ["курпячный", "мерлущатый", "ярковый", "ягнячий"],
    "смущав": ["смущавши"],
    "смущавши": ["смущав"],
    "смущённый": ["растерянный", "сбитый с толку", "сбитый с панталыку"],
    "смъртник": ["мъртвец", "починал", "умрял", "умряло"],
    "смывав": ["смывавши"],
    "смывавши": ["смывав"],
    "смывальный": ["смывной", "смывочный"],
    "смывать кровью": ["искупать грехи"],
    "смываться": ["отмываться", "стираться", "забываться"],
    "смывка": ["смывание"],
    "смывши": ["смыв"],
    "смык": ["смыкание", "стык", "суковатка"],
    "смыкав": ["смыкавши"],
    "смыкавши": ["смыкав"],
    "смылив": ["смыливши"],
    "смыливав": ["смыливавши"],
    "смыливавши": ["смыливав"],
    "смыливать": ["измыливать"],
    "смыливши": ["смылив"],
    "смылить": ["измылить"],
    "смысл": ["значение", "назначение", "цель", "обоснование", "основание", "рассудок", "разум", "ум"],
    "смысл жизни": ["смысл бытия"],
    "смыслив": ["смысливши"],
    "смысливши": ["смыслив"],
    "смыться": ["удрать", "исчезнуть", "задать дёру"],
    "смычный": ["взрывной", "мгновенный", "затворный"],
    "смычок": ["член", "пенис"],
    "смышляв": ["смышлявши"],
    "смышлявши": ["смышляв"],
    "смышлёно": ["сооброзительно", "умно"],
    "смышлёность": ["сообразительность", "сметливость"],
    "смышлёный": ["сообразительный", "понятливый", "сметливый", "толковый", "умный"],
    "смэ": ["судмедэкспертиза"],
    "смяв": ["смявши"],
    "смявши": ["смяв"],
    "смягчав": ["смягчавши"],
    "смягчавши": ["смягчав"],
    "смягчать": ["размягчать", "растоплять", "ослаблять", "умерять", "облегчать", "сглаживать", "палатализовать"],
    "смягченье": ["смягчение"],
    "смягчив": ["смягчивши"],
    "смягчивши": ["смягчив"],
    "смякав": ["смякавши"],
    "смякавши": ["смякав"],
    "смякнув": ["смякнувши"],
    "смякнувши": ["смякнув"],
    "смятение": ["смятенность", "ошеломление", "переполох", "паника", "волнение", "мятеж", "смута"],
    "смять": ["измять", "помять", "скомкать"],
    "смёрзнув": ["смёрзнувши"],
    "смёрзнувши": ["смёрзнув"],
    "смётывав": ["смётывавши"],
    "смётывавши": ["смётывав"],
    "снабдевав": ["снабдевавши"],
    "снабдевавши": ["снабдевав"],
    "снабдив": ["снабдивши"],
    "снабдивши": ["снабдив"],
    "снабдить": ["обеспечить"],
    "снабжав": ["снабжавши"],
    "снабжавши": ["снабжав"],
    "снабжающий": ["обеспечивающие"],
    "снабженец": ["экипировщик", "снабжатель"],
    "снабженье": ["снабжение"],
    "снадобье": ["зелье", "эликсир", "снадобьице"],
    "снаивничав": ["снаивничавши"],
    "снаивничавши": ["снаивничав"],
    "снайперка": ["снайперская винтовка"],
    "снайперская винтовка": ["снайперка"],
    "снайтовив": ["снайтовивши"],
    "снайтовивши": ["снайтовив"],
    "снайтовить": ["занайтовить"],
    "снаружи": ["вовне", "вне", "на улице", "под открытым небом", "вовнутрь", "внутрь", "извне"],
    "снаряга": ["снаряжение", "снаряженье"],
    "снарядив": ["снарядивши"],
    "снарядивши": ["снарядив"],
    "снаряжав": ["снаряжавши"],
    "снаряжавши": ["снаряжав"],
    "снаряжать": ["экипировать", "обеспечивать", "посылать", "отправлять", "отсылать", "оснащать", "снабжать", "наряжать", "прихорашивать", "вооружать", "заряжать"],
    "снаряжение": ["оснащение", "амуниция", "снаряга"],
    "снаряженье": ["снаряжение"],
    "снасильничав": ["снасильничавши"],
    "снасильничавши": ["снасильничав"],
    "снасмешничав": ["снасмешничавши"],
    "снасмешничавши": ["снасмешничав"],
    "снастив": ["снастивши"],
    "снастивши": ["снастив"],
    "снастить": ["оснащать"],
    "снасть": ["оснащение", "оборудование", "снаряжение"],
    "сначала": ["сперва", "раньше", "прежде", "поначалу", "вначале", "первоначально", "вновь", "ещё раз", "заново", "опять", "снова", "сызнова"],
    "снашивав": ["снашивавши"],
    "снашивавши": ["снашивав"],
    "снашивание": ["стирание", "изнашивание", "износ", "истаскивание", "истрепывание", "топтание"],
    "снашивать": ["изнашивать"],
    "снг": ["содружество независимых государств", "с новым годом"],
    "снговский": ["снгшный", "эсэнговский"],
    "снгшный": ["снговский"],
    "снд": ["совет народных депутатов", "съезд народных депутатов"],
    "снебрежничав": ["снебрежничавши"],
    "снебрежничавши": ["снебрежничав"],
    "снег": ["снегопад", "снежный покров", "белый шум", "кокс", "снежок", "мука"],
    "снегирь": ["снигирь", "опер"],
    "снегование": ["снегозадержание"],
    "снеговик": ["снежная баба", "снежный человек"],
    "снеговой": ["снежный"],
    "снегогон": ["цветень", "брезень", "апрель"],
    "снегозадержание": ["снегонакопление"],
    "снегокат": ["велолыжи"],
    "снеголавинный": ["снежнолавинный"],
    "снегонакопление": ["снегозадержание"],
    "снегоочиститель": ["снегоуборщик"],
    "снегоподобный": ["снегообразный"],
    "снеготаялка": ["таялка"],
    "снеготаяние": ["снеготаянье"],
    "снегоуборка": ["снегоочистка"],
    "снегоуборщик": ["снегоочиститель"],
    "снегоход": ["аэросани", "мотонарты"],
    "снегурка": ["снегурочка"],
    "снегурочка": ["снегурка"],
    "снедав": ["снедавши"],
    "снедавши": ["снедав"],
    "снедать": ["есть", "съедать", "губить", "уничтожать", "сокрушать", "мучить", "овладевать", "поглощать", "обуревать", "томить", "измождать", "тяготить"],
    "снедь": ["еда", "пища", "съестное", "яство", "харч"],
    "снежана": ["снежа", "снежка"],
    "снежен барс": ["барс", "снежен леопард", "ирбис"],
    "снежень": ["февраль"],
    "снежеть": ["снежка"],
    "снежив": ["снеживши"],
    "снеживши": ["снежив"],
    "снежинка": ["пушинка"],
    "снежная баба": ["снеговик"],
    "снежник": ["перелеток", "снежник мерзлоты"],
    "снежничав": ["снежничавши"],
    "снежничавши": ["снежничав"],
    "снежно-белый": ["белоснежный"],
    "снежногорск": ["вьюжный"],
    "снежнолавинный": ["снеголавинный"],
    "снежноягодник": ["снежная ягода", "снежник", "волчья ягода"],
    "снежный": ["снеговой"],
    "снежный человек": ["йети", "сасквоч", "бигфут"],
    "снейкборд": ["снейк"],
    "снесло башню": ["сорвало башню", "свернуло башню", "отвернуло башню", "башню снесло", "башню сорвало", "башню свернуло", "башню отвернуло"],
    "снеток": ["озёрная корюшка", "вандыш", "сниток", "сняток"],
    "снивелировав": ["снивелировавши"],
    "снивелировавши": ["снивелировав"],
    "снидев": ["снидевши"],
    "снидевши": ["снидев"],
    "снижав": ["снижавши"],
    "снижавши": ["снижав"],
    "снижать": ["понижать", "опускать", "спускать", "уменьшать"],
    "снижаться": ["опускаться", "спускаться", "понижаться", "сокращаться", "уменьшаться"],
    "снижение": ["понижение", "сниженье", "сокращение", "сбавление", "успокоение", "огрубление"],
    "сниженье": ["снижение"],
    "снизав": ["снизавши"],
    "снизавши": ["снизав"],
    "снизив": ["снизивши"],
    "снизивши": ["снизив"],
    "снизить": ["опустить", "спустить", "уменьшить", "сократить", "понизить"],
    "снизиться": ["опуститься", "спуститься", "понизиться", "сократиться", "уменьшиться"],
    "снизу": ["вверх", "внизу", "понизу"],
    "снизывав": ["снизывавши"],
    "снизывавши": ["снизывав"],
    "сникав": ["сникавши"],
    "сникавши": ["сникав"],
    "сникер": ["сникерс", "кеды"],
    "сникнув": ["сникнувши"],
    "сникнувши": ["сникнув"],
    "снимав": ["снимавши"],
    "снимавши": ["снимав"],
    "сниманье": ["снимание"],
    "снимать": ["убирать", "раздеваться", "собирать", "отзывать", "фотографировать", "фоткать", "фотать", "составлять", "арендовать", "нанимать", "кадрить", "цеплять", "клеить", "увольнять", "отстранять"],
    "снимать трусы и бегать": ["таракану хуй приделать"],
    "снимать штаны и бегать": ["таракану хуй приделать"],
    "сниматься": ["фотографироваться", "фоткаться", "фотаться"],
    "снимка": ["клячка"],
    "снимок": ["фотография", "фотоизображение", "фотка"],
    "снип": ["однонуклеотидный полиморфизм", "мононуклеотидный полиморфизм"],
    "сниппет": ["информационный блок", "фрагмент"],
    "снискав": ["снискавши"],
    "снискавши": ["снискав"],
    "снискать": ["приобрести", "добыть", "принести", "доставить", "обеспечить"],
    "снискивав": ["снискивавши"],
    "снискивавши": ["снискивав"],
    "снискивать": ["стяжать"],
    "снисходив": ["снисходивши"],
    "снисходивши": ["снисходив"],
    "снисходительность": ["толерантность"],
    "снисходительный": ["терпимый", "толерантный", "благосклонный", "нестрогий", "невзыскательный"],
    "снисходительствовав": ["снисходительствовавши"],
    "снисходительствовавши": ["снисходительствовав"],
    "снисходить": ["нисходить", "сходить", "спускаться", "осенять"],
    "снисхождение": ["невзыскательность", "прощение", "поблажка", "покровительственность", "высокомерие"],
    "снисхожденье": ["снисхождение"],
    "сниться": ["грезиться"],
    "сноб": ["денди"],
    "снова": ["опять", "заново", "вновь", "ещё"],
    "снова-здорово": ["опять двадцать пять"],
    "сновав": ["сновавши"],
    "сновавши": ["сновав"],
    "сновальня": ["сновалка", "сновальница", "ремизный станок", "изба-сновальня"],
    "снованье": ["снование"],
    "сновать": ["шастать", "суетиться", "бегать"],
    "сновида": ["лунатик", "сомнамбула"],
    "сновидев": ["сновидевши"],
    "сновидевши": ["сновидев"],
    "сновидение": ["сон", "грёза"],
    "сновиденье": ["сновидение", "сон"],
    "сновидица": ["ясновидица"],
    "сноговорение": ["сомнилоквия"],
    "сногсшибательно": ["обалденно", "потрясающе"],
    "сногсшибательный": ["потрясающий", "поразительный"],
    "сноп": ["вязанка"],
    "сноповидный": ["снопообразный"],
    "сноповязальщик": ["сноповяз"],
    "сноповязка": ["сноповязальщица"],
    "снопообразный": ["сноповидный"],
    "сноравливав": ["сноравливавши"],
    "сноравливавши": ["сноравливав"],
    "сноркелер": ["сноркелист"],
    "сноркелист": ["сноркелер"],
    "сноровив": ["сноровивши"],
    "сноровивши": ["сноровив"],
    "сноровистость": ["расторопность", "ловкость"],
    "сноровистый": ["ловкий", "умелый", "расторопный"],
    "сноровка": ["ловкость", "мастерство", "искусность", "навык", "умение"],
    "сноровляв": ["сноровлявши"],
    "сноровлявши": ["сноровляв"],
    "снос": ["износ", "изнашивание"],
    "сносив": ["сносивши"],
    "сносивши": ["сносив"],
    "сносливость": ["выносливость", "терпеливость"],
    "сносливый": ["выносливый", "терпеливый"],
    "сносно": ["терпимо", "приемлемо"],
    "сносный": ["терпимый", "приемлемый"],
    "сносу нет": ["сноса нет", "износа нет", "сносу нету", "сноса не знать", "сноса не знают", "сносу не знать", "износу нет", "износу не знать"],
    "снотворный": ["усыпляющий"],
    "сноуборд": ["снегодоск", "доск", "доцк", "борд", "сноубординг", "бординг"],
    "сноуборд-кросс": ["бордер-кросс", "бордеркросс", "борд-кросс"],
    "сноубордер": ["сноубордист"],
    "сноубордив": ["сноубордивши"],
    "сноубордивши": ["сноубордив"],
    "сноха": ["невестка"],
    "снохарь": ["снохач"],
    "снохач": ["снохарь"],
    "снохачествовав": ["снохачествовавши"],
    "снохачествовавши": ["снохачествовав"],
    "снохождение": ["сомнамбулизм", "лунатизм", "ноктамбулизм"],
    "сношав": ["сношавши"],
    "сношавши": ["сношав"],
    "сношавшийся": ["якшавшийся"],
    "сношать": ["пороть"],
    "сношаться": ["совокупляться", "сноситься", "общаться"],
    "сношение": ["связь", "общение", "взаимоотношения"],
    "сношенье": ["сношение"],
    "снс": ["свёрточная нейронная сеть"],
    "снт": ["дача", "сад"],
    "снув": ["снувши"],
    "снувши": ["снув"],
    "снутри": ["внутри"],
    "снытка": ["сныть"],
    "сныть": ["снить", "снытка"],
    "снюрревод": ["донный невод", "драга"],
    "сняв": ["снявши"],
    "снявши": ["сняв"],
    "снягурачка": ["снягурка"],
    "снярда": ["эста"],
    "снять": ["убрать", "отозвать", "зафиксировать", "сфотографировать", "арендовать", "отсоединить", "демонтировать", "запикапить"],
    "со временем": ["впоследствии"],
    "со всей дури": ["изо всех сил", "что есть силы", "со всего размаха", "со всей мочи"],
    "со всех ног": ["стремительно", "стремглав", "опрометью", "как подкошенный"],
    "со всех сторон": ["отовсюду"],
    "со свиным рылом в калашный ряд": ["с суконным рылом в калашный ряд"],
    "со скоростью света": ["молниеносно", "стремительно"],
    "со скрипом": ["с трудом", "с большим трудом", "через силу", "с натугой", "с усилием"],
    "со сна": ["сонный", "помятый"],
    "со-": ["ко-"],
    "соавторствовав": ["соавторствовавши"],
    "соавторствовавши": ["соавторствовав"],
    "собака": ["пёс", "псина", "друг человека", "четвероногий друг", "кобяк", "скотина", "негодяй", "мерзавец", "поганец", "сукин сын", "чёрт", "мастак", "мастер", "хищник", "насильник"],
    "собака на сене": ["сам не ам и другим не дам", "жадина", "скупердяй"],
    "собаке собачья смерть": ["собаке собачья и смерть", "так ему и надо", "туда ему и дорога"],
    "собакен": ["пёсель"],
    "собаковедение": ["кинология"],
    "собаковод": ["кинолог"],
    "собаку съел": ["зубы съел"],
    "собацюра": ["собацюга", "собачище"],
    "собачар": ["собачник", "псарь"],
    "собачара": ["собачища", "псина"],
    "собачей": ["собачник"],
    "собачив": ["собачивши"],
    "собачивши": ["собачив"],
    "собачий": ["собакин", "псовый", "псиный", "пёсий", "несчастливый", "ничтожный", "жалкий"],
    "собачий холод": ["холодина", "колотун", "трескучий мороз"],
    "собачить": ["бранить", "ругать"],
    "собачка": ["собачонка", "моська"],
    "собачонка": ["псинка"],
    "собачонок": ["щенок", "кутёнок", "собачонка", "пёсик"],
    "собачье рыло": ["свиное рыло", "свинячье рыло", "суконное рыло", "немытое рыло", "неумытое рыло"],
    "собачья петрушка": ["кокорыш"],
    "собезьянив": ["собезьянивши"],
    "собезьянивши": ["собезьянив"],
    "собезьянничав": ["собезьянничавши"],
    "собезьянничавши": ["собезьянничав"],
    "собек": ["себек"],
    "собеседовав": ["собеседовавши"],
    "собеседовавши": ["собеседовав"],
    "собеседование": ["беседа", "собеседованье"],
    "собеседованье": ["собеседование"],
    "собибур": ["собибор"],
    "собив": ["собивши"],
    "собивши": ["собив"],
    "собирав": ["собиравши"],
    "собиравши": ["собирав"],
    "собирание": ["аккумулирование", "агрегирование", "подбор", "коллекционирование", "сосредотачивание"],
    "собиранье": ["собирание"],
    "собирательный": ["обобщённый"],
    "собк": ["себек"],
    "соблаговолив": ["соблаговоливши"],
    "соблаговоливши": ["соблаговолив"],
    "соблаговоляв": ["соблаговолявши"],
    "соблаговолявши": ["соблаговоляв"],
    "соблаговолять": ["соизволять"],
    "соблазн": ["искушение"],
    "соблазнение": ["соблазненье"],
    "соблазненье": ["соблазнение"],
    "соблазнив": ["соблазнивши"],
    "соблазнивши": ["соблазнив"],
    "соблазнитель": ["искуситель"],
    "соблазнительница": ["искусительница"],
    "соблазниться": ["впасть", "соблазн", "искушение", "грех", "поддаться", "прельститься", "польститься", "клюнуть", "позариться", "раскатать", "губа", "покорыстоваться"],
    "соблазняв": ["соблазнявши"],
    "соблазнявши": ["соблазняв"],
    "соблазнять": ["прельщать"],
    "соблюдав": ["соблюдавши"],
    "соблюдавши": ["соблюдав"],
    "соблюдать": ["блюсти", "выполнять", "следовать", "придерживаться"],
    "соблюденье": ["соблюдение"],
    "соблюсти": ["сберечь", "сохранить"],
    "собойка": ["ссобойка", "тормозок"],
    "соболевав": ["соболевавши"],
    "соболевавши": ["соболевав"],
    "соболевий": ["соболиний"],
    "соболезновав": ["соболезновавши"],
    "соболезновавши": ["соболезновав"],
    "соболезнование": ["сочувствие", "сострадание", "сердечное соучастие", "соболезнованье"],
    "соболезнованье": ["соболезнование"],
    "соболезновательный": ["сострадательный"],
    "соболезновать": ["сочувствовать", "сострадать", "сожалеть", "болеть сердцем"],
    "соболий": ["соболиный"],
    "соболиный": ["соболий"],
    "собор": ["храм"],
    "соборне": ["соборно"],
    "соборно": ["соборне"],
    "соборовав": ["соборовавши"],
    "соборовавши": ["соборовав"],
    "соборование": ["елеосвящение"],
    "соборованье": ["соборование"],
    "собрав": ["собравши"],
    "собравши": ["собрав"],
    "собрание": ["сбор", "сходка", "совещание", "митинг", "парламент", "ассамблея", "коллекция"],
    "собрат": ["товарищ"],
    "собратствовав": ["собратствовавши"],
    "собратствовавши": ["собратствовав"],
    "собственник": ["владелец", "хозяин", "обладатель"],
    "собственничество": ["жадность"],
    "собственно говоря": ["в конечном счёте", "в сущности", "вообще", "если разобраться", "по сути дела", "по существу", "по существу говоря", "собственно", "строго говоря", "фактически"],
    "собственное существительное": ["оним"],
    "собственноручно": ["лично"],
    "собственность": ["имущество", "владение", "обладание"],
    "собственный": ["свой", "персональный", "личный", "имманентный", "настоящий"],
    "собутыльничав": ["собутыльничавши"],
    "собутыльничавши": ["собутыльничав"],
    "событие": ["событье", "случай", "история"],
    "событье": ["событие"],
    "совав": ["совавши"],
    "совавши": ["совав"],
    "сованье": ["сование"],
    "совать": ["протягивать", "пихать", "заталкивать"],
    "совать в печку": ["в печку совать", "сувать под хвост", "сувать под хвостик", "под хвост сувать", "под хвостик сувать", "баловаться под хвостик", "под хвостик баловаться", "жалиться под хвост", "под хвост жалиться"],
    "совбур": ["нэпман"],
    "соввласть": ["советская власть"],
    "совгаванец": ["гаванец"],
    "совгаванский": ["советско-гаванский"],
    "совдеп": ["совнардеп", "совок"],
    "совдепия": ["совок"],
    "совдеповский": ["совковый"],
    "совев": ["совевши"],
    "совевши": ["совев"],
    "совершав": ["совершавши"],
    "совершавши": ["совершав"],
    "совершатель": ["свершитель"],
    "совершательница": ["совершительница", "свершательница", "содетельница", "содевательница", "свершительница"],
    "совершать": ["выполнять", "делать", "исполнять", "осуществлять"],
    "совершение": ["осуществление"],
    "совершенно": ["безупречно", "безукоризненно", "идеально", "в совершенстве", "совсем", "полностью", "абсолютно", "напрочь"],
    "совершеннолетие": ["совершеннолетье"],
    "совершеннолетний": ["взрослый"],
    "совершеннолетье": ["совершеннолетие"],
    "совершенность": ["совершенство", "безукоризненность"],
    "совершенный": ["безупречный", "идеальный", "полный", "абсолютный", "настоящий", "подлинный"],
    "совершенство": ["безукоризненность", "безупречность", "совершенность"],
    "совершенствовав": ["совершенствовавши"],
    "совершенствовавши": ["совершенствовав"],
    "совершенствование": ["улучшение"],
    "совершенствованье": ["совершенствование"],
    "совершенствоваться": ["прогрессировать", "развиваться", "улучшаться"],
    "совершенье": ["совершение"],
    "совершив": ["совершивши"],
    "совершивши": ["совершив"],
    "совершитель": ["осуществитель"],
    "совершить": ["осуществить", "произвести", "выполнить", "завершить", "свершить"],
    "совершённость": ["свершённость", "завершённость", "законченность", "перфективность", "полнозаконченность"],
    "совершённый": ["выполненный", "сделанный", "исполненный", "осуществлённый"],
    "совеселиться": ["сорадоваться"],
    "совестив": ["совестивши"],
    "совестивши": ["совестив"],
    "совестить": ["стыдить"],
    "совестно": ["стыдно"],
    "совестность": ["совесть"],
    "совестный": ["совестливый"],
    "совесть": ["ответственность", "стыд", "совестность", "совестливость"],
    "совет": ["указание", "рекомендация", "напутствие", "совещание", "обсуждение", "согласие", "гармония"],
    "совет министров": ["совмин", "см"],
    "совет народных комиссаров": ["совнарком", "снк"],
    "совет федерации": ["совфед", "сф"],
    "советизировав": ["советизировавши"],
    "советизировавши": ["советизировав"],
    "советизм": ["советскость"],
    "советник": ["консультант", "референт", "советчик"],
    "советовав": ["советовавши"],
    "советовавши": ["советовав"],
    "советовать": ["рекомендовать"],
    "советоваться": ["консультироваться", "совещаться"],
    "советолог": ["кремленолог"],
    "советская власть": ["совейская власть", "софья власьевна"],
    "советская гавань": ["императорская гавань"],
    "советская россия": ["рсфср"],
    "советски": ["по-советски"],
    "советский": ["общесоветский", "серпастый", "серпастый-молоткастый", "совдеповский", "совковый", "прокоммунистический"],
    "советский союз": ["союз сср", "ссср", "самая читающая страна", "союз нерушимый", "совдепия", "совдеп", "совок"],
    "советско-гаванский": ["совгаванский"],
    "советско-финляндский": ["советско-финский"],
    "советско-финский": ["советско-финляндский"],
    "советскость": ["советизм"],
    "советтар союзы": ["совет социалистик республикалар союзы"],
    "совещанье": ["совещание"],
    "совик": ["накидка"],
    "совковский": ["совковый"],
    "совковщина": ["совок", "советчина"],
    "совковый": ["совковский"],
    "совкодрочер": ["совок"],
    "совладав": ["совладавши"],
    "совладавши": ["совладав"],
    "совладать": ["овладеть", "победить", "справиться", "управиться"],
    "совладев": ["совладевши"],
    "совладевши": ["совладев"],
    "совластвовав": ["совластвовавши"],
    "совластвовавши": ["совластвовав"],
    "совлекав": ["совлекавши"],
    "совлекавши": ["совлекав"],
    "совлекание": ["совлечение"],
    "совлечение": ["совлекание", "сбрасывание", "снятие", "удаление", "убирание", "доставание"],
    "совместив": ["совместивши"],
    "совместивши": ["совместив"],
    "совместимость": ["сочетаемость", "совместность"],
    "совместительствовав": ["совместительствовавши"],
    "совместительствовавши": ["совместительствовав"],
    "совместник": ["соперник"],
    "совместничав": ["совместничавши"],
    "совместничавши": ["совместничав"],
    "совместничествовав": ["совместничествовавши"],
    "совместничествовавши": ["совместничествовав"],
    "совместно": ["вместе", "сообща", "коллективно"],
    "совместное предприятие": ["сп"],
    "совместный": ["общий", "коллективный", "совместимый"],
    "совмещав": ["совмещавши"],
    "совмещавши": ["совмещав"],
    "совмещать": ["сочетать", "соединять"],
    "совмещенье": ["совмещение"],
    "совнархоз": ["снх"],
    "совок": ["лопатка"],
    "совокупив": ["совокупивши"],
    "совокупивши": ["совокупив"],
    "совокупиться": ["соединиться", "объединиться"],
    "совокупление": ["соединение", "сочетание"],
    "совокупленье": ["совокупление"],
    "совокупляв": ["совокуплявши"],
    "совокуплявши": ["совокупляв"],
    "совокупляться": ["соединяться", "объединяться", "сношаться", "трахаться"],
    "совокупный": ["объединённый", "совместный", "общий"],
    "совпадав": ["совпадавши"],
    "совпадавши": ["совпадав"],
    "совпадение": ["одновременность", "сходство", "общность", "одинаковость", "единство"],
    "совпаденье": ["совпадение"],
    "соврав": ["совравши"],
    "совравши": ["соврав"],
    "совратив": ["совративши"],
    "совративши": ["совратив"],
    "совратить": ["отклонить", "спровоцировать", "соблазнить"],
    "соврать": ["солгать"],
    "совращав": ["совращавши"],
    "совращавши": ["совращав"],
    "совращать": ["отклонять", "поворачивать", "искушать", "развращать", "соблазнять"],
    "совращенье": ["совращение"],
    "современнейший": ["наисовременнейший", "новейший"],
    "современник": ["одногодок", "ровесник", "сверстник"],
    "современница": ["соотечественница"],
    "современность": ["актуальность", "настоящее"],
    "современный": ["одновременный", "нынешний", "сегодняшний", "теперешний", "новый", "модерновый"],
    "современщина": ["новодел"],
    "совсем": ["полностью", "совершенно", "абсолютно", "вполне", "вовсе", "ничуть", "нисколько", "навсегда", "насовсем"],
    "совхозно-колхозный": ["колхозно-совхозный"],
    "согд": ["согдиана", "сугуд"],
    "согдиана": ["согд", "согдия"],
    "согдский": ["согдийский"],
    "согипоним": ["когипоним", "эквоним", "элемент множества"],
    "согласив": ["согласивши"],
    "согласивши": ["согласив"],
    "согласие": ["антанта"],
    "согласиться": ["уступить", "дать согласие", "выразить согласие", "пойти навстречу"],
    "согласно": ["по версии"],
    "согласный": ["готовый", "склонный", "расположенный", "единый", "конгениальный", "соответствующий", "стройный", "гармоничный", "согласованный", "слаженный", "дружный", "единодушный"],
    "согласный звук": ["согласный"],
    "согласовав": ["согласовавши"],
    "согласовавши": ["согласовав"],
    "согласованно": ["слаженно", "вместе", "скоординированно"],
    "согласованье": ["согласование"],
    "согласовать": ["синхронизировать"],
    "согласовывав": ["согласовывавши"],
    "согласовывавши": ["согласовывав"],
    "согласовывание": ["согласование", "увязывание", "координация"],
    "согласье": ["согласие", "единомыслие", "единодушие"],
    "соглашав": ["соглашавши"],
    "соглашавши": ["соглашав"],
    "соглашательство": ["оппортунизм", "приспособленчество"],
    "соглашаться": ["подтверждать"],
    "соглашение": ["договор", "договорённость", "согласие", "консенсус", "соглашенье", "конвенция", "пакт", "акт", "контракт"],
    "соглашенье": ["соглашение"],
    "соглядатай": ["шпик", "сексот", "филёр", "шпион"],
    "соглядатайствовав": ["соглядатайствовавши"],
    "соглядатайствовавши": ["соглядатайствовав"],
    "соглядать": ["подсматривать", "следить", "наблюдать"],
    "согнав": ["согнавши"],
    "согнавши": ["согнав"],
    "согнув": ["согнувши"],
    "согнувши": ["согнув"],
    "согнутость": ["гнутость"],
    "согнуть": ["искривить", "изогнуть", "наклонить"],
    "согнуться": ["искривиться", "изогнуться", "наклониться", "натутуршиться", "склониться", "прогнуться", "уступить", "поддаться"],
    "соградив": ["соградивши"],
    "соградивши": ["соградив"],
    "сограждав": ["сограждавши"],
    "сограждавши": ["сограждав"],
    "согражданин": ["соотечественник", "земляк"],
    "согрев": ["согревание", "согреванье", "сугрев"],
    "согревав": ["согревавши"],
    "согревавши": ["согревав"],
    "согревать": ["нагревать"],
    "согревши": ["согрев"],
    "согреть": ["нагреть", "греть", "подогреть", "разогреть", "обогреть", "отогреть", "утешить", "ободрить"],
    "согреться": ["нагреться", "жаскнуться", "обогреться"],
    "согрешав": ["согрешавши"],
    "согрешавши": ["согрешав"],
    "согрешать": ["грешить"],
    "согрешенье": ["согрешение"],
    "согрешив": ["согрешивши"],
    "согрешивши": ["согрешив"],
    "согрубив": ["согрубивши"],
    "согрубивши": ["согрубив"],
    "сода": ["карбонат натрия", "гидрокарбонат натрия", "питьевая сода", "пищевая сода"],
    "содамс": ["маштомс", "шарьхкодемс"],
    "содвигав": ["содвигавши"],
    "содвигавши": ["содвигав"],
    "содвинув": ["содвинувши"],
    "содвинувши": ["содвинув"],
    "содевав": ["содевавши"],
    "содевавши": ["содевав"],
    "содеватель": ["свершитель", "совершитель", "совершатель", "содетель", "содетельница"],
    "содевательница": ["совершительница", "совершательница", "свершительница", "содетельница"],
    "содевать": ["соделывать", "соделать"],
    "содействие": ["содейство"],
    "содействовав": ["содействовавши"],
    "содействовавши": ["содействовав"],
    "содействовать": ["помогать", "помочь"],
    "соделанье": ["содеванье", "содеяние", "соделыванье", "сделанье", "свершенье"],
    "соделать": ["содеять", "сделать"],
    "соделывав": ["соделывавши"],
    "соделывавши": ["соделывав"],
    "соделывать": ["содевать", "содеять", "соделать"],
    "содержав": ["содержавши"],
    "содержавши": ["содержав"],
    "содержание": ["поддержание", "средства", "жалование"],
    "содержант": ["нахлебник"],
    "содержанье": ["содержание"],
    "содержательный": ["информативный"],
    "содержимое": ["содержание"],
    "содетель": ["содеватель"],
    "содеяв": ["содеявши"],
    "содеявши": ["содеяв"],
    "содеяние": ["содеванье", "соделыванье", "соделанье", "сделанье", "свершенье"],
    "содеянный": ["совершённый"],
    "содеянье": ["содеяние", "содеванье", "соделыванье", "соделанье", "сделанье", "свершенье"],
    "содеять": ["сделать", "совершить", "сотворить", "соделать"],
    "содовая": ["содовая вода"],
    "содовая вода": ["содовая"],
    "содомив": ["содомивши"],
    "содомивши": ["содомив"],
    "содомизировав": ["содомизировавши"],
    "содомизировавши": ["содомизировав"],
    "содомировав": ["содомировавши"],
    "содомировавши": ["содомировав"],
    "содомист": ["гомосексуал", "гомосексуалист", "содомит"],
    "содомит": ["зоофил", "скотоложец"],
    "содомить": ["шуметь", "кричать", "ссориться", "браниться"],
    "содомия": ["анальный секс", "анал", "анализм", "педерастия", "мужеложество", "гомосексуализм"],
    "содрав": ["содравши"],
    "содравши": ["содрав"],
    "содранный": ["оторванный"],
    "содрогав": ["содрогавши"],
    "содрогавши": ["содрогав"],
    "содрогнув": ["содрогнувши"],
    "содрогнувши": ["содрогнув"],
    "содружество": ["союз"],
    "содружество независимых государств": ["снг"],
    "соевый": ["феминный"],
    "соединение": ["объединение", "сочетание", "стык", "химическое соединение"],
    "соединив": ["соединивши"],
    "соединивши": ["соединив"],
    "соединительный падеж": ["совместный падеж", "комитатив"],
    "соединиться": ["присоединиться", "подключиться"],
    "соединяв": ["соединявши"],
    "соединявши": ["соединяв"],
    "соединять": ["объединять"],
    "соединяться": ["объединяться", "сочетаться"],
    "соединённое королевство": ["великобритания"],
    "соединённые штаты": ["соединённые штаты америки", "сша"],
    "сожалев": ["сожалевши"],
    "сожалевши": ["сожалев"],
    "сожаление": ["сожаленье", "огорчение", "жалость", "сострадание", "эмпатия"],
    "сожаленье": ["сожаление"],
    "сожалеть": ["жалеть", "раскаиваться", "досадовать", "жалковать", "тосковать", "сочувствовать"],
    "сожалительно": ["сожалеюще"],
    "сожалительный": ["сожалеющий"],
    "сожжение": ["сжигание", "испепеление"],
    "сожженье": ["сожжение"],
    "сожжённый": ["сгоревший"],
    "сожигание": ["сжигание", "сожжение"],
    "сожигать": ["сжигать"],
    "сожитель": ["любовник"],
    "сожительство": ["сожитие", "соседство", "сосуществование", "незарегистрированный", "брак", "фактический", "брачный", "отношение", "гражданский брак", "конкубинат"],
    "сожительствовав": ["сожительствовавши"],
    "сожительствовавши": ["сожительствовав"],
    "сожительствовать": ["сосуществовать", "жить"],
    "сожитие": ["сожительство"],
    "сожмурив": ["сожмуривши"],
    "сожмуривав": ["сожмуривавши"],
    "сожмуривавши": ["сожмуривав"],
    "сожмуриваться": ["жмуриться"],
    "сожмуривши": ["сожмурив"],
    "сожмуриться": ["зажмуриться"],
    "сожрав": ["сожравши"],
    "сожравши": ["сожрав"],
    "сожрать": ["слопать", "закусать"],
    "созвав": ["созвавши"],
    "созвавши": ["созвав"],
    "созванивав": ["созванивавши"],
    "созванивавши": ["созванивав"],
    "созвездие": ["астеризм", "плеяда"],
    "созвездье": ["созвездие"],
    "созвучие": ["гармония", "ассонанс"],
    "создав": ["создавши"],
    "создавав": ["создававши"],
    "создававши": ["создавав"],
    "создаваемый": ["изготовляемый", "делаемый", "производимый", "созидаемый", "сотворяемый", "творимый"],
    "создавать": ["изготовлять", "делать", "производить", "созидать", "сотворять", "творить"],
    "создаваться": ["созиждиться"],
    "создавши": ["создав"],
    "создание": ["творение", "сотворение", "созидание", "произведение", "тварь"],
    "созданный": ["сотворённый", "организованный", "основанный", "сформированный", "учреждённый", "образованный"],
    "созданье": ["создание"],
    "создатель": ["творец", "автор", "созидатель"],
    "создательница": ["созидательница"],
    "создать": ["сотворить", "построить", "воздвигнуть", "возвести", "созиждить"],
    "созерцав": ["созерцавши"],
    "созерцавши": ["созерцав"],
    "созерцание": ["созерцанье"],
    "созерцатель": ["наблюдатель"],
    "созерцать": ["рассматривать", "смотреть", "наблюдать"],
    "созидав": ["созидавши"],
    "созидавши": ["созидав"],
    "созидание": ["создание", "творчество", "сотворение"],
    "созиданье": ["созидание"],
    "созидатель": ["создатель", "творец"],
    "созидать": ["создавать", "строить", "творить"],
    "созидающий": ["создающий", "творящий"],
    "созиждив": ["созиждивши"],
    "созиждивши": ["созиждив"],
    "созиждить": ["создать"],
    "созиждиться": ["создаваться", "воздвигаться", "строиться"],
    "сознав": ["сознавши"],
    "сознавав": ["сознававши"],
    "сознававши": ["сознавав"],
    "сознавать": ["понимать"],
    "сознаваться": ["выкладывать душу", "исповедоваться", "открываться", "признаваться", "распахивать душу", "выворачивать душу наизнанку", "каяться", "виниться", "виноватиться", "приходить", "с повинной", "приносить повинную голову"],
    "сознавши": ["сознав"],
    "сознание": ["психика", "ум", "разум", "рацио", "разумение", "рассудок", "уразумение", "уяснение", "чувство"],
    "сознательно": ["осмысленно", "осознанно", "добросовестно", "на совесть", "нарочно", "преднамеренно", "умышленно"],
    "созопол": ["созополь", "сизополь"],
    "созополь": ["созопол", "сизополь"],
    "созорничав": ["созорничавши"],
    "созорничавши": ["созорничав"],
    "созоровав": ["созоровавши"],
    "созоровавши": ["созоровав"],
    "созрев": ["созревши"],
    "созревав": ["созревавши"],
    "созревавши": ["созревав"],
    "созреванье": ["созревание"],
    "созревать": ["поспевать"],
    "созревши": ["созрев"],
    "созывав": ["созывавши"],
    "созывавши": ["созывав"],
    "созывание": ["сзывание", "созыв"],
    "созывать": ["сзывать", "скликать"],
    "соизволение": ["соизволенье"],
    "соизволенье": ["соизволение"],
    "соизволив": ["соизволивши"],
    "соизволивши": ["соизволив"],
    "соизволить": ["соблаговолить", "сделать милость", "изволить"],
    "соизволяв": ["соизволявши"],
    "соизволявши": ["соизволяв"],
    "соизмерив": ["соизмеривши"],
    "соизмеривши": ["соизмерив"],
    "соизмеримо": ["заслуженно", "справедливо", "сопоставимо", "соразмерно", "сравнимо"],
    "соизмеряв": ["соизмерявши"],
    "соизмерявши": ["соизмеряв"],
    "соименник": ["тёзка"],
    "соименница": ["тёзка"],
    "соинвестировав": ["соинвестировавши"],
    "соинвестировавши": ["соинвестировав"],
    "соискатель": ["соперник", "соревнователь", "конкурент", "претендент", "кандидат", "аспирант", "номинант"],
    "соитье": ["соитие"],
    "сойка": ["кареза"],
    "сойот": ["тувинец"],
    "сок": ["моджо", "ци", "суть", "квинтэссенция", "сливки", "выжимки"],
    "соклассник": ["одноклассник", "однокашник"],
    "соколий": ["соколиный"],
    "соколиный": ["соколий"],
    "соколиха": ["соколица"],
    "соколица": ["соколиха"],
    "сокомандник": ["тиммейт", "товарищ по команде", "соратник", "напарник", "компаньон"],
    "сокпаппет": ["виртуал", "кукла", "твинк", "мульт"],
    "сократ": ["срез", "напрямик"],
    "сократив": ["сокративши"],
    "сокративши": ["сократив"],
    "сократимость": ["сокращаемость"],
    "сокращав": ["сокращавши"],
    "сокращавши": ["сокращав"],
    "сокращать": ["укорачивать", "спрямлять", "срезать", "коротать", "уменьшать", "снижать", "урезать", "увольнять", "упрощать"],
    "сокращаться": ["укорачиваться", "уменьшаться", "сжиматься", "напрягаться", "упрощаться"],
    "сокращение": ["уменьшение", "укорачивание", "снижение", "урезание", "аббревиатура", "акроним", "сжимание", "напряжение"],
    "сокращённо": ["вкратце", "кратко", "лапидарно"],
    "сокращённый": ["сжатый", "укороченный", "краткий"],
    "сокровенный": ["тайный", "потайной", "секретный"],
    "сокровище": ["клад", "ценность", "драгоценность", "ценности", "золото", "золотко", "золотце"],
    "сокрушав": ["сокрушавши"],
    "сокрушавши": ["сокрушав"],
    "сокрушать": ["разрушать", "уничтожать", "ниспровергать"],
    "сокрушаться": ["гибнуть", "рушиться", "печалиться", "горевать"],
    "сокрушение": ["слом", "разрушение", "уничтожение", "горе", "огорчение", "печаль"],
    "сокрушенье": ["сокрушение"],
    "сокрушив": ["сокрушивши"],
    "сокрушивши": ["сокрушив"],
    "сокрыв": ["сокрывши"],
    "сокрывши": ["сокрыв"],
    "сокрытие": ["скрытие"],
    "сокрытье": ["сокрытие"],
    "сокурсник": ["однокурсник"],
    "сокурсница": ["однокурсница"],
    "сокъур": ["сокур"],
    "солгав": ["солгавши"],
    "солгавши": ["солгав"],
    "солд-аут": ["аншлаг"],
    "солдат": ["рядовой", "боец", "военный", "воин", "майор"],
    "солдатня": ["солдатьё", "военщина"],
    "солдатский": ["салдацкий"],
    "солдатьё": ["солдатня"],
    "солдафон": ["чурбан", "дуб"],
    "солеварня": ["солеварная"],
    "солевыварочный": ["солеваренный", "солеварный"],
    "соледар": ["карло-либкнехтовск"],
    "солемер": ["салинометр"],
    "соление": ["солка", "засол", "засолка", "соленье"],
    "соленье": ["солка", "засол", "засолка", "соление"],
    "солестойкий": ["солевыносливый"],
    "солестойкость": ["солевыносливость", "солеустойчивость"],
    "солживить": ["предать"],
    "солив": ["соливши"],
    "соливши": ["солив"],
    "солид": ["безант", "бизантин", "номизма"],
    "солидаризироваться": ["солидаризоваться"],
    "солидаризоваться": ["солидаризироваться"],
    "солидничав": ["солидничавши"],
    "солидничавши": ["солидничав"],
    "солидно": ["крепко", "надёжно"],
    "солидность": ["основательность", "значительность"],
    "солидный": ["основательный", "серьёзный", "глубокий", "зрелый", "важный", "представительный", "авторитетный", "видный", "почтенный"],
    "солидол": ["тавот"],
    "соликамск": ["соль камская"],
    "солило": ["солонка", "солоница", "солоничка", "сольница", "солянка"],
    "солильщик": ["солильщица"],
    "солировав": ["солировавши"],
    "солировавши": ["солировав"],
    "солкосерил": ["актовегин"],
    "солнечная батарея": ["солнечная панель", "фотоэлектрическая панель", "солнечный модуль"],
    "солнечник": ["топинамбур", "земляная груша", "подсолнечник клубненосный", "иерусалимский артишок"],
    "солнечно": ["ярко", "светло", "ясно", "безоблачно"],
    "солнечно-планетный": ["гелио-планетный"],
    "солнечное затмение": ["затмение солнца"],
    "солнечное сплетение": ["чревное сплетение", "солнышко"],
    "солнечные очки": ["солнцезащитные очки"],
    "солнопёк": ["солнцепёк"],
    "солнце": ["звезда", "дневное светило", "солнечный свет", "солнышко", "светоч"],
    "солнцеворот": ["солнцестояние", "свастика", "коловрат"],
    "солнцеликий": ["яркий", "светлый"],
    "солнцепоклонничество": ["гелиолатрия"],
    "солнцепёк": ["припёк", "жара"],
    "солнцестояние": ["солнцеворот"],
    "солнцестоянье": ["солнцестояние"],
    "солнышко": ["солнце", "светило", "солнечное сплетение"],
    "соло-гитара": ["лид-гитара", "лидер-гитара"],
    "соло-гитарист": ["лид-гитарист", "лидер-гитарист"],
    "соловев": ["соловевши"],
    "соловевши": ["соловев"],
    "соловей": ["соловушка", "соловейка", "соловейко", "соловьюшка"],
    "соловецкие острова": ["соловки"],
    "соловки": ["соловецкие острова"],
    "солодев": ["солодевши"],
    "солодевши": ["солодев"],
    "солодив": ["солодивши"],
    "солодивши": ["солодив"],
    "солодка": ["лакрица", "лакричник"],
    "солодкий": ["сладкий"],
    "солодковый": ["лакричный", "лакричниковый"],
    "солодовня": ["солодильня"],
    "соложествовав": ["соложествовавши"],
    "соложествовавши": ["соложествовав"],
    "соложник": ["сексуальный партнёр"],
    "солома": ["сено", "сухостой", "мякина", "пожниво", "полова"],
    "соломенно-жёлтый": ["соломенно-пшеничный"],
    "соломина": ["соломинка", "соломка"],
    "соломинка": ["соломина"],
    "соломонович": ["соломоныч"],
    "солонгой": ["сусленник"],
    "солонев": ["солоневши"],
    "солоневши": ["солонев"],
    "солонив": ["солонивши"],
    "солонивши": ["солонив"],
    "солоница": ["солонка"],
    "солонкуватий": ["солонуватий"],
    "солоноватый": ["соленоватый"],
    "солонцевав": ["солонцевавши"],
    "солонцевавши": ["солонцевав"],
    "солоный": ["солёный"],
    "солсберецкий": ["солсберийский"],
    "солсбери": ["хараре"],
    "солсберийский": ["солсберецкий", "солберецкий"],
    "солунь": ["салоники", "фессалоники", "фессалоника"],
    "соль": ["поваренная соль", "хлорид натрия", "квинтэссенция", "существо", "изюминка", "гвоздь", "соль для ванны"],
    "соль земли": ["элита"],
    "соль-бемоль": ["фа-диез"],
    "соль-диез": ["ля-бемоль"],
    "сольватохромия": ["сольватофлуорохромия"],
    "сольвычегодец": ["вычегодец", "сольвычегодчанин", "усолец"],
    "сольвычегодск": ["усолье", "усольск", "соль-вычегодская"],
    "сольмизация": ["сольфеджирование"],
    "сольно": ["соло"],
    "сольпуга": ["фаланга"],
    "сольфеджировав": ["сольфеджировавши"],
    "сольфеджировавши": ["сольфеджировав"],
    "сольфеджирование": ["сольмизация", "сольфеджио"],
    "сольфеджо": ["сольфеджио"],
    "соляная кислота": ["хлористоводородная кислота", "хлороводородная кислота", "хлористый водород"],
    "соляр": ["соляровое масло", "соляра", "солярка", "дизельное топливо"],
    "соляра": ["соляровое масло", "солярка", "соляр", "дизельное топливо"],
    "солярка": ["соляровое масло", "соляра", "соляр", "дизельное топливо"],
    "солярный": ["солнечный"],
    "соляровое масло": ["солярка", "соляра", "соляр", "дизельное топливо"],
    "солёный": ["солесодержащий", "солоный", "соляной", "посоленный", "солоноватый", "присоленный", "присолённый", "засоленный", "засолённый", "рассольный", "грубоватый", "острый", "колкий", "колючий", "язвительный"],
    "сом": ["сом обыкновенный"],
    "сомали": ["федеративная республика сомали", "сомалийская республика", "сомалийская демократическая республика", "огаден", "огадения"],
    "сомалиец": ["сомали"],
    "сомалийка": ["сомали"],
    "соматика": ["тело"],
    "соматически": ["телесно", "физически"],
    "соматогамия": ["псевдогамия", "псевдомиксис"],
    "соматология": ["анатомия"],
    "соматосенсорный": ["соматовисцеральный"],
    "соматотропин": ["гормон роста", "соматропин"],
    "соматропин": ["соматотропин"],
    "сомелье": ["виночерпий"],
    "сомерсет": ["сомерсетшир"],
    "сомерсетшир": ["сомерсет"],
    "сомина": ["сомовина", "сомятина"],
    "сомит": ["артромер", "первичный сегмент", "спинной сегмент"],
    "сомкнув": ["сомкнувши"],
    "сомкнувши": ["сомкнув"],
    "сомлев": ["сомлевши"],
    "сомлевши": ["сомлев"],
    "соммация": ["предупреждение", "призыв", "воззвание"],
    "сомнамбул": ["лунатик", "сомнамбула"],
    "сомнамбула": ["лунатик"],
    "сомнамбулизм": ["лунатизм", "ноктамбулизм", "снохождение"],
    "сомнамбуличность": ["лунатичность"],
    "сомнамбуличный": ["лунатичный"],
    "сомнение": ["неуверенность"],
    "сомненье": ["сомнение"],
    "сомнилоквия": ["сноговорение"],
    "сомнительный": ["маловероятный", "гадательный", "проблематичный", "недостоверный", "невероятный", "неправдоподобный", "подозрительный"],
    "сомнифобия": ["гипнофобия"],
    "сомовина": ["сомятина"],
    "сомовник": ["крючок", "крюк"],
    "сомуститель": ["подстрекатель", "смутьян", "искуситель", "сомулян", "сомуста"],
    "сомчав": ["сомчавши"],
    "сомчавши": ["сомчав"],
    "сомыслив": ["сомысливши"],
    "сомысливши": ["сомыслив"],
    "сомятина": ["сомовина", "сомина"],
    "сон": ["сновидение", "грёза", "мечта", "иллюзия", "спокойствие", "покой", "тишина", "однообразие", "серость", "застой", "бездействие"],
    "сон-час": ["тихий час"],
    "сонар": ["гидролокатор"],
    "сонаследовав": ["сонаследовавши"],
    "сонаследовавши": ["сонаследовав"],
    "сонгми": ["милай"],
    "сонграйтер": ["песенник"],
    "сонечко": ["сонце"],
    "соника": ["сразу", "тотчас"],
    "сонливый": ["сонный"],
    "сонм": ["сход", "собрание", "сборище", "сходбище", "толпа", "сонмище", "множество"],
    "сонмище": ["сонм", "множество", "собрание", "толпа"],
    "сонно": ["спросонья", "спросонок", "вяло"],
    "сонность": ["сонливость"],
    "сонный": ["вялый", "ленивый", "медлительный"],
    "сонограмма": ["спектрограмма", "сонография"],
    "сонография": ["эхография"],
    "сонорный": ["звонкий"],
    "сонохимия": ["акустохимия", "звукохимия"],
    "сонцастаянне": ["сонцаварот"],
    "сонць": ["мирде", "кудазор"],
    "соня": ["сонечка"],
    "соня-полчок": ["полчок"],
    "соображав": ["соображавши"],
    "соображавши": ["соображав"],
    "соображалка": ["головоломка"],
    "соображать": ["понимать", "додумываться"],
    "соображенье": ["соображение"],
    "сообразив": ["сообразивши"],
    "сообразивши": ["сообразив"],
    "сообразительный": ["смышлёный", "умный", "догадливый", "смекалистый"],
    "сообразить": ["придумать", "сварганить", "приготовить"],
    "сообразность": ["согласованность", "соответствие"],
    "сообразный": ["адекватный"],
    "сообразовав": ["сообразовавши"],
    "сообразовавши": ["сообразовав"],
    "сообразовывав": ["сообразовывавши"],
    "сообразовывавши": ["сообразовывав"],
    "сообразовывать": ["сообразовать", "согласовывать"],
    "сообща": ["совместно", "вместе", "вкупе"],
    "сообщав": ["сообщавши"],
    "сообщавши": ["сообщав"],
    "сообщать": ["вещать", "говорить", "передавать", "транслировать", "информировать", "извещать", "уведомлять", "осведомлять", "докладывать", "доносить", "заявлять", "объявлять", "оповещать", "предупреждать", "придавать"],
    "сообщение": ["оповещение", "известие", "сведение", "послание", "связь"],
    "сообщенье": ["сообщение"],
    "сообщив": ["сообщивши"],
    "сообщивши": ["сообщив"],
    "сообщительный": ["общительный"],
    "сообщить": ["проинформировать", "передать", "оповестить", "транслировать", "уведомить", "рассказать", "придать"],
    "сообщник": ["соучастник"],
    "соорудив": ["соорудивши"],
    "соорудивши": ["соорудив"],
    "сооружав": ["сооружавши"],
    "сооружавши": ["сооружав"],
    "сооружать": ["строить", "возводить", "воздвигать"],
    "сооружаться": ["строиться", "возводиться"],
    "сооружение": ["строительство", "возведение", "постройка", "конструкция"],
    "сооруженье": ["сооружение"],
    "соос": ["асьсэос"],
    "сооснователь": ["соучредитель"],
    "соосновательница": ["соучредительница"],
    "соосность": ["коаксиальность"],
    "соосный": ["коаксиальный"],
    "соответственно": ["соответствующе"],
    "соответствие": ["согласованность", "сообразность"],
    "соответствовав": ["соответствовавши"],
    "соответствовавши": ["соответствовав"],
    "соответствующе": ["идентично", "подобающе", "соответственно", "адекватно", "должно", "достойно", "надлежаще", "параллельно"],
    "соответствующий": ["подходящий", "годный"],
    "соотечественник": ["земляк", "компатриот"],
    "соотнесение": ["сопоставление"],
    "соотнести": ["сопоставить"],
    "соотносив": ["соотносивши"],
    "соотносивши": ["соотносив"],
    "соотносительно": ["коррелятивно", "сообразно"],
    "соотносительный": ["коррелятивный", "корреспондирующий", "сообразованный"],
    "соотчич": ["единоплеменник", "соотечественник"],
    "сопа": ["синец"],
    "сопалатник": ["однопалатник"],
    "сопартиец": ["однопартиец"],
    "сопатка": ["нос", "шнобель", "носопырка", "носопатка", "рубильник"],
    "сопдет": ["сотис"],
    "сопев": ["сопевши"],
    "сопевши": ["сопев"],
    "сопелка": ["сопель", "сопилка", "свирель", "носопатка", "носопырка"],
    "сопель": ["сопелка"],
    "сопелька": ["сопля"],
    "сопенье": ["сопение"],
    "сопереживав": ["сопереживавши"],
    "сопереживавши": ["сопереживав"],
    "сопереживание": ["сочувствие", "эмпатия"],
    "сопереживать": ["сострадать", "сочувствовать"],
    "соперник": ["противник", "оппонент", "конкурент"],
    "соперница": ["перебойка", "перебоечка"],
    "соперничав": ["соперничавши"],
    "соперничавши": ["соперничав"],
    "соперничество": ["состязание", "состязательность"],
    "соперничествовав": ["соперничествовавши"],
    "соперничествовавши": ["соперничествовав"],
    "сопка": ["холм", "вулкан"],
    "соплежуй": ["мямля", "недотёпа", "размазня", "тряпка", "трус", "тюфтя", "тюфяк", "хлюпик", "соплеед", "мудак", "мудло"],
    "соплеменник": ["земляк"],
    "соплеменный": ["одноплеменный", "единоплеменный"],
    "соплестрой": ["дрянь", "шняга", "фуфло"],
    "сопли жевать": ["медлить", "тянуть время", "тянуть резину", "тянуть кота за хвост"],
    "соплив": ["сопливши"],
    "сопливив": ["соплививши"],
    "соплививши": ["сопливив"],
    "сопливить": ["простудиться"],
    "сопливши": ["соплив"],
    "соплить": ["сопливить"],
    "сопло": ["дюза"],
    "сопляк": ["мальчишка", "молокосос"],
    "сопнув": ["сопнувши"],
    "сопнувши": ["сопнув"],
    "соподчинив": ["соподчинивши"],
    "соподчинивши": ["соподчинив"],
    "соподчинительный": ["соподчинённый"],
    "соподчиняв": ["соподчинявши"],
    "соподчинявши": ["соподчиняв"],
    "соподчинённый": ["соподчинительный"],
    "сопоставив": ["сопоставивши"],
    "сопоставивши": ["сопоставив"],
    "сопоставимо": ["достойно", "заслуженно", "сравнимо", "соизмеримо"],
    "сопоставимый": ["сравнимый"],
    "сопоставить": ["сравнить", "соотнести"],
    "сопоставление": ["соотнесение", "сравнение"],
    "сопоставленье": ["сопоставление"],
    "сопоставляв": ["сопоставлявши"],
    "сопоставлявши": ["сопоставляв"],
    "сопостат": ["враг", "неприятель", "противник", "супостат"],
    "сопранный": ["сопрановый"],
    "сопрановый": ["сопранный"],
    "сопрев": ["сопревши"],
    "сопревав": ["сопревавши"],
    "сопревавши": ["сопревав"],
    "сопревание": ["прение"],
    "сопревши": ["сопрев"],
    "сопредельный": ["смежный", "прилегающий"],
    "соприкосновенье": ["соприкосновение"],
    "соприсутствовав": ["соприсутствовавши"],
    "соприсутствовавши": ["соприсутствовав"],
    "сопричастный": ["причастный", "соучастный", "прикосновенный"],
    "сопричислив": ["сопричисливши"],
    "сопричисливши": ["сопричислив"],
    "сопричисляв": ["сопричислявши"],
    "сопричислявши": ["сопричисляв"],
    "сопричитав": ["сопричитавши"],
    "сопричитавши": ["сопричитав"],
    "сопроводив": ["сопроводивши"],
    "сопроводивши": ["сопроводив"],
    "сопровождав": ["сопровождавши"],
    "сопровождавши": ["сопровождав"],
    "сопродюсер": ["копродюсер"],
    "сопромат": ["сопротивление материалов"],
    "сопротивление": ["противодействие", "противление", "отпор", "резистенция", "сопротивляемость", "резистор"],
    "сопротивление материалов": ["сопромат"],
    "сопроцессор": ["копроцессор"],
    "сопруга": ["жена"],
    "сопрягав": ["сопрягавши"],
    "сопрягавши": ["сопрягав"],
    "сопрягать": ["связывать", "соединять", "сочленять"],
    "сопряженье": ["сопряжение"],
    "сопряжённый": ["связанный"],
    "сопрячь": ["связать", "соединить", "сочленить"],
    "сопутник": ["спутник", "попутчик"],
    "сопутница": ["спутница", "попутчица"],
    "сопутничав": ["сопутничавши"],
    "сопутничавши": ["сопутничав"],
    "сопутничать": ["состранствовать"],
    "сопутствовав": ["сопутствовавши"],
    "сопутствовавши": ["сопутствовав"],
    "сопутствовать": ["сопровождать"],
    "сопутствующий": ["коллатеральный", "сопроводительный", "попутный"],
    "сопхнув": ["сопхнувши"],
    "сопхнувши": ["сопхнув"],
    "сопхнуть": ["спихнуть", "столкнуть"],
    "сор": ["мусор", "пыль", "грязь"],
    "соразмерив": ["соразмеривши"],
    "соразмеривши": ["соразмерив"],
    "соразмерность": ["соответственность"],
    "соразмеряв": ["соразмерявши"],
    "соразмерявши": ["соразмеряв"],
    "сорани": ["центральнокурдский язык"],
    "соратник": ["однополчанин", "сослуживец", "единомышленник", "сподвижник"],
    "сорбе": ["сорбет"],
    "сорбет": ["сорбе"],
    "сорбийский": ["лужицкий", "серболужицкий", "вендский"],
    "сорбировав": ["сорбировавши"],
    "сорбировавши": ["сорбировав"],
    "сорбирование": ["сорбция"],
    "сорбит": ["сорбитол", "глюцит"],
    "сорбитизировав": ["сорбитизировавши"],
    "сорбитизировавши": ["сорбитизировав"],
    "сорбитол": ["сорбит"],
    "сорбонна": ["парижский университет"],
    "сорвав": ["сорвавши"],
    "сорвавши": ["сорвав"],
    "сорванец": ["проказник", "озорник", "шалун"],
    "сорвать": ["снять", "сбросить", "сдёрнуть", "посадить", "провалить", "расстроить", "выместить"],
    "сорвать башню": ["сойти с ума", "слететь с катушек", "двинуться", "повредиться", "поссориться с головой", "башню сорвать"],
    "сорвиголова": ["смельчак", "храбрец", "отчаянная голова", "лихач", "удалец", "бедовая голова"],
    "сорганизовав": ["сорганизовавши"],
    "сорганизовавши": ["сорганизовав"],
    "сорганизовать": ["организовать"],
    "сорганизовывав": ["сорганизовывавши"],
    "сорганизовывавши": ["сорганизовывав"],
    "сорго": ["веники", "гаолян"],
    "соревновав": ["соревновавши"],
    "соревновавши": ["соревновав"],
    "соревнование": ["состязание", "соперничество", "конкуренция", "тендер"],
    "соревнованье": ["соревнование"],
    "соревновательность": ["конкурентность", "состязательность"],
    "соревноваться": ["соперничать", "состязаться"],
    "сорив": ["соривши"],
    "соривши": ["сорив"],
    "соригинальничав": ["соригинальничавши"],
    "соригинальничавши": ["соригинальничав"],
    "сориентировав": ["сориентировавши"],
    "сориентировавши": ["сориентировав"],
    "сорить": ["мусорить"],
    "сорно": ["грязно"],
    "сорняк": ["сорное растение"],
    "сородич": ["родич", "родственник", "земляк", "соплеменник"],
    "сородичка": ["подруга", "подружка"],
    "сорок сороков": ["тьма", "стопицот"],
    "сорока": ["белобока", "сплетник", "сплетница", "трепач", "трещотка"],
    "сорока на хвосте принесла": ["слухом земля полнится"],
    "сорокавосьмигранник": ["гексакисоктаэдр", "гексаоктаэдр", "гексоктаэдр"],
    "сорокалетье": ["сорокалетие"],
    "сорокет": ["сороковник"],
    "сороковины": ["сорочины"],
    "сороковник": ["сорокет"],
    "сороконожка": ["многоножка", "стоножка", "шиповка"],
    "сорокопут": ["жулан", "птица-мясник"],
    "сором": ["бесчестье", "позор", "срам", "срамота"],
    "соромив": ["соромивши"],
    "соромивши": ["соромив"],
    "соромный": ["срамной"],
    "сорочек": ["посорка"],
    "сорочив": ["сорочивши"],
    "сорочивши": ["сорочив"],
    "сорочины": ["сороковины"],
    "сорочка": ["рубашка"],
    "сорпо": ["шорпо"],
    "сорри": ["извините", "извини", "сорян"],
    "сорт": ["категория", "разряд", "вид", "род", "разновидность"],
    "сортавала": ["сердоболь"],
    "сортамент": ["сортимент"],
    "сортимент": ["сорт", "сортамент", "разнообразие"],
    "сортир": ["уборная"],
    "сортировав": ["сортировавши"],
    "сортировавши": ["сортировав"],
    "сортировать": ["рассортировывать", "классифицировать"],
    "сортия": ["выход"],
    "сортный": ["сортовой"],
    "сортовав": ["сортовавши"],
    "сортовавши": ["сортовав"],
    "сортоваться": ["сортироваться"],
    "сортосмесь": ["разносортица"],
    "сортучка": ["амальгама", "нартучка", "сортутка", "сортуток", "сотручение", "сотручивание"],
    "сорудовав": ["сорудовавши"],
    "сорудовавши": ["сорудовав"],
    "сорфинг": ["сёрфинг"],
    "соря": ["мусоря"],
    "сосав": ["сосавши"],
    "сосавши": ["сосав"],
    "сосалка": ["сосачка"],
    "сосальце": ["присоска", "хоботок", "лабеллум"],
    "сосание": ["сосанье"],
    "сосанье": ["сосание"],
    "сосать лапу": ["лапу сосать", "сосать хуй", "хуй сосать"],
    "сосать хуй": ["сосать лапу", "сосать член", "заработать хуем по спине"],
    "сосачка": ["карамельная конфета", "леденец", "сосучка", "сосалка", "сосатка", "сосулька"],
    "сосборив": ["сосборивши"],
    "сосборивши": ["сосборив"],
    "сосватав": ["сосватавши"],
    "сосватавши": ["сосватав"],
    "сосватывав": ["сосватывавши"],
    "сосватывавши": ["сосватывав"],
    "сосводничав": ["сосводничавши"],
    "сосводничавши": ["сосводничав"],
    "сосворив": ["сосворивши"],
    "сосворивав": ["сосворивавши"],
    "сосворивавши": ["сосворивав"],
    "сосворивши": ["сосворив"],
    "сосед": ["ближний"],
    "соседив": ["соседивши"],
    "соседивши": ["соседив"],
    "соседний": ["ближний", "близлежащий"],
    "соседов": ["соседский"],
    "соседствовав": ["соседствовавши"],
    "соседствовавши": ["соседствовав"],
    "соседствовать": ["соседить"],
    "сосенка": ["сосёнка"],
    "сосец": ["сосок"],
    "сосиска": ["сосисочка"],
    "сосиська": ["сосиска"],
    "соска": ["сосочка"],
    "соскабливав": ["соскабливавши"],
    "соскабливавши": ["соскабливав"],
    "соскабливать": ["соскребать"],
    "соскакивав": ["соскакивавши"],
    "соскакивавши": ["соскакивав"],
    "соскальзывав": ["соскальзывавши"],
    "соскальзывавши": ["соскальзывав"],
    "соскоблив": ["соскобливши"],
    "соскобливши": ["соскоблив"],
    "соскок": ["соскакивание"],
    "соскользав": ["соскользавши"],
    "соскользавши": ["соскользав"],
    "соскользнув": ["соскользнувши"],
    "соскользнувши": ["соскользнув"],
    "соскочив": ["соскочивши"],
    "соскочивши": ["соскочив"],
    "соскребав": ["соскребавши"],
    "соскребавши": ["соскребав"],
    "соскрёбывав": ["соскрёбывавши"],
    "соскрёбывавши": ["соскрёбывав"],
    "соскучив": ["соскучивши"],
    "соскучивши": ["соскучив"],
    "соскучить": ["заскучать", "соскучиться"],
    "соскучиться": ["заскучать", "стосковаться"],
    "сослав": ["сославши"],
    "сославши": ["сослав"],
    "сослагав": ["сослагавши"],
    "сослагавши": ["сослагав"],
    "сослагательное наклонение": ["конъюнктив", "сюбжонктив"],
    "сослагательный": ["условный"],
    "соследив": ["соследивши"],
    "соследивши": ["соследив"],
    "сослеживав": ["сослеживавши"],
    "сослеживавши": ["сослеживав"],
    "сословье": ["сословие"],
    "сослужащий": ["сослужитель"],
    "сослужив": ["сослуживши"],
    "сослуживец": ["коллега"],
    "сослуживши": ["сослужив"],
    "сослужитель": ["сослужащий"],
    "сосненка": ["кудра"],
    "соснуть": ["пососать", "сделать минет", "отсосать", "поработать ртом", "взять в рот", "взять за щёку", "взять на клык", "лососнуть", "лососнуть тунца"],
    "сосочек": ["сосок"],
    "сосплетничав": ["сосплетничавши"],
    "сосплетничавши": ["сосплетничав"],
    "сосплетничать": ["насплетничать"],
    "соспорив": ["соспоривши"],
    "соспоривши": ["соспорив"],
    "сосредотачивав": ["сосредотачивавши"],
    "сосредотачивавши": ["сосредотачивав"],
    "сосредотачивать": ["сосредоточивать", "концентрировать", "фокусировать"],
    "сосредотачиваться": ["собираться", "концентрироваться", "сосредоточиваться", "фокусироваться"],
    "сосредоточенно": ["пристально", "собранно", "сфокусированно"],
    "сосредоточенность": ["сконцентрированность", "сфокусированность", "сосредоточение"],
    "сосредоточенье": ["сосредоточение"],
    "сосредоточив": ["сосредоточивши"],
    "сосредоточивав": ["сосредоточивавши"],
    "сосредоточивавши": ["сосредоточивав"],
    "сосредоточиваться": ["собираться", "концентрироваться", "сосредотачиваться", "фокусироваться"],
    "сосредоточивши": ["сосредоточив"],
    "сосредоточить": ["сконцентрировать", "сфокусировать"],
    "соссав": ["соссавши"],
    "соссавши": ["соссав"],
    "соссать": ["испугаться"],
    "соссюрианский": ["соссюровский"],
    "соссюритизировав": ["соссюритизировавши"],
    "соссюритизировавши": ["соссюритизировав"],
    "соссюровский": ["соссюрианский"],
    "состав": ["набор", "комплект", "смесь", "препарат", "железнодорожный состав", "поезд", "описание"],
    "составив": ["составивши"],
    "составивши": ["составив"],
    "составление": ["подборка", "собирание", "написание"],
    "составляв": ["составлявши"],
    "составлявши": ["составляв"],
    "составляющая": ["компонент", "элемент", "ингредиент"],
    "составляющее вещество": ["индивидуальное вещество"],
    "составная часть": ["компонент", "элемент"],
    "составной": ["составленный", "составляющий"],
    "состарив": ["состаривши"],
    "состаривав": ["состаривавши"],
    "состаривавши": ["состаривав"],
    "состариваться": ["стареть", "стариться"],
    "состаривши": ["состарив"],
    "состариться": ["постареть"],
    "состегав": ["состегавши"],
    "состегавши": ["состегав"],
    "состегнув": ["состегнувши"],
    "состегнувши": ["состегнув"],
    "состирав": ["состиравши"],
    "состиравши": ["состирав"],
    "состирывав": ["состирывавши"],
    "состирывавши": ["состирывав"],
    "состольник": ["сотрапезник"],
    "состояв": ["состоявши"],
    "состоявши": ["состояв"],
    "состоятельность": ["обеспеченность", "зажиточность", "материальное благополучие", "обоснованность", "непротиворечивость", "убедительность"],
    "состоятельный": ["богатый", "зажиточный", "обеспеченный"],
    "состоять": ["складываться", "из", "содержать", "заключаться", "пребывать", "быть", "находиться", "на"],
    "состояться": ["произойти", "осуществиться", "воплотиться", "реализоваться"],
    "сострагивав": ["сострагивавши"],
    "сострагивавши": ["сострагивав"],
    "сострадав": ["сострадавши"],
    "сострадавши": ["сострадав"],
    "сострадание": ["милосердие", "сердоболие", "сердобольность", "состраданье"],
    "состраданье": ["сострадание", "милосердие", "сердоболие", "сердобольность"],
    "сострадательный": ["сочувственный", "участливый"],
    "сострадать": ["сочувствовать", "сопереживать", "сердобольничать", "соболезновать"],
    "состраждать": ["сострадать"],
    "состранствовав": ["состранствовавши"],
    "состранствовавши": ["состранствовав"],
    "состранствовать": ["сопутничать"],
    "сострачивав": ["сострачивавши"],
    "сострачивавши": ["сострачивав"],
    "сострив": ["состривши"],
    "состривши": ["сострив"],
    "состригав": ["состригавши"],
    "состригавши": ["состригав"],
    "сострить": ["пошутить"],
    "сострогав": ["сострогавши"],
    "сострогавши": ["сострогав"],
    "сострогнув": ["сострогнувши"],
    "сострогнувши": ["сострогнув"],
    "состроив": ["состроивши"],
    "состроивши": ["состроив"],
    "сострочив": ["сострочивши"],
    "сострочивши": ["сострочив"],
    "состругав": ["состругавши"],
    "состругавши": ["состругав"],
    "состругивав": ["состругивавши"],
    "состругивавши": ["состругивав"],
    "состругнув": ["состругнувши"],
    "состругнувши": ["состругнув"],
    "состружив": ["соструживши"],
    "соструживав": ["соструживавши"],
    "соструживавши": ["соструживав"],
    "соструживши": ["состружив"],
    "сострунив": ["сострунивши"],
    "сострунивав": ["сострунивавши"],
    "сострунивавши": ["сострунивав"],
    "сострунивать": ["струнить"],
    "сострунивши": ["сострунив"],
    "состряпав": ["состряпавши"],
    "состряпавши": ["состряпав"],
    "соступав": ["соступавши"],
    "соступавши": ["соступав"],
    "соступать": ["сходить"],
    "соступив": ["соступивши"],
    "соступивши": ["соступив"],
    "соступить": ["сойти"],
    "состыковав": ["состыковавши"],
    "состыковавши": ["состыковав"],
    "состыковать": ["согласовать", "утрясти"],
    "состыковывав": ["состыковывавши"],
    "состыковывавши": ["состыковывав"],
    "состязание": ["соревнование", "соперничество"],
    "состязанье": ["состязание"],
    "состязательный": ["конкурентный"],
    "состязаться": ["соревноваться"],
    "состёгивав": ["состёгивавши"],
    "состёгивавши": ["состёгивав"],
    "сосуд": ["ёмкость", "жила"],
    "сосудорасширяющий": ["вазодилататорный"],
    "сосулька": ["сталактит", "сосуля", "соска", "блоха"],
    "сосунок": ["сосун", "сосачка"],
    "сосуществовав": ["сосуществовавши"],
    "сосуществовавши": ["сосуществовав"],
    "сосуществование": ["симбиоз"],
    "сосуществованье": ["сосуществование"],
    "сосчитав": ["сосчитавши"],
    "сосчитавши": ["сосчитав"],
    "сосчитать": ["посчитать", "пересчитать"],
    "сосчитывав": ["сосчитывавши"],
    "сосчитывавши": ["сосчитывав"],
    "сосчитывать": ["считать"],
    "сосьетер": ["пайщик"],
    "сосёт под ложечкой": ["в животе урчит"],
    "сот": ["соты"],
    "сота": ["софа"],
    "сотворение": ["создание"],
    "сотворив": ["сотворивши"],
    "сотворивши": ["сотворив"],
    "сотворить": ["совершить", "сделать", "создать"],
    "сотворяв": ["сотворявши"],
    "сотворявши": ["сотворяв"],
    "сотворять": ["создавать", "творить"],
    "сотерн": ["семильон"],
    "сотиз": ["глупость", "бетиз"],
    "сотик": ["сотовый телефон", "сотовый", "мобильный телефон", "мобильный", "мобильник", "мобилка", "мобила", "труба"],
    "соткав": ["соткавши"],
    "соткавши": ["соткав"],
    "соткать": ["выткать", "сплести", "состоять"],
    "соткнув": ["соткнувши"],
    "соткнувши": ["соткнув"],
    "соткровенничав": ["соткровенничавши"],
    "соткровенничавши": ["соткровенничав"],
    "сотлев": ["сотлевши"],
    "сотлевав": ["сотлевавши"],
    "сотлевавши": ["сотлевав"],
    "сотлевать": ["тлеть"],
    "сотлевши": ["сотлев"],
    "сотник": ["поручик", "лейтенант"],
    "сотняга": ["стольник"],
    "сотовариществовав": ["сотовариществовавши"],
    "сотовариществовавши": ["сотовариществовав"],
    "сотоварка": ["соучастница"],
    "сотомс": ["сюлмамс"],
    "сотрапезник": ["состольник"],
    "сотрапезничав": ["сотрапезничавши"],
    "сотрапезничавши": ["сотрапезничав"],
    "сотрудник": ["коллега", "сослуживец", "работник", "служащий"],
    "сотрудничав": ["сотрудничавши"],
    "сотрудничавши": ["сотрудничав"],
    "сотрудничество": ["соучастие", "взаимодействие", "партнерство", "кооперация", "коллаборация"],
    "сотряс": ["сотрясение мозга", "сотрясение", "коммоция"],
    "сотрясав": ["сотрясавши"],
    "сотрясавши": ["сотрясав"],
    "сотрясание": ["дрожание", "трясение", "трепетание", "содрогание"],
    "сотрясение": ["содрогание", "сотрясение мозга", "коммоция"],
    "сотрясение мозга": ["коммоция", "сотряс"],
    "сотрясенье": ["сотрясение"],
    "сотью": ["стократно"],
    "соузник": ["сокамерник"],
    "соумышленник": ["сообщник"],
    "соус": ["подливка"],
    "соучаствовав": ["соучаствовавши"],
    "соучаствовавши": ["соучаствовав"],
    "соучастие": ["скоп"],
    "соучастье": ["соучастие"],
    "соучредив": ["соучредивши"],
    "соучредивши": ["соучредив"],
    "соучредительница": ["соосновательница"],
    "соучреждав": ["соучреждавши"],
    "соучреждавши": ["соучреждав"],
    "софа": ["софия", "софья", "софочка", "софьюшка", "софи", "соня", "сонечка", "сонька", "сонюша", "сончик", "сонюшка"],
    "софизм": ["увёртка", "уловка", "ухищрение"],
    "софинансировав": ["софинансировавши"],
    "софинансировавши": ["софинансировав"],
    "софинансирование": ["совместное финансирование"],
    "софистский": ["софистический"],
    "софия": ["софья", "соня", "софа", "софьюшка", "сонечка", "софочка", "сонька", "софка"],
    "софт": ["софтвер", "программное обеспечение"],
    "софтвер": ["программное обеспечение"],
    "софтина": ["софт", "прога", "программулина"],
    "софья": ["софия", "софа", "софочка", "софи", "соня", "сонечка", "сонька", "сонюша", "сончик", "сонюшка"],
    "софья власьевна": ["советская власть", "совейская власть", "советский союз"],
    "соха": ["шест", "жердь", "столб", "подставка", "подпора"],
    "сохатый": ["лось"],
    "сохнув": ["сохнувши"],
    "сохнувши": ["сохнув"],
    "сохра": ["сохранёнка"],
    "сохранение": ["экономия"],
    "сохранив": ["сохранивши"],
    "сохранивши": ["сохранив"],
    "сохраниться": ["уцелеть"],
    "сохраня": ["сохранивши"],
    "сохраняв": ["сохранявши"],
    "сохранявши": ["сохраняв"],
    "сохранять спокойствие": ["владеть собой", "не терять головы"],
    "сохраняться": ["уцелевать", "продолжаться", "сберегаться"],
    "сохранёнка": ["сохра"],
    "соцветье": ["соцветие"],
    "соцдек": ["соцдем"],
    "соцдем": ["соцдек"],
    "социал-демократ": ["эсдек"],
    "социал-демократизировав": ["социал-демократизировавши"],
    "социал-демократизировавши": ["социал-демократизировав"],
    "социал-демократический": ["эсдековский"],
    "социал-фашизм": ["социал-демократия"],
    "социал-фашист": ["социал-демократ"],
    "социал-фашистский": ["социал-демократический"],
    "социал-шовинизм": ["социал-патриотизм"],
    "социал-шовинист": ["социал-патриот"],
    "социал-шовинистический": ["социал-патриотический"],
    "социализировав": ["социализировавши"],
    "социализировавши": ["социализировав"],
    "социализм": ["коммунизм"],
    "социалистическая республика вьетнам": ["вьетнам", "срв"],
    "социалистический": ["коммунистический"],
    "социалистический лагерь": ["восточный блок"],
    "социалистическое соревнование": ["соцсоревнование"],
    "социалка": ["социальная сфера", "социальная сеть"],
    "социальная дистанция": ["соцдистанция"],
    "социальная защита": ["соцзащита"],
    "социальная сеть": ["соцсеть"],
    "социальная стратификация": ["расслоение общества"],
    "социальное дистанцирование": ["соцдистанцирование"],
    "социальное обеспечение": ["собес", "соцобеспечение"],
    "социальное страхование": ["соцстрахование"],
    "социальный": ["общественный", "городской", "муниципальный"],
    "социальный институт": ["институция"],
    "социальный пакет": ["соцпакет"],
    "социатив": ["совместно-орудийный падеж"],
    "социативный": ["сопроводительный", "совместный"],
    "социогенез": ["социогенезис"],
    "социолект": ["социальный диалект", "жаргон"],
    "социопатический": ["психопатический"],
    "социопатия": ["психопатия", "диссоциальное расстройство личности", "антисоциальное расстройство личности"],
    "социум": ["общество", "общность", "среда"],
    "соцлагерь": ["социалистический лагерь"],
    "соцподдержка": ["соцпомощь"],
    "соцпомощь": ["соцподдержка"],
    "соцсеть": ["социальная сеть"],
    "соцсоревнование": ["социалистическое соревнование"],
    "соцстроительство": ["социалистическое строительство"],
    "сочельник": ["навечерие"],
    "сочень": ["сочник", "сочиво"],
    "сочетав": ["сочетавши"],
    "сочетавши": ["сочетав"],
    "сочетаемость": ["совместимость", "соединимость", "лексическая сочетаемость"],
    "сочетание": ["соединение", "объединение", "комбинирование", "единство", "сосуществование", "комбинация"],
    "сочетание клавиш": ["горячая клавиша", "шорткат", "клавиша быстрого доступа", "клавиша быстрого вызова", "клавиатурный ускоритель"],
    "сочетать": ["соединять", "объединять", "совмещать", "комбинировать", "женить"],
    "сочив": ["сочивши"],
    "сочивши": ["сочив"],
    "сочинение": ["сотворение", "произведение"],
    "сочиненье": ["сочинение"],
    "сочинив": ["сочинивши"],
    "сочинивши": ["сочинив"],
    "сочинитель": ["писатель", "автор", "создатель", "выдумщик", "лгун"],
    "сочинительствовав": ["сочинительствовавши"],
    "сочинительствовавши": ["сочинительствовав"],
    "сочиниться": ["сделаться", "произойти", "образоваться", "придуматься"],
    "сочиняв": ["сочинявши"],
    "сочинявши": ["сочиняв"],
    "сочинять": ["создавать"],
    "сочлененье": ["сочленение"],
    "сочленив": ["сочленивши"],
    "сочленивши": ["сочленив"],
    "сочленяв": ["сочленявши"],
    "сочленявши": ["сочленяв"],
    "сочник": ["сочень"],
    "сочувствие": ["жалость", "сострадание", "участие", "похвала", "симпатия", "приязнь"],
    "сочувствовав": ["сочувствовавши"],
    "сочувствовавши": ["сочувствовав"],
    "сочувствовать": ["сострадать", "сопереживать", "поддерживать", "одобрять"],
    "сочувствующий": ["сопереживающий"],
    "сош": ["средняя общеобразовательная школа", "средняя школа", "система ориентации шпинделя"],
    "сошвыривав": ["сошвыривавши"],
    "сошвыривавши": ["сошвыривав"],
    "сошвырнув": ["сошвырнувши"],
    "сошвырнувши": ["сошвырнув"],
    "сошка": ["соха"],
    "сошкольничав": ["сошкольничавши"],
    "сошкольничавши": ["сошкольничав"],
    "сошлифовывав": ["сошлифовывавши"],
    "сошлифовывавши": ["сошлифовывав"],
    "сошлифовывание": ["абразия"],
    "сошмыгнув": ["сошмыгнувши"],
    "сошмыгнувши": ["сошмыгнув"],
    "сошник": ["лемех", "омежь", "ральник"],
    "сошпаргалив": ["сошпаргаливши"],
    "сошпаргаливши": ["сошпаргалив"],
    "сошпионив": ["сошпионивши"],
    "сошпионивши": ["сошпионив"],
    "сощипав": ["сощипавши"],
    "сощипавши": ["сощипав"],
    "сощипнув": ["сощипнувши"],
    "сощипнувши": ["сощипнув"],
    "сощипывав": ["сощипывавши"],
    "сощипывавши": ["сощипывав"],
    "сощурив": ["сощуривши"],
    "сощуривав": ["сощуривавши"],
    "сощуривавши": ["сощуривав"],
    "сощуривши": ["сощурив"],
    "соэволюция": ["коэволюция"],
    "союз": ["ссср", "соединённые штаты америки"],
    "союзив": ["союзивши"],
    "союзивши": ["союзив"],
    "союзник": ["единомышленник", "товарищ", "друг"],
    "союзничав": ["союзничавши"],
    "союзничавши": ["союзничав"],
    "союзписательский": ["союзписовский"],
    "союргаль": ["лен", "икт"],
    "соя": ["соевые бобы"],
    "соябон": ["чатр"],
    "соядаст": ["имзо"],
    "спавн": ["появление", "сравн-поинт"],
    "спавши": ["спав"],
    "спагетти": ["паста"],
    "спагетти-код": ["индусский код"],
    "спад": ["спадание", "спадение", "понижение", "убыль", "ослабление", "снижение"],
    "спадав": ["спадавши"],
    "спадавши": ["спадав"],
    "спадать": ["падать", "понижаться", "ослабевать", "идти на убыль", "ниспадать"],
    "спадение": ["спад"],
    "спазм": ["спазма", "судорога", "корча"],
    "спазма": ["спазм", "судорога"],
    "спазматически": ["судорожно", "конвульсивно", "нерегулярно", "перерыв"],
    "спазматический": ["судорожный", "конвульсивный", "спастический"],
    "спазмировав": ["спазмировавши"],
    "спазмировавши": ["спазмировав"],
    "спазмодический": ["спазматический"],
    "спазмолитик": ["антиспазмодик"],
    "спаивав": ["спаивавши"],
    "спаивавши": ["спаивав"],
    "спаивание": ["выпаивание", "выпаиванье", "спаиванье"],
    "спаиванье": ["спаивание"],
    "спайковый": ["шиповидный", "импульсный", "пиковый"],
    "спайник": ["дипорпа"],
    "спайщик": ["спайщица"],
    "спакетировав": ["спакетировавши"],
    "спакетировавши": ["спакетировав"],
    "спакостив": ["спакостивши"],
    "спакостивши": ["спакостив"],
    "спакостничав": ["спакостничавши"],
    "спакостничавши": ["спакостничав"],
    "спалзывав": ["спалзывавши"],
    "спалзывавши": ["спалзывав"],
    "спалив": ["спаливши"],
    "спаливав": ["спаливавши"],
    "спаливавши": ["спаливав"],
    "спаливши": ["спалив"],
    "спалить": ["сжечь", "иссушить", "испортить", "застукать"],
    "спалить контору": ["проболтаться"],
    "спалить щи": ["засветить"],
    "спалиться": ["сгореть", "попасться"],
    "спална соба": ["спална"],
    "спалохаць": ["спужаць"],
    "спалывав": ["спалывавши"],
    "спалывавши": ["спалывав"],
    "спалывать": ["выпалывать", "полоть"],
    "спальная": ["спальня", "спальная комната", "опочивальня", "спальная зала", "спальные покои"],
    "спальный район": ["спальник"],
    "спальня": ["опочивальня", "палата", "дортуар", "дормиторий", "спальная"],
    "спалённый": ["сожжённый", "иссушенный", "обожжённый"],
    "спам": ["реклама"],
    "спамив": ["спамивши"],
    "спамивши": ["спамив"],
    "спамилка": ["спам-бот"],
    "спамный": ["спамовый"],
    "спамовый": ["спамный"],
    "спандекс": ["лайкра", "эластан", "эластомерная нить"],
    "спаниковав": ["спаниковавши"],
    "спаниковавши": ["спаниковав"],
    "спаниковать": ["запаниковать"],
    "спанорамировав": ["спанорамировавши"],
    "спанорамировавши": ["спанорамировав"],
    "спаньё": ["сон"],
    "спарашютировав": ["спарашютировавши"],
    "спарашютировавши": ["спарашютировав"],
    "спаренность": ["парность", "сдвоенность"],
    "спаржа": ["аспарагус", "фучжу", "соевая спаржа"],
    "спарив": ["спаривши"],
    "спаривав": ["спаривавши"],
    "спаривавши": ["спаривав"],
    "спаривание": ["сдваивание", "копуляция"],
    "спариванье": ["спаривание"],
    "спаривши": ["спарив"],
    "спаровав": ["спаровавши"],
    "спаровавши": ["спаровав"],
    "спародировав": ["спародировавши"],
    "спародировавши": ["спародировав"],
    "спарринговав": ["спарринговавши"],
    "спарринговавши": ["спарринговав"],
    "спарта": ["лакедемон"],
    "спартанский": ["лакедемонский", "аскетичный", "простой", "строгий", "суровый", "мужественный", "стойкий", "выносливый"],
    "спартиат": ["гомей"],
    "спарус": ["дорада"],
    "спархивав": ["спархивавши"],
    "спархивавши": ["спархивав"],
    "спарывав": ["спарывавши"],
    "спарывавши": ["спарывав"],
    "спас": ["второй спас", "яблочный спас", "спас на горе", "преображение господне", "преображение"],
    "спасав": ["спасавши"],
    "спасавши": ["спасав"],
    "спасатель": ["спаситель"],
    "спасательный жилет": ["спасжилет"],
    "спасать": ["выручать", "избавлять", "сохранять"],
    "спасение": ["избавление"],
    "спасенье": ["спасение"],
    "спасжилет": ["спасательный жилет"],
    "спасибо": ["благодарю", "благодарствую", "мерси", "спаси господи", "спаси христос", "ладно"],
    "спасибо в карман не положишь": ["спасибо на хлеб не намажешь", "спасибо в стакан не нальёшь"],
    "спасибо на хлеб не намажешь": ["спасибо в карман не положишь"],
    "спасибочки": ["благодарю", "благодарствую", "мерси", "аття", "спасибо", "спасибочко", "спасибки", "спасиб", "пасиб"],
    "спаситель": ["избавитель"],
    "спасовав": ["спасовавши"],
    "спасовавши": ["спасовав"],
    "спассеровав": ["спассеровавши"],
    "спассеровавши": ["спассеровав"],
    "спасти": ["избавить", "защитить", "уберечь", "выручить"],
    "спастись": ["выжить"],
    "спастический": ["спазматический"],
    "спасть": ["отпасть", "опасть"],
    "спасть с лица": ["осунуться"],
    "спатифиллум": ["женское счастье"],
    "спать": ["покоиться", "бездействовать", "тормозить", "вафлю жевать", "жить", "сношаться", "спать вечным сном"],
    "спать сном праведника": ["спать без задних ног"],
    "спахав": ["спахавши"],
    "спахавши": ["спахав"],
    "спахивав": ["спахивавши"],
    "спахивавши": ["спахивав"],
    "спаяв": ["спаявши"],
    "спаявши": ["спаяв"],
    "спаянность": ["единство", "сплочённость", "слитность"],
    "спаясничав": ["спаясничавши"],
    "спаясничавши": ["спаясничав"],
    "спб": ["санкт-петербург", "санкт-петербургский"],
    "спбгу": ["лгу"],
    "спев": ["спевши"],
    "спевав": ["спевавши"],
    "спевавши": ["спевав"],
    "спевать": ["петь"],
    "спевши": ["спев"],
    "спека": ["спекота"],
    "спекав": ["спекавши"],
    "спекавши": ["спекав"],
    "спекание": ["агломерация"],
    "спекательный": ["агломерационный", "спекальный", "спековый"],
    "спекать": ["сплавлять"],
    "спекота": ["спека"],
    "спектакль": ["пьеса", "постановка", "зрелище", "представление", "розыгрыш"],
    "спектр": ["радуга", "распределение", "многообразие", "диапазон"],
    "спектральность": ["спектр"],
    "спектрографировав": ["спектрографировавши"],
    "спектрографировавши": ["спектрографировав"],
    "спектрометрировав": ["спектрометрировавши"],
    "спектрометрировавши": ["спектрометрировав"],
    "спекулировав": ["спекулировавши"],
    "спекулировавши": ["спекулировав"],
    "спекульнув": ["спекульнувши"],
    "спекульнувши": ["спекульнув"],
    "спекулянт": ["перекупщик"],
    "спекулятивно": ["умозрительно"],
    "спекулятивность": ["отвлечённость", "умозрительность", "метафизичность"],
    "спекуляторный": ["спекулятивный"],
    "спеленав": ["спеленавши"],
    "спеленавши": ["спеленав"],
    "спелеодайвер": ["кейв-дайвер"],
    "спелеодайвинг": ["кейв-дайвинг"],
    "спелеология": ["спелеотуризм"],
    "спелл-чекер": ["спеллер"],
    "спеллер": ["спелл-чекер"],
    "спелость": ["зрелость"],
    "спелый": ["зрелый"],
    "спелёнывав": ["спелёнывавши"],
    "спелёнывавши": ["спелёнывав"],
    "спензер": ["шпензер", "спенсер", "шпенсер", "спенцер", "шпенцер", "спензерь", "спензель", "спендель", "пендель", "пендея"],
    "спенсер": ["шпенсер", "спенцер", "шпенцер", "спензер", "шпензер", "спензерь", "спензель", "спендель", "пендель", "пендея"],
    "сперва": ["вначале", "сначала", "прежде", "раньше", "изначально", "поперву"],
    "спервоначала": ["спервоначалу"],
    "спервоначалу": ["спервоначала"],
    "сперев": ["спёрши"],
    "спереди": ["впереди"],
    "спереть": ["украсть", "своровать", "похитить", "сбондить", "стибрить", "стырить", "слямзить", "сдвинуть"],
    "сперматозоид": ["живчик", "спермий"],
    "спесивев": ["спесивевши"],
    "спесивевши": ["спесивев"],
    "спесивец": ["воображала", "фанаберист", "зазнайка", "задавака", "задавала"],
    "спесивиться": ["чваниться"],
    "спесиво": ["высокомерно", "кичливо", "чванно", "горделиво", "надменно"],
    "спесивость": ["высокомерие", "гонор", "гордыня", "зазнайство", "заносчивость", "кичливость", "надменность", "надутость", "чванство", "чванность", "чванливость", "фанаберия"],
    "спесивый": ["высокомерный", "надменный", "кичливый", "заносчивый", "тщеславный"],
    "спесь": ["высокомерие", "надменность", "гордыня", "тщеславие", "чванство", "чванливость", "гонор", "заносчивость", "кичливость", "надутость", "амбициозность"],
    "спеть": ["созревать", "поспевать"],
    "спех": ["спешка", "поспешность"],
    "спец": ["специалист", "шкраб", "профессионал", "дока", "мастер", "эксперт", "спецназовец"],
    "спецавтомашина": ["спецавтомобиль", "спецмашина", "спецавтотранспорт"],
    "спецавтомобиль": ["спецавтомашина", "спецмашина", "спецавтотранспорт"],
    "спецавтотранспорт": ["спецавтомашина", "спецавтомобиль", "спецмашина"],
    "спецгашение": ["специальное гашение"],
    "спецдеп": ["спецдепозитарий"],
    "спецдепозитарий": ["спецдеп"],
    "спецзвание": ["специальное звание"],
    "специализировав": ["специализировавши"],
    "специализировавши": ["специализировав"],
    "специалист": ["профессионал", "дока"],
    "специалистура": ["специалитет"],
    "специалитет": ["специалистура"],
    "специальная техника": ["спецтехника"],
    "специально": ["исключительно", "намеренно", "нарочно", "преднамеренно", "умышленно", "сознательно", "целенаправленно", "спецом"],
    "специальное звание": ["спецзвание"],
    "специальное предложение": ["спецпредложение"],
    "специальность": ["особость", "отрасль", "направление", "профессия"],
    "специальные права заимствования": ["спз", "сдр"],
    "специальный": ["особый", "необычный", "специализированный", "узкий", "узкофункциональный"],
    "специальный административный район": ["сар"],
    "специфика": ["особенность"],
    "специфицировав": ["специфицировавши"],
    "специфицировавши": ["специфицировав"],
    "специфически": ["особенным образом", "характерно"],
    "специфический": ["отличительный", "характерный", "особый", "своеобразный", "экстраординарный"],
    "специфичность": ["избирательность", "чувствительность"],
    "специфичный": ["высокоспецифичный", "индивидуальный", "неординарный", "неповторимый", "неповторяемый", "нестандартный", "нетрадиционный", "нетривиальный", "оригинальный", "особенный", "особый", "отличительный", "самобытный", "своеобразный", "своеобычный"],
    "специя": ["снадобье", "микстура", "приправа", "пряность"],
    "спецконтингент": ["зэк", "заключённый", "арестант"],
    "спецкор": ["специальный корреспондент", "спецкорреспондент"],
    "спецкорреспондент": ["спецкор"],
    "спецкостюм": ["спецодежда"],
    "спецмашина": ["спецавтомашина", "спецавтомобиль", "спецавтотранспорт"],
    "спецназовец": ["коммандос"],
    "спецовка": ["прозодежда", "спецуха"],
    "спецодежда": ["прозодежда", "спецовка", "спецуха"],
    "спецом": ["специально"],
    "спецпредложение": ["специальное предложение"],
    "спецприёмник": ["цип"],
    "спецпту": ["спецуха"],
    "спецсредство": ["специальное средство"],
    "спецтехника": ["специальная техника"],
    "спецуха": ["спецодежда", "спецовка", "спецшкола", "спецподготовка"],
    "спецыя": ["прыправа"],
    "спечатав": ["спечатавши"],
    "спечатавши": ["спечатав"],
    "спечатывав": ["спечатывавши"],
    "спечатывавши": ["спечатывав"],
    "спечь": ["испечь", "сплавить"],
    "спечься": ["испечься", "запечься", "напечься", "попечься", "загустеть", "соединиться", "обгореть", "обуглиться", "изжариться"],
    "спешив": ["спешивши"],
    "спешивав": ["спешивавши"],
    "спешивавши": ["спешивав"],
    "спешивши": ["спешив"],
    "спешка": ["поспешность", "торопливость"],
    "спешна": ["неадкладна"],
    "спешно": ["второпях", "поспешно", "наспех", "небрежно"],
    "спешный": ["быстрый", "скорый", "торопливый", "срочный"],
    "спз": ["специальные права заимствования", "сдр"],
    "спив": ["спивши"],
    "спивав": ["спивавши"],
    "спивавши": ["спивав"],
    "спивки": ["опивки"],
    "спивши": ["спив"],
    "спид": ["спидак", "вич"],
    "спид-метал": ["скоростной металл"],
    "спидоносица": ["спидозный"],
    "спидорак": ["пиздецома"],
    "спидофобский": ["спидофобный"],
    "спиды": ["амфетамин", "скорости"],
    "спизданув": ["спизданувши"],
    "спизданувши": ["спизданув"],
    "спиздев": ["спиздевши"],
    "спиздевши": ["спиздев"],
    "спиздив": ["спиздивши"],
    "спиздивши": ["спиздив"],
    "спизднув": ["спизднувши"],
    "спизднувши": ["спизднув"],
    "спизженный": ["украденный", "сворованный"],
    "спикав": ["спикавши"],
    "спикавши": ["спикав"],
    "спикер": ["громкоговоритель", "репродуктор", "динамик"],
    "спикировав": ["спикировавши"],
    "спикировавши": ["спикировав"],
    "спил": ["спиливание"],
    "спилив": ["спиливши"],
    "спиливав": ["спиливавши"],
    "спиливавши": ["спиливав"],
    "спиливши": ["спилив"],
    "спин-офф": ["вбоквел"],
    "спина": ["плечи", "тыл", "спинка"],
    "спинка": ["спина"],
    "спиннер": ["крутилка для рук", "фиджет-спиннер"],
    "спинномозговая жидкость": ["ликвор", "цереброспинальная жидкость"],
    "спинномозговой": ["цереброспинальный"],
    "спиногрыз": ["карапуз", "малыш", "короед", "эксплуататор"],
    "спинодержатель": ["аппарат ниропа", "прямодержатель ниропа", "прямодержатель"],
    "спинопокрышечный": ["спинотектальный"],
    "спиноцеллюлярный": ["эпидермоидный", "плоскоклеточный"],
    "спинулозизм": ["шиповатость"],
    "спионерив": ["спионеривши"],
    "спионеривши": ["спионерив"],
    "спирав": ["спиравши"],
    "спиравши": ["спирав"],
    "спиралевидный": ["спиралеобразный"],
    "спиралеобразный": ["спиралевидный", "спиральный"],
    "спирализация": ["конденсация"],
    "спирализовав": ["спирализовавши"],
    "спирализовавши": ["спирализовав"],
    "спирально": ["винтообразно", "по спирали"],
    "спиральный орган": ["кортиев орган"],
    "спирант": ["фрикатив"],
    "спиратив": ["спиративши"],
    "спиративши": ["спиратив"],
    "спиратировав": ["спиратировавши"],
    "спиратировавши": ["спиратировав"],
    "спиратить": ["сплагиатить"],
    "спирея": ["таволга"],
    "спиритизм": ["духоведение"],
    "спиритический": ["спиритский"],
    "спиритский": ["спиритический"],
    "спиритус": ["псили", "звательце", "тонкое придыхание"],
    "спирка": ["станция", "гара"],
    "спирография": ["спирометрия"],
    "спирометаболограф": ["метаболограф", "спирополиграф"],
    "спирт": ["алкоголь", "этиловый спирт", "этанол"],
    "спиртное": ["спиртной напиток", "спирт"],
    "спиртной напиток": ["алкогольный напиток"],
    "спиртовав": ["спиртовавши"],
    "спиртовавши": ["спиртовав"],
    "спиртовой": ["спиртной"],
    "спиртометрия": ["алкоголиметрия"],
    "спиртосодержащий": ["алкогольный", "спиртовой"],
    "спиртяга": ["спиртец"],
    "списав": ["списавши"],
    "списавши": ["списав"],
    "список": ["опись", "перечень", "перепись"],
    "списывав": ["списывавши"],
    "списывавши": ["списывав"],
    "списыванье": ["списывание"],
    "спитой": ["разбавленный", "испитой"],
    "спить": ["отпить", "отхлебнуть"],
    "спихивав": ["спихивавши"],
    "спихивавши": ["спихивав"],
    "спихнув": ["спихнувши"],
    "спихнувши": ["спихнув"],
    "спихнуть": ["столкнуть"],
    "спицевав": ["спицевавши"],
    "спицевавши": ["спицевав"],
    "спиця": ["дротик", "шпиця"],
    "спич": ["речь", "разговор"],
    "спичка": ["жердь"],
    "сплав": ["синтез"],
    "сплавав": ["сплававши"],
    "сплававши": ["сплавав"],
    "сплавив": ["сплавивши"],
    "сплавивши": ["сплавив"],
    "сплавина": ["зыбун"],
    "сплавляв": ["сплавлявши"],
    "сплавлявши": ["сплавляв"],
    "сплагиировав": ["сплагиировавши"],
    "сплагиировавши": ["сплагиировав"],
    "спланировав": ["спланировавши"],
    "спланировавши": ["спланировав"],
    "спланхноптоз": ["энтероптоз", "висцероптоз"],
    "спласировав": ["спласировавши"],
    "спласировавши": ["спласировав"],
    "сплачивав": ["сплачивавши"],
    "сплачивавши": ["сплачивав"],
    "спленит": ["лиенит"],
    "спленомегалия": ["мегалоспления"],
    "сплеснивав": ["сплеснивавши"],
    "сплеснивавши": ["сплеснивав"],
    "сплеснивать": ["соединять", "сплетать", "сращивать", "стращивать"],
    "сплеснить": ["сплести", "срастить", "стростить"],
    "сплеснув": ["сплеснувши"],
    "сплеснувши": ["сплеснув"],
    "сплести": ["заплести"],
    "сплетав": ["сплетавши"],
    "сплетавши": ["сплетав"],
    "сплетание": ["сплетение"],
    "сплетенка": ["сплетня"],
    "сплетенье": ["сплетение"],
    "сплетница": ["клеветница", "кляузница"],
    "сплетничав": ["сплетничавши"],
    "сплетничавши": ["сплетничав"],
    "сплетничество": ["судачество"],
    "сплетня": ["пересуды", "домысел"],
    "сплетённый": ["заплетённый"],
    "сплин": ["уныние", "хандра", "тоска", "печаль", "грусть"],
    "сплит-альбом": ["сплит"],
    "сплоив": ["сплоивши"],
    "сплоивши": ["сплоив"],
    "сплотив": ["сплотивши"],
    "сплотивши": ["сплотив"],
    "сплотить": ["объединить"],
    "сплотка": ["сплачивание"],
    "сплоховав": ["сплоховавши"],
    "сплоховавши": ["сплоховав"],
    "сплоховать": ["оплошать", "опростоволоситься", "дать маху"],
    "сплочённость": ["единство"],
    "сплошав": ["сплошавши"],
    "сплошавши": ["сплошав"],
    "сплошать": ["оплошать", "сплоховать"],
    "сплошной": ["плотный", "полнотелый", "густой", "непроходимый", "один", "безостановочный", "беспрерывный", "непрерывный", "тотальный", "поголовный"],
    "сплошность": ["беспрерывность", "непрерывность"],
    "сплутовав": ["сплутовавши"],
    "сплутовавши": ["сплутовав"],
    "сплыв": ["сплывши"],
    "сплывав": ["сплывавши"],
    "сплывавши": ["сплывав"],
    "сплывши": ["сплыв"],
    "сплюнув": ["сплюнувши"],
    "сплюнувши": ["сплюнув"],
    "сплюснув": ["сплюснувши"],
    "сплюснувши": ["сплюснув"],
    "сплюснутый": ["сплющенный", "расплющенный", "приплюснутый"],
    "сплюснуться": ["сплющиться"],
    "сплюх": ["сплюха"],
    "сплюшка": ["совка", "зорька"],
    "сплющенный": ["сплюснутый"],
    "сплющив": ["сплющивши"],
    "сплющивав": ["сплющивавши"],
    "сплющивавши": ["сплющивав"],
    "сплющивши": ["сплющив"],
    "сплющить": ["сплюснуть", "расплющить"],
    "сплющиться": ["сплюснуться"],
    "сплясав": ["сплясавши"],
    "сплясавши": ["сплясав"],
    "сплясать": ["станцевать"],
    "сплёвывав": ["сплёвывавши"],
    "сплёвывавши": ["сплёвывав"],
    "сплёвывать": ["выплёвывать", "плевать"],
    "сплёскивав": ["сплёскивавши"],
    "сплёскивавши": ["сплёскивав"],
    "сподвигнув": ["сподвигнувши"],
    "сподвигнувши": ["сподвигнув"],
    "сподвижник": ["соратник", "товарищ"],
    "сподвижничество": ["помощь", "содействие"],
    "сподличав": ["сподличавши"],
    "сподличавши": ["сподличав"],
    "сподобив": ["сподобивши"],
    "сподобивши": ["сподобив"],
    "сподобиться": ["удостоиться", "суметь", "смочь"],
    "сподобляв": ["сподоблявши"],
    "сподоблявши": ["сподобляв"],
    "сподобляться": ["удостаиваться"],
    "сподручник": ["подручный", "помощник", "пособник"],
    "сподручничав": ["сподручничавши"],
    "сподручничавши": ["сподручничав"],
    "сподручно": ["удобно", "ловко"],
    "сподручный": ["удобный"],
    "спозабыть": ["позабыть", "запамятовать"],
    "спозаранку": ["спозаранок", "с утра пораньше"],
    "спозаранок": ["спозаранку"],
    "спознав": ["спознавши"],
    "спознавав": ["спознававши"],
    "спознававши": ["спознавав"],
    "спознавать": ["узнавать", "опознавать", "распознавать"],
    "спознавши": ["спознав"],
    "споив": ["споивши"],
    "споивши": ["споив"],
    "спойлер": ["технический кандидат"],
    "спойлерив": ["спойлеривши"],
    "спойлеривши": ["спойлерив"],
    "спойлерный": ["спойлерский"],
    "спойлерский": ["спойлерный"],
    "спокойнее": ["спокойней"],
    "спокойней": ["спокойнее"],
    "спокойно": ["плавно", "мерно", "неподвижно", "тихо", "безмятежно", "бесстрастно", "невозмутимо", "легко", "запросто", "без труда"],
    "спокойной ночи": ["покойной ночи", "доброй ночи", "сладких снов", "приятных сновидений", "ночи покочи", "споки ноки"],
    "спокойность": ["спокойствие"],
    "спокойный": ["умиротворенный", "неподвижный", "вялый", "ленивый", "безмятежный", "уравновешенный", "сдержанный", "смиренный", "смирный", "тихий", "кроткий", "уютный", "удобный", "плавный"],
    "спокойствие": ["покой", "неподвижность", "порядок", "правопорядок", "безмятежность", "размеренность"],
    "спокон": ["издавна", "испокон", "испокон веку", "испокон веков", "традиционно"],
    "спокуха": ["спокойствие", "спокойно"],
    "сполагоря": ["без труда", "и заботы мало"],
    "споласкивав": ["споласкивавши"],
    "споласкивавши": ["споласкивав"],
    "сползав": ["сползавши"],
    "сползавши": ["сползав"],
    "сполитиковав": ["сполитиковавши"],
    "сполитиковавши": ["сполитиковав"],
    "сполна": ["полностью", "целиком"],
    "сполов": ["споловши"],
    "споловинив": ["споловинивши"],
    "споловинивши": ["споловинив"],
    "споловинить": ["уполовинить"],
    "споловши": ["сполов"],
    "сполоскав": ["сполоскавши"],
    "сполоскавши": ["сполоскав"],
    "сполоснув": ["сполоснувши"],
    "сполоснувши": ["сполоснув"],
    "сполоть": ["выполоть"],
    "сполох": ["набат", "всполох", "суматоха", "тревога", "переполох"],
    "сполошив": ["сполошивши"],
    "сполошивши": ["сполошив"],
    "сполука": ["речовина"],
    "спондилёз": ["спондилоз"],
    "спонсировав": ["спонсировавши"],
    "спонсировавши": ["спонсировав"],
    "спонсорство": ["меценатство"],
    "спонсорствовав": ["спонсорствовавши"],
    "спонсорствовавши": ["спонсорствовав"],
    "спонтанно": ["самопроизвольно", "неожиданно"],
    "спонтанность": ["самопроизвольность"],
    "спонтанный": ["самопроизвольный"],
    "спонтировав": ["спонтировавши"],
    "спонтировавши": ["спонтировав"],
    "спор": ["диспут", "дискуссия", "полемика"],
    "спорадически": ["нерегулярно", "случайным образом"],
    "спорадический": ["спорадичный", "нерегулярный", "эпизодический", "эпизодичный", "непостоянный", "случайный", "единичный"],
    "спорадичный": ["спорадический", "нерегулярный", "эпизодический", "эпизодичный", "непостоянный", "случайный", "единичный"],
    "спорив": ["споривши"],
    "споривши": ["спорив"],
    "спорить": ["соперничать"],
    "спорливый": ["вздорный", "сварливый", "любопрительный", "прекословный", "прительный"],
    "спорный": ["дискуссионный", "небесспорный", "проблематичный"],
    "споро": ["быстро", "успешно", "умело", "ловко", "сноровисто"],
    "споров": ["споровши"],
    "споровик": ["апикомплекс"],
    "споровши": ["споров"],
    "спорогенез": ["спорообразование"],
    "спорогоний": ["спорофит"],
    "споролистик": ["спорофилл", "спороносный лист"],
    "споротрихоз": ["ринокладиоз"],
    "спорофилл": ["споролистик", "спороносный лист"],
    "спорофит": ["растение"],
    "спорт-шик": ["спортшик"],
    "спортив": ["спортивши"],
    "спортивная игра": ["игровой вид спорта"],
    "спортивная площадка": ["спортплощадка"],
    "спортивно-военный": ["военно-спортивный"],
    "спортивный интерес": ["азарт", "от нечего делать", "просто так", "праздное любопытство"],
    "спортивный снаряд": ["снаряд"],
    "спортивши": ["спортив"],
    "спортинвентарь": ["спортивный инвентарь"],
    "спортинг-компакт": ["компакт-спортинг"],
    "спортить": ["испортить", "сделать женщиной", "порвать целку", "сломать целку", "трахнуть"],
    "спорткар": ["спортивный", "автомобиль"],
    "спортплощадка": ["спортивная площадка"],
    "спортрота": ["спортивная рота"],
    "спортсмен": ["атлет"],
    "спорхнув": ["спорхнувши"],
    "спорхнувши": ["спорхнув"],
    "спорынья": ["маточные рожки", "чёрные рожки", "ржанец"],
    "спорыш": ["горец птичий", "птичья греча"],
    "спорэндомикоз": ["гемиспороз"],
    "способ": ["метод"],
    "способ глагольного действия": ["способ  действия"],
    "способ действия": ["способ глагольного действия"],
    "способность": ["возможность", "умение", "талант", "дар", "дарование", "одарённость", "талантливость", "даровитость", "задатки"],
    "способный": ["одарённый", "талантливый", "могущий"],
    "способствовав": ["способствовавши"],
    "способствовавши": ["способствовав"],
    "способствовать": ["помогать", "пособлять", "подсоблять", "содействовать", "благоприятствовать"],
    "способствующий": ["помогающий"],
    "споспешествовав": ["споспешествовавши"],
    "споспешествовавши": ["споспешествовав"],
    "споспешествование": ["поспешествование", "содействие", "способствование", "помощь", "пособствование"],
    "споспешествовать": ["поспешествовать", "способствовать", "содействовать"],
    "спосылав": ["спосылавши"],
    "спосылавши": ["спосылав"],
    "споткнув": ["споткнувши"],
    "споткнувши": ["споткнув"],
    "спотыканье": ["спотыкание"],
    "спотыкаться": ["запинаться"],
    "спотыкаясь": ["запинаясь"],
    "спотыкливый": ["сбивчивый", "неровный", "заикающийся", "запинающийся"],
    "споуксмен": ["пресс-секретарь"],
    "спохабничав": ["спохабничавши"],
    "спохабничавши": ["спохабничав"],
    "спочин": ["спочинок"],
    "спочуття": ["почуття"],
    "спошествовав": ["спошествовавши"],
    "спошествовавши": ["спошествовав"],
    "справа": ["по правую руку"],
    "справедливоросс": ["справоросс"],
    "справедливость": ["беспристрастие", "беспристрастность", "непредвзятость"],
    "справедливый": ["беспристрастный", "честный", "оправданный", "законный", "верный", "истинный", "правильный"],
    "справив": ["справивши"],
    "справивши": ["справив"],
    "справиться": ["управиться", "сладить", "совладать", "осилить"],
    "справкомания": ["бюрократизм", "крючкотворство"],
    "справляв": ["справлявши"],
    "справлявши": ["справляв"],
    "справлять": ["устраивать", "приобретать"],
    "справлять нужду": ["отправлять естественные надобности"],
    "справоросс": ["эсер", "справедливоросс"],
    "справочник": ["компендиум"],
    "спраздновав": ["спраздновавши"],
    "спраздновавши": ["спраздновав"],
    "спрашивав": ["спрашивавши"],
    "спрашивавши": ["спрашивав"],
    "спрашивать": ["вопрошать", "задавать вопрос", "просить"],
    "спрей": ["пульверизатор", "разбрызгиватель"],
    "спрелюбодействовав": ["спрелюбодействовавши"],
    "спрелюбодействовавши": ["спрелюбодействовав"],
    "спрелюбодействовать": ["изменить"],
    "спрессовав": ["спрессовавши"],
    "спрессовавши": ["спрессовав"],
    "спрессовывав": ["спрессовывавши"],
    "спрессовывавши": ["спрессовывав"],
    "спрессовывать": ["прессовать", "сжимать", "уплотнять"],
    "спрингер": ["английский", "спрингер-спаниель"],
    "спринклер": ["разбрызгиватель", "ороситель", "поливалка"],
    "спринцевав": ["спринцевавши"],
    "спринцевавши": ["спринцевав"],
    "спринцевать": ["шпринцевать"],
    "спринцовка": ["клизма", "спринцевание"],
    "спробовав": ["спробовавши"],
    "спробовавши": ["спробовав"],
    "спровадив": ["спровадивши"],
    "спровадивши": ["спровадив"],
    "спровадить": ["выпроводить"],
    "спроваживав": ["спроваживавши"],
    "спроваживавши": ["спроваживав"],
    "спроваживать": ["выпроваживать"],
    "спроворив": ["спроворивши"],
    "спроворивши": ["спроворив"],
    "спровориться": ["умудриться"],
    "спровоцировав": ["спровоцировавши"],
    "спровоцировавши": ["спровоцировав"],
    "спровоцировать": ["сподвигнуть"],
    "спрогнозировав": ["спрогнозировавши"],
    "спрогнозировавши": ["спрогнозировав"],
    "спродюсировав": ["спродюсировавши"],
    "спродюсировавши": ["спродюсировав"],
    "спроектировав": ["спроектировавши"],
    "спроектировавши": ["спроектировав"],
    "спроецировав": ["спроецировавши"],
    "спроецировавши": ["спроецировав"],
    "спроказив": ["спроказивши"],
    "спроказивши": ["спроказив"],
    "спросив": ["спросивши"],
    "спросить": ["осведомиться", "поинтересоваться", "вопросить", "попросить", "потребовать"],
    "спросонков": ["со сна", "впросонках", "спросонья"],
    "спросонку": ["спросонок", "спросонья"],
    "спросонок": ["спросонья", "спросонку"],
    "спросонья": ["спросонок", "спросонку"],
    "спрофилировав": ["спрофилировавши"],
    "спрофилировавши": ["спрофилировав"],
    "спрохвала": ["полегоньку"],
    "спружинив": ["спружинивши"],
    "спружинивши": ["спружинив"],
    "спрут": ["осьминог", "кальмар"],
    "спрыгивав": ["спрыгивавши"],
    "спрыгивавши": ["спрыгивав"],
    "спрыгивать": ["соскакивать"],
    "спрыгнув": ["спрыгнувши"],
    "спрыгнувши": ["спрыгнув"],
    "спрыгнуть": ["соскочить"],
    "спрыгнуть с ума": ["сойти с ума"],
    "спрыскивав": ["спрыскивавши"],
    "спрыскивавши": ["спрыскивав"],
    "спрыснув": ["спрыснувши"],
    "спрыснувши": ["спрыснув"],
    "спрягав": ["спрягавши"],
    "спрягавши": ["спрягав"],
    "спряженье": ["спряжение"],
    "спрямив": ["спрямивши"],
    "спрямивши": ["спрямив"],
    "спрямить": ["выпрямить"],
    "спрямление": ["выпрямление", "полное усечение"],
    "спрямляв": ["спрямлявши"],
    "спрямлявши": ["спрямляв"],
    "спрямлять": ["выпрямлять"],
    "спрянув": ["спрянувши"],
    "спрянувши": ["спрянув"],
    "спрятав": ["спрятавши"],
    "спрятавши": ["спрятав"],
    "спрятанный": ["заныканный"],
    "спрятать": ["скрыть", "укрыть", "упрятать", "запрятать", "припрятать"],
    "спрятать агитатора": ["прикусить язык", "прикусить язычок", "язык прикусить", "язычок прикусить", "завалить ебало", "ебало завалить"],
    "спрятаться": ["скрыться", "укрыться"],
    "спс": ["спасибо"],
    "спугивав": ["спугивавши"],
    "спугивавши": ["спугивав"],
    "спугнув": ["спугнувши"],
    "спугнувши": ["спугнув"],
    "спурт": ["рывок"],
    "спуртанув": ["спуртанувши"],
    "спуртанувши": ["спуртанув"],
    "спуртовав": ["спуртовавши"],
    "спуртовавши": ["спуртовав"],
    "спускав": ["спускавши"],
    "спускавши": ["спускав"],
    "спускать": ["опускать"],
    "спускаться": ["опускаться", "снижаться"],
    "спускной": ["сливной"],
    "спусковой крючок": ["спуск", "гашетка", "курок", "собачка", "триггер"],
    "спустив": ["спустивши"],
    "спустивши": ["спустив", "опустив"],
    "спустить с рук": ["продать", "сбыть", "сжить", "растратить", "расточить", "простить", "спустить на тормозах"],
    "спуститься": ["опуститься", "снизиться"],
    "спустя": ["через"],
    "спустя рукава": ["халатно", "с ленцой"],
    "спутав": ["спутавши"],
    "спутавши": ["спутав"],
    "спутанность сознания": ["нарушение сознания", "помрачение сознания"],
    "спутаться": ["перепутаться", "запутаться", "сцепиться", "смешаться"],
    "спутник": ["попутчик", "сопровождающий", "сопутник", "луна", "искусственный спутник"],
    "спутывав": ["спутывавши"],
    "спутывавши": ["спутывав"],
    "спутываться": ["перепутываться", "запутываться", "сцепляться", "смешиваться"],
    "спьяна": ["навеселе", "под хмельком", "в подпитии", "подшофе", "под банкой", "вполпьяна", "под газом"],
    "спьяну": ["навеселе", "под хмельком"],
    "спялив": ["спяливши"],
    "спяливав": ["спяливавши"],
    "спяливавши": ["спяливав"],
    "спяливши": ["спялив"],
    "спятив": ["спятивши"],
    "спятивши": ["спятив"],
    "спятивший": ["рехнувшийся"],
    "спятить": ["сдвинуть", "попятить"],
    "спячка": ["гибернация", "зимняя спячка", "эстивация", "летняя спячка", "диапауза"],
    "спящая": ["дремлющая"],
    "спёртый": ["тесный", "душный", "несвежий", "тяжёлый"],
    "спёрши": ["сперев"],
    "срабатывав": ["срабатывавши"],
    "срабатывавши": ["срабатывав"],
    "срабатывать": ["действовать"],
    "сработав": ["сработавши"],
    "сработавши": ["сработав"],
    "срав": ["сравши"],
    "сравненье": ["сравнение"],
    "сравнив": ["сравнивши"],
    "сравнивав": ["сравнивавши"],
    "сравнивавши": ["сравнивав"],
    "сравнивание": ["сопоставление", "сравнение", "сверка"],
    "сравнивши": ["сравнив"],
    "сравнительная степень": ["компаратив"],
    "сравнительно с": ["по сравнению с", "в сравнении с"],
    "сравнительно-историческое языкознание": ["компаративистика"],
    "сравнительный": ["сопоставительный", "компаративный", "относительный", "некоторый"],
    "сравнить": ["сопоставить", "приравнять", "уподобить"],
    "сравнить жопу с пальцем": ["сравнить хуй с пальцем", "сравнить божий дар с яичницей", "сравнить вилку с бутылкой"],
    "сравнить хуй с пальцем": ["сравнить божий дар с яичницей", "сравнить вилку с бутылкой", "сравнить жопу с пальцем"],
    "сравняв": ["сравнявши"],
    "сравнявши": ["сравняв"],
    "сравнять": ["уравнять"],
    "сравши": ["срав"],
    "сражав": ["сражавши"],
    "сражавши": ["сражав"],
    "сражать": ["поражать", "губить", "потрясать"],
    "сражаться": ["биться", "воевать", "избивать", "бить"],
    "сражение": ["сраженье", "битва", "баталия", "бой"],
    "сразив": ["сразивши"],
    "сразивши": ["сразив"],
    "сразить": ["поразить", "погубить", "потрясти", "убить"],
    "сразу": ["зараз", "единовременно", "моментально", "одним махом", "тотчас", "сейчас же", "тут же"],
    "срака": ["афедрон", "зад", "сидальница", "ягодица", "ягодицы", "попа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея", "гузло"],
    "сракопад": ["ожеледь", "ожеледиця"],
    "сральник": ["сральня"],
    "срам": ["сором", "интимное место", "поганое место"],
    "срамец": ["страмец"],
    "срамив": ["срамивши"],
    "срамивши": ["срамив"],
    "срамная": ["чикольтоджек", "засцыха"],
    "срамословив": ["срамословивши"],
    "срамословивши": ["срамословив"],
    "срамословить": ["сквернословить"],
    "срамословье": ["срамословие"],
    "срамота": ["срам"],
    "срамотив": ["срамотивши"],
    "срамотивши": ["срамотив"],
    "срандель": ["задница", "зад", "жопа"],
    "сраный": ["ничтожный"],
    "сраный ковбой": ["пиндос"],
    "срань": ["дрянь", "сволочь"],
    "срастание": ["сращение", "сращивание"],
    "срастив": ["срастивши"],
    "срастивши": ["срастив"],
    "срастись": ["слиться", "удаться"],
    "срастить": ["склеить", "сложить", "восстановить"],
    "срать хотеть": ["плевать хотеть"],
    "срать хотеть с большой колокольни": ["срать хотеть", "срать хотеть с высокой колокольни", "срать хотеть с высокой ёлки", "срать хотеть с останкинской башни"],
    "сраться": ["обсираться", "обосраться", "обкакаться", "какаться", "обделаться", "облажаться", "наложить в штаны"],
    "срач": ["бардак", "хлев", "помойка", "кавардак", "ругань", "перепалка", "перебранка", "ссора", "грызня", "склока", "свара", "флейм", "холивар"],
    "срачица": ["сорочка"],
    "сращенье": ["сращение"],
    "сращивав": ["сращивавши"],
    "сращивавши": ["сращивав"],
    "сращённая ламель": ["срощенная ламель"],
    "сращённый": ["срощенный", "сращёный"],
    "сращённый мебельный щит": ["мебельный щит"],
    "сращённый щит": ["срощенный щит"],
    "сращёный": ["срощенный", "сращённый"],
    "срв": ["социалистическая республика вьетнам", "вьетнам"],
    "среагировав": ["среагировавши"],
    "среагировавши": ["среагировав"],
    "сребрив": ["сребривши"],
    "сребривши": ["сребрив"],
    "сребро": ["серебро"],
    "сребролистый": ["сребролистный"],
    "сребролюбие": ["алчность"],
    "среда": ["окружение", "вещество", "материал", "слой"],
    "среда обитания": ["естественная среда", "экосистема", "биотоп"],
    "среди": ["внутри", "посреди", "средь", "середи", "серед", "середь", "между"],
    "средиземный": ["средиземноморский"],
    "средина": ["середина"],
    "срединный": ["серединный", "центральный", "медианный", "рядовой", "заурядный"],
    "средне": ["так себе", "ничего", "фифти-фифти", "на троечку"],
    "средне-сухой": ["среднесухой"],
    "среднеазиатский": ["центральноазиатский"],
    "среднеанглийский": ["среднеанглийский язык"],
    "средневековье": ["средние века"],
    "средневерхненемецкий": ["средневерхненемецкий язык"],
    "среднегреческий": ["среднегреческий язык", "византийский"],
    "среднегреческий язык": ["византийский", "язык"],
    "среднее общее образование": ["среднее полное образование"],
    "средней руки": ["заурядный", "серёдка руки"],
    "среднеквадратический": ["среднеквадратичный"],
    "среднеквадратичный": ["среднеквадратический"],
    "среднекембрийский": ["акадский"],
    "среднекорейский": ["среднекорейский язык"],
    "среднеспинка": ["мезонотум"],
    "среднестатистический": ["средний"],
    "среднесухой": ["средне-сухой"],
    "среднефранцузский": ["среднефранцузский язык"],
    "средние века": ["средневековье"],
    "средний": ["промежуточный", "срединный", "усреднённый"],
    "средний залог": ["медиальный залог", "медий"],
    "средняя": ["средняя сопка"],
    "средняя азия": ["передняя азия"],
    "средняя школа": ["старшая школа", "основная школа"],
    "средостенье": ["средостение"],
    "средоточие": ["центр", "фокус"],
    "средство измерений": ["си"],
    "средство индивидуальной защиты": ["сиз"],
    "средство индивидуальной защиты кожи": ["сизк"],
    "средство массовой информации": ["сми", "четвёртая власть"],
    "средство передвижения": ["транспортное средство"],
    "средь": ["среди"],
    "средь бела дня": ["среди бела дня"],
    "срежиссировав": ["срежиссировавши"],
    "срежиссировавши": ["срежиссировав"],
    "срезав": ["срезавши"],
    "срезавши": ["срезав"],
    "срезанно": ["коротко"],
    "срезанный": ["отрезанный", "обрезанный", "скошенный", "убранный", "сжатый", "оборванный"],
    "срезать": ["опилить", "срубить"],
    "срезать фонтан": ["закрыть фонтан", "заткнуть фонтан"],
    "срезонировав": ["срезонировавши"],
    "срезонировавши": ["срезонировав"],
    "срезывав": ["срезывавши"],
    "срезывавши": ["срезывав"],
    "срепетировав": ["срепетировавши"],
    "срепетировавши": ["срепетировав"],
    "срепетовав": ["срепетовавши"],
    "срепетовавши": ["срепетовав"],
    "сретав": ["сретавши"],
    "сретавши": ["сретав"],
    "сретать": ["встречать"],
    "сретение": ["сретенье"],
    "сретение господне": ["сретенье господне", "сретение", "сретенье"],
    "сретенный": ["встреченный"],
    "сретенье": ["сретение", "встречанье"],
    "сретенье господне": ["сретение господне", "сретенье"],
    "сретив": ["сретивши"],
    "сретивши": ["сретив"],
    "сретивший": ["встретивший"],
    "сретить": ["встретить"],
    "сретиться": ["встретиться"],
    "сретне": ["срете"],
    "сречав": ["сречавши"],
    "сречавши": ["сречав"],
    "сречать": ["встречать"],
    "срикошетив": ["срикошетивши"],
    "срикошетивши": ["срикошетив"],
    "срикошетировав": ["срикошетировавши"],
    "срикошетировавши": ["срикошетировав"],
    "срисовав": ["срисовавши"],
    "срисовавши": ["срисовав"],
    "срисовывав": ["срисовывавши"],
    "срисовывавши": ["срисовывав"],
    "срифмовав": ["срифмовавши"],
    "срифмовавши": ["срифмовав"],
    "сробев": ["сробевши"],
    "сробевши": ["сробев"],
    "сробив": ["сробивши"],
    "сробивши": ["сробив"],
    "сробить": ["сделать", "создать"],
    "сровнив": ["сровнивши"],
    "сровнивши": ["сровнив"],
    "сровняв": ["сровнявши"],
    "сровнявши": ["сровняв"],
    "сровнять с землёй": ["стереть с лица земли"],
    "сродни": ["подобно"],
    "сроднив": ["сроднивши"],
    "сроднивши": ["сроднив"],
    "сродник": ["родственник", "родич", "сородич", "сродственник"],
    "сродница": ["родственница"],
    "сродственник": ["родственник", "сродственница"],
    "сроду": ["никогда"],
    "сродясь": ["отродясь", "сроду"],
    "сроив": ["сроивши"],
    "сроивши": ["сроив"],
    "срок": ["промежуток", "период"],
    "срок годности": ["срок хранения", "срок жизни"],
    "срок хранения": ["срок годности"],
    "сронив": ["сронивши"],
    "сронивши": ["сронив"],
    "срочник": ["солдат-срочник"],
    "срочница": ["призывница"],
    "срочно": ["немедленно", "спешно", "экстренно", "безотлагательно"],
    "срочно-мальпостное сообщение": ["мальпостное сообщение"],
    "срочность": ["неотложность", "неотлагательность", "безотложность", "безотлагательность", "экстренность", "немедленность", "спешность", "сиюминутность"],
    "срочный": ["безотлагательный", "немедленный", "неотложный", "экстренный"],
    "срощенный": ["сращённый"],
    "срубав": ["срубавши"],
    "срубавши": ["срубав"],
    "срубец": ["срубик"],
    "срубив": ["срубивши"],
    "срубивши": ["срубив"],
    "срубик": ["срубец"],
    "срубить": ["снести"],
    "срубный": ["срубовый"],
    "срун": ["серун", "поносник", "засранец", "пакостник", "паскудник", "вредитель", "предатель"],
    "сручный": ["сподручный", "споручный", "сноровчивый", "сноровитый"],
    "срывав": ["срывавши"],
    "срывавши": ["срывав"],
    "срыванье": ["срывание"],
    "срыву": ["срывка"],
    "срывши": ["срыв"],
    "срыгивав": ["срыгивавши"],
    "срыгивавши": ["срыгивав"],
    "срыгнув": ["срыгнувши"],
    "срыгнувши": ["срыгнув"],
    "срыгнуть": ["отрыгнуть", "сблевать", "выблевать", "вырвать"],
    "срыть": ["скопать"],
    "срядив": ["срядивши"],
    "срядивши": ["срядив"],
    "сряду": ["кряду", "подряд", "беспрерывно"],
    "сряжав": ["сряжавши"],
    "сряжавши": ["сряжав"],
    "сс": ["совместный сон"],
    "ссавши": ["ссав"],
    "ссадив": ["ссадивши"],
    "ссадивши": ["ссадив"],
    "ссаживав": ["ссаживавши"],
    "ссаживавши": ["ссаживав"],
    "ссака": ["моча", "урина", "писка", "писька", "пиписка", "пиписька", "писун", "писюн", "писуля"],
    "ссаки": ["моча"],
    "ссаный": ["уссаный", "сцаный", "ссаный-прессаный", "ссаный-перессаный"],
    "ссасывав": ["ссасывавши"],
    "ссасывавши": ["ссасывав"],
    "ссати": ["смоктати"],
    "ссать": ["мочиться", "писать", "справляться по нужде", "ходить по-малому", "облегчаться", "оправляться", "отливать", "делать пи-пи", "сикать", "ходить до ветру", "ссять", "сцать", "трусить", "пугаться", "бояться"],
    "ссать против ветра": ["против ветра ссать"],
    "ссаться": ["писаться", "бояться", "страшиться"],
    "ссекав": ["ссекавши"],
    "ссекавши": ["ссекав"],
    "ссекать": ["отсекать"],
    "сселив": ["сселивши"],
    "сселивши": ["сселив"],
    "сселяв": ["сселявши"],
    "сселявши": ["сселяв"],
    "ссесться": ["сесть"],
    "ссечь": ["отсечь"],
    "ссобойка": ["собойка", "забутовка", "припарок", "тормозок"],
    "ссовав": ["ссовавши"],
    "ссовавши": ["ссовав"],
    "ссовывав": ["ссовывавши"],
    "ссовывавши": ["ссовывав"],
    "ссора": ["распря", "раздор", "склока", "ругачка", "свара"],
    "ссорив": ["ссоривши"],
    "ссоривши": ["ссорив"],
    "ссориться": ["враждовать", "браниться", "ругаться", "собачиться", "лаяться"],
    "ссорщик": ["задира", "забияка", "склочник"],
    "ссосав": ["ссосавши"],
    "ссосавши": ["ссосав"],
    "сср": ["советская социалистическая республика"],
    "ссрля": ["бас"],
    "ссс": ["тише", "ш-ш", "тс", "тсс", "тш", "тш-ш-ш-ш", "чш"],
    "ссср": ["советский союз", "советская власть", "шестая часть суши", "край непуганых идиотов", "страна непуганых идиотов", "страна вечнозелёных помидоров", "софья власьевна", "нерушимый", "эсэсэрия", "совдепия", "советы"],
    "ссу": ["студсамоуправление"],
    "ссуда": ["заём", "одалживание", "кредит"],
    "ссудив": ["ссудивши"],
    "ссудивши": ["ссудив"],
    "ссудить": ["одолжить", "одалживать"],
    "ссудно-сберегательный": ["ссудо-сберегательный", "ссудосберегательный"],
    "ссудополучатель": ["ссудоприниматель"],
    "ссудоприниматель": ["ссудополучатель"],
    "ссужав": ["ссужавши"],
    "ссужавши": ["ссужав"],
    "ссужать": ["давать в долг", "давать взаймы"],
    "ссуживав": ["ссуживавши"],
    "ссуживавши": ["ссуживав"],
    "ссуживать": ["ссужать"],
    "ссунув": ["ссунувши"],
    "ссунувши": ["ссунув"],
    "ссутулив": ["ссутуливши"],
    "ссутуливши": ["ссутулив"],
    "ссучив": ["ссучивши"],
    "ссучивав": ["ссучивавши"],
    "ссучивавши": ["ссучивав"],
    "ссучивши": ["ссучив"],
    "ссущий": ["писающий", "мочащийся"],
    "ссыкливый": ["трусливый", "малодушный", "пугливый", "боязливый"],
    "ссыкотно": ["очково", "сцыкотно"],
    "ссыкотный": ["пугливый", "трусливый", "ссыкливый"],
    "ссыкун": ["энуретик", "зассанец", "зассыха", "зассыка", "трус", "трусишка", "секундей", "ссыкло", "хороняка", "муравей"],
    "ссылав": ["ссылавши"],
    "ссылавши": ["ссылав"],
    "ссылка": ["высылка", "изгнание"],
    "ссыль": ["сцыль"],
    "ссыльнопоселенец": ["изгнанный"],
    "ссыпав": ["ссыпавши"],
    "ссыпавши": ["ссыпав"],
    "ссяв": ["ссявши"],
    "ссявши": ["ссяв"],
    "ссять": ["ссать"],
    "стаб": ["болванка"],
    "стабилизация": ["регулирование", "упрочнение", "поддержание"],
    "стабилизировав": ["стабилизировавши"],
    "стабилизировавши": ["стабилизировав"],
    "стабилизовав": ["стабилизовавши"],
    "стабилизовавши": ["стабилизовав"],
    "стабилитрон": ["диод зенера"],
    "стабильно": ["стойко", "устойчиво", "неизменно", "постоянно"],
    "стабильность": ["устойчивость", "постоянность", "постоянство", "неизменность", "неизменяемость", "прочность", "стабилизец", "равновесие", "равновесность"],
    "стабильный": ["постоянный", "устойчивый"],
    "стабунив": ["стабунивши"],
    "стабунивав": ["стабунивавши"],
    "стабунивавши": ["стабунивав"],
    "стабунивши": ["стабунив"],
    "ставав": ["стававши"],
    "стававши": ["ставав"],
    "ставать": ["хватать"],
    "ставень": ["ставня"],
    "ставец": ["миска", "чашка", "поставец", "светец"],
    "ставив": ["ставивши"],
    "ставивши": ["ставив"],
    "ставить": ["поднимать"],
    "ставить в известность": ["оповещать", "сообщать", "информировать"],
    "ставить в тупик": ["приводить в тупик"],
    "ставить к стенке": ["приговаривать к расстрелу", "расстреливать"],
    "ставленник": ["креатура"],
    "ставливав": ["ставливавши"],
    "ставливавши": ["ставливав"],
    "ставливать": ["устанавливать"],
    "ставной невод": ["ставник"],
    "ставный": ["ставной"],
    "ставня": ["ставень"],
    "ставочка": ["ставка"],
    "ставропигия": ["ставропигиальный монастырь"],
    "ставрополец": ["ставропольчанин"],
    "ставрополь": ["ставрополь кавказский", "ворошиловск", "тольятти", "ставрополь-на-волге", "ставрополь волжский"],
    "ставрополье": ["ставропольский край"],
    "ставропольский край": ["ставрополье"],
    "ставши": ["став"],
    "стагнация": ["застой", "загнивание", "регресс"],
    "стагнировав": ["стагнировавши"],
    "стагнировавши": ["стагнировав"],
    "стадиальность": ["поэтапность"],
    "стадий": ["стадия"],
    "стадийный": ["стадиальный"],
    "стадик": ["стадион", "стедик"],
    "стадионный": ["ристалищный"],
    "стадиться": ["стаиться", "сходиться", "объединиться"],
    "стадия": ["этап", "фаза", "ступень", "стадий"],
    "стадный инстинкт": ["стадность"],
    "стадонга": ["стаконга"],
    "стажары": ["плеяды"],
    "стажер": ["стажерка", "стажист", "стажування"],
    "стажерка": ["стажистка"],
    "стажировав": ["стажировавши"],
    "стажировавши": ["стажировав"],
    "стажирование": ["стажировка"],
    "стажировать": ["стажироваться"],
    "стажистка": ["стажёрка"],
    "стажёр": ["практикант"],
    "стаивав": ["стаивавши"],
    "стаивавши": ["стаивав"],
    "стаиться": ["стадиться"],
    "стайка": ["хлев"],
    "стайл": ["стиль"],
    "стак": ["тяфтак", "ярмакфтома", "питнефтома"],
    "стака": ["аф тёждя"],
    "стакан": ["гильза", "обезьянник"],
    "стакаться": ["стакнуться"],
    "стакнуться": ["стакаться"],
    "стаконга": ["стадонга"],
    "сталагнат": ["сталактон", "колонна"],
    "сталактит": ["мукарна"],
    "сталин": ["коба"],
    "сталинабад": ["душанбе", "дюшамбе"],
    "сталинаул": ["атланаул", "ленинаул", "мескеты"],
    "сталинварош": ["дунауйварош"],
    "сталинград": ["волгоград", "царицын"],
    "сталинец": ["сталинист"],
    "сталинизм": ["сталинщина"],
    "сталинир": ["сталинири"],
    "сталинири": ["сталинир"],
    "сталиниси": ["хашури"],
    "сталинист": ["сталинец"],
    "сталино": ["донецк", "юзовка"],
    "сталинская конституция": ["конституция победившего социализма"],
    "сталинский план преобразования природы": ["великий план преобразования природы"],
    "сталинщина": ["сталинизм"],
    "сталировав": ["сталировавши"],
    "сталировавши": ["сталировав"],
    "сталкеринг": ["сталкерство", "сталкинг"],
    "сталкерство": ["сталкинг", "сталкеринг", "преследование"],
    "сталкивав": ["сталкивавши"],
    "сталкивавши": ["сталкивав"],
    "сталкинг": ["сталкерство", "сталкеринг", "преследование"],
    "стальной": ["сталелитейный", "сталеплавильный", "металлургический", "серый", "металлический", "железный", "мощный", "крепкий"],
    "стальной шлем": ["штальхельм"],
    "стальные яйца": ["железные яйца", "чугунные яйца", "титановые яйца"],
    "стамбул": ["константинополь", "бизант", "визант", "цареград"],
    "стамеска": ["гранильник"],
    "стамс": ["стафтомс", "петфтамс", "стамс ланга"],
    "стамуха": ["торос", "ставуха"],
    "стан": ["туловище", "корпус", "торс", "тело"],
    "станавливав": ["станавливавши"],
    "станавливавши": ["станавливав"],
    "стандарт": ["норма"],
    "стандартизация": ["унификация", "нивелировка", "обезличивание"],
    "стандартизировав": ["стандартизировавши"],
    "стандартизировавши": ["стандартизировав"],
    "стандартизировать": ["стандартизовать"],
    "стандартизовав": ["стандартизовавши"],
    "стандартизовавши": ["стандартизовав"],
    "стандартизовать": ["стандартизировать"],
    "стандартный": ["шаблонный", "трафаретный", "типовой"],
    "стане жа": ["тяфта жа"],
    "станислав": ["стас", "стася", "стасик", "стасян"],
    "станислава": ["стася"],
    "станица луганская": ["станично-луганское", "косиорово"],
    "станнан": ["моностаннан", "станнометан"],
    "станнин": ["оловянный колчедан"],
    "станнум": ["олово"],
    "становав": ["становавши"],
    "становавши": ["становав"],
    "становив": ["становивши"],
    "становивши": ["становив"],
    "становить": ["ставить"],
    "становиться": ["вставать", "умещаться", "размещаться", "помещаться"],
    "становище": ["привал"],
    "становление": ["формирование", "образование", "стояние", "постановка"],
    "становой хребет": ["позвоночник"],
    "становье": ["привал"],
    "станок": ["машина", "станина", "лафет", "установка"],
    "станок с чпу": ["станок чпу"],
    "станцевав": ["станцевавши"],
    "станцевавши": ["станцевав"],
    "станционный": ["вокзальный"],
    "станция": ["остановка", "точка", "пункт", "вокзал", "узел", "пост", "установка"],
    "станяк": ["тяфтак"],
    "стапливав": ["стапливавши"],
    "стапливавши": ["стапливав"],
    "стаптывав": ["стаптывавши"],
    "стаптывавши": ["стаптывав"],
    "стара-планина": ["балканы"],
    "старателен": ["прилежен", "усърден"],
    "старатель": ["рачитель", "ревнитель", "попечитель", "золотодобытчик"],
    "старательница": ["золотодобытчица"],
    "старательно": ["прилежно", "тщательно", "усидчиво", "усердно"],
    "старательность": ["прилежание", "усердие"],
    "старательный": ["прилежный", "усидчивый", "трудолюбивый", "радетельный", "тщательный"],
    "старатися": ["намагатися", "силкуватися", "турбуватися", "стягатися"],
    "стараться": ["усердствовать", "пытаться", "стремиться"],
    "старая дева": ["вековуха", "вековушка", "девуниха", "домовуха", "браковка", "перезрелка", "перестарка", "старка", "однокосая"],
    "старая кочерга": ["старая ведьма", "старая клюшка", "старая кошёлка", "чёртова кочерга", "чёртова перечница"],
    "старая кошёлка": ["старая перечница"],
    "старая перечница": ["старая кошёлка"],
    "старая песочница": ["развалина", "старый пень", "старый пердун", "старая перечница", "старая карга", "старая ведьма", "старая пердунья"],
    "старев": ["старевши"],
    "старевши": ["старев"],
    "старейшинствовав": ["старейшинствовавши"],
    "старейшинствовавши": ["старейшинствовав"],
    "старенье": ["старение"],
    "старенький": ["старый"],
    "стареть": ["стареться", "стариться", "устаревать"],
    "стареться": ["стареть", "стариться"],
    "старец": ["старик"],
    "старив": ["старивши"],
    "старивши": ["старив"],
    "стариган": ["старигань"],
    "старикан": ["старик"],
    "старикашка": ["старичок", "старый пердун"],
    "стариковство": ["старость", "дедовщина"],
    "стариковщина": ["дедовщина"],
    "старина": ["былина"],
    "старинный": ["древний", "старый", "давний", "стародавний", "давно прошедший", "археологический", "исконный", "архаический", "старомодный", "антикварный"],
    "старинщик": ["антиквар", "старьёвщик", "фурильщик", "подфурник"],
    "стариться": ["стареть"],
    "старичишка": ["старикашка"],
    "старичонко": ["старичок", "старинушка", "старик"],
    "старлей": ["старший лейтенант"],
    "старлетка": ["звёздочка"],
    "старновав": ["старновавши"],
    "старновавши": ["старновав"],
    "старовер": ["старообрядец", "раскольник", "консерватор", "ретроград"],
    "староверский": ["староверческий"],
    "старого покроя": ["старой закалки", "старомодный", "человек старого покроя"],
    "стародавний": ["давний"],
    "старожил": ["коренной житель", "ветеран", "автохтон", "абориген", "казак", "первопроходец"],
    "старожилый": ["старожильский"],
    "старожильский": ["старожильческий"],
    "старожильческий": ["старожильский"],
    "старозапашный": ["старопахотный"],
    "старомодно": ["архаично", "допотопно", "несовременно", "устарело"],
    "старомодный": ["старорежимный", "стародавний"],
    "старообразный": ["староватый", "постарелый"],
    "старообрядец": ["старовер", "раскольник"],
    "старообрядский": ["старообрядческий"],
    "старообрядческий": ["старообрядский"],
    "старообрядчество": ["древлеправославие"],
    "старосветский": ["старозаветный"],
    "старославянский": ["древнеславянский", "староболгарский", "древнеболгарский", "древнецерковнославянский"],
    "старославянский язык": ["старослав"],
    "старослужащий": ["старослуживый", "дед"],
    "староство": ["предводительство", "начальствование"],
    "старость": ["преклонные годы", "преклонные лета", "преклонный возраст", "престарелость", "ветхость", "древность", "дряхлость", "изношенность", "обветшалость"],
    "старпом": ["чиф"],
    "старпёрский": ["стариковский", "старческий"],
    "старт": ["запуск", "стартовая площадка"],
    "стартапер": ["стартаповец", "стартапщик"],
    "стартовав": ["стартовавши"],
    "стартовавши": ["стартовав"],
    "стартовать": ["брать старт", "взять старт", "взлетать", "взлететь", "полететь", "начинаться", "начаться"],
    "стартёр": ["пускатель"],
    "старуха": ["старушка", "старушонка", "бабка"],
    "старушенция": ["старуха", "старушка", "бабка", "бабушка", "бабулька", "бабуська"],
    "старуший": ["старушечий"],
    "старушка": ["бабушка", "бабулька", "бабусенька", "бабуська", "старая", "старушенция"],
    "старшак": ["старшеклассник"],
    "старшая сестра": ["старшая"],
    "старший": ["старый", "древний", "высокий", "старослужащий", "почтенный", "значимый", "достойный", "уважаемый", "выпускной"],
    "старший лейтенант": ["старлей"],
    "старшинствовав": ["старшинствовавши"],
    "старшинствовавши": ["старшинствовав"],
    "старшой": ["старший", "главный"],
    "старый": ["пожилой", "изношенный", "знакомый", "устаревший", "древний", "бывший", "прежний"],
    "старый город": ["старушка"],
    "старый новый год": ["новый год"],
    "старый пердун": ["старикашка", "старикан", "старый пень", "старый сыч", "старый хер", "старый хрен", "старпер", "старый хуй"],
    "старый салтов": ["салтов"],
    "старь": ["старьё"],
    "старьё": ["рухлядь", "ветошь", "старичьё"],
    "старьёвщик": ["тряпичник", "старьевщик", "брик-а-брак", "брикабракист", "плюшкин", "барахольщик"],
    "старьёвщица": ["барахольщица"],
    "стас": ["станислав"],
    "стаскав": ["стаскавши"],
    "стаскавши": ["стаскав"],
    "стаскивав": ["стаскивавши"],
    "стаскивавши": ["стаскивав"],
    "стасовав": ["стасовавши"],
    "стасовавши": ["стасовав"],
    "стасовывав": ["стасовывавши"],
    "стасовывавши": ["стасовывав"],
    "стася": ["станислав", "анастасий"],
    "статер": ["статир"],
    "статив": ["безлично-предикативное слово", "безличный предикатив", "вербоид", "неглагольный предикатив", "предикативное наречие"],
    "статист": ["массовка", "пешка"],
    "статичность": ["неподвижность", "статика"],
    "статичный": ["статический"],
    "статный": ["стройный"],
    "статолит": ["отолит"],
    "статочный": ["возможный"],
    "статталон": ["статистический талон"],
    "статус": ["положение", "позиция", "состояние"],
    "статус-кво": ["прежнее положение"],
    "статуя": ["скульптура", "изваяние"],
    "статуя свободы": ["символ свободы и демократии", "леди свобода"],
    "стать": ["телосложение", "осанка", "фигура", "стан", "суть", "характер", "необходимость", "надобность", "нужда"],
    "статьишка": ["статеечка", "статейка"],
    "статься": ["сделаться", "остановиться"],
    "стафилококк": ["гроздекокк"],
    "стафф": ["амстафф", "стаффордшир-терьер", "стафф-терьер"],
    "стаффордшир": ["стаффордшир-терьер", "стаффорд"],
    "стаффордшир-терьер": ["амстафф"],
    "стаффордширский терьер": ["стаффорд", "стаффордшир", "стаффордшир-терьер"],
    "стахановство": ["ударничество"],
    "стахановщина": ["стахановское движение", "стахановство"],
    "стационар": ["больница", "лазарет", "стационер"],
    "стационировав": ["стационировавши"],
    "стационировавши": ["стационировав"],
    "стачав": ["стачавши"],
    "стачавши": ["стачав"],
    "стачать": ["сшить"],
    "стачечный": ["забастовочный"],
    "стачивав": ["стачивавши"],
    "стачивавши": ["стачивав"],
    "стачка": ["забастовка", "сговор"],
    "стащив": ["стащивши"],
    "стащивши": ["стащив"],
    "стащить": ["стянуть", "снять", "перетащить", "собрать", "свести", "спереть", "стибрить", "своровать", "украсть"],
    "стая": ["ватага"],
    "стаяв": ["стаявши"],
    "стаявши": ["стаяв"],
    "ствол": ["столб", "стержень", "трубка", "дуло", "пушка", "волына", "брандспойт"],
    "ствол с тишиной": ["ерунда с тишиной"],
    "стволовая клетка": ["ск"],
    "стволоцветение": ["каулифлория"],
    "ствольщик": ["ствольник"],
    "створаживав": ["створаживавши"],
    "створаживавши": ["створаживав"],
    "створив": ["створивши"],
    "створивши": ["створив"],
    "створожив": ["створоживши"],
    "створоживши": ["створожив"],
    "створяв": ["створявши"],
    "створявши": ["створяв"],
    "стеапсин": ["липаза"],
    "стеатит": ["талькохлорит", "жировик", "жирный камень", "мыльный камень"],
    "стеаторея": ["стеаторрея", "стеаторрэа"],
    "стебав": ["стебавши"],
    "стебавши": ["стебав"],
    "стебанув": ["стебанувши"],
    "стебанувши": ["стебанув"],
    "стебать": ["хлестать", "стегать", "насмехаться", "иронизировать", "уплетать"],
    "стебаться": ["насмехаться", "высмеивать", "осмеивать", "потешаться", "прикалываться", "злорадствовать", "издеваться", "веселиться", "шутить", "зубоскалить", "хохмить", "ёрничать", "ржать", "драться", "бодаться"],
    "стебая": ["стебя"],
    "стебель": ["ствол"],
    "стебелёк": ["стебель", "черенок", "ножка"],
    "стеблевидный": ["стеблеобразный", "стеблеподобный", "стебельчатый"],
    "стеблекорень": ["каудекс"],
    "стеблеобразный": ["стеблевидный", "стеблеподобный"],
    "стеблеподобный": ["стеблевидный", "стеблеобразный"],
    "стеблистий": ["стеблястий"],
    "стеблёвый": ["стеблевой"],
    "стебнув": ["стебнувши"],
    "стебнувши": ["стебнув"],
    "стебя": ["стебая"],
    "стевия": ["медовая трава"],
    "стегав": ["стегавши"],
    "стегавши": ["стегав"],
    "стегальный череп": ["стегокротафический череп"],
    "стегальщик": ["стегальщица"],
    "стеганув": ["стеганувши"],
    "стеганувши": ["стеганув"],
    "стегануть": ["стегнуть", "хлестануть"],
    "стеганье": ["стегание"],
    "стегать": ["хлестать"],
    "стегно": ["бедро", "ляжка"],
    "стегнув": ["стегнувши"],
    "стегнувши": ["стегнув"],
    "стегнуть": ["хлестнуть"],
    "стегокротафический череп": ["стегальный череп"],
    "стегоцефал": ["панцирноголовый"],
    "стедикам": ["стэдикам"],
    "стежина": ["стежка"],
    "стежка": ["стежина"],
    "стежок": ["шаг"],
    "стежь": ["стезя"],
    "стезя": ["путь", "дорога", "тропа"],
    "стейк": ["бифштекс"],
    "стейси": ["стэйси"],
    "стекав": ["стекавши"],
    "стекавши": ["стекав"],
    "стекание": ["стеканье"],
    "стекаться": ["сливаться"],
    "стеклев": ["стеклевши"],
    "стеклевши": ["стеклев"],
    "стекленев": ["стекленевши"],
    "стекленевши": ["стекленев"],
    "стеклив": ["стекливши"],
    "стекливши": ["стеклив"],
    "стеклобой": ["бой стекла"],
    "стекловав": ["стекловавши"],
    "стекловавши": ["стекловав"],
    "стекловальный": ["стекловарный", "стеклоплавильный"],
    "стекловальщик": ["стекловар"],
    "стеклование": ["витрификация"],
    "стекловар": ["стеклоплав", "стеклодел"],
    "стекловаренный": ["стекловарный", "стекловарочный"],
    "стекловарный": ["стекловаренный", "стекловарочный"],
    "стекловарочный": ["стекловарный", "стекловаренный"],
    "стекловидно": ["стеклообразно"],
    "стекловыдувальщик": ["стеклодув"],
    "стеклографировав": ["стеклографировавши"],
    "стеклографировавши": ["стеклографировав"],
    "стеклографист": ["стеклографистка"],
    "стеклодел": ["стекловар", "стеклоплав"],
    "стеклообразный": ["стекловидный"],
    "стеклооптикобетон": ["литракон"],
    "стеклоочиститель": ["дворник"],
    "стеклопакет": ["спо", "спд", "стекло"],
    "стеклоплав": ["стекловар", "стеклодел"],
    "стеклорезный": ["стеклорезочный"],
    "стеклорезочный": ["стеклорезный"],
    "стеклотара": ["банка", "бутылка"],
    "стеклянев": ["стекляневши"],
    "стекляневши": ["стеклянев"],
    "стеклярус": ["бисер"],
    "стекольна": ["стокгольм"],
    "стекольщик": ["стеклильщик"],
    "стела": ["стель", "стеле"],
    "стелив": ["стеливши"],
    "стеливши": ["стелив"],
    "стелить": ["стлать"],
    "стелиться": ["стлаться", "расстилаться"],
    "стелс-": ["малозаметный"],
    "стель": ["стела", "центральный цилиндр"],
    "стельный": ["сутельный", "сутелый", "огулянный", "брюхатый", "обрюхаченный", "беремчатый", "толстый", "с брюшком", "с брюхом"],
    "стемнев": ["стемневши"],
    "стемневши": ["стемнев"],
    "стемнеть": ["потемнеть", "смеркнуться"],
    "стемнив": ["стемнивши"],
    "стемнивши": ["стемнив"],
    "стенав": ["стенавши"],
    "стенавши": ["стенав"],
    "стенание": ["стон", "жалоба"],
    "стенанье": ["стенание"],
    "стенать": ["стонать", "охать", "страдать", "мучиться", "томиться"],
    "стенгазета": ["стенная газета", "стенновка", "стенгаз", "стенная"],
    "стендап-комик": ["стендапер"],
    "стендапер": ["стендап-комик"],
    "стенная газета": ["стенгазета", "стенновка"],
    "стенный": ["стенной"],
    "стенограф": ["стенографист"],
    "стенографировав": ["стенографировавши"],
    "стенографировавши": ["стенографировав"],
    "стенография": ["скоропись"],
    "стеноз": ["стриктура"],
    "стенозировав": ["стенозировавши"],
    "стенозировавши": ["стенозировав"],
    "стенокардия": ["грудная жаба"],
    "стеноп": ["пинхол"],
    "стеношный": ["стеночный"],
    "стентор": ["трубач"],
    "степ": ["чечётка"],
    "степанакерт": ["ханкенди", "варарагн"],
    "степенив": ["степенивши"],
    "степенивши": ["степенив"],
    "степенничав": ["степенничавши"],
    "степенничавши": ["степенничав"],
    "степенность": ["степенство", "чинность"],
    "степенный": ["важный", "родовитый"],
    "степень": ["мера", "ступень", "показатель", "уровень", "степень сравнения"],
    "степень окисления": ["окислительное число", "формальный заряд"],
    "степист": ["чечёточник"],
    "степистка": ["чечёточница"],
    "степлер": ["сшиватель"],
    "степное блюдце": ["западина"],
    "степовав": ["степовавши"],
    "степовавши": ["степовав"],
    "степуха": ["степаха"],
    "стеран": ["циклопентанпергидрофенантрен", "гонан"],
    "стерва": ["ехидна", "грымза", "язва", "сука", "паскуда", "дрянь", "мерзавка", "сволочь", "негодяйка", "гнида", "тварь", "падла", "злюка", "мегера", "гадина"],
    "стервенев": ["стервеневши"],
    "стервеневши": ["стервенев"],
    "стервенив": ["стервенивши"],
    "стервенивши": ["стервенив"],
    "стервец": ["негодяй", "мерзавец"],
    "стервятина": ["падаль", "гадина"],
    "стервятник": ["стервятник обыкновенный"],
    "стерев": ["стёрши"],
    "стерео": ["монозвук", "монозвучание"],
    "стереовизор": ["стереотелевизор"],
    "стереограмма": ["стереокартинка", "магический глаз"],
    "стереозвук": ["стереофония"],
    "стереоизображение": ["стереопара"],
    "стереоизомер": ["эпимер"],
    "стереокартограф": ["автокартограф", "стереоавтограф"],
    "стереомаг": ["стереомагнитофон"],
    "стереомагнитофон": ["стереомаг"],
    "стереосистема": ["стереокомплекс"],
    "стереоскопический": ["стереоскопичный"],
    "стереоскопичный": ["стереоскопический"],
    "стереотелевизор": ["стереовизор"],
    "стереотип": ["представление"],
    "стереотипировав": ["стереотипировавши"],
    "стереотипировавши": ["стереотипировав"],
    "стереофония": ["стереозвук"],
    "стереоэкран": ["стереодисплей"],
    "стереть": ["вытереть", "натереть", "истереть"],
    "стереть с лица земли": ["смести с лица земли"],
    "стеречь": ["охранять", "сторожить", "караулить", "стоять на страже", "подстерегать"],
    "стерж": ["стержи"],
    "стержень": ["хребет"],
    "стерилизовав": ["стерилизовавши"],
    "стерилизовавши": ["стерилизовав"],
    "стерин": ["стерол"],
    "стерлядь": ["чечуга", "стерляжина"],
    "стерня": ["жнивьё"],
    "стерпев": ["стерпевши"],
    "стерпевши": ["стерпев"],
    "стерпливав": ["стерпливавши"],
    "стерпливавши": ["стерпливав"],
    "стерх": ["белый журавль"],
    "стесав": ["стесавши"],
    "стесавши": ["стесав"],
    "стесненье": ["стеснение"],
    "стеснив": ["стеснивши"],
    "стеснивши": ["стеснив"],
    "стеснительно": ["застенчиво", "робко"],
    "стеснительный": ["застенчивый", "робкий"],
    "стесняв": ["стеснявши"],
    "стеснявши": ["стесняв"],
    "стеснять": ["сжимать", "стискивать"],
    "стесняша": ["стесняшка"],
    "стеснённо": ["скованно", "скудно", "затруднённо", "стеснительно"],
    "стеснённый": ["стиснутый", "смущённый"],
    "стетоскоп": ["слуховая трубка"],
    "стетоскопический": ["стетоскопный"],
    "стефания": ["стеша"],
    "стефанович": ["стефаныч"],
    "стеченье": ["стечение"],
    "стечь": ["сбежать", "убежать"],
    "стеша": ["стефания"],
    "стибин": ["сурьмянистый водород"],
    "стибнит": ["антимонит", "сурьмяный блеск"],
    "стибрив": ["стибривши"],
    "стибривши": ["стибрив"],
    "стивен-кинговский": ["кинговский"],
    "стивер": ["штивер"],
    "стивидор": ["грузчик", "погрузчик", "портовый грузчик"],
    "стигийский": ["загробный"],
    "стигматизировав": ["стигматизировавши"],
    "стигматизировавши": ["стигматизировав"],
    "стид": ["стидко", "стидно"],
    "стидовисько": ["стидовище", "стид"],
    "стикер": ["наклейка"],
    "стикеровав": ["стикеровавши"],
    "стикеровавши": ["стикеровав"],
    "стилав": ["стилавши"],
    "стилавши": ["стилав"],
    "стилив": ["стиливши"],
    "стиливши": ["стилив"],
    "стилизовав": ["стилизовавши"],
    "стилизовавши": ["стилизовав"],
    "стилистическая фигура": ["фигура речи", "риторическая фигура"],
    "стило": ["писало", "стиль", "стилус", "стилограф", "перо"],
    "стилус": ["стило", "стиль", "стилограф"],
    "стиль": ["стило", "почерк", "стайл", "летосчисление"],
    "стиль жизни": ["лайфстайл"],
    "стильб": ["сб"],
    "стильный": ["модный"],
    "стиляга": ["пижон"],
    "стиляжничав": ["стиляжничавши"],
    "стиляжничавши": ["стиляжничав"],
    "стимпанк": ["паропанк"],
    "стимул": ["мотив", "мотивация"],
    "стимулировав": ["стимулировавши"],
    "стимулировавши": ["стимулировав"],
    "стимулирование": ["стимуляция"],
    "стимулированный брак": ["брак вдогонку", "залёт"],
    "стимулировать": ["мотивировать"],
    "стипа": ["стипон", "стипончик", "стипуха", "стипушка", "стёпа", "стёпка", "степуха"],
    "стипендия": ["стипуха"],
    "стипуха": ["стипендия"],
    "стирав": ["стиравши"],
    "стиравши": ["стирав"],
    "стиракс": ["бензоиновое дерево"],
    "стиралка": ["стиральная машина"],
    "стиральная машина": ["стиралка"],
    "стирание": ["вытирание", "перетирание", "удаление", "уничтожение", "стирка", "отстирывание"],
    "стирательная резинка": ["ластик", "резинка", "стёрка", "стиралка", "стирашка"],
    "стираться": ["вытираться", "истираться"],
    "стирашка": ["стёрка", "ластик"],
    "стирол": ["фенилэтилен", "винилбензол", "этенилбензол"],
    "стирывав": ["стирывавши"],
    "стирывавши": ["стирывав"],
    "стискав": ["стискавши"],
    "стискавши": ["стискав"],
    "стискивав": ["стискивавши"],
    "стискивавши": ["стискивав"],
    "стискивание": ["сжатие", "сдавливание"],
    "стиснув": ["стиснувши"],
    "стиснувши": ["стиснув"],
    "стиснуть": ["сдавить"],
    "стих": ["блажь"],
    "стихав": ["стихавши"],
    "стихавши": ["стихав"],
    "стихать": ["переставать", "смиряться", "смолкать", "успокаиваться", "униматься", "ослабевать", "затихать", "утихать", "остывать"],
    "стихийно": ["самопроизвольно", "неорганизованно", "самотёком"],
    "стихира": ["гимн"],
    "стихия": ["элемент"],
    "стихнув": ["стихнувши"],
    "стихнувши": ["стихнув"],
    "стихнуть": ["перестать", "присмиреть", "смолкнуть", "уняться", "улечься", "ослабеть", "затихнуть", "утихнуть", "приутихнуть", "угомониться", "уходиться", "остынуть", "образумиться", "опомниться", "смириться"],
    "стихокропатель": ["стихоплёт", "рифмач", "рифмоплёт"],
    "стихоплёт": ["рифмоплёт", "рифмач", "стихокропатель"],
    "стихоплётствовав": ["стихоплётствовавши"],
    "стихоплётствовавши": ["стихоплётствовав"],
    "стихослагатель": ["поэт", "пиит", "стихотворец"],
    "стихосложение": ["поэзия", "стихотворство", "стихотворчество"],
    "стихосложенье": ["стихосложение"],
    "стихотворение": ["стих", "вирша", "стихотворенье"],
    "стихотворенье": ["стихотворение"],
    "стихотворец": ["поэт", "бард", "пиит", "рифмоплёт", "рифмач", "версификатор"],
    "стихотворица": ["поэтесса"],
    "стихотворство": ["стихотворчество", "стихосложение"],
    "стихотворствовав": ["стихотворствовавши"],
    "стихотворствовавши": ["стихотворствовав"],
    "стихотворческий": ["поэтический"],
    "стихотворчество": ["поэзия", "стихосложение"],
    "стклянка": ["скляница", "склянка"],
    "стлав": ["стлавши"],
    "стлавши": ["стлав"],
    "стланик": ["стланец"],
    "стлать": ["стелить"],
    "стлаться": ["стелиться"],
    "стлев": ["стлевши"],
    "стлевши": ["стлев"],
    "стлеть": ["истлеть", "сгнить"],
    "сто": ["специальная теория относительности", "станция техобслуживания"],
    "сто лет в обед": ["с вот такой бородой"],
    "сто проц": ["сто процентов", "на сто процентов", "точно", "наверняка", "железно"],
    "сто процентов": ["сто проц", "на сто процентов", "точно", "наверняка", "железно"],
    "сто раз": ["тыщу раз", "тысячу раз"],
    "стовбняк": ["правець"],
    "стовбурина": ["стовбур"],
    "стовп": ["стовб"],
    "стог": ["копна"],
    "стогна": ["площадь", "страна", "территория"],
    "стоговав": ["стоговавши"],
    "стоговавши": ["стоговав"],
    "стогование": ["стогометание", "стогометанье", "скирдование", "скирдованье"],
    "стоговище": ["остожье"],
    "стоголовый": ["стоглавый"],
    "стогом": ["кучей", "грудой", "внавал"],
    "стодвадцатиминутный": ["двухчасовой"],
    "стодвадцатиячейник": ["гекатоникосахор", "гипердодекаэдр", "додекаплекс", "полидодекаэдр"],
    "стодола": ["сарай"],
    "стожары": ["семь сестёр", "волосожары", "утиное гнездо", "воз"],
    "стожив": ["стоживши"],
    "стоживши": ["стожив"],
    "стожильный": ["семижильный"],
    "стоив": ["стоивши"],
    "стоивши": ["стоив"],
    "стоимость": ["ценность", "цена"],
    "стоить": ["цениться", "оцениваться"],
    "стоически": ["мужественно", "стойко"],
    "стоический": ["мужественный", "стойкий"],
    "стойка": ["опора"],
    "стойкий": ["прочный", "крепкий", "твёрдый", "железный", "упорный", "упрямый", "непоколебимый", "непреклонный", "непокорный", "несгибаемый", "химстойкий"],
    "стойкость": ["выдержка", "выносливость", "крепкость", "сопротивляемость"],
    "стоймя": ["на попа", "стоя", "вертикально"],
    "сток": ["стекание"],
    "стокгольм": ["стекольна"],
    "стол": ["столик", "тумба", "плато"],
    "стола": ["орарь", "епитрахиль"],
    "столб": ["столп", "ствол", "шест", "мачта", "шпиль"],
    "столбенев": ["столбеневши"],
    "столбеневши": ["столбенев"],
    "столбив": ["столбивши"],
    "столбивши": ["столбив"],
    "столбик": ["столб", "башня", "свечка", "точечный дом"],
    "столбняк": ["ступор"],
    "столбняковый": ["столбнячный"],
    "столбнячный": ["столбняковый"],
    "столетие": ["век"],
    "столетье": ["столетие"],
    "столик": ["стол"],
    "столикий": ["многоликий", "многообразный", "разнообразный"],
    "столица арктики": ["мурманск", "столица заполярья", "рыбная столица", "романов-на-мурмане", "мурик", "диксон"],
    "столица беломорья": ["архангельск", "столица поморья", "новохолмогоры", "архангельский город"],
    "столица заполярья": ["мурманск", "столица арктики", "рыбная столица", "романов-на-мурмане", "мурик"],
    "столица поморья": ["архангельск", "столица беломорья", "новохолмогоры", "архангельский город"],
    "столица фонтанов": ["петергоф", "петродворец"],
    "столица черноземья": ["воронеж"],
    "столичный": ["стольный"],
    "столкав": ["столкавши"],
    "столкавши": ["столкав"],
    "столкновение": ["соударение", "стычка"],
    "столкновение интересов": ["конфликт интересов"],
    "столкновенье": ["столкновение"],
    "столкнув": ["столкнувши"],
    "столкнувши": ["столкнув"],
    "столоваться": ["кормиться", "харчеваться", "есть", "кушать"],
    "столовая": ["кухня", "столовка", "тошниловка", "рыгаловка", "хавалка"],
    "столовая комната": ["столовая"],
    "столоверченье": ["столоверчение"],
    "столовка": ["столовая"],
    "столон": ["ус"],
    "столп": ["столб", "колонна", "башня"],
    "столпив": ["столпивши"],
    "столпивши": ["столпив"],
    "столпляться": ["сталпливаться", "скучиваться"],
    "столпотворенье": ["столпотворение"],
    "столыпинский вагон": ["вагонзак"],
    "столыпинский галстук": ["столыпинский галстух", "муравьёвский галстук"],
    "столыпинский галстух": ["столыпинский галстук", "муравьёвский галстук"],
    "столь": ["настолько", "так", "до такой степени"],
    "стольничав": ["стольничавши"],
    "стольничавши": ["стольничав"],
    "стольный": ["престольный", "столичный"],
    "столяр": ["мебельщик", "плотник"],
    "столярив": ["столяривши"],
    "столяривши": ["столярив"],
    "столярить": ["столярничать"],
    "столярка": ["столярная"],
    "столярная": ["столярка"],
    "столярничав": ["столярничавши"],
    "столярничавши": ["столярничав"],
    "стома": ["свищ"],
    "стоматолог": ["дантист", "зубной врач"],
    "стоматологический": ["зубной"],
    "стон": ["стенание", "жалоба"],
    "стонав": ["стонавши"],
    "стонавши": ["стонав"],
    "стонать": ["стенать", "охать", "жаловаться", "ныть", "вздыхать", "скулить", "плакаться", "роптать", "сетовать", "страдать", "мучиться", "томиться"],
    "стоножка": ["многоножка", "сороконожка"],
    "стонущий": ["стенающий"],
    "стоп": ["стой", "хватит"],
    "стоп-лист": ["чёрный список"],
    "стоп-огонь": ["стоп-сигнал"],
    "стоп-сигнал": ["стоп-огонь"],
    "стопа": ["ступня", "след", "шаг", "поступь"],
    "стопанка": ["господарка", "домакиня", "чорбаджийка"],
    "стопив": ["стопивши"],
    "стопивши": ["стопив"],
    "стопка": ["пачка", "кучка", "горка", "рюмка", "шот"],
    "стопорив": ["стопоривши"],
    "стопоривши": ["стопорив"],
    "стопроцентный": ["чистый", "истинный", "однозначный", "гарантированный", "точный"],
    "стоптав": ["стоптавши"],
    "стоптавши": ["стоптав"],
    "стопудняк": ["наверняка"],
    "стопудово": ["наверняка", "сто пудов"],
    "стопщик": ["автостопщик"],
    "стопэ": ["стоять"],
    "стопятьсот": ["много"],
    "стора": ["штора"],
    "стораживав": ["стораживавши"],
    "стораживавши": ["стораживав"],
    "сторговав": ["сторговавши"],
    "сторговавши": ["сторговав"],
    "сторговаться": ["условиться"],
    "сторговывав": ["сторговывавши"],
    "сторговывавши": ["сторговывав"],
    "сторис": ["история", "истории"],
    "сторица": ["сотня"],
    "сторицей": ["сторицею", "стократно", "избыток"],
    "сторицею": ["сторицей", "стократно", "избыток"],
    "сторичний": ["стократний"],
    "стормозив": ["стормозивши"],
    "стормозивши": ["стормозив"],
    "сторнировав": ["сторнировавши"],
    "сторнировавши": ["сторнировав"],
    "сторнирование": ["аннулирование"],
    "сторнировать": ["аннулировать", "отменять"],
    "сторновав": ["сторновавши"],
    "сторновавши": ["сторновав"],
    "сторовъ": ["здоровъ"],
    "сторож": ["охранник"],
    "сторожевав": ["сторожевавши"],
    "сторожевавши": ["сторожевав"],
    "сторожевик": ["сторожевой катер", "сторожевой корабль"],
    "сторожевой таймер": ["собака"],
    "сторожив": ["стороживши"],
    "стороживши": ["сторожив"],
    "сторожка": ["будка"],
    "сторожкий": ["осторожный", "осмотрительный", "настороженный"],
    "сторожко": ["осторожно", "осмотрительно"],
    "сторожкость": ["осторожность", "осмотрительность", "настороженность"],
    "сторона договора": ["участник договора", "субъект договора"],
    "сторонник": ["последователь", "приверженец"],
    "сторцевав": ["сторцевавши"],
    "сторцевавши": ["сторцевав"],
    "стос": ["фараон", "банк"],
    "стосковаться": ["соскучиться"],
    "стотина": ["сто"],
    "стоунер-рок": ["стоунер"],
    "стохастический": ["стохастичный", "случайный", "вероятностный"],
    "сточив": ["сточивши"],
    "сточивши": ["сточив"],
    "стоша-говнозад": ["стоша-говнозад тихона пальцем"],
    "стошка": ["стоха", "сотняга", "стошечка"],
    "стошнив": ["стошнивши"],
    "стошнивши": ["стошнив"],
    "стошнить": ["вытошнить", "вырвать"],
    "стощав": ["стощавши"],
    "стощавши": ["стощав"],
    "стоя": ["стоймя"],
    "стояв": ["стоявши"],
    "стоявши": ["стояв"],
    "стояк": ["торчок", "эрекция"],
    "стоянка": ["остановка", "стояние", "стойбище"],
    "стоянщик": ["парковщик", "стояночник"],
    "стоянье": ["стояние"],
    "стоять": ["находиться", "покоиться", "бездействовать"],
    "стоять во главе": ["быть во главе"],
    "стоять на часах": ["караулить"],
    "стоять на шухере": ["быть на шухере", "стоять на стрёме"],
    "стоять над душой": ["докучать"],
    "стоять одной ногой в могиле": ["стоять одной ногой в гробу"],
    "стравив": ["стравивши"],
    "стравивши": ["стравив"],
    "стравливав": ["стравливавши"],
    "стравливавши": ["стравливав"],
    "стравливание": ["стравление", "стравливанье"],
    "стравляв": ["стравлявши"],
    "стравлявши": ["стравляв"],
    "страгивав": ["страгивавши"],
    "страгивавши": ["страгивав"],
    "страда": ["уборка", "аврал", "страдание", "мучение"],
    "страдав": ["страдавши"],
    "страдавши": ["страдав"],
    "страдалец": ["мученик"],
    "страдалица": ["мученица"],
    "страдальчески": ["болезненно", "мученически"],
    "страдание": ["мучение", "мука"],
    "страданка": ["страдинка", "остроданка"],
    "страдательный": ["пассивный", "мученический", "страдальческий"],
    "страдательный залог": ["пассивный залог", "пассив"],
    "страдать": ["мучиться", "болеть"],
    "страдать хернёй": ["дурью маяться", "страдать фигнёй"],
    "страдивари": ["страдиварий", "страдивариус"],
    "страдиварий": ["страдивариус"],
    "страдивариус": ["страдиварий"],
    "страдник": ["страдный человек"],
    "страдовав": ["страдовавши"],
    "страдовавши": ["страдовав"],
    "страж": ["стражник", "охранник", "защитник"],
    "страж закона": ["страж порядка", "блюститель порядка", "правоохранитель"],
    "страж порядка": ["блюститель порядка", "страж закона"],
    "страждав": ["страждавши"],
    "страждавши": ["страждав"],
    "страждать": ["страдать"],
    "страивав": ["страивавши"],
    "страивавши": ["страивав"],
    "страйкбол": ["эйрсофт"],
    "страм": ["срам", "сором"],
    "страма": ["стыд"],
    "страмец": ["срамец", "бесстыдник"],
    "страмоний": ["дурман"],
    "страна": ["местность", "земля", "край", "территория", "регион", "сторона", "государство", "держава", "люди", "народ"],
    "страна басков": ["эускади", "баскония"],
    "страна вечнозелёных помидоров": ["край вечнозелёных помидоров"],
    "страна восходящего солнца": ["япония"],
    "страна кленового листа": ["канада", "канадская конфедерация"],
    "страна тюльпанов": ["нидерланды"],
    "страна утренней свежести": ["корея"],
    "страна-агрессор": ["государство-агрессор", "агрессор"],
    "страна-изгой": ["государство-изгой"],
    "страна-оператор": ["страна-эксплуатант"],
    "страна-организатор": ["страна-хозяйка"],
    "страна-хозяйка": ["страна-организатор"],
    "странджалия": ["странджанец"],
    "страница": ["страничка", "лист", "интернет-страница", "веха"],
    "странник": ["путешественник", "скиталец", "путник", "пилигрим", "паломник", "богомолец"],
    "странница": ["путница", "путешественница", "скиталица", "богомолка", "паломница", "пилигримка", "луна", "селена", "диана"],
    "странничав": ["странничавши"],
    "странничавши": ["странничав"],
    "страннический": ["бродячий", "бродяжий", "скитальческий"],
    "странничий": ["страннический"],
    "странно": ["необычно", "непривычно", "подозрительно", "особенно"],
    "странноватый": ["чудноватый"],
    "странноприимница": ["странноприимный дом", "странноприемница", "странноприятелище", "странноприимная", "странноприемная", "гостиница", "ночлежный дом", "ночлежка", "постоялый двор", "богадельня", "божий приют", "дом призрения", "дом престарелых"],
    "странноприимство": ["странноприемство", "страннолюбие", "странноприятие"],
    "страннорог": ["диноцерат"],
    "странный": ["причудливый", "необычный", "ненормальный"],
    "страновой": ["страновый"],
    "страновый": ["страновой"],
    "странствие": ["странствование", "путешествие", "перегринация"],
    "странствовав": ["странствовавши"],
    "странствовавши": ["странствовав"],
    "странствованье": ["странствование"],
    "странствовать": ["путешествовать", "скитаться"],
    "странствующий": ["путешествующий"],
    "страпелька": ["странглет"],
    "страпон": ["фаллопротез"],
    "страпонтен": ["откидное сиденье"],
    "страстная пятница": ["великая пятница", "великий пяток"],
    "страстная суббота": ["великая суббота"],
    "страстно": ["горячо", "беззаветно"],
    "страстность": ["пылкость", "горячность"],
    "страстный": ["эмоциональный", "пылкий", "воодушевлённый", "жаркий", "огненный", "пассионарный", "пламенный", "одержимый", "заядлый", "увлечённый", "чувственный"],
    "страстолюбие": ["любострастие", "сладострастие"],
    "страстотерпец": ["страдалец", "мученик"],
    "страстотерпица": ["мученица", "страстоносица", "страдалица"],
    "страстоцвет": ["пассифлора"],
    "страсть": ["любовь", "нежное чувство", "порыв", "горячность", "пыл", "исступление", "пристрастие", "влечение", "увлечение", "страдание", "мучение", "ужас", "ужастик", "страх", "страшилка"],
    "стратагема": ["стратегема"],
    "стратег": ["стратегик"],
    "стратега": ["стратегия"],
    "стратегическая оборонная инициатива": ["сои", "звёздные войны"],
    "стратегия": ["политика", "стратежка"],
    "стратежка": ["стратегия"],
    "стратиграфическая зона": ["зона", "хронозона"],
    "стратиграфическая шкала": ["геохронологическая шкала"],
    "стратиграфический": ["геохронологический"],
    "стратиграфическое подразделение": ["стратиграфическая единица"],
    "стратить": ["истратить", "потратить", "потерять", "лишиться", "утрачивать"],
    "стратифицировав": ["стратифицировавши"],
    "стратифицировавши": ["стратифицировав"],
    "стратовулкан": ["слоистый вулкан"],
    "стратометр": ["микробентометр"],
    "стратон": ["стратиграфическое подразделение", "стратиграфическая единица"],
    "стратостат": ["стратосферный", "аэростат"],
    "страус": ["строфокамил"],
    "страх": ["боязнь", "испуг", "ужас", "паника", "риск", "ответственность"],
    "страх потерять": ["совесть потерять"],
    "страха ради иудейска": ["страха ради иудейского"],
    "страхвнесок": ["страховий внесок"],
    "страховав": ["страховавши"],
    "страховавши": ["страховав"],
    "страхование": ["страховка"],
    "страхованье": ["страхование"],
    "страховисько": ["страховище"],
    "страховище": ["страховисько"],
    "страховка": ["страхование"],
    "страховой рынок": ["рынок страхования"],
    "страхолюд": ["страхолюдина"],
    "страхолюдина": ["урод", "уродина"],
    "страхолюдный": ["страховидный", "страхотный"],
    "страхопиздище": ["страшилище"],
    "страхопуд": ["опудало", "страховище", "страховисько"],
    "страхоёбина": ["страхолюд", "страхолюдка", "страхолюдина"],
    "страхуила": ["страшила", "страшило", "страшилище", "пугало", "страхолюдина"],
    "страчивав": ["страчивавши"],
    "страчивавши": ["страчивав"],
    "страчивать": ["истратить", "потратить", "потерять", "лишиться", "утрачивать"],
    "страшенний": ["страшнючий"],
    "страшенный": ["страшнющий", "престрашный"],
    "страшив": ["страшивши"],
    "страшивши": ["страшив"],
    "страшила": ["страшилище", "страшило", "пугало"],
    "страшило": ["страшилище"],
    "страшить": ["стращать"],
    "страшиться": ["бояться", "пугаться", "опасаться", "трусить", "дрейфить", "робеть", "трепетать", "дрожать", "трястись"],
    "страшно": ["ужасно", "пугающе", "жутко", "боязно", "очень", "поразительно"],
    "страшной": ["страшный"],
    "страшность": ["страшнота"],
    "страшнота": ["страшность"],
    "страшный": ["пугающий", "ужасный", "жуткий"],
    "страшнючий": ["страшенний"],
    "страшнющий": ["страшенный", "престрашный"],
    "стращав": ["стращавши"],
    "стращавши": ["стращав"],
    "стращанье": ["стращание"],
    "стращать": ["грозить", "грозиться", "пугать", "угрожать", "устрашать", "терроризировать", "страшить", "ужасать", "кошмарить"],
    "стращивать": ["ссучивать", "свивать", "соединять", "сплетать", "сращивать", "сплеснивать"],
    "стребовав": ["стребовавши"],
    "стребовавши": ["стребовав"],
    "стребовать": ["взыскать", "истребовать", "вытребовать", "выбить", "вытрясти", "получить", "взять", "потребовать", "спросить"],
    "стрейт-дро": ["стрит-дро"],
    "стрекав": ["стрекавши"],
    "стрекавив": ["стрекавивши"],
    "стрекавивши": ["стрекавив"],
    "стрекавши": ["стрекав"],
    "стреканув": ["стреканувши"],
    "стреканувши": ["стреканув"],
    "стрекательный": ["жгущий", "жалящий"],
    "стрекать": ["жечь", "жалить"],
    "стрекающий": ["книдарий"],
    "стрекнув": ["стрекнувши"],
    "стрекнувши": ["стрекнув"],
    "стрекоза": ["егоза", "попрыгунья", "вертолёт", "вертушка"],
    "стрекозив": ["стрекозивши"],
    "стрекозивши": ["стрекозив"],
    "стрекозий": ["стрекозиный"],
    "стрекозиный": ["стрекозий"],
    "стрекот": ["стрекотание"],
    "стрекотав": ["стрекотавши"],
    "стрекотавши": ["стрекотав"],
    "стрекотанье": ["стрекотание"],
    "стрела": ["стрелка"],
    "стрелевав": ["стрелевавши"],
    "стрелевавши": ["стрелевав"],
    "стрелец": ["ратник", "стрелок"],
    "стрелив": ["стреливши"],
    "стреливав": ["стреливавши"],
    "стреливавши": ["стреливав"],
    "стреливши": ["стрелив"],
    "стрелка": ["дротик"],
    "стреловидный": ["стрелообразный", "стрелоподобный"],
    "стрелолист": ["болотник", "шильник"],
    "стрелолистный": ["остролистый"],
    "стрелообразный": ["стреловидный", "стрелоподобный"],
    "стрелоподобный": ["стреловидный", "стрелообразный"],
    "стрелочник": ["козёл отпущения", "крайний"],
    "стрельба": ["пальба"],
    "стрельнув": ["стрельнувши"],
    "стрельнувши": ["стрельнув"],
    "стрельнуть": ["выстрелить", "треснуть", "хлопнуть"],
    "стреляв": ["стрелявши"],
    "стрелявши": ["стреляв"],
    "стрелялка": ["боевик", "шутер"],
    "стреляный воробей": ["тёртый калач", "ветеран"],
    "стрелянье": ["стреляние"],
    "стрелять": ["охотиться", "выпрашивать"],
    "стрелять из пушек по воробьям": ["за мухой угоняешься с обухом"],
    "стрелять из пушки по воробьям": ["за мухой угоняешься с обухом"],
    "стреляться": ["застреливаться", "драться"],
    "стремав": ["стремавши"],
    "стремавши": ["стремав"],
    "стрематься": ["дрейфить", "пугаться", "трусить", "робеть", "опасаться"],
    "стремглав": ["стремительно", "молниеносно", "опрометью", "лихо", "кубарем", "бегом", "резво"],
    "стремеж": ["стремление"],
    "стремечко": ["стремя"],
    "стремив": ["стремивши"],
    "стремивши": ["стремив"],
    "стремительно": ["молниеносно", "пулей"],
    "стремительный": ["быстрый", "быстроходный", "скоростной", "ходкий", "быстроногий", "резвый", "проворный", "молниеносный", "резкий", "порывистый", "поспешный", "мощный", "спешный"],
    "стремить": ["устремлять"],
    "стремление": ["влечение", "тяга"],
    "стремнина": ["стрежень", "обрыв"],
    "стремя": ["стремечко"],
    "стремянка": ["лестница-стремянка"],
    "стремянный": ["стременной"],
    "стремёшка": ["штрипка"],
    "стреножив": ["стреноживши"],
    "стреноживав": ["стреноживавши"],
    "стреноживавши": ["стреноживав"],
    "стреноживать": ["треножить"],
    "стреноживши": ["стреножив"],
    "стрептоцид": ["сульфаниламид"],
    "стрескав": ["стрескавши"],
    "стрескавши": ["стрескав"],
    "стресс": ["шок", "стрессняк"],
    "стресснер": ["штрёсснер"],
    "стрессовав": ["стрессовавши"],
    "стрессовавши": ["стрессовав"],
    "стрессопсихотерапия": ["стрессотерапия"],
    "стрессор": ["раздражитель"],
    "стрессотерапия": ["стрессопсихотерапия"],
    "стретто": ["стретта"],
    "стретч": ["стретч-плёнка"],
    "стретчевав": ["стретчевавши"],
    "стретчевавши": ["стретчевав"],
    "стреха": ["карниз", "свес"],
    "стречь": ["охранять", "стеречь"],
    "стриарный": ["стриатальный"],
    "стриатум": ["полосатое тело", "герань кровяно-красная"],
    "стрибати": ["плигати"],
    "стригаль": ["стригальщик"],
    "стригнув": ["стригнувши"],
    "стригнувши": ["стригнув"],
    "стригун": ["стригунец", "стрижек"],
    "стрижка": ["причёска"],
    "стриктура": ["стеноз"],
    "стримив": ["стримивши"],
    "стримивши": ["стримив"],
    "стрип-бар": ["стриптиз-бар"],
    "стрип-клуб": ["стриптиз-клуб"],
    "стриппер": ["съёмник", "изоляция", "колосоуборник"],
    "стриптиз-бар": ["стрип-бар"],
    "стриптизёрка": ["стриптизёрша"],
    "стриптизёрша": ["стриптизёрка"],
    "стрит-арт": ["граффити"],
    "стритбол": ["стритбаскет"],
    "стритфуд": ["уличная еда"],
    "стрихнинный": ["стрихниновый"],
    "стрихниновый": ["стрихнинный"],
    "стричь": ["подстригать"],
    "стричь капусту": ["варить капусту", "окучивать капусту", "много", "рубить капусту"],
    "стричься": ["подстригаться"],
    "стробировав": ["стробировавши"],
    "стробировавши": ["стробировав"],
    "стробический": ["стробоскопический"],
    "строгав": ["строгавши"],
    "строгавши": ["строгав"],
    "строгальщик": ["строгаль"],
    "строганина": ["струганина"],
    "строганный": ["струганный"],
    "строганый": ["струганый"],
    "строганье": ["строгание"],
    "строгать": ["стругать", "штамповать"],
    "строгач": ["парфорс", "строгий ошейник"],
    "строгий": ["требовательный", "взыскательный", "жёсткий", "суровый", "грозный", "точный", "чёткий", "аскетичный", "аскетический", "спартанский"],
    "строгий ошейник": ["парфорс", "строгач"],
    "строгнув": ["строгнувши"],
    "строгнувши": ["строгнув"],
    "строго": ["сурово", "жёстко", "точно", "неуклонно", "неукоснительно", "в точности"],
    "строго-настрого": ["категорически"],
    "строгость": ["суровость", "жёсткость"],
    "строевичок": ["марш", "солдатик-строевичок", "новичок"],
    "строение": ["здание", "корпус", "постройка"],
    "строжать": ["строжеть"],
    "строжеть": ["строжать"],
    "строжив": ["строживши"],
    "строживши": ["строжив"],
    "строжка": ["строгание", "зачистка"],
    "строив": ["строивши"],
    "строивши": ["строив"],
    "строитель": ["созидатель"],
    "строительная техника": ["стройтехника"],
    "строительно-проектный": ["проектно-строительный"],
    "строительный мусор": ["строймусор"],
    "строительство": ["постройка", "возведение", "строительный объект", "сооружение", "создание", "изготовление", "производство", "зодчество", "формирование", "становление", "наладка", "организация"],
    "строить": ["сооружать", "воздвигать", "возводить", "изготовлять", "созидать", "создавать", "вычерчивать", "намечать", "планировать", "основывать", "базировать", "составлять", "выстраивать", "изображать", "корячить"],
    "строить воздушные замки": ["строить испанские замки", "строить на песке", "делить шкуру неубитого медведя", "витать в облаках"],
    "строиться": ["возводиться", "сооружаться", "строить", "выстраиваться"],
    "строй": ["устройство", "порядок", "гармония", "устроенность"],
    "стройка": ["постройка", "строительство", "строительная площадка", "объект"],
    "стройматериал": ["строительный материал", "компонент", "деталь", "кирпичик", "составляющая"],
    "стройнев": ["стройневши"],
    "стройневши": ["стройнев"],
    "стройненько": ["стройно", "складненько", "изящно", "легко", "грациозно", "элегантно"],
    "строкатий": ["рябий", "зозулястий"],
    "строковая константа": ["строковый литерал"],
    "строматолит": ["биогерм"],
    "стромбус": ["стромбиды"],
    "стронув": ["стронувши"],
    "стронувши": ["стронув"],
    "строп": ["крыша", "чердак", "потолок"],
    "стропа": ["строп"],
    "стропив": ["стропивши"],
    "стропивши": ["стропив"],
    "стропилив": ["стропиливши"],
    "стропиливши": ["стропилив"],
    "стропорез": ["нож-стропорез"],
    "строптивев": ["строптивевши"],
    "строптивевши": ["строптивев"],
    "строптивец": ["упрямец"],
    "строптивость": ["упрямство"],
    "строптивый": ["упрямый", "своенравный", "непокорный", "стропотный"],
    "стростив": ["стростивши"],
    "стростивши": ["стростив"],
    "стростить": ["ссучить", "свить", "соединить", "сплести", "связать", "срастить", "сростить", "сплеснить"],
    "строфический": ["изострофический"],
    "строфокамил": ["страус"],
    "строченный": ["строчённый"],
    "строчечный": ["строковый"],
    "строчив": ["строчивши"],
    "строчивши": ["строчив"],
    "строчила": ["писака"],
    "строчка": ["шов"],
    "строчкогон": ["графоман"],
    "строчкогонство": ["графомания", "строкогонство"],
    "строчная буква": ["маленькая буква"],
    "строчённый": ["строченный"],
    "струбцина": ["цвинга"],
    "стругав": ["стругавши"],
    "стругавши": ["стругав"],
    "струганина": ["строганина"],
    "струганый": ["строганый"],
    "стругать": ["строгать", "нарезать", "нарезывать"],
    "стругивав": ["стругивавши"],
    "стругивавши": ["стругивав"],
    "стругнув": ["стругнувши"],
    "стругнувши": ["стругнув"],
    "струение": ["струенье"],
    "струенье": ["струение"],
    "стружив": ["струживши"],
    "струживши": ["стружив"],
    "струив": ["струивши"],
    "струивши": ["струив"],
    "структура": ["устройство", "строение", "запись", "организация", "учреждение"],
    "структурализовав": ["структурализовавши"],
    "структурализовавши": ["структурализовав"],
    "структуризация": ["структурирование"],
    "структуризовав": ["структуризовавши"],
    "структуризовавши": ["структуризовав"],
    "структурировав": ["структурировавши"],
    "структурировавши": ["структурировав"],
    "струм": ["струминь", "струмок"],
    "струнив": ["струнивши"],
    "струнивши": ["струнив"],
    "струнка": ["струна", "фибра"],
    "струноплодник": ["экзохорда"],
    "струночка": ["струнка"],
    "струсив": ["струсивши"],
    "струсивши": ["струсив"],
    "струттофайбер": ["струтто"],
    "струхнув": ["струхнувши"],
    "струхнувши": ["струхнув"],
    "струхнуть": ["заробеть", "вструхнуть", "перетрухать"],
    "стручкообразный": ["стручковидный"],
    "стручок": ["стручочек"],
    "стручья": ["стручок"],
    "струшивав": ["струшивавши"],
    "струшивавши": ["струшивав"],
    "струя": ["поток", "полоса", "течение", "направление", "ток"],
    "стряпав": ["стряпавши"],
    "стряпавши": ["стряпав"],
    "стряпать": ["кухарничать", "кухарить", "поварничать", "поварить"],
    "стряпная": ["кухня", "поварня", "стряпущая"],
    "стряпня": ["готовка", "стряпание", "кушанье", "еда", "поделка", "тяп-ляп"],
    "стряпуха": ["кухарка", "повариха"],
    "стряпущая": ["кухня", "поварня", "стряпная"],
    "стряпчий": ["поверенный", "солиситор"],
    "стрясав": ["стрясавши"],
    "стрясавши": ["стрясав"],
    "стряха": ["навес", "сушина", "покрив", "дом", "жилище", "къща", "керемида"],
    "стряхав": ["стряхавши"],
    "стряхавши": ["стряхав"],
    "стряхивав": ["стряхивавши"],
    "стряхивавши": ["стряхивав"],
    "стряхнув": ["стряхнувши"],
    "стряхнувши": ["стряхнув"],
    "стрём": ["страх", "тревога", "охрана", "стража"],
    "стрёмив": ["стрёмивши"],
    "стрёмивши": ["стрёмив"],
    "стрёмно": ["страшно", "опасно", "неудобно", "стыдно"],
    "стрёмный": ["опасный", "рискованный", "нелепый"],
    "студак": ["студенческий билет", "студень", "студняк", "студик"],
    "студенев": ["студеневши"],
    "студеневши": ["студенев"],
    "студенистый": ["желеобразный"],
    "студениться": ["студенеть"],
    "студентик": ["студентишко"],
    "студентишка": ["студентик"],
    "студентишко": ["студентишка", "студентик"],
    "студентка": ["ученица"],
    "студентство": ["студенчество"],
    "студентствование": ["студенчество", "студентство"],
    "студенческая весна": ["студвесна"],
    "студенческий билет": ["студбилет", "студенческий", "студак", "студен", "студень", "студик", "студняк"],
    "студенчество": ["студентство"],
    "студень": ["заливное", "холодец", "желе"],
    "студив": ["студивши"],
    "студивши": ["студив"],
    "студиоз": ["студент", "студиозус"],
    "студиозус": ["студент"],
    "студить": ["остужать", "выстуживать"],
    "студневидный": ["студнеобразный"],
    "студнеобразный": ["студневидный"],
    "студёный": ["холодный", "морозный"],
    "стужа": ["мороз"],
    "стук": ["стучок"],
    "стукав": ["стукавши"],
    "стукавши": ["стукав"],
    "стукалка": ["колотушка"],
    "стукать": ["стучать"],
    "стукач": ["боец", "ябеда", "жалобщик", "наушник", "доносчик", "дятел", "наседка", "фискал"],
    "стукаческий": ["доносительский"],
    "стукачество": ["доносительство", "осведомительство"],
    "стукачка": ["доносительница", "доносчица", "клеветница", "осведомительница"],
    "стукко": ["искусственный мрамор", "штук"],
    "стукнув": ["стукнувши"],
    "стукнувши": ["стукнув"],
    "стукнуть": ["пожаловаться", "нажаловаться", "капнуть", "заявить", "исполниться"],
    "стукнуться": ["удариться", "шваркнуться", "долбануться", "постучаться"],
    "стуколка": ["стукалка"],
    "стуловой": ["стуловый", "стульевой", "верстачный"],
    "ступа": ["ступка", "ступочка"],
    "ступав": ["ступавши"],
    "ступавши": ["ступав"],
    "ступать": ["шагать", "наступать", "идти", "уходить"],
    "ступенчатый": ["дискретный"],
    "ступенька": ["ступёнка", "ступень"],
    "ступив": ["ступивши"],
    "ступивши": ["ступив"],
    "ступити": ["покрокувати"],
    "ступить": ["шагнуть", "наступить"],
    "ступка": ["иготь"],
    "ступня": ["стопа", "подошва"],
    "ступор": ["оцепенение"],
    "стухнув": ["стухнувши"],
    "стухнувши": ["стухнув"],
    "стухнуть": ["протухнуть", "потухнуть", "погаснуть"],
    "стучав": ["стучавши"],
    "стучавши": ["стучав"],
    "стучание": ["стук"],
    "стучанье": ["стучание"],
    "стучать": ["бить", "стукать"],
    "стучаться": ["ударяться", "стукаться", "стучать"],
    "стушевав": ["стушевавши"],
    "стушевавши": ["стушевав"],
    "стушив": ["стушивши"],
    "стушивши": ["стушив"],
    "стушить": ["потушить"],
    "стушёвывав": ["стушёвывавши"],
    "стушёвывавши": ["стушёвывав"],
    "стърготина": ["треска", "тресчица", "стружка", "отломка", "шушка"],
    "стыбзив": ["стыбзивши"],
    "стыбзивши": ["стыбзив"],
    "стыв": ["стывши"],
    "стывши": ["стыв"],
    "стыд": ["стыдоба", "позор", "бесчестье", "срам", "срамное место"],
    "стыдив": ["стыдивши"],
    "стыдивши": ["стыдив"],
    "стыдище": ["позорище"],
    "стыдливая мимоза": ["недотрога"],
    "стыдливец": ["скромник"],
    "стыдливо": ["застенчиво", "смущённо"],
    "стыдливый": ["застенчивый", "стеснительный"],
    "стыдная болезнь": ["сифилис", "льюис", "французская болезнь", "дурная болезнь", "скверная болезнь", "сиф", "сифак", "сифачина"],
    "стыдно": ["неловко", "неудобно", "совестно"],
    "стыдный": ["позорный"],
    "стыдоба": ["стыд", "стыдобушка"],
    "стыдобушка": ["стыдоба", "стыд", "позорище"],
    "стыкав": ["стыкавши"],
    "стыкавши": ["стыкав"],
    "стыковав": ["стыковавши"],
    "стыковавши": ["стыковав"],
    "стылый": ["остывший", "холодный", "студёный", "постылый"],
    "стынув": ["стынувши"],
    "стынувши": ["стынув"],
    "стынуть": ["стыть", "холодеть", "мёрзнуть", "застывать", "охлаждаться"],
    "стынь": ["стужа", "мороз"],
    "стыр": ["стырь"],
    "стырив": ["стыривши"],
    "стыривши": ["стырив"],
    "стыривший": ["укравший", "скоммуниздивший"],
    "стыть": ["остывать", "стынуть", "мёрзнуть", "успокаиваться", "слабеть", "ослабевать"],
    "стюард": ["официант", "бортпроводник", "эконом"],
    "стюардесса": ["бортпроводница"],
    "стюк": ["стукко"],
    "стяг": ["древко", "жердь", "шест", "кол", "знамя", "флаг"],
    "стягав": ["стягавши"],
    "стягавши": ["стягав"],
    "стягивав": ["стягивавши"],
    "стягивавши": ["стягивав"],
    "стяжав": ["стяжавши"],
    "стяжавши": ["стяжав"],
    "стяжание": ["стяжательство", "накопительство", "имущество", "богатство"],
    "стяжанье": ["стяжание"],
    "стяжатель": ["корыстолюбец"],
    "стяжательский": ["меркантильный"],
    "стяжательство": ["стяжательность", "алчность", "накопительство", "ростовщичество"],
    "стяжать": ["заслужить", "заслуживать", "снискать", "снискивать", "удостоиться", "удостаиваться"],
    "стяжение": ["контракция", "элизия", "конкреция"],
    "стямс": ["арамс", "кеподемс", "съргоземс", "лисемс"],
    "стянув": ["стянувши"],
    "стянувши": ["стянув"],
    "стёб": ["осмеивание", "высмеивание", "ёрничество", "ёрничание", "пародирование", "ирония", "насмешка", "издёвка", "сарказм"],
    "стёбщик": ["ёрник"],
    "стёганка": ["набивняк"],
    "стёпа": ["степан", "стенька", "стёпка", "степанида"],
    "стёрка": ["тёрка", "стирательная резинка", "стиралка", "резинка", "ластик"],
    "стёртый": ["стёршийся", "избитый", "пошлый", "заезженный", "истасканный"],
    "стёрши": ["стерев"],
    "стёсывав": ["стёсывавши"],
    "стёсывавши": ["стёсывав"],
    "су буе": ["яр"],
    "су иясе": ["су бабасы"],
    "суавъярви": ["сувари"],
    "суаре": ["вечеринка", "пати"],
    "суахили": ["кисуахили"],
    "суб-": ["при-", "суп-", "почти"],
    "субаб": ["набоб", "наваб", "субадар"],
    "субаквальный": ["подводный"],
    "субалтерн": ["субалтерн-офицер"],
    "субалтерн-офицер": ["субалтерн"],
    "субантарктический пояс": ["субантарктика"],
    "субарахноидальный": ["подпаутинный"],
    "субарендатор": ["поднаниматель"],
    "субарту": ["субар"],
    "субботничав": ["субботничавши"],
    "субботничавши": ["субботничав"],
    "субвариант": ["подвариант", "подразновидность"],
    "субгармонический": ["субгармоничный"],
    "субгармоничный": ["субгармонический"],
    "субдерево": ["поддерево"],
    "субдиакон": ["иподиакон"],
    "субдиректория": ["подкаталог", "подпапка", "поддиректория"],
    "субкортекс": ["подкорка"],
    "субкритический": ["докритический"],
    "сублимация": ["перегон", "возгонка"],
    "сублимировав": ["сублимировавши"],
    "сублимировавши": ["сублимировав"],
    "сублимировать": ["возгонять", "возносить", "культивировать", "замещать"],
    "сублимироваться": ["возгоняться"],
    "сублингвальный": ["подъязычный"],
    "сублюксация": ["подвывих"],
    "субмарина": ["подводная лодка", "подлодка"],
    "субмикроскопический": ["ультрамикроскопический"],
    "субноутбук": ["субноут"],
    "субоптимальный": ["неоптимальный"],
    "субординация": ["иерархия", "подчинённость"],
    "субординировав": ["субординировавши"],
    "субординировавши": ["субординировав"],
    "субординированный": ["подчинённый", "зависимый", "подотчётный", "ранжированный"],
    "субретка": ["инженю"],
    "субсветовой": ["околосветовой"],
    "субсидировав": ["субсидировавши"],
    "субсидировавши": ["субсидировав"],
    "субсидировать": ["финансировать"],
    "субсидия": ["пособие", "субвенция"],
    "субсистенция": ["продовольствие", "припас"],
    "субстантив": ["имя существительное", "существительное"],
    "субстантивация": ["субстантивирование", "номинализация"],
    "субстантивировав": ["субстантивировавши"],
    "субстантивировавши": ["субстантивировав"],
    "субстантивирование": ["субстантивация"],
    "субстантивировать": ["материализовывать", "материализовать", "воплощать", "воплотить"],
    "субстантивный": ["содержательный"],
    "субстанциализировав": ["субстанциализировавши"],
    "субстанциализировавши": ["субстанциализировав"],
    "субстанциализм": ["эссенциализм"],
    "субстанциально": ["субстанционально"],
    "субстанциальный": ["материальный", "существенный"],
    "субстанционализировав": ["субстанционализировавши"],
    "субстанционализировавши": ["субстанционализировав"],
    "субстанционализироваться": ["овеществиться"],
    "субстанционально": ["субстанциально"],
    "субстанция": ["материал"],
    "субталамус": ["преталамус", "периталамус"],
    "субтильность": ["хрупкость"],
    "субтильный": ["тщедушный", "хрупкий", "деликатный"],
    "субтитр": ["саб"],
    "субтитрировав": ["субтитрировавши"],
    "субтитрировавши": ["субтитрировав"],
    "субтитрование": ["титрование", "титрирование"],
    "субфебрильный": ["подострый"],
    "субчик": ["субъект", "тип", "типчик"],
    "субъект": ["подлежащее", "тип"],
    "субъективация": ["субъективизация"],
    "субъективировав": ["субъективировавши"],
    "субъективировавши": ["субъективировав"],
    "субъективно": ["односторонне", "пристрастно", "предвзято"],
    "субъективный": ["пристрастный", "предвзятый"],
    "субъективщина": ["субъективность"],
    "субъюнктив": ["сослагательное наклонение", "конъюнктив"],
    "субэтнос": ["субэтническая группа"],
    "сував": ["сувавши"],
    "сувавши": ["сував"],
    "суверенизатор": ["суверенитетчик"],
    "суверенизировав": ["суверенизировавши"],
    "суверенизировавши": ["суверенизировав"],
    "суверенитет": ["независимость", "самостоятельность"],
    "суверенитетчик": ["суверенизатор"],
    "суверенность": ["суверенитет", "независимость"],
    "суверенный": ["властный", "независимый"],
    "сувой": ["сугроб", "субой", "надув", "зыбь", "токунцы", "свиток", "связка", "узел", "свиль", "кап", "виль"],
    "сувтса зэр": ["кызсьыв зэр"],
    "сувук": ["сувух"],
    "суглинний": ["суглинистий"],
    "сугроб": ["намёт", "сувой"],
    "сугс": ["сухс"],
    "сугубив": ["сугубивши"],
    "сугубивши": ["сугубив"],
    "сугубо": ["особенно", "исключительно", "совершенно", "полностью", "всецело", "чисто", "единственно", "очень"],
    "сугубый": ["особенный", "исключительный", "двойной", "двукратный", "удвоенный", "сдвоенный", "усиленный"],
    "сугуд": ["сугуда"],
    "сугуда": ["согдиана"],
    "суд": ["судилище", "судище", "судопроизводство", "судоустройство", "суждение", "осуждение", "мнение", "заключение", "вывод"],
    "судав": ["судин", "ятвяг"],
    "судавия": ["судовия", "судува", "сувалкия", "ятвягия"],
    "судак": ["солдая", "сугдея", "сурож"],
    "судаковый": ["судачий"],
    "судан": ["республика судан"],
    "сударыня": ["барышня"],
    "сударь": ["господин"],
    "судачив": ["судачивши"],
    "судачивши": ["судачив"],
    "судачий": ["судаковый"],
    "судачить": ["сплетничать", "болтать"],
    "судда": ["остона"],
    "судебно-медицинский эксперт": ["судмедэксперт"],
    "судебный": ["судейский", "тяжебный", "судный"],
    "судебный пристав": ["судебный исполнитель"],
    "судебный процесс": ["тяжба"],
    "судейский": ["судебный"],
    "судействовав": ["судействовавши"],
    "судействовавши": ["судействовав"],
    "судив": ["судивши"],
    "судивши": ["судив"],
    "судилище": ["суд"],
    "судить": ["обслуживать"],
    "судиться": ["вести тяжбу"],
    "судмедэксперт": ["судмед"],
    "судмедэкспертиза": ["смэ"],
    "судно": ["вуоки"],
    "судно на воздушной подушке": ["аэроход", "ховеркрафт"],
    "судно на подводных крыльях": ["гидрофойл"],
    "суднобудування": ["кораблебудування"],
    "судный": ["судебный"],
    "судоведение": ["судопроизводство"],
    "судовладелец": ["фрахтовщик", "арматор"],
    "судоводитель": ["навигатор"],
    "судовождение": ["кораблевождение"],
    "судозавод": ["судзавод"],
    "судок": ["соусник", "контейнер", "ланчбокс", "бокс", "плошка", "лоток", "чеплашка", "топсик", "тормозок", "ссобойка", "шкоробатка", "тазик", "карэчек", "кандейка", "кузовок"],
    "судомойка": ["посудомойка"],
    "судоплотник": ["судовой", "плотник"],
    "судорембаза": ["судоремонтная база"],
    "судоремонтно-судостроительный": ["судостроительно-судоремонтный"],
    "судорога": ["спазм", "конвульсия"],
    "судорожно": ["спазматически", "лихорадочно", "суетливо", "тревожно"],
    "судосборщик": ["судосборщица"],
    "судостроение": ["кораблестроение", "кораблестроенье"],
    "судостроенье": ["кораблестроение", "кораблестроенье"],
    "судосутки": ["судо-сутки"],
    "судочек": ["кастрюлька"],
    "судьба": ["доля", "жребий", "удел", "участь", "провидение", "рок", "фатум", "судьбина", "фортуна", "планида", "биография", "будущее", "будущность"],
    "судьбина": ["судьба", "удел", "рок"],
    "судьбоносный": ["важный", "значительный", "существенный", "эпохальный", "решающий"],
    "судья": ["судия", "арбитр", "рефери", "критик", "ценитель", "знаток", "эксперт", "критикан"],
    "судя по всему": ["наверное", "вероятно", "видимо", "по-видимому", "по всей видимости", "по всей вероятности", "очевидно", "верно", "видно", "как видно", "должно быть", "надо думать", "надо полагать", "знать", "видать"],
    "суеверив": ["суеверивши"],
    "суеверивши": ["суеверив"],
    "суеверие": ["суеверье"],
    "суеверствовав": ["суеверствовавши"],
    "суеверствовавши": ["суеверствовав"],
    "суеверствовать": ["суеверить"],
    "суеверье": ["суеверие"],
    "суемудрие": ["мудрствование"],
    "суемудрствовав": ["суемудрствовавши"],
    "суемудрствовавши": ["суемудрствовав"],
    "суемыслие": ["суемудрие"],
    "суесловив": ["суесловивши"],
    "суесловивши": ["суесловив"],
    "суесловие": ["суесловье", "пустословие", "празднословие"],
    "суесловить": ["болтать", "болтать попусту", "пустословить", "пустозвонить"],
    "суесловье": ["суесловие", "пустословие"],
    "суета": ["суетня", "суматоха", "маета", "тщета", "пустое"],
    "суетный": ["тщетный", "пустой"],
    "сужав": ["сужавши"],
    "сужавши": ["сужав"],
    "сужать": ["суживать", "ограничивать"],
    "сужаться": ["суживаться", "утоньшаться", "уменьшаться", "сокращаться"],
    "суждение": ["сужденье"],
    "суждено": ["судьба"],
    "сужденье": ["суждение"],
    "суженая": ["невеста"],
    "суженый": ["предназначенный", "предопределённый", "жених"],
    "суженье": ["сужение"],
    "суживав": ["суживавши"],
    "суживавши": ["суживав"],
    "суживание": ["сужение"],
    "суживать": ["сужать"],
    "суживаться": ["сужаться", "утоньшаться", "уменьшаться", "сокращаться"],
    "сузив": ["сузивши"],
    "сузивши": ["сузив"],
    "сузиться": ["утоньшиться", "уменьшиться", "сократиться"],
    "суицид": ["самоубийство"],
    "суицидальный": ["суицидный"],
    "суицидент": ["суицидник"],
    "суицидник": ["суицидент"],
    "суицидница": ["самоубийца"],
    "суйфэньхэ": ["сунька"],
    "сук": ["ветка"],
    "сука": ["сучка", "псица", "собака", "стерва", "мерзавец", "мразь", "негодяй", "сволочь", "подлец", "сучара"],
    "сукин сын": ["негодяй", "мерзавец", "проходимец", "паршивец", "сукин кот", "сучара"],
    "сукка": ["шалаш"],
    "сукман": ["сукманец", "сукня"],
    "сукно": ["стол"],
    "сукновал": ["валяльщик", "сукновальщик", "сукнодел"],
    "сукня": ["плаття"],
    "суковатка": ["смык"],
    "суконное рыло": ["свиное рыло", "собачье рыло", "свинячье рыло", "немытое рыло", "неумытое рыло"],
    "сукотая": ["сукотная"],
    "сукотная": ["сукотая"],
    "сукровица": ["экссудат"],
    "суктория": ["сосущая инфузория"],
    "сукут": ["сумт"],
    "сукцес": ["успех"],
    "сукцессия": ["престолонаследие"],
    "сукыр": ["надан", "белемсез", "томана", "кара", "черек", "бозылган"],
    "сулавеси": ["целебес"],
    "сулема": ["дихлорид ртути", "едкий сублимат", "двухлористая ртуть", "бихлорид ртути"],
    "сулея": ["горшок", "кувшин"],
    "сулив": ["суливши"],
    "суливши": ["сулив"],
    "суливший": ["обещавший"],
    "сулить": ["обещать", "предвещать", "предсказывать", "пророчить"],
    "суллам": ["нардбон"],
    "султанчик": ["султан"],
    "сулугун": ["сулугуни"],
    "сулугуни": ["сулугун"],
    "сулук": ["тарикат"],
    "сулуу": ["чырайлуу", "татынакай"],
    "сулуулук": ["кооздук"],
    "сульфамид": ["сульфапрепарат"],
    "сульфан": ["полисульфид"],
    "сульфаниловая кислота": ["парааминобензолсульфокислота", "п-анилин-сульфокислота"],
    "сульфат": ["сернокислая соль", "купорос"],
    "сульфацетамид": ["альбуцид"],
    "сульфидировав": ["сульфидировавши"],
    "сульфидировавши": ["сульфидировав"],
    "сульфировав": ["сульфировавши"],
    "сульфировавши": ["сульфировав"],
    "сульфитация": ["сульфитирование"],
    "сульфитировав": ["сульфитировавши"],
    "сульфитировавши": ["сульфитировав"],
    "сульфитирование": ["сульфитация"],
    "сульфитный процесс": ["сульфитная варка"],
    "сульфонал": ["диэтилсульфондиметилметан"],
    "сульфохлорид": ["сульфонилхлорид"],
    "сульфохлорировав": ["сульфохлорировавши"],
    "сульфохлорировавши": ["сульфохлорировав"],
    "сульфурил": ["сульфонил"],
    "сульфурилфторид": ["сульфурилдифторид", "фтористый сульфурил", "фторид сульфурила"],
    "сульфурилхлорид": ["хлористый", "сульфурил", "сульфурилдихлорид"],
    "сума": ["сумка"],
    "суман": ["ёсуман", "саман"],
    "сумасбродив": ["сумасбродивши"],
    "сумасбродивши": ["сумасбродив"],
    "сумасбродничав": ["сумасбродничавши"],
    "сумасбродничавши": ["сумасбродничав"],
    "сумасбродно": ["безумно", "необдуманно", "экстравагантно", "непродуманно", "безрассудно"],
    "сумасбродство": ["безрассудство"],
    "сумасбродствовав": ["сумасбродствовавши"],
    "сумасбродствовавши": ["сумасбродствовав"],
    "сумасшедший": ["умалишённый", "помешанный", "безумный", "бешеный"],
    "сумасшедший принтер": ["госдура", "взбесившийся принтер", "бешеный принтер"],
    "сумасшествие": ["помешательство", "безумие", "полоумие", "умопомешательство", "умоисступление", "безрассудство", "сумасбродство", "неистовство"],
    "сумасшествовав": ["сумасшествовавши"],
    "сумасшествовавши": ["сумасшествовав"],
    "сумасшествовать": ["сходить с ума", "съезжать с катушек", "беситься", "сумасбродничать"],
    "суматоха": ["хлопотня", "суета", "беспокойство", "хлопоты", "сумятица", "кутерьма"],
    "суматошно": ["суматошливо", "суетливо"],
    "суматошность": ["суматошливость", "суетливость"],
    "сумах": ["сумак"],
    "сумашествовав": ["сумашествовавши"],
    "сумашествовавши": ["сумашествовав"],
    "сумбур": ["путаница", "неразбериха"],
    "сумбурив": ["сумбуривши"],
    "сумбуривши": ["сумбурив"],
    "сумбурно": ["беспорядочно", "хаотично"],
    "сумбурность": ["неупорядоченность", "хаотичность"],
    "сумбурный": ["путаный", "беспорядочный", "сбивчивый", "хаотичный"],
    "сумгаит": ["сумгайыт"],
    "сумев": ["сумевши"],
    "сумевши": ["сумев"],
    "сумеречный": ["сумрачный"],
    "сумерки": ["полумрак", "полутьма"],
    "сумерничав": ["сумерничавши"],
    "сумерничавши": ["сумерничав"],
    "суметь": ["смочь"],
    "сумка": ["сума", "аксессуар", "карман", "аск", "мультимножество"],
    "сумка-коляска": ["сумка-тележка"],
    "сумка-тележка": ["сумка-коляска"],
    "сумкообразный": ["мешкообразный"],
    "сумление": ["сомнение", "нерешимость", "недоумение", "недоверие", "опасение", "подозрение"],
    "сумленье": ["сумление"],
    "суммаризация": ["автореферирование"],
    "суммарно": ["всего"],
    "суммировав": ["суммировавши"],
    "суммировавши": ["суммировав"],
    "суммирование": ["сложение", "прибавление", "складывание"],
    "суммировать": ["складывать"],
    "сумневаться": ["сомневаться"],
    "сумний": ["сумливий"],
    "сумничав": ["сумничавши"],
    "сумничавши": ["сумничав"],
    "сумоист": ["сумотори"],
    "сумочка": ["дамская сумочка"],
    "сумрак": ["полумрак", "полутьма", "темь", "потёмки"],
    "сумрачно": ["сумеречно"],
    "сумрачный": ["полутёмный", "мрачный", "пасмурный", "облачный", "угрюмый", "тяжёлый", "безрадостный", "унылый"],
    "сумская область": ["сумщина"],
    "сумт": ["сукут"],
    "сумчатый": ["чревосумчатый"],
    "сумщина": ["сумська область"],
    "сундук": ["сундучок", "сундучишко", "сундучище"],
    "сундучить": ["хомячить", "крысятничать"],
    "сунна": ["предание"],
    "сунув": ["сунувши"],
    "сунувши": ["сунув"],
    "сунуть": ["дать на лапу"],
    "сунька": ["суйфэньхэ"],
    "суол": ["пурсиш", "савол"],
    "суп": ["супчик", "супешник", "супец", "похлёбка", "бульон", "коктейль"],
    "суп из семи залуп": ["суп из трёх залуп", "суп из конских залуп"],
    "супер": ["суперобложка", "супергетеродин", "суппер", "супермаркет", "супергерой"],
    "супер-": ["сверх-"],
    "супер-мини-компьютер": ["супер-мини-эвм"],
    "супер-мини-эвм": ["супер-мини-компьютер"],
    "супер-пупер": ["атас", "шик-модерн"],
    "супер-эго": ["сверх-я"],
    "супербактерия": ["сверхинфект"],
    "супербанкнота": ["супердоллар"],
    "супербогач": ["сверхбогач", "ультрабогач"],
    "супербоевик": ["сверхбоевик"],
    "супервайзер": ["инспектор", "контролёр", "супервизор"],
    "супергармонический": ["супергармоничный"],
    "супергармоничный": ["супергармонический"],
    "супергетеродинный": ["супергетеродиновый"],
    "супергетеродиновый": ["супергетеродинный"],
    "супергород": ["мегаполис", "сверхгород"],
    "супердемократ": ["сверхдемократ"],
    "суперденьги": ["супервалюты"],
    "супердержава": ["сверхдержава", "великая держава"],
    "супердоллар": ["супербанкнота"],
    "суперечний": ["суперечливий"],
    "суперзащищённый": ["сверхзащищённый"],
    "суперземля": ["сверхземля"],
    "суперидея": ["сверхидея"],
    "суперинтендант": ["суперинтендент"],
    "суперклуб": ["топ-клуб"],
    "суперкомпьютер": ["суперэвм"],
    "суперконденсатор": ["ионистор", "ультраконденсатор"],
    "суперлатив": ["суперлятив"],
    "суперлояльный": ["лояльнейший"],
    "суперлятив": ["суперлатив"],
    "супермарафон": ["сверхмарафон"],
    "супермен": ["сверхчеловек"],
    "супермодель": ["топ-модель"],
    "супермодный": ["сверхмодный"],
    "супермотард": ["мотард", "супермото"],
    "супермото": ["мотард", "супермотард"],
    "супернировав": ["супернировавши"],
    "супернировавши": ["супернировав"],
    "супероружие": ["сверхоружие"],
    "суперпользователь": ["системный администратор", "админ", "рут"],
    "суперприложение": ["суперапп"],
    "суперраспространитель": ["сверхраспространитель", "суперспредер"],
    "суперсовременный": ["наисовременнейший"],
    "суперстильный": ["ультрастильный"],
    "суперстиция": ["предрассудок"],
    "суперструктура": ["надструктура", "надстройка"],
    "суперструна": ["гиперструна"],
    "супертяж": ["супертяжеловес"],
    "супертяжеловес": ["супертяж"],
    "суперфекундация": ["сверхоплодотворение"],
    "суперфиниш": ["суперфиниширование"],
    "суперфорвард": ["супернападающий"],
    "суперфуд": ["суперпища"],
    "суперцентрифуга": ["ультрацентрифуга"],
    "супершпион": ["сверхшпион"],
    "супесок": ["супесчаник", "супесь"],
    "супив": ["супивши"],
    "супивши": ["супив"],
    "супин": ["достигательное наклонение"],
    "супник": ["супница"],
    "супница": ["супник"],
    "супонив": ["супонивши"],
    "супонивши": ["супонив"],
    "супонь": ["супоня"],
    "супоня": ["супонь"],
    "супориш": ["фармоиш"],
    "супоросая": ["супоросная"],
    "супоросная": ["супоросая"],
    "супоросность": ["супоросость"],
    "супоросость": ["супоросность"],
    "супостат": ["враг", "неприятель", "противник", "сопостат", "злодей", "негодяй"],
    "супостатка": ["супостаточка"],
    "суппер": ["супер", "супергетеродин"],
    "супплетивизм": ["супплетивная форма"],
    "суппозиторий": ["свеча"],
    "супра-": ["супер-", "сверх-", "над-"],
    "суправитальный": ["поствитальный", "постмортальный", "интерлетальный"],
    "супрадентальный": ["альвеолярный"],
    "супрасегментный": ["суперсегментный", "надсегментный"],
    "супрацилиарный": ["бровный"],
    "супрематизм": ["супремизм"],
    "супрематистский": ["супрематический"],
    "супрематический": ["супрематистский"],
    "супремум": ["точная верхняя грань"],
    "супрессия": ["подавление", "угнетение"],
    "супротив": ["напротив", "против"],
    "супротивничав": ["супротивничавши"],
    "супротивничавши": ["супротивничав"],
    "супруг": ["муж", "муженёк", "супружник", "благоверный"],
    "супруга": ["жена", "супружница"],
    "супружеская измена": ["адюльтер"],
    "супружество": ["брак"],
    "супружествовав": ["супружествовавши"],
    "супружествовавши": ["супружествовав"],
    "супружник": ["супруг", "муж"],
    "супружница": ["жена", "супруга", "благоверная"],
    "супрядки": ["субботка"],
    "супурдан": ["супориш додан"],
    "сурвивализм": ["сервайвализм", "сурвайвализм"],
    "сурвивалист": ["выживальщик"],
    "сургучовый": ["сургучный"],
    "сурдут": ["сюртук"],
    "сурепа": ["сурепка", "сурепица"],
    "сурепица": ["сурепка"],
    "сурепка": ["сурепица"],
    "суржанка": ["суржа", "суржик"],
    "суржик": ["суржанка", "суржанок", "суржа", "суржанковый хлеб", "полубелый"],
    "сурик": ["миниум"],
    "сурица": ["сурья"],
    "сурковый": ["сурочий"],
    "сурляв": ["сурлявши"],
    "сурлявши": ["сурляв"],
    "сурма": ["зурна"],
    "суровая куделя": ["озорник"],
    "суровев": ["суровевши"],
    "суровевши": ["суровев"],
    "суровость": ["строгость", "неумолимость", "нетерпимость", "непримиримость", "жёсткость", "ригоризм"],
    "суровый": ["строгий", "серьёзный", "грозный", "беспощадный", "безжалостный", "жестокий", "безмилостный", "немилостивый", "угрюмый", "сердитый", "трудный", "тягостный", "северный", "холодный", "морозный"],
    "сурогат": ["имитация", "подправка", "заместител", "ерзац"],
    "суродовав": ["суродовавши"],
    "суродовавши": ["суродовав"],
    "сурочий": ["сурковый", "сурчиный"],
    "суррогатировав": ["суррогатировавши"],
    "суррогатировавши": ["суррогатировав"],
    "суртук": ["суртюк", "сертук", "сюртук"],
    "суртюк": ["суртук", "сертук", "сюртук"],
    "суруд": ["тарона"],
    "сурфактант": ["лёгочный сурфактант", "поверхностно-активное вещество", "пав"],
    "сурх": ["асух"],
    "сурчиный": ["сурочий", "сурковый"],
    "сурыкат": ["сурыката"],
    "сурьма": ["антимоний"],
    "сурьмив": ["сурьмивши"],
    "сурьмивши": ["сурьмив"],
    "сурьёз": ["серьёз", "серьёзность"],
    "сурьёзничав": ["сурьёзничавши"],
    "сурьёзничавши": ["сурьёзничав"],
    "сурьёзный": ["серьёзный"],
    "сус": ["вики"],
    "сусала": ["щи"],
    "сусалив": ["сусаливши"],
    "сусаливши": ["сусалив"],
    "сусальный": ["потальный", "приторный", "сентиментальный", "слащавый"],
    "сусанин": ["иван сусанин", "гид", "проводник", "провожатый"],
    "сусветны": ["спадчына"],
    "сусветный": ["повсеместный", "общий", "мирской", "обычный", "общепринятый"],
    "сусек": ["сусека", "закром", "засек", "сукром"],
    "сусека": ["закром", "засека", "сусек"],
    "суси": ["суши"],
    "сусиана": ["сусида", "сузиан", "хузистан"],
    "сускомс": ["ярхцамс", "улемс сускикс"],
    "суслив": ["сусливши"],
    "сусливши": ["суслив"],
    "сусликовый": ["сусличий"],
    "суслить": ["посасывать", "слюнявить"],
    "сусличий": ["сусликовый"],
    "сусолив": ["сусоливши"],
    "сусоливши": ["сусолив"],
    "сусолить": ["суслить", "обсасывать", "мусолить"],
    "суспендировав": ["суспендировавши"],
    "суспендировавши": ["суспендировав"],
    "суспендирование": ["суспензирование"],
    "суспензивный": ["суспенсивный"],
    "суспензировав": ["суспензировавши"],
    "суспензировавши": ["суспензировав"],
    "суспензирование": ["суспендирование"],
    "суспензировать": ["суспендировать"],
    "суспензия": ["взвесь"],
    "суспиция": ["подозрение", "недоверие", "омбраж"],
    "сустрев": ["сустревши"],
    "сустревши": ["сустрев"],
    "сустреть": ["встретить", "повстречать", "сретить"],
    "сустречав": ["сустречавши"],
    "сустречавши": ["сустречав"],
    "сусу": ["сосо"],
    "сусцептанс": ["реактивная проводимость"],
    "сутемь": ["полумрак", "сумрак"],
    "сутенёр": ["сутер", "шмаровоз", "кот", "альфонс", "сводник"],
    "сутенёрив": ["сутенёривши"],
    "сутенёривши": ["сутенёрив"],
    "сутка": ["судка"],
    "сутки": ["солнечные сутки", "день"],
    "сутолока": ["толкотня", "толчея", "толока", "сутолка"],
    "сутолочь": ["сутолока", "толкотня", "толчея"],
    "сутрин": ["утро", "заран", "утрин"],
    "сутуга": ["проволока", "хорда"],
    "сутулив": ["сутуливши"],
    "сутуливши": ["сутулив"],
    "сутулиться": ["горбиться"],
    "сутулый": ["сгорбленный"],
    "сутура": ["геосутура"],
    "суть": ["сущность", "существо"],
    "сутьба": ["доля", "жребий", "судьбина", "удел", "участь", "провидение", "рок", "фатум", "фортуна"],
    "сутюжив": ["сутюживши"],
    "сутюживав": ["сутюживавши"],
    "сутюживавши": ["сутюживав"],
    "сутюживши": ["сутюжив"],
    "сутяга": ["склочник", "склочница", "кляузник", "крючкотвор"],
    "сутяжество": ["сутяжничество"],
    "сутяжив": ["сутяживши"],
    "сутяживши": ["сутяжив"],
    "сутяжить": ["сутяжничать"],
    "сутяжник": ["тяжущийся", "жалобщик", "сутяга", "кляузник", "кверулянт", "бюрократ"],
    "сутяжничав": ["сутяжничавши"],
    "сутяжничавши": ["сутяжничав"],
    "сутяжничать": ["кляузничать", "сутяжить"],
    "сутяжничество": ["сутяжество"],
    "суфизм": ["суфийство", "тасаввуф"],
    "суфийский": ["суфистский"],
    "суфийство": ["суфизм"],
    "суфист": ["суфий"],
    "суфлер": ["шаптач"],
    "суфлировав": ["суфлировавши"],
    "суфлировавши": ["суфлировав"],
    "суфлирование": ["суфлированье"],
    "суфра": ["дастархон"],
    "суфражетка": ["суфражистка"],
    "суфражистка": ["суфражетка", "феминистка"],
    "суффолк": ["саффолк"],
    "суханвар": ["суханпардоз"],
    "суханпардоз": ["суханвар"],
    "сухара": ["сухарина"],
    "сухарик": ["сухарь", "дентикул"],
    "сухарина": ["сухара"],
    "сухарь": ["дрищ", "шатаут"],
    "сухая беда": ["удавленник", "висельник"],
    "сухая любовь": ["платоническая любовь"],
    "сухмень": ["сушь", "засуха"],
    "сухо": ["досуха", "бесчувственно", "бездушно", "скупо", "лаконично"],
    "сухобылье": ["сухобыльник"],
    "сухобыльник": ["сухобылье"],
    "суходол": ["балка"],
    "суходолье": ["суходол"],
    "суходрочка": ["мастурбация", "онанизм", "ручной блуд", "рукоблудие", "рукоблудье", "рукоблудство", "рукоделие", "дроч", "дрочка", "суходроч"],
    "сухое горючее": ["сухой спирт", "гекса"],
    "сухое молоко": ["порошковое молоко"],
    "сухожилье": ["сухожилие"],
    "сухой": ["безводный", "иссохший", "пересохший", "худощавый", "тощий", "тонкий", "сухопарый", "поджарый", "холодный", "суровый", "малословный", "безучастный", "неласковый", "скучный", "незанимательный"],
    "сухой остаток": ["итог", "резюме", "дайджест"],
    "сухой спирт": ["сухое горючее", "гекса"],
    "сухолюбивый": ["ксерофильный"],
    "сухонос": ["сухоносый гусь"],
    "сухопарый": ["худощавый", "поджарый"],
    "сухопутные войска": ["св"],
    "сухопутный": ["наземный"],
    "сухопутный пароход": ["паровая телега", "пароходный дилижанец"],
    "сухопутье": ["суша"],
    "сухорос": ["сухоросица"],
    "сухоросица": ["сухорос"],
    "сухостой": ["сухостойник", "сушняк"],
    "сухостойник": ["сухостой"],
    "сухота": ["сушь"],
    "сухотка": ["туберкулёз", "бугорчатка", "чахотка"],
    "сухощавый": ["худощавый", "сухопарый", "поджарый"],
    "сухояденье": ["сухоядение"],
    "сухпаёк": ["сухой паёк", "сухпай"],
    "сухс": ["сугс"],
    "сухум": ["сухуми"],
    "сухуми": ["сухум"],
    "сухур": ["сахур"],
    "сухый": ["март"],
    "сучара": ["сука", "подонок", "скотина"],
    "сучасний": ["актуальний"],
    "сученье": ["сучение"],
    "сучив": ["сучивши"],
    "сучивав": ["сучивавши"],
    "сучивавши": ["сучивав"],
    "сучивши": ["сучив"],
    "сучить": ["скать"],
    "сучкожог": ["сучкожёг"],
    "сучкожёг": ["сучкожог"],
    "сучоныш": ["сука", "сучара", "сукин сын"],
    "сучьё": ["хворост"],
    "суша": ["земля", "твердь"],
    "сушарня": ["сушарка"],
    "сушение": ["сушка"],
    "сушенье": ["сушение"],
    "суши": ["суси"],
    "сушив": ["сушивши"],
    "сушивав": ["сушивавши"],
    "сушивавши": ["сушивав"],
    "сушивши": ["сушив"],
    "сушило": ["сушилка"],
    "сушильня": ["сушилка"],
    "сушист": ["повар-сушист"],
    "сушка": ["сушение", "просушка", "обезвоживание", "сушилка"],
    "сушуар": ["климазон"],
    "сушёный": ["высушенный"],
    "существенно": ["значительно", "заметно", "намного", "важно", "значимо", "немаловажно"],
    "существенное условие": ["существенное условие договора"],
    "существенный": ["первостепенный", "значимый", "значительный", "важный", "весомый", "заметный", "знаменательный", "кардинальный", "конкретный", "немаловажный", "основной", "принципиальный", "решительный", "серьёзный", "субстанциальный"],
    "существительное": ["имя существительное", "субстантив"],
    "существо": ["создание", "животное"],
    "существовав": ["существовавши"],
    "существовавши": ["существовав"],
    "существование": ["наличествование", "экзистенция", "жизнь", "бытие", "проживание", "прозябание"],
    "существовать": ["жить", "иметься", "быть"],
    "существующий": ["сущий", "бывающий"],
    "сущий": ["подлинный", "истинный", "существующий", "имеющийся"],
    "сущностно": ["существенно"],
    "сущность": ["главное", "существенное", "содержание", "суть", "существо", "сучность", "квинтэссенция", "суть дела", "на деле", "в действительности"],
    "суык": ["салкын"],
    "суьмме": ["куье"],
    "сфабриковав": ["сфабриковавши"],
    "сфабриковавши": ["сфабриковав"],
    "сфабриковать": ["подделать"],
    "сфагнум": ["сфагн"],
    "сфальсифицировав": ["сфальсифицировавши"],
    "сфальсифицировавши": ["сфальсифицировав"],
    "сфальсифицированность": ["фальсифицированность"],
    "сфальсифицировать": ["подделать"],
    "сфальцевав": ["сфальцевавши"],
    "сфальцевавши": ["сфальцевав"],
    "сфальшивив": ["сфальшививши"],
    "сфальшививши": ["сфальшивив"],
    "сфантазировав": ["сфантазировавши"],
    "сфантазировавши": ["сфантазировав"],
    "сфеноид": ["диэдр осевой"],
    "сферический": ["шарообразный", "шаровидный"],
    "сферичность": ["шаровидность", "шарообразность", "округленность"],
    "сферичный": ["сферический", "шаровидный"],
    "сферокристалл": ["сферолит"],
    "сферосидерит": ["железный шпат"],
    "сферосома": ["олеосома"],
    "сфиглярив": ["сфигляривши"],
    "сфигляривши": ["сфиглярив"],
    "сфиглярничав": ["сфиглярничавши"],
    "сфиглярничавши": ["сфиглярничав"],
    "сфинкс": ["мандрил"],
    "сфискалив": ["сфискаливши"],
    "сфискаливши": ["сфискалив"],
    "сфокусировав": ["сфокусировавши"],
    "сфокусировавши": ["сфокусировав"],
    "сфокусировать": ["сосредоточить", "сконцентрировать"],
    "сфокусничав": ["сфокусничавши"],
    "сфокусничавши": ["сфокусничав"],
    "сфолдив": ["сфолдивши"],
    "сфолдивши": ["сфолдив"],
    "сфолив": ["сфоливши"],
    "сфоливши": ["сфолив"],
    "сформатировать": ["отформатировать"],
    "сформировав": ["сформировавши"],
    "сформировавши": ["сформировав"],
    "сформировывав": ["сформировывавши"],
    "сформировывавши": ["сформировывав"],
    "сформовав": ["сформовавши"],
    "сформовавши": ["сформовав"],
    "сформовывав": ["сформовывавши"],
    "сформовывавши": ["сформовывав"],
    "сформулировав": ["сформулировавши"],
    "сформулировавши": ["сформулировав"],
    "сфорцандо": ["сфорцато"],
    "сфотав": ["сфотавши"],
    "сфотавши": ["сфотав"],
    "сфотать": ["сфотографировать", "сфоткать", "снять"],
    "сфотаться": ["сфотографироваться", "сфоткаться", "сняться"],
    "сфоткав": ["сфоткавши"],
    "сфоткавши": ["сфоткав"],
    "сфоткать": ["сфотографировать", "сфотать", "снять"],
    "сфоткаться": ["сфотографироваться", "сфотаться", "сняться"],
    "сфотографировав": ["сфотографировавши"],
    "сфотографировавши": ["сфотографировав"],
    "сфотографировать": ["снять", "сфоткать", "сфотать", "зафотографировать"],
    "сфотографироваться": ["сняться", "сфоткаться", "сфотаться"],
    "сфрагистика": ["сигиллография"],
    "сфуговав": ["сфуговавши"],
    "сфуговавши": ["сфуговав"],
    "сфуговывав": ["сфуговывавши"],
    "сфуговывавши": ["сфуговывав"],
    "сфуговываться": ["фуговаться"],
    "схавав": ["схававши"],
    "схававши": ["схавав"],
    "схаживав": ["схаживавши"],
    "схаживавши": ["схаживав"],
    "схалтурив": ["схалтуривши"],
    "схалтуривши": ["схалтурив"],
    "схамив": ["схамивши"],
    "схамивши": ["схамив"],
    "схапав": ["схапавши"],
    "схапавши": ["схапав"],
    "схапавший": ["заграбаставший", "зажавший", "зажуливший", "запустивший руку", "захапавший", "зацапавший", "наложивший лапу", "наложивший руку", "прибравший к рукам", "пригрёбший к рукам", "прикарманивший", "урвавший", "хапнувший"],
    "схарапудити": ["налякати", "злякати"],
    "схарчив": ["схарчивши"],
    "схарчивши": ["схарчив"],
    "схарчить": ["съесть"],
    "схвастав": ["схваставши"],
    "схваставши": ["схвастав"],
    "схвастнув": ["схвастнувши"],
    "схвастнувши": ["схвастнув"],
    "схватив": ["схвативши"],
    "схвативши": ["схватив"],
    "схватить": ["захватить", "арестовать", "подцепить", "заполучить", "понять", "усвоить", "ухватить", "сковать", "прихватить", "скрутить"],
    "схватка": ["стычка", "борьба", "противостояние"],
    "схватчивый": ["понятливый"],
    "схватывав": ["схватывавши"],
    "схватывавши": ["схватывав"],
    "схема": ["структура", "блок-схема", "план", "чертёж", "электронная схема", "микросхема", "шаблон", "порядок", "сценарий", "схематоз"],
    "схематизировав": ["схематизировавши"],
    "схематизировавши": ["схематизировав"],
    "схематически": ["схематично"],
    "схематический": ["схематичный"],
    "схематично": ["схематически"],
    "схибнути": ["схибити"],
    "схизантус": ["шизантус"],
    "схизис": ["дискордантность", "интрапсихическая атаксия"],
    "схизма": ["раскол"],
    "схизмат": ["схизматик"],
    "схизматик": ["раскольник"],
    "схизматицький": ["схизматичний"],
    "схизматичний": ["схизматицький"],
    "схизонепета": ["шизонепета"],
    "схизофрения": ["шизофрения", "деменция прекокс", "раннее слабоумие"],
    "схизоцель": ["гемоцель"],
    "схиляв": ["схилявши"],
    "схилявши": ["схиляв"],
    "схима": ["аскетизм"],
    "схимив": ["схимивши"],
    "схимивши": ["схимив"],
    "схимичив": ["схимичивши"],
    "схимичивши": ["схимичив"],
    "схитрив": ["схитривши"],
    "схитривши": ["схитрив"],
    "схитрить": ["обмануть", "сфальшивить", "провести"],
    "схлебав": ["схлебавши"],
    "схлебавши": ["схлебав"],
    "схлебнув": ["схлебнувши"],
    "схлебнувши": ["схлебнув"],
    "схлеснув": ["схлеснувши"],
    "схлеснувши": ["схлеснув"],
    "схлеснуться": ["схлестнуться"],
    "схлестав": ["схлеставши"],
    "схлеставши": ["схлестав"],
    "схлестнув": ["схлестнувши"],
    "схлестнувши": ["схлестнув"],
    "схлопатывав": ["схлопатывавши"],
    "схлопатывавши": ["схлопатывав"],
    "схлопотав": ["схлопотавши"],
    "схлопотавши": ["схлопотав"],
    "схлопывание": ["схлопыванье", "сжатие", "закрытие"],
    "схлынув": ["схлынувши"],
    "схлынувши": ["схлынув"],
    "схлёбывав": ["схлёбывавши"],
    "схлёбывавши": ["схлёбывав"],
    "схлёстывав": ["схлёстывавши"],
    "схлёстывавши": ["схлёстывав"],
    "сховав": ["сховавши"],
    "сховавши": ["сховав"],
    "схованка": ["схов", "схованок", "сховок"],
    "сход-развал": ["развал-схождение"],
    "сходбище": ["сходка"],
    "сходив": ["сходивши"],
    "сходивши": ["сходив"],
    "сходить на нет": ["нивелироваться"],
    "сходно": ["похоже", "подобно"],
    "сходный": ["напоминающий", "похожий", "подобный", "схожий", "сходственный"],
    "сходня": ["суходня", "всходня", "входня", "выходня"],
    "сходство": ["похожесть", "подобие", "схожесть", "уподобление", "мимикрия", "подражание", "аналогия", "тождество", "симметрия"],
    "сходствовав": ["сходствовавши"],
    "сходствовавши": ["сходствовав"],
    "схождение": ["схожденье"],
    "схожденье": ["схождение"],
    "схожесть": ["похожесть", "подобие"],
    "схожий": ["подобный", "похожий", "сходный", "аналогичный"],
    "схожим образом": ["похоже", "похожим образом", "аналогично"],
    "схоластический": ["схоластичный"],
    "схоластичный": ["схоластический"],
    "схолия": ["примечание"],
    "схомячив": ["схомячивши"],
    "схомячивать": ["хомячить"],
    "схомячивши": ["схомячив"],
    "схорон": ["схоронка", "схрон"],
    "схороненный": ["похороненный", "захороненный", "погребённый"],
    "схоронив": ["схоронивши"],
    "схоронивши": ["схоронив"],
    "схоронить": ["похоронить", "захоронить", "погрести", "закопать", "предать земле", "спрятать", "укрыть", "упрятать", "запрятать", "припрятать"],
    "схорониться": ["спрятаться", "укрыться", "притаиться"],
    "схоронка": ["схорон", "схрон"],
    "схрон": ["тайник"],
    "схрумкав": ["схрумкавши"],
    "схрумкавши": ["схрумкав"],
    "схрумкать": ["схряпать"],
    "схряпав": ["схряпавши"],
    "схряпавши": ["схряпав"],
    "схряпать": ["схрумкать"],
    "схуднець": ["змарнець", "схудзець", "высахнуць", "выпетраць"],
    "схулиганив": ["схулиганивши"],
    "схулиганивши": ["схулиганив"],
    "схуячив": ["схуячивши"],
    "схуячивши": ["схуячив"],
    "сцав": ["сцавши"],
    "сцавши": ["сцав"],
    "сцаки": ["моча", "урина", "бурда", "пойло", "баланда", "брандахлыст", "бурдамага", "помои"],
    "сцапав": ["сцапавши"],
    "сцапавши": ["сцапав"],
    "сцапнув": ["сцапнувши"],
    "сцапнувши": ["сцапнув"],
    "сцапнуть": ["сцапать"],
    "сцапывав": ["сцапывавши"],
    "сцапывавши": ["сцапывав"],
    "сцарапав": ["сцарапавши"],
    "сцарапавши": ["сцарапав"],
    "сцарапнув": ["сцарапнувши"],
    "сцарапнувши": ["сцарапнув"],
    "сцарапывав": ["сцарапывавши"],
    "сцарапывавши": ["сцарапывав"],
    "сцать": ["ссать", "мочиться", "писать", "справляться по нужде", "ходить по-малому", "сосать", "сердиться", "раздражаться", "ссять", "бояться", "трусить", "дрейфить", "бздеть", "опасаться", "пугаться"],
    "сцедив": ["сцедивши"],
    "сцедивши": ["сцедив"],
    "сцеживав": ["сцеживавши"],
    "сцеживавши": ["сцеживав"],
    "сцементировав": ["сцементировавши"],
    "сцементировавши": ["сцементировав"],
    "сценарий": ["скрипт"],
    "сценарист": ["кинодраматург"],
    "сценический": ["театральный"],
    "сценичность": ["театральность"],
    "сцентрировав": ["сцентрировавши"],
    "сцентрировавши": ["сцентрировав"],
    "сцентрированный": ["сцентрованный"],
    "сцентрировать": ["сцентровать"],
    "сцентровав": ["сцентровавши"],
    "сцентровавши": ["сцентровав"],
    "сцентрованный": ["сцентрированный"],
    "сцепив": ["сцепивши"],
    "сцепивши": ["сцепив"],
    "сцепка": ["упряжь"],
    "сцепленье": ["сцепление"],
    "сцепляв": ["сцеплявши"],
    "сцеплявши": ["сцепляв"],
    "сциентологический": ["саентологический", "сайентологический"],
    "сциентология": ["сайентология"],
    "сцилла": ["пролеска"],
    "сцинтиллировав": ["сцинтиллировавши"],
    "сцинтиллировавши": ["сцинтиллировав"],
    "сциопод": ["монопод", "монокуль"],
    "сциофит": ["тенелюб"],
    "сцифоидные": ["сцифомедузы"],
    "счавкав": ["счавкавши"],
    "счавкавши": ["счавкав"],
    "счалив": ["счаливши"],
    "счаливав": ["счаливавши"],
    "счаливавши": ["счаливав"],
    "счаливать": ["чалить"],
    "счаливши": ["счалив"],
    "счалка": ["счаливание", "чал", "счал"],
    "счастие": ["счастье"],
    "счастливейший": ["наисчастливейший"],
    "счастливец": ["счастливчик", "везун", "везунчик"],
    "счастливив": ["счастлививши"],
    "счастлививши": ["счастливив"],
    "счастливица": ["удачница"],
    "счастливо": ["удачно", "успешно"],
    "счастливчик": ["счастливец", "везунчик", "любимец судьбы", "удачник", "удачливый", "родиться в рубашке"],
    "счастье": ["благополучие", "благоденствие", "благодать", "блаженство", "успех", "удача", "случай", "счастие"],
    "счеканив": ["счеканивши"],
    "счеканивав": ["счеканивавши"],
    "счеканивавши": ["счеканивав"],
    "счеканивши": ["счеканив"],
    "счерпав": ["счерпавши"],
    "счерпавши": ["счерпав"],
    "счерпнув": ["счерпнувши"],
    "счерпнувши": ["счерпнув"],
    "счерпывав": ["счерпывавши"],
    "счерпывавши": ["счерпывав"],
    "счертив": ["счертивши"],
    "счертивши": ["счертив"],
    "счерчивав": ["счерчивавши"],
    "счерчивавши": ["счерчивав"],
    "счесав": ["счесавши"],
    "счесавши": ["счесав"],
    "счесть": ["сосчитать", "посчитать"],
    "счетверив": ["счетверивши"],
    "счетверивши": ["счетверив"],
    "счетоведение": ["счетоводство", "бухгалтерия"],
    "счетовод": ["бухгалтер"],
    "счетоводка": ["бухгалтерша"],
    "счетоводство": ["бухгалтерия"],
    "счетоводша": ["счетоводка"],
    "счисленье": ["счисление"],
    "счислив": ["счисливши"],
    "счисливши": ["счислив"],
    "счисляв": ["счислявши"],
    "счислявши": ["счисляв"],
    "счистив": ["счистивши"],
    "счистивши": ["счистив"],
    "счистить": ["очистить", "зачистить"],
    "считав": ["считавши"],
    "считавши": ["считав"],
    "считаемый": ["подсчитываемый"],
    "считалка": ["считалочка"],
    "считание": ["счёт", "отсчёт", "пересчитывание"],
    "считанье": ["считание"],
    "считать": ["рассчитывать", "вычислять", "обсчитывать", "пересчитывать", "перечислять", "вести перекличку", "иметь в виду", "учитывать"],
    "считать само собой разумеющимся": ["воспринимать как должное"],
    "считая": ["расчитывая", "вычисляя", "думая", "полагая"],
    "считывав": ["считывавши"],
    "считывавши": ["считывав"],
    "считывание": ["чтение"],
    "счищав": ["счищавши"],
    "счищавши": ["счищав"],
    "счёс": ["счёсывание", "счёска", "счёсыванье"],
    "счёсывав": ["счёсывавши"],
    "счёсывавши": ["счёсывав"],
    "счётная форма": ["счётный падеж"],
    "счётно-вычислительный": ["счётно-решающий"],
    "счётно-решающий": ["счётно-вычислительный"],
    "счётное слово": ["нумератив"],
    "счётный": ["вычислительный", "счетоводный", "исчислимый"],
    "счётный падеж": ["счётная форма"],
    "счёты": ["абак", "расчёты", "претензии", "недовольство"],
    "сшабрив": ["сшабривши"],
    "сшабривав": ["сшабривавши"],
    "сшабривавши": ["сшабривав"],
    "сшабривши": ["сшабрив"],
    "сшалив": ["сшаливши"],
    "сшаливши": ["сшалив"],
    "сшевельнув": ["сшевельнувши"],
    "сшевельнувши": ["сшевельнув"],
    "сшибав": ["сшибавши"],
    "сшибавши": ["сшибав"],
    "сшибив": ["сшибивши"],
    "сшибивши": ["сшибив"],
    "сшибить": ["сбить", "снести"],
    "сшивав": ["сшивавши"],
    "сшивавши": ["сшивав"],
    "сшивальщик": ["сшивальщица"],
    "сшиватель": ["скоросшиватель", "степлер"],
    "сшивной": ["прошивной", "сквозной", "прокалывающий", "сшитый", "сшивающий"],
    "сшивши": ["сшив"],
    "сшинковав": ["сшинковавши"],
    "сшинковавши": ["сшинковав"],
    "сшинковать": ["нашинковать"],
    "сшить": ["скрепить"],
    "сшить в юбку": ["в юбку сшить"],
    "сшутив": ["сшутивши"],
    "сшутивши": ["сшутив"],
    "сщепляв": ["сщеплявши"],
    "сщеплявши": ["сщепляв"],
    "сщеплять": ["расщеплять"],
    "събирач": ["колекционер"],
    "съебав": ["съебавши"],
    "съебавши": ["съебав"],
    "съебаторы врубить": ["врубить съебаторы", "съебаться", "свалить", "сдристнуть"],
    "съебать": ["съебаться"],
    "съебаться": ["съебать", "свалить"],
    "съебошив": ["съебошивши"],
    "съебошивши": ["съебошив"],
    "съев": ["съевши"],
    "съедав": ["съедавши"],
    "съедавши": ["съедав"],
    "съедать": ["есть", "поедать", "поглощать", "портить", "разъедать", "изводить", "мучить"],
    "съеденье": ["съедение"],
    "съединоросить": ["скоммуниздить", "спионерить", "скомсомолить"],
    "съедобное": ["съестное"],
    "съедобный": ["съестной", "вкусный"],
    "съезд": ["горка", "скат", "выезд", "рампа", "слёт"],
    "съезд народных депутатов": ["снд"],
    "съездив": ["съездивши"],
    "съездивши": ["съездив"],
    "съездить": ["посетить", "вдарить", "вмазать", "ударить", "заехать"],
    "съезжав": ["съезжавши"],
    "съезжавши": ["съезжав"],
    "съезжаться": ["сближаться", "сходиться", "встречаться", "собираться", "сселяться"],
    "съезжая": ["съезжий дом"],
    "съезжий дом": ["съезжая"],
    "съестное": ["еда", "пища"],
    "съесть": ["скушать", "сожрать", "проглотить", "побить", "уничтожить", "израсходовать", "свести на нет", "разъесть"],
    "съехав": ["съехавши"],
    "съехавши": ["съехав"],
    "съехидничав": ["съехидничавши"],
    "съехидничавши": ["съехидничав"],
    "съехидничать": ["съязвить", "подколоть"],
    "създател": ["автор", "изобретател", "основател", "основоположник", "производител", "родоначалник", "съчинител", "творец", "учредител"],
    "сън": ["спане", "дрямка", "съновидение", "блян", "мечта", "илюзия", "утопия", "фантазия", "нереалност"],
    "състрадание": ["съчувствие"],
    "същество": ["създание", "организъм", "живина", "твар", "човек", "лице", "същина"],
    "съюморив": ["съюморивши"],
    "съюморивши": ["съюморив"],
    "съютив": ["съютивши"],
    "съютивши": ["съютив"],
    "съютить": ["собрать", "соединить", "объединить", "сблизить", "соорудить", "возвести", "обустроить", "смастерить", "сработать", "сладить", "свить", "снять", "арендовать"],
    "съябедничав": ["съябедничавши"],
    "съябедничавши": ["съябедничав"],
    "съязвив": ["съязвивши"],
    "съязвивши": ["съязвив"],
    "съякшавшись": ["сдружившись"],
    "съёбывав": ["съёбывавши"],
    "съёбывавши": ["съёбывав"],
    "съёбывать": ["сваливать", "уёбывать", "съёбываться", "съябывать", "съябываться", "уябывать"],
    "съёжив": ["съёживши"],
    "съёживав": ["съёживавши"],
    "съёживавши": ["съёживав"],
    "съёживши": ["съёжив"],
    "съёжиться": ["сжаться", "скорчиться", "скрючиться", "скукожиться"],
    "съём": ["снимание", "снятие", "аренда", "наём", "найм"],
    "съёмка": ["снятие", "снимание"],
    "съёрзнув": ["съёрзнувши"],
    "съёрзнувши": ["съёрзнув"],
    "съёрзывав": ["съёрзывавши"],
    "съёрзывавши": ["съёрзывав"],
    "сыворотка": ["сыравадка", "сыроводка"],
    "сыграв": ["сыгравши"],
    "сыгравши": ["сыграв"],
    "сыгранув": ["сыгранувши"],
    "сыгранувши": ["сыгранув"],
    "сыгрывав": ["сыгрывавши"],
    "сыгрывавши": ["сыгрывав"],
    "сыгъыт": ["сыйыт"],
    "сыздетства": ["издетства", "сызмала", "сызмалу", "сызмальства"],
    "сызлау": ["сызлав"],
    "сызмала": ["сызмалу", "сызмальства", "сыздетства", "сызмалости"],
    "сызмалу": ["сызмала", "сыздетства"],
    "сызмальства": ["сыздетства", "сызмала", "с малых лет", "с детства", "смолоду", "с пелёнок"],
    "сызнова": ["опять", "заново", "сначала", "снова", "повторно", "вновь", "вдругорядь"],
    "сызранка": ["сызрань"],
    "сый": ["сущий"],
    "сыйыт": ["сыгъыт"],
    "сыктывкар": ["усть-сысольск"],
    "сымав": ["сымавши"],
    "сымавши": ["сымав"],
    "сымак": ["сыман"],
    "сымать": ["снимать"],
    "сымать на нет": ["сводить"],
    "сымитировав": ["сымитировавши"],
    "сымитировавши": ["сымитировав"],
    "сымитировать": ["проимитировать", "скопировать", "смоделировать", "собезъянничать", "воспроизвести"],
    "сымпровизировав": ["сымпровизировавши"],
    "сымпровизировавши": ["сымпровизировав"],
    "сын": ["отпрыск", "потомок"],
    "сын стекольщика": ["не стеклянный"],
    "сына": ["сынка", "сынок"],
    "сынициировав": ["сынициировавши"],
    "сынициировавши": ["сынициировав"],
    "сынишка": ["сынок"],
    "сыновий": ["сыновний"],
    "сынок": ["сын"],
    "сыночек": ["сынок", "сынишка"],
    "сыныпташ": ["классташ"],
    "сыпав": ["сыпавши"],
    "сыпавши": ["сыпав"],
    "сыпанув": ["сыпанувши"],
    "сыпанувши": ["сыпанув"],
    "сыпать": ["моросить", "сеяться", "частить", "тараторить", "расточать", "сорить"],
    "сыпной тиф": ["сыпняк"],
    "сыпнув": ["сыпнувши"],
    "сыпнувши": ["сыпнув"],
    "сыпуха": ["осыпь"],
    "сыпучий": ["рыхлый", "рассыпной", "рассыпчатый", "сыпкий", "сыплющийся", "легкосыпучий"],
    "сыпь": ["высыпь"],
    "сыр": ["творог"],
    "сырев": ["сыревши"],
    "сыревши": ["сырев"],
    "сыриха": ["фанатка", "лемешистка"],
    "сырник": ["творожник", "чизкейк"],
    "сыровар": ["сыродел"],
    "сыроварение": ["сыроделие"],
    "сыроваренный": ["сыроварный", "сыродельный"],
    "сыроварный": ["сыроваренный", "сыродельный"],
    "сыроварня": ["сыродельня"],
    "сыровато": ["сыро"],
    "сыроватый": ["влажноватый", "мокроватый", "недожаренный", "недоваренный"],
    "сыродел": ["сыровар"],
    "сыроделие": ["сыроварение"],
    "сыродельный": ["сыроваренный", "сыроварный"],
    "сыродельня": ["сыроварня"],
    "сыродельческий": ["сыроварческий", "сыроваренный", "сыродельный"],
    "сыроежка": ["сыроега"],
    "сырок": ["сыр", "творог"],
    "сыромятина": ["сыромять"],
    "сыронизировав": ["сыронизировавши"],
    "сыронизировавши": ["сыронизировав"],
    "сырость": ["влажность"],
    "сырть": ["рыбец"],
    "сырцовый": ["нежжёный"],
    "сырьё вторичной переработки": ["вторичное сырьё", "вторсырьё"],
    "сыскав": ["сыскавши"],
    "сыскавши": ["сыскав"],
    "сыскарский": ["сыщицкий"],
    "сыскарь": ["сыскник", "сыщик"],
    "сыскать": ["отыскать", "разыскать", "расследовать"],
    "сыскивав": ["сыскивавши"],
    "сыскивавши": ["сыскивав"],
    "сыскник": ["сыскарь", "сыщик"],
    "сыта": ["сыть", "канун"],
    "сытев": ["сытевши"],
    "сытевши": ["сытев"],
    "сытив": ["сытивши"],
    "сытивши": ["сытив"],
    "сытный": ["питательный"],
    "сытый": ["насытившийся"],
    "сыть": ["ситовник", "циперус", "сытость", "насыщенность", "сытность", "питательность", "еда", "пища", "корм", "кормёжка", "харч", "питание", "пропитание", "сыта"],
    "сыч": ["сычик", "бирюк", "бука", "нелюдим"],
    "сычужина": ["химозин"],
    "сыщик": ["детектив", "дознаватель", "сыскарь", "следователь"],
    "сыщик-следователь": ["сыскарь"],
    "сьыв": ["бушков"],
    "сьюзен": ["сью"],
    "сэвэки": ["амака"],
    "сэвэнчэдеми": ["яядями"],
    "сэкономив": ["сэкономивши"],
    "сэкономивши": ["сэкономив"],
    "сэкономить": ["сберечь"],
    "сэкономленный": ["накопленный"],
    "сэлэм": ["илд"],
    "сэм": ["сэмюэл", "сэмми"],
    "сэмми": ["сэмюэл"],
    "сэмплер": ["семплер"],
    "сэмюэл": ["сэмюэль", "сэм", "сэмми"],
    "сэмюэль": ["сэмюэл"],
    "сэн": ["сень"],
    "сэндвич": ["сандвич"],
    "сэппуку": ["харакири"],
    "сэрман": ["сэрак"],
    "сэс": ["санэпидемслужба", "санэпидемстанция"],
    "сэсэн": ["акын"],
    "сюбжонктив": ["сослагательное наклонение"],
    "сювярлик": ["сиверлик"],
    "сюда": ["сюдакась", "сюдой", "сюдою", "сюды", "сюдытка", "сюдыкась", "туда", "здесь"],
    "сюдой": ["сюдою", "сюды", "сюда"],
    "сюжет": ["содержание", "канва", "фабула"],
    "сюжетик": ["сюжетец"],
    "сюлмамс": ["сотомс"],
    "сюне": ["сюнера"],
    "сюнеда": ["инкса", "кувалма"],
    "сюнну": ["хунну"],
    "сюр": ["сюрреализм"],
    "сюр-": ["сверх-", "над-"],
    "сюргис": ["гиргис"],
    "сюрикен": ["звёздочка"],
    "сюрко": ["накидка"],
    "сюркуп": ["подрезка"],
    "сюрприз": ["подарок", "сурприз", "игрушка-сюрприз", "неожиданность", "нежданчик"],
    "сюрреализм": ["сюр", "абсурд", "парадокс"],
    "сюрреалистический": ["сюрреалистичный", "необычный", "причудливый", "странный", "нетрадиционный", "парадоксальный", "абсурдный", "нереалистичный", "фантасмагорический", "фантасмагоричный", "иррациональный", "нелепый"],
    "сюртук": ["редингот", "пиджак", "лапсердак"],
    "сюртучишко": ["сертучишко"],
    "сюртучник": ["барин"],
    "сюрюнчяк": ["сюрюньчяк"],
    "сюсюкав": ["сюсюкавши"],
    "сюсюкавши": ["сюсюкав"],
    "ся": ["тона"],
    "сяб": ["спасибо", "благодарю", "спасибки", "сябки"],
    "сябар": ["сябра", "прыяцель"],
    "сявка": ["воришка", "проститутка", "ничтожество"],
    "сявомс": ["получамс", "нельгомс", "фатямс", "мумс", "ёрдамс", "ункстамс", "сёрмадомс"],
    "сягав": ["сягавши"],
    "сягавши": ["сягав"],
    "сягать": ["достигать"],
    "сяда": ["сядонга"],
    "сяда меле": ["меле", "оду", "сяльде", "мекпяли"],
    "сядонгольдень": ["тънярстонь"],
    "сяк": ["так", "эдак"],
    "сяка тев": ["фалу", "сидеста"],
    "сякнув": ["сякнувши"],
    "сякнувши": ["сякнув"],
    "сякой": ["такой-сякой", "разэдакий", "разэтакий"],
    "сякокс": ["сембе сяка"],
    "сялгомс": ["кърхцадемс", "пупамс", "пялемс", "повфтамс", "пезфтамс", "сардыяфтомс", "печкомс"],
    "сялдаз": ["кърга"],
    "сялдаз видева": ["кърга видева"],
    "сяльде": ["мекпяли", "меле", "сяда меле", "оду"],
    "сям": ["там", "здесь", "тут"],
    "сямжена": ["сямшенга"],
    "сямисэн": ["самисэн"],
    "сямынь": ["сямэнь", "амой"],
    "сянган": ["гонконг"],
    "сянкса": ["сяс", "сянкса штоба", "сянь кувалма"],
    "сянкса штоба": ["сянкса", "сянь кувалма"],
    "сянь кувалма": ["сянкса", "сянкса штоба"],
    "сяп": ["спасибо", "пасиб", "спс"],
    "сяс": ["сянкса"],
    "сяське": ["сеське"],
    "сё": ["это", "то"],
    "сёдзи": ["перегородка"],
    "сёдлывав": ["сёдлывавши"],
    "сёдлывавши": ["сёдлывав"],
    "сёдни": ["сёдне", "сёдня"],
    "сёйлемек": ["демек"],
    "сём-ка": ["давай", "давай-ка", "дай-ка", "ну", "ну-ка", "сем", "сём"],
    "сёмга": ["лосось", "благородный лосось", "атлантический лосось"],
    "сёмка": ["сёма"],
    "сёрбав": ["сёрбавши"],
    "сёрбавши": ["сёрбав"],
    "сёрбать": ["чавкать", "хлюпать"],
    "сёрпав": ["сёрпавши"],
    "сёрпавши": ["сёрпав"],
    "сёрпать": ["чавкать", "хлюпать", "прихлёбывать"],
    "сёрф": ["сёрфер", "сёрфинг"],
    "сёрфер": ["сёрфингист", "сёрф", "сёрфинг"],
    "сёрферный": ["сёрферский", "сёрфинговый", "сёрфовый"],
    "сёрфив": ["сёрфивши"],
    "сёрфивши": ["сёрфив"],
    "сёрфингист": ["сёрфер"],
    "т-киллер": ["клетка-киллер"],
    "та": ["телефон"],
    "табак": ["тютюн"],
    "табакерочка": ["табакерка"],
    "табакокурение": ["табакокуренье"],
    "табакокурильщик": ["курильщик"],
    "табакомания": ["никотинизм"],
    "табанив": ["табанивши"],
    "табанивши": ["табанив"],
    "табанить": ["таванить"],
    "табарган": ["тарабаган", "тарбаган"],
    "табасаран": ["табасаранец"],
    "табасаранец": ["табасаран"],
    "табассум": ["лабханд"],
    "табатерка": ["табакерка"],
    "табачив": ["табачивши"],
    "табачивши": ["табачив"],
    "табачить": ["табачиться"],
    "табачничав": ["табачничавши"],
    "табачничавши": ["табачничав"],
    "табачный сучок": ["табачный сук"],
    "табелировав": ["табелировавши"],
    "табелировавши": ["табелировав"],
    "табельный": ["штатный"],
    "табес": ["сухотка спинного мозга", "спинная сухотка"],
    "табити": ["гестия"],
    "таблетировав": ["таблетировавши"],
    "таблетировавши": ["таблетировав"],
    "таблица": ["табель", "массив"],
    "таблица пифагора": ["таблица умножения"],
    "таблица умножения": ["таблица пифагора"],
    "табло": ["индикатор", "лицо", "физиономия", "физия", "рыло", "ряха", "морда", "хлебало", "хлебальник", "пачка", "бубен", "ебало", "ебло"],
    "таблоид": ["бульварная газета", "жёлтая пресса"],
    "табльдот": ["комплексный обед"],
    "табор": ["стан", "гуляй-город", "обоз"],
    "табуизация": ["табуирование", "табуизирование"],
    "табуизировав": ["табуизировавши"],
    "табуизировавши": ["табуизировав"],
    "табуизирование": ["табуирование", "табуизация"],
    "табуизировать": ["табуировать"],
    "табуировав": ["табуировавши"],
    "табуировавши": ["табуировав"],
    "табуирование": ["табуизирование", "табуизация"],
    "табуированность": ["запретность"],
    "табуированный": ["запрещённый"],
    "табуировать": ["табуизировать"],
    "табулатура": ["табулятура", "таба"],
    "табулировав": ["табулировавши"],
    "табулировавши": ["табулировав"],
    "табулирование": ["табуляция"],
    "табулька": ["табуляграмма", "расчётка", "расчётный лист", "расчётный листок"],
    "табулятура": ["табулатура", "таба"],
    "табуляция": ["табулирование"],
    "табун": ["стадо", "толпа"],
    "табунець": ["табунок"],
    "табурет": ["табуретка"],
    "табуретка": ["табурет", "баночка", "тубарь", "тубаретка"],
    "таваллуд": ["зоиш"],
    "таванив": ["таванивши"],
    "таванивши": ["таванив"],
    "таванить": ["табанить"],
    "тавенисси": ["тавена", "табенна", "табенисси"],
    "таверна": ["трактир", "кабак", "рюмочная"],
    "таволга": ["лабазник"],
    "таволговий": ["таволжаний"],
    "таволожка": ["таволжанка"],
    "тавор": ["фавор"],
    "тавот": ["солидол"],
    "тавотив": ["тавотивши"],
    "тавотивши": ["тавотив"],
    "тавотник": ["тавотница"],
    "тавотниця": ["тавотник"],
    "тавотный": ["солидольный"],
    "таврение": ["клеймение"],
    "таврив": ["тавривши"],
    "тавривши": ["таврив"],
    "таврида": ["крым", "таврия"],
    "таврийский": ["крымский"],
    "таврика": ["таврида", "таврия", "крым"],
    "таврический": ["крымский"],
    "таврия": ["таврида", "таврика"],
    "тавро": ["клеймо", "железо", "калёное железо", "жегало", "жегло"],
    "тавромахия": ["тауромахия", "торео", "коррида"],
    "тавтологический": ["повторный", "тавтологичный"],
    "тавтологичный": ["тавтологический"],
    "тавтология": ["масло масляное", "плеоназм"],
    "тавукъ": ["тавух"],
    "тавух": ["тавук", "тавукъ"],
    "тагал": ["меш"],
    "тагальский": ["тагалог"],
    "таган": ["таганок"],
    "таганец": ["таганрожец"],
    "таганок": ["таган"],
    "таганочек": ["таганок"],
    "таганочок": ["таганок"],
    "тагъ": ["тав"],
    "тагын": ["тагы"],
    "тадбир": ["чора"],
    "таджик": ["таджикистанец"],
    "таджикистан": ["республика таджикистан", "таджикия"],
    "таджикистанец": ["таджик"],
    "таджикистанский": ["таджикский"],
    "таджикская сср": ["таджикистан"],
    "таджикский": ["таджикистанский"],
    "таеквон-до": ["тхэквондо", "тейквон-до"],
    "таем": ["тайно", "втайне", "тайком", "потайком"],
    "таех": ["таих", "талиг"],
    "таец": ["таиландец"],
    "таз": ["тазик", "шайка", "лохань"],
    "тазиковый": ["коксальный"],
    "таиб": ["тиб"],
    "таив": ["таивши"],
    "таивав": ["таивавши"],
    "таивавши": ["таивав"],
    "таивши": ["таив"],
    "таиланд": ["сиам"],
    "таиландец": ["таец", "сиамец"],
    "таиландка": ["тайка"],
    "таиландский": ["тайский", "сиамский", "таиландский язык"],
    "таиландский бокс": ["тайский бокс", "муай-тай"],
    "таинственность": ["загадочность"],
    "таинственный": ["загадочный"],
    "таинство": ["тайна", "тайнодействие"],
    "тай-брейк": ["овертайм"],
    "тай-чи": ["тайцзицюань"],
    "тайбэй": ["тайвань"],
    "тайвань": ["формоза", "китайская республика"],
    "тайговый": ["таёжный"],
    "тайка": ["таиландка"],
    "тайком": ["тайно", "скрытно", "украдкой"],
    "тайланд": ["таиланд", "сиам"],
    "тайм": ["период"],
    "тайм-код": ["таймкод"],
    "тайм-менеджмент": ["управление временем", "организация времени"],
    "таймений": ["тайменевый"],
    "тайминг": ["хронометраж", "хронометрирование", "кайрос", "задержка", "таймирование"],
    "таймкод": ["тайм-код"],
    "таймлапс": ["таймлэпс"],
    "тайна": ["загадка", "секрет"],
    "тайник": ["схрон", "нычка"],
    "тайно": ["втайне", "тайком", "скрытно"],
    "тайнобрачие": ["криптогамия"],
    "тайнобрачный": ["криптогамический"],
    "тайновиденье": ["тайновидение"],
    "тайновидец": ["ясновидец", "прозорливец", "предсказатель", "прорицатель"],
    "тайнодействие": ["таинство"],
    "тайный": ["секретный", "потайной", "сокровенный", "скрытый"],
    "тайр": ["парранда"],
    "тайский бокс": ["муай-тай", "тай-бокс"],
    "тайтл": ["название"],
    "тайтсы": ["легинсы", "лосины"],
    "тайфун": ["ураган"],
    "тайцзи": ["тайцзицюань", "тайчи"],
    "тайцзицюань": ["тайцзи", "тайчи"],
    "тайч": ["идиш-тайч", "лошн-койдэш"],
    "тайч-хумаш": ["тайч-хумеш"],
    "так": ["таким образом", "вот так", "настолько", "в такой мере", "до такой степени", "легко", "просто так", "до чего", "ну", "например", "а именно", "хм", "так-так"],
    "так ведь": ["не так ли"],
    "так же": ["таким же образом", "точно так же", "как и", "равно как и", "так же как", "подобно", "похоже", "одинаково", "аналогично"],
    "так и": ["да и"],
    "так и есть": ["в самом деле", "действительно", "действительно так", "и действительно", "вне сомнения", "вне всякого сомнения", "без обмана", "точно", "точно так", "иначе быть не может", "иначе и быть не может", "точняк", "в натуре"],
    "так и не": ["никогда", "ни разу"],
    "так или иначе": ["так или этак"],
    "так как": ["потому что", "поскольку", "ибо", "понеже", "бо"],
    "так себе": ["посредственный", "средний", "средненький", "посредственно", "средне", "средненько", "не бог весть"],
    "так точно": ["слушаюсь", "есть", "да"],
    "так что": ["таким образом", "следовательно", "стало быть"],
    "так-то": ["то-то же"],
    "такаббур": ["ифтихор"],
    "такавши": ["такав"],
    "таквин": ["офариниш"],
    "такелажив": ["такелаживши"],
    "такелаживши": ["такелажив"],
    "такелажник": ["грузчик", "стропальщик"],
    "такенный": ["такущий"],
    "также": ["тоже", "кроме того", "к тому же", "в равной мере", "вместе с тем", "равным образом", "при этом"],
    "таки": ["всё же", "однако же", "тем не менее"],
    "таким макаром": ["так", "таким образом"],
    "таким образом": ["итак", "в результате", "поэтому", "соответственно", "следовательно", "так что", "так"],
    "таким побытом": ["так", "таким образом", "таким макаром"],
    "такировий": ["такирний"],
    "такнув": ["такнувши"],
    "такнувши": ["такнув"],
    "таковой": ["такой"],
    "таковский": ["такой"],
    "такой": ["насколько", "столь", "до того", "некий"],
    "такой же": ["одинаковый"],
    "такой себе": ["так себе", "такой"],
    "такой-то": ["имярек"],
    "таколдомс": ["ёрамс", "улемс мяль"],
    "такса": ["тариф"],
    "таксатор": ["оценщик"],
    "таксация": ["учёт", "оценка"],
    "такси": ["таксомотор"],
    "таксидермист": ["чучельник"],
    "таксировав": ["таксировавши"],
    "таксировавши": ["таксировав"],
    "таксирование": ["таксация"],
    "таксировать": ["тарифицировать", "нормировать"],
    "таксировка": ["таксирование", "таксация"],
    "таксис": ["тропизм"],
    "таксия": ["такция"],
    "таксовав": ["таксовавши"],
    "таксовавши": ["таксовав"],
    "таксодиум": ["таксодий"],
    "таксомотор": ["такси"],
    "таксон": ["категория", "класс"],
    "таксономист": ["систематик"],
    "таксономическая единица": ["таксон"],
    "таксономическая категория": ["систематическая категория", "таксон", "таксономический ранг"],
    "таксофон": ["телефонная будка", "телефон-автомат", "телефон общего пользования"],
    "такт": ["шаг", "ход", "фаза", "этап", "ритм", "каданс", "пульс", "вежливость", "воспитанность", "выдержка", "дипломатичность", "тактичность"],
    "тактильний": ["дотикальний", "дотиковий"],
    "тактильно": ["осязательно", "на ощупь"],
    "тактильность": ["осязательность", "осязаемость", "предмет", "фактура", "текстура", "зримость", "чувственность"],
    "тактильный": ["осязательный"],
    "тактировав": ["тактировавши"],
    "тактировавши": ["тактировав"],
    "тактирование": ["настраивание", "синхронизация"],
    "тактическое голосование": ["вынужденное голосование", "умное голосование"],
    "тактично": ["деликатно", "приветливо", "любезно"],
    "тактичность": ["такт", "деликатность"],
    "тактичный": ["деликатный"],
    "тактный": ["тактовый"],
    "тактовый": ["тактный"],
    "такусенький": ["крохотный", "крошечный", "малюсенький", "малёхонький", "махонький", "крохотулечный"],
    "такущий": ["такенный"],
    "такция": ["таксия"],
    "такъалыбакъа": ["къапкъачлыбакъа"],
    "тал": ["тальник"],
    "талаз": ["вълна"],
    "талак": ["талах"],
    "талалакав": ["талалакавши"],
    "талалакавши": ["талалакав"],
    "таламус": ["задний таламус", "зрительный бугор"],
    "таланив": ["таланивши"],
    "таланивши": ["таланив"],
    "талантливость": ["талант", "дар", "дарование", "одарённость", "даровитость", "способность", "задатки"],
    "талантливый": ["одарённый", "даровитый"],
    "талантъ": ["даръ", "одарённость", "талантливость", "даровитость", "способность", "задатки"],
    "талас": ["дмитриевка"],
    "талассография": ["мореведение", "гидрография"],
    "талассотерапия": ["морелечение"],
    "талах": ["талак"],
    "талботипия": ["калотипия"],
    "талдычив": ["талдычивши"],
    "талдычивши": ["талдычив"],
    "талдычить": ["долдонить", "настаивать"],
    "талер": ["гульденгрош", "гульдинер", "йоахимсталер", "дальдер"],
    "талес": ["талит", "таллит"],
    "талец": ["ключ", "родник", "источник"],
    "талина": ["ива", "тал", "тальник"],
    "талинка": ["ива", "талина", "тал", "тальник"],
    "талисман": ["амулет", "оберег", "ладанка", "апотропей"],
    "талит": ["таллит", "талес"],
    "талия": ["фалия"],
    "талкан": ["кама"],
    "талкивав": ["талкивавши"],
    "талкивавши": ["талкивав"],
    "таллин": ["таллинн", "колывань", "ревель", "реваль", "линданизе"],
    "таллит": ["талит", "таллиф", "талес"],
    "таллиф": ["таллит"],
    "таллом": ["слоевище"],
    "талмудизм": ["начётничество", "догматизм", "схоластика"],
    "талмудистский": ["талмудический"],
    "талмудический": ["талмудистский"],
    "талнахец": ["талнахчанин"],
    "талнахчанин": ["талнахец"],
    "таловиця": ["таловина"],
    "таловый": ["ивовый"],
    "талон": ["талончик", "талонище", "квиток"],
    "талончик": ["талон"],
    "талышский": ["талышинский"],
    "тальгеймит": ["арсенопирит"],
    "талькохлорит": ["талькомагнезит", "жировик", "стеатит"],
    "тальник": ["тал", "талина"],
    "тальяночка": ["тальянка"],
    "там": ["тама", "тамотки", "потом", "затем", "впоследствии"],
    "там-там": ["тамтам"],
    "таман": ["тмутаракань"],
    "тамань": ["тмуторокань", "тмутаракань", "таманский полуостров"],
    "тамара": ["тамарочка"],
    "тамарикс": ["тамариск", "гребенщик", "божье дерево", "гребенчук", "бисерник", "жидовильник", "астраханская сирень", "дженгил"],
    "тамариксовый": ["тамарисковый"],
    "тамариндовый": ["тамариндный"],
    "тамариск": ["гребенщик", "тамарикс", "божье дерево", "гребенчук", "бисерник", "жидовильник", "астраханская сирень", "дженгил"],
    "тамарисковый": ["тамариксовый"],
    "тамасалык": ["тамашалык"],
    "таматарха": ["тмутаракань"],
    "тамаулипас": ["новый сантадер"],
    "тамбовец": ["тамбовчанин"],
    "тамбовская область": ["тамбовщина"],
    "тамбовчанин": ["тамбовец"],
    "тамбовщина": ["тамбовская область"],
    "тамбур": ["сени"],
    "тамбурин": ["бубен"],
    "тамга": ["родовой знак"],
    "тамил-наду": ["тамилнад"],
    "тамилнад": ["тамил-наду"],
    "таможня": ["таможенное управление", "мытница"],
    "тамоман": ["пурра", "комилан"],
    "тамотки": ["там"],
    "тамошобин": ["мухлис"],
    "тампакс": ["тампон"],
    "тамплиер": ["храмовник"],
    "тампонация": ["тампонада", "тампонирование"],
    "тампонировав": ["тампонировавши"],
    "тампонировавши": ["тампонировав"],
    "тамыз": ["август"],
    "тан": ["дон"],
    "тана": ["тенойока"],
    "танаис": ["танаид", "тен", "тан", "тин", "гилас", "дон", "северский донец"],
    "танаквисль": ["ванаквисль", "дон"],
    "танатоморфоз": ["гниение", "разложение", "тление"],
    "танатофобия": ["некрофобия"],
    "танах": ["еврейский", "библия"],
    "танбур": ["тамбур"],
    "тангаж": ["дифферент"],
    "танганьика": ["танганайка", "танзания"],
    "танганьикец": ["танганьиканец"],
    "тангенциальная распиловка": ["тангенциальный распил"],
    "танги-чу": ["танги", "липовка"],
    "тандем": ["дуэт", "пара"],
    "танення": ["розтавання"],
    "танец": ["пляска"],
    "танець": ["танок"],
    "танечний": ["танцювальний"],
    "танзания": ["объединённая республика танзания"],
    "танин": ["таннин"],
    "танит": ["таннита", "тиннит", "танк"],
    "таних": ["мэдэх"],
    "танкер": ["самолёт-заправщик"],
    "танкист": ["тракторист", "бронелобый"],
    "танковав": ["танковавши"],
    "танковавши": ["танковав"],
    "таннець": ["дзешавець"],
    "таннид": ["таннин"],
    "таннин": ["танин"],
    "тановул": ["таом"],
    "танри": ["адонай", "тэндри", "тэнри"],
    "танталовы муки": ["муки тантала"],
    "тантризм": ["тантра"],
    "тануць": ["патанаць"],
    "танхаз": ["танхизыдарья"],
    "танхизыдарья": ["танхаз", "танхаздарья", "танхазыдарья", "танхазы", "танхизадарья"],
    "танхо": ["танхвах"],
    "танцевав": ["танцевавши"],
    "танцевавши": ["танцевав"],
    "танцевать от печки": ["танцовать от печки"],
    "танцевать под дудку": ["плясать под дудку"],
    "танцовав": ["танцовавши"],
    "танцовавши": ["танцовав"],
    "танцовальный": ["плясовой"],
    "танцовать": ["танцевать", "плясать"],
    "танцовщик": ["балерун", "танцор", "плясун"],
    "танцовщица": ["танцорша", "плясунья"],
    "танцовывав": ["танцовывавши"],
    "танцовывавши": ["танцовывав"],
    "танцор": ["танцовщик"],
    "танцорка": ["танцовщица"],
    "танцорша": ["танцорка", "танцовщица"],
    "танцплощадка": ["танцпол"],
    "танцпол": ["танцплощадка"],
    "танцстудия": ["танцзал", "танцкласс"],
    "танцы с бубном": ["танцы с бубнами", "шаманство"],
    "танцювальник": ["танцюрист"],
    "танъры": ["худа", "алла", "ярадан", "рабби", "мевля", "илях", "чалап"],
    "танык": ["таных"],
    "таных": ["танык"],
    "таныхлых": ["таныклык"],
    "таньга": ["тенга"],
    "танютеллаяха": ["таню-телла-яха"],
    "таня": ["танюша", "танечка"],
    "тао": ["троицкий административный округ", "таймырский автономный округ"],
    "таоизм": ["даосизм", "таосизм"],
    "таом": ["авкот", "таъом"],
    "тапака": ["цыплёнок табака"],
    "тапиока": ["кассава"],
    "тапка": ["тапок"],
    "тапливав": ["тапливавши"],
    "тапливавши": ["тапливав"],
    "тапнув": ["тапнувши"],
    "тапнувши": ["тапнув"],
    "тапок": ["тапка", "тапочек", "тапочка"],
    "тапочек": ["тапочка", "тапка", "тапок"],
    "тапочка": ["тапочек", "тапок", "тапка"],
    "таптывав": ["таптывавши"],
    "таптывавши": ["таптывав"],
    "тапу": ["ко-тапу"],
    "тарабанив": ["тарабанивши"],
    "тарабанивши": ["тарабанив"],
    "тарабанить": ["колотить", "барабанить", "тараторить"],
    "тарабарив": ["тарабаривши"],
    "тарабаривши": ["тарабарив"],
    "тарабарщина": ["абракадабра", "бессмыслица", "китайская грамота"],
    "тарадайка": ["таратайка"],
    "тараджа": ["теряжя"],
    "тарак": ["таракъ", "тарах"],
    "таракан": ["тарасик", "друг", "сосед"],
    "таракановый": ["тараканий"],
    "таракану хуй приделать": ["снимать штаны и бегать", "снимать трусы и бегать"],
    "таракашка": ["тараканчик"],
    "таралли": ["тараллини"],
    "таранив": ["таранивши"],
    "таранивши": ["таранив"],
    "таранка": ["таранька", "тарань", "путассу"],
    "таранный": ["таранящий"],
    "тарановий": ["таранний"],
    "таранта": ["балабон", "балаболка", "балалайка", "бесструнная", "простоплет", "чечетка", "пустослов", "балабол", "пустоплет", "пустозвон", "пустобрех", "трепач", "тараторка", "пустомеля", "сорока"],
    "тарантачка": ["колымага"],
    "тарантив": ["тарантивши"],
    "тарантивши": ["тарантив"],
    "тарантить": ["частить", "тараторить", "трындычать", "лотошить", "трещать", "молоть"],
    "тарань": ["таранька"],
    "тарарам": ["шум", "грохот"],
    "тарарахав": ["тарарахавши"],
    "тарарахавши": ["тарарахав"],
    "тарарахнув": ["тарарахнувши"],
    "тарарахнувши": ["тарарахнув"],
    "тарас": ["тарасий"],
    "таратора": ["тараторка", "болтун"],
    "тараторение": ["тараторенье"],
    "тараторенье": ["тараторение"],
    "тараторив": ["тараторивши"],
    "тараторивши": ["тараторив"],
    "тараторить": ["частить", "трындычать", "тарантить", "лотошить", "трещать", "молоть", "стрекотать", "строчить", "трескотать"],
    "тараторка": ["таратора", "трещотка", "болтун"],
    "тарахкальце": ["брязкальце"],
    "тарахтев": ["тарахтевши"],
    "тарахтевши": ["тарахтев"],
    "тарахтенье": ["тарахтение"],
    "тарашкевица": ["классическое правописание"],
    "таращение": ["выпучивание"],
    "таращенье": ["таращение"],
    "таращив": ["таращивши"],
    "таращивши": ["таращив"],
    "таращить": ["выпучивать", "пучить", "выпяливать", "пялить"],
    "таращиться": ["глазеть", "пялиться", "пучиться"],
    "тарбаган": ["тарабаган", "табарган"],
    "тарберивчю": ["тарберювчю"],
    "таргамс": ["лихтемс", "нотфтамс", "шувомс", "вешемс", "мумс", "сатомс", "таргамс куватьс", "таргамс ламос", "ускомс", "таргамс сталма", "тердемс"],
    "таргамс вайме": ["нолдамс вайме кожф", "панемс кожф тевлавста"],
    "таргетировав": ["таргетировавши"],
    "таргетировавши": ["таргетировав"],
    "таргетолог": ["сммщик"],
    "тарелка": ["блюдо", "тарелочка", "блюдце", "блюдечко"],
    "тарельчатый": ["дисковый"],
    "тарзанка": ["банджи-джампинг"],
    "тарикат": ["сулук"],
    "тарировав": ["тарировавши"],
    "тарировавши": ["тарировав"],
    "тарирование": ["тарировка"],
    "тарировать": ["взвешивать", "калибровать", "юстировать", "эталонировать", "градуировать", "упаковывать"],
    "тарировка": ["тарирование", "калибровка"],
    "тариться": ["закупаться"],
    "тарифицировав": ["тарифицировавши"],
    "тарифицировавши": ["тарифицировав"],
    "тарифицировать": ["расценивать", "расценить"],
    "таркатий": ["строкатий", "плямистий", "цяткований", "тарканистий"],
    "тарлык": ["тарлых"],
    "тарлых": ["тарлык"],
    "тарма": ["киндер"],
    "тармак": ["ботак"],
    "тармалама": ["термалама"],
    "тармаламовый": ["термаламовый"],
    "тарник": ["тарщик"],
    "тароват": ["назорат"],
    "тароватый": ["щедрый", "тороватый"],
    "тарозу": ["мизон"],
    "тарона": ["суруд"],
    "тарпонообразный": ["элопсообразный"],
    "тарсальный": ["тарзальный"],
    "тарсондан": ["бим додан"],
    "тарсончак": ["тарсу"],
    "тартан": ["шотландка"],
    "тартана": ["тартан"],
    "тартар": ["тартарары"],
    "тартарары": ["ад", "преисподняя", "тартар", "пропасть", "гибель"],
    "тартиб": ["низом"],
    "тартор": ["главатар", "байрактар", "вожд", "войвода", "предводител"],
    "тарту": ["юрьев", "дерпт"],
    "тартюф": ["лицемер", "ханжа"],
    "тартюфовский": ["лицемерный"],
    "тартюфство": ["лицемерие", "ханжество"],
    "тархун": ["эстрагон"],
    "тархунный": ["эстрагонный", "эстрагоновый"],
    "тарщик": ["тарник"],
    "тары-бары": ["тары да бары", "тары-бары-растабары"],
    "тарёк": ["афюн"],
    "тас бол": ["таспол"],
    "таска": ["азас"],
    "таскав": ["таскавши"],
    "таскавши": ["таскав"],
    "тасканье": ["таскание"],
    "таскать": ["носить", "перетаскивать", "трепать", "дёргать", "водить", "изнашивать", "воровать", "красть"],
    "таскаться": ["шляться"],
    "таскивав": ["таскивавши"],
    "таскивавши": ["таскивав"],
    "таслиб": ["салб", "чормех"],
    "тасманийский": ["тасманский"],
    "тасманский": ["тасманийский"],
    "тасовав": ["тасовавши"],
    "тасовавши": ["тасовав"],
    "тасование": ["тасовка"],
    "тасочнейший": ["наитасочнейший"],
    "тасочный": ["смешной", "забавный", "потешный"],
    "таспол": ["тас бол"],
    "тастатура": ["номеронабиратель", "клавиатура"],
    "татакав": ["татакавши"],
    "татакавши": ["татакав"],
    "татар теле": ["татарча"],
    "татарва": ["татарьё"],
    "татарин": ["татарва", "татарщина"],
    "татария": ["татарстан"],
    "татаркин": ["татарочкин"],
    "татаро-монголы": ["монголо-татары"],
    "татаро-монгольский": ["монголо-татарский"],
    "татарский": ["татарский язык"],
    "татарский язык": ["татарский"],
    "татарстан": ["татария"],
    "татарщина": ["татарское иго", "монголо-татарское иго", "татаро-монгольское иго", "ордынское иго", "ордынское владычество", "ясак", "грубость", "дикость", "жестокость", "некультурность", "отсталость", "азиатчина", "татары", "татарва"],
    "татарьё": ["татарва"],
    "татко": ["татонько", "таточко", "татусь", "татусик", "татуньо"],
    "татковина": ["родина", "бащиния", "отечество"],
    "тато": ["батько"],
    "тату": ["татуировка", "наколка", "партак"],
    "татуаж": ["микропигментация", "дермопигментация", "контурный макияж", "тату-визаж"],
    "татуировав": ["татуировавши"],
    "татуировавши": ["татуировав"],
    "татуировка": ["тату", "татуаж", "наколка", "татуировочка", "татушка", "татуня"],
    "татуировщик": ["татуировальщик", "татумейкер"],
    "татуировщица": ["татуировальщица"],
    "татумейкер": ["тату-мастер", "мастер", "татуировка"],
    "татусик": ["татко"],
    "татусь": ["татко", "татонько", "таточко", "татусик", "татуньо"],
    "татуха": ["татуировка", "татушка"],
    "татушка": ["татуировка", "тату", "татуха"],
    "татцельвурм": ["шпрингвурм", "штоллвурм", "хазельвурм", "мурбль", "татцельбур"],
    "тать": ["вор", "похититель", "мошенник", "грабитель"],
    "татьба": ["воровство"],
    "татьяна": ["таня"],
    "тау": ["таф"],
    "тауз": ["траубенфельд"],
    "тауншип": ["таун"],
    "тауп": ["тауповый"],
    "тауромахия": ["тавромахия", "торео", "коррида"],
    "таутомерия": ["десмотропия"],
    "таутомерный": ["десмотропный"],
    "таутохронизм": ["таутохронность"],
    "таутохронность": ["таутохронизм", "равновременность"],
    "таф": ["тау"],
    "тафаккур": ["фикр", "ният", "фарз", "хаёл"],
    "тафиец": ["телебой"],
    "тафия": ["тафья"],
    "тафс": ["тафт"],
    "тафсон": ["тафтон"],
    "тафтон": ["гарм"],
    "тафтяной": ["тафтяный"],
    "тафтяный": ["тафтяной"],
    "тафья": ["тафия", "наплешник"],
    "тахина": ["ежемуха", "скоролётка"],
    "тахини": ["тахина", "тхина"],
    "тахинный": ["тахиновый"],
    "тахиновый": ["тахинный"],
    "тахион": ["дромотрон"],
    "тахипноэ": ["полипноэ"],
    "тахта": ["оттоманка"],
    "тачав": ["тачавши"],
    "тачавши": ["тачав"],
    "тачание": ["тачанье"],
    "тачивав": ["тачивавши"],
    "тачивавши": ["тачивав"],
    "тачка": ["тачание"],
    "тачскрин": ["сенсорный", "экран"],
    "таш": ["камень", "валун"],
    "таша": ["наташа", "наталия"],
    "ташбакъа": ["къапгъачлыбакъа", "такъалыбакъа"],
    "ташка": ["сума", "яхташ", "ягдташ", "ноша", "беремя", "охапка", "мышка", "подплечье"],
    "ташкентский договор": ["одкб", "ташкентский пакт"],
    "ташкентский пакт": ["одкб", "ташкентский договор"],
    "ташларга": ["ыргытырга"],
    "ташувати": ["розташовувати"],
    "тащив": ["тащивши"],
    "тащивши": ["тащив"],
    "тащить": ["волочить", "тянуть", "воровать", "красть"],
    "тащить нищего за хер": ["тянуть нищего за хер", "тащить нищих за хер", "тянуть нищих за хер", "тащить нищего за хуй", "тянуть нищего за хуй", "тащить нищих за хуй", "тянуть нищих за хуй"],
    "тащиться": ["тянуться", "волочиться", "плестись", "брести", "ковылять", "переться", "получать кайф", "наслаждаться"],
    "таъбир": ["фразеологизм"],
    "таълим гирифтан": ["таълим дидан"],
    "таълимгирифта": ["таълимдида"],
    "таълимдида": ["таълимгирифта"],
    "таъом": ["таом"],
    "таяв": ["таявши"],
    "таявши": ["таяв"],
    "таяние": ["плавление"],
    "таянье": ["таяние"],
    "таять": ["плавиться"],
    "таёжный": ["тайговый"],
    "тбилисец": ["тифлисец"],
    "тбилиси": ["тифлис"],
    "тв": ["телевизионное вещание", "телевидение", "телевизор"],
    "тварина": ["тварь", "тварюка", "тваринка"],
    "тваринництво": ["скотарство"],
    "тваринячий": ["тваринний"],
    "тварный": ["тленный", "животный", "вещественный", "материальный"],
    "тварь": ["создание", "животина", "животное", "тварина", "тварюка", "тваринка", "мразь", "скотина", "гад"],
    "тварюга": ["тварь"],
    "тварюка": ["тварь"],
    "твердев": ["твердевши"],
    "твердевши": ["твердев"],
    "твердение": ["затвердевание", "отвердевание", "застывание"],
    "твердеться": ["твердеть"],
    "твердив": ["твердивши"],
    "твердивши": ["твердив"],
    "твердить": ["повторять", "вдалбливать", "вколачивать"],
    "твердолобий": ["твердоголовий"],
    "твердолобый": ["глупый", "тупоголовый", "тупой"],
    "твердомер": ["дюрометр"],
    "твердосердый": ["жестокосердый"],
    "твердостойкий": ["стойкий"],
    "твердыня": ["крепость", "цитадель", "бастион", "фортеция", "замок", "оплот", "опора"],
    "твердь": ["земля", "суша", "купол неба", "небо", "твердыня", "твёрдость"],
    "тверия": ["тиверия", "тивериада", "табария", "тиберия"],
    "тверк": ["тверкинг"],
    "тверкав": ["тверкавши"],
    "тверкавши": ["тверкав"],
    "тверкинг": ["тверк"],
    "тверская область": ["калининская область"],
    "тверской": ["тверский"],
    "тверь": ["калинин"],
    "тверёзый": ["трезвый"],
    "твизл": ["твиззл"],
    "твистовав": ["твистовавши"],
    "твистовавши": ["твистовав"],
    "твит": ["твитт"],
    "твитив": ["твитивши"],
    "твитивши": ["твитив"],
    "твитнув": ["твитнувши"],
    "твитнувши": ["твитнув"],
    "твиттер": ["твитырь"],
    "твиттерив": ["твиттеривши"],
    "твиттеривши": ["твиттерив"],
    "твиттерный": ["твиттерский"],
    "твиттерский": ["твиттерный"],
    "творение": ["созидание", "творчество", "сооружение", "изготовление", "создание", "креатив", "шедевр", "существо", "тварь"],
    "творенье": ["творение"],
    "творец": ["создатель", "созидатель", "автор", "бог", "господь"],
    "творив": ["творивши"],
    "творивши": ["творив"],
    "творилка": ["творило", "квашня"],
    "творитель": ["творець"],
    "творительный": ["творческий", "креативный", "созидательный", "инструментальный"],
    "творительный падеж": ["инструменталис"],
    "творить": ["сотворять", "созидать", "создавать", "вершить", "чинить"],
    "творить суд": ["чинить суд", "вершить суд", "судить"],
    "творог": ["сыр"],
    "творожив": ["твороживши"],
    "твороживши": ["творожив"],
    "творожник": ["сырник"],
    "творожничек": ["сырничек"],
    "творожок": ["творог", "сырок"],
    "творческий": ["креативный"],
    "творчество": ["созидание", "творение", "наследие", "труд"],
    "твц": ["тв центр"],
    "твёрдо": ["устойчиво", "неколебимо", "непреклонно", "уверенно"],
    "твёрдость": ["стойкость", "решимость", "непоколебимость", "жёсткость", "механическое свойство", "способность"],
    "твёрдый": ["жёсткий", "застывший", "прочный", "устойчивый", "неколебимый", "непоколебимый"],
    "твёрдый знак": ["ер", "еръ"],
    "тгму": ["вгми", "вгму"],
    "тгту": ["политех"],
    "тд": ["торговый дом", "трудовой договор"],
    "тдзакв": ["квы"],
    "тднао": ["таймырский автономный округ", "тао"],
    "театр абсурда": ["драма абсурда"],
    "театр военных действий": ["твд"],
    "театр одного актёра": ["моноспектакль"],
    "театрализировав": ["театрализировавши"],
    "театрализировавши": ["театрализировав"],
    "театрализовав": ["театрализовавши"],
    "театрализовавши": ["театрализовав"],
    "театрализованный": ["драматизированный"],
    "театрализовать": ["инсценировать"],
    "театральничав": ["театральничавши"],
    "театральничавши": ["театральничав"],
    "театральность": ["наигранность"],
    "театральный": ["наигранный", "аффектированный"],
    "театростроительство": ["театростроение"],
    "тебаин": ["параморфин"],
    "тебеневав": ["тебеневавши"],
    "тебеневавши": ["тебеневав"],
    "тебриз": ["табриз", "тавриз"],
    "тевкати": ["плямкати"],
    "тевкр": ["секер", "зекер", "чаккара", "миз"],
    "тевтон": ["тевтонец", "немец"],
    "тевтонец": ["тевтон", "немец", "германец"],
    "тевтофобия": ["германофобия", "немцененавистничество"],
    "тевя": ["дэвэ", "тэвэ"],
    "тег": ["дескриптор"],
    "тегенди": ["шундый"],
    "тегер": ["копчек"],
    "тегерань": ["иранский экспресс", "шахид"],
    "тегировав": ["тегировавши"],
    "тегировавши": ["тегировав"],
    "теглайн": ["девиз", "слоган"],
    "тегло": ["тежина", "тежест"],
    "тегнув": ["тегнувши"],
    "тегнувши": ["тегнув"],
    "теж": ["також"],
    "тежина": ["тежест", "тегло", "маса", "авторитет", "влияние", "важност", "значение"],
    "теза": ["тезис"],
    "тезаврация": ["тезаврирование"],
    "тезаврировав": ["тезаврировавши"],
    "тезаврировавши": ["тезаврировав"],
    "тезаурус": ["идеографический словарь"],
    "тезей": ["тесей"],
    "тезировав": ["тезировавши"],
    "тезировавши": ["тезировав"],
    "тезисний": ["тезовий"],
    "тезоименитый день": ["именины", "тезоименитство"],
    "теин": ["кофеин", "гуаранин", "матеин"],
    "теист": ["верующий"],
    "теистический": ["религиозный"],
    "тейк": ["аргумент", "тезис", "заявление", "утверждение"],
    "тейлоризировав": ["тейлоризировавши"],
    "тейлоризировавши": ["тейлоризировав"],
    "тейпировав": ["тейпировавши"],
    "тейпировавши": ["тейпировав"],
    "текав": ["текавши"],
    "текавши": ["текав"],
    "текать": ["драпать", "тикать"],
    "текинский": ["туркменский"],
    "текодонт": ["орнитозух"],
    "текстиль": ["ткань", "материал"],
    "текстовка": ["подпись"],
    "текстовое": ["текстовуха"],
    "текстовой": ["текстовый"],
    "текстовыделитель": ["текстовыделительный маркер", "текст-маркер"],
    "текстовый": ["текстовой"],
    "текстуалист": ["начётчик", "буквалист"],
    "текстурировав": ["текстурировавши"],
    "текстурировавши": ["текстурировав"],
    "тектогенез": ["складчатость"],
    "тектоник": ["тектонист", "электро-дэнс"],
    "тектонист": ["тектоник"],
    "тектономагматический": ["тектоно-магматический"],
    "тектофугальный": ["ретинотектальный"],
    "текущий": ["сегодняшний", "нынешний", "актуальный", "повседневный"],
    "теламон": ["атлант", "атлас"],
    "теле-": ["дально-"],
    "телевариант": ["телеверсия"],
    "телевата": ["вата"],
    "телевещание": ["телевещанье"],
    "телевещанье": ["телевещание"],
    "телевидение": ["тв"],
    "телевидение высокой чёткости": ["твч"],
    "телевиденье": ["телевидение"],
    "телевизионная приставка": ["тв-приставка"],
    "телевизионная программа": ["телепрограмма", "телепередача", "программа передач"],
    "телевизионные консервы": ["консервы"],
    "телевизионный канал": ["телеканал", "твк"],
    "телевизор": ["телевидение", "рыболовный экран"],
    "телега": ["воз", "лямка", "кляуза"],
    "телеграмма": ["каблограмма"],
    "телеграмма-молния": ["телеграмммолния"],
    "телеграммно": ["телеграммой"],
    "телеграфив": ["телеграфивши"],
    "телеграфивши": ["телеграфив"],
    "телеграфировав": ["телеграфировавши"],
    "телеграфировавши": ["телеграфировав"],
    "телеевангелист": ["телепроповедник"],
    "тележив": ["тележивши"],
    "тележивши": ["тележив"],
    "тележить": ["тележничать", "доносить", "наговаривать", "клеветать", "беседовать", "обсуждать", "общаться"],
    "тележка": ["телега", "каретка", "вагонная тележка"],
    "телезвезда": ["теледива"],
    "телезрительство": ["телесмотрение"],
    "телеканал": ["твк"],
    "телекант": ["телекантус"],
    "телекантус": ["телекант"],
    "телекинез": ["психокинез"],
    "телеконвертер": ["телеэкстендер"],
    "телекс": ["телетайп"],
    "телемак": ["телемах"],
    "телемах": ["телемак", "тилемах"],
    "телеметр": ["дальномер"],
    "телемеханизировав": ["телемеханизировавши"],
    "телемеханизировавши": ["телемеханизировав"],
    "телеобъектив": ["телевик"],
    "телеология": ["предопределение", "детерминизм"],
    "телепав": ["телепавши"],
    "телепавши": ["телепав"],
    "телепат": ["экстрасенс"],
    "телепатировав": ["телепатировавши"],
    "телепатировавши": ["телепатировав"],
    "телепередача": ["трансляция", "телетрансляция", "телевизионная передача", "программа", "передача"],
    "телепортировав": ["телепортировавши"],
    "телепортировавши": ["телепортировав"],
    "телепостановка": ["телеспектакль"],
    "телесериал": ["телесерия"],
    "телесериальный": ["телесерийный"],
    "телесерийный": ["телесериальный"],
    "телесеть": ["телеканал"],
    "телескоп": ["подзорная труба"],
    "телесмотрение": ["телезрительство"],
    "телесность": ["материальность", "телеса"],
    "телеспектакль": ["телевизионный спектакль"],
    "телетайп": ["телекс"],
    "телетайпировав": ["телетайпировавши"],
    "телетайпировавши": ["телетайпировав"],
    "телефакс": ["факс"],
    "телефицировав": ["телефицировавши"],
    "телефицировавши": ["телефицировав"],
    "телефон": ["телефония", "телефонный аппарат", "телефонный номер", "номер телефона", "наушник"],
    "телефон-автомат": ["таксофон"],
    "телефонив": ["телефонивши"],
    "телефонивши": ["телефонив"],
    "телефонизировав": ["телефонизировавши"],
    "телефонизировавши": ["телефонизировав"],
    "телефонировав": ["телефонировавши"],
    "телефонировавши": ["телефонировав"],
    "телефонировать": ["звонить", "позвонить"],
    "телефонический": ["телефонный"],
    "телефонная будка": ["таксофон", "телефон-автомат", "телефон общего пользования"],
    "телефонный": ["коммуникационный", "связной"],
    "телефонный аппарат": ["телефон", "та"],
    "телец": ["телёнок", "бычок"],
    "телеш": ["телёнок"],
    "телешив": ["телешивши"],
    "телешивши": ["телешив"],
    "телешом": ["голышом", "нагишом", "в чём мать родила", "ню"],
    "телив": ["теливши"],
    "теливши": ["телив"],
    "телить": ["отелить", "тянуть", "медлить", "тормозить"],
    "телиться": ["отеляться", "медлить", "мешкать", "тормозить", "втыкать", "тупить"],
    "телица": ["тёлка", "тёлочка", "телушка"],
    "теллус": ["теллуда", "гея"],
    "телогрейка": ["душегрейка", "ватник"],
    "телодвижение": ["движение", "жест", "действие", "поступок", "активность"],
    "телодвиженье": ["телодвижение"],
    "телок": ["теля", "телёнок"],
    "теломера": ["теломер"],
    "телосложение": ["конституция", "комплекция", "фигура", "сложение"],
    "телосложенье": ["телосложение"],
    "телохранитель": ["бодигард", "секьюрити", "телохран"],
    "телугу": ["андхра"],
    "телушка": ["тёлка"],
    "тельбатий": ["тельбухатий"],
    "тельбухатий": ["тельбатий"],
    "тельник": ["тельняшка", "нательный крест"],
    "тельняшка": ["тельник", "тельняха"],
    "тельфер": ["таль"],
    "телэ": ["динлин", "гаочэ"],
    "теля": ["телёнок", "телок", "пентюх", "дурак"],
    "телячий восторг": ["щенячья радость"],
    "телёнок": ["телок", "телец"],
    "телёночек": ["телёнок"],
    "тем более": ["тем паче", "особенно"],
    "тем временем": ["тогда"],
    "тем не менее": ["всё же", "однако", "несмотря на это"],
    "тем паче": ["благо", "подавно", "тем более"],
    "тематизировав": ["тематизировавши"],
    "тематизировавши": ["тематизировав"],
    "тембр": ["зык", "разнозык", "позвук"],
    "тембральный": ["тембровый"],
    "темень": ["мрак", "тьма", "темь"],
    "темерницкий": ["темерский"],
    "темечко": ["темя"],
    "темна вода во облацех": ["тайна за семью печатями"],
    "темнев": ["темневши"],
    "темневши": ["темнев"],
    "темнее": ["темней"],
    "темней": ["темнее"],
    "темнеть": ["затемняться", "вечереть", "смеркаться", "чернеть", "мрачнеть"],
    "темнив": ["темнивши"],
    "темнивши": ["темнив"],
    "темнила": ["обманщик", "хитрец"],
    "темнить": ["чернить", "хитрить"],
    "темница": ["тюрьма"],
    "темноволосый": ["брюнет", "брюнетистый", "чернявый"],
    "темноглазый": ["темноокий"],
    "темнокожий": ["смуглокожий"],
    "темнолиственный": ["темнолистый"],
    "темнолистый": ["темнолиственный"],
    "темнолицый": ["смуглолицый"],
    "темноокий": ["темноглазый"],
    "темноспондильный": ["расчленённопозвонковый"],
    "темнушка": ["кладовка", "чулан", "тёщина комната"],
    "темный": ["тематический"],
    "темным-темно": ["темным-темнёшенько"],
    "темнёхонький": ["темнёшенький"],
    "темнёхонько": ["темнёшенько"],
    "темнёшенький": ["темнёхонький"],
    "темнёшенько": ["темнёхонько"],
    "теморхона": ["тиморхона"],
    "темп": ["скорость"],
    "темперамент": ["нрав", "характер", "темпераментность", "энергичность", "чувственность"],
    "темпераментный": ["пламенный", "энергичный", "горячий", "пылкий"],
    "температура": ["жар"],
    "температурив": ["температуривши"],
    "температуривши": ["температурив"],
    "темперировав": ["темперировавши"],
    "темперировавши": ["темперировав"],
    "темь": ["тьма", "темень", "темнота"],
    "темьян": ["чабрец", "тимьян", "ладан", "фимиам"],
    "темэн": ["орыжъ"],
    "темя": ["макушка", "верхушка", "вершина"],
    "темяшив": ["темяшивши"],
    "темяшивши": ["темяшив"],
    "тенарон": ["матапан"],
    "тенденциозничав": ["тенденциозничавши"],
    "тенденциозничавши": ["тенденциозничав"],
    "тенденциозно": ["предвзято", "пристрастно", "необъективно"],
    "тенденциозность": ["предвзятость", "пристрастность", "необъективность"],
    "тенденциозный": ["предвзятый", "пристрастный", "необъективный"],
    "тенденция": ["тренд", "тенденциозность", "наклонность"],
    "тендир": ["тандур", "тандыр", "танур", "тонир", "тонэ"],
    "теневой": ["тенистый", "тенелюбивый", "отрицательный", "неблагоприятный", "негативный", "неофициальный", "подпольный", "криминальный"],
    "теневой кабинет": ["теневое правительство", "теневой кабинет министров"],
    "теневыносливый": ["тенелюбивый"],
    "тенелюб": ["сциофит", "гелиофоб"],
    "тенелюбивый": ["теневыносливый"],
    "тенив": ["тенивши"],
    "тенивши": ["тенив"],
    "тенистый": ["затенённый"],
    "теннесси": ["добровольческий штат"],
    "теннессин": ["унунсептий", "эка-астат"],
    "теннис": ["лаун-теннис", "большой теннис", "пинг-понг", "настольный теннис"],
    "теннисист": ["белобрючник"],
    "тенниска": ["майка", "рубашка", "поло"],
    "тенок": ["танок"],
    "тенсона": ["тенцона", "партимен"],
    "тентакль": ["щупальце"],
    "тенцона": ["тенсона"],
    "тень": ["тенёк", "дух", "призрак", "видение", "привидение", "фантом", "очертание", "силуэт", "фигура", "подполье"],
    "теньгизь": ["тэнгиз"],
    "тенькав": ["тенькавши"],
    "тенькавши": ["тенькав"],
    "тенькнув": ["тенькнувши"],
    "тенькнувши": ["тенькнув"],
    "тенятник": ["паук"],
    "тенёк": ["тень"],
    "тенёта": ["сети", "путы", "паутина"],
    "тенётник": ["паук", "паутина"],
    "теобромин": ["диметилксантин"],
    "теодицея": ["богооправдание"],
    "теозис": ["обожение"],
    "теократизировав": ["теократизировавши"],
    "теократизировавши": ["теократизировав"],
    "теолог": ["богослов"],
    "теологический": ["богословский"],
    "теология": ["богословие"],
    "теорвер": ["теория вероятностей", "тервер"],
    "теорема эскобара": ["аксиома эскобара", "эскобар"],
    "теоретизировав": ["теоретизировавши"],
    "теоретизировавши": ["теоретизировав"],
    "теоретизированье": ["теоретизирование"],
    "теоретический минимум": ["теормин", "термин"],
    "теоретичный": ["отвлечённый", "абстрактный", "умозрительный"],
    "теория": ["предположение", "спекуляция", "суждение"],
    "теория вероятностей": ["теорвер", "тервер"],
    "теория заговора": ["конспирология"],
    "теория познания": ["эпистемология", "гносеология"],
    "теория решения изобретательских задач": ["триз"],
    "теормех": ["термех"],
    "теософический": ["теософский"],
    "теософия": ["духоведение"],
    "теософский": ["теософический"],
    "теотокология": ["мариология"],
    "теофания": ["феофания"],
    "тепер": ["зараз"],
    "теперешний": ["нынешний", "современный"],
    "теперича": ["теперь", "в настоящее время", "ныне", "нынче"],
    "теперь": ["сейчас", "сегодня", "в настоящее время", "нынче", "ныне", "отныне", "далее"],
    "теперь же": ["немедленно", "безотлагательно"],
    "тепидарий": ["тепидариум"],
    "теплев": ["теплевши"],
    "теплевши": ["теплев"],
    "теплесенький": ["тепленький"],
    "теплив": ["тепливши"],
    "тепливши": ["теплив"],
    "теплица": ["парник", "оранжерея"],
    "тепличность": ["изнеженность"],
    "тепло": ["теплота", "душевность", "сердечность"],
    "тепловизор": ["прибор ночного видения"],
    "тепловое излучение": ["теплоизлучение"],
    "тепловой пункт": ["тп", "теплоузел"],
    "тепловыделяющий элемент": ["твэл"],
    "теплозащита": ["термозащита"],
    "теплозащитный": ["термозащитный"],
    "теплоизлучение": ["тепловое излучение", "термоизлучение"],
    "теплоизоляция": ["термоизоляция"],
    "теплокровность": ["гомойотермия", "эндотермность"],
    "теплокровный": ["гомойотермный"],
    "теплолюбивый": ["термофильный"],
    "теплонагреватель": ["обогреватель", "калорифер"],
    "теплонагревательный элемент": ["тэн"],
    "теплообменник": ["подогреватель"],
    "теплопроводный": ["теплопроницаемый", "теплопроводящий"],
    "теплопроводящий": ["теплопроводный", "теплопроницаемый"],
    "теплоресурс": ["тепловой ресурс"],
    "теплосбережение": ["теплосохранение"],
    "теплосодержание": ["энтальпия", "тепловая функция"],
    "теплостойкий": ["теплоупорный"],
    "теплосчётчик": ["тепломер"],
    "теплоупорность": ["теплостойкость"],
    "теплоупорный": ["теплостойкий"],
    "теплоустойчивость": ["теплостойкость"],
    "теплофицировав": ["теплофицировавши"],
    "теплофицировавши": ["теплофицировав"],
    "теплоэлектростанция": ["тепловая электростанция", "тэс"],
    "теплоэлектроцентраль": ["тэц"],
    "теплынь": ["тепло"],
    "тепляк": ["подсобка", "теплик"],
    "теплёхонький": ["теплёшенький"],
    "теплёхонько": ["теплёшенько"],
    "теплёшенький": ["теплёхонький"],
    "теплёшенько": ["теплёхонько"],
    "теппа": ["тал"],
    "тер-ри-кон": ["террикон"],
    "терабайт": ["тебибайт"],
    "терабайтный": ["терабайтовый"],
    "терабайтовый": ["терабайтный"],
    "терагерц": ["тгц"],
    "теракт": ["террористический акт"],
    "терапевт": ["интернист", "психотерапевт"],
    "терапевтика": ["терапия", "врачеванье"],
    "терат": ["тератоморф"],
    "тератоморф": ["уродство", "терат"],
    "тербат": ["территориальный батальон"],
    "тервер": ["теорвер", "теория вероятностей"],
    "тервинг": ["вестгот"],
    "теребив": ["теребивши"],
    "теребивши": ["теребив"],
    "теребить": ["дёргать", "перебирать", "надоедать", "собирать"],
    "теребиться": ["собираться"],
    "теребление": ["тереб", "теребка", "теребленье"],
    "теребленье": ["теребление", "тереб", "теребка"],
    "теребонькав": ["теребонькавши"],
    "теребонькавши": ["теребонькав"],
    "теребонькать": ["теребить", "тормошить", "дергать"],
    "терек": ["терка", "терексу", "термадонт", "термодонт", "ломеки"],
    "терем": ["чердак", "вышка"],
    "тереть": ["жать", "давить", "натирать"],
    "тереться": ["ошиваться", "околачиваться", "тусоваться"],
    "терзав": ["терзавши"],
    "терзавши": ["терзав"],
    "терзать": ["раздирать"],
    "терзия": ["абаджия", "шивач"],
    "теризбирком": ["тик"],
    "териология": ["маммалогия", "маммалиология"],
    "териоморфизм": ["зооморфизм"],
    "терк": ["образец", "модел", "калъп"],
    "терлиця": ["терниця"],
    "терлич": ["тирлич"],
    "термалама": ["тармалама"],
    "термаламовый": ["тармаламовый"],
    "термех": ["теормех"],
    "термин": ["терминус"],
    "терминал": ["консоль оператора"],
    "терминатив": ["предельный падеж", "вентив"],
    "терминатор": ["согласованная нагрузка"],
    "терминировав": ["терминировавши"],
    "терминировавши": ["терминировав"],
    "терминоведение": ["терминология"],
    "терминография": ["прикладное терминоведение"],
    "терминологизировав": ["терминологизировавши"],
    "терминологизировавши": ["терминологизировав"],
    "терминологизовав": ["терминологизовавши"],
    "терминологизовавши": ["терминологизовав"],
    "терминология": ["терминоведение"],
    "терминус": ["термин"],
    "термионный": ["термоионный", "термоэлектронный"],
    "термистор": ["терморезистор", "термосопротивление"],
    "термитный": ["термитовый"],
    "термитовый": ["термитный"],
    "термо-": ["тепло-"],
    "термобатиграф": ["батитермограф"],
    "термогигрометр": ["термогигрограф"],
    "термография": ["термоскопия", "тепловидение"],
    "термодатчик": ["датчик температуры"],
    "термозащита": ["теплозащита"],
    "термозащитный": ["теплозащитный"],
    "термоизлучение": ["теплоизлучение", "тепловое излучение"],
    "термоизоляция": ["теплоизоляция"],
    "термокаустика": ["гальванокаустика", "гальванотермия", "электрокаустика"],
    "термокоагуляция": ["термокаустика"],
    "термокружка": ["кружка-термос"],
    "термолифтинг": ["термаж"],
    "термомагнетизм": ["магнитный эффект зеебека"],
    "термометр": ["градусник"],
    "термообробка": ["термооброблення"],
    "термооброблення": ["термообробка"],
    "термоодеяло": ["электроодеяло"],
    "термопара": ["термоэлемент"],
    "термопаста": ["теплопроводная паста"],
    "термопласт": ["термопластик"],
    "термопластик": ["термопласт"],
    "термопластический": ["термопластичный"],
    "термопластичный": ["термопластический"],
    "терморегуляционный": ["терморегулирующий", "теплорегулирующий", "термотаксический"],
    "терморегуляция": ["теплорегуляция"],
    "термоскопия": ["термография"],
    "термослияние": ["термосинтез"],
    "термосопротивление": ["терморезистор", "термистор"],
    "термостабильность": ["термостойкость"],
    "термостатировав": ["термостатировавши"],
    "термостатировавши": ["термостатировав"],
    "термостойкость": ["термостабильность"],
    "термотрансфер": ["термонаклейка", "термоаппликация"],
    "термотренировка": ["термоциклирование"],
    "термоусадка": ["термоусаживаемый", "трубка"],
    "термоустойчивый": ["жаростойкий"],
    "термофизика": ["теплофизика"],
    "термоэмиссия": ["термоэлектронная эмиссия"],
    "термоядерник": ["термоядерщик"],
    "термоядерный": ["водородный", "мощный", "ядрёный"],
    "термоядерный синтез": ["ядерный синтез"],
    "термоядерщик": ["термоядерник"],
    "тернарный": ["тринарный", "троичный", "трёхчленный"],
    "терние": ["дерябник", "колючка", "шип", "игла", "трудность", "невзгода", "горесть"],
    "терница": ["мялка", "льномялка"],
    "терно": ["кашмир-терно"],
    "тернополец": ["тернопольчанин"],
    "тернопольская область": ["тернопольщина"],
    "тернослив": ["тернослива"],
    "тернье": ["терние"],
    "тероборонец": ["трошник"],
    "тероморф": ["синапсид"],
    "теропод": ["звероногий"],
    "терпана": ["ферапна"],
    "терпев": ["терпевши"],
    "терпевши": ["терпев"],
    "терпеливо": ["великодушно"],
    "терпеливость": ["терпение", "терпеть", "терпенье", "выдержка"],
    "терпеливый": ["настойчивый"],
    "терпен": ["монотерпен", "терпеноид"],
    "терпение": ["терпенье", "терпеливость", "выдержка", "терпёж", "постоянство", "настойчивость", "упорство", "ожидание"],
    "терпение и труд всё перетрут": ["терпенье и труд всё перетрут"],
    "терпентин": ["скипидар"],
    "терпентинное масло": ["скипидар"],
    "терпенье": ["терпение", "терпеливость", "выдержка", "терпёж"],
    "терпеть": ["переносить", "сносить", "ждать", "мириться", "очень", "не", "любить", "допускать", "испытывать", "переживать"],
    "терпеть крах": ["проваливаться", "терпеть фиаско"],
    "терпеть ненавидеть": ["недолюбливать"],
    "терпеть неудачу": ["терпеть крах", "терпеть фиаско"],
    "терпила": ["жертва", "потерпевший", "лох", "фраер", "политический заключенный"],
    "терпимо": ["сносно"],
    "терпимость": ["толерантность"],
    "терпимый": ["толерантный", "веротерпимый"],
    "терпливав": ["терпливавши"],
    "терпливавши": ["терпливав"],
    "терпнув": ["терпнувши"],
    "терпнувши": ["терпнув"],
    "терпсихорейский": ["танцевальный", "плясовой"],
    "терпуг": ["терпуга"],
    "терпёж": ["терпение"],
    "терра": ["незнакомый", "область", "неисследованный", "территория", "неизученный", "проблема"],
    "терра инкогнита": ["незнакомый", "область", "неисследованный", "территория", "неизученный", "проблема"],
    "терракотовый": ["красновато-коричневый"],
    "террарий": ["террариум"],
    "террариум": ["террарий"],
    "террасировав": ["террасировавши"],
    "террасировавши": ["террасировав"],
    "террасирование": ["террасировка"],
    "террасовидный": ["террасообразный"],
    "террасообразный": ["террасовидный"],
    "терренкур": ["моцион", "променад"],
    "терренс": ["терри"],
    "терригенный": ["терригеновый"],
    "терригеновый": ["терригенный"],
    "террикон": ["терриконик", "отвал", "гора", "холм", "куча"],
    "территориальная оборона": ["тероборона", "тро"],
    "территориальное море": ["территориальные воды"],
    "территориальные воды": ["территориальное море"],
    "территориальный батальон": ["тербат"],
    "территориальный центр комплектования": ["тцк", "тцк и сп", "военный комиссариат", "военкомат"],
    "территория": ["земля"],
    "терроризировав": ["терроризировавши"],
    "терроризировавши": ["терроризировав"],
    "терроризировать": ["терроризовать", "ужасать", "кошмарить"],
    "терроризовав": ["терроризовавши"],
    "терроризовавши": ["терроризовав"],
    "терроризовать": ["терроризировать"],
    "террористический": ["террористский"],
    "террористический акт": ["террористическая атака", "теракт"],
    "тертер": ["мир-башир"],
    "терцет": ["трио", "терцина", "трёхстишие"],
    "терцина": ["терцет"],
    "теряв": ["терявши"],
    "терявши": ["теряв"],
    "теряжя": ["тараджа", "тержя"],
    "теряк": ["тёряк"],
    "терять": ["лишаться", "утрачивать", "ронять", "растрачивать", "тратить", "расходовать"],
    "терять счёт": ["без счёту", "счёту нет", "выше крыши"],
    "тесав": ["тесавши"],
    "тесавши": ["тесав"],
    "тесанув": ["тесанувши"],
    "тесанувши": ["тесанув"],
    "теслив": ["тесливши"],
    "тесливши": ["теслив"],
    "теслювати": ["теслярувати"],
    "тесля": ["тесляр"],
    "теслярувати": ["теслювати"],
    "теснив": ["теснивши"],
    "теснивши": ["теснив"],
    "теснина": ["долина", "дефиле", "дифелея", "каньон", "проход", "узина", "ущелье"],
    "тесниться": ["толпиться", "грудиться", "кучиться", "кучковаться", "толочься", "скучиваться", "табуниться", "жаться"],
    "теснота": ["тесность", "стеснённость"],
    "тесный": ["узкий"],
    "тессалия": ["фессалия"],
    "тессеракт": ["восьмиячейник", "октахор"],
    "тестенёк": ["тесть", "отец", "тестюга", "тестёк", "тестёк-батюшка", "тестютка", "тестюшко", "тестушко", "тестюшка", "тестюшка-батюшка", "тестик", "батюшка-тестик", "тестеть", "тестяга"],
    "тестикула": ["яичко", "семенник"],
    "тестировав": ["тестировавши"],
    "тестировавши": ["тестировав"],
    "тестировать": ["проверять", "испытывать", "пробовать"],
    "тестить": ["тестировать", "пробовать", "проверять", "испытывать"],
    "тесто": ["каша"],
    "тестовидный": ["тестообразный"],
    "тестомес": ["тестомесильщик"],
    "тестомесилка": ["тестомес", "тестомеска"],
    "тестообразный": ["тестовидный"],
    "тестостерон": ["андроген"],
    "тесть": ["тестюшка"],
    "тестюшка": ["тестенька"],
    "тесьма": ["тесёмка", "бахрома", "кант"],
    "тесьмив": ["тесьмивши"],
    "тесьмивши": ["тесьмив"],
    "тет-а-тет": ["наедине", "с глазу на глаз"],
    "тета": ["фита"],
    "тетерев": ["тетерев-косач", "балбес", "балда", "болван", "глупец", "дуралей", "дурачина", "дурень"],
    "тетерев-глухарь": ["глухарь"],
    "тетеревятник": ["ястреб-тетеревятник"],
    "тетерук": ["тетерюк", "тетервак", "тетерев", "тетеря"],
    "тетис": ["тефида", "тефия", "тетия", "тифия"],
    "тетра-": ["квадра-"],
    "тетрагидрогармин": ["термопсин"],
    "тетрагидроканнабинол": ["тгк"],
    "тетрагидрофуран": ["тетраметиленоксид", "фуранидин", "оксолан"],
    "тетрагон": ["четырёхугольник"],
    "тетраграмма": ["тетраграмматон"],
    "тетраграмматон": ["тетраграмма", "тетраграмон"],
    "тетрадка": ["тетрадь"],
    "тетрадон": ["фугу", "тетраодон", "иглобрюх"],
    "тетрадочка": ["тетрадка", "тетрадь"],
    "тетрадь": ["тетрадка"],
    "тетракисгексаэдр": ["тетрагексаэдр", "преломлённый куб"],
    "тетралогия": ["тетраптих"],
    "тетрамерный": ["четырёхчленный", "четырёхсубъединичный"],
    "тетраметилен": ["циклобутан"],
    "тетраодон": ["иглобрюх"],
    "тетрапак": ["коробка", "пакет"],
    "тетрапарез": ["тетраплегия", "квадриплегия"],
    "тетрапилон": ["тетрапил"],
    "тетраплегия": ["квадриплегия", "тетрапарез"],
    "тетрапод": ["четвероногий"],
    "тетрарх": ["четвертовластник"],
    "тетрархия": ["четверовластие"],
    "тетрацен": ["нафтацен"],
    "тетраэдр": ["четырёхгранник", "правильный тетраэдр"],
    "тетраэдральный": ["тетраэдрический", "четырёхгранный"],
    "тетраэдрический": ["тетраэдральный"],
    "тетраэтилсвинец": ["тэс"],
    "тетрил": ["нитрамин", "тетралит"],
    "тетум": ["тетун"],
    "тетурам": ["антабус", "дисульфирам"],
    "тетёрка": ["тетёра", "витушка", "жаворонок", "воробышек", "воробушек", "снегирёк", "кулик", "сорока", "петушок"],
    "тетёха": ["толстушка", "пышка", "пампушка", "пончик", "кубышка", "бочка", "тумба", "колода", "корова", "трупёрда"],
    "тетёшкав": ["тетёшкавши"],
    "тетёшкавши": ["тетёшкав"],
    "теургический": ["магический"],
    "тефида": ["тефия", "тетия", "тифия", "тетис"],
    "тефлон": ["политетрафторэтилен"],
    "тефтели": ["ёжик"],
    "тефтелька": ["кнель"],
    "технарь": ["техник"],
    "технизировав": ["технизировавши"],
    "технизировавши": ["технизировав"],
    "техника": ["машинерия", "мастерство"],
    "техника безопасности": ["тб", "охрана труда"],
    "техникум": ["колледж"],
    "технические требования": ["технические условия"],
    "технические условия": ["ту", "техусловия", "технические требования"],
    "технический": ["промышленный", "процедурный", "функциональный", "рутинный", "второстепенный", "формальный", "механический", "поверхностный", "неглубокий", "механистический"],
    "техническое требование": ["техническое условие"],
    "техническое условие": ["техническое требование"],
    "техничка": ["уборщица"],
    "технично": ["искусно", "мастерски"],
    "технократия": ["ноократия", "меритократия"],
    "технопоп": ["техно-поп"],
    "технорук": ["технический", "руководитель"],
    "техпомощь": ["помощь", "техподдержка", "автомеханика", "техотдел"],
    "техреволюция": ["научно-техническая революция"],
    "техсредство": ["техническое средство"],
    "техусловие": ["технические условия", "ту"],
    "течение": ["ток", "поток", "струя", "ход", "развитие", "направление", "движение"],
    "течка": ["эструс", "эструм"],
    "течь": ["литься", "струиться", "бежать", "катиться", "протекать", "двигаться", "приходить", "проходить", "миновать", "идти", "совершаться"],
    "тешив": ["тешивши"],
    "тешивши": ["тешив"],
    "тешить": ["радовать", "забавлять", "развлекать", "утешать"],
    "тз": ["техзадание"],
    "тиаго": ["тиагу", "тьягу"],
    "тиагу": ["тиаго", "тьягу"],
    "тиамин": ["аневрин"],
    "тиаминдифосфат": ["тиаминпирофосфат"],
    "тиара": ["диадема"],
    "тибрив": ["тибривши"],
    "тибривши": ["тибрив"],
    "тибур": ["тиволи"],
    "тигез": ["шома"],
    "тигим": ["тегим"],
    "тигр": ["лев", "орёл"],
    "тиграй": ["тыграй"],
    "тигрица": ["львица"],
    "тигролев": ["тигон"],
    "тигули": ["глухомань", "у чёрта на куличках"],
    "тиемс": ["анокламс", "петемс", "путомс", "кеподемс", "стяфтомс", "шарфтомс", "топафтомс", "ётафтомс эряфс", "пяшкодемс"],
    "тизерив": ["тизеривши"],
    "тизеривши": ["тизерив"],
    "тизерить": ["анонсировать"],
    "тизлик": ["тюзьлюк"],
    "тизь": ["тиз"],
    "тиийин": ["тийин"],
    "тииран": ["этиленсульфид", "тиоокись этилена", "диметиленсульфид"],
    "тика в тику": ["в точности", "точь-в-точь", "одновременно", "только-только", "еле-еле"],
    "тикав": ["тикавши"],
    "тикавши": ["тикав"],
    "тикле": ["тиклем"],
    "тикнув": ["тикнувши"],
    "тикнувши": ["тикнув"],
    "тиксотропия": ["тиксотропность"],
    "тиксотропность": ["тиксотропия"],
    "тикток-хаус": ["тикток-дом"],
    "тиле": ["акылсыз", "ахмак", "сантый"],
    "тиликав": ["тиликавши"],
    "тиликавши": ["тиликав"],
    "тилиликав": ["тилиликавши"],
    "тилиликавши": ["тилиликав"],
    "тилиликать": ["тиликать"],
    "тилинькав": ["тилинькавши"],
    "тилинькавши": ["тилинькав"],
    "тилинькающий": ["брякающий", "дзинькающий"],
    "тилиснув": ["тилиснувши"],
    "тилиснувши": ["тилиснув"],
    "тилл": ["тилль"],
    "тилло": ["зар"],
    "тиль": ["тил"],
    "тильтанув": ["тильтанувши"],
    "тильтанувши": ["тильтанув"],
    "тильтовав": ["тильтовавши"],
    "тильтовавши": ["тильтовав"],
    "тим": ["тимоти"],
    "тимбилдинг": ["командообразование"],
    "тиммейт": ["сокомандник", "товарищ по команде", "соратник", "напарник", "компаньон"],
    "тимоаналептик": ["тимолептик", "антидепрессант"],
    "тимолептик": ["тимоаналептик", "антидепрессант"],
    "тиморец": ["восточнотиморец"],
    "тимофеевич": ["тимофеич"],
    "тимофеевка": ["аржанец", "тимофеева трава"],
    "тимоха": ["тимофей"],
    "тимпанит": ["тимпания рубца"],
    "тимпания": ["метеоризм", "тимпанит"],
    "тимпанометрия": ["импедансометрия"],
    "тимус": ["вилочковая железа"],
    "тимьян": ["темьян", "тимиан", "тимян", "чабрец", "чебрец", "чеборец", "чебарка", "чабёр", "чобор", "богородская трава", "боровой перец", "верест", "жадобник", "лебюшка", "лимонный душок"],
    "тина": ["ил"],
    "тинао": ["новая москва"],
    "тинейджер": ["подросток", "юноша"],
    "тинейджър": ["младеж", "юноша"],
    "тинжис": ["тинга"],
    "тиноль": ["припой"],
    "тинь": ["динь"],
    "тинькав": ["тинькавши"],
    "тинькавши": ["тинькав"],
    "тинькування": ["штукатурення", "обштукатурювання"],
    "тиняти": ["блукати"],
    "тиокарбамид": ["тиомочевина"],
    "тиокетон": ["тион"],
    "тиол": ["меркаптан"],
    "тиомочевина": ["тиокарбамид"],
    "тион": ["тиокетон"],
    "тиофенол": ["фенилмеркаптан", "меркаптобензол"],
    "тиофосфат": ["фосфоротиоат"],
    "тиоциан": ["родан", "диродан", "дитиоциан", "сульфоциан"],
    "тип": ["вид", "чел", "человек"],
    "типа": ["вроде", "вроде бы", "как бы", "вроде как", "вроде как бы", "как будто", "навроде", "наподобие"],
    "типизировав": ["типизировавши"],
    "типизировавши": ["типизировав"],
    "типикон": ["трагос"],
    "типировав": ["типировавши"],
    "типировавши": ["типировав"],
    "типифицировав": ["типифицировавши"],
    "типифицировавши": ["типифицировав"],
    "типичный": ["характерный", "ярко выраженный", "типический", "обычный"],
    "типовой": ["стандартный", "однотипный"],
    "типограф": ["типографщик", "полиграфист"],
    "типографщик": ["типограф"],
    "типок": ["типчик", "типан", "типанок"],
    "типологизировав": ["типологизировавши"],
    "типологизировавши": ["типологизировав"],
    "типоразмер": ["форм-фактор"],
    "типунев": ["типуневши"],
    "типуневши": ["типунев"],
    "типчик": ["типок"],
    "тир": ["стрельбище"],
    "тирав": ["тиравши"],
    "тиравши": ["тирав"],
    "тирада": ["спич"],
    "тиражив": ["тираживши"],
    "тираживши": ["тиражив"],
    "тиражировав": ["тиражировавши"],
    "тиражировавши": ["тиражировав"],
    "тиражирование": ["репродуцирование"],
    "тиражироваться": ["копироваться", "размножаться"],
    "тиран": ["деспот", "угнетатель", "самодур"],
    "тиранив": ["тиранивши"],
    "тиранивши": ["тиранив"],
    "тиранизировав": ["тиранизировавши"],
    "тиранизировавши": ["тиранизировав"],
    "тиранизировать": ["тиранить"],
    "тиранить": ["угнетать", "гнобить", "изводить"],
    "тираничный": ["деспотичный", "придирчивый"],
    "тиранка": ["тиранша"],
    "тиранничав": ["тиранничавши"],
    "тиранничавши": ["тиранничав"],
    "тираноубийство": ["цареубийство"],
    "тиранский": ["тиранический"],
    "тиранствовав": ["тиранствовавши"],
    "тиранствовавши": ["тиранствовав"],
    "тире": ["черта", "чёрточка"],
    "тиреотоксикоз": ["гипертиреоз"],
    "тиреотропный гормон": ["тиреотропин", "тиротропин"],
    "тирил": ["тириль"],
    "тириль": ["тирил"],
    "тирлич": ["терлич"],
    "тировав": ["тировавши"],
    "тировавши": ["тировав"],
    "тирозиназа": ["фенолаза", "катехолоксидаза", "монофенолоксидаза"],
    "тиротропин": ["тиреотропин"],
    "тиррен": ["тирсен", "этруск", "пеласг"],
    "тирренское море": ["авсонийское море", "нижнее море"],
    "тиртханкар": ["тиртханкара"],
    "тиртханкара": ["тиртханкар", "тирхакара"],
    "тирукамон": ["рангинкамон"],
    "тис": ["тисс"],
    "тис ягодный": ["зеленица", "негниючка", "негной", "красное дерево"],
    "тискав": ["тискавши"],
    "тискавши": ["тискав"],
    "тискать": ["давить", "жать", "сжимать", "прижимать", "втискивать", "запихивать", "отпечатывать", "оттискивать", "печатать", "издавать"],
    "тиски": ["тисы"],
    "тисковый": ["тисочный"],
    "тиснення": ["тиск"],
    "тисненье": ["тиснение"],
    "тиснив": ["тиснивши"],
    "тиснивши": ["тиснив"],
    "тиснув": ["тиснувши"],
    "тиснувши": ["тиснув"],
    "тисочный": ["тисковый"],
    "тисс": ["тис"],
    "тиссагет": ["фиссагет"],
    "тиссовый": ["тисовый"],
    "тисячократний": ["тисячоразовий"],
    "тисячоразовий": ["тисячократний"],
    "титанировав": ["титанировавши"],
    "титанировавши": ["титанировав"],
    "титанит": ["сфен"],
    "титанический": ["титановый", "циклопический", "чудовищный", "колоссальный", "исполинский", "гигантский", "огромный", "грандиозный", "эпохальный", "громадный", "величайший", "великий"],
    "титано-магниевый": ["титаномагниевый"],
    "титаномагниевый": ["титано-магниевый"],
    "титечка": ["сисечка"],
    "тити": ["гаврош", "озорник"],
    "титин": ["тайтин", "коннектин"],
    "титло": ["титла", "заголовок", "заглавие", "название", "наименование", "достоинство"],
    "титриметрический анализ": ["титрование"],
    "титрировав": ["титрировавши"],
    "титрировавши": ["титрировав"],
    "титровав": ["титровавши"],
    "титровавши": ["титровав"],
    "титрование": ["титриметрический анализ"],
    "титул": ["звание", "чин", "статус", "должность"],
    "титуловав": ["титуловавши"],
    "титуловавши": ["титуловав"],
    "титульный": ["первый"],
    "титушня": ["титушок", "титушки"],
    "титушок": ["титушка", "титушня"],
    "титька": ["сиська", "грудь", "сосок"],
    "титястый": ["грудастый", "сисястый"],
    "тиун": ["приказчик", "тивун", "посадник"],
    "тифдрук": ["глубокая печать"],
    "тифилис": ["тифлис"],
    "тифл": ["бача"],
    "тифлис": ["тбилиси"],
    "тифлисец": ["тбилисец"],
    "тифлисъ": ["тбилиси"],
    "тифлокомментирование": ["аудиодескрипция"],
    "тифлотомия": ["цекотомия"],
    "тифозив": ["тифозивши"],
    "тифозивши": ["тифозив"],
    "тихариться": ["таиться", "прятаться"],
    "тихарь": ["тихоня", "тихуша", "тихушник", "крыса"],
    "тихас": ["фокино", "тихоокеанский"],
    "тихие воды глубоки": ["в тихом омуте черти водятся"],
    "тихий": ["негромкий", "приглушённый", "глухой", "неслышный", "бесшумный", "безмолвный", "спокойный", "смирный", "размеренный", "неторопливый", "медленный"],
    "тихий ангел пролетел": ["мент родился"],
    "тихий океан": ["великий океан", "великое южное море", "восточный океан"],
    "тихий час": ["сон-час"],
    "тихим матом": ["потайком"],
    "тихим сапом": ["тихой сапой", "молча", "молчком", "тишком", "тишком-ладком", "из-под руки", "шито-крыто", "шито и крыто", "без шума", "без шума и гама", "по-тихому", "втихую", "втихаря"],
    "тихнув": ["тихнувши"],
    "тихнувши": ["тихнув"],
    "тихо": ["негромко", "бесшумно", "крадучись", "неспешно", "незаметно", "украдкой", "спокойно", "безветренно", "тише"],
    "тиховарка": ["медленноварка"],
    "тиховодь": ["тиховоддя"],
    "тиховодье": ["заводь", "затон"],
    "тихой сапой": ["молча", "молчком", "тишком", "тишком-ладком", "из-под руки", "шито-крыто", "шито и крыто", "без шума", "без шума и гама", "по-тихому", "втихую", "втихаря", "незаметно", "втихомолку", "под шумок"],
    "тихомолка": ["шёпот"],
    "тихомолком": ["тихо", "потихоньку", "тихонько", "тихохонько", "бесшумно", "неслышно", "вполголоса", "понизив", "голос", "шепотом", "вполслуха", "про себя", "в сторону", "молча", "молчаливо"],
    "тихонько": ["тихо", "тихоньки", "потихоньку", "тайком", "втихомолку"],
    "тихоня": ["паинька"],
    "тихоокеанский": ["фокино", "тихас"],
    "тихоходка": ["тихоход"],
    "тицькати": ["тицяти"],
    "тишав": ["тишавши"],
    "тишавши": ["тишав"],
    "тишанка": ["тишина"],
    "тишать": ["утихать", "усмиряться"],
    "тиши": ["тиси"],
    "тишина": ["тишанка"],
    "тишкино": ["ванино"],
    "тишком": ["потихоньку", "тайком", "тихо", "украдкой", "незаметно"],
    "тиштрйа": ["тиштрия"],
    "тишь": ["тишина", "безмолвие", "беззвучие", "покой", "безветрие", "штиль"],
    "тишь да гладь": ["мир", "покой", "спокойствие", "благополучие", "благоденствие", "мир да лад", "тишь да крыш"],
    "тияк": ["сияк", "тяка пингть"],
    "ткав": ["ткавши"],
    "ткавши": ["ткав"],
    "ткальний": ["ткацький"],
    "тканевое дыхание": ["клеточное дыхание"],
    "ткань": ["материал", "материя", "канва"],
    "тканьё": ["ткачество", "ткань"],
    "тканьёвый": ["вытканный", "тканый", "тканьевой"],
    "ткать": ["плести"],
    "ткацкий": ["ткаческий"],
    "ткач": ["ткачик"],
    "ткачик": ["ткач"],
    "ткемали": ["алыча"],
    "тклапи": ["левишник", "лавашник"],
    "ткнув": ["ткнувши"],
    "ткнувши": ["ткнув"],
    "ткнуть": ["пихнуть"],
    "ткъаесна": ["ткъаяссана"],
    "ткъайоьсна": ["ткъаесна", "ткъаяссана"],
    "ткъаяссана": ["ткъаесна"],
    "тлев": ["тлевши"],
    "тлевши": ["тлев"],
    "тлен": ["тление", "гниение", "тленье", "гниенье", "прах", "тщета"],
    "тление": ["истление", "загнивание", "разложение", "гниение", "сгнивание", "распад", "сопревание", "перегнивание", "тлен", "перетлевание", "истлевание"],
    "тленность": ["смертность", "недолговечность"],
    "тлетворно": ["вредно", "губительно", "пагубно", "разрушительно"],
    "тлетворность": ["гибельность", "губительность", "погибельность", "вредность", "пагубность", "смертоносность"],
    "тлив": ["тливши"],
    "тливши": ["тлив"],
    "тлинкит": ["колош"],
    "тлумак": ["клунок"],
    "тлумитися": ["товпитися"],
    "тлумны": ["шумны", "неспакойны"],
    "тлумок": ["клунок"],
    "тлунок": ["шлунок"],
    "тлуса": ["риссю"],
    "тля": ["букашка", "клоп", "вошь", "вша"],
    "тмеза": ["тмезис", "тмесис"],
    "тмезис": ["тмесис", "тмеза"],
    "тмесис": ["тмезис", "тмеза"],
    "тмив": ["тмивши"],
    "тмивши": ["тмив"],
    "тмин": ["тимон", "кимин", "арлек", "козловки", "ганус", "гуньба", "полевой анис", "анис", "кмин", "зира"],
    "тминний": ["тминовий"],
    "тминовий": ["кминний", "кминовий", "тминний"],
    "тмить": ["затмевать", "темнить"],
    "тмутаракан": ["тьмутаракань"],
    "тмутараканский": ["тьмутараканский"],
    "тмутаракань": ["гермонасс", "тумен-тархан", "тумантархан", "таматарха", "самкерц", "тмутаракан", "тмуторокань", "тьмуторокань", "матарха", "матраха", "матрика", "матрега", "таман", "тамань"],
    "тмуторокань": ["тмутаракань"],
    "тнути": ["тяти"],
    "то": ["техобслуживание", "техосмотр"],
    "то бишь": ["то есть", "иными словами", "иначе говоря", "а именно"],
    "то есть": ["иначе говоря", "другими словами", "иными словами", "то бишь", "точнее говоря", "точнее", "вернее"],
    "то же": ["такой же"],
    "то же самое": ["похоже"],
    "то и дело": ["беспрестанно", "на каждом шагу"],
    "то ли": ["ли", "или", "либо", "может", "не то"],
    "то что": ["что"],
    "тоат": ["ибодат", "намоз"],
    "тобиас": ["тоби"],
    "тобоган": ["тобогган"],
    "тобогган": ["тобоган", "табогган", "таббоган"],
    "тоболец": ["тоболка", "сума", "сумка", "котомка", "калита"],
    "тобольчанка": ["тоболячка"],
    "тоболяк": ["тоболец"],
    "тоболянин": ["тоболяк", "тоболец"],
    "тобто": ["цебто", "себто"],
    "тов": ["тоза"],
    "товарищ": ["коллега", "друг", "соратник", "единомышленник", "камрад", "помощник", "заместитель"],
    "товарищ по команде": ["сокомандник", "соратник", "напарник", "компаньон", "тиммейт"],
    "товарищество": ["дружба", "приятельство", "кооператив", "компания", "общество", "артель"],
    "товарка": ["подруга", "подружка", "приятельница", "другиня"],
    "товарная номенклатура": ["номенклатура изделий"],
    "товарник": ["товарняк"],
    "товарный знак": ["товарная марка", "торговая марка"],
    "товарняк": ["товарник"],
    "товароведный": ["товароведческий"],
    "товароведческий": ["товароведный"],
    "товарообмен": ["товарный обмен", "товарообменная операция", "товаробмен"],
    "товда": ["тувда"],
    "товмач": ["перекладач"],
    "товстезний": ["товстелезний", "товстенний", "товстючий", "товстющий"],
    "товстелезний": ["товстезний", "товстенний", "товстючий", "товстющий"],
    "товстенний": ["товстелезний", "товстючий", "товстезний", "товстющий"],
    "товстенький": ["грубенький", "гладенький", "дебеленький"],
    "товстун": ["гладун"],
    "товстушка": ["товстуля"],
    "товстючий": ["товстелезний", "товстенний", "товстезний", "товстющий"],
    "товстющий": ["товстелезний", "товстючий", "товстезний", "товстенний"],
    "товща": ["товщина", "жир", "товпа", "натовп"],
    "товьсь": ["готовьсь"],
    "тогда как": ["в то время как"],
    "тогдашний": ["прошлый", "прежний"],
    "того": ["тоголезская республика"],
    "тодор": ["теодор", "феодор", "фёдор"],
    "тож": ["или", "иначе говоря", "тот же", "тоже", "то есть"],
    "тож на тож": ["баш на баш"],
    "тождество": ["равенство", "тождественность", "идентичность"],
    "тоже": ["аналогично", "равным образом", "в равной степени", "тож", "также", "ещё", "вот ещё"],
    "тоже мне": ["подумаешь"],
    "тожественный": ["тождественный"],
    "тожество": ["тождество", "идентичность"],
    "тоза": ["тов"],
    "тойтерьер": ["той", "той-терьер"],
    "ток": ["поток", "течение", "электроток", "сила тока", "бег", "движение"],
    "токарив": ["токаривши"],
    "токаривши": ["токарив"],
    "токарить": ["токарничать"],
    "токарний": ["токарський"],
    "токарничав": ["токарничавши"],
    "токарничавши": ["токарничав"],
    "токарський": ["токарний"],
    "токен": ["текстоформа", "жетон"],
    "токенизировав": ["токенизировавши"],
    "токенизировавши": ["токенизировав"],
    "токио": ["эдо"],
    "токмо": ["только", "лишь", "исключительно", "единственно"],
    "токовав": ["токовавши"],
    "токовавши": ["токовав"],
    "токование": ["ток"],
    "токованье": ["токование"],
    "токой": ["ормон"],
    "токолог": ["акушер"],
    "токологический": ["акушерский"],
    "токология": ["акушерство"],
    "токоограничительный": ["токоограничивающий"],
    "токоприёмник": ["токосъёмник", "токосниматель"],
    "токопровод": ["электропровод"],
    "токосниматель": ["токосъёмник", "токоприёмник"],
    "токосъёмник": ["токоприёмник", "токосниматель"],
    "токофобия": ["малевзиофобия"],
    "токсемия": ["токсинемия"],
    "токсидермия": ["экзантема", "токсический", "токсикодермия"],
    "токсик": ["токсикоман"],
    "токсикант": ["яд"],
    "токсикоз": ["интоксикация", "токсемия"],
    "токсикоманив": ["токсикоманивши"],
    "токсикоманивши": ["токсикоманив"],
    "токсикомания": ["токсикоманство"],
    "токсикоманство": ["токсикомания"],
    "токсичний": ["отруйний"],
    "токсичность": ["ядовитость"],
    "токсичный": ["ядовитый", "токсический", "отравляющий", "вредный", "гадкий"],
    "токсоид": ["анатоксин"],
    "тол": ["тротил", "тринитротолуол"],
    "тол-я": ["толья", "талья"],
    "толгоки": ["сирга", "тэгэк"],
    "толеразм": ["толерастия"],
    "толеранс": ["допуск", "допустимое отклонение"],
    "толерантно": ["снисходительно", "терпимо"],
    "толерантность": ["терпимость", "иммунологическая толерантность"],
    "толерантный": ["терпимый"],
    "толераст": ["терпила", "либераст"],
    "толерастия": ["толеразм"],
    "толерировав": ["толерировавши"],
    "толерировавши": ["толерировав"],
    "толерировать": ["терпеть"],
    "толика": ["зерно", "крупица", "частица", "доля", "долька"],
    "толк": ["разумность", "панталык", "прок"],
    "толкав": ["толкавши"],
    "толкавши": ["толкав"],
    "толкан": ["толчок"],
    "толканув": ["толканувши"],
    "толканувши": ["толканув"],
    "толканье": ["толкание"],
    "толкать": ["пихать"],
    "толкач": ["пест"],
    "толкиенист": ["толкинист"],
    "толкинист": ["толкиенист"],
    "толкнув": ["толкнувши"],
    "толкнувши": ["толкнув"],
    "толковав": ["толковавши"],
    "толковавши": ["толковав"],
    "толкование": ["объяснение", "разъяснение"],
    "толковать": ["определять", "разъяснять", "истолковывать", "растолковывать", "объяснять", "беседовать", "разговаривать", "обсуждать", "говорить", "рассказывать", "рассуждать"],
    "толковник": ["толкователь", "истолкователь", "изъяснитель", "переводчик", "толковый словарь"],
    "толковый": ["дельный", "понятливый", "смышлёный", "умный", "головастый", "мозговитый", "башковитый", "разумный"],
    "толковый словарь": ["словотолкователь"],
    "толкунец": ["толкач"],
    "толкучка": ["толкотня", "толчея", "давка", "блошиный рынок", "толчок", "тульч", "горбушка"],
    "толкушка": ["мялка", "картофелемялка", "картофеледавилка", "пестик"],
    "толмач": ["переводчик", "синхронист", "синхронный переводчик"],
    "толмачив": ["толмачивши"],
    "толмачивши": ["толмачив"],
    "толмив": ["толмивши"],
    "толмивши": ["толмив"],
    "толобаец": ["талабаец", "толабаец"],
    "толовый": ["тротиловый"],
    "толока": ["выгон", "выпуск", "поскотина", "потрава", "толочение", "толчёнка"],
    "толокно": ["малай", "толоконце"],
    "толос": ["фолос"],
    "толочь воду в ступе": ["носить воду решетом", "в лес дрова возить", "сизифов труд"],
    "толпа": ["скопище", "сборище", "масса"],
    "толпами": ["толпой", "валом"],
    "толповод": ["толповодитель", "вожак"],
    "толстев": ["толстевши"],
    "толстевши": ["толстев"],
    "толстенный": ["толстущий", "толстющий", "претолстый"],
    "толстенький": ["полненький", "пухленький"],
    "толстеть": ["поправляться", "раздаваться", "распухать", "раздуваться"],
    "толстив": ["толстивши"],
    "толстивши": ["толстив"],
    "толстовка": ["гарвардка", "худи"],
    "толстожопик": ["толстяк", "жирдяй"],
    "толстожопый": ["толстозадый", "жопастый", "жопистый", "толстожопистый"],
    "толстозадый": ["толстожопый"],
    "толстолапый": ["широколапый"],
    "толстолобик": ["толстолоб"],
    "толстомясый": ["толстый", "жирный", "дородный"],
    "толстосум": ["богатей", "богач"],
    "толстуха": ["толстячка", "трупёрда"],
    "толстущий": ["толстенный", "толстющий"],
    "толстый": ["широкий", "полный", "жирный", "упитанный", "тучный", "грузный", "толстяк", "жиртрест", "жирдяй", "жиропупокомбинат"],
    "толстющий": ["толстенный", "толстущий"],
    "толстячка": ["толстуха", "толстушка", "жируха"],
    "толуол": ["метилбензол", "монометилбензол", "фенилметан"],
    "толуэн": ["бензоин"],
    "толхмадемс": ["ряфцодомс", "тостядемс", "тутмадемс"],
    "толченье": ["толчение"],
    "толчея": ["толкотня", "давка", "сутолока", "толча"],
    "толчковый": ["толкательный"],
    "толчок": ["тычок", "пинок"],
    "толчёнка": ["картофельное пюре"],
    "толща": ["глубина", "глубь"],
    "толщина": ["глубина", "обхват", "полнота", "тучность", "дородность", "ширина"],
    "толь": ["рубероид"],
    "только": ["всего", "всего-навсего", "лишь", "токмо", "единственно", "исключительно", "еще", "пока", "всего лишь", "едва", "но", "однако", "именно", "если", "ещё"],
    "только бы": ["лишь бы"],
    "только мокро останется": ["только мокрое место останется", "одно мокрое место останется", "только рожки да ножки останутся", "костей не соберёшь"],
    "только через мой труп": ["ни в коем случае", "ни за что"],
    "только что": ["только", "как только", "лишь", "едва лишь", "едва ли", "чуть ли"],
    "только-только": ["тютелька в тютельку", "в аккурат"],
    "тольтек": ["толтек"],
    "тольятти": ["ставрополь", "ставрополь волжский", "ставрополь-на-волге"],
    "том": ["логический диск"],
    "томан": ["туман", "таман"],
    "томас": ["том"],
    "томат": ["помидор"],
    "томатик": ["помидорчик"],
    "томболо": ["перейма"],
    "томив": ["томивши"],
    "томивши": ["томив"],
    "томизм": ["фомизм"],
    "томиться": ["мучиться", "страдать", "жить в заключении"],
    "томич": ["томичанин"],
    "томичанка": ["томичка"],
    "томный": ["вялый", "меланхоличный", "томительный", "тягостный"],
    "томоскопия": ["томография"],
    "томская область": ["томщина"],
    "тому назад": ["ранее"],
    "тон": ["нота", "большая секунда", "два полутона", "звучание"],
    "тон-ателье": ["тонателье"],
    "тона": ["ся"],
    "тонателье": ["тон-ателье", "студия звукозаписи"],
    "тондракиец": ["тондракит", "павликианин"],
    "тондракит": ["тондракиец"],
    "тонзура": ["гуменце"],
    "тонизировав": ["тонизировавши"],
    "тонизировавши": ["тонизировав"],
    "тонина": ["тонкость"],
    "тонировав": ["тонировавши"],
    "тонировавши": ["тонировав"],
    "тонкая кишка": ["тонкий кишечник"],
    "тонкий": ["узкий", "худой", "тощий", "жердяй", "деликатный", "утончённый", "высокий"],
    "тонкин": ["бакбо"],
    "тонковатый": ["тонковастый"],
    "тонкодисперсный": ["мелкодисперсный", "высокодисперсный"],
    "тонкоизмельчённый": ["диспергированный", "эмульсированный"],
    "тонкокожий": ["чувствительный"],
    "тонколистный": ["тонколистый", "тонколистовой"],
    "тонколистый": ["тонколистный"],
    "тонкопряха": ["тонкопрядица", "тонкопрялья", "тонкопряльюшка", "тонкопрялица"],
    "тонкость": ["частность", "подробность", "оттенок"],
    "тонкошёрстный": ["тонкошёрстый"],
    "тонкошёрстый": ["тонкошёрстный"],
    "тонмейстер": ["звукооператор"],
    "тонна": ["мегаграмм", "штука"],
    "тонна-километр": ["тоннокилометр", "тонно-километр"],
    "тоннелеобразный": ["туннелеобразный"],
    "тоннелестроение": ["туннелестроение"],
    "тоннельный": ["туннельный"],
    "тонно-километр": ["тонна-километр", "тоннокилометр"],
    "тоннокилометр": ["тонна-километр", "тонно-километр"],
    "тонометр": ["сфигмоманометр"],
    "тонув": ["тонувши"],
    "тонувши": ["тонув"],
    "тончав": ["тончавши"],
    "тончавши": ["тончав"],
    "тончайший": ["тонюсенький"],
    "тончив": ["тончивши"],
    "тончивши": ["тончив"],
    "тонь": ["эсь"],
    "тонька": ["антонинка", "тоня", "тонюня", "тонюра", "тонюся", "нюся", "тонюха", "тонюша", "антося", "тося", "тася", "антоша", "тоша", "нина", "ина"],
    "топ": ["топик"],
    "топ-клуб": ["суперклуб"],
    "топав": ["топавши"],
    "топавши": ["топав"],
    "топать": ["топотать", "идти", "уходить"],
    "топиар": ["топиари"],
    "топиари": ["топиар"],
    "топиарий": ["дерево счастья"],
    "топив": ["топивши"],
    "топивши": ["топив"],
    "топик": ["топ"],
    "топикстартер": ["топикастер"],
    "топинамбур": ["земляная груша", "подсолнечник клубненосный", "клубненосный подсолнечник", "иерусалимский артишок", "солнечник", "булва", "волошская репа"],
    "топиться": ["растапливаться", "расплавляться", "плавиться", "отапливаться", "протапливаться", "томиться"],
    "топка": ["топление", "камера сгорания"],
    "топление": ["топка"],
    "топливная ячейка": ["топливный элемент", "батарея электропитания"],
    "топливо": ["горючее", "горючка"],
    "топляк": ["морёный лес"],
    "топлёное молоко": ["томлёное молоко"],
    "топнув": ["топнувши"],
    "топнувши": ["топнув"],
    "топовый": ["выдающийся", "популярный", "лидирующий", "ведущий", "первенствующий"],
    "тополиний": ["тополевий"],
    "тополиный": ["тополевый"],
    "топология": ["дифференциальная геометрия"],
    "топоним": ["географическое название"],
    "топонимика": ["топонимия"],
    "топонимикон": ["топонимика", "топонимия"],
    "топонимист": ["топономаст"],
    "топонимия": ["топонимика"],
    "топопривязка": ["геолокация", "топографическая привязка"],
    "топор": ["плаха"],
    "топорик": ["топорок"],
    "топоришко": ["топор"],
    "топорщив": ["топорщивши"],
    "топорщивши": ["топорщив"],
    "топорщить": ["щетинить", "ощетинивать", "встопорщивать", "ерошить", "взъерошивать"],
    "топорщиться": ["топыриться", "ощетиниваться", "нахохливаться", "надуваться"],
    "топотав": ["топотавши"],
    "топотавши": ["топотав"],
    "топотать": ["топать"],
    "топотун": ["топотуха", "топотуша", "топтун"],
    "топоформант": ["топонимический формант"],
    "топрик": ["топрек"],
    "топтав": ["топтавши"],
    "топтавши": ["топтав"],
    "топтанье": ["топтание"],
    "топтать": ["утаптывать", "растаптывать"],
    "топтаться": ["переминаться", "отираться", "тереться"],
    "топтун": ["сыщик", "топотун"],
    "топтыгин": ["медведь", "мишка", "косолапый"],
    "топуз": ["токмак"],
    "топчан": ["топчанчик", "топчанчишко", "лежанка", "лежак", "нары", "полати", "шезлонг"],
    "топчик": ["лидер"],
    "топырив": ["топыривши"],
    "топыривши": ["топырив"],
    "топырить": ["растопыривать", "топорщить"],
    "топь": ["трясина", "зыбь"],
    "тор": ["перун", "зевс", "юпитер"],
    "тора": ["фора"],
    "торакальный": ["грудной"],
    "торакоскопия": ["видеоторакоскопия", "втс", "плевроскопия"],
    "торбаз": ["унты"],
    "торбалан": ["просяк", "парцалан", "дрипльо", "бедняк", "сиромах"],
    "торбас": ["торбаз"],
    "торбив": ["торбивши"],
    "торбивши": ["торбив"],
    "торботряс": ["жебрак"],
    "торг": ["торговля", "базар", "рынок", "торжище", "ярмарка"],
    "торгашествовав": ["торгашествовавши"],
    "торгашествовавши": ["торгашествовав"],
    "торговав": ["торговавши"],
    "торговавши": ["торговав"],
    "торговать дрожжами": ["продавать дрожжи", "покупать дрожжи"],
    "торговать пиздой": ["торговать собой", "торговать пиздой и жопой"],
    "торговать пиздой и жопой": ["торговать собой", "торговать пиздой"],
    "торговать собой": ["торговать пиздой", "торговать пиздой и жопой"],
    "торговаться": ["продаваться"],
    "торговая марка": ["бренд", "марка", "торговый знак"],
    "торговая точка": ["тт"],
    "торговец": ["продавец", "торгаш", "коммерсант", "купец"],
    "торговий": ["торговельний"],
    "торговка": ["продавщица", "лавочница", "купчиха"],
    "торговое представительство": ["торгпредство"],
    "торговый центр": ["торгцентр"],
    "тореадор": ["тореро"],
    "торев": ["торевши"],
    "торевши": ["торев"],
    "тореро": ["тореадор"],
    "тореть": ["ториться", "утаптываться", "укатываться", "натореть", "навыкать", "привыкать"],
    "торецк": ["дзержинск", "щербиновка"],
    "торжественно": ["важно", "официально", "серьёзно", "возвышенно", "величаво", "величественно", "нерушимо", "священно"],
    "торжественность": ["парадность", "официальность", "церемониальность", "величавость"],
    "торжественный": ["важный", "официальный", "серьёзный", "приподнятый", "напыщенный", "величавый", "величественный", "сияющий", "праздничный", "нерушимый", "священный"],
    "торжество": ["праздник", "радость", "ликование", "победа"],
    "торжествовав": ["торжествовавши"],
    "торжествовавши": ["торжествовав"],
    "торжествовать": ["ликовать", "радоваться"],
    "торжище": ["рынок", "базар", "ярмарка", "торг", "торговля", "преходящий"],
    "торжковский": ["торжокский"],
    "торжок": ["новый торг", "новоторжск"],
    "торжокец": ["новотор", "новоторжец", "торжанин", "торжковец"],
    "торжокский": ["торжковский"],
    "торзион": ["скрученность"],
    "торив": ["торивши", "утаптывав", "укатывав"],
    "торивши": ["торив"],
    "торить": ["проторять", "прокладывать"],
    "торица": ["шпергель"],
    "торк": ["торквес"],
    "торкав": ["торкавши"],
    "торкавши": ["торкав"],
    "торквес": ["торк"],
    "торкнув": ["торкнувши"],
    "торкнувши": ["торкнув"],
    "торкретировав": ["торкретировавши"],
    "торкретировавши": ["торкретировав"],
    "торкретировать": ["производить торкретирование", "произвести торкретирование"],
    "тормашка": ["дно", "дыбо"],
    "торможенье": ["торможение"],
    "тормоз": ["тугодум"],
    "тормозив": ["тормозивши"],
    "тормозивши": ["тормозив"],
    "тормозильщик": ["тормозной", "кондуктор"],
    "тормозить": ["стопорить", "тупить", "лагать"],
    "тормозной": ["медленный", "тугодумный"],
    "тормознув": ["тормознувши"],
    "тормознувши": ["тормознув"],
    "тормознуть": ["затормозить", "притормозить", "остановиться", "остановить", "задержать", "приостановить", "прекратить"],
    "тормозок": ["тормоз", "ссобойка", "перекус"],
    "тормозуха": ["тормозная жидкость"],
    "тормошив": ["тормошивши"],
    "тормошивши": ["тормошив"],
    "тормошливый": ["беспокойный", "докучливый"],
    "тормыш": ["гомер"],
    "торнадо": ["смерч", "тромб", "ураган"],
    "торно": ["проторённо", "гладко", "ровно", "наезженно", "укатанно"],
    "торный": ["проторённый", "гладкий", "ровный", "обычный", "шаблонный"],
    "тороватость": ["щедрость", "расточительство"],
    "тороватый": ["щедрый", "великодушный"],
    "тороидальный": ["торообразный"],
    "торообразный": ["тороидальный"],
    "торопев": ["торопевши"],
    "торопевши": ["торопев"],
    "торопив": ["торопивши"],
    "торопивши": ["торопив"],
    "торопить": ["подгонять", "приближать"],
    "торопиться": ["спешить"],
    "торопкий": ["торопливый", "спешный", "суетливый", "неспокойный", "нетерпеливый"],
    "торопливо": ["поспешно", "второпях"],
    "торопливость": ["поспешность"],
    "торопыга": ["торопыжка"],
    "торопыжка": ["торопыга"],
    "торосив": ["торосивши"],
    "торосивши": ["торосив"],
    "торосистый": ["покрытый", "торос"],
    "торосить": ["громоздить", "накапливать"],
    "торосовый": ["торосистый"],
    "торочив": ["торочивши"],
    "торочивши": ["торочив"],
    "торпедировав": ["торпедировавши"],
    "торпедировавши": ["торпедировав"],
    "торпедировать": ["атаковать", "поразить", "поражать", "сорвать", "срывать"],
    "торпедист": ["торпедник"],
    "торпедистка": ["торпедист"],
    "торпедник": ["торпедист"],
    "торпедный аппарат": ["та"],
    "торпедо": ["торпеда", "приборный", "панель", "гнюс", "электрический скат"],
    "торпедовец": ["автозаводец"],
    "торпидность": ["вялость", "бесчувственность", "слабосилие"],
    "торпидный": ["слабосильный", "вялый", "малосимптомный", "бессимптомный", "бесчувственный", "оцепенелый", "нераздражительный", "брадипсихический"],
    "торр": ["миллиметр ртутного столба"],
    "торс": ["туловище"],
    "торсиометр": ["моментометр"],
    "торсион": ["рессора", "пружина"],
    "тортури": ["тортура"],
    "торулез": ["криптококкоз"],
    "торфенев": ["торфеневши"],
    "торфеневши": ["торфенев"],
    "торфовав": ["торфовавши"],
    "торфовавши": ["торфовав"],
    "торфорез": ["торфорезка"],
    "торфянев": ["торфяневши"],
    "торфяневши": ["торфянев"],
    "торцевав": ["торцевавши"],
    "торцевавши": ["торцевав"],
    "торцевой": ["торцовый"],
    "торцовый": ["торцевой", "торцевый"],
    "торч": ["кайф"],
    "торчав": ["торчавши"],
    "торчавши": ["торчав"],
    "торчащий": ["выпирающий"],
    "торчком": ["торчмя"],
    "торчок": ["наркоман", "нарик"],
    "торшонировав": ["торшонировавши"],
    "торшонировавши": ["торшонировав"],
    "тоска": ["уныние", "депрессия", "меланхолия", "подавленность", "скука", "печаль", "тревога", "грусть", "кручина"],
    "тоска зелёная": ["зелёная скука", "смертная скука", "скука смертная", "тоска чёрная", "тоска смертная"],
    "тоскливо": ["скучно", "безрадостно"],
    "тоскливый": ["скучный"],
    "тоскний": ["тужний", "тужливий"],
    "тосковав": ["тосковавши"],
    "тосковавши": ["тосковав"],
    "тосковать": ["грустить", "маяться", "томиться", "сохнуть", "болеть", "ныть"],
    "тост": ["здравица"],
    "тостядемс": ["ряфцодомс", "толхмадемс", "тутмадемс"],
    "тот": ["теут", "тут", "туут", "тоут", "техути", "джехути"],
    "тот же": ["тот же самый", "прежний", "тогдашний"],
    "тот или иной": ["какой-либо", "какой-нибудь", "какой-то", "определённый", "каждый"],
    "тот свет": ["мир иной", "потусторонний мир", "загробный мир"],
    "тотализатор": ["букмекер", "гемблинг"],
    "тоталитаризм": ["деспотизм", "диктатура"],
    "тоталитарный": ["деспотичный", "диктаторский"],
    "тотальный": ["всеобщий", "всеобъемлющий"],
    "тотчас": ["сразу же", "немедленно", "тут же", "сей же час"],
    "тофалар": ["карагас"],
    "тофу": ["соевый творог"],
    "тоха": ["антон"],
    "точав": ["точавши"],
    "точавши": ["точав"],
    "точать": ["тачать"],
    "точенье": ["точение"],
    "точечно": ["локально"],
    "точечный дом": ["башня"],
    "точечный массаж": ["акупрессура"],
    "точив": ["точивши"],
    "точивши": ["точив"],
    "точилка": ["чинка", "чинилка"],
    "точило": ["оселок", "брус", "брусок", "наждак", "заточной станок", "электрический заточной станок"],
    "точильщик": ["древоточец"],
    "точить": ["затачивать", "заострять", "острить", "обстругивать", "обтачивать", "изъедать", "проедать", "грызть", "источать", "изливать", "лить", "цедить", "давать течь", "течь", "капать"],
    "точить зуб": ["злоумышлять"],
    "точить лясы": ["празднословить", "балаболить", "балясничать", "трепаться", "точить балясы"],
    "точиться": ["источаться", "изливаться", "вытекать", "течь", "проникать"],
    "точка": ["заострение", "заточка", "вытачивание"],
    "точка зрения": ["сторона", "позиция", "подход", "взгляд", "отношение", "воззрение", "кочка зрения"],
    "точка невозврата": ["точка невозвращения", "критическая точка", "критическая черта", "рубикон", "точка бифуркации"],
    "точка отсчёта": ["начало", "начало координат", "нулевая точка", "нулевой километр", "точка отправления", "пункт отправления", "старт"],
    "точная верхняя грань": ["супремум"],
    "точная нижняя грань": ["инфимум"],
    "точно": ["аккуратно", "строго", "прецизионно", "ровно", "метко", "точняк", "именно", "да", "словно", "будто", "как будто", "как если бы"],
    "точность": ["аккуратность", "выверенность"],
    "точный": ["точняк", "выверенный", "чёткий", "прицельный", "аккуратный", "пунктуальный", "строгий"],
    "точняк": ["стопудово", "полюбас"],
    "точнямба": ["точно", "точняк"],
    "точь-в-точь": ["точно", "в точности", "один к одному", "не отличишь", "неотличимо", "неотличимый"],
    "точёный": ["наточенный", "острый", "выточенный", "крупноточеный", "точенный", "изящный", "красивый", "очерченный", "правильный", "тонкий"],
    "тоша": ["антон", "антонина", "тоня"],
    "тошнив": ["тошнивши"],
    "тошнивши": ["тошнив"],
    "тошниловка": ["забегаловка", "кабак"],
    "тошнить": ["мутить", "рвать", "выворачивать", "тащиться"],
    "тошнота": ["рвота", "омерзение", "отвращение"],
    "тошнотный": ["рвотный", "тошнотворный"],
    "тошнёхонько": ["тошненько", "тошнёшенько"],
    "тошнёшенько": ["тошненько", "тошнёхонько"],
    "тоштер": ["музей"],
    "тощав": ["тощавши"],
    "тощавши": ["тощав"],
    "тощища": ["тоска смертная", "нудь", "скукота", "скука", "скучища", "скучнятина", "тягомотина"],
    "тпрукав": ["тпрукавши"],
    "тпрукавши": ["тпрукав"],
    "тпрукнув": ["тпрукнувши"],
    "тпрукнувши": ["тпрукнув"],
    "трабзон": ["трапезус", "трапезунд"],
    "трабл": ["неприятность", "беда", "трабла"],
    "трабла": ["трабл"],
    "трава": ["травянистое растение", "зелень", "мурава", "трава-мурава", "травка"],
    "траванув": ["траванувши"],
    "траванувши": ["траванув"],
    "травенев": ["травеневши"],
    "травеневши": ["травенев"],
    "травень": ["май"],
    "траверз": ["траверс"],
    "траверза": ["траверса"],
    "траверс": ["траверз", "траверса", "траверза", "поперечина", "поперечная балка"],
    "траверса": ["траверза"],
    "траверсировав": ["траверсировавши"],
    "траверсировавши": ["траверсировав"],
    "травестировав": ["травестировавши"],
    "травестировавши": ["травестировав"],
    "травив": ["травивши"],
    "травивши": ["травив"],
    "травинка": ["росточек"],
    "травить": ["отравлять", "буллить"],
    "травление": ["отравление"],
    "травливав": ["травливавши"],
    "травливавши": ["травливав"],
    "травля": ["гон", "охота", "нападки", "преследование", "задирание", "буллинг"],
    "травма": ["повреждение", "увечье"],
    "травматизм": ["травматичность"],
    "травматик": ["пациент"],
    "травматологический пункт": ["травмпункт"],
    "травмировав": ["травмировавши"],
    "травмировавши": ["травмировав"],
    "травник": ["гербарий", "лечебник", "настойка", "знахарь", "лекарь", "целитель", "зайчонок", "май", "травень"],
    "травокосилка": ["триммер"],
    "травокур": ["планокур"],
    "траволатор": ["травалатор", "эскалатор", "конвейер"],
    "травушка": ["травка", "муравушка"],
    "травянев": ["травяневши"],
    "травяневши": ["травянев"],
    "травяник": ["бычок-травяник"],
    "трагедийно": ["драматично", "драматически", "безысходно", "безнадежно", "обречённо"],
    "трагедийный": ["трагичный"],
    "трагедия": ["драма", "несчастье", "горе", "бедствие", "злоключение", "злополучие", "беда", "катастрофа"],
    "трагизм": ["трагичность"],
    "трагико-комический": ["трагикомический"],
    "трагикомически": ["трагикомично"],
    "трагикомический": ["трагико-комический", "трагикомичный"],
    "трагикомичный": ["трагикомический"],
    "трагически": ["трагично"],
    "трагический": ["трагичный", "страшный", "ужасный", "катастрофический"],
    "трагично": ["трагически"],
    "трагичность": ["трагизм"],
    "трагичный": ["трагический"],
    "традиционализм": ["консерватизм"],
    "традиционалист": ["консерватор"],
    "традиционный": ["обычайный", "обычный", "каждодневный", "обыденный"],
    "традиция": ["история", "наследие", "предание", "обычай", "устой"],
    "трайбализм": ["трибализм", "трайбализация"],
    "тракт": ["шоссе"],
    "трактамент": ["жалованье", "оклад", "приём", "обхождение", "обращение"],
    "трактат": ["монография", "конвенция", "пакт"],
    "трактир": ["кабак", "шалман", "кружало", "питейное заведение", "питейный дом", "погребок"],
    "трактиришко": ["трактир"],
    "трактовав": ["трактовавши"],
    "трактовавши": ["трактовав"],
    "трактование": ["трактовка"],
    "трактовать": ["истолковывать", "интерпретировать", "объяснять", "расценивать", "рассуждать", "обсуждать"],
    "трактоваться": ["интерпретироваться"],
    "трактовка": ["трактование"],
    "трактор": ["тарахтелка"],
    "тракторизировав": ["тракторизировавши"],
    "тракторизировавши": ["тракторизировав"],
    "тракторизовав": ["тракторизовавши"],
    "тракторизовавши": ["тракторизовав"],
    "тралив": ["траливши"],
    "траливши": ["тралив"],
    "тралировав": ["тралировавши"],
    "тралировавши": ["тралировав"],
    "тралить": ["тралировать"],
    "тралмастер": ["тралмейстер"],
    "трамбовав": ["трамбовавши"],
    "трамбовавши": ["трамбовав"],
    "трамбование": ["утрамбовка"],
    "трамбовать": ["утрамбовывать"],
    "трамбовка": ["трамбование", "утрамбовывание"],
    "трамбувати": ["утрамбовувати", "втрамбовувати"],
    "трамвай": ["электричка"],
    "трампист": ["трампианец"],
    "трампнаш": ["трампнашист"],
    "трампоман": ["трампофил"],
    "трампофил": ["трампоман"],
    "транда": ["манда", "транда ивановна", "мудак", "падла"],
    "транжир": ["транжира", "расточитель", "мот"],
    "транжира": ["транжир", "расточитель", "мот", "мотовка"],
    "транжирение": ["транжирство", "растрачивание"],
    "транжирив": ["транжиривши"],
    "транжиривши": ["транжирив"],
    "транжирить": ["растрачивать", "разбазаривать", "профукивать"],
    "транжирничав": ["транжирничавши"],
    "транжирничавши": ["транжирничав"],
    "транжирствовав": ["транжирствовавши"],
    "транжирствовавши": ["транжирствовав"],
    "транзакция": ["операция", "действие"],
    "транзистор": ["полупроводниковый триод", "транзисторный приёмник"],
    "транзитивировав": ["транзитивировавши"],
    "транзитивировавши": ["транзитивировав"],
    "транзитивность": ["переходность"],
    "транзитивный": ["переходный"],
    "транзитник": ["проезжающий", "проезжий", "транзитница"],
    "транзиторный": ["преходящий"],
    "транквилизатор": ["анксиолитик"],
    "транс": ["прострация"],
    "транс-конфигурация": ["транс-положение"],
    "транс-персона": ["транс-человек", "трансгендер", "транссексуал"],
    "транс-положение": ["транс-конфигурация"],
    "транс-человек": ["транс-персона", "трансгендер", "транссексуал"],
    "трансверзальный": ["поперечный"],
    "трансверсаль": ["секущая"],
    "трансверсальный": ["поперечный", "косой"],
    "трансграничный": ["пограничный"],
    "трансгрессировав": ["трансгрессировавши"],
    "трансгрессировавши": ["трансгрессировав"],
    "трансгрессировать": ["телепортироваться"],
    "трансивер": ["приёмопередатчик"],
    "трансизомер": ["транс-изомер"],
    "транскодировав": ["транскодировавши"],
    "транскодировавши": ["транскодировав"],
    "трансконтинентальный": ["межконтинентальный"],
    "транскрибировав": ["транскрибировавши"],
    "транскрибировавши": ["транскрибировав"],
    "транслатив": ["превратительный падеж", "второй винительный падеж", "включительный падеж"],
    "транслировав": ["транслировавши"],
    "транслировавши": ["транслировав"],
    "транслит": ["транслитерация"],
    "транслитерировав": ["транслитерировавши"],
    "транслитерировавши": ["транслитерировав"],
    "транслокация": ["перенос"],
    "трансляция": ["передача", "компиляция"],
    "трансмиссия": ["коробка передач"],
    "трансмиттерный": ["передаточный"],
    "транснациональный": ["международный"],
    "трансокеанский": ["заокеанский", "заморский", "трансконтинентальный"],
    "транспарант": ["плакат"],
    "транспарентность": ["прозрачность", "ясность"],
    "транспарентный": ["открытый", "прозрачный"],
    "транспилер": ["транспилятор"],
    "транспирировав": ["транспирировавши"],
    "транспирировавши": ["транспирировав"],
    "трансплантировав": ["трансплантировавши"],
    "трансплантировавши": ["трансплантировав"],
    "трансплантировать": ["пересаживать", "переносить"],
    "транспозиция": ["конверсия"],
    "транспондер": ["радиоответчик", "приёмоответчик", "ретранслятор", "радиомаяк", "гидроакустический маяк"],
    "транспонировав": ["транспонировавши"],
    "транспонировавши": ["транспонировав"],
    "транспонирование": ["транспонировка"],
    "транспонировать": ["переносить"],
    "транспорт": ["перевозка", "транспортировка", "доставка", "обоз", "шлюз", "гейт", "репорт"],
    "транспортир": ["угломер"],
    "транспортировав": ["транспортировавши"],
    "транспортировавши": ["транспортировав"],
    "транспортировка": ["перевозка", "транспортирование"],
    "транспортная компания": ["тк"],
    "транспортная рибонуклеиновая кислота": ["трнк", "транспортная рнк"],
    "транспортная рнк": ["трнк"],
    "транспортное средство": ["транспорт", "средство передвижения"],
    "транспортёр": ["конвейер"],
    "транссексуализм": ["транссексуальность"],
    "транссексуальность": ["транссексуализм", "гендерная дисфория"],
    "трансуран": ["заурановый элемент", "трансурановый элемент"],
    "трансурановый": ["заурановый"],
    "трансфер": ["переход", "перевод", "перенос", "переезд", "перемещение"],
    "трансфинитный": ["бесконечный", "безграничный", "находящийся", "за", "пределами", "конечного"],
    "трансфокатор": ["вариообъектив"],
    "трансфокация": ["зумирование"],
    "трансформация": ["преобразование", "превращение"],
    "трансформировав": ["трансформировавши"],
    "трансформировавши": ["трансформировав"],
    "трансформировать": ["преобразовывать", "преобразовать"],
    "трансформироваться": ["видоизменяться", "видоизмениться", "преобразовываться", "преобразоваться", "превращаться", "превратиться"],
    "трансхохол": ["вырусь"],
    "трансцендентальность": ["философичность", "абстрактность", "отвлечённость", "метафизичность", "теоретичность", "книжность", "умозрительность", "спекулятивность", "выспренность", "доопытность"],
    "трансцендентальный": ["априорный", "сверхопытный", "доопытный", "внеопытный", "отвлеченный", "абстрактный", "академический", "мысленный", "умозрительный", "умственный", "теоретический", "метафизический", "трансцендентный"],
    "трансцендентный": ["непознаваемый"],
    "трансцендирование": ["трансценденция"],
    "траншеекопатель": ["траншейный экскаватор"],
    "траншея": ["окоп"],
    "трапани": ["дрепанон"],
    "трапезник": ["трапезничий", "трапезарь", "трапезарий"],
    "трапезничав": ["трапезничавши"],
    "трапезничавши": ["трапезничав"],
    "трапезничать": ["трапезовать"],
    "трапезовав": ["трапезовавши"],
    "трапезовавши": ["трапезовав"],
    "трапезовать": ["трапезничать"],
    "трапезунд": ["трабзон"],
    "трапецевидный": ["трапециевидный"],
    "трапециевидный": ["трапецевидный", "трапецеидальный"],
    "трапповый": ["платобазальтовый"],
    "траса": ["шлях"],
    "трасий": ["фрасий"],
    "трасса": ["автотрасса", "автострада", "автомагистраль", "трассер"],
    "трассировав": ["трассировавши"],
    "трассировавши": ["трассировав"],
    "трассовый": ["магистральный", "дорожный"],
    "трассёр": ["трасса"],
    "траст": ["доверительная собственность"],
    "трата": ["расходование", "расход"],
    "тратив": ["тративши"],
    "тративши": ["тратив"],
    "тратить": ["расходовать"],
    "тратиться": ["расходовать", "расходоваться", "травиться", "портиться", "гибнуть"],
    "тратта": ["переводной вексель"],
    "траттория": ["ресторанчик", "трактир", "закусочная"],
    "траулер": ["тральщик"],
    "траур": ["скорбь"],
    "трафаретив": ["трафаретивши"],
    "трафаретивши": ["трафаретив"],
    "трафаретный": ["обыкновенный", "банальный", "шаблонный", "стандартный", "стереотипный"],
    "трафив": ["трафивши"],
    "трафивши": ["трафив"],
    "трафик": ["движение", "поток", "циркулирование"],
    "трафить": ["держать путь", "потрафлять", "потворствовать", "угождать", "ублажать"],
    "трах": ["трах-тарарах"],
    "трахав": ["трахавши"],
    "трахавши": ["трахав"],
    "трахание": ["траханье"],
    "трахать": ["грохать", "грохотать", "хлопать", "бабахать"],
    "трахаться": ["возиться", "ковыряться", "колупаться", "стукаться", "ударяться"],
    "трахейный": ["трахейнодышащий", "неполноусый"],
    "трахеотомировав": ["трахеотомировавши"],
    "трахеотомировавши": ["трахеотомировав"],
    "трахеотомия": ["горлосечение"],
    "трахея": ["дыхательное горло", "псевдотрахея"],
    "трахилипарит": ["трахириолит"],
    "трахнув": ["трахнувши"],
    "трахнувши": ["трахнув"],
    "трахнуть": ["бахнуть", "тарарахнуть", "стрельнуть", "совокупиться"],
    "трахнуться": ["бухнуться", "грохнуться", "перепихнуться", "переспать"],
    "траходром": ["сексодром"],
    "трачивав": ["трачивавши"],
    "трачивавши": ["трачивав"],
    "траш": ["трашаибэн", "дар"],
    "тре-": ["трёх-"],
    "треба": ["нужда", "потребность"],
    "требище": ["жертвенник"],
    "требник": ["потребник"],
    "требовав": ["требовавши"],
    "требовавши": ["требовав"],
    "требование": ["требованье", "условие", "статья", "договор", "определяющий", "то", "или", "иной", "обязательство", "либо", "договаривающийся", "сторона"],
    "требовательный": ["повелительный", "властный", "строгий", "взыскательный"],
    "требовать": ["предъявлять требование", "домогаться", "настаивать"],
    "требовать удовлетворения": ["требовать сатисфакции"],
    "требуха": ["потроха", "кишки"],
    "требушет": ["требюше"],
    "требушив": ["требушивши"],
    "требушивши": ["требушив"],
    "требушина": ["требуха", "потроха"],
    "требующий": ["диктующий", "выколачивающий", "домогающийся", "претендующий", "призывающий", "взыскивающий", "настаивающий", "предписывающий", "вызывающий"],
    "тревел-райтинг": ["путешествие", "хроника"],
    "треверы": ["триер"],
    "тревога": ["беспокойство", "волнение", "забота", "озабоченность"],
    "тревожив": ["тревоживши"],
    "тревоживши": ["тревожив"],
    "тревожить": ["волновать", "настораживать", "беспокоить", "тормошить", "трогать"],
    "тревожиться": ["беспокоиться", "волноваться", "хлопотать"],
    "тревожнодепрессивный": ["тревожно-депрессивный"],
    "тревожный": ["беспокойный", "озабоченный", "взволнованный", "предупреждающий"],
    "тревожный чемодан": ["тревожный комплект", "тревожный набор", "тревожный рюкзак", "тревожный чемоданчик"],
    "тревожный чемоданчик": ["тревожный комплект", "тревожный набор", "тревожный рюкзак", "тревожный чемодан"],
    "треволнение": ["беспокойство", "волнение", "тревога", "суета"],
    "треволненье": ["треволнение"],
    "треглавый": ["трёхглавый"],
    "трегубый": ["тройной", "троекратный", "утроенный"],
    "тред-юнион": ["профессиональный", "союз", "профсоюз"],
    "тред-юнионистский": ["трэд-юнионистский", "профсоюзный"],
    "тредбан": ["беговая дорожка"],
    "трезвев": ["трезвевши"],
    "трезвевши": ["трезвев"],
    "трезвенник": ["непьющий"],
    "трезвив": ["трезвивши"],
    "трезвивши": ["трезвив"],
    "трезвить": ["отрезвлять"],
    "трезво": ["здраво", "рассудительно"],
    "трезвонив": ["трезвонивши"],
    "трезвонивши": ["трезвонив"],
    "трезвонить": ["тилинькать"],
    "трезвый": ["трезвеный", "тверёзый", "читый", "черезвый", "непьяный", "нехмельной", "бесхмельный", "непьющий", "ясный", "здравый"],
    "трезен": ["трезена", "трезены", "троисена"],
    "трезор": ["сокровище", "драгоценность"],
    "трезубец": ["острога"],
    "трейд": ["трансфер"],
    "трейдер": ["брокер"],
    "трейлер": ["автодача", "автодом", "дом на колёсах", "караван", "кемпер"],
    "трейнспоттер": ["рейлфан"],
    "трейнсёрфер": ["трайнсёрфер"],
    "трейнсёрфинг": ["трейнхоппинг"],
    "трейнхоп": ["трейнхоппинг"],
    "трейнхоппинг": ["трейнхоп"],
    "трейсер": ["паркурист", "паркурщик"],
    "трекер": ["семплер"],
    "трекинг": ["мониторинг"],
    "треклятый": ["проклятый"],
    "трелевав": ["трелевавши"],
    "трелевавши": ["трелевав"],
    "трелив": ["треливши"],
    "треливши": ["трелив"],
    "трема": ["диерезис"],
    "трематода": ["сосальщик"],
    "тремкий": ["тремтячий"],
    "тремолировав": ["тремолировавши"],
    "тремолировавши": ["тремолировав"],
    "тремолированный": ["дрожащий"],
    "тремпель": ["плечики", "вешалка", "распялка"],
    "тремтячий": ["тремкий"],
    "трен": ["шлейф"],
    "тренаж": ["тренировка", "тренинг"],
    "тренд": ["тенденция", "веяние", "курс", "направление"],
    "трендафил": ["роза", "гюл"],
    "тренер": ["коуч", "инструктор"],
    "тренерствовав": ["тренерствовавши"],
    "тренерствовавши": ["тренерствовав"],
    "тренерша": ["инструкторша"],
    "трензель": ["музыкальный треугольник"],
    "тренив": ["тренивши"],
    "тренивши": ["тренив"],
    "трение": ["фрикционное взаимодействие"],
    "тренинг-кемп": ["тренировочный", "лагерь"],
    "тренинговый": ["тренировочный"],
    "тренировав": ["тренировавши"],
    "тренировавши": ["тренировав"],
    "тренированный": ["натренированный"],
    "тренироваться": ["упражняться"],
    "тренировка": ["упражнение", "треня"],
    "тренировочный": ["разминочный", "спарринговый", "тренинговый"],
    "тренога": ["треножник"],
    "треножив": ["треноживши"],
    "треноживши": ["треножив"],
    "тренчик": ["сматузовник", "пришкертовник"],
    "тренчкот": ["тренч"],
    "трень": ["брень", "трень-брень", "трень-трень"],
    "трень-брень": ["треньканье", "брякотушки", "брекотушки", "хлам", "смешки", "шутк", "шуточка", "хиханьки", "хаханьки", "хиханьки да хаханьки", "вздор", "ерунда", "трень"],
    "тренье": ["трение"],
    "тренькав": ["тренькавши"],
    "тренькавши": ["тренькав"],
    "тренькание": ["треньканье"],
    "тренькать": ["бренчать"],
    "тренькнув": ["тренькнувши"],
    "тренькнувши": ["тренькнув"],
    "трепав": ["трепавши"],
    "трепавши": ["трепав"],
    "трепалка": ["трепало"],
    "трепальщик": ["трепальщица"],
    "трепанг": ["голотурия", "морской огурец", "морская кубышка"],
    "трепанировав": ["трепанировавши"],
    "трепанировавши": ["трепанировав"],
    "трепанирование": ["трепанация"],
    "трепанув": ["трепанувши"],
    "трепанувши": ["трепанув"],
    "трепанье": ["трепание"],
    "трепать нервы": ["тянуть за душу", "гладить против шерсти", "портить кровь", "не давать житья", "портить нервы"],
    "трепать языком": ["трепаться", "распространяться"],
    "трепач": ["суеслов", "пустослов", "пустомеля", "балабон", "водолей", "празднослов", "говорун", "фразёр", "хайло", "простоплёт", "балалайка бесструнная", "пустовраль", "язык без костей", "балабол", "трубач"],
    "трепет": ["дрожание", "дрожь", "колебание"],
    "трепетав": ["трепетавши"],
    "трепетавши": ["трепетав"],
    "трепетанье": ["трепетание"],
    "трепетать": ["дрожать", "содрогаться", "страшиться", "ужасаться"],
    "трепло": ["трепало"],
    "трепотня": ["трёп"],
    "трепыхав": ["трепыхавши"],
    "трепыхавши": ["трепыхав"],
    "трепыханье": ["трепыхание"],
    "трепыхать": ["трепыхаться"],
    "трепыхнув": ["трепыхнувши"],
    "трепыхнувши": ["трепыхнув"],
    "тресиле": ["трясилка", "трясулька", "цитернадель", "эгрет"],
    "треск": ["хруст"],
    "трескав": ["трескавши"],
    "трескавши": ["трескав"],
    "тресканье": ["трескание"],
    "трескать": ["жрать", "лопать", "хавать", "наворачивать"],
    "трескоед": ["архангелогородец", "помор", "шанёжник"],
    "трескотня": ["треск", "болтовня"],
    "трескун": ["тараторка"],
    "трескучий": ["выспренный", "напыщенный", "высокопарный"],
    "треснув": ["треснувши"],
    "треснувши": ["треснув"],
    "трест": ["синдикат", "здание", "управление", "контора", "стройтрест"],
    "треста": ["тростник"],
    "трестировав": ["трестировавши"],
    "трестировавши": ["трестировав"],
    "третейский": ["арбитражный"],
    "третейский судья": ["посредник", "арбитр"],
    "третий рейх": ["гитлеровская германия", "нацистская германия", "фашистская германия", "германская империя"],
    "третий спас": ["ореховый спас"],
    "третировав": ["третировавши"],
    "третировавши": ["третировав"],
    "третировать": ["трактовать", "гнобить"],
    "треть": ["третья часть"],
    "третьего дня": ["позавчера", "третьёводни", "третьёвось", "завчера", "завчора", "ководни"],
    "третьеразрядность": ["третьесортность"],
    "третьеразрядный": ["посредственный", "третьесортный"],
    "третьесортность": ["третьеразрядность"],
    "третья палатализация": ["бодуэновская палатализация"],
    "третьёводни": ["позавчера"],
    "третьёвось": ["позавчера", "третьего дня", "третьёводни", "завчера", "завчора", "ководни"],
    "третёвось": ["позавчера", "третьего дня", "два", "дня", "назад", "третьёводни", "завчера", "завчора", "ководни", "третёвдни", "третёвки", "третевни", "третёвни", "третевнись", "третёвнясь"],
    "треуголка": ["трёхуголка"],
    "треугольник серпинского": ["решётка серпинского", "салфетка серпинского"],
    "трефной": ["некошерный", "трефный"],
    "трефовый": ["крестовый"],
    "трефы": ["крести"],
    "трехвостка": ["щетинохвостка"],
    "трехвостый": ["трёххвостый"],
    "трехъяйцевый": ["трехяйцевый"],
    "трехяйцовый": ["трехъяйцовый"],
    "треш": ["трешак"],
    "треш-метал": ["трэш-метал"],
    "трешак": ["треш", "трешачок"],
    "трешевый": ["трэшевый"],
    "трещав": ["трещавши"],
    "трещавши": ["трещав"],
    "трещит ширинка": ["ширинка дуется", "дуется ширинка"],
    "трещётка": ["трещотка"],
    "три": ["тройка", "уд", "удовлетворительно"],
    "три кита": ["основы основ", "фундамент"],
    "три семёрки": ["три топора"],
    "три топора": ["три семёрки"],
    "триада": ["триединство", "тройка", "троица"],
    "триаконтан": ["мелиссан"],
    "триаконтановая кислота": ["мелиссовая кислота"],
    "триаконтановый": ["мелиссовый"],
    "триаконтаэдр": ["тридцатигранник"],
    "триальный": ["пробный"],
    "триангулировав": ["триангулировавши"],
    "триангулировавши": ["триангулировав"],
    "триас": ["триасовый период"],
    "триатлет": ["триатлонист"],
    "триатлон": ["троеборье"],
    "триатлонист": ["триатлет", "троеборец"],
    "триб": ["трибка"],
    "триба": ["колено", "надрод"],
    "трибагреник": ["трикольор", "трицвет"],
    "трибетив": ["трибетивши"],
    "трибетивши": ["трибетив"],
    "трибетнув": ["трибетнувши"],
    "трибетнувши": ["трибетнув"],
    "трибка": ["триб"],
    "трибоника": ["трибология"],
    "тривиально": ["банально", "пошло", "примитивно", "незамысловато"],
    "тривиальность": ["трюизм", "банальность", "клише", "простота", "примитивность"],
    "тривиальный": ["неоригинальный", "банальный", "стандартный", "элементарный", "примитивный", "простейший"],
    "тривиум": ["тривий", "трехпутье", "трехпутие"],
    "тривух": ["вушанка"],
    "триггер": ["спусковой крючок"],
    "триггерив": ["триггеривши"],
    "триггеривши": ["триггерив"],
    "триггернув": ["триггернувши"],
    "триггернувши": ["триггернув"],
    "триггернуть": ["спровоцировать"],
    "триглецирид": ["триацилглицерид"],
    "тригон": ["трогон"],
    "тригопункт": ["тригонометрический пункт", "геодезический пункт", "пункт триангуляции"],
    "тридевять": ["двадцать семь"],
    "тридесет": ["трийсет"],
    "тридневный": ["трёхдневный"],
    "тридцатигранник": ["триаконтаэдр"],
    "тридцатидвухгранник": ["икосододекаэдр"],
    "тридцатисекундный": ["полуминутный"],
    "тридцатник": ["тридцатка"],
    "тридцать": ["тридцатник", "тридцатка"],
    "триенс": ["тремисс", "тремиссис"],
    "триер": ["трир", "треверы"],
    "триера": ["трирема"],
    "триеровав": ["триеровавши"],
    "триеровавши": ["триеровав"],
    "трижды": ["троекратно"],
    "тризна": ["поминки"],
    "трииодметан": ["иодоформ"],
    "триипостасный": ["троичный"],
    "трикарбодиоксид": ["диоксид триуглерода", "недокись углерода"],
    "трикветр": ["триквестр"],
    "трикирий": ["трёхсвечник"],
    "трикислород": ["озон"],
    "триклинический": ["трёхклиномерный", "асимметрический"],
    "трико": ["трикотаж"],
    "трикотажник": ["текстильщик"],
    "трикотин": ["трикотинчик"],
    "трикошка": ["трико", "спортивка", "бриджи"],
    "трикстер": ["озорник", "проказник", "сорванец", "шалун", "баловник"],
    "триктрак": ["нарды"],
    "трилингвизм": ["триязычие"],
    "трилистник": ["клевер", "вахта трёхлистная", "трифоль"],
    "триллион": ["биллион", "квинтиллион"],
    "тримати": ["держати"],
    "триместр": ["квартал"],
    "тримминговав": ["тримминговавши"],
    "тримминговавши": ["тримминговав"],
    "трин": ["тригон"],
    "тринадесет": ["тринайсет"],
    "тринадцатилетний": ["тринадцатигодовый"],
    "тринадцатый": ["тринадцать", "тринадцатое число", "тринадцатый день", "тринадцатая часть"],
    "тринадцать": ["чёртова дюжина"],
    "тринайсет": ["тринадесет"],
    "тринарный": ["тернарный"],
    "тринитрометилбензол": ["тринитротолуол", "тнмб", "тротил", "тол"],
    "тринитротолуол": ["тринитрометилбензол", "тротил", "тол", "тнт"],
    "тринитрофенол": ["лиддит", "мелинит", "пикриновая кислота", "шимоза", "пертит", "пикринит", "экразит"],
    "трином": ["трёхчлен"],
    "тринькав": ["тринькавши"],
    "тринькавши": ["тринькав"],
    "тринькання": ["розтрачання"],
    "трио": ["тройка", "троица"],
    "триодь": ["триодион"],
    "триоксиметилен": ["триоксан", "параформ"],
    "трипак": ["триппер", "гонорея", "французский насморк", "перелой", "три пера"],
    "трипаносома": ["трипанозома"],
    "триплет": ["тройка", "тройник", "кодон"],
    "триплицитет": ["тригон"],
    "триппер": ["гонорея", "перелой", "три пера"],
    "трипс": ["пузыреногие", "колбоногие", "бахромчатокрылые"],
    "трир": ["триер"],
    "трирема": ["триера"],
    "трирутенийгептанеодим": ["гептанеодимтрирутений"],
    "трисиллаб": ["трёхсложный", "слово"],
    "трисичуха": ["трясипуха", "трисипуха"],
    "трискаидекафобия": ["тредекафобия", "трискайдекафобия"],
    "трискайдекафобия": ["тредекафобия", "трискаидекафобия"],
    "триста": ["три сотни"],
    "триста тридцать три": ["огонь", "готовьсь", "цельсь", "пли"],
    "тристих": ["трёхстишие", "терцет"],
    "тритеизм": ["троебожие"],
    "тритий": ["сверхтяжёлый водород"],
    "триумвират": ["тройка"],
    "триумфальный": ["торжествующий", "победный", "победоносный"],
    "триумфовав": ["триумфовавши"],
    "триумфовавши": ["триумфовав"],
    "трифоль": ["вахта", "вахта трёхлистная", "трилистник водяной"],
    "трифторметан": ["фтороформ"],
    "трихальный": ["нитчатый"],
    "трихинелла": ["трихина"],
    "трихиноз": ["трихинеллёз"],
    "трихогин": ["трихогина"],
    "трихоспория": ["пьедра"],
    "трихофития": ["дерматофития", "дерматомикоз", "дерматофитоз", "парша"],
    "триэдр": ["трёхгранник"],
    "триязычие": ["трилингвизм"],
    "триянда тэ шов": ["триндэша тэ шов"],
    "троада": ["бига"],
    "трогав": ["трогавши"],
    "трогавши": ["трогав"],
    "трогательно": ["умилительно"],
    "трогательный": ["умилительный", "душещипательный"],
    "трогать": ["задевать", "касаться", "прикасаться", "соприкасаться", "дотрагиваться", "притрагиваться", "волновать"],
    "троглодит": ["дикарь"],
    "трое": ["три"],
    "троебан": ["удовлетворительно", "тройка", "троечка", "трояк", "тройбан", "тройбанчик"],
    "троебожие": ["тритеизм"],
    "троеборье": ["триатлон"],
    "троекратно": ["трижды", "трёхкратно", "втрое"],
    "троекратный": ["трёхкратный"],
    "троеполье": ["трёхполье"],
    "троеточие": ["многоточие"],
    "троечка": ["тройка", "трояк", "уд", "удовлетворительно"],
    "троив": ["троивши"],
    "троивши": ["троив"],
    "троировав": ["троировавши"],
    "троировавши": ["троировав"],
    "троицкий административный округ": ["тао"],
    "тройбан": ["тройка", "трояк", "троячок", "троебан"],
    "тройничный": ["тройной", "тройниковый", "троичный"],
    "тройной": ["троякий", "трёхчастный", "троекратный", "утроенный"],
    "тройня": ["тройняшка"],
    "троллей": ["контактный провод", "контактная шина", "роликовый токосниматель", "роликовый токосъёмник"],
    "троллейбус": ["рогатый лимузин"],
    "троллив": ["тролливши"],
    "тролливши": ["троллив"],
    "троллинг": ["блеснение", "подначивание", "подзуживание"],
    "троллить": ["тралить", "подначивать", "поддевать", "дразнить", "издеваться", "провоцировать", "бретёрствовать"],
    "тромбоз": ["тромбообразование"],
    "тромбопоэз": ["тромбоцитопоэз"],
    "тромбофилия": ["гиперкоагуляция"],
    "тромбоцит": ["бляшка биццоцеро", "кровяная пластинка"],
    "тромбоцитемия": ["тромбоцитоз"],
    "тромбоцитоз": ["тромбоцитемия"],
    "тромбоцитопения": ["тромбопения"],
    "трон": ["престол", "корона"],
    "тронув": ["тронувши"],
    "тронувши": ["тронув"],
    "тронуть": ["коснуться", "прикоснуться", "притронуться"],
    "тронуться": ["двинуться", "сдвинуться", "зашевелиться", "шевельнуться", "спятить", "сойти с ума", "лишиться рассудка"],
    "тропа": ["тропинка", "стёжка"],
    "тропарь": ["кондак"],
    "тропив": ["тропивши"],
    "тропивши": ["тропив"],
    "тропики": ["тропик", "тропическая зона"],
    "тропина": ["тропа", "тропинка"],
    "тропинка": ["тропка", "тропа", "стёжка"],
    "тропот": ["тропота"],
    "тропотав": ["тропотавши"],
    "тропотавши": ["тропотав"],
    "тросовый": ["линевой", "тросиковый", "леерный", "канатный"],
    "тростив": ["тростивши"],
    "тростивши": ["тростив"],
    "тростник": ["камыш"],
    "тротил": ["тринитротолуол", "тол"],
    "троттлив": ["троттливши"],
    "троттливши": ["троттлив"],
    "тротуар": ["панель"],
    "трофеить": ["затрофеивать"],
    "трофологический": ["диетологический"],
    "трохей": ["хорей"],
    "трохлу": ["троцки"],
    "троцки": ["трохлу"],
    "троцкий": ["перо", "антид ото", "старик"],
    "трошки": ["трохи"],
    "трошник": ["тероборонец"],
    "троя": ["илион"],
    "трояк": ["трёшка", "тройка", "троячок", "тройбан"],
    "троякий": ["тройной"],
    "троян": ["троянец", "троянский конь"],
    "троянда": ["роза"],
    "трояндний": ["трояндовий"],
    "трояндовий": ["трояндний"],
    "троянец": ["троян", "троянский конь"],
    "троянский": ["илионский"],
    "троянский конь": ["троян", "троянец", "трой", "лошадка"],
    "трск": ["турецкая республика северного кипра", "северный кипр"],
    "тру": ["трушный"],
    "труба": ["дымоход", "горн", "дудка", "крышка", "каюк", "трындец", "копец", "табак", "сотовый телефон", "сотовый", "сотик", "мобильный телефон", "мобильный", "мобильник", "мобилка"],
    "трубадур": ["воспеватель", "певец"],
    "трубач": ["сигнальщик", "горнист", "сплетник", "болтун"],
    "трубив": ["трубивши"],
    "трубивши": ["трубив"],
    "трубить": ["дудеть", "гудеть"],
    "трубка": ["труба", "люлька", "мобильник", "сотовый", "сотик", "мобила", "электронно-лучевая трубка", "трубка взрыва"],
    "трубковидный": ["трубкообразный"],
    "трубковий": ["трубочний"],
    "трубкозуб": ["африканский трубкозуб"],
    "трубкообразный": ["трубковидный"],
    "труболет": ["трубочист"],
    "трубочная": ["курилка"],
    "трубочний": ["трубковий"],
    "трубочник": ["трубокур"],
    "трубчастий": ["трубчатий"],
    "трубчатий": ["трубчастий"],
    "труд": ["работа", "усилие", "напряжение", "произведение", "исследование", "книга", "опус", "творение", "трактат", "сочинение"],
    "трудив": ["трудивши"],
    "трудивши": ["трудив"],
    "трудиться": ["работать", "силиться", "стараться", "затрудняться"],
    "трудник": ["труженик", "батрак", "послушник"],
    "трудно": ["сложно", "непросто", "нелегко", "тяжело", "тяжко", "затруднительно", "проблематично", "с трудом"],
    "трудновато": ["тяжеловато"],
    "трудновоспламеняемый": ["трудновоспламеняющийся", "негорючий"],
    "трудновоспламеняющийся": ["трудновоспламеняемый", "негорючий"],
    "трудновыговариваемый": ["труднопроизносимый"],
    "трудновыполнимый": ["трудноисполнимый"],
    "труднодостижимый": ["сложнодостижимый"],
    "труднодоступный": ["недоступный"],
    "трудноизлечимый": ["плохоизлечимый"],
    "трудноисполнимый": ["трудновыполнимый", "трудноосуществимый", "труднореализуемый"],
    "трудноосуществимый": ["трудновыполнимый", "трудноисполнимый", "труднореализуемый"],
    "труднопереводимый": ["сложнопереводимый"],
    "труднопредставимый": ["трудновообразимый"],
    "труднопроизносимый": ["трудновыговариваемый"],
    "трудность": ["сложность", "тяжесть", "трудоёмкость", "затруднение", "препятствие", "невзгода", "помеха", "осложнение", "проблема", "загвоздка"],
    "трудные щи": ["сложные щи"],
    "трудный": ["тяжёлый", "сложный", "непростой", "нелёгкий", "тяжкий", "запутанный"],
    "трудняк": ["трудность", "тяжесть", "тяжеляк", "сложность"],
    "трудовая": ["трудовая книжка"],
    "трудовая книжка": ["трудовая"],
    "трудовое право": ["тп"],
    "трудовой": ["трудящийся", "рабочий"],
    "трудовой договор": ["тд"],
    "трудовой мигрант": ["гастарбайтер", "ценный специалист", "ценный иностранный специалист"],
    "трудовой семестр": ["третий", "семестр"],
    "трудоголик": ["работоголик", "работяга", "трудяга"],
    "трудолюб": ["трудолюбец"],
    "трудолюбец": ["труженик", "работящий"],
    "трудолюбивость": ["трудолюбие"],
    "трудолюбивый": ["работящий"],
    "трудолюбие": ["трудолюбивость", "трудолюбье", "прилежание", "работящесть", "трудоспособность"],
    "трудолюбье": ["трудолюбие", "трудолюбивость", "работящесть", "трудоспособность"],
    "трудосберегающий": ["трудоэкономный"],
    "трудотерапия": ["эрготерапия"],
    "трудоустраивав": ["трудоустраивавши"],
    "трудоустраивавши": ["трудоустраивав"],
    "трудоустроив": ["трудоустроивши"],
    "трудоустроивши": ["трудоустроив"],
    "трудяга": ["работяга", "труженик"],
    "трудящий": ["работающий", "трудящийся"],
    "трудящийся": ["работающий", "рабочий", "работник", "трудящий"],
    "труждав": ["труждавши"],
    "труждавши": ["труждав"],
    "труждать": ["утруждать"],
    "труженик": ["работяга", "трудяга", "работник"],
    "труженик тыла": ["труженица тыла"],
    "труженица": ["работница"],
    "труизм": ["банальность", "ляпалиссиада"],
    "трукач": ["каскадзёр", "спрытнюга", "штукар"],
    "трунив": ["трунивши"],
    "трунивши": ["трунив"],
    "трунить": ["подшучивать", "подсмеиваться"],
    "трунок": ["отрута"],
    "труп": ["трупак", "трупик", "трупешник", "тело", "останки", "мертвец", "покойник", "прах", "мумия", "жмурик", "кадавр", "мертвяк", "умерший", "мёртвый", "покойный"],
    "трупак": ["труп", "мертвяк"],
    "трупарня": ["морг", "покойницкая", "мертвецкая"],
    "трупешник": ["труп"],
    "трупиал": ["кассик", "желтушник"],
    "трупик": ["труп"],
    "трупный яд": ["птомаин"],
    "трупо": ["мас", "муло"],
    "труповозка": ["катафалк", "труповоз"],
    "трупоед": ["падальщик", "некрофаг"],
    "труположество": ["некрофилия"],
    "трупъ": ["мертвецъ", "покойникъ", "прахъ"],
    "трупёрда": ["тетёха", "толстуха"],
    "трус": ["трусишка", "трусишечка", "хороняка", "бояка", "боягуз", "очкушник", "ссыкун", "ссыкло", "кролик"],
    "трусив": ["трусивши"],
    "трусивши": ["трусив"],
    "трусик": ["трусишка"],
    "трусиковый": ["кроличий"],
    "трусить": ["бояться", "пугаться", "страшиться", "опасаться", "дрейфить", "робеть", "трепетать", "дрожать", "трястись"],
    "трусишка": ["трус"],
    "трусливо": ["боязливо", "робко"],
    "трусливый": ["пугливый", "боязливый"],
    "трусняк": ["трусы", "труселя", "трусера", "труханы"],
    "трусость": ["боязливость", "малодушие"],
    "трусца": ["рысца"],
    "трусцой": ["впритруску"],
    "трусы": ["труселя", "трусняк", "трусник", "труханы"],
    "трусы жмут под мышками": ["трусы на коленях протёрлись"],
    "трусы на коленях протёрлись": ["трусы жмут под мышками"],
    "трусы с глушителем": ["подштанники"],
    "трусы целлофановые": ["плавари", "плавцы"],
    "трутень": ["паразит", "тунеядец", "дармоед", "чужеяд"],
    "трухав": ["трухавши"],
    "трухавши": ["трухав"],
    "трухлев": ["трухлевши"],
    "трухлевши": ["трухлев"],
    "трухлявев": ["трухлявевши"],
    "трухлявевши": ["трухлявев"],
    "трухлявив": ["трухлявивши"],
    "трухлявивши": ["трухлявив"],
    "трухлявый": ["прогнивший", "сгнивший", "гнилой", "прелый", "сопрелый", "перегорелый", "рассыпающийся", "крошащийся", "червивый", "больной", "немощный", "хворый", "слабый", "слабосильный", "дряхлый"],
    "трухнув": ["трухнувши"],
    "трухнувши": ["трухнув"],
    "трухтев": ["трухтевши"],
    "трухтевши": ["трухтев"],
    "трушный": ["тру"],
    "трущоба": ["чаща", "чащоба", "глушь", "глухомань", "захолустье", "халупа"],
    "тръбозъб": ["аардварк"],
    "тръст": ["концерн", "монопол", "синдикат"],
    "трындев": ["трындевши"],
    "трындевши": ["трындев"],
    "трындеть": ["пустомелить", "балаболить", "болтать", "разглагольствовать", "нудеть", "тренькать", "бренчать"],
    "трындец": ["каюк", "кранты", "хана", "пипец", "пиздец"],
    "трындычав": ["трындычавши"],
    "трындычавши": ["трындычав"],
    "трындычиха": ["болтун", "болтушка", "сплетник", "сплетница", "балабол", "балаболка", "трещётка", "язык без костей"],
    "трэд-юнионистский": ["тред-юнионистский"],
    "трэш": ["трэш-фарс", "жесть"],
    "трэш-метал": ["треш-метал", "трэш"],
    "трэшевый": ["трешевый"],
    "трюизм": ["тривиальность", "банальность", "ляпалиссиада"],
    "трюк": ["манёвр", "уловка"],
    "трюкач": ["каскадёр", "фокусник", "ловкач", "штукарь"],
    "трюкачествовав": ["трюкачествовавши"],
    "трюкачествовавши": ["трюкачествовав"],
    "трюковой": ["трюковый"],
    "трюфель": ["трюфля"],
    "трюхав": ["трюхавши"],
    "трюхавши": ["трюхав"],
    "трюхать": ["трусить"],
    "тряпичник": ["старьёвщик"],
    "тряпичничав": ["тряпичничавши"],
    "тряпичничавши": ["тряпичничав"],
    "тряпичность": ["слабовольность", "уступчивость", "безвольность", "бесхарактерность", "бесхребетность", "мягкотелость", "слабодушие", "слабохарактерность"],
    "тряпичный": ["слабовольный", "уступчивый"],
    "тряпка": ["лоскут", "ветошка", "ветошь", "шмотьё", "шмотка", "тюря", "тютя", "рохля", "мямля", "половая тряпка", "фильтр", "экранка"],
    "тряпочка": ["тряпица", "тряпка"],
    "тряпьё": ["тряпка"],
    "трясина": ["топь", "застой"],
    "трясовица": ["трясавица"],
    "трясогузка": ["трясожопка"],
    "трясожопка": ["трясогузка"],
    "трясти": ["колебать", "раскачивать"],
    "трясти булками": ["шевелиться", "шевелить чулками", "шевелить колготками", "шевелить помидорами", "дёргать булками", "шевелить булками"],
    "трястись": ["дрожать", "содрогаться", "прерываться", "бояться", "пугаться", "страшиться", "опасаться", "трусить", "дрейфить", "робеть", "трепетать"],
    "трясця": ["лихоманка"],
    "трясък": ["шум", "бумтеж", "грохот", "тропот"],
    "тряхав": ["тряхавши"],
    "тряхавши": ["тряхав"],
    "тряханув": ["тряханувши"],
    "тряханувши": ["тряханув"],
    "тряхивав": ["тряхивавши"],
    "тряхивавши": ["тряхивав"],
    "тряхнув": ["тряхнувши"],
    "тряхнувши": ["тряхнув"],
    "трёкнутый": ["чокнутый", "тронутый", "чеканутый"],
    "трёп": ["болтовня", "пустословие", "трепотня", "враньё"],
    "трёпка": ["трепание", "нервотрёпка", "трёпка нервов"],
    "трёпка нервов": ["нервотрёпка", "трёпка"],
    "трёхатомный": ["трёхвалентный"],
    "трёхгодичный": ["трёхгодовой", "трёхлетний"],
    "трёхголосие": ["троегласие"],
    "трёхкратно": ["троекратно"],
    "трёхлинейка": ["винтовка", "мосин", "мосинка"],
    "трёхмерность": ["объёмность"],
    "трёхраздельный": ["трёхдольный", "тройчатый"],
    "трёхразовый": ["троекратный"],
    "трёхрогий": ["трёхроговый"],
    "трёхрядка": ["трёхрядная гармонь"],
    "трёхстишие": ["тристих"],
    "трёххвостый": ["трехвостый"],
    "трёхцветка": ["анютины глазки", "фиалка трехцветная"],
    "трёхчастный": ["трёхчленный"],
    "трёхчлен": ["трином"],
    "трёхчленный": ["трёхчастный"],
    "трёшка": ["трояк"],
    "трёшник": ["трёхрублевка", "трояк", "копейка"],
    "трёшница": ["трёха", "трёхрублёвая", "трёхрублёвка", "трёшка", "трёшник", "тройка", "тройчатка", "трояк", "трояшка", "трюндель"],
    "тс": ["тише", "ш-ш", "тсс", "ссс", "тш", "тш-ш-ш-ш", "чш"],
    "тсвана": ["бечуаны", "чуана"],
    "тсонга": ["шангаан"],
    "тсс": ["тише", "ш-ш", "тс", "ссс", "тш", "тш-ш-ш-ш", "чш"],
    "ттг": ["тиреотропин", "тиротропин"],
    "ттугъ": ["байрахъ"],
    "ту": ["жалау"],
    "туалет": ["уборная", "сортир", "нужник", "толчок", "клозет", "гальюн", "костюм", "прихорашивание", "трюмо"],
    "туалетная бумага": ["подтирка", "пипифакс", "туалетка", "толканка"],
    "туалетная вода": ["одеколон"],
    "туалетная комната": ["туалетная", "уборная"],
    "туальденер": ["туальденор"],
    "туальденеровый": ["туальденоровый"],
    "туальденор": ["туальденер"],
    "туальденоровый": ["туальденеровый"],
    "туамоту": ["паумоту", "пти-бас", "острова россиян"],
    "туарга": ["яралырга"],
    "туарег": ["имошаг"],
    "туатара": ["гаттерия"],
    "туба": ["тюбик"],
    "тубазид": ["изониазид"],
    "тубаретка": ["табуретка", "табуреточка", "тубареточка"],
    "туберальный": ["медиобазальный"],
    "туберкулёз": ["чахотка", "бугорчатка", "сухотная болезнь", "сухотка"],
    "туберкулёзный": ["чахоточный", "сухоточный"],
    "туберкулёма": ["туберкулома"],
    "тубероза": ["полиантес клубненосный"],
    "тубзик": ["тубзалет", "тубалет", "тубартрес", "тубаркас", "дабл", "туалет", "сортир", "уборная"],
    "тубик": ["туберкулёз", "туберкулёзник"],
    "тубулато-клатрат": ["тубулатоклатрат"],
    "тува": ["тыва"],
    "тувалу": ["острова эллис"],
    "тувда": ["товда"],
    "тувинская народная республика": ["танну-тува", "тнр"],
    "тувинский язык": ["тувинский"],
    "туго": ["сильно", "впритык", "тесно"],
    "тугодумный": ["косный", "туповатый"],
    "тугой": ["упругий", "неподатливый", "твёрдый", "медленный", "замедленный", "затруднённый", "тупой", "медлительный"],
    "тугой на ухо": ["глухой", "глуховатый", "тугоухий"],
    "тугосисий": ["малодойный", "малоудойный"],
    "тугоухость": ["брадиакузия"],
    "тугрик": ["монгольский тугрик"],
    "тугулан": ["тогулан"],
    "тугун": ["тугунок", "манерка"],
    "туда": ["туды", "дотуда"],
    "туда и дорога": ["так и надо"],
    "туда и обратно": ["туда-обратно"],
    "туда-сюда": ["туды-сюды", "взад и вперёд"],
    "туды": ["туда"],
    "туес": ["бурак"],
    "туесок": ["бурак"],
    "тужив": ["туживши"],
    "туживши": ["тужив"],
    "тужить": ["горевать", "тосковать", "скорбеть", "печалиться", "грустить", "кручиниться"],
    "туз": ["шишка", "бугор"],
    "туземец": ["абориген"],
    "туземный": ["туземский"],
    "тузив": ["тузивши"],
    "тузивши": ["тузив"],
    "тузлуковав": ["тузлуковавши"],
    "тузлуковавши": ["тузлуковав"],
    "тузлучный посол": ["мокрый посол"],
    "туйон": ["монотерпин"],
    "тук": ["жир", "сало", "перегной", "минеральный", "удобрение", "рыбный", "мука"],
    "тукав": ["тукавши"],
    "тукавши": ["тукав"],
    "тукалан": ["тукулан"],
    "тукан": ["перцеед"],
    "тукнув": ["тукнувши"],
    "тукнувши": ["тукнув"],
    "тукулан": ["тукалан"],
    "тукум": ["урук", "жумуртка"],
    "тукхум": ["туккхум", "тухум"],
    "тул": ["колчан", "сагайдак"],
    "тула": ["город мастеров", "город оружейников", "красная кузница", "самоварная столица"],
    "тулбар": ["панель инструментов"],
    "тулив": ["туливши"],
    "туливши": ["тулив"],
    "тулипэ": ["лаля"],
    "тулит": ["розалин", "унионит"],
    "тулиться": ["прятаться", "скрываться", "укрываться", "хорониться", "таиться", "уклоняться", "жаться", "прижиматься", "льнуть", "приставать", "надоедать", "ютиться"],
    "туловище": ["корпус", "торс", "стан", "тело"],
    "тулово": ["туловище", "торс", "корпус"],
    "тулумбасив": ["тулумбасивши"],
    "тулумбасивши": ["тулумбасив"],
    "тулуп": ["шерсть"],
    "тульпа": ["воображаемый друг"],
    "тульская область": ["тульщина"],
    "тульч": ["толкучка", "толчок", "горбушка", "блошиный рынок"],
    "туляк": ["тульчанин", "тулянин"],
    "тумак": ["подзатыльник", "затрещина", "удар"],
    "туман": ["туманность"],
    "туманец": ["туманчик"],
    "туманив": ["туманивши"],
    "туманивши": ["туманив"],
    "туманность": ["безжизненность", "невыразительность", "тусклость", "запутанность", "небула", "галактика"],
    "туманный альбион": ["англия", "британия"],
    "туманчик": ["туманец"],
    "тумбак": ["корем", "тулум", "търбух"],
    "тумблер": ["перекидной переключатель"],
    "тумс": ["молемс", "лисемс", "ётамс", "аердомс", "эрявкстомс", "юронзамс", "озамс", "ладямс", "кондястемс", "яраштомс"],
    "тумс прянек": ["путомс эряфцень"],
    "тун": ["тунец"],
    "тунгус": ["эвенк"],
    "тунгусский": ["эвенкийский"],
    "тундар": ["раъд"],
    "тундра": ["трунда"],
    "тундровый": ["тундреный", "тундренный"],
    "тунец": ["тун"],
    "тунеядец": ["дармоед", "нахлебник", "паразит", "трутень"],
    "тунеядка": ["дармоедка", "захребетница", "паразитка", "бездельница", "лентяйка"],
    "тунеядничав": ["тунеядничавши"],
    "тунеядничавши": ["тунеядничав"],
    "тунеядский": ["дармоедский"],
    "тунеядство": ["паразитизм", "дармоедство"],
    "тунеядствовав": ["тунеядствовавши"],
    "тунеядствовавши": ["тунеядствовав"],
    "тунеядческий": ["тунеядский", "дармоедский"],
    "туника": ["тюника", "тюник"],
    "тунит": ["кожволон"],
    "туннель": ["тоннель", "тунель", "расширитель"],
    "туннельный": ["тоннельный"],
    "тунук": ["тунух"],
    "тупанув": ["тупанувши"],
    "тупанувши": ["тупанув"],
    "тупануть": ["протупить", "лохануться", "лажануться", "облажаться", "опростоволоситься", "дать маху", "оплошать", "словить бэна"],
    "тупарь": ["тупица"],
    "тупая пизда": ["тп", "тпшка"],
    "тупев": ["тупевши"],
    "тупевши": ["тупев"],
    "тупей": ["хохол", "кок", "чуб", "вихор", "накладка"],
    "тупейший": ["наитупейший"],
    "тупень": ["тупица"],
    "тупи": ["тупинамба"],
    "тупив": ["тупивши"],
    "тупивши": ["тупив"],
    "тупик": ["топорик"],
    "тупить перо": ["марать бумагу"],
    "тупица": ["болван", "дурак", "бестолочь", "идиот", "глупец", "затупок"],
    "тупняк": ["недоумение", "недопонимание"],
    "туповатый": ["затупленный", "глуповатый"],
    "тупоголовый": ["тупой"],
    "туподум": ["тугодум", "недотёпа", "придурок", "дурак", "недоумок", "ебанько"],
    "тупой": ["незаострённый", "затупленный", "неострый", "приглушённый", "нерезкий", "притупившийся", "безмозглый", "безголовый", "бестолковый", "глупый", "малоумный", "недалёкий", "недогадливый", "неразумный", "несмышлёный"],
    "туполистый": ["туполистный"],
    "тупомордый": ["тупой", "тупорожий", "тупоносый", "тупомозглый"],
    "тупопёздный": ["тпшный"],
    "тупость": ["глупость", "тупоумие"],
    "тупоумничав": ["тупоумничавши"],
    "тупоумничавши": ["тупоумничав"],
    "тупоумный": ["тупой"],
    "тупоумье": ["тупоумие"],
    "тупьё": ["обух"],
    "тур": ["турне", "этап", "раунд", "круг", "пируэт"],
    "тура": ["штурмовая башня", "турус"],
    "турако": ["бананоед"],
    "туран": ["туркестан"],
    "турач": ["франколин"],
    "турбийон": ["турбильон"],
    "турбильон": ["турбийон", "вихрь", "жаворонок"],
    "турбиностроение": ["турбостроение"],
    "турбиностроитель": ["турбостроитель"],
    "турбировав": ["турбировавши"],
    "турбировавши": ["турбировав"],
    "турбопатриот": ["ура-патриот", "квасной патриот"],
    "турбулентный": ["беспорядочный", "вихревой"],
    "турбулизовав": ["турбулизовавши"],
    "турбулизовавши": ["турбулизовав"],
    "тургор": ["упругость"],
    "турель": ["турельная установка"],
    "туретчина": ["турция"],
    "турецкая республика": ["турция"],
    "турецкая республика северного кипра": ["трск", "северный кипр", "турецкое федеративное государство кипр"],
    "турецкий": ["турецкий язык"],
    "турецкий язык": ["турецкий"],
    "турецкоподданный": ["турецко-подданный", "иностранноподданный"],
    "турив": ["туривши"],
    "туривши": ["турив"],
    "туризм": ["поход"],
    "турий": ["туриный"],
    "туриный": ["турий"],
    "турист": ["путешественник"],
    "туристический": ["туристский"],
    "туристский": ["туристический"],
    "турить": ["выпроваживать", "выдворять", "выпровождать", "гнать", "выставлять", "вышибать"],
    "турка": ["джезва"],
    "туркав": ["туркавши"],
    "туркавши": ["туркав"],
    "туркестан": ["туран", "ясы", "яссы"],
    "туркменабад": ["чарджев", "чарджоу", "чарджуй", "ленинск", "ленинск-туркменский", "амуль"],
    "туркменбаши": ["сердар", "туркменбашы", "красноводск"],
    "туркменбашы": ["туркменбаши", "красноводск"],
    "туркменистан": ["туркмения"],
    "туркмения": ["туркменистан"],
    "туркменская сср": ["туркмения"],
    "туркоман": ["туркмен", "туркуман", "туркман", "таурмен"],
    "туркс": ["нучк", "ширем сельмот", "кяжиста"],
    "турку": ["або"],
    "туркуский": ["абоский"],
    "турлыкав": ["турлыкавши"],
    "турлыкавши": ["турлыкав"],
    "турма": ["подразделение", "формирование"],
    "турман": ["вертун", "перевёртыш"],
    "турне": ["вояж", "гастроль", "тур"],
    "турнепс": ["кормовая репа"],
    "турник": ["перекладина"],
    "турникет": ["жгут"],
    "турнир": ["ристание"],
    "турничок": ["турник", "перекладина"],
    "турнув": ["турнувши"],
    "турнувши": ["турнув"],
    "турнуть": ["выставить", "выпроводить"],
    "турок": ["турка", "турчин"],
    "турпоездка": ["тур"],
    "турсучив": ["турсучивши"],
    "турсучивши": ["турсучив"],
    "турсучить": ["теребить", "трепать", "тискать", "тормошить", "мусолить", "беспокоить", "докучать", "надоедать", "доставать", "задалбывать", "колошматить", "наказывать", "порочить", "ругать", "хаять"],
    "турумти": ["красношейный сокол"],
    "туруса": ["тырыса"],
    "турухтан": ["курухтан"],
    "турф": ["торф"],
    "турфирма": ["туроператор", "турагент"],
    "турция": ["турецкая республика"],
    "турчелка": ["сверчок"],
    "турында": ["хакта", "хакында", "турысында"],
    "турысында": ["хакта", "хакында", "турында"],
    "тусив": ["тусивши"],
    "тусивши": ["тусив"],
    "тусить": ["тусоваться", "проводить время"],
    "тускииз": ["тус кииз", "текемет", "сырмак", "гобелен", "шпалера"],
    "тускло-красный": ["бледно-красный"],
    "тусклый": ["мутный"],
    "тускнев": ["тускневши"],
    "тускневши": ["тускнев"],
    "тускнеть": ["блёкнуть", "тускнуть", "слабеть"],
    "тускнув": ["тускнувши"],
    "тускнувши": ["тускнув"],
    "тусовав": ["тусовавши"],
    "тусовавши": ["тусовав"],
    "тусоваться": ["проводить время", "тусить", "дружить", "водиться", "якшаться", "гулять", "находиться", "пребывать", "присутствовать", "околачиваться", "обретаться", "ошиваться", "слоняться"],
    "тусовка": ["гулянка", "кружок", "междусобойчик"],
    "тут": ["здесь", "сейчас"],
    "тут как тут": ["сразу"],
    "тута": ["тутовое дерево", "тут", "шелковица"],
    "тутка": ["туточка"],
    "тутмадемс": ["ряфцодомс", "толхмадемс", "тостядемс"],
    "тутовник": ["тутовое дерево", "тут", "тутовница", "шелковица"],
    "тутовое дерево": ["шелковица"],
    "тутовый": ["шелковичный"],
    "тутошний": ["местный", "здешний"],
    "тутси": ["батутси"],
    "тутушкав": ["тутушкавши"],
    "тутушкавши": ["тутушкав"],
    "тутушкать": ["тетёшкать"],
    "туул": ["тола"],
    "туфель": ["туфля"],
    "туфля": ["ботинок", "полуботинок"],
    "туфта": ["враньё", "ложь", "неправда", "фигня", "фуфло", "подделка", "фальшивка", "мошенничество"],
    "тухату": ["асам"],
    "тухлив": ["тухливши"],
    "тухливши": ["тухлив"],
    "тухлить": ["скучать", "тухнуть"],
    "тухлый": ["протухший", "гнилой"],
    "тухнув": ["тухнувши"],
    "тухнувши": ["тухнув"],
    "тухнуть": ["ослабевать", "уменьшаться", "затухать", "тускнеть", "загнивать", "разлагаться", "депрессовать", "расстраиваться", "скучать"],
    "тухта": ["тюхта"],
    "туця": ["ковол"],
    "туча": ["базар", "рынок", "толкучка"],
    "тучка": ["облачко"],
    "тучнев": ["тучневши"],
    "тучневши": ["тучнев"],
    "тучность": ["полнота", "упитанность"],
    "тучный": ["толстый", "жирный", "корпулентный"],
    "туша": ["громада"],
    "тушбера": ["барак"],
    "тушевав": ["тушевавши"],
    "тушевавши": ["тушевав"],
    "тушеваться": ["робеть", "смущаться"],
    "тушение": ["гашение"],
    "тушенье": ["тушение"],
    "тушив": ["тушивши"],
    "тушивши": ["тушив"],
    "тушировав": ["тушировавши"],
    "тушировавши": ["тушировав"],
    "тушитель": ["гаситель"],
    "тушить": ["гасить", "выключать", "подавлять"],
    "тушка": ["окорочок", "тельце"],
    "тушканчик": ["тушкан"],
    "тушёнка": ["тушняк"],
    "туьбек": ["мылтык"],
    "туя": ["туйя"],
    "тфилин": ["филактерия", "тфиллин"],
    "тхамна": ["чеджу"],
    "тхьапш": ["шыдфэдиз"],
    "тц": ["торговый центр", "тормозной цилиндр"],
    "тцк": ["территориальный центр комплектования", "тцк и сп", "военный комиссариат", "военкомат"],
    "тцк и сп": ["территориальный центр комплектования", "тцк", "военный комиссариат", "военкомат"],
    "тчк": ["точка"],
    "тщание": ["рвение", "старание", "тщательность", "усердие"],
    "тщанье": ["тщание"],
    "тщательно": ["прилежно", "усердно", "аккуратно", "добросовестно", "основательно", "скрупулёзно", "старательно"],
    "тщательный": ["аккуратный", "доскональный", "скрупулёзный", "старательный"],
    "тщедушие": ["слабосилие", "хилость"],
    "тщедушный": ["хилый", "слабый", "слабосильный", "немощный"],
    "тщеславие": ["тщеславность", "честолюбие"],
    "тщеславность": ["тщеславие"],
    "тщеславье": ["тщеславие"],
    "тщета": ["тщетность"],
    "тщетно": ["напрасно", "зря", "безуспешно", "безрезультатно", "бесполезно", "без толку", "впустую", "понапрасну", "попусту", "даром", "вотще", "втуне", "всуе", "бесплодно", "зазря"],
    "тщетность": ["тщета", "безуспешность", "безрезультатность", "бесплодность", "бесполезность", "напрасность", "зряшность", "безрезультативность", "суетность"],
    "тщетный": ["напрасный", "безрезультатный", "безуспешный", "бесплодный", "бесполезный"],
    "тщиться": ["силиться"],
    "тъждество": ["тъждественост", "еднаквост", "равенство", "идентичност"],
    "тъжител": ["молител", "ищец", "апелатор"],
    "тълковник": ["тълкувател", "интерпретатор"],
    "тълпа": ["множество", "многолюдие", "навалица", "калабалък", "орталък"],
    "тъмнина": ["мрачина", "мрачевина", "тъма", "нощ", "тъмнота", "тъмнотия", "невежество", "мракобесие", "обскурантизъм"],
    "тънтеж": ["тътнеж", "тътен", "кънтеж", "екот", "грохот", "бумтеж"],
    "тънярс": ["инголе", "тянемс"],
    "тънярстонь": ["сядонгольдень"],
    "тъпак": ["глупак", "малоумник", "дръвник"],
    "търгаш": ["спекулант", "гешефтар", "търговец"],
    "тържище": ["панаир"],
    "търнокоп": ["копач", "копачка"],
    "търпеж": ["търпение"],
    "тътен": ["тънтеж", "тътнеж", "грохот"],
    "тыва": ["тува", "республика тыва", "рт"],
    "тывалар": ["тыва кижи"],
    "тызылдарга": ["жуылдарга", "бызылдарга", "выжларга", "выжылдарга"],
    "тык": ["тычок", "толчок"],
    "тыкав": ["тыкавши"],
    "тыкавши": ["тыкав"],
    "тыканье": ["тыкание"],
    "тыкая": ["тыча"],
    "тыква": ["тебека", "кебебка", "кипека", "гарбуз", "кабак", "кабака", "бухарка", "дурак"],
    "тыквообразный": ["тыквоподобный"],
    "тыквоподобный": ["тыквообразный"],
    "тыкнув": ["тыкнувши"],
    "тыкнувши": ["тыкнув"],
    "тыкнуть": ["ткнуть"],
    "тыл": ["зад"],
    "тыльный": ["задний", "наружный", "внешний"],
    "тын": ["забор", "частокол", "плетень"],
    "тында": ["столица бама"],
    "тынзян": ["маут"],
    "тынч": ["тынц"],
    "тырах": ["цхиря", "чобота"],
    "тырив": ["тыривши"],
    "тыривши": ["тырив"],
    "тырить": ["красть", "воровать", "лямзить", "уворовывать", "бондить", "тибрить", "таскать", "утаскивать", "тянуть", "похищать", "тащить", "грабить", "хватать", "присваивать", "прятать"],
    "тыркав": ["тыркавши"],
    "тыркавши": ["тыркав"],
    "тыркнув": ["тыркнувши"],
    "тыркнувши": ["тыркнув"],
    "тырнауыш": ["тырма", "тырмауыш"],
    "тырнув": ["тырнувши"],
    "тырнувши": ["тырнув"],
    "тырса": ["ковыль-волосатик", "ковыль волосовидный"],
    "тыры-пыры": ["пятое-десятое", "то-сё", "туда-сюда"],
    "тырыса": ["туруса"],
    "тысяча": ["тысяща", "тыща", "куча", "мириады", "множество", "туча"],
    "тысячеглавый": ["тысячеголовый"],
    "тысячегласый": ["тысячеголосый", "многоголосый", "многозвучный"],
    "тысячеголовый": ["тысячеглавый"],
    "тысячеголосый": ["тысячегласый", "многоголосый"],
    "тысячелетие": ["миллениум", "тысячелетье"],
    "тысячелетье": ["тысячелетие"],
    "тысяченожка": ["многоножка"],
    "тысячу раз": ["сто пятьсот"],
    "тыфиля": ["тэфилла"],
    "тыча": ["тыкая"],
    "тычинка": ["пыльцелистик"],
    "тычинковый": ["тычиночный"],
    "тычиночный": ["тычинковый"],
    "тьма": ["темнота", "темень", "мгла", "мрак", "потёмки", "хаос"],
    "тьма-тьмущая": ["тьма"],
    "тьмутараканский": ["тмутараканский"],
    "тьмутаракань": ["тмутаракань"],
    "тьфу": ["фу", "тьфу ты"],
    "тьютор": ["тьютер"],
    "тьягу": ["тиаго", "тиагу"],
    "тэгэк": ["сирга", "толгоки"],
    "тэй": ["ча"],
    "тэк": ["сибирский козёл", "центральноазиатский козёл"],
    "тэмир": ["дэмир"],
    "тэнгиз": ["дэниз", "дэнъиз", "теньгизь", "тэниз"],
    "тэндри": ["адонай", "танри"],
    "тэс": ["тёш"],
    "тэтан": ["фетан"],
    "тэфила": ["йалбармак"],
    "тэфилла": ["тэфила", "тыфиля"],
    "тэц": ["теплоэлектроцентраль"],
    "тю": ["шам", "сам"],
    "тю-тю": ["аля-улю", "прощать", "поезд ушёл", "пиши пропало", "ту-ту"],
    "тюб": ["тюбик"],
    "тюбетейка": ["такыя", "татарская ермолка", "тафья"],
    "тюбик": ["туба", "додик"],
    "тюбиковый": ["тюбичный"],
    "тюбинг": ["бублик", "ватрушка"],
    "тюбичный": ["тюбиковый"],
    "тюз": ["театр юного зрителя"],
    "тюзлюк": ["тюзьлюк"],
    "тюзьлюк": ["тизлик"],
    "тюк": ["связка"],
    "тюкав": ["тюкавши"],
    "тюкавши": ["тюкав"],
    "тюкнув": ["тюкнувши"],
    "тюкнувши": ["тюкнув"],
    "тюкнуть": ["ударить"],
    "тюковав": ["тюковавши"],
    "тюковавши": ["тюковав"],
    "тюленебоец": ["тюленебой"],
    "тюленевый": ["тюлений"],
    "тюлений": ["тюленевый"],
    "тюлень": ["сиварь", "сивуч", "секач", "лысун"],
    "тюлень-монах": ["белобрюхий тюлень"],
    "тюль": ["занавеска", "штора", "полотно", "занавес", "сетка", "шатёр", "ткань", "завеса", "покрывало"],
    "тюлька": ["сарделька"],
    "тюльпан": ["раковина-тюльпан", "юбка-тюльпан", "морской тюльпан", "морской жёлудь"],
    "тюльпановая революция": ["революция тюльпанов"],
    "тюльпанчик": ["тюльпан"],
    "тюлюлюкав": ["тюлюлюкавши"],
    "тюлюлюкавши": ["тюлюлюкав"],
    "тюменская область": ["тюменщина"],
    "тюнер": ["тьюнер"],
    "тюнинг": ["настройка"],
    "тюнинговав": ["тюнинговавши"],
    "тюнинговавши": ["тюнинговав"],
    "тюпати": ["тюпачити"],
    "тюрбан": ["чалма"],
    "тюрбо": ["большой ромб", "камбала"],
    "тюремный": ["пенитенциарный"],
    "тюремс": ["бороцямс"],
    "тюрик": ["кулёк", "тюрюк", "шпуля"],
    "тюрк": ["тюрок"],
    "тюркизация": ["отуречивание"],
    "тюркоязычный": ["тюркскоязычный", "тюркский"],
    "тюркскоязычный": ["тюркоязычный"],
    "тюрок": ["тюрк", "чурка"],
    "тюрьма": ["заключение"],
    "тюря": ["месиво", "мешанина", "каша", "рохля", "губошлеп", "мямля", "недотёпа", "растяпа", "размазня", "телепень", "тюфяк", "шляпа"],
    "тютелька": ["тютя"],
    "тютелька в тютельку": ["ни на йоту", "ни на волос"],
    "тютина": ["шелковица"],
    "тютю": ["тю-тю"],
    "тютюкав": ["тютюкавши"],
    "тютюкавши": ["тютюкав"],
    "тютюн": ["табак"],
    "тютюшкав": ["тютюшкавши"],
    "тютюшкавши": ["тютюшкав"],
    "тютя": ["разиня", "растяпа", "раззява"],
    "тюфяк": ["мешок", "тюшак", "лентяй", "лопух", "мямля", "недотёпа", "растяпа", "рохля", "слабак", "тряпка", "тюлень", "увалень"],
    "тюхадемс": ["сельгомс"],
    "тя": ["па", "папа", "отец", "папенька"],
    "тявкав": ["тявкавши"],
    "тявкавши": ["тявкав"],
    "тявкать": ["вякать", "выступать"],
    "тявкаться": ["собачиться"],
    "тявкнув": ["тявкнувши"],
    "тявкнувши": ["тявкнув"],
    "тяга": ["сила", "страсть", "тяготение", "притяжение", "пристрастие"],
    "тягав": ["тягавши"],
    "тягавши": ["тягав"],
    "тягальный": ["тяговый"],
    "тягать": ["тянуть", "дёргать", "вытаскивать", "носить", "таскать"],
    "тягаться": ["соперничать", "состязаться", "судиться"],
    "тягач": ["грузовой тягач"],
    "тягивав": ["тягивавши"],
    "тягивавши": ["тягивав"],
    "тяглый": ["тягловый"],
    "тягостный": ["тяжёлый", "тяжкий"],
    "тяготев": ["тяготевши"],
    "тяготевши": ["тяготев"],
    "тяготение": ["притяжение", "влечение", "стремление"],
    "тяготив": ["тяготивши"],
    "тяготивши": ["тяготив"],
    "тяготить": ["отягощать", "обременять", "угнетать"],
    "тягуче": ["медленно", "неторопливо", "протяжно", "пространно"],
    "тягчив": ["тягчивши"],
    "тягчивши": ["тягчив"],
    "тягчимый": ["отягчаемый", "отягощаемый"],
    "тядя": ["тяря", "ава"],
    "тяжба": ["процесс", "судебный процесс", "спор", "разногласие"],
    "тяжебщик": ["тяжебник", "сутяга"],
    "тяжелев": ["тяжелевши"],
    "тяжелевши": ["тяжелев"],
    "тяжелеть": ["тучнеть", "толстеть", "полнеть", "деревенеть"],
    "тяжелив": ["тяжеливши"],
    "тяжеливши": ["тяжелив"],
    "тяжело": ["тяжко", "трудно", "трудоёмко", "сурово"],
    "тяжелодум": ["тугодум", "тяжкодум"],
    "тяжелораненый": ["тяжелопоражённый"],
    "тяжеляк": ["тяжёлый металл", "тяжесть", "трудность", "трудняк"],
    "тяжение": ["натяжение"],
    "тяжесть": ["тяжёлость", "весомость", "вес", "серьёзность", "тяжкость", "тяготение", "груз", "бремя", "трудность", "затруднение", "дискомфорт", "угнетённость"],
    "тяжкость": ["тяжесть", "тяжёлость"],
    "тяжёлая огнемётная система": ["тос"],
    "тяжёлость": ["тяжесть", "тяжкость"],
    "тяжёлый": ["увесистый", "массивный", "трудный", "сложный", "невосполнимый", "густой", "низкий"],
    "тяжёлый металл": ["тяжеляк"],
    "тяжёлый острый респираторный синдром": ["торс", "атипичная пневмония"],
    "тякав": ["тякавши"],
    "тякавши": ["тякав"],
    "тяло": ["предмет", "вещ", "нещо", "организъм", "труп", "мъртвец", "туловище"],
    "тям": ["ум"],
    "тяма": ["соображалка", "мозги"],
    "тямити": ["тямкувати", "тямувати"],
    "тямкий": ["тямовитий", "тямущий"],
    "тян": ["девушка", "девочка", "тянка", "гёрлфренд"],
    "тяникиге": ["тяниёк"],
    "тяниёк": ["тяникиге"],
    "тянка": ["тян"],
    "тяночка": ["милашка"],
    "тянув": ["тянувши"],
    "тянувши": ["тянув"],
    "тянуть": ["тащить", "притягивать", "подтягивать", "веять", "нести", "влечь", "манить", "увлекать", "хотеться", "подмывать", "не терпеться", "медлить", "мешкать", "тянуть кота за хвост", "тормозить"],
    "тянуть волынку": ["волынить"],
    "тянуть за душу": ["трепать нервы", "не давать житья", "выматывать душу", "портить кровь", "изводить"],
    "тянуть канитель": ["разводить канитель", "канителиться"],
    "тянуть кота за хвост": ["тянуть резину", "ходить вокруг да около"],
    "тянуть одеяло на себя": ["ходить по головам"],
    "тянуть резину": ["тянуть кота за хвост", "вафлю жевать"],
    "тянуться": ["устремляться", "направляться", "домогаться", "удлиняться", "протянуться", "потягиваться", "простираться", "продолжаться", "длиться", "оставаться", "ползти", "следовать", "тянуть", "тягаться", "соперничать"],
    "тянучка": ["тянушка"],
    "тяп да ляп": ["спустя рукава"],
    "тяп-ляп": ["тяп да ляп", "и так сойдёт", "кое-как"],
    "тяпав": ["тяпавши"],
    "тяпавши": ["тяпав"],
    "тяпка": ["сечка", "сапка", "мотыга"],
    "тяпнув": ["тяпнувши"],
    "тяпнувши": ["тяпнув"],
    "тяпнуть": ["куснуть", "хряпнуть"],
    "тяря": ["тядя", "ава"],
    "тятенька": ["папа", "отец", "тятя", "тата", "папенька", "папуля", "папулька", "папулечка"],
    "тятька": ["тятя", "папка", "папа", "отец"],
    "тятя": ["отец"],
    "тяф": ["гав", "ав", "вау"],
    "тяфта жа": ["стане жа"],
    "тяфтак": ["станяк", "стак", "ярмакфтома", "питнефтома"],
    "тяште": ["тяштеня", "тяштькс"],
    "тёбе": ["тав"],
    "тёзка": ["соименник", "соименница", "тёза", "тезь", "тезя", "пантёма"],
    "тёлка": ["нетель", "телица", "телушка", "цыпочка"],
    "тёлочка": ["тёлка"],
    "тёма": ["артём", "артёмка", "артюха", "тёмка", "тюха"],
    "тёмная": ["арестантская", "карцер"],
    "тёмная вода": ["слепота"],
    "тёмная комната": ["темнуха"],
    "тёмная лошадка": ["кот в мешке"],
    "тёмная полоса": ["чёрная полоса", "неурядицы"],
    "тёмная цистерна": ["бочка"],
    "тёмно-жёлтый": ["желтоватый", "коричневатый", "желтовато-коричневатый", "охристый"],
    "тёмно-медовый": ["тёмно-янтарный"],
    "тёмный": ["печальный", "безрадостный", "мрачный", "гнетущий", "хмурый"],
    "тёмный лес": ["дремучий лес"],
    "тёрка": ["разборки", "спор", "стёрка", "ластик", "резинка"],
    "тёрн": ["терновник", "тёрен", "слива"],
    "тёрочник": ["курант", "пест"],
    "тёртый": ["бывалый", "видавший виды", "искушённый", "матёрый", "опытный"],
    "тёртый калач": ["стреляный воробей", "тёртый хуй"],
    "тёсаный": ["тесовый"],
    "тёска": ["тесание"],
    "тёсывав": ["тёсывавши"],
    "тёсывавши": ["тёсывав"],
    "тётин": ["тёткин"],
    "тётка": ["тётя", "мадам", "фрау"],
    "тёткин": ["тётин"],
    "тётьмак": ["идь", "шаба"],
    "тётя": ["тётка", "тётенька", "женщина", "баба"],
    "тётя мотя": ["тётя-мотя", "тётка", "баба"],
    "тёхана": ["тётка", "бабенция"],
    "тёш": ["тэс"],
    "у семи нянек дитя без глаза": ["при двух кормчих корабль тонет"],
    "у смерти": ["при смерти"],
    "у спесивого волчья шея": ["у спесивого кол в шее"],
    "у чёрта на куличках": ["в глуши", "за тридевять земель", "у чёрта на рогах"],
    "уаджет": ["уджат", "узат", "утчат"],
    "уаз": ["бобик", "буханка", "уазик"],
    "убавив": ["убавивши"],
    "убавивши": ["убавив"],
    "убавиться": ["уменьшиться"],
    "убавление": ["уменьшение"],
    "убавляв": ["убавлявши"],
    "убавлявши": ["убавляв"],
    "убавлять": ["сокращать", "убирать", "скидывать"],
    "убагнути": ["збагнути"],
    "убакат": ["журнал"],
    "убалтывав": ["убалтывавши"],
    "убалтывавши": ["убалтывав"],
    "убаюкав": ["убаюкавши"],
    "убаюкавши": ["убаюкав"],
    "убаюкивав": ["убаюкивавши"],
    "убаюкивавши": ["убаюкивав"],
    "убаюкиванье": ["убаюкивание"],
    "убаюкиватель": ["успокоитель"],
    "убаюкивать": ["баюкать", "укачивать", "усыплять", "успокаивать"],
    "убегав": ["убегавши"],
    "убегавши": ["убегав"],
    "убегание": ["убежание"],
    "убеганье": ["убегание"],
    "убегать": ["отбегать", "избегать"],
    "убегти": ["убечь", "убежать"],
    "убедив": ["убедивши"],
    "убедивши": ["убедив"],
    "убедить": ["уговорить", "доказать", "уверить", "склонить", "перетянуть"],
    "убедиться": ["удостовериться", "увериться", "утвердиться"],
    "убежав": ["убежавши"],
    "убежавши": ["убежав"],
    "убежание": ["убегание", "избегание"],
    "убежать": ["удалиться", "дать тягу", "смыться", "избежать"],
    "убеждав": ["убеждавши"],
    "убеждавши": ["убеждав"],
    "убеждать": ["уговаривать", "доказывать"],
    "убеждаться": ["удостоверяться"],
    "убеждение": ["уговор", "уговаривание", "уверение", "увещание", "убежденье", "уговариванье", "уверенье", "увещанье", "вера", "уверенность", "убеждённость", "принцип"],
    "убежденье": ["убеждение"],
    "убеждённость": ["уверенность", "вера"],
    "убежище": ["укрытие", "бункер", "укромное место", "крепость", "приют", "пристанище", "прибежище"],
    "убелив": ["убеливши"],
    "убеливши": ["убелив"],
    "убеляв": ["убелявши"],
    "убелявши": ["убеляв"],
    "уберегав": ["уберегавши"],
    "уберегавши": ["уберегав"],
    "уберегать": ["беречь", "сохранять", "сберегать"],
    "уберечь": ["сохранить", "оградить", "защитить"],
    "убив": ["убивши"],
    "убивав": ["убивавши"],
    "убивавши": ["убивав"],
    "убиваемый": ["умерщвляемый"],
    "убивание": ["убийство", "убиение", "умерщвление"],
    "убиванье": ["убивание"],
    "убивать": ["умерщвлять", "уничтожать", "губить", "разрушать"],
    "убиваться": ["разбиваться", "горевать", "пахать"],
    "убивец": ["убийца", "душегуб"],
    "убивець": ["убивця"],
    "убивица": ["убийца", "киллерша", "абречка"],
    "убивство": ["убийство", "убиение", "умерщвление", "мокрое дело", "душегубство", "смертоубийство", "кровь"],
    "убивця": ["убивець"],
    "убивши": ["убив"],
    "убивший": ["умертвивший"],
    "убиение": ["убийство", "умерщвление", "душегубство", "смертоубийство", "мокрое дело", "кровь"],
    "убиенный": ["убитый", "умерщвлённый"],
    "убийственность": ["смертоносный", "вредный", "губительный"],
    "убийственный": ["смертоносный", "гибельный", "убойный", "вредный", "губительный", "вредоносный", "чрезмерный", "резкий", "беспощадный", "уничтожающий"],
    "убийство": ["умерщвление", "убиение", "смертоубийство", "душегубство", "мокрое дело", "кровь"],
    "убийца": ["душегуб", "душегубец", "убивец"],
    "убиквист": ["эврибионт", "приспособленец", "хамелеон"],
    "убиквитарность": ["повсеместность", "вездесущесть", "вездесущность"],
    "убирав": ["убиравши"],
    "убиравши": ["убирав"],
    "убирание": ["уборка"],
    "убиратка": ["промокашка"],
    "убирать": ["удалять", "изымать", "уносить", "устранять", "прятать", "складывать", "собирать", "прибирать", "наводить порядок", "украшать", "наряжать"],
    "убираться": ["убирать", "наводить порядок", "прибираться", "производить уборку", "наряжаться", "украшаться"],
    "убитый": ["убиенный", "умерщвлённый", "павший", "потрясённый", "подавленный", "сломанный", "ушатанный", "упоротый", "вмазанный"],
    "убитый енот": ["доллар", "бакс", "условная единица"],
    "убить": ["разрушить", "уничтожить", "умножить на ноль", "огорошить"],
    "убиться": ["зашибиться", "ушибиться", "разбиться"],
    "убихинон": ["убидекаренон"],
    "ублаготворив": ["ублаготворивши"],
    "ублаготворивши": ["ублаготворив"],
    "ублаготворить": ["угобзить"],
    "ублаготворяв": ["ублаготворявши"],
    "ублаготворявши": ["ублаготворяв"],
    "ублажав": ["ублажавши"],
    "ублажавши": ["ублажав"],
    "ублажать": ["угождать", "обхаживать"],
    "ублаженье": ["ублажение"],
    "ублажив": ["ублаживши"],
    "ублаживши": ["ублажив"],
    "ублюдок": ["помесь", "полукровка", "мразь", "бастард"],
    "ублюдочный": ["дрянной", "омерзительный", "чудовищный", "уёбищный"],
    "убогий": ["жалкий", "нищий", "скудный", "ничтожный", "попрошайка", "больной", "юродивый"],
    "убогость": ["увечье", "увечность", "убожество", "бедность", "нищета", "ничтожество", "незначительность"],
    "убожев": ["убожевши"],
    "убожевши": ["убожев"],
    "убожество": ["убогость", "ничтожность", "ничтожество", "бедность"],
    "убожив": ["убоживши"],
    "убоживши": ["убожив"],
    "убойный": ["смертоносный", "смертельный", "классный", "офигенный"],
    "уболтав": ["уболтавши"],
    "уболтавши": ["уболтав"],
    "убор": ["уборка", "сбор", "наряд", "убранство"],
    "уборик": ["убор"],
    "убористо": ["компактно", "тесно", "плотно"],
    "убористый": ["компактный", "плотный"],
    "уборка": ["сбор", "чистка"],
    "уборная": ["гримёрная", "туалетная комната", "туалет", "сортир", "толчок", "нужник"],
    "уборщик": ["чистильщик"],
    "уборщица": ["техничка", "техслужащая", "поломойка"],
    "убояться": ["испугаться", "устрашиться"],
    "убрав": ["убравши"],
    "убравши": ["убрав"],
    "убранство": ["наряд", "отделка", "обстановка", "интерьер"],
    "убрать": ["устранить", "спрятать", "пожать", "прибрать", "уложить", "причесать", "украсить", "нарядить", "принять на грудь", "вмазать", "клюкнуть", "накатить", "распить", "выбухать", "убить"],
    "убредав": ["убредавши"],
    "убредавши": ["убредав"],
    "уброд": ["пухляк"],
    "убухав": ["убухавши"],
    "убухавши": ["убухав"],
    "убывав": ["убывавши"],
    "убывавши": ["убывав"],
    "убыванье": ["убывание"],
    "убывать": ["уменьшаться", "спадать", "выбывать"],
    "убывши": ["убыв"],
    "убылой": ["убывший", "отлив"],
    "убыль": ["убыток", "убывание"],
    "убыстрив": ["убыстривши"],
    "убыстривши": ["убыстрив"],
    "убыстрить": ["ускорить"],
    "убыстриться": ["ускориться"],
    "убыстряв": ["убыстрявши"],
    "убыстрявши": ["убыстряв"],
    "убыстрять": ["ускорять"],
    "убыстрённый": ["ускоренный"],
    "убыток": ["потеря", "урон"],
    "убыточив": ["убыточивши"],
    "убыточивши": ["убыточив"],
    "убыточность": ["бесприбыльность"],
    "убыточный": ["невыгодный", "нерентабельный", "убытчивый", "накладный"],
    "убыхский": ["убыхский язык", "убыхоязычный"],
    "убыхский язык": ["убыхский"],
    "уважав": ["уважавши"],
    "уважавши": ["уважав"],
    "уважаемый": ["почитаемый", "почтенный", "почтеннейший", "достопочтенный"],
    "уважать": ["почитать", "благоговеть", "боготворить", "соблюдать"],
    "уважение": ["почёт", "респект", "уваженье"],
    "уваженье": ["уважение"],
    "уважив": ["уваживши"],
    "уваживав": ["уваживавши"],
    "уваживавши": ["уваживав"],
    "уваживши": ["уважив"],
    "уважительно": ["почтительно"],
    "уважительный": ["значительный", "почтительный"],
    "уважить": ["оказать", "внимание"],
    "уважуха": ["респект"],
    "увал": ["ухаб", "уваливание"],
    "увалив": ["уваливши"],
    "уваливав": ["уваливавши"],
    "уваливавши": ["уваливав"],
    "уваливши": ["увалив"],
    "увалистый": ["холмистый"],
    "уваляв": ["увалявши"],
    "увалявши": ["уваляв"],
    "уварив": ["уваривши"],
    "уваривав": ["уваривавши"],
    "уваривавши": ["уваривав"],
    "уваривши": ["уварив"],
    "уведав": ["уведавши"],
    "уведавши": ["уведав"],
    "уведомив": ["уведомивши"],
    "уведомивши": ["уведомив"],
    "уведомитель": ["заявитель"],
    "уведомить": ["известить", "оповестить", "проинформировать", "сообщить"],
    "уведомление": ["информирование", "оповещение", "извещение"],
    "уведомленье": ["уведомление"],
    "уведомляв": ["уведомлявши"],
    "уведомлявши": ["уведомляв"],
    "уведомлять": ["сообщать", "информировать", "извещать", "осведомлять", "докладывать", "доносить", "заявлять", "объявлять", "оповещать", "предупреждать"],
    "увезя": ["увёзши"],
    "увековечение": ["увековечивание"],
    "увековеченье": ["увековечение"],
    "увековечив": ["увековечивши"],
    "увековечивав": ["увековечивавши"],
    "увековечивавши": ["увековечивав"],
    "увековечивши": ["увековечив"],
    "увековечить": ["обессмертить", "укоренить"],
    "увеличение": ["возрастание", "рост", "повышение", "прибавление", "разрастание", "умножение", "подъём", "прирост", "приближение", "зум"],
    "увеличенный": ["превышенный", "превзойдённый"],
    "увеличенье": ["увеличение"],
    "увеличив": ["увеличивши"],
    "увеличивав": ["увеличивавши"],
    "увеличивавши": ["увеличивав"],
    "увеличивать": ["наращивать", "повышать"],
    "увеличиваться": ["умножаться", "прибавляться"],
    "увеличивши": ["увеличив"],
    "увеличитель": ["фотоувеличитель"],
    "увеличительное стекло": ["лупа"],
    "увеличить": ["нарастить", "повысить"],
    "увеличиться": ["вырасти"],
    "увенчав": ["увенчавши"],
    "увенчавши": ["увенчав"],
    "увенчанье": ["увенчание"],
    "увенчивав": ["увенчивавши"],
    "увенчивавши": ["увенчивав"],
    "уверен": ["сигурен"],
    "уверенно": ["твёрдо"],
    "уверенье": ["уверение"],
    "уверив": ["уверивши"],
    "уверивши": ["уверив"],
    "увериться": ["убедиться", "удостовериться", "поверить"],
    "увернув": ["увернувши"],
    "увернувши": ["увернув"],
    "увернуться": ["уклониться", "увильнуть"],
    "уверовав": ["уверовавши"],
    "уверовавши": ["уверовав"],
    "уверовать": ["поверить"],
    "уверстав": ["уверставши"],
    "уверставши": ["уверстав"],
    "увертев": ["увертевши"],
    "увертевши": ["увертев"],
    "увертюра": ["прелюдия", "пролог", "вступление"],
    "уверяв": ["уверявши"],
    "уверявши": ["уверяв"],
    "уверять": ["убеждать", "внушать"],
    "уверяться": ["убеждаться", "удостоверяться"],
    "увеселенье": ["увеселение"],
    "увеселив": ["увеселивши"],
    "увеселивши": ["увеселив"],
    "увеселитель": ["забавник", "острослов", "остряк", "проказник", "затейщик", "массовик", "затейник", "чудак", "шутник", "весельчак", "потешатель", "потешник", "развлекатель", "шут", "уморник"],
    "увеселительный": ["развлекательный"],
    "увеселяв": ["увеселявши"],
    "увеселявши": ["увеселяв"],
    "увесив": ["увесивши"],
    "увесивши": ["увесив"],
    "увесистый": ["тяжёлый", "тяжеленный"],
    "увесить": ["увешать"],
    "увести": ["вывести", "отклонить", "отбить"],
    "увестив": ["увестивши"],
    "увестивши": ["увестив"],
    "увечар": ["увечары", "вечарам"],
    "увечары": ["увечар", "вечарам"],
    "увечив": ["увечивши"],
    "увечивши": ["увечив"],
    "увечие": ["увечье"],
    "увечить": ["калечить", "уродовать", "портить", "искажать", "извращать"],
    "увечный": ["искалеченный", "калека"],
    "увечье": ["увечие"],
    "увешав": ["увешавши"],
    "увешавши": ["увешав"],
    "увешивав": ["увешивавши"],
    "увешивавши": ["увешивав"],
    "увешивать": ["обвешивать"],
    "увещав": ["увещавши"],
    "увещавши": ["увещав"],
    "увещание": ["увещевание"],
    "увещанье": ["увещание"],
    "увещатель": ["увещеватель"],
    "увещать": ["уговаривать", "убеждать", "увещевать"],
    "увещевав": ["увещевавши"],
    "увещевавши": ["увещевав"],
    "увещевание": ["убеждение", "внушение", "уговаривание", "увещеванье", "убежденье", "внушенье", "уговариванье"],
    "увещеванье": ["увещевание"],
    "увещевательно": ["назидательно"],
    "увещевательный": ["увещательный", "назидательный"],
    "увещевать": ["увещать", "уговаривать", "убеждать"],
    "увз": ["увх"],
    "увив": ["увивши"],
    "увивав": ["увивавши"],
    "увивавши": ["увивав"],
    "увивши": ["увив"],
    "увидав": ["увидавши"],
    "увидавши": ["увидав"],
    "увидать": ["углядеть", "узреть", "увидеть"],
    "увидев": ["увидевши"],
    "увидевши": ["увидев"],
    "увидеться": ["встретиться", "повидаться", "свидеться", "пересечься"],
    "увиливав": ["увиливавши"],
    "увиливавши": ["увиливав"],
    "увильнув": ["увильнувши"],
    "увильнувши": ["увильнув"],
    "увинтив": ["увинтивши"],
    "увинтивши": ["увинтив"],
    "увинчивав": ["увинчивавши"],
    "увинчивавши": ["увинчивав"],
    "увить": ["обвить"],
    "увлажав": ["увлажавши"],
    "увлажавши": ["увлажав"],
    "увлажив": ["увлаживши"],
    "увлаживши": ["увлажив"],
    "увлажить": ["увлажнить"],
    "увлажнив": ["увлажнивши"],
    "увлажнивши": ["увлажнив"],
    "увлажнявши": ["увлажняв"],
    "увлажняться": ["мокнуть", "намокать"],
    "увлекав": ["увлекавши"],
    "увлекавши": ["увлекав"],
    "увлекательный": ["занимательный", "интересный"],
    "увлекаться": ["интересоваться"],
    "увлечение": ["утягивание", "увод", "хобби", "увлечённость", "воодушевление", "азарт", "пассия", "страсть", "краш"],
    "увлеченье": ["увлечение"],
    "увлечь": ["заинтересовать"],
    "увлечённо": ["пылко", "заинтересованно", "с энтузиазмом", "воодушевлённо", "с огоньком", "с подъёмом", "страстно", "вдохновенно", "возбуждённо", "с увлечением", "запальчиво", "с азартом", "с пафосом"],
    "уводив": ["уводивши"],
    "уводивши": ["уводив"],
    "уводнив": ["уводнивши"],
    "уводнивши": ["уводнив"],
    "уводняв": ["уводнявши"],
    "уводнявши": ["уводняв"],
    "увозив": ["увозивши"],
    "увозивши": ["увозив"],
    "уволакивав": ["уволакивавши"],
    "уволакивавши": ["уволакивав"],
    "уволив": ["уволивши"],
    "уволивши": ["уволив"],
    "уволочив": ["уволочивши"],
    "уволочивши": ["уволочив"],
    "увольненье": ["увольнение"],
    "увольнительная": ["увольнительная записка", "увал"],
    "увольняв": ["увольнявши"],
    "увольнявши": ["увольняв"],
    "увольнять": ["давать расчёт"],
    "уворачивав": ["уворачивавши"],
    "уворачивавши": ["уворачивав"],
    "уворачивать": ["увёртывать"],
    "уворачиваться": ["завёртываться", "заворачиваться"],
    "уворовав": ["уворовавши"],
    "уворовавши": ["уворовав"],
    "уворовывав": ["уворовывавши"],
    "уворовывавши": ["уворовывав"],
    "уворотив": ["уворотивши"],
    "уворотивши": ["уворотив"],
    "увраж": ["книга", "сочинение", "фолиант"],
    "уврачевав": ["уврачевавши"],
    "уврачевавши": ["уврачевав"],
    "увч": ["увч-терапия"],
    "увч-терапия": ["увч"],
    "увы": ["к сожалению", "к несчастью", "к несчастию"],
    "увыл": ["ул"],
    "увядав": ["увядавши"],
    "увядавши": ["увядав"],
    "увядание": ["усыхание", "угасание", "упадок"],
    "увяданье": ["увядание"],
    "увядший": ["вялый", "поблекший", "пожухлый"],
    "увязав": ["увязавши"],
    "увязавши": ["увязав"],
    "увязать": ["вязнуть"],
    "увязив": ["увязивши"],
    "увязивши": ["увязив"],
    "увязка": ["увязывание"],
    "увязнув": ["увязнувши"],
    "увязнувши": ["увязнув"],
    "увязнуть": ["завязнуть"],
    "увязывав": ["увязывавши"],
    "увязывавши": ["увязывав"],
    "увязывать": ["обвязывать", "взаимоувязывать", "согласовывать", "координировать"],
    "увянув": ["увянувши"],
    "увянувши": ["увянув"],
    "увёзши": ["увезя"],
    "увёрстывав": ["увёрстывавши"],
    "увёрстывавши": ["увёрстывав"],
    "увёртывав": ["увёртывавши"],
    "увёртывавши": ["увёртывав"],
    "уг": ["унылое говно"],
    "угадав": ["угадавши"],
    "угадавши": ["угадав"],
    "угадив": ["угадивши"],
    "угадивши": ["угадив"],
    "угадывав": ["угадывавши"],
    "угадывавши": ["угадывав"],
    "угадыванье": ["угадывание"],
    "угадывать": ["отгадывать"],
    "угаживав": ["угаживавши"],
    "угаживавши": ["угаживав"],
    "угарный газ": ["угар", "окись углерода", "монооксид углерода"],
    "угасав": ["угасавши"],
    "угасавши": ["угасав"],
    "угасание": ["потухание"],
    "угасання": ["вгасання"],
    "угасать": ["гаснуть", "затухать", "погасать", "потухать", "тухнуть"],
    "угасив": ["угасивши"],
    "угасивши": ["угасив"],
    "угаснув": ["угаснувши"],
    "угаснувши": ["угаснув"],
    "угашав": ["угашавши"],
    "угашавши": ["угашав"],
    "угащивав": ["угащивавши"],
    "угащивавши": ["угащивав"],
    "угваздав": ["угваздавши"],
    "угваздавши": ["угваздав"],
    "угваздать": ["изгваздать", "измарать"],
    "угибав": ["угибавши"],
    "угибавши": ["угибав"],
    "угладив": ["угладивши"],
    "угладивши": ["угладив"],
    "углаживав": ["углаживавши"],
    "углаживавши": ["углаживав"],
    "углевод": ["сахар"],
    "углеволокно": ["углеродное волокно"],
    "углегорск": ["эсуторо", "хацапетовка", "циолковский"],
    "углежог": ["угольщик"],
    "углекислота": ["углекислый газ"],
    "углекислый газ": ["двуокись углерода", "диоксид углерода", "угольный ангидрид", "углекислота"],
    "углекоп": ["рудокоп", "шахтёр"],
    "углепластик": ["карбон"],
    "углепром": ["углепромышленность"],
    "углепромышленность": ["углепром"],
    "углеродный скелет": ["скелетная формула"],
    "углеродосодержащий": ["углеродсодержащий"],
    "углеродсодержащий": ["углеродосодержащий"],
    "углеткань": ["карбон"],
    "угловой коэффициент": ["наклон", "тангенс"],
    "угловой удар": ["угловой", "корнер"],
    "угломер": ["угломерка", "углометр"],
    "углометр": ["угломер"],
    "углубивши": ["углубив"],
    "углубление": ["погружение", "ямка", "выемка", "впадина"],
    "углубленье": ["углубление"],
    "углубляв": ["углублявши"],
    "углублявши": ["углубляв"],
    "углублённость": ["основательность", "углубление"],
    "углядев": ["углядевши"],
    "углядевши": ["углядев"],
    "углядывав": ["углядывавши"],
    "углядывавши": ["углядывав"],
    "углядывать": ["усматривать"],
    "угнав": ["угнавши"],
    "угнавши": ["угнав"],
    "угнездив": ["угнездивши"],
    "угнездивши": ["угнездив"],
    "угнетав": ["угнетавши"],
    "угнетавши": ["угнетав"],
    "угнетательница": ["притеснительница"],
    "угнетать": ["гнести", "притеснять", "подавлять", "удручать"],
    "угнетающе": ["гнетуще", "удручающе", "тягостно"],
    "угнетение": ["притеснение", "подавление", "подавленность"],
    "угнетенье": ["угнетение"],
    "угнетённо": ["удручённо", "подавленно"],
    "угнетённый": ["удручённый", "подавленный"],
    "угнув": ["угнувши"],
    "угнувши": ["угнув"],
    "угобжав": ["угобжавши"],
    "угобжавши": ["угобжав"],
    "угобзив": ["угобзивши"],
    "угобзивши": ["угобзив"],
    "уговаривав": ["уговаривавши"],
    "уговаривавши": ["уговаривав"],
    "уговариванье": ["уговаривание"],
    "уговаривать": ["убеждать", "успокаивать", "утешать", "выпивать"],
    "уговор": ["увещевание", "уговаривание", "договор", "договорённость", "обязательство", "соглашение"],
    "уговорив": ["уговоривши"],
    "уговоривши": ["уговорив"],
    "уговорить": ["убедить", "уверить"],
    "уговорчик": ["договорчик"],
    "угода": ["услада", "выгода", "угодье"],
    "угодив": ["угодивши"],
    "угодивши": ["угодив"],
    "угодить": ["потрафить", "попасть"],
    "угодливый": ["льстивый", "раболепный"],
    "угодничав": ["угодничавши"],
    "угодничавши": ["угодничав"],
    "угодничанье": ["угодничание"],
    "угодничать": ["подхалимничать", "заискивать", "лебезить", "пресмыкаться"],
    "угоднический": ["угодливый"],
    "угодничество": ["раболепство", "раболепие", "подхалимаж", "угодливость"],
    "угодно": ["желательно", "потребно"],
    "угодный": ["желанный", "желательный", "приемлемый"],
    "угодье": ["угодие"],
    "угождав": ["угождавши"],
    "угождавши": ["угождав"],
    "угождать": ["потворствовать", "услуживать", "потрафлять"],
    "угожденье": ["угождение"],
    "угоить": ["угоивать"],
    "угол": ["выступ", "пересечение", "пристанище", "приют", "обиталище", "обитель", "кров", "крыша над головой"],
    "уголовник": ["уголовничек"],
    "уголовно-процессуальное право": ["упп"],
    "уголовный": ["преступный", "криминальный"],
    "уголовный розыск": ["угро", "ур"],
    "уголь": ["чёрное золото", "головешка"],
    "уголье": ["уголь"],
    "угольный": ["угловой"],
    "угольщица": ["угольщик", "металлург"],
    "угомонив": ["угомонивши"],
    "угомонивши": ["угомонив"],
    "угомонить": ["успокоить", "унять", "утихомирить", "убить"],
    "угомонювати": ["угомоняти"],
    "угомоняв": ["угомонявши"],
    "угомонявши": ["угомоняв"],
    "угомоняти": ["угомонювати"],
    "угомонять": ["успокаивать", "унимать", "утихомиривать"],
    "угоняв": ["угонявши"],
    "угонявши": ["угоняв"],
    "угор": ["горка"],
    "угорав": ["угоравши"],
    "угоравши": ["угорав"],
    "угораздив": ["угораздивши"],
    "угораздивши": ["угораздив"],
    "угорать": ["увлекаться", "насмехаться", "насмешничать", "зубоскалить", "высмеивать"],
    "угорев": ["угоревши"],
    "угоревши": ["угорев"],
    "угорелый": ["угоревший"],
    "угорський": ["мадярський"],
    "угорье": ["предгорие", "предгорье", "взгорок", "взгорье"],
    "угостив": ["угостивши"],
    "угостивши": ["угостив"],
    "уготавливав": ["уготавливавши"],
    "уготавливавши": ["уготавливав"],
    "уготавливать": ["уготовлять"],
    "уготовав": ["уготовавши"],
    "уготовавши": ["уготовав"],
    "уготовать": ["уготовить"],
    "уготовив": ["уготовивши"],
    "уготовивши": ["уготовив"],
    "уготовить": ["уготовать"],
    "уготовляв": ["уготовлявши"],
    "уготовлявши": ["уготовляв"],
    "уготовлять": ["уготавливать"],
    "угощав": ["угощавши"],
    "угощавши": ["угощав"],
    "угребав": ["угребавши"],
    "угребавши": ["угребав"],
    "угрев": ["угревание", "нагрев", "нагревание", "согревание", "угрева", "припёк", "солнечная", "сторона", "пригрев"],
    "угревав": ["угревавши"],
    "угревавши": ["угревав"],
    "угреватев": ["угреватевши"],
    "угреватевши": ["угреватев"],
    "угревши": ["угрев"],
    "угро-финн": ["финно-угр"],
    "угробив": ["угробивши"],
    "угробивши": ["угробив"],
    "угробить": ["уничтожить", "ликвидировать", "погубить", "испортить", "убрать", "сломать"],
    "угробиться": ["убиться"],
    "угрожав": ["угрожавши"],
    "угрожавши": ["угрожав"],
    "угрожать": ["грозить", "грозиться", "таить опасность"],
    "угроза": ["предостережение", "острастка", "опасность"],
    "угрозив": ["угрозивши"],
    "угрозивши": ["угрозив"],
    "угрохав": ["угрохавши"],
    "угрохавши": ["угрохав"],
    "угрохать": ["убить", "грохнуть", "загубить", "испортить", "потратить", "израсходовать"],
    "угрубив": ["угрубивши"],
    "угрубивши": ["угрубив"],
    "угрубляв": ["угрублявши"],
    "угрублявши": ["угрубляв"],
    "угрызав": ["угрызавши"],
    "угрызавши": ["угрызав"],
    "угрызенье": ["угрызение"],
    "угрюмев": ["угрюмевши"],
    "угрюмевши": ["угрюмев"],
    "угрюмец": ["понура", "брюзгач", "мичура", "тухтырь"],
    "угрюмый": ["мрачный", "суровый", "неприветливый", "хмурый"],
    "угрязав": ["угрязавши"],
    "угрязавши": ["угрязав"],
    "угрязать": ["увязать", "погрязать"],
    "угрязнув": ["угрязнувши"],
    "угрязнувши": ["угрязнув"],
    "угу": ["мгм", "ага", "да"],
    "угыл": ["ул"],
    "уд": ["снасть", "уда"],
    "уда": ["удочка", "верёвка"],
    "удабривав": ["удабривавши"],
    "удабривавши": ["удабривав"],
    "удав": ["констриктор"],
    "удавив": ["удавивши"],
    "удавивши": ["удавив"],
    "удавить": ["удушить", "задавить", "задушить", "перекрыть кислород"],
    "удавиться": ["удушиться"],
    "удавленник": ["висельник"],
    "удавливав": ["удавливавши"],
    "удавливавши": ["удавливав"],
    "удавчик": ["песчаный удав"],
    "удаление": ["отдаление", "устранение", "изъятие", "абляция", "извлечение", "расстояние", "стирание", "уничтожение"],
    "удаленье": ["удаление"],
    "удалец": ["храбрец", "смельчак", "сорвиголова", "лихач"],
    "удалив": ["удаливши"],
    "удаливши": ["удалив"],
    "удалить": ["отдалить", "выдворить", "увести", "изъять", "вынуть", "устранить", "стереть", "уничтожить"],
    "удалиться": ["отдалиться", "скрыться", "пропасть из вида", "уйти", "устраниться", "отбыть", "покинуть"],
    "удало": ["удальски", "удалецки", "залихватски"],
    "удалой": ["удалый"],
    "удалый": ["удалой"],
    "удаль": ["молодечество", "удальство", "удалость"],
    "удальство": ["удаль"],
    "удаляв": ["удалявши"],
    "удалявши": ["удаляв"],
    "удалять": ["отдалять", "выдворять", "уводить", "изымать", "вынимать", "устранять", "стирать", "уничтожать"],
    "удаляться": ["отдаляться", "скрываться", "пропадать из вида", "уходить", "устраняться"],
    "удалёнка": ["удалённый доступ", "удалённая работа", "удалённое обучение", "дистант"],
    "удалённо": ["дистанционно"],
    "удалённость": ["удаление", "дальность", "отдалённость"],
    "удалённый": ["отдалённый"],
    "удар": ["толчок", "хлопок", "бомбёжка", "обстрел", "обработка"],
    "удар каблуком": ["каблук"],
    "удар ниже пейджера": ["удар ниже пояса"],
    "ударение": ["акцент"],
    "ударенный": ["битый", "побитый", "избитый", "ударяемый", "ударный", "звонкий", "звучный"],
    "ударенье": ["ударение"],
    "ударив": ["ударивши"],
    "ударивши": ["ударив"],
    "ударить в грязь лицом": ["оплошать"],
    "ударить в дёсны": ["удариться в дёсны"],
    "удариться": ["стукнуться", "предаться", "броситься"],
    "удариться в дёсны": ["ударить в дёсны"],
    "удариться в слёзы": ["зарыдать"],
    "ударник": ["боёк"],
    "ударница": ["хорошистка", "четвёрочница"],
    "ударостойкий": ["удароустойчивый"],
    "ударостойкость": ["удароустойчивость"],
    "удароустойчивость": ["ударостойкость"],
    "удароустойчивый": ["ударостойкий"],
    "ударяв": ["ударявши"],
    "ударявши": ["ударяв"],
    "ударять": ["бить", "стукать"],
    "удаться": ["выйти", "получиться", "довестись"],
    "удача": ["успех", "везение", "счастье", "фортуна", "шанс"],
    "удачливый": ["везучий"],
    "удачник": ["счастливчик", "везунчик"],
    "удачница": ["счастливица"],
    "удачно": ["успешно", "благополучно", "счастливо", "уместно", "к месту", "кстати", "вовремя"],
    "удачность": ["успешность"],
    "удачный": ["успешный", "благополучный", "хороший"],
    "удваивав": ["удваивавши"],
    "удваивавши": ["удваивав"],
    "удваивание": ["удвоение"],
    "удвоение": ["удваивание", "удвоенье"],
    "удвоив": ["удвоивши"],
    "удвоивав": ["удвоивавши"],
    "удвоивавши": ["удвоивав"],
    "удвоивши": ["удвоив"],
    "удвояв": ["удвоявши"],
    "удвоявши": ["удвояв"],
    "удевятерив": ["удевятеривши"],
    "удевятеривши": ["удевятерив"],
    "удевятеряв": ["удевятерявши"],
    "удевятерявши": ["удевятеряв"],
    "удел": ["судьба", "доля", "участь", "жребий"],
    "уделав": ["уделавши"],
    "уделавши": ["уделав"],
    "уделив": ["уделивши"],
    "уделивши": ["уделив"],
    "уделывав": ["уделывавши"],
    "уделывавши": ["уделывав"],
    "уделяв": ["уделявши"],
    "уделявши": ["уделяв"],
    "удерж": ["сдерживание"],
    "удержав": ["удержавши"],
    "удержавши": ["удержав"],
    "удержанье": ["удержание"],
    "удержать": ["сдержать", "остановить"],
    "удерживав": ["удерживавши"],
    "удерживавши": ["удерживав"],
    "удерживать": ["сдерживать", "сохранять", "сберегать", "придерживать", "вычитать", "подавлять"],
    "удесятерив": ["удесятеривши"],
    "удесятеривши": ["удесятерив"],
    "удесятеряв": ["удесятерявши"],
    "удесятерявши": ["удесятеряв"],
    "удешевив": ["удешевивши"],
    "удешевивши": ["удешевив"],
    "удешевляв": ["удешевлявши"],
    "удешевлявши": ["удешевляв"],
    "удзьмухнуць": ["удзьмуць"],
    "удзьмуць": ["удзьмухнуць"],
    "удив": ["удивши"],
    "удивив": ["удививши"],
    "удививши": ["удивив"],
    "удивительно": ["необычайно", "поразительно", "страшно"],
    "удивиться": ["диву даться"],
    "удивление": ["изумление", "удивленье"],
    "удивленье": ["удивление"],
    "удивляв": ["удивлявши"],
    "удивлявши": ["удивляв"],
    "удивлённость": ["озадаченность", "недоумённость", "ошеломлённость", "поражённость"],
    "удивши": ["удив"],
    "удила": ["мундштук", "бразды", "кнут"],
    "удильщик": ["рыболов"],
    "удинский язык": ["язык удинов", "удинский"],
    "удирав": ["удиравши"],
    "удиравши": ["удирав"],
    "удить": ["рыбачить"],
    "удлиненье": ["удлинение"],
    "удлинив": ["удлинивши"],
    "удлинивши": ["удлинив"],
    "удлинитель": ["электрический удлинитель", "электроудлинитель", "переноска", "крыса", "тройник", "сетевой фильтр", "сетевик", "пилот"],
    "удлиняв": ["удлинявши"],
    "удлинявши": ["удлиняв"],
    "удмурт": ["вотяк"],
    "удмуртия": ["удмуртская республика"],
    "удмуртская республика": ["удмуртия"],
    "удмуртский": ["удмуртский язык"],
    "удмуртский язык": ["удмуртский"],
    "удобнее": ["удобней"],
    "удобней": ["удобнее"],
    "удобно": ["комфортно", "уютно", "с удобством", "ладно", "сподручно", "прилично"],
    "удобный": ["благоприятный", "комфортный", "своевременный", "подходящий"],
    "удобренье": ["удобрение"],
    "удобрив": ["удобривши"],
    "удобривав": ["удобривавши"],
    "удобривавши": ["удобривав"],
    "удобривши": ["удобрив"],
    "удобряв": ["удобрявши"],
    "удобрявши": ["удобряв"],
    "удобрять": ["удабривать"],
    "удобства": ["блага цивилизации", "уборная", "сортир", "клозет", "нужник"],
    "удобство": ["удобность", "комфортность", "комфорт", "уют"],
    "удова": ["удовиця"],
    "удовлетворение": ["удовлетворенье"],
    "удовлетворенье": ["удовлетворение"],
    "удовлетворив": ["удовлетворивши"],
    "удовлетворивши": ["удовлетворив"],
    "удовлетворительно": ["приемлемо", "тройка"],
    "удовлетворяв": ["удовлетворявши"],
    "удовлетворявши": ["удовлетворяв"],
    "удовлетворяющий": ["удовлетворительный"],
    "удовлить": ["удовлетворить"],
    "удовлять": ["удовлетворять"],
    "удоволив": ["удоволивши"],
    "удоволивши": ["удоволив"],
    "удовольствие": ["удовлетворение", "приятность", "развлечение"],
    "удовольствовав": ["удовольствовавши"],
    "удовольствовавши": ["удовольствовав"],
    "удовольствовать": ["удовлетворить", "насытить", "утолить"],
    "удод": ["пустушка", "потатуйка", "балбес", "балда", "болван", "глупец", "дебил", "дурачина", "дурень", "идиот", "обалдуй", "олух", "остолоп", "простофиля", "тупица"],
    "удомс": ["ётафтомс ве", "удомс ве"],
    "удорожав": ["удорожавши"],
    "удорожавши": ["удорожав"],
    "удорожив": ["удороживши"],
    "удороживши": ["удорожив"],
    "удостаивав": ["удостаивавши"],
    "удостаивавши": ["удостаивав"],
    "удостоверение": ["подтверждение", "проверка"],
    "удостоверенье": ["удостоверение"],
    "удостоверив": ["удостоверивши"],
    "удостоверивши": ["удостоверив"],
    "удостоверить": ["убедить"],
    "удостоверяв": ["удостоверявши"],
    "удостоверявши": ["удостоверяв"],
    "удостоверять": ["подтверждать", "свидетельствовать"],
    "удостоив": ["удостоивши"],
    "удостоивав": ["удостоивавши"],
    "удостоивавши": ["удостоивав"],
    "удостоивши": ["удостоив"],
    "удостоить": ["наградить", "почтить"],
    "удочерив": ["удочеривши"],
    "удочеривши": ["удочерив"],
    "удочеряв": ["удочерявши"],
    "удочерявши": ["удочеряв"],
    "удочка": ["уда"],
    "удрав": ["удравши"],
    "удравши": ["удрав"],
    "удрать": ["убежать", "сбежать", "улепетнуть"],
    "удревнив": ["удревнивши"],
    "удревнивши": ["удревнив"],
    "удревняв": ["удревнявши"],
    "удревнявши": ["удревняв"],
    "удрочиться": ["задрочиться"],
    "удружав": ["удружавши"],
    "удружавши": ["удружав"],
    "удружив": ["удруживши"],
    "удруживши": ["удружив"],
    "удручав": ["удручавши"],
    "удручавши": ["удручав"],
    "удручать": ["отягощать", "обременять", "быть в тягость", "подавлять", "угнетать", "тяготить"],
    "удручающе": ["тягостно", "гнетуще", "угнетающе"],
    "удручающий": ["удручительный"],
    "удручение": ["уныние"],
    "удрученье": ["удручение"],
    "удручив": ["удручивши"],
    "удручивши": ["удручив"],
    "удручительный": ["удручающий"],
    "удручить": ["обременить", "отяготить", "огорчить"],
    "удручённый": ["расстроенный", "подавленный", "угнетённый"],
    "удув": ["удувши"],
    "удувши": ["удув"],
    "удумав": ["удумавши"],
    "удумавши": ["удумав"],
    "удумывав": ["удумывавши"],
    "удумывавши": ["удумывав"],
    "удушав": ["удушавши"],
    "удушавши": ["удушав"],
    "удушение": ["удавление"],
    "удушенье": ["удушение"],
    "удушив": ["удушивши"],
    "удушивши": ["удушив"],
    "удушить": ["задушить", "придушить"],
    "удушиться": ["удавиться"],
    "удушье": ["асфиксия"],
    "удэгеец": ["удэге", "удэ"],
    "уебав": ["уебавши"],
    "уебавши": ["уебав"],
    "уебан": ["страшила", "урод", "недотыкомка"],
    "уебать": ["сломать", "доломать", "угондошить", "угандошить", "разъебать", "вымотать", "оставить без сил", "заебать", "заебти"],
    "уебти": ["вымотать", "оставить без сил", "заебать", "заебти"],
    "уев": ["уевши"],
    "уевши": ["уев"],
    "уедав": ["уедавши"],
    "уедавши": ["уедав"],
    "уединение": ["затворничество"],
    "уединенно": ["уединённо", "одиноко"],
    "уединив": ["уединивши"],
    "уединивши": ["уединив"],
    "уединообразив": ["уединообразивши"],
    "уединообразивши": ["уединообразив"],
    "уединяв": ["уединявши"],
    "уединявши": ["уединяв"],
    "уединённо": ["одиноко"],
    "уединённый": ["укромный", "тихий", "безлюдный"],
    "уездив": ["уездивши"],
    "уездивши": ["уездив"],
    "уезжав": ["уезжавши"],
    "уезжавши": ["уезжав"],
    "уезжать": ["отъезжать"],
    "уезживав": ["уезживавши"],
    "уезживавши": ["уезживав"],
    "уемс": ["тумс уема", "уемс шири", "пачкодемс уезь", "аделамс уемать"],
    "уеть": ["уязвить"],
    "уефа": ["союз европейских футбольных ассоциаций"],
    "уехав": ["уехавши"],
    "уехавши": ["уехав"],
    "уехать": ["укатить"],
    "уж": ["ужак", "ужака"],
    "ужав": ["ужавши"],
    "ужавши": ["ужав"],
    "ужалев": ["ужалевши"],
    "ужалевши": ["ужалев"],
    "ужалив": ["ужаливши"],
    "ужаливав": ["ужаливавши"],
    "ужаливавши": ["ужаливав"],
    "ужаливание": ["укус"],
    "ужаливать": ["жалить"],
    "ужаливши": ["ужалив"],
    "ужарив": ["ужаривши"],
    "ужаривав": ["ужаривавши"],
    "ужаривавши": ["ужаривав"],
    "ужаривши": ["ужарив"],
    "ужас": ["ужасть"],
    "ужасав": ["ужасавши"],
    "ужасавши": ["ужасав"],
    "ужасаться": ["пугаться"],
    "ужасающе": ["страшно"],
    "ужасающий": ["жуткий", "кошмарный", "ужасный", "отвратительный", "дрянной", "поганый", "гадкий", "неимоверный", "огромный"],
    "ужасия": ["ужас", "страх", "паника", "уплаха", "страхотия", "страшилище"],
    "ужасно": ["отвратительно", "кошмарно", "очень", "жутко", "крайне", "чрезмерно"],
    "ужаснув": ["ужаснувши"],
    "ужаснувши": ["ужаснув"],
    "ужасный": ["кошмарный", "страшный", "жуткий", "отвратительный", "мерзкий", "омерзительный", "безобразный"],
    "ужастик": ["ужас", "ужасник", "страшилка"],
    "ужасть": ["ужас"],
    "ужели": ["ужли", "неужели"],
    "ужель": ["ужели", "неужели", "разве", "неужто"],
    "ужение": ["ловля", "уженье"],
    "уженье": ["ужение", "ловля"],
    "ужесточав": ["ужесточавши"],
    "ужесточавши": ["ужесточав"],
    "ужесточать": ["усиливать"],
    "ужесточение": ["ужесточенье"],
    "ужесточенье": ["ужесточение"],
    "ужесточив": ["ужесточивши"],
    "ужесточивши": ["ужесточив"],
    "ужесточить": ["усилить"],
    "уживав": ["уживавши"],
    "уживавши": ["уживав"],
    "уживаться": ["приживаться", "ладить", "сосуществовать"],
    "ужилив": ["ужиливши"],
    "ужиливав": ["ужиливавши"],
    "ужиливавши": ["ужиливав"],
    "ужиливши": ["ужилив"],
    "ужимать": ["сжимать", "сужать", "сокращать", "убавлять"],
    "ужимка": ["гримаса"],
    "ужин": ["вечеря", "званый ужин"],
    "ужинав": ["ужинавши"],
    "ужинавши": ["ужинав"],
    "ужиный": ["ужовый"],
    "ужли": ["ужели", "неужели"],
    "ужо": ["потом", "позже"],
    "ужовый": ["ужиный"],
    "ужратый": ["бухой"],
    "ужраться": ["упиться", "набраться"],
    "узаконив": ["легализовав", "узаконивши"],
    "узаконивав": ["узаконивавши"],
    "узаконивавши": ["узаконивав"],
    "узаконивание": ["легитимизация", "узаконение"],
    "узаконивать": ["узаконять"],
    "узаконивая": ["легализуя"],
    "узаконивши": ["легализовав", "узаконив"],
    "узаконять": ["узаконивать"],
    "узаконяя": ["легализуя"],
    "узбекистан": ["республика узбекистан"],
    "узбекская сср": ["узбекистан"],
    "узбекско-российский": ["российско-узбекский"],
    "узвар": ["взвар", "отвар"],
    "уздечка": ["уздцы", "узда"],
    "узел": ["развязка", "центр", "миля в час", "нод", "нода"],
    "узел расчёта": ["расчётный узел"],
    "узел сети": ["хост"],
    "узелок": ["узел", "котомка"],
    "узенько": ["узочко"],
    "узи": ["ультразвуковое исследование"],
    "узив": ["узивши"],
    "узивши": ["узив"],
    "узилище": ["застенок", "темница", "каземат"],
    "узкий": ["тесный", "тонкий", "небольшой", "неширокий"],
    "узкоглазие": ["узкоглазость"],
    "узкоглазость": ["узкоглазие"],
    "узкоглазый": ["узкоплёночный"],
    "узкое место": ["недостаток", "слабый", "звено"],
    "узкокостный": ["астенический"],
    "узколистный": ["узколистый"],
    "узколобие": ["узколобость"],
    "узколобость": ["узколобие", "узость", "недалёкость", "недостаточность", "однобокость", "глупость"],
    "узколобый": ["недалёкий", "ограниченный"],
    "узкомордый": ["узколицый"],
    "узкоплановый": ["однобокий", "узкопрофильный", "специфический", "специфичный", "узконаправленный", "секторальный", "нишевый", "фокусированный", "монотематический", "узкотематический", "узкоспециальный", "узкоспециализированный", "специализированный", "ограниченный", "узколобый"],
    "узкоплечий": ["щуплый"],
    "узкоплёночный": ["узкоглазый"],
    "узкопрофессиональный": ["узкопрофильный"],
    "узкотазый": ["узкобёдрый"],
    "узкотелый": ["лептосомный"],
    "узластый": ["узловатый"],
    "узлистость": ["узловатость"],
    "узловатый": ["неровный", "бугристый"],
    "узнавав": ["узнававши"],
    "узнававши": ["узнавав"],
    "узнаваемость": ["знакомость", "известность", "различимость"],
    "узнаваемый": ["знакомый", "известный"],
    "узнавание": ["распознавание", "опознавание", "познание"],
    "узнаванье": ["узнавание"],
    "узнавать": ["дознавать", "разузнавать", "выспрашивать", "выпытывать", "отгадывать", "разгадывать", "угадывать", "идентифицировать", "признавать", "опознавать", "распознавать", "знакомиться", "познавать"],
    "узнавши": ["узнав", "узнамши"],
    "узнать": ["идентифицировать", "опознать", "признать", "распознать", "усвоить", "выяснить"],
    "узник": ["заключённый", "пленник", "невольник"],
    "узор": ["сплетение"],
    "узорив": ["узоривши"],
    "узоривши": ["узорив"],
    "узористый": ["узорный"],
    "узорный": ["узорочный", "узорчатый"],
    "узорчатый": ["узорный", "узорочный", "фигурный", "орнаментальный"],
    "узость": ["узкость"],
    "узрев": ["узревши"],
    "узревав": ["узревавши"],
    "узревавши": ["узревав"],
    "узревать": ["усматривать"],
    "узревши": ["узрев"],
    "узреть": ["увидеть"],
    "узрив": ["узривши"],
    "узривши": ["узрив"],
    "узуальность": ["общеупотребительность", "общепринятость", "обыденность"],
    "узура": ["взятка", "лихва", "лихоимство"],
    "узурпатор": ["захватчик"],
    "узурпация": ["захват"],
    "узурпировав": ["узурпировавши"],
    "узурпировавши": ["узурпировав"],
    "узурпировать": ["захватить", "присвоить"],
    "узус": ["обычай", "обыкновение"],
    "узути": ["взути"],
    "узы": ["юза"],
    "узюка": ["кукузяка", "бяка"],
    "уик-энд": ["выходные"],
    "уикэнд": ["уик-энд", "уикенд"],
    "уилкинс": ["вилкинс", "вилкинз"],
    "уилсон": ["вильсон"],
    "уилтшир": ["вильтшир", "вильтс"],
    "уильям": ["вильям", "вильгельм", "гийом"],
    "уильямс": ["вильямс"],
    "уистити": ["мармозетка", "обыкновенная игрунка"],
    "уитлендер": ["ойтландер"],
    "уй": ["вуй"],
    "уйти": ["удалиться", "уволиться", "погрузиться", "отстраниться", "испустить дух"],
    "ука": ["додар"],
    "укав": ["укавши"],
    "укавши": ["укав"],
    "указ": ["повеление", "распоряжение", "постановление", "закон", "декрет"],
    "указав": ["указавши"],
    "указавши": ["указав"],
    "указание": ["разъяснение", "приказ", "распоряжение"],
    "указанье": ["указание"],
    "указувати": ["вказувати"],
    "указующий": ["указывающий", "указательный"],
    "указующий перст": ["указка", "императив"],
    "указывав": ["указывавши"],
    "указывавши": ["указывав"],
    "указывать": ["показывать", "приводить", "сообщать", "распоряжаться", "давать указания", "руководить"],
    "указывающий": ["указующий"],
    "укалывав": ["укалывавши"],
    "укалывавши": ["укалывав"],
    "укапав": ["укапавши"],
    "укапавши": ["укапав"],
    "укапывав": ["укапывавши"],
    "укапывавши": ["укапывав"],
    "укараулив": ["укарауливши"],
    "укарауливав": ["укарауливавши"],
    "укарауливавши": ["укарауливав"],
    "укарауливши": ["укараулив"],
    "укат": ["укатка"],
    "укатав": ["укатавши"],
    "укатавши": ["укатав"],
    "укатив": ["укативши"],
    "укативши": ["укатив"],
    "укатнув": ["укатнувши"],
    "укатнувши": ["укатнув"],
    "укатывав": ["укатывавши"],
    "укатывавши": ["укатывав"],
    "укачав": ["укачавши"],
    "укачавши": ["укачав"],
    "укачивав": ["укачивавши"],
    "укачивавши": ["укачивав"],
    "укашивав": ["укашивавши"],
    "укашивавши": ["укашивав"],
    "уквасив": ["уквасивши"],
    "уквасивши": ["уквасив"],
    "уквашивав": ["уквашивавши"],
    "уквашивавши": ["уквашивав"],
    "укипав": ["укипавши"],
    "укипавши": ["укипав"],
    "укипев": ["укипевши"],
    "укипевши": ["укипев"],
    "укисав": ["укисавши"],
    "укисавши": ["укисав"],
    "укиснув": ["укиснувши"],
    "укиснувши": ["укиснув"],
    "уклад": ["устройство", "жизнь", "житьё", "темперамент", "дань", "булат"],
    "укладав": ["укладавши"],
    "укладавши": ["укладав"],
    "укладывав": ["укладывавши"],
    "укладывавши": ["укладывав"],
    "укладыванье": ["укладывание"],
    "укланивав": ["укланивавши"],
    "укланивавши": ["укланивав"],
    "укланяв": ["укланявши"],
    "укланявши": ["укланяв"],
    "уклеив": ["уклеивши"],
    "уклеивав": ["уклеивавши"],
    "уклеивавши": ["уклеивав"],
    "уклеивши": ["уклеив"],
    "уклейка": ["выклейка", "уклеивание", "уклеиванье"],
    "уклонение": ["отклонение", "избегание"],
    "уклоненье": ["уклонение"],
    "уклонив": ["уклонивши"],
    "уклонивши": ["уклонив"],
    "уклонист": ["дезертир"],
    "уклоняв": ["уклонявши"],
    "уклонявши": ["уклоняв"],
    "уковыливав": ["уковыливавши"],
    "уковыливавши": ["уковыливав"],
    "уковыляв": ["уковылявши"],
    "уковылявши": ["уковыляв"],
    "уковыривав": ["уковыривавши"],
    "уковыривавши": ["уковыривав"],
    "уковырнув": ["уковырнувши"],
    "уковырнувши": ["уковырнув"],
    "укокав": ["укокавши"],
    "укокавши": ["укокав"],
    "укокать": ["укокошить", "убить"],
    "укокошив": ["укокошивши"],
    "укокошивав": ["укокошивавши"],
    "укокошивавши": ["укокошивав"],
    "укокошивши": ["укокошив"],
    "уколачивав": ["уколачивавши"],
    "уколачивавши": ["уколачивав"],
    "уколов": ["уколовши"],
    "уколовши": ["уколов"],
    "уколотив": ["уколотивши"],
    "уколотивши": ["уколотив"],
    "уколоться": ["напороться", "упороться"],
    "уколошматив": ["уколошмативши"],
    "уколошмативши": ["уколошматив"],
    "уколупнув": ["уколупнувши"],
    "уколупнувши": ["уколупнув"],
    "уколупывав": ["уколупывавши"],
    "уколупывавши": ["уколупывав"],
    "укомплектовав": ["укомплектовавши"],
    "укомплектовавши": ["укомплектовав"],
    "укомплектование": ["комплектование"],
    "укомплектовывав": ["укомплектовывавши"],
    "укомплектовывавши": ["укомплектовывав"],
    "укомплектовывать": ["комплектовать"],
    "уконопатив": ["уконопативши"],
    "уконопативши": ["уконопатив"],
    "уконопачивав": ["уконопачивавши"],
    "уконопачивавши": ["уконопачивав"],
    "уконтентовав": ["уконтентовавши"],
    "уконтентовавши": ["уконтентовав"],
    "уконтентовать": ["удоволить"],
    "уконтрапупив": ["уконтрапупивши"],
    "уконтрапупивши": ["уконтрапупив"],
    "уконтрапупить": ["упупить", "уничтожить"],
    "укопав": ["укопавши"],
    "укопавши": ["укопав"],
    "укор": ["упрёк", "порицание", "осуждение", "укоризна"],
    "укорачивав": ["укорачивавши"],
    "укорачивавши": ["укорачивав"],
    "укорачиваться": ["сокращаться"],
    "укоренив": ["укоренивши"],
    "укоренивши": ["укоренив"],
    "укорениться": ["вкорениться"],
    "укореняв": ["укоренявши"],
    "укоренявши": ["укореняв"],
    "укоренённость": ["встроенность"],
    "укорив": ["укоривши"],
    "укоривши": ["укорив"],
    "укоризна": ["укор", "упрёк", "попрёк", "обвинение", "нарекание", "зазирание", "покор", "обличение", "порицание", "хула"],
    "укоризненно": ["неодобрительно", "осуждающе", "укорительно"],
    "укоризненный": ["укорительный", "укоряющий", "порицающий", "неодобрительный"],
    "укорительно": ["укоризненно", "неодобрительно", "осуждающе"],
    "укорительный": ["укоризненный"],
    "укорот": ["укрощение", "ксюха"],
    "укоротив": ["укоротивши"],
    "укоротивши": ["укоротив"],
    "укоряв": ["укорявши"],
    "укорявши": ["укоряв"],
    "укорять": ["упрекать", "корить", "попенять", "журить"],
    "укоряющий": ["укоризненный"],
    "укосив": ["укосивши"],
    "укосивши": ["укосив"],
    "укосина": ["подкос", "раскос"],
    "укоснив": ["укоснивши"],
    "укоснивши": ["укоснив"],
    "укосняв": ["укоснявши"],
    "укоснявши": ["укосняв"],
    "укочевав": ["укочевавши"],
    "укочевавши": ["укочевав"],
    "укочёвывав": ["укочёвывавши"],
    "укочёвывавши": ["укочёвывав"],
    "укр": ["укроп", "евроукр", "свидомый"],
    "украдкой": ["незаметно", "скрытно", "тайком", "тайно", "втихомолку"],
    "украина": ["окраина"],
    "украинец": ["малоросс", "малорос", "малорусс", "малороссиянин", "хохол", "укр"],
    "украинизировав": ["украинизировавши"],
    "украинизировавши": ["украинизировав"],
    "украинистика": ["украиноведение"],
    "украинка": ["малороссиянка", "малоросска", "малоруска", "хохлушка", "оксанка"],
    "украино-американский": ["американо-украинский"],
    "украино-израильский": ["украинско-израильский"],
    "украино-натовский": ["украинско-натовский"],
    "украино-российский": ["российско-украинский", "украинско-российский"],
    "украинофобия": ["украинофобство", "украиноненавистничество"],
    "украинофобство": ["украинофобия"],
    "украинская держава": ["украинское государство", "второй гетманат"],
    "украинская народная республика": ["унр"],
    "украинская сср": ["украина", "усср"],
    "украинский": ["малороссийский", "хохлацкий", "хохляцкий"],
    "украинский язык": ["украинский", "мова"],
    "украинско-израильский": ["украино-израильский"],
    "украинско-натовский": ["украино-натовский"],
    "украинско-российский": ["российско-украинский", "украино-российский"],
    "украйна": ["украина"],
    "украсив": ["украсивши"],
    "украсивши": ["украсив"],
    "украсить": ["декорировать", "расцветить", "облагородить"],
    "украсти": ["збондрити", "свиснути", "шопнути"],
    "украшав": ["украшавши"],
    "украшавши": ["украшав"],
    "украшать": ["прихорашивать", "наряжать"],
    "украшение": ["приукрашивание", "украс", "украса", "прикраса", "гордость"],
    "украшенье": ["украшение", "украс", "украса", "прикраса", "гордость"],
    "укрепивши": ["укрепив"],
    "укрепить": ["упрочить", "закрепить", "усилить"],
    "укрепление": ["усиление", "упрочение", "фортификация"],
    "укрепленье": ["укрепление"],
    "укрепляв": ["укреплявши"],
    "укреплявши": ["укрепляв"],
    "укреплять": ["крепить", "упрочивать", "закреплять", "усиливать"],
    "укреплённый район": ["укрепрайон", "ур", "укреп"],
    "укрепрайон": ["укреплённый район", "укреп"],
    "укро-": ["хохло-", "сало-", "свино-"],
    "укровермахт": ["хохловермахт", "саловермахт"],
    "укролюфтваффе": ["хохлолюфтваффе", "салолюфтваффе"],
    "укромный": ["скрытый", "потаённый", "незаметный"],
    "укронацист": ["укрофашист", "бандеровец"],
    "укронацистка": ["укрофашистка"],
    "укропатриот": ["хохлопатриот", "салопатриот", "свинопатриот"],
    "укропропаганда": ["хохлопропаганда"],
    "укропчик": ["укроп"],
    "укротив": ["укротивши"],
    "укротивши": ["укротив"],
    "укротитель": ["дрессировщик"],
    "укротить": ["обуздать", "усмирить"],
    "укроукреп": ["хохлоукреп", "свиноукреп"],
    "укрофашист": ["укронацист", "бандеровец"],
    "укрофашистка": ["укронацистка"],
    "укрофюрер": ["хохлофюрер", "салофюрер"],
    "укрощав": ["укрощавши"],
    "укрощавши": ["укрощав"],
    "укрощать": ["усмирять", "подчинять", "приручать", "подавлять", "сдерживать"],
    "укрощение": ["усмирение", "покорение", "утихомиривание", "укорот"],
    "укрощенье": ["укрощение"],
    "укроюгенд": ["хохлоюгенд"],
    "укрупнение": ["укрупненье", "увеличение"],
    "укрупнив": ["укрупнивши"],
    "укрупнивши": ["укрупнив"],
    "укрупняв": ["укрупнявши"],
    "укрупнявши": ["укрупняв"],
    "укрутив": ["укрутивши"],
    "укрутивши": ["укрутив"],
    "укрух": ["отрезок", "краюха"],
    "укручивав": ["укручивавши"],
    "укручивавши": ["укручивав"],
    "укрыв": ["укрывши"],
    "укрывав": ["укрывавши"],
    "укрывавши": ["укрывав"],
    "укрывши": ["укрыв"],
    "укрытие": ["укрывание", "покрывание", "сокрытие", "убежище", "защита"],
    "укрыть": ["раскрыть"],
    "укрытье": ["укрытие"],
    "укрыться": ["спрятаться", "сокрыться", "скрыться"],
    "укрючив": ["укрючивши"],
    "укрючивши": ["укрючив"],
    "уксусная кислота": ["этановая кислота"],
    "уксусник": ["уксусница"],
    "уксусница": ["уксусник"],
    "уксуснокислый": ["ацетатный"],
    "уку": ["кку"],
    "укулеле": ["уке", "гавайская гитара"],
    "укупив": ["укупивши"],
    "укупивши": ["укупив"],
    "укупорив": ["укупоривши"],
    "укупоривав": ["укупоривавши"],
    "укупоривавши": ["укупоривав"],
    "укупоривание": ["укупорка", "закупоривание", "закупорка"],
    "укупоривши": ["укупорив"],
    "укупорить": ["закупорить"],
    "укупориться": ["закупориться"],
    "укурок": ["укуренный", "идиот"],
    "укусив": ["укусивши"],
    "укусивши": ["укусив"],
    "укусывав": ["укусывавши"],
    "укусывавши": ["укусывав"],
    "укусывать": ["кусать", "жалить"],
    "укутав": ["укутавши"],
    "укутавши": ["укутав"],
    "укутывав": ["укутывавши"],
    "укутывавши": ["укутывав"],
    "улавливав": ["улавливавши"],
    "улавливавши": ["улавливав"],
    "улавливатель": ["уловитель"],
    "уладарыць": ["панаваць"],
    "уладив": ["уладивши"],
    "уладивши": ["уладив"],
    "уладить": ["урегулировать", "разрешить", "наладить"],
    "улаженный": ["устроенный"],
    "улаживав": ["улаживавши"],
    "улаживавши": ["улаживав"],
    "уламывав": ["уламывавши"],
    "уламывавши": ["уламывав"],
    "уламывать": ["уговаривать", "убеждать", "склонять"],
    "улан-удинский": ["улан-удэнский"],
    "улан-удэнский": ["улан-удинский"],
    "уланудинец": ["уланудэнец"],
    "уланудэнец": ["уланудинец"],
    "улар": ["горная индейка"],
    "уластив": ["уластивши"],
    "уластивши": ["уластив"],
    "улахан": ["куттас"],
    "улащивав": ["улащивавши"],
    "улащивавши": ["улащивав"],
    "уле": ["оле"],
    "улегчась": ["облегчившись"],
    "улежав": ["улежавши"],
    "улежавши": ["улежав"],
    "улезав": ["улезавши"],
    "улезавши": ["улезав"],
    "улей": ["человейник"],
    "улелеяв": ["улелеявши"],
    "улелеявши": ["улелеяв"],
    "улемс": ["ащемс", "эрямс", "лисемс", "тиемс", "эвондамс", "няевомс"],
    "улемс мяль": ["таколдомс", "ёрамс"],
    "уленшпигель": ["ойленшпигель", "эйленшпигель"],
    "улепетнув": ["улепетнувши"],
    "улепетнувши": ["улепетнув"],
    "улепетнуть": ["удрать"],
    "улепив": ["улепивши"],
    "улепивши": ["улепив"],
    "улепливав": ["улепливавши"],
    "улепливавши": ["улепливав"],
    "улепляв": ["улеплявши"],
    "улеплявши": ["улепляв"],
    "улепётывав": ["улепётывавши"],
    "улепётывавши": ["улепётывав"],
    "улепётывание": ["бегство"],
    "улестив": ["улестивши"],
    "улестивши": ["улестив"],
    "улестить": ["прельстить"],
    "улетав": ["улетавши"],
    "улетавши": ["улетав"],
    "улетев": ["улетевши"],
    "улетевши": ["улетев"],
    "улетучив": ["улетучивши"],
    "улетучивав": ["улетучивавши"],
    "улетучивавши": ["улетучивав"],
    "улетучивши": ["улетучив"],
    "улетучиться": ["испариться"],
    "улещав": ["улещавши"],
    "улещавши": ["улещав"],
    "улещать": ["улещивать"],
    "улещив": ["улещивши"],
    "улещивав": ["улещивавши"],
    "улещивавши": ["улещивав"],
    "улещивать": ["улещать"],
    "улещиваться": ["улещаться"],
    "улещивши": ["улещив"],
    "улив": ["уливши"],
    "уливав": ["уливавши"],
    "уливавши": ["уливав"],
    "уливши": ["улив"],
    "улизав": ["улизавши"],
    "улизавши": ["улизав"],
    "улизнув": ["улизнувши"],
    "улизнувши": ["улизнув"],
    "улизывав": ["улизывавши"],
    "улизывавши": ["улизывав"],
    "улита": ["улитка"],
    "улитковый": ["улиточный"],
    "улиточный": ["улитковый"],
    "улить": ["залить"],
    "улица": ["линия", "двор"],
    "улицезрев": ["улицезревши"],
    "улицезревши": ["улицезрев"],
    "улицезреть": ["увидеть", "узреть"],
    "уличав": ["уличавши"],
    "уличавши": ["уличав"],
    "уличать": ["изобличать"],
    "уличив": ["уличивши"],
    "уличивши": ["уличив"],
    "уличить": ["изобличить"],
    "улмо": ["яблок", "алма", "багалма", "быгыльма"],
    "улов": ["вылов"],
    "уловив": ["уловивши"],
    "уловивши": ["уловив"],
    "уловить": ["уличить", "изобличить"],
    "уловка": ["ухищрение", "хитрость"],
    "уловляв": ["уловлявши"],
    "уловлявши": ["уловляв"],
    "уловлять": ["улавливать"],
    "улово": ["суводь"],
    "уложение": ["устав", "положение", "закон", "обычай", "традиции", "правило", "правила", "обыкновение", "укладывание", "укладка", "размещение", "устилание"],
    "уложенье": ["уложение"],
    "уложив": ["уложивши"],
    "уложивши": ["уложив"],
    "уложить": ["поместить", "уместить", "успеть", "устлать", "выложить", "расположить", "сложить", "свалить", "завалить", "сбить с ног"],
    "уложить в голове": ["запомнить", "понять", "постигнуть"],
    "уложить в гроб": ["доконать"],
    "уломав": ["уломавши"],
    "уломавши": ["уломав"],
    "уломать": ["уговорить", "убедить", "склонить"],
    "уломив": ["уломивши"],
    "уломивши": ["уломив"],
    "улук": ["водосток", "водосточна", "тръба"],
    "улун": ["оолонг"],
    "улут": ["эл"],
    "улучав": ["улучавши"],
    "улучавши": ["улучав"],
    "улучення": ["влучення"],
    "улучив": ["улучивши"],
    "улучивши": ["улучив"],
    "улучить": ["выбрать", "найти", "выкроить"],
    "улучшав": ["улучшавши"],
    "улучшавши": ["улучшав"],
    "улучшение": ["совершенствование", "оптимизация"],
    "улучшенье": ["улучшение"],
    "улучшив": ["улучшивши"],
    "улучшивши": ["улучшив"],
    "улучшить": ["усовершенствовать"],
    "улыбаться": ["канать"],
    "улыбка": ["лыба"],
    "улыбнув": ["улыбнувши"],
    "улыбнувши": ["улыбнув"],
    "улыбнуть": ["развеселить", "порадовать", "обмануть", "надуть"],
    "улыбнуться": ["показаться", "представиться", "достаться", "пропасть", "понравиться", "привлечь"],
    "улыбчивый": ["усмешливый", "смешливый"],
    "ульнув": ["ульнувши"],
    "ульнувши": ["ульнув"],
    "ульнуть": ["улизнуть"],
    "ультимативно": ["в приказном порядке"],
    "ультимативность": ["категоричность", "безапелляционность"],
    "ультра-": ["гипер-", "супер-", "сверх-"],
    "ультраабиссаль": ["хадаль"],
    "ультрабогач": ["сверхбогач", "супербогач", "раскапиталист"],
    "ультравысокотемпературнообработанный": ["ультрапастеризованный"],
    "ультрадешёвый": ["сверхдешёвый", "недорогой", "доступный"],
    "ультрадорогой": ["предорогой", "сверхдорогой", "супердорогой"],
    "ультразвуковое исследование": ["узи", "эхография"],
    "ультрамарин": ["лазурит"],
    "ультрамикроскопический": ["субмикроскопический"],
    "ультрарадикал": ["ультрарадикалист", "корень бринга"],
    "ультрарадикалист": ["ультрарадикал"],
    "ультрастильный": ["суперстильный"],
    "ультраустойчивый": ["ультрастабильный"],
    "ультрафеминистический": ["радикально-феминистический"],
    "ультрафиолетовый": ["высокоэнергетический"],
    "ультрацентрифуга": ["сверхцентрифуга", "суперцентрифуга"],
    "ульцерозный": ["язвенный"],
    "ульяна": ["уля"],
    "ульянка": ["ульяна"],
    "ульяновск": ["симбирск", "синбирск", "родина ильича"],
    "ульяновская область": ["ульяновщина"],
    "улюлюкав": ["улюлюкавши"],
    "улюлюкавши": ["улюлюкав"],
    "улюлюкание": ["улюлюканье"],
    "улюлюканье": ["улюлюкание"],
    "улюлюкивав": ["улюлюкивавши"],
    "улюлюкивавши": ["улюлюкивав"],
    "улюнгур": ["булунг-тохой"],
    "улягнув": ["улягнувши"],
    "улягнувши": ["улягнув"],
    "улягти": ["влягти"],
    "уляпав": ["уляпавши"],
    "уляпавши": ["уляпав"],
    "улёт": ["кайф", "отлёт"],
    "ум": ["интеллект", "разум", "рассудительность", "смысл", "соображение", "сообразительность", "рассудок", "смекалка", "гениальность", "интеллектуал", "мыслитель", "гений"],
    "ума не приложу": ["ума не дам"],
    "умазав": ["умазавши"],
    "умазавши": ["умазав"],
    "умазывав": ["умазывавши"],
    "умазывавши": ["умазывав"],
    "умаивав": ["умаивавши"],
    "умаивавши": ["умаивав"],
    "умакнув": ["умакнувши"],
    "умакнувши": ["умакнув"],
    "умаление": ["уменьшение", "сокращение", "принижение", "преуменьшение"],
    "умаленье": ["умаление"],
    "умалив": ["умаливши"],
    "умаливав": ["умаливавши"],
    "умаливавши": ["умаливав"],
    "умаливать": ["умолять"],
    "умаливши": ["умалив"],
    "умалить": ["уменьшить", "сократить", "преуменьшить", "занизить"],
    "умалишённый": ["помешанный", "сумасшедший", "безумный", "псих"],
    "умалчивав": ["умалчивавши"],
    "умалчивавши": ["умалчивав"],
    "умалчивать": ["недоговаривать", "замалчивать", "утаивать"],
    "умаляв": ["умалявши"],
    "умалявши": ["умаляв"],
    "умалять": ["уменьшать", "принижать", "преуменьшать"],
    "уманив": ["уманивши"],
    "уманивав": ["уманивавши"],
    "уманивавши": ["уманивав"],
    "уманивши": ["уманив"],
    "умаслив": ["умасливши"],
    "умасливав": ["умасливавши"],
    "умасливавши": ["умасливав"],
    "умасливши": ["умаслив"],
    "умастив": ["умастивши"],
    "умастивши": ["умастив"],
    "уматерев": ["уматеревши"],
    "уматеревши": ["уматерев"],
    "уматный": ["смешной", "забавный", "прикольный", "клёвый", "улётный"],
    "уматывав": ["уматывавши"],
    "уматывавши": ["уматывав"],
    "умахав": ["умахавши"],
    "умахавши": ["умахав"],
    "умахивав": ["умахивавши"],
    "умахивавши": ["умахивав"],
    "умачивав": ["умачивавши"],
    "умачивавши": ["умачивав"],
    "умащав": ["умащавши"],
    "умащавши": ["умащав"],
    "умащивав": ["умащивавши"],
    "умащивавши": ["умащивав"],
    "умащивать": ["умащать", "устилать"],
    "умаяв": ["умаявши"],
    "умаявши": ["умаяв"],
    "умбиликус": ["умбиликальный"],
    "умбровый": ["умбристый", "тёмно-коричневый", "тенистый", "зонтичный"],
    "умбрский": ["умбрийский"],
    "умев": ["умевши"],
    "умевши": ["умев"],
    "умедлив": ["умедливши"],
    "умедливши": ["умедлив"],
    "умедляв": ["умедлявши"],
    "умедлявши": ["умедляв"],
    "умелица": ["виртуозка", "мастачка", "профессионалка"],
    "умело": ["искусно", "ловко"],
    "умелый": ["искусный", "ловкий"],
    "умельчав": ["умельчавши"],
    "умельчавши": ["умельчав"],
    "умельчив": ["умельчивши"],
    "умельчивши": ["умельчив"],
    "умение": ["уменье", "знание дела", "навык", "сноровка"],
    "уменье": ["умение"],
    "уменьшав": ["уменьшавши"],
    "уменьшавши": ["уменьшав"],
    "уменьшать": ["сокращать", "убавлять", "умаливать"],
    "уменьшаться": ["сокращаться"],
    "уменьшение": ["сокращение", "спад", "убыль", "понижение", "уменьшенье"],
    "уменьшенье": ["уменьшение"],
    "уменьшив": ["уменьшивши"],
    "уменьшивши": ["уменьшив"],
    "уменьшитель": ["снижатель"],
    "уменьшительно-ласкательный": ["уменьшительный", "ласкательный", "гипокористический"],
    "уменьшительный": ["уменьшающий", "диминутивный"],
    "уменьшиться": ["сократиться", "опуститься"],
    "умерев": ["умерши"],
    "умереть": ["исчезнуть", "прекратиться", "сдохнуть"],
    "умереть голодной смертью": ["помереть с голодной смерти"],
    "умереть не своей смертью": ["свести счёты с жизнью", "наложить на себя руки", "покончить с собой", "придать себе смерть"],
    "умерив": ["умеривши"],
    "умеривав": ["умеривавши"],
    "умеривавши": ["умеривав"],
    "умеривать": ["умерять"],
    "умеривши": ["умерив"],
    "умертвив": ["умертвивши"],
    "умертвивши": ["умертвив"],
    "умертвие": ["убийство", "смерть", "живой мертвец"],
    "умертвляв": ["умертвлявши"],
    "умертвлявши": ["умертвляв"],
    "умертвлять": ["убивать", "умерщвлять", "останавливать", "прекращать", "обуздывать", "подчинять", "смирять", "укрощать", "усмирять", "выхолащивать", "разрушать", "уничтожать"],
    "умертвляться": ["умерщвляться"],
    "умерши": ["умерев"],
    "умерший": ["померший", "скончавшийся", "покойный", "усопший", "бездыханный", "почивший", "опочивший", "покойник", "мертвец"],
    "умерщвление": ["убийство", "убиение", "лишение жизни"],
    "умерщвленье": ["умерщвление"],
    "умерщвляв": ["умерщвлявши"],
    "умерщвлявши": ["умерщвляв"],
    "умерщвлять": ["умертвлять", "обуздывать", "подчинять", "смирять", "укрощать", "усмирять", "разрушать", "выхолащивать", "уничтожать"],
    "умерщвлённый": ["убитый", "деградированный"],
    "умеряв": ["умерявши"],
    "умерявши": ["умеряв"],
    "умесив": ["умесивши"],
    "умесивши": ["умесив"],
    "умесить": ["умешать"],
    "уместив": ["уместивши"],
    "уместивши": ["уместив"],
    "уместиться": ["вместиться", "уложиться", "поместиться", "разместиться", "расположиться", "устроиться"],
    "уметав": ["уметавши"],
    "уметавши": ["уметав"],
    "уметь": ["мочь"],
    "умешав": ["умешавши"],
    "умешавши": ["умешав"],
    "умешать": ["умесить"],
    "умешивав": ["умешивавши"],
    "умешивавши": ["умешивав"],
    "умещав": ["умещавши"],
    "умещавши": ["умещав"],
    "умиление": ["умиленье", "растроганность"],
    "умиленье": ["умиление"],
    "умилив": ["умиливши"],
    "умиливши": ["умилив"],
    "умилительный": ["трогательный", "милый"],
    "умилить": ["растрогать"],
    "умилиться": ["растрогаться"],
    "умилосердив": ["умилосердивши"],
    "умилосердивши": ["умилосердив"],
    "умилостивив": ["умилостививши"],
    "умилостививши": ["умилостивив"],
    "умилостивление": ["умилостивленье"],
    "умилостивляв": ["умилостивлявши"],
    "умилостивлявши": ["умилостивляв"],
    "умиляв": ["умилявши"],
    "умилявши": ["умиляв"],
    "умилять": ["растрогать", "трогать"],
    "уминав": ["уминавши"],
    "уминавши": ["уминав"],
    "уминать": ["приминать", "притаптывать", "утаптывать", "утрамбовывать", "наворачивать", "уплетать", "уплетать за обе щеки", "уплетать за обе щёки", "уписывать", "уписывать за обе щеки", "уписывать за обе щёки", "лопать", "пожирать", "рубать"],
    "умирав": ["умиравши"],
    "умиравши": ["умирав"],
    "умиравший": ["помиравший"],
    "умирание": ["агония", "издыхание", "исчезновение", "прекращение", "угасание"],
    "умиранье": ["умирание"],
    "умирать": ["помирать", "подыхать", "издыхать", "преставляться", "испускать дух", "переходить в мир иной", "отходить", "кончаться", "давать дуба"],
    "умирающий": ["агонизирующий", "помирающий", "отходящий", "издыхающий", "исчезающий"],
    "умирив": ["умиривши"],
    "умиривши": ["умирив"],
    "умиротворение": ["умиротворенье", "утихомиривание", "умиротворённость"],
    "умиротворенье": ["умиротворение"],
    "умиротворив": ["умиротворивши"],
    "умиротворивши": ["умиротворив"],
    "умиротворяв": ["умиротворявши"],
    "умиротворявши": ["умиротворяв"],
    "умиротворённо": ["мирно", "спокойно"],
    "умиротворённый": ["безмятежный", "мирный"],
    "умиряв": ["умирявши"],
    "умирявши": ["умиряв"],
    "умирять": ["мирить"],
    "умисъл": ["намерение", "предумисъл", "умишленост"],
    "умить": ["вмить", "миттю"],
    "умифеновир": ["арбидол"],
    "умка": ["белый медведь"],
    "умлаут": ["умляут"],
    "умляут": ["перегласовка"],
    "уммакъ": ["умют этмек"],
    "уммат": ["мардум"],
    "умная маша": ["простак"],
    "умнев": ["умневши"],
    "умневши": ["умнев"],
    "умней": ["умнее", "поумней", "поумнее"],
    "умнейший": ["преумный", "мудрейший"],
    "умник": ["умница", "всезнайка", "умный крендель"],
    "умница": ["голова", "молодец", "молоток"],
    "умничав": ["умничавши"],
    "умничавши": ["умничав"],
    "умничанье": ["мудрствование", "умничание"],
    "умничать": ["умствовать", "мудрствовать", "мудрить"],
    "умное голосование": ["тактическое голосование", "вынужденное голосование"],
    "умножав": ["умножавши"],
    "умножавши": ["умножав"],
    "умножать": ["множить", "увеличивать"],
    "умножаться": ["множиться"],
    "умножение": ["увеличение", "пополнение", "добавление", "прирост", "приумножение", "прибавление", "рост", "перемножение"],
    "умноженье": ["умножение"],
    "умножив": ["умноживши"],
    "умноживши": ["умножив"],
    "умножить": ["увеличить", "размножить"],
    "умный": ["разумный", "мудрый", "интеллектуальный"],
    "умный дом": ["асуз"],
    "умнёхонький": ["умнёшенький", "умнющий"],
    "умнёхонько": ["умнёшенько"],
    "умнёшенький": ["умнёхонький"],
    "умнёшенько": ["умнёхонько"],
    "умозаключав": ["умозаключавши"],
    "умозаключавши": ["умозаключав"],
    "умозаключение": ["вывод"],
    "умозаключенье": ["умозаключение"],
    "умозаключив": ["умозаключивши"],
    "умозаключивши": ["умозаключив"],
    "умозрев": ["умозревши"],
    "умозревши": ["умозрев"],
    "умозрительно": ["созерцательно", "теоретически", "гипотетически"],
    "умозрительность": ["абстрактность", "отвлечённость", "теоретичность"],
    "умозрительный": ["мысленный", "умозренческий", "теоретический", "абстрактный", "отвлечённый", "виртуальный"],
    "умоисступление": ["умопомешательство", "умопомрачение"],
    "умокав": ["умокавши"],
    "умокавши": ["умокав"],
    "умокнув": ["умокнувши"],
    "умокнувши": ["умокнув"],
    "умолачивав": ["умолачивавши"],
    "умолачивавши": ["умолачивав"],
    "умолвив": ["умолвивши"],
    "умолвивши": ["умолвив"],
    "умолив": ["умоливши"],
    "умоливши": ["умолив"],
    "умолкав": ["умолкавши"],
    "умолкавши": ["умолкав"],
    "умолкать": ["замолкать", "смолкать"],
    "умолкнув": ["умолкнувши"],
    "умолкнувши": ["умолкнув"],
    "умолотив": ["умолотивши"],
    "умолотивши": ["умолотив"],
    "умолчав": ["умолчавши"],
    "умолчавши": ["умолчав"],
    "умолчание": ["замалчивание"],
    "умолчанье": ["умолчание"],
    "умоляв": ["умолявши"],
    "умолявши": ["умоляв"],
    "умолять": ["молить"],
    "умоначертание": ["умонастроение"],
    "умопомешательство": ["психическое расстройство", "сумасшествие"],
    "умопомрачение": ["умопомешательство", "помешательство", "помрачение ума"],
    "умопомраченье": ["умопомрачение"],
    "умопомрачительный": ["потрясающий", "головокружительный", "сногсшибательный", "обалденный", "поразительный"],
    "умопостроение": ["умствование"],
    "умора": ["потеха", "смехота"],
    "уморив": ["уморивши"],
    "уморивши": ["уморив"],
    "уморительный": ["потешный"],
    "умориться": ["измучиться"],
    "уморщив": ["уморщивши"],
    "уморщивши": ["уморщив"],
    "умостив": ["умостивши"],
    "умостивши": ["умостив"],
    "умотав": ["умотавши"],
    "умотавши": ["умотав"],
    "умочив": ["умочивши"],
    "умочивши": ["умочив"],
    "умра": ["малый хадж"],
    "умственная отсталость": ["олигофрения", "задержка психического развития"],
    "умственно": ["ментально"],
    "умственный": ["мыслительный", "интеллектуальный"],
    "умствовав": ["умствовавши"],
    "умствовавши": ["умствовав"],
    "умствование": ["размышление"],
    "умствованье": ["умствование"],
    "умствовать": ["размышлять", "рассуждать", "философствовать", "мудрствовать", "мудрить"],
    "уму непостижимо": ["с ума сойти", "невероятно", "немыслимо", "невообразимо"],
    "умудрив": ["умудривши"],
    "умудривши": ["умудрив"],
    "умудряв": ["умудрявши"],
    "умудрявши": ["умудряв"],
    "умудрённость": ["многоопытность"],
    "умучав": ["умучавши"],
    "умучавши": ["умучав"],
    "умучив": ["умучивши"],
    "умучивав": ["умучивавши"],
    "умучивавши": ["умучивав"],
    "умучивши": ["умучив"],
    "умчав": ["умчавши"],
    "умчавши": ["умчав"],
    "умыв": ["умывши"],
    "умывав": ["умывавши"],
    "умывавши": ["умывав"],
    "умывальник": ["раковина"],
    "умывание": ["умыванье", "мытьё"],
    "умыванье": ["умывание"],
    "умывать": ["мыть"],
    "умывши": ["умыв"],
    "умыкав": ["умыкавши"],
    "умыкавши": ["умыкав"],
    "умыкание": ["умычка"],
    "умыкивав": ["умыкивавши"],
    "умыкивавши": ["умыкивав"],
    "умыкнув": ["умыкнувши"],
    "умыкнувши": ["умыкнув"],
    "умыкнуть": ["похитить", "выкрасть"],
    "умысел": ["замысел", "задумка", "план", "проект", "прожект"],
    "умыслив": ["умысливши"],
    "умысливши": ["умыслив"],
    "умыть": ["обуть", "развести"],
    "умычка": ["умыкание"],
    "умышление": ["помысл", "замышление", "задумывание"],
    "умышленно": ["намеренно", "преднамеренно", "специально", "нарочно", "с умыслом"],
    "умышляв": ["умышлявши"],
    "умышлявши": ["умышляв"],
    "умяв": ["умявши"],
    "умявши": ["умяв"],
    "умягчав": ["умягчавши"],
    "умягчавши": ["умягчав"],
    "умягчать": ["смягчать"],
    "умягчение": ["смягчение"],
    "умягчив": ["умягчивши"],
    "умягчивши": ["умягчив"],
    "умягчить": ["смягчить"],
    "умякав": ["умякавши"],
    "умякавши": ["умякав"],
    "умякнув": ["умякнувши"],
    "умякнувши": ["умякнув"],
    "умять": ["упихнуть", "утрамбовать", "уплести"],
    "умётывав": ["умётывавши"],
    "умётывавши": ["умётывав"],
    "унаваживав": ["унаваживавши"],
    "унаваживавши": ["унаваживав"],
    "унаваживаться": ["унавоживаться"],
    "унавоживав": ["унавоживавши"],
    "унавоживавши": ["унавоживав"],
    "унавозив": ["унавозивши"],
    "унавозивши": ["унавозив"],
    "унарный": ["унитарный", "одинарный"],
    "унаследовав": ["унаследовавши"],
    "унаследовавши": ["унаследовав"],
    "унбан": ["анбан", "разбан", "разблокирование"],
    "унбинилий": ["эка-радий"],
    "унгаристика": ["хунгаристика"],
    "унгвентарий": ["бальзамарий", "флакон"],
    "унгтутыдеми": ["сэвэнчэдеми"],
    "ундина": ["русалка", "никса", "обольстительница", "соблазнительница"],
    "унести": ["нести"],
    "униат": ["грекокатолик", "унионист"],
    "униатский": ["греко-католический"],
    "универ": ["университет"],
    "универбация": ["универбизация", "универбализация"],
    "универмаг": ["гипермаркет", "торговый центр"],
    "универсал": ["энциклопедист", "эрудит", "ерундит", "глобалог", "уник"],
    "универсализировав": ["универсализировавши"],
    "универсализировавши": ["универсализировав"],
    "универсализм": ["универсальность"],
    "универсальность": ["универсализм"],
    "универсальный": ["всеобъемлющий", "всеохватывающий", "всеобщий", "разносторонний", "многогранный"],
    "универсальный магазин": ["универмаг"],
    "универсам": ["супермаркет"],
    "универсант": ["университант", "студент"],
    "университет": ["универ"],
    "унижав": ["унижавши"],
    "унижавши": ["унижав"],
    "унижать": ["оскорблять"],
    "унизав": ["унизавши"],
    "унизавши": ["унизав"],
    "унизив": ["унизивши"],
    "унизивши": ["унизив"],
    "унизить": ["оскорбить"],
    "унизывав": ["унизывавши"],
    "унизывавши": ["унизывав"],
    "уник": ["уникум"],
    "уникальность": ["единственность", "неповторимость"],
    "уникальный": ["неповторимый", "единичный", "единственный", "исключительный", "особый"],
    "уникум": ["редкость", "раритет", "диковина", "уник", "гений", "талант", "талантище"],
    "унимав": ["унимавши"],
    "унимавши": ["унимав"],
    "унимодальность": ["выпуклость", "одновершинность"],
    "унимодальный": ["одновершинный"],
    "унионист": ["юнионист"],
    "униполярность": ["однополюсность"],
    "униполярный": ["однополюсный"],
    "униполярный транзистор": ["полевой транзистор", "алькатрон"],
    "унирема": ["монера"],
    "унисон": ["созвучие", "согласие"],
    "унитаз": ["сортир", "сральник", "белый друг", "белый телефон", "горшок", "очко", "толчок"],
    "унитазенька": ["унитазик"],
    "унитаризм": ["централизм"],
    "унитарное предприятие": ["уп"],
    "унитарность": ["унитаризм"],
    "унификация": ["унифицирование"],
    "унифицировав": ["унифицировавши"],
    "унифицировавши": ["унифицировав"],
    "унифицирование": ["унификация"],
    "униформизм": ["актуализм"],
    "униформизовав": ["униформизовавши"],
    "униформизовавши": ["униформизовав"],
    "уничижав": ["уничижавши"],
    "уничижавши": ["уничижав"],
    "уничижение": ["унижение"],
    "уничиженье": ["уничижение"],
    "уничижив": ["уничиживши"],
    "уничиживши": ["уничижив"],
    "уничижительный": ["пренебрежительный", "презрительный", "умаляющий", "пейоративный"],
    "уничтожав": ["уничтожавши"],
    "уничтожавши": ["уничтожав"],
    "уничтожать": ["ликвидировать"],
    "уничтожаться": ["разрушаться", "гибнуть"],
    "уничтожение": ["искоренение"],
    "уничтожив": ["уничтоживши"],
    "уничтоживши": ["уничтожив"],
    "уничтожить": ["ликвидировать"],
    "уничтожиться": ["ликвидироваться", "исчезнуть", "пропасть"],
    "уния": ["союз", "объединение", "альянс", "федерация", "конфедерация", "протекторат", "слияние"],
    "ункоартроз": ["унковертебральный артроз", "артроз люшка"],
    "унковертебральный артроз": ["ункоартроз", "артроз люшка"],
    "унлу": ["унлы"],
    "уннобранг": ["сурх", "уннобгун"],
    "уносив": ["уносивши"],
    "уносивши": ["уносив"],
    "уносить": ["уволакивать"],
    "уносить ноги": ["отступать"],
    "унр": ["украинская народная республика", "управление начальника работ"],
    "унт": ["унтайка"],
    "унтер-офицер": ["унтер", "ундер-офицер"],
    "унтер-офицерствовав": ["унтер-офицерствовавши"],
    "унтер-офицерствовавши": ["унтер-офицерствовав"],
    "унтерменш": ["урод", "выродок", "ублюдок"],
    "унунбий": ["коперниций", "эка-ртуть"],
    "унунгексий": ["ливерморий", "эка-полоний"],
    "унунквадий": ["флеровий", "эка-свинец"],
    "унуноктий": ["оганесон", "эка-радон"],
    "унунпентий": ["московий", "эка-висмут"],
    "унунсептий": ["теннессин", "эка-астат"],
    "унунтрий": ["нихоний", "эка-таллий"],
    "унунуний": ["рентгений", "эка-золото"],
    "унциальный": ["минускульный"],
    "уныв": ["унывши"],
    "унывать": ["хандрить"],
    "унывши": ["уныв"],
    "уныло": ["понуро", "тоскливо"],
    "унылый": ["грустный", "понурый", "тоскливый", "подавленный"],
    "уныние": ["тоска", "печаль", "грусть", "унынье"],
    "унынье": ["уныние", "тоска", "печаль", "грусть"],
    "уныривав": ["уныривавши"],
    "уныривавши": ["уныривав"],
    "унырнув": ["унырнувши"],
    "унырнувши": ["унырнув"],
    "унюхав": ["унюхавши"],
    "унюхавши": ["унюхав"],
    "уняв": ["унявши"],
    "унявши": ["уняв"],
    "уняться": ["успокоиться", "угомониться", "прекратиться"],
    "уоднообразив": ["уоднообразивши"],
    "уоднообразивши": ["уоднообразив"],
    "уоднообразить": ["однообразить", "унифицировать"],
    "уорс": ["уорт"],
    "уп": ["унитарное предприятие"],
    "упав": ["упавши"],
    "упаги": ["выпуки"],
    "упадав": ["упадавши"],
    "упадавши": ["упадав"],
    "упадать": ["падать", "угорать", "опадать", "спадать"],
    "упадничество": ["упадочничество"],
    "упадок": ["ослабление", "расстройство", "спад"],
    "упадочничество": ["упадничество"],
    "упаивав": ["упаивавши"],
    "упаивавши": ["упаивав"],
    "упаивать": ["упоевать"],
    "упакав": ["упакавши"],
    "упакавши": ["упакав"],
    "упакать": ["попасть"],
    "упаковав": ["упаковавши"],
    "упаковавши": ["упаковав"],
    "упакованный": ["запакованный"],
    "упаковщица": ["запаковщица"],
    "упаковывав": ["упаковывавши"],
    "упаковывавши": ["упаковывав"],
    "упаковывать": ["паковать", "запаковывать"],
    "упалзывав": ["упалзывавши"],
    "упалзывавши": ["упалзывав"],
    "упарив": ["упаривши"],
    "упаривав": ["упаривавши"],
    "упаривавши": ["упаривав"],
    "упаривши": ["упарив"],
    "упариться": ["вспотеть", "взопреть"],
    "упархивав": ["упархивавши"],
    "упархивавши": ["упархивав"],
    "упархивать": ["улетать"],
    "упасть в обморок": ["потерять сознание"],
    "упаяв": ["упаявши"],
    "упаявши": ["упаяв"],
    "упекав": ["упекавши"],
    "упекавши": ["упекав"],
    "упеленав": ["упеленавши"],
    "упеленавши": ["упеленав"],
    "упеленать": ["запеленать"],
    "упелёнывав": ["упелёнывавши"],
    "упелёнывавши": ["упелёнывав"],
    "уперев": ["упёрши"],
    "упередив": ["упередивши"],
    "упередивши": ["упередив"],
    "упережав": ["упережавши"],
    "упережавши": ["упережав"],
    "упереться": ["опереться", "заупрямиться", "заартачиться"],
    "упестрив": ["упестривши"],
    "упестривши": ["упестрив"],
    "упестряв": ["упестрявши"],
    "упестрявши": ["упестряв"],
    "упечатав": ["упечатавши"],
    "упечатавши": ["упечатав"],
    "упечатывав": ["упечатывавши"],
    "упечатывавши": ["упечатывав"],
    "упив": ["упивши"],
    "упивав": ["упивавши"],
    "упивавши": ["упивав"],
    "упивши": ["упив"],
    "упиздив": ["упиздивши"],
    "упиздивши": ["упиздив"],
    "упиздить": ["съебаться", "спиздить", "скоммуниздить", "отхуярить", "отпиздить"],
    "упизднув": ["упизднувши"],
    "упизднувши": ["упизднув"],
    "упиздовав": ["упиздовавши"],
    "упиздовавши": ["упиздовав"],
    "упилив": ["упиливши"],
    "упиливав": ["упиливавши"],
    "упиливавши": ["упиливав"],
    "упиливши": ["упилив"],
    "упирав": ["упиравши"],
    "упиравши": ["упирав"],
    "упирать": ["утыкать", "устремлять", "вперять", "вперивать"],
    "упираться": ["опираться", "наталкиваться", "упорствовать", "упрямиться", "артачиться", "ерепениться", "ломаться", "уматывать", "уходить"],
    "уписав": ["уписавши"],
    "уписавши": ["уписав"],
    "уписывав": ["уписывавши"],
    "уписывавши": ["уписывав"],
    "упитав": ["упитавши"],
    "упитавши": ["упитав"],
    "упитывав": ["упитывавши"],
    "упитывавши": ["упитывав"],
    "упитывать": ["откармливать", "кормить", "напитывать", "насыщать", "пропитывать"],
    "упихав": ["упихавши"],
    "упихавши": ["упихав"],
    "упихивав": ["упихивавши"],
    "упихивавши": ["упихивав"],
    "упихивать": ["впихивать", "запихивать", "втискивать"],
    "упихнув": ["упихнувши"],
    "упихнувши": ["упихнув"],
    "упихнуть": ["упихать"],
    "упичкав": ["упичкавши"],
    "упичкавши": ["упичкав"],
    "упластав": ["упластавши"],
    "упластавши": ["упластав"],
    "упластывав": ["упластывавши"],
    "упластывавши": ["упластывав"],
    "уплата": ["оплата"],
    "уплатив": ["уплативши"],
    "уплативши": ["уплатив"],
    "уплатить": ["заплатить", "оплатить"],
    "уплатный": ["выплатной"],
    "уплаха": ["страх", "боязън", "малодушие", "нерешителност"],
    "уплачивав": ["уплачивавши"],
    "уплачивавши": ["уплачивав"],
    "уплетав": ["уплетавши"],
    "уплетавши": ["уплетав"],
    "уплетать": ["лопать", "поглощать", "уписывать"],
    "уплотнив": ["уплотнивши"],
    "уплотнивши": ["уплотнив"],
    "уплотнительная застройка": ["точечная застройка"],
    "уплотняв": ["уплотнявши"],
    "уплотнявши": ["уплотняв"],
    "уплощав": ["уплощавши"],
    "уплощавши": ["уплощав"],
    "уплощив": ["уплощивши"],
    "уплощивши": ["уплощив"],
    "уплыв": ["уплывши"],
    "уплывав": ["уплывавши"],
    "уплывавши": ["уплывав"],
    "уплывши": ["уплыв"],
    "уплыть": ["отплыть"],
    "уплюснув": ["уплюснувши"],
    "уплюснувши": ["уплюснув"],
    "уплющив": ["уплющивши"],
    "уплющивши": ["уплющив"],
    "уповав": ["уповавши"],
    "уповавши": ["уповав"],
    "упование": ["надежда", "вера", "символ веры"],
    "упованье": ["упование"],
    "уповати": ["розраховувати"],
    "уповать": ["надеяться", "вверяться", "полагаться", "рассчитывать"],
    "уподобив": ["уподобивши"],
    "уподобивши": ["уподобив"],
    "уподобительный": ["экватив"],
    "уподобление": ["уподобленье", "ассимиляция"],
    "уподобленье": ["уподобление"],
    "уподобляв": ["уподоблявши"],
    "уподоблявши": ["уподобляв"],
    "уподробить": ["растолковать"],
    "упоевав": ["упоевавши"],
    "упоевавши": ["упоевав"],
    "упоение": ["восторг", "восхищение", "наслаждение", "вдохновение", "очарование", "экстаз", "энтузиазм", "самозабвение", "исступление", "безумство"],
    "упоенье": ["упоение", "восторг", "восхищение", "экстаз"],
    "упоив": ["упоивши"],
    "упоивши": ["упоив"],
    "упоительный": ["восхитительный"],
    "упокат": ["покатам"],
    "упокоевав": ["упокоевавши"],
    "упокоевавши": ["упокоевав"],
    "упокоенье": ["упокоение"],
    "упокоив": ["упокоивши"],
    "упокоивши": ["упокоив"],
    "упокоиться": ["успокоиться", "почить"],
    "упокойник": ["покойник", "мертвец", "умерший", "покойный", "усопший", "почивший", "мёртвый", "опочивший"],
    "упокойница": ["покойница", "покойная", "почившая", "умершая", "усопшая", "мёртвая"],
    "уползав": ["уползавши"],
    "уползавши": ["уползав"],
    "уползти": ["отползти"],
    "уполномачивав": ["уполномачивавши"],
    "уполномачивавши": ["уполномачивав"],
    "уполномочив": ["уполномочивши"],
    "уполномочивав": ["уполномочивавши"],
    "уполномочивавши": ["уполномочивав"],
    "уполномочивать": ["санкционировать"],
    "уполномочивши": ["уполномочив"],
    "уполномочить": ["препоручить", "санкционировать", "аккредитовать", "аккредитировать"],
    "уполовинив": ["уполовинивши"],
    "уполовинивав": ["уполовинивавши"],
    "уполовинивавши": ["уполовинивав"],
    "уполовинивши": ["уполовинив"],
    "уполовник": ["половник"],
    "упоминав": ["упоминавши"],
    "упоминавши": ["упоминав"],
    "упоминание": ["упоминанье"],
    "упоминанье": ["упоминание"],
    "упоминаться": ["называться"],
    "упоминовение": ["упоминание"],
    "упомнив": ["упомнивши"],
    "упомнивши": ["упомнив"],
    "упомнить": ["запомнить"],
    "упомянув": ["упомянувши"],
    "упомянувши": ["упомянув"],
    "упомянуть": ["вспомнить", "затронуть", "помянуть"],
    "упоперак": ["папярок"],
    "упорно": ["настойчиво", "упрямо"],
    "упорность": ["упорство", "настойчивость", "безустанность"],
    "упорный": ["настойчивый"],
    "упоров": ["упоровши"],
    "упоровши": ["упоров"],
    "упоротый": ["повёрнутый", "поехавший", "упёртый", "обдолбанный", "под кайфом", "пырнутый"],
    "упороть": ["удрать", "убежать", "улепетнуть", "учесать", "смыться", "спороть", "одурманить", "сожрать", "слопать", "выжрать"],
    "упороться": ["уколоться", "одурманиться", "пырнуться", "зарезаться", "вскрыться", "упороть", "убежать", "удрать", "запороться", "объесться", "обожраться", "налопаться", "нахомячиться"],
    "упорство": ["настойчивость"],
    "упорствовав": ["упорствовавши"],
    "упорствовавши": ["упорствовав"],
    "упорствование": ["упорство"],
    "упорствовать": ["настаивать", "сопротивляться", "отказываться"],
    "упорхнув": ["упорхнувши"],
    "упорхнувши": ["упорхнув"],
    "упорядочение": ["упорядочивание"],
    "упорядоченность": ["порядок", "система"],
    "упорядоченье": ["упорядочение"],
    "упорядочив": ["упорядочивши"],
    "упорядочивав": ["упорядочивавши"],
    "упорядочивавши": ["упорядочивав"],
    "упорядочивание": ["упорядочение"],
    "упорядочивать": ["приводить в порядок", "наводить порядок"],
    "упорядочиваться": ["налаживаться"],
    "упорядочивши": ["упорядочив"],
    "употай": ["тайком"],
    "употев": ["употевши"],
    "употевши": ["употев"],
    "употребив": ["употребивши"],
    "употребивши": ["употребив"],
    "употребительный": ["общепринятый", "распространённый"],
    "употребленье": ["употребление"],
    "употребляв": ["употреблявши"],
    "употреблявши": ["употребляв"],
    "употреблять": ["задействовать", "пускать в ход", "прибегать", "эксплуатировать", "утилизировать", "принимать", "проглатывать", "использовать", "применять"],
    "употреблённый": ["использованный"],
    "употчевав": ["употчевавши"],
    "употчевавши": ["употчевав"],
    "упояв": ["упоявши"],
    "упоявши": ["упояв"],
    "управдом": ["домоуправитель", "домоуправ"],
    "управив": ["управивши"],
    "управивши": ["управив"],
    "управия": ["управа"],
    "управленец": ["управляющий", "руководитель"],
    "управление": ["руководство", "регулирование", "администрирование", "правление"],
    "управление рисками": ["риск-менеджмент"],
    "управляв": ["управлявши"],
    "управлявши": ["управляв"],
    "управляемый": ["руководимый"],
    "управлять": ["руководить", "верховодить", "править"],
    "управляшка": ["управляйка"],
    "управляющая компания": ["управкомпания", "управляющая организация"],
    "управляющий": ["директор", "начальник", "руководитель"],
    "упражнение": ["тренировка", "тренинг", "урок"],
    "упражненье": ["упражнение"],
    "упражняв": ["упражнявши"],
    "упражнявши": ["упражняв"],
    "упразднение": ["отмена", "ликвидация", "расформирование", "вывод из обращения", "аннулирование", "денонсирование"],
    "упразднив": ["упразднивши"],
    "упразднивши": ["упразднив"],
    "упразднительный": ["упраздняющий"],
    "упраздняв": ["упразднявши"],
    "упразднявши": ["упраздняв"],
    "упразднять": ["отменять", "запрещать", "опорожнять", "опустошать"],
    "упрашивав": ["упрашивавши"],
    "упрашивавши": ["упрашивав"],
    "упрашиванье": ["упрашивание"],
    "упрашивать": ["просить", "уговаривать"],
    "упрев": ["упревши"],
    "упревав": ["упревавши"],
    "упревавши": ["упревав"],
    "упревши": ["упрев"],
    "упредив": ["упредивши"],
    "упредивши": ["упредив"],
    "упредительный": ["предупредительный", "обходительный", "превентивный"],
    "упредить": ["предупредить"],
    "упреждав": ["упреждавши"],
    "упреждавши": ["упреждав"],
    "упрежденье": ["упреждение"],
    "упрекав": ["упрекавши"],
    "упрекавши": ["упрекав"],
    "упрекать": ["укорять", "критиковать", "обвинять", "попрекать", "корить", "порицать", "журить"],
    "упрекнув": ["упрекнувши"],
    "упрекнувши": ["упрекнув"],
    "упрекнуть": ["укорить"],
    "упрелый": ["уварившийся", "упревший", "взмокнувший", "взмокший", "взопревший", "вспотевший", "разогревшийся", "распарившийся"],
    "упроваджування": ["упровадження"],
    "упросив": ["упросивши"],
    "упросивши": ["упросив"],
    "упростив": ["упростивши"],
    "упростивши": ["упростив"],
    "упростить": ["облегчить"],
    "упрочение": ["закрепление", "укрепление", "утверждение", "усиление"],
    "упрочив": ["упрочивши"],
    "упрочивав": ["упрочивавши"],
    "упрочивавши": ["упрочивав"],
    "упрочивать": ["укреплять", "закреплять"],
    "упрочивши": ["упрочив"],
    "упрочить": ["укрепить", "упрочнить", "закрепить"],
    "упрочнив": ["упрочнивши"],
    "упрочнивши": ["упрочнив"],
    "упрочняв": ["упрочнявши"],
    "упрочнявши": ["упрочняв"],
    "упрочнять": ["упрочивать", "укреплять"],
    "упрощав": ["упрощавши"],
    "упрощавши": ["упрощав"],
    "упрощать": ["симплифицировать"],
    "упрощение": ["симплификация"],
    "упрощенье": ["упрощение"],
    "упрощёнка": ["усн"],
    "упрощённая система налогообложения": ["усн"],
    "упругий": ["эластичный"],
    "упругость": ["эластичность"],
    "упружив": ["упруживши"],
    "упруживши": ["упружив"],
    "упрыгав": ["упрыгавши"],
    "упрыгавши": ["упрыгав"],
    "упрыгивав": ["упрыгивавши"],
    "упрыгивавши": ["упрыгивав"],
    "упрыгнув": ["упрыгнувши"],
    "упрыгнувши": ["упрыгнув"],
    "упрягав": ["упрягавши"],
    "упрягавши": ["упрягав"],
    "упряжка": ["впряг", "запрягание", "упряжь", "запряжка"],
    "упряжь": ["сбруя", "сцепка", "винтовая  сцепка", "винтовая упряжь", "винтовая стяжка", "винтовая муфта"],
    "упрямо": ["упорно"],
    "упрямство": ["упёртость", "неуступчивость", "несговорчивость"],
    "упрямствовав": ["упрямствовавши"],
    "упрямствовавши": ["упрямствовав"],
    "упрямый": ["несговорчивый", "неуступчивый", "непокорный", "неподдающийся"],
    "упрятав": ["упрятавши"],
    "упрятавши": ["упрятав"],
    "упрятывав": ["упрятывавши"],
    "упрятывавши": ["упрятывав"],
    "упрёк": ["укор", "укоризна", "обвинение"],
    "упс": ["ибп", "бесперебойник"],
    "упупив": ["упупивши"],
    "упупивши": ["упупив"],
    "упускав": ["упускавши"],
    "упускавши": ["упускав"],
    "упустив": ["упустивши"],
    "упустивши": ["упустив"],
    "упутав": ["упутавши"],
    "упутавши": ["упутав"],
    "упутывав": ["упутывавши"],
    "упутывавши": ["упутывав"],
    "упущенье": ["упущение"],
    "упчк": ["упячка"],
    "упырь": ["вампир", "вурдалак", "кровосос", "изверг", "изувер", "садист", "людоед", "каннибал", "кровопийца"],
    "упыхаться": ["запыхаться"],
    "упятерив": ["упятеривши"],
    "упятеривши": ["упятерив"],
    "упятеряв": ["упятерявши"],
    "упятерявши": ["упятеряв"],
    "упячка": ["упчк"],
    "упёртый": ["прижатый", "притиснутый", "украденный", "сворованный", "свиснутый", "слямзенный", "спёртый", "стыренный", "стянутый"],
    "упёрши": ["уперев"],
    "ура": ["виват"],
    "ура-патриот": ["турбопатриот", "квасной патриот"],
    "ура-патриотизм": ["шовинизм", "джингоизм", "квасной патриотизм"],
    "уработав": ["уработавши"],
    "уработавши": ["уработав"],
    "уработать": ["работнуть"],
    "уравнение": ["уравнивание", "приравнивание"],
    "уравненье": ["уравнение"],
    "уравнивав": ["уравнивавши"],
    "уравнивавши": ["уравнивав"],
    "уравниловка": ["уравнивание", "нивелирование"],
    "уравнитель": ["уравниватель", "левеллер"],
    "уравновесив": ["уравновесивши"],
    "уравновесивши": ["уравновесив"],
    "уравновешенный": ["сбалансированный"],
    "уравновешивав": ["уравновешивавши"],
    "уравновешивавши": ["уравновешивав"],
    "уравняв": ["уравнявши"],
    "уравнявши": ["уравняв"],
    "уравняться": ["сравняться"],
    "ураган": ["тропический циклон", "торнадо", "шторм"],
    "ураганив": ["ураганивши"],
    "ураганивши": ["ураганив"],
    "ураганить": ["дебоширить"],
    "ураганный": ["мощный", "сокрушительный", "яростный"],
    "ураз": ["удар", "уражение", "травма", "рана", "ушиб", "увечье", "сражение", "битва", "сшибка", "поражение", "разгром"],
    "уразай": ["зайка"],
    "уразнообразив": ["уразнообразивши"],
    "уразнообразивши": ["уразнообразив"],
    "уразумев": ["уразумевши"],
    "уразумевав": ["уразумевавши"],
    "уразумевавши": ["уразумевав"],
    "уразумевши": ["уразумев"],
    "уразуметь": ["понять", "постигнуть", "сообразить"],
    "урал": ["уральские горы"],
    "уральские горы": ["урал"],
    "урамустин": ["допан"],
    "уран": ["ураний"],
    "уранинит": ["настуран"],
    "ураносодержащий": ["ураноносный"],
    "урантия": ["земля"],
    "урастав": ["ураставши"],
    "ураставши": ["урастав"],
    "уратовав": ["уратовавши"],
    "уратовавши": ["уратовав"],
    "уратовать": ["подать помощь", "спасти"],
    "уратурия": ["урикурия"],
    "урба": ["уруба"],
    "урбан": ["урван"],
    "урбанизировав": ["урбанизировавши"],
    "урбанизировавши": ["урбанизировав"],
    "урбанизовав": ["урбанизовавши"],
    "урбанизовавши": ["урбанизовав"],
    "урбанизованный": ["урбанизированный"],
    "урбанизовать": ["урбанизировать"],
    "урбаноним": ["урбоним"],
    "урбоним": ["урбаноним"],
    "урвав": ["урвавши"],
    "урвавши": ["урвав"],
    "урганч": ["ургенч"],
    "ургентность": ["срочность", "экстренность"],
    "ургентный": ["срочный", "немедленный", "неотложный", "безотлагательный"],
    "ургенч": ["урганч"],
    "уреветься": ["обреветься", "изреветься"],
    "урегулировав": ["урегулировавши"],
    "урегулировавши": ["урегулировав"],
    "урегулирование": ["урегулированье"],
    "урегулировать": ["упорядочить", "настроить", "наладить", "уладить", "утрясти"],
    "уредив": ["уредивши"],
    "уредивши": ["уредив"],
    "урежав": ["урежавши"],
    "урежавши": ["урежав"],
    "урежать": ["уреживать"],
    "уреживав": ["уреживавши"],
    "уреживавши": ["уреживав"],
    "уреживать": ["урежать"],
    "урез": ["урезка", "урезание", "урезанье", "кромка", "верёвка", "прорубь"],
    "урезав": ["урезавши"],
    "урезавши": ["урезав"],
    "урезонив": ["урезонивши"],
    "урезонивав": ["урезонивавши"],
    "урезонивавши": ["урезонивав"],
    "урезонивши": ["урезонив"],
    "урезонить": ["уговорить", "убедить", "обуздать", "успокоить", "утихомирить"],
    "урезывав": ["урезывавши"],
    "урезывавши": ["урезывав"],
    "урекав": ["урекавши"],
    "урекавши": ["урекав"],
    "урема": ["урёма"],
    "уремия": ["мочекровие"],
    "уретан": ["карбамат"],
    "уретра": ["мочеиспускательный канал"],
    "уретрография": ["урография"],
    "уречевлення": ["уречевлювання"],
    "уречевлювання": ["уречевлення"],
    "урз": ["арз"],
    "ури": ["урин"],
    "уриил": ["уриэль"],
    "урикозурия": ["уратурия"],
    "урильник": ["горшок", "ночная ваза", "ночная посуда", "урыльник", "ночной горшок", "уринник"],
    "урин": ["ури"],
    "урина": ["моча", "ссаки"],
    "урка": ["вор", "уркаган", "уркан"],
    "уркав": ["уркавши"],
    "уркавши": ["уркав"],
    "уркаган": ["урка"],
    "уркан": ["урка", "уркаган"],
    "уркнув": ["уркнувши"],
    "уркнувши": ["уркнув"],
    "урковав": ["урковавши"],
    "урковавши": ["урковав"],
    "урла": ["жульё", "хулиганьё", "шпана", "быдло"],
    "урлукъ": ["урлух"],
    "урна": ["мусорная корзина", "мусорка", "избирательный ящик", "ваза"],
    "уробилин": ["урохром"],
    "уровень": ["высота", "показатель", "звено", "слой", "ступень", "ватерпас", "ярус", "этаж"],
    "уровень жизни": ["уровень благосостояния", "уровень потребления"],
    "уровняв": ["уровнявши"],
    "уровнявши": ["уровняв"],
    "уровнять": ["выровнять"],
    "урода": ["врода", "краса"],
    "уродив": ["уродивши"],
    "уродивши": ["уродив"],
    "уродина": ["дурнушка", "уродка", "урод"],
    "уродиха": ["уродка", "уродина"],
    "уродка": ["уродина", "уродиха"],
    "уродливость": ["уродство"],
    "уродливый": ["дефективный", "безобразный", "омерзительный"],
    "уродничав": ["уродничавши"],
    "уродничавши": ["уродничав"],
    "уродовав": ["уродовавши"],
    "уродовавши": ["уродовав"],
    "уродовать": ["искажать", "обезображивать", "калечить", "увечить"],
    "уродство": ["безобразие", "уродливость", "безобразность"],
    "урождав": ["урождавши"],
    "урождавши": ["урождав"],
    "урождённый": ["настоящий", "по рождению", "с детства", "первоначальный", "добрачный", "до брака", "девичий", "в девичестве", "подлинный", "прирождённый", "коренной", "исконный", "родом"],
    "уроженец": ["выходец"],
    "урок": ["занятие", "домашнее задание", "наука", "опыт"],
    "урон": ["ущерб", "убыток"],
    "уронив": ["уронивши"],
    "уронивши": ["уронив"],
    "уронить": ["выронить", "обронить"],
    "уротропин": ["гексаметилентетрамин", "гексамин"],
    "урочив": ["урочивши"],
    "урочивши": ["урочив"],
    "урочить": ["межевать"],
    "урочище": ["межа", "граница"],
    "урсон": ["урзон", "иглошерст"],
    "урта бармак": ["озын бармак"],
    "уртак": ["гомуми"],
    "уртекст": ["авторский текст"],
    "урубав": ["урубавши"],
    "урубавши": ["урубав"],
    "урубив": ["урубивши"],
    "урубивши": ["урубив"],
    "урукхаец": ["урук-хай"],
    "уруш": ["батыс"],
    "урчав": ["урчавши"],
    "урчавши": ["урчав"],
    "урыв": ["урывши"],
    "урывав": ["урывавши"],
    "урывавши": ["урывав"],
    "урывать": ["отхватывать", "выхватывать", "захапывать"],
    "урывочный": ["непостоянный", "отрывочный", "беспорядочный", "бессвязный", "несвязный", "нерегулярный", "совершаемый", "урывками"],
    "урывши": ["урыв"],
    "урыльник": ["ночной горшок", "горшок", "ночная ваза", "ночная посуда", "урильник", "уринник", "умывальник", "рожа", "морда", "харя", "рыло", "ебало", "физия", "уголовный розыск", "угрозыск"],
    "урындык": ["утыргыч"],
    "урэшце": ["нарэшце", "у рэшце рэшт"],
    "урюк": ["курага"],
    "урядив": ["урядивши"],
    "урядивши": ["урядив"],
    "уряжав": ["уряжавши"],
    "уряжавши": ["уряжав"],
    "урёма": ["урема"],
    "ус": ["вибрисса"],
    "усадив": ["усадивши"],
    "усадивши": ["усадив"],
    "усажав": ["усажавши"],
    "усажавши": ["усажав"],
    "усаживав": ["усаживавши"],
    "усаживавши": ["усаживав"],
    "усалив": ["усаливши"],
    "усаливав": ["усаливавши"],
    "усаливавши": ["усаливав"],
    "усаливши": ["усалив"],
    "усастый": ["усатый"],
    "усатев": ["усатевши"],
    "усатевши": ["усатев"],
    "усатый": ["усатенький", "усастый"],
    "усатый кит": ["беззубый кит"],
    "усахарив": ["усахаривши"],
    "усахаривав": ["усахаривавши"],
    "усахаривавши": ["усахаривав"],
    "усахаривши": ["усахарив"],
    "усач": ["усатик", "марена", "дровосек-усач"],
    "усваивав": ["усваивавши"],
    "усваивавши": ["усваивав"],
    "усваиваемый": ["усвояемый"],
    "усватав": ["усватавши"],
    "усватавши": ["усватав"],
    "усватывав": ["усватывавши"],
    "усватывавши": ["усватывав"],
    "усвоив": ["усвоивши"],
    "усвоивав": ["усвоивавши"],
    "усвоивавши": ["усвоивав"],
    "усвоивши": ["усвоив"],
    "усвояв": ["усвоявши"],
    "усвоявши": ["усвояв"],
    "усевав": ["усевавши"],
    "усевавши": ["усевав"],
    "усеевав": ["усеевавши"],
    "усеевавши": ["усеевав"],
    "усеивав": ["усеивавши"],
    "усеивавши": ["усеивав"],
    "усеивать": ["усевать"],
    "усекав": ["усекавши"],
    "усекавши": ["усекав"],
    "усекновение": ["отсечение", "отсеченье", "урезание"],
    "усекновенье": ["усекновение", "отсечение", "отрезание", "отсеченье", "отрезанье"],
    "усекнув": ["усекнувши"],
    "усекнувши": ["усекнув"],
    "усемерив": ["усемеривши"],
    "усемеривши": ["усемерив"],
    "усемеряв": ["усемерявши"],
    "усемерявши": ["усемеряв"],
    "усердие": ["усердность", "любовь", "прилежание", "рвение", "радение", "радивость"],
    "усердничав": ["усердничавши"],
    "усердничавши": ["усердничав"],
    "усердничать": ["усердствовать"],
    "усердно": ["старательно", "прилежно", "ревностно", "рьяно", "ретиво", "истово"],
    "усердный": ["заботливый", "ревностный", "неутомимый", "старательный", "прилежный"],
    "усердствовав": ["усердствовавши"],
    "усердствовавши": ["усердствовав"],
    "усердье": ["усердие"],
    "усет": ["усещане", "възприятие", "чувство"],
    "усечение": ["отсечение", "усекновение"],
    "усечка": ["зарубка", "падрубка"],
    "усечённый": ["отсечённый", "отрезанный", "укороченный", "упрощённый"],
    "усеяв": ["усеявши"],
    "усеявши": ["усеяв"],
    "усидев": ["усидевши"],
    "усидевши": ["усидев"],
    "усидчивость": ["терпение", "прилежание"],
    "усидчивый": ["старательный", "прилежный", "упорный"],
    "усиживав": ["усиживавши"],
    "усиживавши": ["усиживав"],
    "усик": ["ус"],
    "усикав": ["усикавши"],
    "усикавши": ["усикав"],
    "усикать": ["обоссать"],
    "усики": ["усы", "вибрисса"],
    "усиление": ["усиливание"],
    "усиленно": ["усильно", "настойчиво", "упорно"],
    "усиленье": ["усиление"],
    "усилив": ["усиливши"],
    "усиливав": ["усиливавши"],
    "усиливавши": ["усиливав"],
    "усиливание": ["усиление", "усиливанье"],
    "усиливаться": ["усиляться"],
    "усиливши": ["усилив"],
    "усилитель": ["аттенюатор"],
    "усилитель звуковых частот": ["узч"],
    "усилитель мощности": ["каскад усиления"],
    "усилиться": ["посильнеть", "окрепнуть", "укрепиться"],
    "усилье": ["усилие"],
    "усильный": ["усиленный", "напряжённый", "напряжный", "интенсивный", "настойчивый", "настоятельный"],
    "усиляв": ["усилявши"],
    "усилявши": ["усиляв"],
    "усилясь": ["усилившись", "приложив", "усилие"],
    "усиляться": ["усиливаться"],
    "усиляясь": ["усиливаясь"],
    "усир": ["осирис"],
    "усираться": ["усериваться", "обсираться"],
    "усисивач": ["усисач"],
    "усище": ["ус"],
    "ускакав": ["ускакавши"],
    "ускакавши": ["ускакав"],
    "ускакивав": ["ускакивавши"],
    "ускакивавши": ["ускакивав"],
    "ускакнув": ["ускакнувши"],
    "ускакнувши": ["ускакнув"],
    "ускакнуть": ["ускакать", "ускочить"],
    "ускальзывав": ["ускальзывавши"],
    "ускальзывавши": ["ускальзывав"],
    "ускользав": ["ускользавши"],
    "ускользавши": ["ускользав"],
    "ускользанье": ["ускользание"],
    "ускользнув": ["ускользнувши"],
    "ускользнувши": ["ускользнув"],
    "ускользнуть": ["сбежать", "смотаться", "избегнуть"],
    "ускомс": ["пачфтемс", "сувафтомс", "каяфтомс", "ускомс лангста", "таргамс", "тердемс"],
    "ускоренье": ["ускорение"],
    "ускорив": ["ускоривши"],
    "ускоривши": ["ускорив"],
    "ускоритель": ["акселератор", "бустер", "акселератор частиц", "графический процессор", "графический акселератор"],
    "ускорительный": ["акселерационный", "акцелераторный"],
    "ускорить": ["убыстрить"],
    "ускоряв": ["ускорявши"],
    "ускорявши": ["ускоряв"],
    "ускорять": ["убыстрять", "приближать"],
    "ускоряться": ["убыстряться"],
    "ускочив": ["ускочивши"],
    "ускочивши": ["ускочив"],
    "ускочить": ["ускакать", "ускакнуть"],
    "услав": ["уславши"],
    "уславливаться": ["условливаться", "сговариваться"],
    "уславши": ["услав"],
    "услада": ["наслаждение", "удовольствие", "отрада", "радость"],
    "усладив": ["усладивши"],
    "усладивши": ["усладив"],
    "усладитель": ["услада"],
    "усладительный": ["усладный", "доставляющий", "услада"],
    "усладный": ["усладительный", "доставляющий", "услада"],
    "услаждав": ["услаждавши"],
    "услаждавши": ["услаждав"],
    "усластив": ["усластивши"],
    "усластивши": ["усластив"],
    "усластить": ["усладить"],
    "услащав": ["услащавши"],
    "услащавши": ["услащав"],
    "услащивав": ["услащивавши"],
    "услащивавши": ["услащивав"],
    "уследив": ["уследивши"],
    "уследивши": ["уследив"],
    "уследить": ["усмотреть", "проследить", "углядеть", "доглядеть", "устеречь", "укараулить", "уберечь"],
    "услеживав": ["услеживавши"],
    "услеживавши": ["услеживав"],
    "условие": ["соглашение", "договор", "договорённость", "пункт", "требование"],
    "условиться": ["оговорить", "договориться"],
    "условленный": ["условный", "назначенный", "обещанный", "договорённый"],
    "условное вознаграждение": ["гонорар успеха"],
    "условность": ["допущение", "относительность", "релятивность", "символичность", "условленность", "церемония"],
    "условный": ["условленный", "относительный"],
    "усложнение": ["компликация", "запутывание", "рекомпозиция"],
    "усложнив": ["усложнивши"],
    "усложнивши": ["усложнив"],
    "усложняв": ["усложнявши"],
    "усложнявши": ["усложняв"],
    "услуга": ["услужение", "услуженье", "польза", "помощь"],
    "услужив": ["услуживши"],
    "услуживав": ["услуживавши"],
    "услуживавши": ["услуживав"],
    "услуживши": ["услужив"],
    "услужливый": ["угодливый"],
    "услужник": ["слуга", "лакей", "служитель", "человек", "прислуга", "раб", "крепостной", "холоп", "услужающий", "прислужник", "угодник", "льстец"],
    "услужничав": ["услужничавши"],
    "услужничавши": ["услужничав"],
    "услыхав": ["услыхавши"],
    "услыхавши": ["услыхав"],
    "услыхать": ["услышать", "расслышать"],
    "услышав": ["услыша"],
    "услышавши": ["услышав"],
    "услышать": ["услыхать", "расслышать", "узнать", "заметить", "обратить внимание", "почуять", "почувствовать"],
    "усмарь": ["кожевник"],
    "усматривав": ["усматривавши"],
    "усматривавши": ["усматривав"],
    "усматривать": ["считать", "думать", "полагать", "находить", "рассматривать", "смотреть", "видеть"],
    "усмирев": ["усмиревши"],
    "усмиревши": ["усмирев"],
    "усмирение": ["утихомиривание"],
    "усмиренье": ["усмирение"],
    "усмирив": ["усмиривши"],
    "усмиривши": ["усмирив"],
    "усмиритель": ["укротитель"],
    "усмирительный": ["карательный", "смирительный"],
    "усмирить": ["укротить", "умиротворить", "смирить", "ослабить"],
    "усмиряв": ["усмирявши"],
    "усмирявши": ["усмиряв"],
    "усмотрев": ["усмотревши"],
    "усмотревши": ["усмотрев"],
    "усмотрение": ["усмотренье", "заключение", "мнение", "решение", "заключенье", "мненье", "решенье"],
    "усмотренье": ["усмотрение"],
    "усмотреть": ["углядеть"],
    "уснастив": ["уснастивши"],
    "уснастивши": ["уснастив"],
    "уснастить": ["оснастить", "украсить"],
    "уснащав": ["уснащавши"],
    "уснащавши": ["уснащав"],
    "уснащивав": ["уснащивавши"],
    "уснащивавши": ["уснащивав"],
    "уснув": ["уснувши"],
    "уснувши": ["уснув"],
    "уснуть": ["заснуть", "задрыхнуть", "закемарить"],
    "усобица": ["война"],
    "усовав": ["усовавши"],
    "усовавши": ["усовав"],
    "усовершенствовав": ["усовершенствовавши"],
    "усовершенствовавши": ["усовершенствовав"],
    "усовершенствованье": ["усовершенствование"],
    "усовершенствовать": ["модернизировать", "улучшать", "улучшить"],
    "усовестив": ["усовестивши"],
    "усовестивши": ["усовестив"],
    "усовестить": ["воззвать", "совесть", "пристыдить", "устыдить", "застыдить"],
    "усовещивав": ["усовещивавши"],
    "усовещивавши": ["усовещивав"],
    "усовывав": ["усовывавши"],
    "усовывавши": ["усовывав"],
    "усолив": ["усоливши"],
    "усоливши": ["усолив"],
    "усомниться": ["усумниться", "засомневаться", "поколебаться", "поставить под сомнение", "поставить под вопрос", "посомниться"],
    "усопнув": ["усопнувши"],
    "усопнувши": ["усопнув"],
    "усопнуть": ["уснуть", "заснуть", "опочить", "почить", "скончаться"],
    "усопшая": ["покойная", "упокойница", "покойница", "умершая", "почившая", "мёртвая"],
    "усопший": ["умерший", "скончавшийся", "почивший", "опочивший", "покойный", "преставившийся", "покойник", "мертвец"],
    "усосав": ["усосавши"],
    "усосавши": ["усосав"],
    "усохнув": ["усохнувши"],
    "усохнувши": ["усохнув"],
    "успев": ["успевши"],
    "успевав": ["успевавши"],
    "успевавши": ["успевав"],
    "успевать": ["поспевать"],
    "успевши": ["успев"],
    "успение": ["смерть"],
    "успех": ["удача"],
    "успешно": ["благополучно", "удачно", "с успехом"],
    "успешный": ["удачный", "благополучный", "удачливый"],
    "успокаивав": ["успокаивавши"],
    "успокаивавши": ["успокаивав"],
    "успокаивающее": ["психолептик", "седативный", "средство", "успокоительное"],
    "успокаивающий": ["успокоительный", "утешительный"],
    "успокоение": ["успокоенье"],
    "успокоенье": ["успокоение"],
    "успокоив": ["успокоивши"],
    "успокоивав": ["успокоивавши"],
    "успокоивавши": ["успокоивав"],
    "успокоивши": ["успокоив"],
    "успокоительный": ["успокаивающий"],
    "успокоиться": ["остыть", "уняться", "ослабеть", "расслабиться"],
    "усрав": ["усравши"],
    "усравши": ["усрав"],
    "усратый": ["усранный", "ничтожный"],
    "усрать": ["испачкать", "упачкать", "устряпать", "изгадить", "загадить", "угадить", "уделать", "улючкать", "упучкать", "изнахратить"],
    "усраться": ["обосраться"],
    "усреднив": ["усреднивши"],
    "усреднивши": ["усреднив"],
    "усредняв": ["усреднявши"],
    "усреднявши": ["усредняв"],
    "уссав": ["уссавши"],
    "уссавши": ["уссав"],
    "уссать": ["зассать"],
    "уссаться": ["обоссаться", "обмочиться", "описаться"],
    "усср": ["украинская сср"],
    "уссурийск": ["никольское", "никольск-уссурийский", "ворошилов"],
    "уста": ["рот", "губа"],
    "уставав": ["устававши"],
    "устававши": ["уставав"],
    "уставать": ["утомляться", "наскучивать"],
    "уставая": ["утомляясь", "наскучивая"],
    "уставив": ["уставивши"],
    "уставивши": ["уставив"],
    "уставиться": ["разместиться", "уместиться", "усеяться", "впереть"],
    "уставливав": ["уставливавши"],
    "уставливавши": ["уставливав"],
    "уставляв": ["уставлявши"],
    "уставлявши": ["уставляв"],
    "уставной": ["уставный"],
    "уставши": ["устав"],
    "уставший": ["притомившийся"],
    "устаджлу": ["устаджлы"],
    "устаивав": ["устаивавши"],
    "устаивавши": ["устаивав"],
    "устаканив": ["устаканивши"],
    "устаканивав": ["устаканивавши"],
    "устаканивавши": ["устаканивав"],
    "устаканивши": ["устаканив"],
    "устаканиться": ["установиться", "урегулироваться", "устояться"],
    "усталость": ["утомление", "утомлённость"],
    "усталый": ["утомлённый", "измученный", "разбитый"],
    "усталь": ["усталость", "утомление"],
    "устанавливав": ["устанавливавши"],
    "устанавливавши": ["устанавливав"],
    "устанавливать": ["постанавливать"],
    "установив": ["установивши"],
    "установивши": ["установив"],
    "установитель": ["создатель", "учредитель", "инициатор"],
    "установиться": ["встать", "утвердиться", "уместиться", "воцариться", "устаканиться", "наступить", "настать", "водвориться", "сформироваться", "сложиться"],
    "установка": ["установление"],
    "установленный": ["поставленный", "инсталлированный", "водружённый", "назначенный", "определённый", "положенный"],
    "установляв": ["установлявши"],
    "установлявши": ["установляв"],
    "установочный": ["инсталляционный"],
    "установщик": ["монтажник", "инсталлятор"],
    "устарев": ["устаревши"],
    "устаревав": ["устаревавши"],
    "устаревавши": ["устаревав"],
    "устаревание": ["износ", "амортизация", "старение", "моральный износ", "устареванье"],
    "устаревать": ["стареть"],
    "устаревши": ["устарев"],
    "устаревший": ["устарелый"],
    "устарелость": ["старомодность", "допотопность"],
    "устарелый": ["устаревший"],
    "устареть": ["постареть", "состариться"],
    "устелив": ["устеливши"],
    "устеливши": ["устелив"],
    "устелить": ["устлать"],
    "устерегав": ["устерегавши"],
    "устерегавши": ["устерегав"],
    "устерегти": ["встерегти"],
    "устерс": ["устрица"],
    "устигти": ["встигти"],
    "устилав": ["устилавши"],
    "устилавши": ["устилав"],
    "устинович": ["устиныч"],
    "устинья": ["устинька", "устиньюшка", "устя", "устюша", "стюша"],
    "устлав": ["устлавши"],
    "устлавши": ["устлав"],
    "устная речь": ["разговорная речь"],
    "устод": ["омузгор", "муаллим", "мударрис"],
    "устойчиво": ["неизменно"],
    "устойчивость": ["стабильность", "неколебимость", "непоколебимость", "неподвижность", "стойкость", "сопротивляемость", "продолжительность", "неизменность"],
    "устойчивый": ["стойкий", "неизменный", "постоянный", "стабильный", "неколебимый", "непоколебимый"],
    "усторожив": ["устороживши"],
    "устороживши": ["усторожив"],
    "устояв": ["устоявши"],
    "устоявши": ["устояв"],
    "устрагивав": ["устрагивавши"],
    "устрагивавши": ["устрагивав"],
    "устраивав": ["устраивавши"],
    "устраивавши": ["устраивав"],
    "устранение": ["изъятие", "исключение", "отстранение", "удаление", "уничтожение", "ликвидация"],
    "устраненье": ["устранение"],
    "устранив": ["устранивши"],
    "устранивши": ["устранив"],
    "устранить": ["удалить", "изъять", "исключить", "изжить", "ликвидировать", "отстранить"],
    "устраняв": ["устранявши"],
    "устранявши": ["устраняв"],
    "устранять": ["убирать", "удалять", "изживать", "ликвидировать", "уничтожать", "отстранять"],
    "устрашав": ["устрашавши"],
    "устрашавши": ["устрашав"],
    "устрашать": ["страшить", "пугать"],
    "устрашение": ["запугивание"],
    "устрашенье": ["устрашение"],
    "устрашив": ["устрашивши"],
    "устрашивши": ["устрашив"],
    "устремив": ["устремивши"],
    "устремивши": ["устремив"],
    "устремленье": ["устремление"],
    "устремляв": ["устремлявши"],
    "устремлявши": ["устремляв"],
    "устремлённость": ["устремление", "сосредоточенность"],
    "устрогав": ["устрогавши"],
    "устрогавши": ["устрогав"],
    "устроенье": ["устроение"],
    "устрожав": ["устрожавши"],
    "устрожавши": ["устрожав"],
    "устрожив": ["устроживши"],
    "устроживши": ["устрожив"],
    "устроив": ["устроивши"],
    "устроивши": ["устроив"],
    "устроитель": ["организатор", "устраивальщик"],
    "устроительница": ["организаторша"],
    "устроиться": ["наладиться", "уладиться", "обойтись", "утрястись", "образоваться", "расположиться", "разместиться", "обосноваться", "примоститься", "приткнуться", "зачислиться", "пристроиться"],
    "устройство сопряжения": ["ус", "адаптер", "переходник"],
    "устрояв": ["устроявши"],
    "устроявши": ["устрояв"],
    "устругав": ["устругавши"],
    "устругавши": ["устругав"],
    "устругивав": ["устругивавши"],
    "устругивавши": ["устругивав"],
    "устряпав": ["устряпавши"],
    "устряпавши": ["устряпав"],
    "устряпывав": ["устряпывавши"],
    "устряпывавши": ["устряпывав"],
    "устряти": ["встряти", "встрянути", "устрянути"],
    "уступ": ["выступ"],
    "уступав": ["уступавши"],
    "уступавши": ["уступав"],
    "уступать": ["прогибаться"],
    "уступи дорогу": ["уступите дорогу", "рюмка", "морковка"],
    "уступив": ["уступивши"],
    "уступивши": ["уступив"],
    "уступить": ["сдаться", "проиграть"],
    "уступчивость": ["податливость", "покладистость"],
    "уступчивый": ["покладистый"],
    "устура": ["поку"],
    "устыдив": ["устыдивши"],
    "устыдивши": ["устыдив"],
    "устыжав": ["устыжавши"],
    "устыжавши": ["устыжав"],
    "усть-колыванка": ["колыванка", "колывановка"],
    "усть-лабинск": ["усть-лаба", "услаба"],
    "устье": ["жерло", "чело", "очелок", "очёлок", "челесник"],
    "устюг": ["великий устюг"],
    "устюден": ["усьтюнден"],
    "устюнден": ["усьтюнден"],
    "усугубив": ["усугубивши"],
    "усугубивши": ["усугубив"],
    "усугубить": ["увеличить", "усилить", "углубить", "осложнить", "обострить"],
    "усугубление": ["усугубленье"],
    "усугубляв": ["усугублявши"],
    "усугублявши": ["усугубляв"],
    "усугублять": ["усиливать", "увеличивать"],
    "усунути": ["видалити", "всунути"],
    "усушав": ["усушавши"],
    "усушавши": ["усушав"],
    "усушать": ["усушивать"],
    "усушив": ["усушивши"],
    "усушивав": ["усушивавши"],
    "усушивавши": ["усушивав"],
    "усушивать": ["усушать"],
    "усушивши": ["усушив"],
    "усчитав": ["усчитавши"],
    "усчитавши": ["усчитав"],
    "усчитывав": ["усчитывавши"],
    "усчитывавши": ["усчитывав"],
    "усы": ["вибрисса"],
    "усылав": ["усылавши"],
    "усылавши": ["усылав"],
    "усыновив": ["усыновивши"],
    "усыновивши": ["усыновив"],
    "усыновляв": ["усыновлявши"],
    "усыновлявши": ["усыновляв"],
    "усыпав": ["усыпавши"],
    "усыпавши": ["усыпав"],
    "усыпальница": ["склеп"],
    "усыпив": ["усыпивши"],
    "усыпивши": ["усыпив"],
    "усыпительный": ["усыпляющий"],
    "усыпленье": ["усыпление"],
    "усыпляв": ["усыплявши"],
    "усыплявши": ["усыпляв"],
    "усыплять": ["убаюкивать"],
    "усыхав": ["усыхавши"],
    "усыхавши": ["усыхав"],
    "усь": ["фас", "взять"],
    "уськав": ["уськавши"],
    "уськавши": ["уськав"],
    "уськать": ["натравливать", "науськивать", "подстрекать"],
    "уськнув": ["уськнувши"],
    "уськнувши": ["уськнув"],
    "усьтюнден": ["устюден"],
    "утаив": ["утаивши"],
    "утаивав": ["утаивавши"],
    "утаивавши": ["утаивав"],
    "утаивание": ["сокрытие", "утаиванье", "сокрытье", "утаение", "утаенье"],
    "утаиванье": ["утаивание", "сокрытие", "сокрытье"],
    "утаивать": ["придержать", "скрыть", "укрыть", "спрятать"],
    "утаивши": ["утаив"],
    "утайка": ["утаивание", "сокрытие"],
    "утания": ["артания", "аутания"],
    "утапливав": ["утапливавши"],
    "утапливавши": ["утапливав"],
    "утаптывав": ["утаптывавши"],
    "утаптывавши": ["утаптывав"],
    "утаскивав": ["утаскивавши"],
    "утаскивавши": ["утаскивав"],
    "утачав": ["утачавши"],
    "утачавши": ["утачав"],
    "утачивав": ["утачивавши"],
    "утачивавши": ["утачивав"],
    "утащив": ["утащивши"],
    "утащивши": ["утащив"],
    "утварь": ["имущество", "добро", "пожитки"],
    "утвердив": ["утвердивши"],
    "утвердивши": ["утвердив"],
    "утвердительный": ["положительный", "подтверждающий", "уверенный"],
    "утвердить": ["установить", "санкционировать", "ратифицировать", "уверить", "убедить"],
    "утверждав": ["утверждавши"],
    "утверждавши": ["утверждав"],
    "утверждение": ["высказывание", "заявление"],
    "утгард": ["уттгард", "йотунхейм"],
    "утекав": ["утекавши"],
    "утекавши": ["утекав"],
    "утекание": ["отток", "утечка", "бегство", "побег"],
    "утекать": ["исчезать", "пропадать", "проходить", "миновать", "утикать"],
    "утеклец": ["беглец", "сбеглец", "беглый", "сбеглый", "беженец", "эмигрант"],
    "утемнив": ["утемнивши"],
    "утемнивши": ["утемнив"],
    "утемняв": ["утемнявши"],
    "утемнявши": ["утемняв"],
    "утепление": ["изолирование", "теплоустройство", "теплоизоляция", "термоизоляция", "утеплитель"],
    "утеплив": ["утепливши"],
    "утепливши": ["утеплив"],
    "утепляв": ["утеплявши"],
    "утеплявши": ["утепляв"],
    "утерев": ["утёрши"],
    "утереть бороду": ["утереть нос"],
    "утеривав": ["утеривавши"],
    "утеривавши": ["утеривав"],
    "утерпев": ["утерпевши"],
    "утерпевши": ["утерпев"],
    "утеря": ["потеря"],
    "утеряв": ["утерявши"],
    "утерявши": ["утеряв"],
    "утерять": ["утратить"],
    "утесав": ["утесавши"],
    "утесавши": ["утесав"],
    "утеснив": ["утеснивши"],
    "утеснивши": ["утеснив"],
    "утеснитель": ["притеснитель", "угнетатель"],
    "утесняв": ["утеснявши"],
    "утеснявши": ["утесняв"],
    "утетёшив": ["утетёшивши"],
    "утетёшивши": ["утетёшив"],
    "утетёшкав": ["утетёшкавши"],
    "утетёшкавши": ["утетёшкав"],
    "утеха": ["утешение"],
    "утеча": ["втеча"],
    "утечка": ["вытекание", "утекание"],
    "утечка мозгов": ["утечка умов"],
    "утешав": ["утешавши"],
    "утешавши": ["утешав"],
    "утешение": ["успокоение", "утеха", "отрада"],
    "утешив": ["утешивши"],
    "утешивши": ["утешив"],
    "утешный": ["утешительный"],
    "утикав": ["утикавши"],
    "утикавши": ["утикав"],
    "утилизировав": ["утилизировавши"],
    "утилизировавши": ["утилизировав"],
    "утилизировать": ["использовать", "пользоваться", "употреблять", "применять", "прибегать", "эксплуатировать"],
    "утилизовав": ["утилизовавши"],
    "утилизовавши": ["утилизовав"],
    "утилизовать": ["утилизировать"],
    "утилитаризм": ["прагматизм"],
    "утилитарист": ["прагматик"],
    "утилитарный": ["утилитаристский", "прагматический", "практический"],
    "утиль": ["утильсырьё", "вторсырьё", "хлам", "мусор"],
    "утильсырьё": ["утиль", "вторсырьё", "хлам", "мусор"],
    "утиный тест": ["дак-тест"],
    "утирав": ["утиравши"],
    "утиравши": ["утирав"],
    "утирать": ["вытирать"],
    "утирка": ["утирание", "носовой платок"],
    "утискав": ["утискавши"],
    "утискавши": ["утискав"],
    "утискать": ["втискать", "втолкать", "впихнуть"],
    "утискивав": ["утискивавши"],
    "утискивавши": ["утискивав"],
    "утихав": ["утихавши"],
    "утихавши": ["утихав"],
    "утихнув": ["утихнувши"],
    "утихнувши": ["утихнув"],
    "утихомирив": ["утихомиривши"],
    "утихомиривав": ["утихомиривавши"],
    "утихомиривавши": ["утихомиривав"],
    "утихомиривать": ["усмирять", "унимать", "угомонять", "успокаивать"],
    "утихомириваться": ["успокаиваться", "униматься"],
    "утихомиривши": ["утихомирив"],
    "утихомирить": ["усмирить", "унять", "угомонить", "успокоить"],
    "утихомириться": ["успокоиться", "уняться"],
    "утица": ["утка"],
    "утишав": ["утишавши"],
    "утишавши": ["утишав"],
    "утишив": ["утишивши"],
    "утишивши": ["утишив"],
    "уткав": ["уткавши"],
    "уткавши": ["уткав"],
    "уткнув": ["уткнувши"],
    "уткнувши": ["уткнув"],
    "утконосые динозавры": ["гадрозаврид"],
    "утлый": ["ветхий", "дырявый", "худой", "непрочный", "некрепкий", "ненадёжный", "убогий"],
    "уто": ["уаджит"],
    "уток": ["крока"],
    "утолакивав": ["утолакивавши"],
    "утолакивавши": ["утолакивав"],
    "утоленье": ["утоление"],
    "утолив": ["утоливши"],
    "утоливши": ["утолив"],
    "утолстив": ["утолстивши"],
    "утолстивши": ["утолстив"],
    "утолщав": ["утолщавши"],
    "утолщавши": ["утолщав"],
    "утолщение": ["утолщенье"],
    "утолщив": ["утолщивши"],
    "утолщивши": ["утолщив"],
    "утолщиться": ["утолститься"],
    "утоляв": ["утолявши"],
    "утолявши": ["утоляв"],
    "утолять": ["насыщать", "удовлетворять", "утихомиривать"],
    "утомив": ["утомивши"],
    "утомивши": ["утомив"],
    "утомительный": ["трудный", "обременительный", "надоедливый"],
    "утомить": ["изнурить"],
    "утомление": ["уставание", "усталость", "утомлённость"],
    "утомленье": ["утомление"],
    "утомляв": ["утомлявши"],
    "утомлявши": ["утомляв"],
    "утомляемость": ["утомимость"],
    "утомлять": ["надоедать", "наскучивать"],
    "утомляться": ["уставать"],
    "утомлённость": ["усталость"],
    "утомлённый": ["уставший", "усталый"],
    "утонение": ["энтазис"],
    "утонив": ["утонивши"],
    "утонивши": ["утонив"],
    "утонув": ["утонувши"],
    "утонувши": ["утонув"],
    "утонувший": ["затонувший", "потонувший", "утопнувший", "увязнувший", "погрязнувший"],
    "утонуть": ["увязнуть", "потонуть", "затонуть"],
    "утончав": ["утончавши"],
    "утончавши": ["утончав"],
    "утончив": ["утончивши"],
    "утончивши": ["утончив"],
    "утончённо": ["изысканно"],
    "утончённый": ["изысканный", "изощрённый"],
    "утоньшаться": ["сужаться"],
    "утоньшиться": ["сузиться"],
    "утоняв": ["утонявши"],
    "утонявши": ["утоняв"],
    "утопав": ["утопавши"],
    "утопавши": ["утопав"],
    "утопать": ["уйти", "ушагать", "утоптать"],
    "утопив": ["утопивши"],
    "утопивши": ["утопив"],
    "утопить": ["потопить", "спрятать", "скрыть", "заглушить", "подавить", "топить", "оклеветать", "погубить", "доконать", "забить", "завинтить"],
    "утопический": ["утопичный", "фантастический", "химерический"],
    "утопление": ["затопление", "потопление"],
    "утопленница": ["потопленница"],
    "утопленный": ["затопленный", "потопленный"],
    "утопнув": ["утопнувши"],
    "утопнувши": ["утопнув"],
    "утопнуть": ["утонуть"],
    "утоптав": ["утоптавши"],
    "утоптавши": ["утоптав"],
    "утопывав": ["утопывавши"],
    "утопывавши": ["утопывав"],
    "уторапливав": ["уторапливавши"],
    "уторапливавши": ["уторапливав"],
    "уторговав": ["уторговавши"],
    "уторговавши": ["уторговав"],
    "уторговывав": ["уторговывавши"],
    "уторговывавши": ["уторговывав"],
    "уторив": ["уторивши"],
    "уторивши": ["уторив"],
    "уторопив": ["уторопивши"],
    "уторопивши": ["уторопив"],
    "уторопленный": ["ускоренный", "учащённый", "поспешный", "торопливый"],
    "уточив": ["уточивши"],
    "уточивши": ["уточив"],
    "уточненье": ["уточнение"],
    "уточнив": ["уточнивши"],
    "уточнивши": ["уточнив"],
    "уточняв": ["уточнявши"],
    "уточнявши": ["уточняв"],
    "уточнённый": ["скорректированный"],
    "утраивав": ["утраивавши"],
    "утраивавши": ["утраивав"],
    "утрамбовав": ["утрамбовавши"],
    "утрамбовавши": ["утрамбовав"],
    "утрамбовывав": ["утрамбовывавши"],
    "утрамбовывавши": ["утрамбовывав"],
    "утрамбовывать": ["трамбовать", "утаптывать"],
    "утрата": ["потеря"],
    "утратив": ["утративши"],
    "утративши": ["утратив"],
    "утратить": ["лишиться", "потерять"],
    "утрафив": ["утрафивши"],
    "утрафивши": ["утрафив"],
    "утрафляв": ["утрафлявши"],
    "утрафлявши": ["утрафляв"],
    "утрачивав": ["утрачивавши"],
    "утрачивавши": ["утрачивав"],
    "утрачивание": ["потеря"],
    "утрачивать": ["лишаться", "терять"],
    "утренничав": ["утренничавши"],
    "утренничавши": ["утренничав"],
    "утреня": ["заутреня"],
    "утрикул": ["гирогонит"],
    "утрировав": ["утрировавши"],
    "утрировавши": ["утрировав"],
    "утрирование": ["утрировка", "преувеличение", "гиперболизация"],
    "утрировать": ["преувеличивать", "преувеличить", "гиперболизировать"],
    "утро": ["весна"],
    "утроба": ["живот", "внутренности", "нутро", "брюхо", "матка"],
    "утроив": ["утроивши"],
    "утроивав": ["утроивавши"],
    "утроивавши": ["утроивав"],
    "утроивши": ["утроив"],
    "утром": ["наутро", "поутру", "с утра", "утречком", "с утречка", "с утреца", "под утро"],
    "утроя": ["ритупе"],
    "утрояв": ["утроявши"],
    "утроявши": ["утрояв"],
    "утрудив": ["утрудивши"],
    "утрудивши": ["утрудив"],
    "утруднив": ["утруднивши"],
    "утруднивши": ["утруднив"],
    "утрудняв": ["утруднявши"],
    "утруднявши": ["утрудняв"],
    "утруждав": ["утруждавши"],
    "утруждавши": ["утруждав"],
    "утруска": ["лекаж"],
    "утрясав": ["утрясавши"],
    "утрясавши": ["утрясав"],
    "утряхав": ["утряхавши"],
    "утряхавши": ["утряхав"],
    "утухав": ["утухавши"],
    "утухавши": ["утухав"],
    "утухати": ["затухати"],
    "утухнув": ["утухнувши"],
    "утухнувши": ["утухнув"],
    "утучнев": ["утучневши"],
    "утучневши": ["утучнев"],
    "утучнив": ["утучнивши"],
    "утучнивши": ["утучнив"],
    "утучняв": ["утучнявши"],
    "утучнявши": ["утучняв"],
    "утушав": ["утушавши"],
    "утушавши": ["утушав"],
    "утушив": ["утушивши"],
    "утушивши": ["утушив"],
    "утыкав": ["утыкавши"],
    "утыкавши": ["утыкав"],
    "утыкивав": ["утыкивавши"],
    "утыкивавши": ["утыкивав"],
    "утыргыч": ["урындык"],
    "утырок": ["ушлёпок"],
    "уть": ["уть-уть", "ути-ути"],
    "утюг": ["утюжок", "утюжочек", "утюжина", "утюжище"],
    "утюжив": ["утюживши"],
    "утюживши": ["утюжив"],
    "утюжильщик": ["гладильщик"],
    "утюжок": ["утюг"],
    "утя": ["утка"],
    "утягав": ["утягавши"],
    "утягавши": ["утягав"],
    "утягивав": ["утягивавши"],
    "утягивавши": ["утягивав"],
    "утягивать": ["затягивать"],
    "утяжелив": ["утяжеливши"],
    "утяжеливши": ["утяжелив"],
    "утяжеляв": ["утяжелявши"],
    "утяжелявши": ["утяжеляв"],
    "утяжка": ["утягивание"],
    "утянув": ["утянувши"],
    "утянувши": ["утянув"],
    "утятина": ["утка"],
    "утятница": ["гусятница"],
    "утячий": ["утиный"],
    "утёнок": ["утёныш"],
    "утёныш": ["утёнок"],
    "утёрши": ["утерев"],
    "утёсник": ["улекс"],
    "утёсывав": ["утёсывавши"],
    "утёсывавши": ["утёсывав"],
    "уф": ["ах", "ох", "ух"],
    "уфалеец": ["верхнеуфалеец"],
    "уфамс": ["матомс", "уфсемс", "вельхтямс", "тавадомс"],
    "ух": ["фух", "ого"],
    "ух ты": ["ого"],
    "уха": ["ушица", "похлёбка"],
    "ухаб": ["колдобина", "выбоина", "рытвина", "шибель", "нырок"],
    "ухав": ["ухавши"],
    "ухавши": ["ухав"],
    "ухаживав": ["ухаживавши"],
    "ухаживавши": ["ухаживав"],
    "ухаживанье": ["ухаживание"],
    "ухаживатель": ["кавалер", "поклонник", "ухажёр", "хахаль"],
    "ухаживать": ["заботиться", "проявлять", "забота", "внимание", "уделять", "окружать", "опекать", "холить", "лелеять", "ходить", "держать", "под", "крылышко", "пылинки сдувать", "пылинке не давать сесть"],
    "ухажёр": ["поклонник", "кавалер", "воздыхатель", "ухаживатель", "волокита", "дамский угодник", "повеса", "ловелас", "донжуан"],
    "ухайдакав": ["ухайдакавши"],
    "ухайдакавши": ["ухайдакав"],
    "ухайдакать": ["ухайдокать", "ухайдахать", "ухайдохать", "ухандакать"],
    "ухайдакаться": ["ухайдокаться"],
    "ухайдокав": ["ухайдокавши"],
    "ухайдокавши": ["ухайдокав"],
    "ухайдокать": ["ухайдакать"],
    "ухандокав": ["ухандокавши"],
    "ухандокавши": ["ухандокав"],
    "ухандохав": ["ухандохавши"],
    "ухандохавши": ["ухандохав"],
    "уханькав": ["уханькавши"],
    "уханькавши": ["уханькав"],
    "уханькать": ["утащить"],
    "ухарский": ["молодецкий", "бойкий"],
    "ухарствовав": ["ухарствовавши"],
    "ухарствовавши": ["ухарствовав"],
    "ухарь": ["хват", "удалец"],
    "ухати": ["ухкати"],
    "ухаться": ["бухаться"],
    "ухват": ["рогач", "вилки", "вилы", "емки", "ямки"],
    "ухватив": ["ухвативши"],
    "ухвативши": ["ухватив"],
    "ухватывав": ["ухватывавши"],
    "ухватывавши": ["ухватывав"],
    "ухвостье": ["охвостье", "охоботье", "ухоботье", "ухоботь", "озадки", "хвостец", "ость"],
    "ухерачив": ["ухерачивши"],
    "ухерачивши": ["ухерачив"],
    "ухитив": ["ухитивши"],
    "ухитивши": ["ухитив"],
    "ухитить": ["обустроить", "устроить", "уладить", "утеплить"],
    "ухитриться": ["умудриться"],
    "ухитряться": ["умудряться"],
    "ухичивав": ["ухичивавши"],
    "ухичивавши": ["ухичивав"],
    "ухичивать": ["обустраивать", "устраивать", "улаживать", "утеплять"],
    "ухищрение": ["хитрость", "уловка", "трюк"],
    "ухищренье": ["ухищрение"],
    "ухищряться": ["изворачиваться", "изощряться"],
    "ухлебнув": ["ухлебнувши"],
    "ухлебнувши": ["ухлебнув"],
    "ухлеснув": ["ухлеснувши"],
    "ухлеснувши": ["ухлеснув"],
    "ухлестав": ["ухлеставши"],
    "ухлеставши": ["ухлестав"],
    "ухлестнув": ["ухлестнувши"],
    "ухлестнувши": ["ухлестнув"],
    "ухлопав": ["ухлопавши"],
    "ухлопавши": ["ухлопав"],
    "ухлопать": ["израсходовать", "истратить", "укокошить"],
    "ухлопывав": ["ухлопывавши"],
    "ухлопывавши": ["ухлопывав"],
    "ухлыстывав": ["ухлыстывавши"],
    "ухлыстывавши": ["ухлыстывав"],
    "ухлёбывав": ["ухлёбывавши"],
    "ухлёбывавши": ["ухлёбывав"],
    "ухлёстывав": ["ухлёстывавши"],
    "ухлёстывавши": ["ухлёстывав"],
    "ухмылка": ["усмешка", "улыбка"],
    "ухмыляться": ["усмехаться"],
    "ухнув": ["ухнувши"],
    "ухнувши": ["ухнув"],
    "ухнуться": ["бухнуться"],
    "ухо": ["слух", "проушина", "наушник"],
    "уховидный": ["ракушковидный"],
    "уховёртка": ["кожистокрылое"],
    "ухогорлонос": ["оториноларинголог", "ларингооторинолог", "лор"],
    "уход": ["отбытие", "уход из жизни", "смерть", "кончина"],
    "уход из жизни": ["смерть", "кончина"],
    "уходив": ["уходивши"],
    "уходивши": ["уходив"],
    "уходить": ["покидать", "бросать", "избегать", "погружаться", "истекать", "умирать"],
    "ухоженный": ["холёный"],
    "ухолив": ["ухоливши"],
    "ухоливав": ["ухоливавши"],
    "ухоливавши": ["ухоливав"],
    "ухоливши": ["ухолив"],
    "ухоранивав": ["ухоранивавши"],
    "ухоранивавши": ["ухоранивав"],
    "ухорез": ["сорвиголова"],
    "ухоронив": ["ухоронивши"],
    "ухоронивши": ["ухоронив"],
    "ухрюкаться": ["напиться", "до поросячьего визга"],
    "ухта": ["чибью"],
    "уху ел": ["обнаглеть", "офигеть", "охуеть"],
    "ухудшав": ["ухудшавши"],
    "ухудшавши": ["ухудшав"],
    "ухудшать": ["портить"],
    "ухудшенье": ["ухудшение"],
    "ухудшив": ["ухудшивши"],
    "ухудшивши": ["ухудшив"],
    "ухудшиться": ["испортиться"],
    "ухуякивав": ["ухуякивавши"],
    "ухуякивавши": ["ухуякивав"],
    "ухуярив": ["ухуяривши"],
    "ухуяривши": ["ухуярив"],
    "ухуярить": ["въебать", "ебануть", "ёбнуть", "пиздануть", "заебашить", "съебаться", "упиздовать"],
    "уц": ["уч"],
    "уцедив": ["уцедивши"],
    "уцедивши": ["уцедив"],
    "уцеживав": ["уцеживавши"],
    "уцеживавши": ["уцеживав"],
    "уцелев": ["уцелевши"],
    "уцелевав": ["уцелевавши"],
    "уцелевавши": ["уцелевав"],
    "уцелевши": ["уцелев"],
    "уцелевший": ["выживший"],
    "уценив": ["уценивши"],
    "уценивав": ["уценивавши"],
    "уценивавши": ["уценивав"],
    "уценивши": ["уценив"],
    "уценка": ["скидка"],
    "уценять": ["уценивать"],
    "уцепив": ["уцепивши"],
    "уцепивши": ["уцепив"],
    "уцепляв": ["уцеплявши"],
    "уцеплявши": ["уцепляв"],
    "уча": ["изучавам", "обучавам", "школавам", "следвам"],
    "учав": ["учавши"],
    "учавши": ["учав"],
    "учалив": ["учаливши"],
    "учаливав": ["учаливавши"],
    "учаливавши": ["учаливав"],
    "учаливши": ["учалив"],
    "учапав": ["учапавши"],
    "учапавши": ["учапав"],
    "участвовав": ["участвовавши"],
    "участвовавши": ["участвовав"],
    "участив": ["участивши"],
    "участивши": ["участив"],
    "участие": ["вовлечённость", "сотрудничество", "причастность", "жалость", "сочувствие", "сострадание", "доля"],
    "участливость": ["отзывчивость", "сочувственность", "сострадательность"],
    "участок": ["отрезок", "часть", "область"],
    "участь": ["судьба", "доля", "удел", "жребий"],
    "участье": ["участие"],
    "учащав": ["учащавши"],
    "учащавши": ["учащав"],
    "учащаяся": ["ученица", "воспитанница"],
    "учащийся": ["ученик", "уч-ся"],
    "учебное пособие": ["наглядное пособие"],
    "учебный": ["тренировочный"],
    "учение": ["обучение", "обученье", "ученье", "научение", "наученье", "учёба", "учёбля"],
    "ученик": ["школьник", "учащийся", "школяр", "адепт", "выученик", "последователь", "сторонник"],
    "ученичество": ["учёба", "обучение", "незрелость"],
    "ученье": ["учение"],
    "учерпнув": ["учерпнувши"],
    "учерпнувши": ["учерпнув"],
    "учерпывав": ["учерпывавши"],
    "учерпывавши": ["учерпывав"],
    "учесав": ["учесавши"],
    "учесавши": ["учесав"],
    "учесть": ["принять в расчёт", "принять во внимание"],
    "учетверив": ["учетверивши"],
    "учетверивши": ["учетверив"],
    "учетверяв": ["учетверявши"],
    "учетверявши": ["учетверяв"],
    "учив": ["учивши"],
    "учивав": ["учивавши"],
    "учивавши": ["учивав"],
    "учивши": ["учив"],
    "училка": ["учительница"],
    "учинав": ["учинавши"],
    "учинавши": ["учинав"],
    "учинив": ["учинивши"],
    "учинивши": ["учинив"],
    "учинить": ["устроить", "совершить"],
    "учиняв": ["учинявши"],
    "учинявши": ["учиняв"],
    "учинять": ["делать", "совершать", "устраивать"],
    "учител": ["преподавател"],
    "учителка": ["учительница", "учительша", "училка", "учителька"],
    "учителька": ["учительница", "учительша", "училка", "учителка"],
    "учительница": ["преподавательница", "наставница", "светоч", "просветитель", "училка", "учителка", "преподша", "учила"],
    "учительный": ["проповеднический", "нравоучительный"],
    "учительский": ["наставнический", "педагогический"],
    "учительствовав": ["учительствовавши"],
    "учительствовавши": ["учительствовав"],
    "учительствовать": ["учить", "обучать", "наставлять"],
    "учительша": ["училка", "учителка", "учительница"],
    "учитывав": ["учитывавши"],
    "учитывавши": ["учитывав"],
    "учить": ["обучать", "преподавать", "изучать", "учиться", "обучаться", "штудировать", "зубрить", "наказывать"],
    "учиться": ["совершенствоваться", "обучаться"],
    "учпочмак": ["эчпочмак"],
    "учредив": ["учредивши"],
    "учредивши": ["учредив"],
    "учредилка": ["учредиловка"],
    "учредиловка": ["учредилка"],
    "учредитель": ["основатель"],
    "учредительница": ["основательница"],
    "учредить": ["основать", "ввести", "установить"],
    "учредиться": ["основаться", "установиться"],
    "учреждав": ["учреждавши"],
    "учреждавши": ["учреждав"],
    "учреждение": ["создание", "основание", "ввод", "организация", "ведомство", "контора", "структура", "установление", "институт", "институция"],
    "учрежденье": ["учреждение"],
    "учтиво": ["вежливо", "любезно", "галантно", "почтительно"],
    "учтивость": ["вежливость", "почтительность", "любезность", "учтивство"],
    "учтивство": ["учтивость"],
    "учтивый": ["вежливый", "почтительный", "любезный", "обходительный", "уважительный", "корректный", "деликатный"],
    "учув": ["учувши"],
    "учувши": ["учув"],
    "учудив": ["учудивши"],
    "учудивши": ["учудив"],
    "учудить": ["начудить", "отчудить", "отчудачить"],
    "учуивав": ["учуивавши"],
    "учуивавши": ["учуивав"],
    "учуивать": ["чуять"],
    "учуяв": ["учуявши"],
    "учуявши": ["учуяв"],
    "учуять": ["унюхать"],
    "учёба": ["обучение", "учение", "учёбля"],
    "учёный": ["знающий", "обученный", "наученный", "научный"],
    "учёсывав": ["учёсывавши"],
    "учёсывавши": ["учёсывав"],
    "учётка": ["учётная запись", "аккаунт", "акк"],
    "учётная запись": ["аккаунт"],
    "ушагав": ["ушагавши"],
    "ушагавши": ["ушагав"],
    "ушанка": ["шапка-ушанка", "треух"],
    "ушастый": ["длинноухий", "лопоухий", "ушатый"],
    "ушат": ["ведро"],
    "ушатав": ["ушатавши"],
    "ушатавши": ["ушатав"],
    "ушвыривав": ["ушвыривавши"],
    "ушвыривавши": ["ушвыривав"],
    "ушвырнув": ["ушвырнувши"],
    "ушвырнувши": ["ушвырнув"],
    "ушед": ["ушедши", "уйдя"],
    "ушедомс": ["моразевомс", "мора", "самс", "шангамс"],
    "ушестерив": ["ушестеривши"],
    "ушестеривши": ["ушестерив"],
    "ушестеряв": ["ушестерявши"],
    "ушестерявши": ["ушестеряв"],
    "ушибав": ["ушибавши"],
    "ушибавши": ["ушибав"],
    "ушибив": ["ушибивши"],
    "ушибивши": ["ушибив"],
    "ушибленный": ["ударенный"],
    "ушив": ["ушивши"],
    "ушивав": ["ушивавши"],
    "ушивавши": ["ушивав"],
    "ушивши": ["ушив"],
    "уширив": ["уширивши"],
    "уширивши": ["уширив"],
    "уширить": ["расширить"],
    "уширяв": ["уширявши"],
    "уширявши": ["уширяв"],
    "ушица": ["уха"],
    "ушкан": ["заяц"],
    "ушко": ["ухо"],
    "ушкуй": ["ошкуй", "ладья", "лодья", "лодия"],
    "ушкуйник": ["ошкуйник"],
    "ушкуйничав": ["ушкуйничавши"],
    "ушкуйничавши": ["ушкуйничав"],
    "ушлость": ["хитрость", "вёрткость", "хваткость", "изворотливость", "пронырливость", "оборотистость", "находчивость", "хитроумность", "ловкость", "хитрожопость"],
    "ушлый": ["ушедший", "потерянный", "хитрый", "вёрткий", "хваткий", "изворотливый", "пронырливый", "оборотистый", "пальца в рот не клади", "ловкий", "хитрожопый"],
    "ушлёпок": ["утырок", "ублюдок", "уёбок"],
    "ушм": ["мшу", "болгарка", "угловая шлифовальная машина", "углошлифовальная машина"],
    "ушная раковина": ["ухо"],
    "ушник": ["отиатр", "отолог"],
    "уштопав": ["уштопавши"],
    "уштопавши": ["уштопав"],
    "уштопывав": ["уштопывавши"],
    "уштопывавши": ["уштопывав"],
    "уштур": ["шутур"],
    "ушу": ["кунфу"],
    "ушуршав": ["ушуршавши"],
    "ушуршавши": ["ушуршав"],
    "ущелье": ["каньон"],
    "ущемив": ["ущемивши"],
    "ущемивши": ["ущемив"],
    "ущемить": ["придавить", "оскорбить", "обидеть"],
    "ущемление": ["ущемленье", "инкарцерация"],
    "ущемленье": ["ущемление"],
    "ущемляв": ["ущемлявши"],
    "ущемлявши": ["ущемляв"],
    "ущемлять": ["защемлять"],
    "ущерб": ["урон", "убыток"],
    "ущербив": ["ущербивши"],
    "ущербивши": ["ущербив"],
    "ущербляв": ["ущерблявши"],
    "ущерблявши": ["ущербляв"],
    "ущерблённый": ["ущербный", "убывающий"],
    "ущербный": ["убывающий", "неполноценный"],
    "ущипать": ["ущипнуть"],
    "ущипка": ["ущипыванье", "ущипанье", "ущип"],
    "ущипнув": ["ущипнувши"],
    "ущипнувши": ["ущипнув"],
    "ущипывав": ["ущипывавши"],
    "ущипывавши": ["ущипывав"],
    "ущипывание": ["ущипыванье", "ущипанье"],
    "ущупав": ["ущупавши"],
    "ущупавши": ["ущупав"],
    "ущупывав": ["ущупывавши"],
    "ущупывавши": ["ущупывав"],
    "ущучив": ["ущучивши"],
    "ущучивши": ["ущучив"],
    "уьлкю": ["бёлек"],
    "уьф": ["хьэрф"],
    "уэкономив": ["уэкономивши"],
    "уэкономивши": ["уэкономив"],
    "уэкономливав": ["уэкономливавши"],
    "уэкономливавши": ["уэкономливав"],
    "уэльс": ["валлис"],
    "уэльсец": ["валлиец", "кимр"],
    "уэльский": ["валлийский"],
    "уэльсский": ["валлийский"],
    "уэссекс": ["королевство уэссекс"],
    "уэстминстер": ["вестминстер"],
    "уют": ["комфорт"],
    "уютно": ["удобно", "комфортно", "покойно"],
    "уютный": ["комфортный", "удобный"],
    "уязвив": ["уязвивши"],
    "уязвивши": ["уязвив"],
    "уязвимость": ["незащищённость"],
    "уязвимый": ["незащищённый", "ранимый", "чувствительный"],
    "уязвляв": ["уязвлявши"],
    "уязвлявши": ["уязвляв"],
    "уязвлять": ["язвить", "ранить", "жалить", "оскорблять", "обижать", "мучить", "задевать за живое"],
    "уяснив": ["уяснивши"],
    "уяснивши": ["уяснив"],
    "уяснить": ["усвоить", "понять", "врубиться"],
    "уясняв": ["уяснявши"],
    "уяснявши": ["уясняв"],
    "уяснять": ["прояснять", "понимать"],
    "уёба": ["уёбок", "уёбыш"],
    "уёбище": ["удолбище"],
    "уёбищный": ["идиотский", "уебанский", "долбоёбский", "дурной", "некачественный"],
    "уёбок": ["подлец", "сволочь", "падла", "мудак", "мудачина", "уёба", "уёбище", "уебан", "уёбан", "уёбыш", "скотина", "дрянь", "падлюга", "падлюка", "паскуда"],
    "уёбский": ["дрянной", "никудышный", "паршивый", "поганый", "ебаный", "ёбаный", "ебанутый", "ёбнутый", "уёбищный", "хуёвый", "хреновый", "херовый", "фиговый", "сраный"],
    "уёбывав": ["уёбывавши"],
    "уёбывавши": ["уёбывав"],
    "уёбывать": ["исчезать", "проваливать", "смываться", "убегать", "удаляться", "уходить", "съёбывать", "съёбываться", "упиздывать", "уебенивать", "уебёхивать", "уябывать"],
    "уём": ["управа", "удерж"],
    "фа": ["ми-диез"],
    "фа-бемоль": ["ми"],
    "фа-диез": ["соль-бемоль"],
    "фаббинг": ["телефонное залипание"],
    "фаберже прищемить": ["яйца прищемить", "хвост прижать", "за шкирку взять"],
    "фабза": ["хабза"],
    "фабианизм": ["фабианство"],
    "фабианство": ["фабианизм"],
    "фабио": ["фабиньо"],
    "фаблет": ["планшетофон", "фланшет", "плафон", "смартфонопланшет"],
    "фаблио": ["фабльо"],
    "фабра": ["воск", "вакса"],
    "фабрив": ["фабривши"],
    "фабривши": ["фабрив"],
    "фабрика": ["завод", "мануфактура"],
    "фабрика мысли": ["фабрика идей", "исследовательский центр", "научный центр"],
    "фабрика смерти": ["концентрационный лагерь", "лагерь смерти"],
    "фабрикант": ["заводчик", "промышленник", "фабрикатор"],
    "фабрикантка": ["фабрикантша"],
    "фабриковав": ["фабриковавши"],
    "фабриковавши": ["фабриковав"],
    "фабрикование": ["фабрикация"],
    "фабриковаться": ["изготовляться", "производиться"],
    "фабрити": ["фарбувати"],
    "фабрицький": ["фабричний"],
    "фабричний": ["фабрицький"],
    "фабула": ["сюжет"],
    "фабулярный": ["фактический", "сюжетный"],
    "фавна": ["фауна", "фавния"],
    "фавния": ["фавна"],
    "фавозный": ["фавусный"],
    "фавор": ["тавор", "табур", "джебель-тор"],
    "фаворизировав": ["фаворизировавши"],
    "фаворизировавши": ["фаворизировав"],
    "фаворизировать": ["фаворизовать"],
    "фаворизовав": ["фаворизовавши"],
    "фаворизовавши": ["фаворизовав"],
    "фаворизовать": ["фаворизировать"],
    "фаворит": ["любимец", "протеже", "припадочный", "российская газета", "любимчик", "любовник"],
    "фаворитка": ["любимица"],
    "фавт": ["марг", "вафот"],
    "фаг": ["бактериофаг"],
    "фаговар": ["фаготип"],
    "фаготист": ["фаготчик"],
    "фаготний": ["фаготовий"],
    "фаготный": ["фаготовый"],
    "фаготовый": ["фаготный"],
    "фаготроф": ["макроконсумент"],
    "фагоцитировав": ["фагоцитировавши"],
    "фагоцитировавши": ["фагоцитировав"],
    "фагоцитный": ["фагоцитарный"],
    "фад": ["факт"],
    "фаддей": ["фадей"],
    "фаза": ["период", "стадия", "этап"],
    "фазан": ["фазанина", "салага", "черпак"],
    "фазанина": ["фазанинка"],
    "фазаниха": ["фазанка"],
    "фазанка": ["фазаниха"],
    "фазенда": ["асьенда", "эстансия", "шесть соток"],
    "фазендный": ["фазендовый"],
    "фазендовый": ["фазендный"],
    "фазировав": ["фазировавши"],
    "фазировавши": ["фазировав"],
    "фазирование": ["фазировка"],
    "фазировка": ["фазирование"],
    "фазл": ["фазилат"],
    "фазовыравниватель": ["фазокомпенсатор"],
    "фазоиндикатор": ["фазоуказатель"],
    "фазокомпенсатор": ["фазовыравниватель"],
    "фазотрон": ["синхроциклотрон"],
    "фазоуказатель": ["фазоиндикатор"],
    "файдаланучы": ["кулланучы"],
    "файдаланырга": ["кулланырга"],
    "файл": ["электронный документ", "мультифора"],
    "файрволл": ["межсетевой экран", "брандмауэр"],
    "файюм": ["эль-файюм"],
    "фак": ["факультет"],
    "факаофо": ["боудич"],
    "факел": ["светоч", "язык", "столб"],
    "факелоносец": ["факельщик"],
    "факельщик": ["факелоносец"],
    "факир": ["фокусник", "маг", "дервиш"],
    "факсовав": ["факсовавши"],
    "факсовавши": ["факсовав"],
    "факт": ["фад", "фает", "альфа голубя"],
    "фактивный": ["каузальный"],
    "фактитив": ["каузатив"],
    "фактически": ["в самом деле", "в сущности", "на самом деле", "по сути", "по сути дела", "по существу", "практически"],
    "фактографизм": ["фактографичность"],
    "фактографичность": ["фактографизм"],
    "фактология": ["документальность"],
    "фактор": ["причина", "множитель", "сомножитель"],
    "фактор-алгебра": ["факторалгебра"],
    "фактор-группа": ["факторгруппа"],
    "фактор-множество": ["фактормножество"],
    "фактор-полугруппа": ["факторполугруппа"],
    "факторгруппа": ["фактор-группа"],
    "фактория": ["торговый пост", "колония"],
    "фактормножество": ["фактор-множество"],
    "факторствовав": ["факторствовавши"],
    "факторствовавши": ["факторствовав"],
    "фактотум": ["фактор", "доверенное лицо"],
    "фактурировав": ["фактурировавши"],
    "фактурировавши": ["фактурировав"],
    "факультативно": ["опционально"],
    "факультативный": ["необязательный"],
    "факультет": ["фак"],
    "факультет общественных профессий": ["фоп"],
    "фал": ["верёвка", "трос", "канат", "линь", "конец"],
    "фаланга": ["фаланга пальца", "фалака", "сольпуга", "бихорка", "верблюжий паук"],
    "фаланстер": ["фаланстерия"],
    "фалант": ["фаланф"],
    "фалдив": ["фалдивши"],
    "фалдивши": ["фалдив"],
    "фалерист": ["значкист"],
    "фалинь": ["швартов"],
    "фалия": ["талия"],
    "фаллоимитатор": ["дилдо", "годмише", "самотык", "дилдак"],
    "фалломорфировав": ["фалломорфировавши"],
    "фалломорфировавши": ["фалломорфировав"],
    "фалломорфировать": ["удивиться", "изумиться"],
    "фаллопиева труба": ["яйцевод"],
    "фаллопротез": ["страпон"],
    "фалокат": ["бало", "мусибат"],
    "фалс": ["пулакча"],
    "фалу": ["най", "яла", "прокс", "эхярь"],
    "фальконет": ["фалькон"],
    "фальсификат": ["подделка", "фальшивка"],
    "фальсификатор": ["подделыватель"],
    "фальсификация": ["искажение", "фальсифицирование", "подделывание", "подделка", "фальсификат"],
    "фальсифицировав": ["фальсифицировавши"],
    "фальсифицировавши": ["фальсифицировав"],
    "фальсифицированность": ["сфальсифицированность", "фальшивость", "поддельность", "подложность"],
    "фальсифицировать": ["подделывать", "подделать", "подменять", "подменить"],
    "фальсифицируемость": ["опровергаемость", "опровержимость"],
    "фальцаппарат": ["фальцевальный аппарат", "фальцевальное устройство", "фальцевальная машина"],
    "фальцгебель": ["фальцгобель"],
    "фальцгобель": ["фальцгебель"],
    "фальцевав": ["фальцевавши"],
    "фальцевавши": ["фальцевав"],
    "фальцевальный": ["фальцовочный"],
    "фальцет": ["фистула", "головной голос"],
    "фальцовка": ["фальцевание", "соединение", "сгибание"],
    "фальцовочный": ["фальцевальный"],
    "фальшак": ["фальшивка", "подделка"],
    "фальшив": ["фальшивши"],
    "фальшивив": ["фальшививши"],
    "фальшививши": ["фальшивив"],
    "фальшивка": ["подделка"],
    "фальшивши": ["фальшив"],
    "фальшивый": ["поддельный"],
    "фальшпол": ["двойной пол", "поднятый пол"],
    "фальшувати": ["фальшивити"],
    "фальшфасад": ["псевдофасад"],
    "фальшь": ["фальшивка", "подделка", "обман", "мошенничество", "неискренность", "ненатуральность", "ложь", "неестественность"],
    "фамильничав": ["фамильничавши"],
    "фамильничавши": ["фамильничав"],
    "фамильярничав": ["фамильярничавши"],
    "фамильярничавши": ["фамильярничав"],
    "фамильярничание": ["фамильярность"],
    "фамильярничать": ["амикошонствовать", "фамильяриться", "панибратствовать", "вольничать", "быть запанибрата"],
    "фамильярно": ["бесцеремонно", "запанибрата", "панибратски"],
    "фамильярность": ["развязность", "панибратство", "амикошонство", "фамильярничание"],
    "фамильярный": ["бесцеремонный", "развязный"],
    "фамильярствовав": ["фамильярствовавши"],
    "фамильярствовавши": ["фамильярствовав"],
    "фан": ["фэн"],
    "фанаберия": ["высокомерие", "гонор", "заносчивость", "кичливость", "надменность", "понт", "снобизм", "спесь", "спесивость", "чванливость", "чванство", "апломб"],
    "фанаберствовав": ["фанаберствовавши"],
    "фанаберствовавши": ["фанаберствовав"],
    "фанат": ["поклонник", "почитатель", "фанатик", "фан"],
    "фанатев": ["фанатевши"],
    "фанатевши": ["фанатев"],
    "фанатеть": ["тащиться", "быть", "в восторге", "от", "кого-либо", "что-либо", "зависать", "западать", "на", "боготворить", "поклоняться"],
    "фанатизировав": ["фанатизировавши"],
    "фанатизировавши": ["фанатизировав"],
    "фанатизм": ["преданность"],
    "фанатировав": ["фанатировавши"],
    "фанатировавши": ["фанатировав"],
    "фанатически": ["фанатично"],
    "фанатично": ["фанатически"],
    "фанатичность": ["фанатизм"],
    "фанатичный": ["фанатический", "ревностный"],
    "фанатствовав": ["фанатствовавши"],
    "фанатствовавши": ["фанатствовав"],
    "фанатствовать": ["фанатировать"],
    "фандом": ["фэндом"],
    "фандрайзинг": ["фандрейзинг"],
    "фанера": ["шпон", "переклейка", "фанера-переклейка", "фанер", "фанерка", "фанерочка"],
    "фанерив": ["фанеривши"],
    "фанеривши": ["фанерив"],
    "фанерный": ["поддельный", "фальшивый", "глупый", "бестолковый"],
    "фанеровав": ["фанеровавши"],
    "фанеровавши": ["фанеровав"],
    "фанеровщик": ["столяр-фанеровщик"],
    "фанерозой": ["фанерозойский эон"],
    "фанерозойский эон": ["фанерозой"],
    "фанив": ["фанивши"],
    "фанивши": ["фанив"],
    "фановый": ["канализационный"],
    "фантазийный": ["нереальный"],
    "фантазировав": ["фантазировавши"],
    "фантазировавши": ["фантазировав"],
    "фантазировать": ["мечтать", "грезить", "сочинять", "воображать"],
    "фантазия": ["воображение", "мечта", "каприз", "причуда"],
    "фантазм": ["видение", "галлюцинация", "сновидение"],
    "фантазёр": ["выдумщик"],
    "фантасмагоричный": ["фантасмагорический"],
    "фантасмагория": ["калейдоскоп", "галлюцинация", "обман зрения", "бред", "привидение", "феерия", "волшебное зрелище", "сказочное зрелище", "чепуха", "нелепость", "нелепица", "несообразность", "гиль", "вздор", "бессмыслица"],
    "фантастический": ["нереальный", "ненастоящий"],
    "фантастичный": ["фантастический", "нереальный", "сказочный"],
    "фантом": ["призрак", "привидение", "мираж", "иллюзия", "вымысел", "фикция", "муляж"],
    "фантомашка": ["стереоизображение"],
    "фантомная боль": ["алгогаллюциноз"],
    "фантомный": ["воображаемый", "мнимый", "ложный"],
    "фануил": ["пенуэль", "пенуэл"],
    "фанфарон": ["хвастун", "бахвал", "самохвал"],
    "фанфаронив": ["фанфаронивши"],
    "фанфаронивши": ["фанфаронив"],
    "фанфаронить": ["хвастаться", "бахвалиться"],
    "фанфаронство": ["бахвальство"],
    "фанфаронствовав": ["фанфаронствовавши"],
    "фанфаронствовавши": ["фанфаронствовав"],
    "фанфик": ["фан-фикшн", "фэнфик", "фф"],
    "фанфурик": ["фунфырик", "фуфырик"],
    "фапав": ["фапавши"],
    "фапавши": ["фапав"],
    "фара": ["маяк", "глазище", "лупалы", "моргалы", "полтинник", "шар", "шнифт", "синяк", "фонарь", "фингал"],
    "фарад": ["фарада"],
    "фарада": ["фарад"],
    "фараон": ["царь", "полицай", "коп", "мент"],
    "фараоновский": ["фараонов", "фараонский"],
    "фараонский": ["фараоновский", "фараонов"],
    "фарас": ["асп", "асб"],
    "фарбар": ["фарбувальник"],
    "фарватер": ["судоходное русло"],
    "фарерские острова": ["фареры"],
    "фарерский язык": ["фарерский"],
    "фарзанд": ["писар"],
    "фарингеальный": ["глоточный"],
    "фарисей": ["лицемер", "ханжа"],
    "фарисейски": ["по-фарисейски", "лицемерно"],
    "фарисейство": ["ханжество"],
    "фарисействовав": ["фарисействовавши"],
    "фарисействовавши": ["фарисействовав"],
    "фарисействовать": ["лицемерить"],
    "фаришта": ["малак"],
    "фариштамох": ["фаришта", "фариша"],
    "фаркоп": ["сцепной", "шар"],
    "фармазон": ["франкмасон", "масон", "вольнодумец", "нигилист", "безбожник", "фармазонщик"],
    "фармакозависимость": ["лекарственная зависимость", "наркозависимость"],
    "фармакомания": ["лекарствомания"],
    "фармакопея": ["компендиум"],
    "фармакотерапия": ["аллопатия"],
    "фармакохимия": ["фармацевтическая химия"],
    "фармацевтка": ["провизорша", "аптекарша"],
    "фармив": ["фармивши"],
    "фармивши": ["фармив"],
    "фарминг": ["фишинг"],
    "фарминдустрия": ["фармпромышленность"],
    "фармить": ["гриндить", "грайндить"],
    "фармонраво": ["фармонфармо"],
    "фармонфармо": ["фармонраво"],
    "фармоянда": ["фармоишгар"],
    "фармпрепарат": ["лекарство", "лекарственное средство"],
    "фармпроизводитель": ["фармкомпания"],
    "фармпромышленность": ["фарминдустрия"],
    "фаро": ["ба"],
    "фарс": ["парс"],
    "фарсах": ["фарсаг", "фарсанг", "фарасанг", "парасанг", "парасанга", "санг", "таш", "йигач"],
    "фарси": ["персидский язык", "персидский"],
    "фарсёр": ["комедиант", "арлекин", "клоун", "паяц", "гаер", "скоморох", "фигляр", "шут", "шутник"],
    "фарт": ["везение", "пруха", "удача", "счастье", "добыча", "выгода", "прибыль"],
    "фартанув": ["фартанувши"],
    "фартанувши": ["фартанув"],
    "фартануть": ["повезти", "посчастливиться", "удаться", "подвезти", "подфартить", "пофартить"],
    "фартив": ["фартивши"],
    "фартивши": ["фартив"],
    "фартить": ["везти", "удаваться"],
    "фартовый": ["везучий", "удачливый"],
    "фартук": ["передник", "запон", "покрывало"],
    "фартучек": ["передничек"],
    "фарфор": ["порцелан"],
    "фарфоровий": ["порцеляновий"],
    "фарфорово-фаянсовый": ["фарфоро-фаянсовый"],
    "фархунда": ["хушбахт"],
    "фарцевав": ["фарцевавши"],
    "фарцевавши": ["фарцевав"],
    "фарцевать": ["барыжничать", "спекулировать"],
    "фаршировав": ["фаршировавши"],
    "фаршировавши": ["фаршировав"],
    "фас": ["анфас"],
    "фасет": ["фацет", "фасетка"],
    "фасетчатый": ["фасеточный"],
    "фасман": ["фашман"],
    "фасовав": ["фасовавши"],
    "фасовавши": ["фасовав"],
    "фасование": ["фасовка", "расфасовка", "расфасовывание"],
    "фасовать": ["расфасовывать"],
    "фасовщик": ["расфасовщик", "упаковщик"],
    "фасон": ["покрой", "мода", "форс", "шик"],
    "фасонив": ["фасонивши"],
    "фасонивши": ["фасонив"],
    "фасонировав": ["фасонировавши"],
    "фасонировавши": ["фасонировав"],
    "фасонирование": ["моделировать"],
    "фасонистый": ["фасонный", "щегольской", "щёгольский", "франтоватый", "щеголеватый"],
    "фасонить": ["форсить"],
    "фасонный": ["модельный", "фасонистый", "изящный", "щегольской", "франтоватый", "фигурный", "профилированный"],
    "фастфуд": ["быстрое питание"],
    "фастфуд-ресторан": ["ресторан быстрого питания"],
    "фасцинация": ["околдовывание", "завораживание"],
    "фасция": ["фашина"],
    "фат": ["франт", "щёголь", "хлыщ"],
    "фата-моргана": ["мираж"],
    "фаталистический": ["неотвратимый", "предопределённый", "роковой", "фаталистичный", "фатальный"],
    "фатально": ["неминуемо", "неизбежно", "неотвратимо", "непредотвратимо"],
    "фатальность": ["неизбежность", "неотвратимость", "неминуемость", "непредотвратимость"],
    "фатальный": ["роковой", "фаталистический", "смертельный"],
    "фатера": ["квартира", "обиталище", "жилище", "дом"],
    "фатоватый": ["пижонистый", "фатовской", "форсистый", "франтоватый", "хлыщеватый", "щеголеватый", "претенциозный", "стиляжный", "пижонский", "франтовской", "щегольской"],
    "фатовство": ["фатство"],
    "фатство": ["фатовство", "щегольство"],
    "фатум": ["судьба", "рок"],
    "фатюй": ["фетюк"],
    "фауна": ["фавния"],
    "фахридан": ["фахр кардан"],
    "фацет": ["фаска", "фасет"],
    "фацетировав": ["фацетировавши"],
    "фацетировавши": ["фацетировав"],
    "фашизация": ["фашистизация"],
    "фашизировав": ["фашизировавши"],
    "фашизировавши": ["фашизировав"],
    "фашизм": ["коричневая чума"],
    "фашик": ["фашист", "фаш"],
    "фашист": ["нацист", "фашик", "нацик", "гитлеровец", "фриц"],
    "фашиствовав": ["фашиствовавши"],
    "фашиствовавши": ["фашиствовав"],
    "фашистка": ["нацистка", "шовинистка"],
    "фг": ["финансовая группа", "фенидонгидрохинон", "фине гэл"],
    "феатр": ["театр"],
    "фебрильный": ["лихорадочный"],
    "февраль": ["фебруарий"],
    "февральская революция": ["февральский переворот", "февральские события", "февральщина", "мартовская революция"],
    "федеральная резервная система": ["фрс"],
    "федеральная служба безопасности": ["фсб"],
    "федеральный": ["общегосударственный"],
    "федеральный округ": ["фо"],
    "федеральный президент": ["бундеспрезидент"],
    "федеральный резервный банк": ["фрб"],
    "федеративная республика германия": ["фрг", "германия"],
    "федеративный": ["федеральный"],
    "федерация боснии и герцеговины": ["фбиг", "мусульмано-хорватская федерация"],
    "федерировав": ["федерировавши"],
    "федерировавши": ["федерировав"],
    "федора": ["борсалино"],
    "федрезерв": ["федеральный резерв"],
    "федька": ["фёдор"],
    "федя": ["фёдор"],
    "феерически": ["волшебно", "сказочно"],
    "феерический": ["волшебный", "необыкновенный", "поразительный", "неимоверный", "потрясающий", "феноменальный"],
    "феерично": ["сказочно", "волшебно", "дивно", "чудно"],
    "фееричный": ["дивный", "чудный", "волшебный", "сказочный", "феерический"],
    "фейер": ["стольно-белградский комитат"],
    "фейерверк": ["потешные огни", "салют", "каскад", "фонтан", "кутерьма"],
    "фейк": ["неправда", "ложь", "дезинформация", "фальсификация", "фикция", "враньё", "утка"],
    "фейковый": ["ложный", "лживый", "поддельный", "фальшивый", "фальсифицированный", "сфальсифицированный"],
    "фейкометатель": ["фейкомёт", "фейкометательница"],
    "фейкомёт": ["фейкометатель", "фейкометательница"],
    "фейл": ["ошибка"],
    "фейсбук": ["фэйсбук"],
    "фейсбуковский": ["фейсбучий", "фейсбучный"],
    "фейсбучив": ["фейсбучивши"],
    "фейсбучивши": ["фейсбучив"],
    "фейсбучий": ["фейсбуковский", "фейсбучный"],
    "фейсбучный": ["фейсбуковский", "фейсбучий"],
    "фейслифт": ["рестайлинг", "фейслифтинг"],
    "фейслифтинг": ["рестайлинг", "фейслифт"],
    "фейсом об тейбл": ["мордой об стол"],
    "фекал": ["фекалии", "кал", "экскременты"],
    "фекалии": ["кал", "экскременты"],
    "фекальный": ["каловый", "дерьмовый", "говённый"],
    "фекер": ["уй"],
    "фексофенадин": ["фексадин"],
    "фели": ["фелиситас"],
    "фелиситас": ["фели"],
    "фелица": ["фелицитас"],
    "феллоген": ["пробковый камбий"],
    "феллодендрон амурский": ["бархатное дерево", "бархат амурский", "пробковое дерево"],
    "фелляция": ["пенилинкция", "фаллаторизм", "феллаторизм"],
    "фелонь": ["риза"],
    "фельдсвязь": ["фельдъегерская связь"],
    "фельдфебель": ["вахмистр", "старшина", "вевеляй"],
    "фельдшерив": ["фельдшеривши"],
    "фельдшеривши": ["фельдшерив"],
    "фельдшерица": ["медичка"],
    "фельдъегерь": ["посыльный"],
    "фельетонщик": ["фельетонист"],
    "фелькиш": ["фёлькиш", "фёлькише"],
    "фелюга": ["фелука", "фелюка"],
    "фелюжник": ["лодочник", "перевозчик"],
    "фема": ["тэма", "тейма", "феман"],
    "фембой": ["фембойчик"],
    "фембот": ["гиноид"],
    "феминатив": ["феминитив"],
    "феминизация": ["оженствление"],
    "феминизировав": ["феминизировавши"],
    "феминизировавши": ["феминизировав"],
    "феминизм": ["феминность", "фемининность"],
    "фемининность": ["женственность", "феминность"],
    "фемининный": ["женственный"],
    "феминистический": ["феминистский"],
    "феминистская лингвистика": ["феминистская критика языка"],
    "феминистский": ["феминистический"],
    "феминность": ["фемининность"],
    "феминный": ["женственный", "фемининный"],
    "фемицид": ["феминицид"],
    "фемка": ["феминистка"],
    "фемтокулон": ["фкл"],
    "фемтосекунда": ["фс"],
    "феназон": ["антипирин", "анальгезин"],
    "фенакодус": ["фенакод"],
    "фенацетин": ["пара-ацетфенетидин"],
    "фенеботав": ["фенеботавши"],
    "фенеботавши": ["фенеботав"],
    "фенелзин": ["нардил"],
    "фенер": ["лампа", "светило", "светилник"],
    "фенетилкарбамид": ["дульцин"],
    "фенечка": ["фенька", "безделушка", "фича"],
    "фенив": ["фенивши"],
    "фенивши": ["фенив"],
    "феникс": ["греческий феникс"],
    "фенил": ["фенол", "феноловая кислота", "фениловая кислота", "карболовая кислота"],
    "фениламин": ["анилин"],
    "фенилмеркаптан": ["тиофенол"],
    "фенилметан": ["метилбензол", "толуол"],
    "фенилметилпиразолон": ["эдаравон"],
    "фенильный": ["фениловый"],
    "фенилэфрин": ["мезатон"],
    "фенитоин": ["дилантин"],
    "фенноман": ["старофинн"],
    "фенобарбитал": ["люминал"],
    "фенокрист": ["фенокристалл", "вкрапленник"],
    "фенокристалл": ["фенокрист", "вкрапленник"],
    "феноксид": ["фенолят"],
    "фенол": ["гидроксибензол", "карболовая кислота", "карболка"],
    "фенолаза": ["тирозиназа", "полифенолоксидаза", "катехолоксидаза"],
    "фенолрот": ["сульфенталь", "фенолсульфофталеин", "феноловый красный"],
    "фенолформальдегидный": ["фенолоформальдегидный"],
    "фенолфталеин": ["пурген"],
    "фенольний": ["феноловий"],
    "фенольный": ["феноловый"],
    "фенолят": ["феноксид"],
    "феномен": ["уникум", "явление", "парадокс"],
    "фенрик": ["прапорщик"],
    "фенрих": ["прапорщик"],
    "фентезятина": ["фэнтезятина", "фэнтэзятина"],
    "фенугрек": ["пажитник сенной", "пажитник греческий", "шамбала", "метхи", "хельба", "хильба", "гунба", "верблюжья трава"],
    "фенхель": ["фенхель обыкновенный", "укроп аптечный"],
    "фенька": ["фенечка"],
    "феня": ["криминальный жаргон", "арго", "блатная музыка", "жаргон", "сленг"],
    "феодал": ["сеньор"],
    "феодатарий": ["ленник"],
    "феодор": ["фёдор", "божидар"],
    "феофания": ["теофания", "теофана", "феофана"],
    "феохромоцитома": ["хромаффинома"],
    "феральный": ["роковой", "злосчастный", "фатальный"],
    "фередже": ["паранджа"],
    "ферзь": ["королева", "ферязь"],
    "фериште": ["молох"],
    "ферлакур": ["донжуан", "ловелас", "бабник", "ходок"],
    "ферлакурив": ["ферлакуривши"],
    "ферлакуривши": ["ферлакурив"],
    "ферлакурить": ["ухаживать", "волочиться", "флиртовать", "ферлакурничать"],
    "ферлакурничав": ["ферлакурничавши"],
    "ферлакурничавши": ["ферлакурничав"],
    "ферлакурничать": ["ухаживать", "волочиться", "флиртовать", "ферлакурить"],
    "ферма": ["хозяйство", "усадьба", "ранчо"],
    "ферман": ["фирман"],
    "фермент": ["энзим"],
    "ферментативный": ["ферментационный"],
    "ферментировав": ["ферментировавши"],
    "ферментировавши": ["ферментировав"],
    "ферментироваться": ["бродить", "сбраживаться"],
    "ферментопатия": ["энзимопатия", "энзимология"],
    "ферментёр": ["биореактор", "ферментатор"],
    "фермер": ["крестьянин"],
    "фермерствовав": ["фермерствовавши"],
    "фермерствовавши": ["фермерствовав"],
    "фермовый": ["ферменный"],
    "фероньерка": ["фероньера"],
    "феррит-гранат": ["феррогранат"],
    "феррогранат": ["феррит-гранат"],
    "ферромагнит": ["ферромагнетик"],
    "ферросплав": ["сплав железа"],
    "ферросплавный": ["ферросплавовый", "электроферросплавный"],
    "ферроэластик": ["сегнетоэластик"],
    "ферроэлектрик": ["сегнетоэлектрик"],
    "ферроэлектрический": ["сегнетоэлектрический"],
    "ферт": ["эф"],
    "фертильность": ["репродуктивность"],
    "фертильный": ["плодоносный"],
    "фертом": ["подбоченившись", "развязно", "нагло", "нахально"],
    "фес": ["феска"],
    "фесалония": ["фессалия"],
    "фесдре": ["везер"],
    "феска": ["фес"],
    "феспии": ["феспия"],
    "феспис": ["феспид"],
    "фессалийская равнина": ["фессалийская низменность"],
    "фессалия": ["тессалия"],
    "фессалоника": ["солунь", "салоники", "фессалоники"],
    "фессалоники": ["салоники", "солунь"],
    "фест": ["фестик"],
    "фестивалив": ["фестиваливши"],
    "фестиваливши": ["фестивалив"],
    "фестиваль": ["фест", "фестик"],
    "фетальный": ["зародышевый", "эмбриональный"],
    "фетировав": ["фетировавши"],
    "фетировавши": ["фетировав"],
    "фетишизация": ["фетишизирование"],
    "фетишизировав": ["фетишизировавши"],
    "фетишизировавши": ["фетишизировав"],
    "фетишизировать": ["фетишировать"],
    "фетишизм": ["идолопоклонство"],
    "фетишировав": ["фетишировавши"],
    "фетишировавши": ["фетишировав"],
    "фетишировать": ["фетишизировать"],
    "фетопатия": ["эмбриопатия"],
    "фетус": ["плод", "зародиш"],
    "фетюк": ["фитюк", "фатюй"],
    "фефер": ["перец", "пфефер", "пфейфер"],
    "фефёла": ["простофиля", "разиня", "неряха"],
    "фехтовав": ["фехтовавши"],
    "фехтовавши": ["фехтовав"],
    "фехтованье": ["фехтование"],
    "фешенебель": ["фешенебль"],
    "фешенебельно": ["модно"],
    "фешенебельный": ["модный", "престижный"],
    "фешенебль": ["фешенебель"],
    "фея": ["волшебница", "фейри", "кудесница", "благодетельница", "ангел-хранитель"],
    "фи": ["фу"],
    "фиакр": ["экипаж"],
    "фиал": ["фиала"],
    "фиала": ["фиал"],
    "фиалка": ["сенполия"],
    "фианит": ["цирконит", "джевалит", "тажеранит"],
    "фианна файл": ["фф"],
    "фиатный": ["фидуциарный"],
    "фибра": ["жилка", "нерв", "микрофибра", "микроволокно"],
    "фибриллировав": ["фибриллировавши"],
    "фибриллировавши": ["фибриллировав"],
    "фибриллярный": ["нитчатый"],
    "фиброаденома": ["аденофиброма"],
    "фиброз": ["рубцевание"],
    "фиброзит": ["фибромиалгия"],
    "фибропенобетон": ["пенофибробетон"],
    "фиброцистоскоп": ["цистофиброскоп"],
    "фиброцитный": ["фиброцитовый"],
    "фивы": ["карнак"],
    "фиг": ["дуля", "кукиш", "шиш", "фига", "хер", "дудки"],
    "фигарив": ["фигаривши"],
    "фигаривши": ["фигарив"],
    "фигаро": ["кофта", "куртка"],
    "фигатень": ["дребедень", "лабудень", "ерундень"],
    "фигачив": ["фигачивши"],
    "фигачивши": ["фигачив"],
    "фигвам": ["фиг", "фига"],
    "фигев": ["фигевши"],
    "фигевши": ["фигев"],
    "фигеть": ["офигевать", "охреневать"],
    "фигли": ["зачем", "почему", "с какой стати", "чего", "нафиг", "хули", "хуле", "в самом деле", "действительно", "нефиг", "ибо нефиг", "ибо неча", "блин", "ё моё"],
    "фигляр": ["шут", "паяц", "гаер", "кривляка", "позёр", "орёл-скоморох"],
    "фиглярив": ["фигляривши"],
    "фигляривши": ["фиглярив"],
    "фиглярить": ["фиглярствовать", "фиглярничать"],
    "фиглярничав": ["фиглярничавши"],
    "фиглярничавши": ["фиглярничав"],
    "фиглярничать": ["фиглярствовать", "паясничать"],
    "фиглярство": ["клоунада", "позёрство", "кривлянье", "балаганщина"],
    "фиглярствовав": ["фиглярствовавши"],
    "фиглярствовавши": ["фиглярствовав"],
    "фиглярствовать": ["фиглярничать"],
    "фигня": ["дрянь", "хрень", "херня", "пустяк", "ерунда", "лабуда", "штука", "херовина"],
    "фиговина": ["вещь", "штука", "фигня", "хренотень", "херня", "хреновина"],
    "фигово": ["плохо"],
    "фиговый": ["инжирный"],
    "фигулина": ["хреновина"],
    "фигура речи": ["риторическая фигура", "стилистическая фигура"],
    "фигурально": ["иносказательно", "образно", "метафорически"],
    "фигуральный": ["иносказательный", "метафорический"],
    "фигурант": ["статист"],
    "фигуративист": ["фигуративщик"],
    "фигурировав": ["фигурировавши"],
    "фигурировавши": ["фигурировав"],
    "фигурка": ["фигурное катание"],
    "фигурничать": ["выписывать круги"],
    "фигуряв": ["фигурявши"],
    "фигурявши": ["фигуряв"],
    "фигурять": ["щеголять", "красоваться", "форсить", "хвастать"],
    "фигушки": ["фиг", "дудки", "нетушки"],
    "фидер": ["ниблер"],
    "фиджи": ["республика островов фиджи"],
    "фидуциар": ["фидуциарий"],
    "фидуциарный": ["доверительный"],
    "фиельд": ["фьельд"],
    "физалия": ["португальский военный кораблик"],
    "физбой": ["физический бой"],
    "физетин": ["триоксифлавонол"],
    "физиатрический": ["физиотерапевтический"],
    "физиатрия": ["физиотерапия"],
    "физик": ["физическое лицо"],
    "физиогномика": ["физиономика"],
    "физиогномический": ["физиономический"],
    "физиогномия": ["физиономия"],
    "физиография": ["физическая география"],
    "физиолог": ["физиологист"],
    "физиологист": ["физиолог"],
    "физиологическая смерть": ["естественная смерть"],
    "физиологический": ["плотский"],
    "физиологический раствор": ["физраствор"],
    "физиологичный": ["телесный"],
    "физиономика": ["физиогномика"],
    "физиономия": ["лицо", "физия", "лик", "гримаса", "мина", "рожа", "облик"],
    "физиотерапевт": ["физиатр"],
    "физическая культура": ["физкультура"],
    "физическая подготовка": ["физподготовка", "физическая форма"],
    "физический": ["вещественный", "материальный", "мускульный", "мышечный", "физиологический", "телесный", "плотский", "аппаратный"],
    "физическое лицо": ["фл", "физлицо", "физик"],
    "физическое поле": ["поле"],
    "физия": ["физиономия", "лицо"],
    "физкультпауза": ["физпауза", "физкульт-минутка"],
    "физкультура": ["физическая культура"],
    "физкультурник": ["спортсмен", "атлет"],
    "физлицо": ["физическое лицо"],
    "физоксемия": ["аноксемия"],
    "физостигмин": ["эзерина салицилат", "изопто эзерин", "эзерина сульфат"],
    "физпауза": ["физкультпауза"],
    "физра": ["физкультура"],
    "физрук": ["физручка"],
    "физуха": ["физкультура", "физо", "здоровье", "тонус"],
    "фикер": ["уй"],
    "фикр": ["тафаккур", "ният", "фарз", "хаёл"],
    "фиксаж": ["закрепитель"],
    "фиксатор": ["закрепитель", "держатель"],
    "фиксатуар": ["бриолин"],
    "фиксатуарив": ["фиксатуаривши"],
    "фиксатуаривав": ["фиксатуаривавши"],
    "фиксатуаривавши": ["фиксатуаривав"],
    "фиксатуариваться": ["фиксатуариться"],
    "фиксатуаривши": ["фиксатуарив"],
    "фиксатуариться": ["фиксатуариваться"],
    "фиксация": ["фиксирование", "сосредоточение", "сосредоточенность"],
    "фиксив": ["фиксивши"],
    "фиксивши": ["фиксив"],
    "фиксировав": ["фиксировавши"],
    "фиксировавши": ["фиксировав"],
    "фиксирование": ["фиксация"],
    "фиксированный": ["зафиксированный", "закреплённый", "стабилизированный"],
    "фиксить": ["исправлять", "чинить"],
    "фиктивный": ["мнимый", "выдуманный", "поддельный", "фальшивый"],
    "фикция": ["выдумка", "вымысел", "видимость", "фантазия", "небыль", "небылица"],
    "фила": ["филум"],
    "филаггрин": ["филагрин"],
    "филагрин": ["филаггрин"],
    "филадельфус": ["чубушник"],
    "филактерий": ["тфилин", "филактерия"],
    "филактерия": ["тфилин"],
    "филаментная лампа": ["фсл"],
    "филаментный": ["волоконный", "нитевидный", "нитчатый"],
    "филант": ["пчелиный волк", "пчелоед"],
    "филантроп": ["благотворитель", "человеколюбец"],
    "филантропия": ["человеколюбие", "меценатство", "спонсорство", "благотворительность"],
    "филариата": ["филяриата", "филярия"],
    "филателия": ["филателизм"],
    "филворд": ["венгерский кроссворд"],
    "филе": ["филей", "вырезка"],
    "филей": ["вырезка", "филе"],
    "филетировав": ["филетировавши"],
    "филетировавши": ["филетировав"],
    "филетический": ["филогенетический"],
    "филиал": ["отделение"],
    "филиация": ["развитие", "ассоциация"],
    "филигранный": ["филиграновый", "прецизионный"],
    "филиграноведение": ["филигранология"],
    "филиграновый": ["филигранный"],
    "филигранология": ["филиграноведение"],
    "филигрань": ["скань"],
    "филиз": ["израстък", "мустаче", "вейка"],
    "филиппика": ["инвектива"],
    "филиппинский": ["филипино", "пилипино"],
    "филиппины": ["республика филиппины"],
    "филировав": ["филировавши"],
    "филировавши": ["филировав"],
    "филирование": ["филировка"],
    "филировка": ["филирование"],
    "филистер": ["мещанин", "обыватель", "ханжа", "бюргер"],
    "филистерство": ["косность", "лицемерие", "мещанство", "обывательщина", "пошлость", "ханжество"],
    "филистимлянин": ["пеласг"],
    "филистимлянский": ["филистимский"],
    "филистимский": ["филистимлянский"],
    "филлидия": ["филлоид"],
    "филло": ["юфка"],
    "филлоид": ["филлидия"],
    "филлокактус": ["эпифиллум"],
    "филлофорный": ["филлофоровый"],
    "филлофоровый": ["филлофорный"],
    "фило": ["юфка"],
    "филогенез": ["филогенезис", "филогения"],
    "филогенезис": ["филогенез"],
    "филогенетика": ["филогения", "биогенеалогия"],
    "филогенетический": ["филетический"],
    "филогения": ["филогенез", "филогенезис", "биогенеалогия", "филогенетика"],
    "филокартист": ["открыточник"],
    "филолог": ["литературовед"],
    "филон": ["симулянт"],
    "филонив": ["филонивши"],
    "филонивши": ["филонив"],
    "филонить": ["прогуливать", "отлынивать", "халтурить", "сачковать"],
    "философастер": ["псевдофилософ", "лжемудрец", "софист", "философист"],
    "философически": ["философски"],
    "философический": ["философский"],
    "философия": ["любомудрие", "мудрость"],
    "философски": ["философически", "по-философски", "мудро"],
    "философский": ["философический", "теоретический", "отвлечённый", "глубокомысленный"],
    "философствовав": ["философствовавши"],
    "философствовавши": ["философствовав"],
    "филофонист": ["меломан"],
    "филфак": ["литфак"],
    "фильерный": ["волочильный"],
    "фильм": ["кинофильм", "кинокартина", "кинолента", "кино", "лента", "картина"],
    "фильм ужасов": ["ужастик", "жутик", "хоррор", "киноужасы"],
    "фильмообмен": ["кинообмен"],
    "фильмотека": ["кинотека"],
    "фильтрат": ["пермеат"],
    "фильтровав": ["фильтровавши"],
    "фильтровавши": ["фильтровав"],
    "фильтровочный": ["фильтровальный"],
    "фильцевав": ["фильцевавши"],
    "фильцевавши": ["фильцевав"],
    "фильцнадель": ["фильцевание"],
    "филярия": ["нитчатка"],
    "филярный": ["ниточный", "нитяной"],
    "филёр": ["соглядатай", "шпик", "агент", "сыщик"],
    "фимбрия": ["пилус"],
    "фимиам": ["ладан", "лесть"],
    "фимоз": ["незалупа"],
    "финал": ["конец", "завершение", "окончание", "выпуск", "релиз"],
    "финализировав": ["финализировавши"],
    "финализировавши": ["финализировав"],
    "финальный": ["окончательный", "заключительный", "завершающий", "итоговый"],
    "финансировав": ["финансировавши"],
    "финансировавши": ["финансировав"],
    "финансирование": ["ассигнование"],
    "финансист": ["финик"],
    "финансовая аренда": ["лизинг"],
    "финансовое обязательство": ["обязательство"],
    "финансовое право": ["фп"],
    "финансовый": ["денежный"],
    "финансовый рычаг": ["плечо финансового рычага", "кредитный рычаг", "кредитное плечо", "финансовый леверидж"],
    "финансы": ["деньги", "наличность"],
    "финансы поют романсы": ["авансы поют романсы"],
    "финвал": ["финвальный кит", "обыкновенный рогатый кит", "сельдяной кит"],
    "фингал": ["фонарь", "финик", "бланш", "фингальчик", "фингалище", "французские тени"],
    "фине гэл": ["фг"],
    "финеес": ["пинхас", "пинехас"],
    "финес": ["изтънченост", "изящество", "финност"],
    "финикийка": ["финикиянка"],
    "финикиянка": ["финикийка"],
    "финиковая пальма": ["финик"],
    "фининспектор": ["финансовый инспектор"],
    "финита ля комедия": ["абзац", "пипец"],
    "финитивный": ["финитный"],
    "финитность": ["финальность"],
    "финитный": ["конечный", "финитарный", "терминальный", "личный", "определённый", "спрягаемый", "окончательный"],
    "финифть": ["цвет", "эмаль"],
    "финифтяный": ["финифтевый", "финифтяной"],
    "финишировав": ["финишировавши"],
    "финишировавши": ["финишировав"],
    "финка": ["финляндка"],
    "финляндец": ["финн"],
    "финляндия": ["финляндская республика"],
    "финляндская республика": ["финляндия"],
    "финляндский": ["финский"],
    "финна": ["цистицерк"],
    "финно-угр": ["угро-финн"],
    "финноз": ["цистицеркоз"],
    "финский залив": ["кронштадтский залив", "маркизова лужа"],
    "финский нож": ["финка"],
    "финский язык": ["финский"],
    "финт ушами": ["хитрый ход", "ловкий трюк"],
    "финтерлеи": ["безделушка", "финтифлюшка"],
    "финтив": ["финтивши"],
    "финтивши": ["финтив"],
    "финтифлюшка": ["безделушка", "безделица", "безделка", "побрякушка", "финтиклюшка", "фитюлька", "фикушка", "цацка", "пустячок", "пустышка", "вертушка", "вертихвостка", "глупости", "пустяки", "ерунда"],
    "фиолетово": ["лилово"],
    "фиолетовый": ["индиго", "лиловый", "фиолетовый цвет"],
    "фиорд": ["фьорд"],
    "фиоритура": ["колоратура", "мелизм", "мелизма"],
    "фипик": ["фпв"],
    "фиребгар": ["талбискор"],
    "фирма": ["предприятие", "компания", "организация", "бренд", "название", "марка", "вывеска", "прикрытие", "ширма", "подпись", "псевдоним", "ник"],
    "фирман": ["ферман", "охранная грамота"],
    "фирменный": ["корпоративный", "высококачественный", "фирмовый", "превосходный", "отличный"],
    "фирор": ["гурез"],
    "фисгармоника": ["фисгармония"],
    "фисгармония": ["гармониум", "фисгармоника"],
    "фискалив": ["фискаливши"],
    "фискаливши": ["фискалив"],
    "фискалить": ["жаловаться", "нажаловаться", "наушничать", "ябедничать", "капать", "капнуть", "кляузничать", "доносить", "стучать", "стукнуть", "заявлять", "сигнализировать"],
    "фискальничав": ["фискальничавши"],
    "фискальничавши": ["фискальничав"],
    "фискальствовав": ["фискальствовавши"],
    "фискальствовавши": ["фискальствовав"],
    "фисон": ["пишон"],
    "фиссагет": ["тиссагет"],
    "фисташка": ["фисташник"],
    "фисташник": ["фисташковое дерево", "фисташковый куст"],
    "фистула": ["фальцет"],
    "фита": ["тета"],
    "фитема": ["эратема"],
    "фитинг": ["фиттинг"],
    "фитнес-браслет": ["фитнес-трекер"],
    "фитобиология": ["ботаника"],
    "фитология": ["ботаника"],
    "фитоним": ["флороним"],
    "фитономус": ["листовой люцерновый долгоносик", "листовой слоник"],
    "фитонутриент": ["фитохимикат"],
    "фитопалеонтология": ["палеофитология", "палеоботаника"],
    "фитосоциология": ["геоботаника"],
    "фитостерин": ["фитостерол"],
    "фитофагия": ["растительноядность", "травоядность"],
    "фитохимикат": ["фитонутриент"],
    "фитоценология": ["геоботаника", "фитосоциология"],
    "фитюк": ["фетюк"],
    "фитюлька": ["фиговина", "фигнюшка"],
    "фифа": ["международная федерация футбола"],
    "фифочка": ["фифа", "вертихвостка"],
    "фифти-фифти": ["половина на половину", "поровну", "пятьдесят на пятьдесят", "или-или", "либо-либо", "одно из двух"],
    "фифёла": ["неряха", "курица"],
    "фича": ["возможность", "фишка", "функция", "свойство"],
    "фишек": ["бомбичка"],
    "фишка": ["жетон", "штука", "выдумка", "выходка", "затея", "придумка", "прикол", "суть", "прелесть", "достоинство", "фича"],
    "фишкануть": ["выпендриться", "просигнализировать"],
    "флавинадениндинуклеотид": ["фад"],
    "флавонидометр": ["флавонидметр"],
    "флаг": ["знамя", "флажок"],
    "флаг тебе в руки": ["скатертью дорога"],
    "флагеллата": ["биченосец", "жгутиковый", "жгутиконосец"],
    "флагелляция": ["флагелломания", "диппольдизм"],
    "флагман": ["командующий", "ведущий"],
    "флаер": ["рекламка", "афишка", "проходка"],
    "флажок": ["флюгер", "флаговая кнопка", "чекбокс", "галочка"],
    "флайборд": ["гидрофлай", "флайбординг", "флайсёрфинг"],
    "флайбординг": ["флайборд", "флайсёрфинг"],
    "флайер": ["рекламка", "афишка"],
    "флакон": ["бутылочка", "пузырёк"],
    "фламбировав": ["фламбировавши"],
    "фламбировавши": ["фламбировав"],
    "фланелевка": ["голландка синяя", "блуза", "рубаха", "фланка", "фланелька"],
    "фланель": ["бумазея", "бязь", "байка"],
    "фланерствовав": ["фланерствовавши"],
    "фланерствовавши": ["фланерствовав"],
    "фланировав": ["фланировавши"],
    "фланировавши": ["фланировав"],
    "фланировать": ["прогуливаться"],
    "фланкировав": ["фланкировавши"],
    "фланкировавши": ["фланкировав"],
    "фланцевав": ["фланцевавши"],
    "фланцевавши": ["фланцевав"],
    "фланцевать": ["отбортовывать"],
    "фланёрский": ["праздный", "досужий"],
    "фланёрствовав": ["фланёрствовавши"],
    "фланёрствовавши": ["фланёрствовав"],
    "флатировав": ["флатировавши"],
    "флатировавши": ["флатировав"],
    "флеботомия": ["венотомия", "кровопускание"],
    "флегетон": ["пирофлегетон", "пирифлегетон"],
    "флегматизировав": ["флегматизировавши"],
    "флегматизировавши": ["флегматизировав"],
    "флегматически": ["флегматично"],
    "флегматический": ["флегматичный"],
    "флегматично": ["флегматически", "безразлично", "равнодушно"],
    "флегматичность": ["спокойствие", "самообладание", "бесстрастие", "невозмутимость", "хладнокровность"],
    "флегматичный": ["вялый", "равнодушный"],
    "флейвор": ["аромат"],
    "флейм": ["перебранка", "срач"],
    "флеймер": ["ссорщик"],
    "флейта": ["флейт", "флета", "фистула"],
    "флейта пана": ["свирель пана"],
    "флейта-пикколо": ["малая флейта", "пикколо"],
    "флейтный": ["флейтовый"],
    "флейтовый": ["флейтный"],
    "флейцевав": ["флейцевавши"],
    "флейцевавши": ["флейцевав"],
    "флейцевание": ["флейцовка"],
    "флекс": ["флейк", "хлопья", "пэт-флейк", "пэт-флекс", "пэт-хлопья"],
    "флексив": ["флексивши"],
    "флексивный": ["флективный"],
    "флексивши": ["флексив"],
    "флексийный": ["флективный"],
    "флексионный": ["флексийный", "словоизменительный", "сгибательный"],
    "флексировав": ["флексировавши"],
    "флексировавши": ["флексировав"],
    "флексить": ["выпендриваться", "бахвалиться", "щеголять", "хвастаться"],
    "флексия": ["окончание", "сгибание"],
    "флективный": ["флексийный"],
    "флектировав": ["флектировавши"],
    "флектировавши": ["флектировав"],
    "флектировать": ["флексировать"],
    "флеровий": ["флёровий", "унунквадий", "эка-свинец"],
    "флет": ["флэт"],
    "флешбэк": ["ретроспекция"],
    "флешка": ["флеш-накопитель"],
    "флешмоб": ["флэшмоб"],
    "флешмобер": ["мобер", "флешмобист"],
    "флешь": ["редан", "редант", "редут"],
    "флибустьер": ["пират", "капер", "корсар"],
    "флибустьерский": ["пиратский"],
    "флигель": ["крыло"],
    "флигельман": ["фланговый солдат"],
    "флигелёчек": ["флигелёк"],
    "фликер": ["катафот", "световозвращатель", "светоотражатель"],
    "флинт": ["флинтглас"],
    "флинтглас": ["флинт"],
    "флип-флап": ["флип-флоп"],
    "флирт": ["заигрывание", "кокетство", "соблазнение"],
    "флиртовав": ["флиртовавши"],
    "флиртовавши": ["флиртовав"],
    "флиртовать": ["заигрывать", "волочиться", "кокетничать", "ухаживать"],
    "флиска": ["пайта", "толстовка"],
    "флоат": ["флоатинг"],
    "флоатив": ["флоативши"],
    "флоативши": ["флоатив"],
    "флоккулировав": ["флоккулировавши"],
    "флоккулировавши": ["флоккулировав"],
    "флопнув": ["флопнувши"],
    "флопнувши": ["флопнув"],
    "флоппи-диск": ["дискета", "флопик", "гибкий магнитный диск", "гмд"],
    "флопс": ["операций с плавающей запятой в секунду"],
    "флорариум": ["микрооранжерея", "флорарий"],
    "флорентиец": ["флорентинец"],
    "флорентийка": ["флорентинка"],
    "флорентинка": ["флорентийка"],
    "флоризм": ["икебана", "флордизайн"],
    "флорист": ["цветочник"],
    "флористика": ["фитогеография"],
    "флористка": ["цветоводка", "цветочница"],
    "флороним": ["фитоним"],
    "флосс": ["зубной", "нить"],
    "флот": ["флотилия"],
    "флотировав": ["флотировавши"],
    "флотировавши": ["флотировав"],
    "флотоконцентрат": ["флотационный концентрат"],
    "флоэма": ["луб"],
    "флудер": ["флудераст"],
    "флудераст": ["флудер"],
    "флудив": ["флудивши"],
    "флудивши": ["флудив"],
    "флудилка": ["флудильня"],
    "флудильня": ["флудилка"],
    "флуктуационный": ["флюктуационный"],
    "флуктуация": ["флюктуация"],
    "флуктуировав": ["флуктуировавши"],
    "флуктуировавши": ["флуктуировав"],
    "флуктуировать": ["флюктуировать", "колебаться"],
    "флуоксетин": ["прозак"],
    "флуоресцеин": ["диоксифлуоран"],
    "флуоресценция": ["флюоресценция"],
    "флуоресцировав": ["флуоресцировавши"],
    "флуоресцировавши": ["флуоресцировав"],
    "флэт": ["квартира"],
    "флэш-память": ["флэшка"],
    "флэшмоб": ["флешмоб"],
    "флювиальный": ["речной"],
    "флюгер": ["прапор", "прапорица"],
    "флюенс": ["перенос"],
    "флюид": ["ток", "поток", "эманация", "луч", "частица", "импульс", "волна", "вибрация", "аура", "атмосфера", "дух"],
    "флюксия": ["производная"],
    "флюксметр": ["веберметр"],
    "флюктуировав": ["флюктуировавши"],
    "флюктуировавши": ["флюктуировав"],
    "флюктуировать": ["флуктуировать"],
    "флюоресценция": ["флуоресценция", "флюоресцирование"],
    "флюоресцировав": ["флюоресцировавши"],
    "флюоресцировавши": ["флюоресцировав"],
    "флюорограмма": ["рентгенограмма"],
    "флюорография": ["радиофотография", "рентгенофотография", "рентгенофлюорография"],
    "флюсовав": ["флюсовавши"],
    "флюсовавши": ["флюсовав"],
    "флюсовой": ["флюсовый"],
    "флюсовый": ["плюсовый"],
    "флюшка": ["флюорография", "радиофотография", "рентгенофотография"],
    "флюэнта": ["первообразная"],
    "фляга": ["фляжка", "фляжечка"],
    "флягелляция": ["флагеллация"],
    "фляжечный": ["фляжный"],
    "фляжка": ["фляга", "фляжечка"],
    "фляжный": ["фляжечный"],
    "флёр": ["креп"],
    "фнб": ["фонд национального благосостояния"],
    "фнс": ["федеральная налоговая служба"],
    "фоайе": ["преддверие", "хол", "коридор"],
    "фоамиран": ["фом"],
    "фоб": ["франко-борт"],
    "фобия": ["неприязнь", "ненависть", "отвращение", "нетерпимость"],
    "фобофобия": ["фобиофобия"],
    "фогт": ["фохт"],
    "фойе": ["вестибюль", "холл"],
    "фок": ["фок-мачта"],
    "фока": ["фокан", "фокей", "фок"],
    "фокальный": ["фокусный", "очаговый"],
    "фокино": ["тихоокеанский", "тихас"],
    "фокстрот": ["фокс"],
    "фокстротировав": ["фокстротировавши"],
    "фокстротировавши": ["фокстротировав"],
    "фокус-покус": ["трюк", "фокус"],
    "фокусировав": ["фокусировавши"],
    "фокусировавши": ["фокусировав"],
    "фокусирование": ["фокусировка"],
    "фокусировка": ["фокусирование"],
    "фокусник": ["трюкач", "престидижитатор", "иллюзионист"],
    "фокусничав": ["фокусничавши"],
    "фокусничавши": ["фокусничав"],
    "фол": ["нарушение"],
    "фолд": ["пас"],
    "фолдер": ["раскладушка", "ракушка"],
    "фолдив": ["фолдивши"],
    "фолдивши": ["фолдив"],
    "фолиант": ["фолио", "томище", "том", "талмуд"],
    "фолив": ["фоливши"],
    "фоливши": ["фолив"],
    "фолидоз": ["щиткование"],
    "фолиевая кислота": ["фолацин", "фолат", "птероилглютаминовая кислота"],
    "фолк": ["фолк-музыка"],
    "фолк-хистори": ["параистория"],
    "фолликулин": ["эстрон"],
    "фолловер": ["подписчик"],
    "фолловинг": ["подписка"],
    "фолловить": ["подписываться"],
    "фолос": ["толос"],
    "фольварк": ["мыза", "хутор"],
    "фольгировав": ["фольгировавши"],
    "фольгировавши": ["фольгировав"],
    "фолькленд": ["фолькланд"],
    "фома": ["том"],
    "фома неверующий": ["фома неверный"],
    "фомаида": ["томаида", "томазина", "тамзина"],
    "фомизм": ["томизм"],
    "фомино воскресенье": ["фомино воскресение"],
    "фомка": ["монтировка", "фома", "хома", "фомушка"],
    "фонарев": ["фонаревши"],
    "фонаревши": ["фонарев"],
    "фонарь": ["карманный фонарь", "бланш", "фингал", "огонь", "фонарик"],
    "фонд": ["государственный фонд"],
    "фонд национального благосостояния": ["фнб"],
    "фондировав": ["фондировавши"],
    "фондировавши": ["фондировав"],
    "фондоёмкий": ["капиталоёмкий"],
    "фондю": ["сырное фондю"],
    "фонематика": ["фонемология"],
    "фонемический": ["фонемный", "фонематический"],
    "фонемный": ["фонематический"],
    "фонемология": ["фонематика"],
    "фонендоскоп": ["стетоскоп"],
    "фонив": ["фонивши"],
    "фонивши": ["фонив"],
    "фоник": ["звукооператор"],
    "фонить": ["светиться"],
    "фонограмма": ["звуковая дорожка", "саундтрек", "фанера"],
    "фонографизм": ["фонография"],
    "фонографировав": ["фонографировавши"],
    "фонографировавши": ["фонографировав"],
    "фонография": ["фонографизм", "фонетическое письмо"],
    "фонозапись": ["аудиозапись"],
    "фонометрический": ["звукометрический"],
    "фономорфология": ["морфологическая фонология", "морфонология", "морфофонемика"],
    "фонтанировав": ["фонтанировавши"],
    "фонтанировавши": ["фонтанировав"],
    "фонтанировать": ["изливаться", "извергаться"],
    "фонтура": ["игольница"],
    "фора": ["гандикап"],
    "форвард": ["нападающий"],
    "форвардер": ["трелёвочный трактор"],
    "форварднуть": ["отфорвардить"],
    "фордизировав": ["фордизировавши"],
    "фордизировавши": ["фордизировав"],
    "фордыбас": ["фортель"],
    "фордыбачив": ["фордыбачивши"],
    "фордыбачивши": ["фордыбачив"],
    "фордыбачить": ["фордыбачиться", "гордыбачить"],
    "фордыбачиться": ["фордыбачить", "манерничать", "чваниться", "выёживаться", "выделываться", "выпендриваться", "выкаблучиваться", "выкобениваться"],
    "форейтор": ["кучер", "ямщик"],
    "форелевый": ["форельный"],
    "форель": ["пеструшка", "пестряк"],
    "форельный": ["форелевый"],
    "форк": ["ответвление"],
    "форкамера": ["предкамера"],
    "форкастель": ["полубак"],
    "форкнув": ["форкнувши"],
    "форкнувши": ["форкнув"],
    "форкнуть": ["клонировать", "отбранчевать", "ответвиться"],
    "форм-фактор": ["типоразмер"],
    "форма": ["внешность", "вид", "очертания", "наружность", "техника", "бланк", "шаблон", "формуляр", "стереотип", "матрица", "униформа", "мундир", "состояние", "поле ввода"],
    "форма вежливости": ["гоноратив"],
    "формализация": ["структуризация", "стандартизация"],
    "формализировав": ["формализировавши"],
    "формализировавши": ["формализировав"],
    "формализм": ["формалистика"],
    "формализовав": ["формализовавши"],
    "формализовавши": ["формализовав"],
    "формалинный": ["формалиновый"],
    "формалиновый": ["формалинный"],
    "формалист": ["буквоед", "педант"],
    "формалистика": ["формализм", "педантизм", "педантичность", "педантство", "буквоедство"],
    "формалистичный": ["формалистический"],
    "формальдегид": ["метаналь", "оксиметилен"],
    "формально": ["официально", "бюрократически", "фиктивно", "номинально"],
    "формальность": ["бюрократизм"],
    "формант": ["аффикс", "форматив"],
    "формантный": ["гармонический"],
    "формат": ["размер", "вариант", "форма", "направление", "стиль"],
    "форматировав": ["форматировавши"],
    "форматировавши": ["форматировав"],
    "форменная одежда": ["униформа", "форма"],
    "форменный": ["официальный", "прямой", "точный", "настоящий", "подлинный", "действительный", "полномасштабный", "истинный", "сущий", "истый", "чистопробный"],
    "формиат": ["муравьинокислая соль"],
    "формикарий": ["формикариум"],
    "формировав": ["формировавши"],
    "формировавши": ["формировав"],
    "формирование": ["образование", "создание", "подразделение"],
    "формированье": ["формирование"],
    "формовав": ["формовавши"],
    "формовавши": ["формовав"],
    "формовальный": ["формовочный", "формующий"],
    "формование": ["формовка", "формирование", "оформление", "технология формования"],
    "формовка": ["формирование", "формование"],
    "формовочная машина": ["формующая машина"],
    "формовочный": ["формующий"],
    "формоза": ["тайвань"],
    "формоизменяемость": ["видоизменяемость", "трансформация"],
    "формообразование": ["формирование", "словоизменение"],
    "формоутворювальний": ["формоутворюючий"],
    "формула": ["вывод", "формулировка"],
    "формулировав": ["формулировавши"],
    "формулировавши": ["формулировав"],
    "формулировать": ["высказывать", "произносить"],
    "формулировка": ["формулирование", "формула", "выражение"],
    "формующая машина": ["формовочная машина", "формующий агрегат"],
    "формующий": ["формовочный"],
    "формующий агрегат": ["формующая машина"],
    "фороптер": ["фороптор"],
    "форпост": ["аванпост"],
    "форс": ["франтовство", "пижонство", "шик", "спесь", "надменность", "напыщенность", "чванство"],
    "форсаж": ["форсировка"],
    "форсив": ["форсивши"],
    "форсивши": ["форсив"],
    "форсировав": ["форсировавши"],
    "форсировавши": ["форсировав"],
    "форсированный марш": ["форсмарш"],
    "форсировать": ["усиливать", "усилить", "ускорять", "ускорить", "убыстрить", "убыстрять", "газовать"],
    "форсить": ["разгонять", "навязывать", "проталкивать"],
    "форснув": ["форснувши"],
    "форснувши": ["форснув"],
    "форте": ["громко"],
    "фортель": ["фордыбас", "выходка", "закидон", "проделка", "штука", "штукенция"],
    "фортепианный": ["фортепьянный"],
    "фортепиано": ["фортепьяно"],
    "фортепьянный": ["фортепианный"],
    "фортепьяно": ["фортепиано"],
    "фортеция": ["крепость"],
    "фортификация": ["укрепление"],
    "форточка": ["фортка", "виндуза"],
    "фортуна": ["удача", "везение", "счастье", "шанс", "судьба", "фатум"],
    "фортунелла": ["кумкват"],
    "фортунив": ["фортунивши"],
    "фортунивши": ["фортунив"],
    "форум": ["съезд", "конференция", "симпозиум", "веб-форум", "форумок", "форумчик"],
    "форумен": ["форумчанин"],
    "форумок": ["форум", "форумчик"],
    "форумчанин": ["форумен"],
    "форумчик": ["форум", "форумок"],
    "форфейтинг": ["форфейтирование", "форфетирование"],
    "форфейтировав": ["форфейтировавши"],
    "форфейтировавши": ["форфейтировав"],
    "фос": ["фосфорорганическое соединение", "фосфороорганическое соединение"],
    "фосбюри-флоп": ["флоп", "фосбюри"],
    "фосген": ["дихлорангидрид", "угольная кислота", "карбонилхлорид", "хлорокись углерода"],
    "фосгеновий": ["фосгенний"],
    "фосфатизировав": ["фосфатизировавши"],
    "фосфатизировавши": ["фосфатизировав"],
    "фосфатировав": ["фосфатировавши"],
    "фосфатировавши": ["фосфатировав"],
    "фосфор": ["люцифер", "геспер", "эосфор", "веспер"],
    "фосфоресцировав": ["фосфоресцировавши"],
    "фосфоресцировавши": ["фосфоресцировав"],
    "фосфорилировав": ["фосфорилировавши"],
    "фосфорилировавши": ["фосфорилировав"],
    "фосфоритный": ["фосфоритовый"],
    "фосфоритовый": ["фосфоритный"],
    "фосфорная кислота": ["ортофосфорная кислота"],
    "фосфорноватистая кислота": ["гипофосфористая кислота", "фосфиновая кислота"],
    "фосфорный": ["фосфорсодержащий", "фосфорический"],
    "фотав": ["фотавши"],
    "фотавши": ["фотав"],
    "фотать": ["фотографировать", "снимать", "фоткать"],
    "фотаться": ["фоткаться", "фотографироваться"],
    "фотик": ["фотоаппарат", "фотокамера"],
    "фотир": ["офаридгор"],
    "фотка": ["фотография", "снимок", "фото"],
    "фоткав": ["фоткавши"],
    "фоткавши": ["фоткав"],
    "фоткать": ["фотографировать", "снимать", "фотать"],
    "фоткаться": ["фотографироваться", "сниматься", "фотаться"],
    "фото": ["фотография", "фотокарточка", "снимок"],
    "фотоаппарат": ["фотокамера", "фотик", "фот"],
    "фотовольтаический": ["фотогальванический"],
    "фотовёрстка": ["фотонабор"],
    "фотогальванический": ["фотовольтаический"],
    "фотоген": ["керосин"],
    "фотогравюра": ["гелиогравюра"],
    "фотографировав": ["фотографировавши"],
    "фотографировавши": ["фотографировав"],
    "фотографирование": ["фотосъёмка"],
    "фотографировать": ["снимать", "фоткать", "фотать"],
    "фотографироваться": ["сниматься", "фоткаться", "фотаться"],
    "фотография": ["фото", "фотографирование", "фотка", "фотокарточка", "фотоснимок", "снимок", "карточка", "фотоателье", "фотомастерская"],
    "фотографка": ["фотографиня"],
    "фотодеградация": ["фоторазложение", "фоторазрушение"],
    "фотодиссоциация": ["фотолиз"],
    "фотоелемент": ["сонячний елемент", "фотоелектричний перетворювач"],
    "фотожопив": ["фотожопивши"],
    "фотожопивши": ["фотожопив"],
    "фотожопить": ["фотошопить"],
    "фотожурналист": ["фотокорреспондент"],
    "фотоизображение": ["фотография"],
    "фотокамера": ["фотоаппарат"],
    "фотокарточка": ["фотография", "фотографическая карточка", "снимок", "фото"],
    "фотокопировав": ["фотокопировавши"],
    "фотокопировавши": ["фотокопировав"],
    "фотокор": ["фоторепортёр"],
    "фотокорреспондент": ["фотокор"],
    "фотолампа": ["лампа", "перекальная лампа"],
    "фотомастер": ["фотохудожник"],
    "фотомастерская": ["фотоателье"],
    "фотопроводимость": ["фоторезистивный эффект"],
    "фоторазрушение": ["фоторазложение", "фотодеградация", "фотодеструкция"],
    "фотореакция": ["фотохимическая реакция"],
    "фотосенсибилизировав": ["фотосенсибилизировавши"],
    "фотосенсибилизировавши": ["фотосенсибилизировав"],
    "фотосенсор": ["фотоэлемент"],
    "фотосистема": ["первая фотосистема", "вторая фотосистема", "фотоаппарат"],
    "фотоснимок": ["снимок", "фотка", "фотография"],
    "фотосопротивление": ["фоторезистор"],
    "фототелеграф": ["бильдаппарат"],
    "фототипия": ["светотипия"],
    "фототок": ["фотоэлектрический ток"],
    "фототропизм": ["гелиотропизм"],
    "фотофильм": ["слайд-фильм"],
    "фотохимическая реакция": ["фотореакция"],
    "фотохудожник": ["фотомастер"],
    "фотошкола": ["фотоакадемия", "фотостиль"],
    "фотошоп": ["фотожаба", "фотожоп"],
    "фотошопив": ["фотошопивши"],
    "фотошопивши": ["фотошопив"],
    "фотошопить": ["фотожопить"],
    "фотошпион": ["папарацци"],
    "фотоэкспонометр": ["экспозиметр"],
    "фотоэлектролюминесценция": ["фэл"],
    "фотоэлемент": ["фотосенсор"],
    "фотоэмиссия": ["фотоэлектронная эмиссия"],
    "фотоэффект": ["фотоэлектрический эффект"],
    "фофан": ["простофиля"],
    "фофудья": ["православие головного мозга", "христоз головного мозга", "вата", "ватник"],
    "фохт": ["фогт"],
    "фош": ["ошкор"],
    "фра": ["монах", "брат"],
    "фрагмент": ["кусок", "обломок", "обрывок", "деталь"],
    "фрагментарность": ["отрывочность", "неполнота", "раздробленность"],
    "фрагментация": ["фрагментирование"],
    "фрагментировав": ["фрагментировавши"],
    "фрагментировавши": ["фрагментировав"],
    "фрагментирование": ["фрагментация", "дробление"],
    "фрагментировать": ["раздроблять"],
    "фрагмокон": ["фрагмоконус"],
    "фраер": ["терпила", "пижон", "простак", "простофиля", "франт", "наглец"],
    "фраерив": ["фраеривши"],
    "фраеривши": ["фраерив"],
    "фраза": ["предложение", "выражение", "сентенция", "пассаж"],
    "фразема": ["фразеологический оборот", "фразеологизм"],
    "фразеологизм": ["фразеологический оборот", "фразема", "идиома"],
    "фразеологическая единица": ["фразеологизм", "фразеологический оборот"],
    "фразеологический": ["идеоматический"],
    "фразеологический оборот": ["фразеологизм", "фразема"],
    "фразеологическое сращение": ["идиома"],
    "фразеология": ["идиоматика", "набор слов", "фразёрство", "риторика"],
    "фразировав": ["фразировавши"],
    "фразировавши": ["фразировав"],
    "фразис": ["метафора"],
    "фразёр": ["пустослов", "краснобай"],
    "фразёрство": ["пустословие", "краснобайство"],
    "фразёрствовав": ["фразёрствовавши"],
    "фразёрствовавши": ["фразёрствовав"],
    "фрактал": ["фракталь"],
    "фракталь": ["фрактал"],
    "фрактальная размерность": ["дробная размерность"],
    "фракционер": ["раскольник", "еретик", "отщепенец"],
    "фракционировав": ["фракционировавши"],
    "фракционировавши": ["фракционировав"],
    "фракция": ["фаза"],
    "фрамуга": ["форточка"],
    "франкировав": ["франкировавши"],
    "франкировавши": ["франкировав"],
    "франклин": ["статкулон"],
    "франкмасон": ["масон"],
    "франкмасонский": ["масонский"],
    "франкмасонство": ["масонство"],
    "франко-борт": ["фоб"],
    "франко-западногерманский": ["французско-западногерманский"],
    "франковав": ["франковавши"],
    "франковавши": ["франковав"],
    "франкоговорящий": ["франкоязычный"],
    "франколин": ["турач"],
    "франкофил": ["галломан"],
    "франкофилия": ["галломания", "галлофилия", "франкофильство"],
    "франкофилка": ["галломанка"],
    "франкофильский": ["галломанский", "галлофильский"],
    "франкофоб": ["галлофоб"],
    "франкофобия": ["галлофобия"],
    "франкофобка": ["галлофобка"],
    "франкофобский": ["галлофобский"],
    "франкофобський": ["галлофобський"],
    "франкофонский": ["франкоязычный"],
    "франкский язык": ["древнефранкский язык"],
    "франкфурт-на-майне": ["франкфурт"],
    "франсеск": ["сеск"],
    "франсиско": ["иско"],
    "франт": ["щёголь", "модник", "денди"],
    "франтив": ["франтивши"],
    "франтивши": ["франтив"],
    "франтить": ["щеголять"],
    "франтиха": ["щеголиха", "модница"],
    "франтоватый": ["элегантный", "франтовской", "щеголеватый"],
    "франтовской": ["франтоватый"],
    "франтовство": ["модничание", "пижонство", "щегольство", "форс"],
    "францизация": ["галлизация", "офранцуживание"],
    "франция": ["французская республика", "галлия"],
    "франциялык": ["франсуз"],
    "француз": ["галл", "лягушатник"],
    "француз теле": ["французча"],
    "французив": ["французивши"],
    "французивши": ["французив"],
    "французик": ["французишка", "лягушатник"],
    "французка": ["француженка"],
    "французоман": ["галломан", "франкофил"],
    "французомания": ["галломания", "франкофильство"],
    "французская болезнь": ["сифилис", "льюис", "дурная болезнь", "скверная болезнь", "стыдная болезнь", "сиф", "сифак", "сифачина"],
    "французская булка": ["городская булка", "франсоля", "францоля", "франзоля", "франзуля", "франзолька", "франзулька", "багет"],
    "французская гвиана": ["гвиана"],
    "французская республика": ["франция", "галлия", "пятая республика"],
    "французский": ["галльский"],
    "французский поцелуй": ["поцелуй взасос", "оральный секс"],
    "французский язык": ["французский"],
    "французско-западногерманский": ["франко-западногерманский"],
    "франчайз": ["френчайз"],
    "франчайзи": ["франчайзиат"],
    "франчайзиат": ["франчайзи"],
    "франчайзинг": ["коммерческая концессия", "комплексная предпринимательская лицензия", "франшиза"],
    "франшиза": ["договор коммерческой концессии"],
    "фраппировав": ["фраппировавши"],
    "фраппировавши": ["фраппировав"],
    "фраппировать": ["шокировать", "ошеломлять", "изумлять", "огорашивать"],
    "фрасий": ["трасий"],
    "фратернизация": ["братание", "побратимство"],
    "фратрицид": ["братоубийство", "огонь по своим"],
    "фрау": ["госпожа"],
    "фрахт": ["фрахтовка"],
    "фрахтовав": ["фрахтовавши"],
    "фрахтовавши": ["фрахтовав"],
    "фрахтовать": ["зафрахтовывать"],
    "фрахтовщик": ["судовладелец"],
    "фрачник": ["фрачный", "стеблеед"],
    "фрг": ["федеративная республика германия", "германия"],
    "фрегат": ["сторожевой корабль"],
    "фрегезия": ["община", "приход"],
    "фреза": ["раф", "горгера", "лечугилья", "мельничный жернов"],
    "фрезер": ["мэф"],
    "фрезеровав": ["фрезеровавши"],
    "фрезеровавши": ["фрезеровав"],
    "фрезеровальный": ["фрезеровочный"],
    "фрезерование": ["фрезеровка"],
    "фрезеровочный": ["фрезеровальный", "фрезерный"],
    "фрезовав": ["фрезовавши"],
    "фрезовавши": ["фрезовав"],
    "фрейграф": ["фрайграф"],
    "фрейд": ["фрёйд", "фройд"],
    "фрейдистский": ["фрейдовский"],
    "фрейдовский": ["фрейдов", "фрейдистский"],
    "фрейлейн": ["фрейлен", "фройляйн", "барышня", "девушка", "девица", "мадемуазель", "мисс", "сеньорита", "синьорина", "фрекен", "фрёкен"],
    "фрейлен": ["фрейлейн", "фройляйн", "барышня", "девица", "девушка", "мадемуазель", "мисс", "сеньорита", "синьорина", "фрекен", "фрёкен"],
    "фрекен": ["фрёкен", "барышня", "мадемуазель", "мисс", "сеньорита", "фройляйн"],
    "фрекинг": ["гидроразрыв", "пласт"],
    "френд": ["друг", "приятель", "фолловер"],
    "френдесса": ["подруга", "приятельница", "подписчица"],
    "френдив": ["френдивши"],
    "френдивши": ["френдив"],
    "френезия": ["сумасшествие", "воспаление", "бешенство", "исступление", "неистовство"],
    "френотомия": ["френулотомия"],
    "френулэктомия": ["френэктомия"],
    "френч": ["френчик", "хренчик"],
    "френчайз": ["франчайз"],
    "фреон": ["хладон"],
    "фреск": ["фреска"],
    "фрешмен": ["первокурсник", "новичок"],
    "фри-файт": ["фрифайт"],
    "фривольний": ["легковажний"],
    "фривольничав": ["фривольничавши"],
    "фривольничавши": ["фривольничав"],
    "фривольно": ["двусмысленно", "легкомысленно", "пикантно", "нескромно", "непристойно", "игриво", "смело", "нагло", "вольно", "рискованно"],
    "фривольность": ["вольность", "двусмысленность", "игривость", "легкомысленность", "легкомыслие", "малопристойность", "непристойность", "нескромность", "пикантность", "фривольничание", "смелость"],
    "фривольный": ["вольный"],
    "фриганизм": ["фриганство"],
    "фриганство": ["фриганизм"],
    "фриггатрискаидекафобия": ["параскаведекатриафобия"],
    "фригидный": ["холодный"],
    "фридерик": ["фредерик", "фридрих"],
    "фридрих": ["фридерик", "фредерик"],
    "фризия": ["фрисландия"],
    "фризский": ["фрисландский"],
    "фризьор": ["коафьор", "бръснар", "бербер"],
    "фрик": ["чудик"],
    "фрикаделька": ["фрикадель", "ёжик"],
    "фрикасе": ["рагу"],
    "фрикатив": ["спирант", "фрикативный согласный", "щелевой"],
    "фрикативный": ["щелевой"],
    "фрикативный согласный": ["щелевой согласный", "спирант", "фрикатив"],
    "фрикерство": ["фрикинг"],
    "фрикинг": ["фрикерство"],
    "фрикция": ["трение"],
    "фрилансер": ["вольнонаёмный", "подёнщик"],
    "фрилансив": ["фрилансивши"],
    "фрилансивши": ["фрилансив"],
    "фрилансовый": ["фрилансерский"],
    "фриман": ["фримен"],
    "фримен": ["фриман"],
    "фрирайд": ["фрирайдинг"],
    "фрисби": ["летающая тарелка"],
    "фристайлист": ["фристайлер"],
    "фристайло": ["ракамакафо"],
    "фритиллярия": ["рябчик"],
    "фритредерство": ["манчестерство"],
    "фриттовав": ["фриттовавши"],
    "фриттовавши": ["фриттовав"],
    "фриульский": ["фурланский", "фриульский язык"],
    "фриц": ["фридрих"],
    "фрицевский": ["гансовский", "немчурский"],
    "фришевав": ["фришевавши"],
    "фришевавши": ["фришевав"],
    "фриштикав": ["фриштикавши"],
    "фриштикавши": ["фриштикав"],
    "фриштикать": ["фрыштикать", "фриштыкать"],
    "фриштыкав": ["фриштыкавши"],
    "фриштыкавши": ["фриштыкав"],
    "фриштыкать": ["фрыштикать", "фриштикать"],
    "фройляйн": ["фрейлейн", "фрейлен", "барышня", "девушка", "девица", "мадемуазель", "мисс", "сеньорита", "синьорина", "фрекен", "фрёкен"],
    "фрондировав": ["фрондировавши"],
    "фрондировавши": ["фрондировав"],
    "фрондёрствовав": ["фрондёрствовавши"],
    "фрондёрствовавши": ["фрондёрствовав"],
    "фронт": ["шеренга", "передний край"],
    "фронтенд-разработчик": ["фронтендер", "фронтендщик"],
    "фронтендер": ["фронтендщик", "фронтенд-разработчик"],
    "фронтендщик": ["фронтендер", "фронтенд-разработчик"],
    "фронтир": ["приграничье", "буферная зона", "зона безопасности", "нейтральная зона", "приграничная зона", "пограничная зона", "аванпост", "санитарный кордон", "граница", "предел", "раздел", "рубеж", "черта", "водораздел", "передний край"],
    "фронтиспис": ["контртитул", "фасад"],
    "фронтовик": ["военнослужащий", "ветеран"],
    "фроттеризм": ["фроттаж"],
    "фрп": ["плацентарный фактор роста"],
    "фрукт": ["субъект", "тип"],
    "фруктовая летучая мышь": ["летучая лисица"],
    "фрументий": ["фруменций"],
    "фруменций": ["фрументий"],
    "фрунт": ["фронт"],
    "фрустрация": ["аут"],
    "фрустрировав": ["фрустрировавши"],
    "фрустрировавши": ["фрустрировав"],
    "фрыштикав": ["фрыштикавши"],
    "фрыштикавши": ["фрыштикав"],
    "фрыштикать": ["фриштикать", "фриштыкать"],
    "фрю": ["фру", "мадам", "госпожа"],
    "фрюктидор": ["фруктидор"],
    "фря": ["воображала", "зазнайка", "цаца"],
    "фряг": ["итальянец", "волох", "фрязин"],
    "фряжский": ["иностранный", "иноземный", "чужеземный", "заморский", "заграничный", "зарубежный", "импортный"],
    "фрёкен": ["фрекен", "барышня", "мадемуазель", "мисс", "сеньорита", "фройляйн"],
    "фсб": ["контора", "лубянка"],
    "фсин": ["фсин россии"],
    "фсин россии": ["фсин"],
    "фскн": ["наркополиция"],
    "фсфм": ["кфм"],
    "фтал": ["фталкс", "фталце пяль", "пере", "ума"],
    "фталу": ["инголи"],
    "фтизиатрия": ["фтизиология"],
    "фтор": ["флюор"],
    "фторалюминат": ["фтороалюминат"],
    "фторид алюминия": ["фтористый алюминий"],
    "фторировав": ["фторировавши"],
    "фторировавши": ["фторировав"],
    "фторированный кетон": ["фторкетон", "сухая вода"],
    "фторкетон": ["флуорокетон", "сухая вода"],
    "фтороалюминат": ["фторалюминат"],
    "фторопласт": ["фторлон"],
    "фу": ["фи", "фу-фу"],
    "фу-фу": ["фи", "фу"],
    "фуа": ["присяга"],
    "фугас": ["фугаска", "фугасная бомба"],
    "фугировав": ["фугировавши"],
    "фугировавши": ["фугировав"],
    "фуговав": ["фуговавши"],
    "фуговавши": ["фуговав"],
    "фуговальный": ["фуговочный"],
    "фуговка": ["фугование"],
    "фуговочный": ["фуговальный"],
    "фугу": ["тетрадон"],
    "фуд-корт": ["ресторанный дворик"],
    "фуд-маркет": ["ресторанный дворик", "фуд-корт", "фудмолл"],
    "фудкорт": ["ресторанный дворик"],
    "фудмолл": ["фуд-корт", "фудмаркет"],
    "фузея": ["мушкет"],
    "фузионный": ["флективный"],
    "фузиформный": ["веретенообразный"],
    "фука": ["бяка", "кака", "гадость"],
    "фукав": ["фукавши"],
    "фукавши": ["фукав"],
    "фукание": ["фуканье"],
    "фуканье": ["фукание"],
    "фукнув": ["фукнувши"],
    "фукнувши": ["фукнув"],
    "фукс": ["первокурсник", "студент-первокурсник"],
    "фуксин": ["розеин"],
    "фуллерен": ["бакибол", "букибол"],
    "фуллфрейм": ["фулфрейм"],
    "фулуз": ["филиз"],
    "фуляр": ["платок"],
    "фумарола": ["трещина", "отверстие", "дыра"],
    "фумизм": ["фюмизм"],
    "фундальний": ["донний"],
    "фундамент": ["база", "основание", "цоколь", "базис"],
    "фундаменталка": ["фундаментальная наука", "чистая наука", "основная наука", "фундаментальная библиотека"],
    "фундаментально": ["прочно", "основательно", "глубоко"],
    "фундаментальный": ["солидный", "основательный", "глубокий"],
    "фундировав": ["фундировавши"],
    "фундировавши": ["фундировав"],
    "фундук": ["лесной орех", "лещина"],
    "фуник": ["фуникулёр"],
    "фуникул-": ["фуникуло-"],
    "фуникулёр": ["фуник"],
    "функционал": ["метафункция", "функциональность"],
    "функционализм": ["структурный функционализм"],
    "функциональность": ["функционал", "практичность", "полезность"],
    "функциональный": ["полезный", "практичный"],
    "функционер": ["аппаратчик"],
    "функционировав": ["функционировавши"],
    "функционировавши": ["функционировав"],
    "функционировать": ["действовать", "работать"],
    "функционирующий": ["функциклирующий"],
    "функция": ["назначение", "предназначение", "обязанность", "роль", "миссия", "зависимость"],
    "фунт": ["фунт стерлингов"],
    "фунт стерлингов": ["фунт"],
    "фунтовик": ["гиря"],
    "фунфырик": ["фанфурик", "фунфырёк"],
    "фунциклировав": ["фунциклировавши"],
    "фунциклировавши": ["фунциклировав"],
    "фунциклировать": ["функционировать", "пахать"],
    "фунчоза": ["стеклянная лапша"],
    "фура": ["телега", "фургон"],
    "фураж": ["корм"],
    "фуражировав": ["фуражировавши"],
    "фуражировавши": ["фуражировав"],
    "фуражировка": ["фуражирование"],
    "фуражка": ["фура", "бескозырка"],
    "фуран": ["фурфуран"],
    "фуранидин": ["тетрагидрофуран"],
    "фуранокумарин": ["фурокумарин"],
    "фурацилин": ["нитрофурал"],
    "фургалак": ["фургалоид"],
    "фургалить": ["кормить голубей"],
    "фургалоид": ["фургалак"],
    "фургальский": ["фургаловский"],
    "фурильщик": ["подфурник", "старинщик"],
    "фурия": ["эриния", "эринния"],
    "фурлонг": ["фарлонг"],
    "фурманка": ["фура", "фургон", "фурманок", "вагон", "бричка"],
    "фурманщик": ["фурман"],
    "фурнир": ["шпон", "фанера"],
    "фурнировать": ["снабжать", "обеспечивать", "покрывать", "плакировать"],
    "фурниссёр": ["поставщик"],
    "фуронгский": ["верхнекембрийский"],
    "фурор": ["ажиотаж", "триумф", "бум"],
    "фурри": ["фёрри", "фурдом", "фурри-сообщество"],
    "фурри-арт": ["пушистое", "искусство"],
    "фуррик": ["фуррь", "пушистик"],
    "фуррь": ["фурь", "пушистик", "фуррик", "фурфаг"],
    "фуррятник": ["фурдом", "фурри-сообщество", "фурри"],
    "фуррёвый": ["пушистый"],
    "фурункул": ["чирей"],
    "фурфуран": ["фуран"],
    "фурца": ["фырча"],
    "фурчав": ["фурчавши"],
    "фурчавши": ["фурчав"],
    "фуршет": ["а-ля фуршет", "аляфуршет", "банкет"],
    "фурщик": ["дальнобойщик", "фурман", "чумак", "солевозец"],
    "фурыкав": ["фурыкавши"],
    "фурыкавши": ["фурыкав"],
    "фурыкать": ["фурычить"],
    "фурындав": ["фурындавши"],
    "фурындавши": ["фурындав"],
    "фурындать": ["фурскать"],
    "фурычив": ["фурычивши"],
    "фурычивши": ["фурычив"],
    "фурычить": ["фурыкать"],
    "фут-фетишизм": ["фут-фетиш"],
    "футаж": ["футажный номер"],
    "футбайк": ["велосамокат", "кикбайк"],
    "футбик": ["футбол"],
    "футбол": ["соккер", "футбик", "ногомяч"],
    "футболив": ["футболивши"],
    "футболивши": ["футболив"],
    "футболист": ["футболист-профессионал"],
    "футболка": ["майка"],
    "футер": ["французский трикотаж"],
    "футеровав": ["футеровавши"],
    "футеровавши": ["футеровав"],
    "футерование": ["футеровка"],
    "футляр": ["чехол", "ящик"],
    "футуристически": ["футуристски"],
    "футуристический": ["футуристский"],
    "футуристично": ["футуристски", "футуристически"],
    "футурум": ["будущее время"],
    "фуфел": ["фуфло", "фальшак", "новодел"],
    "фуфло": ["фигня", "туфта", "надувательство", "лгун", "лжец", "врун", "дрянь", "гадость", "пакость"],
    "фуфлогон": ["болтун", "лгун", "обманщик"],
    "фуфломицин": ["фуфлоферон", "плацебо"],
    "фух": ["фу"],
    "фф": ["фианна файл", "физическая форма", "фанфик", "факфикшн"],
    "фх": ["ферма"],
    "фчёк": ["вчёк"],
    "фырк": ["фыркание", "фырканье"],
    "фыркав": ["фыркавши"],
    "фыркавши": ["фыркав"],
    "фыркание": ["фырчание"],
    "фыркнув": ["фыркнувши"],
    "фыркнувши": ["фыркнув"],
    "фырнув": ["фырнувши"],
    "фырнувши": ["фырнув"],
    "фырок": ["чих"],
    "фырча": ["фурца"],
    "фырчав": ["фырчавши"],
    "фырчавши": ["фырчав"],
    "фьельд": ["фиельд"],
    "фью": ["фьють", "фюйть", "фю", "ничего себе", "тю-тю", "ищи-свищи", "как ветром сдуло"],
    "фьюкав": ["фьюкавши"],
    "фьюкавши": ["фьюкав"],
    "фьюминговав": ["фьюминговавши"],
    "фьюминговавши": ["фьюминговав"],
    "фьють": ["фюйть"],
    "фьючерс": ["фьючерсный контракт", "фьюч"],
    "фэйсбук": ["фейсбук"],
    "фэйсинг": ["фейсинг"],
    "фэн": ["болельщик", "фанат", "поклонник", "любитель", "фан"],
    "фэндом": ["фандом"],
    "фэнтезятина": ["фэнтэзятина"],
    "фэр": ["рентген-эквивалент"],
    "фэтбайк": ["фатбайк"],
    "фэтшейминг": ["фэтфобия"],
    "фээргэвский": ["эфэргэвский"],
    "фээргэшный": ["эфэргэшный"],
    "фээсбэшник": ["эфэсбэшник"],
    "фээсбэшный": ["эфэсбэшный"],
    "фюзен": ["фюзинит"],
    "фюйть": ["фьють"],
    "фюльке": ["провинция", "губерния", "область"],
    "фюмизм": ["фумизм"],
    "фюрер": ["вождь", "фюрер и рейхсканцлер", "главарь", "правитель"],
    "фюрерство": ["вождизм"],
    "фюсис": ["физис", "фюзис"],
    "фютильность": ["пустота", "бессмысленность"],
    "фёдорович": ["фёдорыч"],
    "ха": ["харьков"],
    "ха-ха": ["хи-хи", "ха-ха-ха", "три ха-ха", "три раза ха-ха", "лол"],
    "хаапсалу": ["гапсаль"],
    "хаар": ["кхетам"],
    "хабад": ["хасидизм"],
    "хабазина": ["громада", "исполин", "громадина", "махина", "палка", "рожон", "жердь", "кол", "шест", "брус", "дубина", "дубинка"],
    "хабалив": ["хабаливши"],
    "хабаливши": ["хабалив"],
    "хабалистый": ["хабальный", "вздорный", "наглый", "бесцеремонный", "хамоватый"],
    "хабалка": ["хамка", "хабальница", "хабалда", "хабарка", "халда", "халдейка", "грубиянка", "нахалка", "нахалюга", "нахалюжница", "грымза", "шалава", "базарная баба"],
    "хабальничав": ["хабальничавши"],
    "хабальничавши": ["хабальничав"],
    "хабальничать": ["хабалить", "нахальничать", "хамить", "грубить", "грубиянить", "дерзить"],
    "хабальный": ["грубый", "пошлый", "наглый", "похабный"],
    "хабар": ["хабара", "взятка"],
    "хабара": ["взятка"],
    "хабарик": ["пятёра"],
    "хабарничество": ["взяточничество"],
    "хабаровский": ["хабарский", "хибаровский"],
    "хабаровский край": ["хк", "родина китов и самолётов"],
    "хаббоз": ["нонво"],
    "хабета": ["хаба", "шкапа"],
    "хабитус": ["габитус"],
    "хав-тайм": ["полупериод"],
    "хава": ["ворона"],
    "хавав": ["хававши"],
    "хававши": ["хавав"],
    "хавалка": ["столовая", "столовка", "тошниловка", "рыгаловка"],
    "хавальник": ["хайло", "рот"],
    "хаванина": ["еда", "пища", "продовольствие", "снедь", "яства", "жратва", "жрачка"],
    "хавать": ["жрать", "лопать", "трескать"],
    "хавать ртом и жопой": ["ртом и жопой хавать"],
    "хавающий": ["едящий", "жрущий", "лопающий"],
    "хавбек": ["полузащитник", "хав"],
    "хаврес": ["хаурес", "хаурас", "флаурос", "флорос"],
    "хавронья": ["хрюшка", "чушка", "грязнуля"],
    "хавф": ["тарс"],
    "хавчик": ["еда", "хавка", "жратва", "жрачка"],
    "хадак": ["хадаг", "хата"],
    "хадаль": ["хадопелагическая зона", "ультраабиссаль"],
    "хадж": ["паломничество"],
    "хадир": ["гъадир"],
    "хадьы": ["хады"],
    "хаер": ["хайр"],
    "хаживав": ["хаживавши"],
    "хаживавши": ["хаживав"],
    "хаживать": ["похаживать"],
    "хазар": ["хозар"],
    "хазария": ["хазарский каганат", "хозария"],
    "хазер": ["свинья"],
    "хазон": ["хазонрез"],
    "хазяйка": ["господиня"],
    "хазяйство": ["господарство"],
    "хай": ["бенц", "скандал", "буза", "бесчинство", "крик", "потасовка", "тарарам", "буча", "дебош", "драка", "шум"],
    "хай-тек": ["высокие технологии"],
    "хайвей": ["шоссе", "автострада"],
    "хайдокать": ["ухайдокивать"],
    "хайкинг": ["пешеходный туризм", "пеший туризм"],
    "хайку": ["хокку"],
    "хайлайтер": ["сиялочка"],
    "хайлив": ["хайливши"],
    "хайливши": ["хайлив"],
    "хайло": ["поддувало", "горло", "глотка", "рыло", "варежка", "хлебальник", "хавальник"],
    "хайп": ["шумиха", "суета", "ажиотаж"],
    "хайпанув": ["хайпанувши"],
    "хайпанувши": ["хайпанув"],
    "хайпануть": ["раздуть", "простимулировать"],
    "хайпив": ["хайпивши"],
    "хайпивши": ["хайпив"],
    "хайпить": ["раздувать", "пускать пыль в глаза"],
    "хайповав": ["хайповавши"],
    "хайповавши": ["хайповав"],
    "хайповать": ["хайпить"],
    "хайпово": ["ажиотажно", "модно"],
    "хайр": ["хаер"],
    "хайркунанда": ["карим"],
    "хайтек": ["высокие технологии"],
    "хак": ["костыль", "клудж", "взломщик", "кряк", "таблетка"],
    "хакав": ["хакавши"],
    "хакавши": ["хакав"],
    "хакамор": ["недоуздок", "недоумлок", "оброть", "обротка", "хакамора"],
    "хакасия": ["республика хакасия", "рх"],
    "хакассец": ["хакас"],
    "хакасский язык": ["хакасский"],
    "хакать": ["ломать", "взламывать"],
    "хаккари": ["хаккяри"],
    "хакнув": ["хакнувши"],
    "хакнувши": ["хакнув"],
    "хакнуть": ["взломать"],
    "хакта": ["турында", "турысында", "хакында"],
    "хакында": ["турында", "турысында", "хакта"],
    "хала": ["халла"],
    "халабуда": ["хибара", "лачуга"],
    "халадо": ["рай", "барэдыр"],
    "халазион": ["халязион", "градина"],
    "халас": ["халаш"],
    "халатничав": ["халатничавши"],
    "халатничавши": ["халатничав"],
    "халатно": ["спустя рукава", "наплевательски", "безответственно"],
    "халатный": ["халтурный", "недобросовестный", "наплевательский", "спокойный", "ленивый", "неповоротливый"],
    "халаш": ["халас"],
    "халдей": ["пройдоха", "лизоблюд", "официант", "бармен", "трактирщик", "халдей иванович", "трактирный слуга", "половой", "человек", "гарсон", "звездочёт"],
    "халдейство": ["шутовство", "кривляние", "угодничество", "подобострастие", "приспособленчество"],
    "халдеополь": ["камарина"],
    "халди": ["халды"],
    "халеб": ["алеппо"],
    "халебец": ["алеппец", "алеппинец"],
    "халебский": ["алеппский"],
    "халинный": ["галинный"],
    "халит": ["омехта"],
    "халиф": ["калиф"],
    "халиф на час": ["временщик", "свадебный боярин", "свадебный генерал"],
    "халифат": ["калифат"],
    "халкедон": ["халкидон"],
    "халкида": ["халкидон"],
    "халкидон": ["халкедон", "калхедон", "халкида"],
    "халколит": ["энеолит"],
    "халоскунанда": ["халосгар"],
    "халосшуда": ["растагор"],
    "халтура": ["подработка", "приработок", "шабашка"],
    "халтурив": ["халтуривши"],
    "халтуривши": ["халтурив"],
    "халтурить": ["небрежничать", "подрабатывать", "подхалтуривать", "шабашничать"],
    "халтурка": ["приработок"],
    "халтурно": ["небрежно", "недобросовестно"],
    "халтурный": ["небрежный", "недобросовестный"],
    "халтурщик": ["портач", "мастер-ломастер", "кое-какер"],
    "халуга": ["плетень"],
    "халупа": ["хибара", "лачуга", "конура"],
    "халх гол": ["халхын гол"],
    "халцедон": ["халкидон", "моховик", "моховой камень"],
    "халькопирит": ["гомихлин", "медный колчедан", "медная руда", "торванит"],
    "халява": ["холявка"],
    "халявив": ["халявивши"],
    "халявивши": ["халявив"],
    "халявить": ["отлынивать", "сачковать", "филонить", "халтурить"],
    "халявный": ["бесплатный", "даровой", "дармовой", "безвозмездный", "безмездный"],
    "халявщик": ["дармоед", "тунеядец"],
    "халязион": ["халазион", "градина"],
    "халяльный": ["дозволенный"],
    "хам": ["невежа", "хамло", "быдло"],
    "хам шудан": ["хамидан"],
    "хамада": ["гамада"],
    "хамев": ["хамевши"],
    "хамевши": ["хамев"],
    "хамелеонствовав": ["хамелеонствовавши"],
    "хамелеонствовавши": ["хамелеонствовав"],
    "хамериния": ["широконосость"],
    "хамив": ["хамивши"],
    "хамивши": ["хамив"],
    "хамила": ["хам", "хамка", "хамло"],
    "хамить": ["грубиянить", "говорить дерзости", "дерзить", "говорить грубости", "грубить"],
    "хамка": ["грубиянка", "нахалка"],
    "хамло": ["хам"],
    "хаммам": ["турецкая баня"],
    "хаммом": ["гармоба"],
    "хамоватый": ["наглый"],
    "хамон": ["ветчина"],
    "хамос": ["кемош"],
    "хамса": ["камса", "европейский анчоус", "черноморский анчоус"],
    "хамски": ["по-хамски"],
    "хамство": ["неотёсанность", "беспардонность", "невежливость", "мужиковатость", "скотство", "наглость", "грубость", "резкость", "грубиянство"],
    "хамёж": ["хамство"],
    "хан-атлас": ["икат"],
    "хана": ["каюк", "капут", "кранты", "крышка", "кирдык", "капец", "пипец", "ппц", "пиздец"],
    "хангыль": ["онмун", "чосонгыль", "корёгыль"],
    "ханджин": ["ханчин", "ханчина", "ханшин", "ханшина", "ханжина", "ханьжина", "ханджа", "ханжа", "ханьжа", "ханка", "хана", "байцзю"],
    "хандра": ["сплин", "тоска", "уныние", "скука", "ипохондрия"],
    "хандрив": ["хандривши"],
    "хандривши": ["хандрив"],
    "хандрить": ["унывать", "болеть"],
    "хандрящий": ["унылый"],
    "ханец": ["хань", "китаец"],
    "ханжа": ["девот", "девотка", "ипокрит", "ипокритка", "иудушка", "лицемер", "лицемерка", "пустосвят", "пустосвятка", "суесвят", "фарисей", "фарисейка", "филистер", "святоша", "волк в овечьей шкуре"],
    "ханжеский": ["фарисейский"],
    "ханжество": ["фарисейство", "пустосвятство", "суесвятство", "девотство", "святошество"],
    "ханжествовав": ["ханжествовавши"],
    "ханжествовавши": ["ханжествовав"],
    "ханжествовать": ["ханжить", "девотствовать"],
    "ханжив": ["ханживши"],
    "ханживши": ["ханжив"],
    "ханжить": ["девотствовать"],
    "ханка": ["опий-сырец"],
    "ханкенди": ["степанакерт", "вараракн"],
    "ханкин": ["ханкюнь"],
    "ханкюнь": ["ханкин"],
    "ханлык": ["ханлых"],
    "ханна": ["анна", "ганна"],
    "ханой": ["тханглонг", "донгдо", "донгкуан", "донгкинь", "бактхань"],
    "хант": ["хантыец", "остяк"],
    "ханты-мансийский автономный округ": ["хмао", "югра"],
    "ханукия": ["менора"],
    "ханурик": ["хиляк", "слабак", "дистрофик", "дрыщ", "анорексик"],
    "ханчин": ["ханчина", "ханшин", "ханшина", "ханжина", "ханьжина", "ханджа", "ханжа", "ханьжа", "ханка", "хана", "байцзю"],
    "ханшин": ["ханшина", "ханчин", "ханджа", "ханжа", "ханка", "хана", "байцзю"],
    "ханшина": ["ханшин", "ханчин", "ханчина", "ханджин", "ханжина", "ханьжина", "ханджа", "ханжа", "хана", "байцзю"],
    "ханыга": ["чмошник", "попрошайка"],
    "ханыжничав": ["ханыжничавши"],
    "ханыжничавши": ["ханыжничав"],
    "хань": ["ханьшуй", "ханьцзян"],
    "ханьжа": ["ханшин", "ханшина", "ханчин", "ханчина", "ханжина", "ханьжина", "ханджин", "хана", "байцзю", "самогон", "брага", "ханджа", "ханжа", "ханька", "ханка"],
    "ханьский": ["китайский"],
    "ханьцзы": ["китайский", "иероглиф"],
    "ханьцзян": ["ханьшуй"],
    "ханьшуй": ["ханьцзян"],
    "ханёнок": ["ханыч"],
    "хаос": ["беспорядок"],
    "хаотизировав": ["хаотизировавши"],
    "хаотизировавши": ["хаотизировав"],
    "хаотически": ["хаотично"],
    "хаотический": ["хаотичный"],
    "хаотично": ["беспорядочно", "хаотически"],
    "хаотичный": ["хаотический"],
    "хап": ["хвать", "цап"],
    "хапав": ["хапавши"],
    "хапавши": ["хапав"],
    "хапанув": ["хапанувши"],
    "хапанувши": ["хапанув"],
    "хапанцы": ["взятка", "хабар", "хабара", "куш", "подарок", "благодарность", "мзда", "подкуп", "посул", "бакшиш", "халтура", "нелегальный доход", "побочный доход", "барашек в бумажке"],
    "хапанье": ["хапание"],
    "хапать": ["хватать"],
    "хапка": ["напас"],
    "хапльо": ["глупак", "будала", "ахмак", "абдал", "зяпльо", "серсем"],
    "хапнув": ["хапнувши"],
    "хапнувши": ["хапнув"],
    "хапнуть": ["хватануть", "цапнуть", "куснуть"],
    "хаптай": ["ичэримни"],
    "хапуга": ["взяточник", "взяточница", "мздоимец", "хапун", "хапунья"],
    "хапужничав": ["хапужничавши"],
    "хапужничавши": ["хапужничав"],
    "хапужничать": ["хапать"],
    "хапужничество": ["взяточничество", "мздоимство", "лихоимство", "рвачество"],
    "хапун": ["взяточник", "лихоимец", "мздоимец", "мздолюбец", "алтынник", "хапала", "хапуга"],
    "хар": ["верамин"],
    "харак": ["нимкат"],
    "харакири": ["сэппуку"],
    "характеризовав": ["характеризовавши"],
    "характеризовавши": ["характеризовав"],
    "характеристика": ["портрет", "описание", "досье", "функция", "зависимость", "корреляция", "параметр"],
    "характеристичный": ["свойственный", "характерный", "присущий", "отличный", "отличительный", "определённый", "индивидуальный", "специфический", "специфичный", "сродный", "неповторимый", "казусный", "самородный", "типичный"],
    "характерник": ["чаклун"],
    "характерно": ["специфически"],
    "характерный": ["типичный", "свойственный", "специфический"],
    "характерство": ["волхвование", "колдовство", "ворожение"],
    "харалуг": ["булат", "дамаск"],
    "харалужний": ["сталевий", "стальний"],
    "харамдаг": ["бердышка"],
    "харамия": ["разбойник", "хайдутин", "бунтовник"],
    "харамный": ["недозволенный"],
    "хараре": ["солсбери"],
    "харари": ["адари"],
    "харассив": ["харассивши"],
    "харассивши": ["харассив"],
    "харассмент": ["домогательство", "приставание"],
    "харатья": ["хартия"],
    "харвестер": ["лесозаготовительный комбайн"],
    "харви": ["гарвей"],
    "хард-порно": ["хардкор"],
    "хардвер": ["аппаратное обеспечение", "железо"],
    "хардкор": ["хард-кор", "хардкор-панк", "жёсткое порно"],
    "хардкорный": ["трудоёмкий"],
    "харе": ["хватит", "довольно", "достаточно", "будет", "полно", "стоп", "хорош"],
    "харив": ["харивши"],
    "харивши": ["харив"],
    "харизма": ["исключительность", "мощь", "сила", "энергетика", "яркость", "обаяние", "дар"],
    "харизматичный": ["притягательный"],
    "харио": ["дриппер", "пуровер"],
    "харкав": ["харкавши"],
    "харкавши": ["харкав"],
    "харкаться": ["сплёвывать"],
    "харкнув": ["харкнувши"],
    "харкнувши": ["харкнув"],
    "харкнуть": ["плюнуть"],
    "харкотина": ["хархотина", "харча"],
    "харлам": ["харлампий"],
    "харсанг": ["шух", "сахра"],
    "хартия": ["харатья", "манускрипт", "папирус", "декларация"],
    "хару": ["кловахарун", "кловхару"],
    "харциз": ["харциза", "харцизник"],
    "харциза": ["харциз"],
    "харцизяка": ["харциз", "харциза", "харцизник"],
    "харчевав": ["харчевавши"],
    "харчевавши": ["харчевав"],
    "харчевание": ["питание"],
    "харчевать": ["кормить", "есть", "питаться", "кормиться"],
    "харчеваться": ["харчиться"],
    "харчевничав": ["харчевничавши"],
    "харчевничавши": ["харчевничав"],
    "харчевня": ["трактир"],
    "харчив": ["харчивши"],
    "харчивши": ["харчив"],
    "харчок": ["плевок", "плювок", "сопля", "слюна", "сморчок"],
    "харьков": ["ха"],
    "харьковец": ["харьковчанин"],
    "харьковская народная республика": ["хнр"],
    "харьковская область": ["харьковщина"],
    "харьковчанин": ["харьковец"],
    "харьковщина": ["харьковская область"],
    "хасавюрт": ["хасу-эвл", "хасав"],
    "хасаг": ["казах"],
    "хасан": ["хассан"],
    "хасидизм": ["хасидство"],
    "хасидство": ["хасидизм"],
    "хасм": ["душман"],
    "хассан": ["хасса", "хасан", "хас"],
    "хастах": ["туора-урях", "халкан", "калкан"],
    "хата": ["хатка", "жилище"],
    "хатасу": ["хатшепсут"],
    "хатина": ["хата"],
    "хатняе заданне": ["хатняя праца"],
    "хатор": ["гатор", "хатхор"],
    "хатхор": ["хатор", "гатор"],
    "хатын-кыз": ["хатын", "кыз-хатын"],
    "хаус-рэп": ["рэп-хаус", "хип-хаус"],
    "хафпайп": ["пайп", "рампа"],
    "хаффош": ["муши паррон", "шабпарак", "ватвот"],
    "хах": ["хех"],
    "хахаль": ["ухажёр", "любовник"],
    "хаханьки": ["хиханьки", "хихоньки да хахоньки", "смехуёчки", "пиздохаханьки", "пиздохахоньки", "смехуёчки да пиздохаханьки", "смехуёчки да пиздохахоньки"],
    "хахоньки": ["хихоньки"],
    "хацапетовка": ["углегорск"],
    "хацкер": ["кулхацкер"],
    "хач": ["хачик", "черномазый"],
    "хачик": ["кавказец", "чучмек", "чёрный", "чурбан", "хач", "чурка"],
    "хашаб": ["тахта"],
    "хашури": ["михайлово", "сталиниси"],
    "хаяв": ["хаявши"],
    "хаявши": ["хаяв"],
    "хаять": ["порочить", "ругать", "хулить", "охаивать"],
    "хаях": ["гээх"],
    "хаёл": ["орзу", "фикр", "тафаккур"],
    "хаёлот": ["хаёл", "фикр"],
    "хбм": ["хбмка"],
    "хвала": ["прославление", "восхваление", "славословие", "похвала", "одобрение", "слава"],
    "хвалба": ["похвала"],
    "хвалебник": ["хвалитель"],
    "хваленье": ["хваление"],
    "хвалив": ["хваливши"],
    "хваливав": ["хваливавши"],
    "хваливавши": ["хваливав"],
    "хваливши": ["хвалив"],
    "хвалительный": ["хвалебный"],
    "хвалить": ["одобрять", "льстить"],
    "хвалиться": ["хвастаться", "хвастать", "бахвалиться"],
    "хварывав": ["хварывавши"],
    "хварывавши": ["хварывав"],
    "хвастав": ["хваставши"],
    "хваставши": ["хвастав"],
    "хвастанув": ["хвастанувши"],
    "хвастанувши": ["хвастанув"],
    "хвастать": ["хвастаться", "хвалиться", "бахвалиться", "самохвальствовать", "похваляться"],
    "хвастаться": ["хвастать", "хвалиться", "бахвалиться"],
    "хвастающийся": ["бахвалящийся"],
    "хвастливий": ["хвалькуватий", "хвальковитий"],
    "хвастливость": ["хвастовство", "бахвальство"],
    "хвастнув": ["хвастнувши"],
    "хвастнувши": ["хвастнув"],
    "хвастнуть": ["хвастануть", "прихвастнуть"],
    "хвастовство": ["бахвальство", "самохвальство"],
    "хвастун": ["самохвал"],
    "хват": ["храбрец", "удалец", "лихач", "ухарь"],
    "хватав": ["хватавши"],
    "хватавши": ["хватав"],
    "хватанув": ["хватанувши"],
    "хватанувши": ["хватанув"],
    "хватануть": ["схватить"],
    "хватанье": ["хватание"],
    "хватать": ["заграбастывать", "схватывать"],
    "хватив": ["хвативши"],
    "хвативши": ["хватив"],
    "хватит": ["довольно", "достаточно", "хорош", "полно", "будет", "харэ"],
    "хватить": ["достаточно"],
    "хваткий": ["ловкий", "цепкий", "восприимчивый"],
    "хватко": ["цепко"],
    "хваткость": ["цепкость", "хватка", "смышлёность"],
    "хватнув": ["хватнувши"],
    "хватнувши": ["хватнув"],
    "хватывав": ["хватывавши"],
    "хватывавши": ["хватывав"],
    "хвоив": ["хвоивши"],
    "хвоивши": ["хвоив"],
    "хвой": ["хвоя", "лапник"],
    "хвойник": ["эфедра"],
    "хвойный лес": ["краснолесье", "красный лес"],
    "хворав": ["хворавши"],
    "хворавши": ["хворав"],
    "хворать": ["болеть", "недомогать"],
    "хвораться": ["нездоровиться"],
    "хвороба": ["хворость", "болезнь", "хворь", "нездоровье"],
    "хворый": ["больной", "нездоровый"],
    "хворь": ["болезнь", "недомогание", "нездоровье", "недуг", "хвороба"],
    "хвостав": ["хвоставши"],
    "хвоставши": ["хвостав"],
    "хвостастый": ["хвостатый"],
    "хвостокол": ["морской кот"],
    "хвоя": ["лапник"],
    "хе": ["ха"],
    "хеб": ["эгер"],
    "хебат": ["вурунсему"],
    "хевея": ["гевея"],
    "хеви": ["хеви-метал", "хэви-метал", "хэви"],
    "хеви-метал": ["хеви-метал-рок", "хеви", "хэви-метал", "хэви"],
    "хевра": ["шайка", "кодла", "шайка-лейка"],
    "хеврон": ["эль-халиль"],
    "хевсурети": ["хевсуретия", "хевсурия"],
    "хедвиг": ["гедвига", "хедвига", "ядвига"],
    "хедж": ["хеджирование"],
    "хеджировав": ["хеджировавши"],
    "хеджировавши": ["хеджировав"],
    "хедлайнер": ["гвоздь программы", "звезда", "заводила"],
    "хезав": ["хезавши"],
    "хезавши": ["хезав"],
    "хезать": ["испражняться", "бояться", "трусить"],
    "хезболла": ["хезболлах", "хизбалла", "хизбаллах"],
    "хейвуд": ["вуди"],
    "хейдарабад": ["хайдарабад"],
    "хейлетиеллёз": ["хейлетиоз"],
    "хейлоз": ["хейлит"],
    "хейт": ["неприязнь"],
    "хейтер": ["антифанат", "ненавистник", "хулитель"],
    "хейтив": ["хейтивши"],
    "хейтивши": ["хейтив"],
    "хейтить": ["ругать", "охаивать", "поносить"],
    "хекав": ["хекавши"],
    "хекавши": ["хекав"],
    "хекимин": ["лекар", "врач", "знахар", "доктор"],
    "хекнув": ["хекнувши"],
    "хекнувши": ["хекнув"],
    "хеликаза": ["геликаза"],
    "хеликобактер": ["хеликобактерия"],
    "хеликоптер": ["въртолет"],
    "хелипорт": ["вертодром", "гелипорт"],
    "хелиски": ["хелискиинг"],
    "хелоид": ["хелоидная микросклера"],
    "хелпанув": ["хелпанувши"],
    "хелпанувши": ["хелпанув"],
    "хелпануть": ["помочь"],
    "хель": ["нифльхель"],
    "хелькур": ["светоотражатель"],
    "хельмут": ["гельмут"],
    "хельсинки": ["гельсингфорс"],
    "хемилюминесценция": ["хемолюминесценция"],
    "хемолюминесценция": ["хемилюминесценция"],
    "хеморезистентность": ["хемотолерантность", "хемоустойчивость", "химиорезистентность"],
    "хеморезистентный": ["хемотолерантный"],
    "хемотаксономия": ["хемосистематика"],
    "хемотолерантность": ["хемоустойчивость", "хеморезистентность"],
    "хемотолерантный": ["хеморезистентный"],
    "хемотронный": ["химотронный"],
    "хемотропизм": ["хемотаксис"],
    "хемочувствительность": ["хеморецепция"],
    "хенд": ["рука"],
    "хенд-мейд": ["рукоделие", "поделка"],
    "хендаут": ["раздатка"],
    "хенде-хох": ["руки вверх"],
    "хендмейд": ["рукоделие", "поделка"],
    "хеопс": ["хуфу"],
    "хепри": ["хепера"],
    "хер": ["перечёркивание"],
    "херачив": ["херачивши"],
    "херачивши": ["херачив"],
    "херачить": ["тащиться", "идти", "волочиться"],
    "херив": ["херивши"],
    "херивши": ["херив"],
    "херить": ["перечёркивать", "зачёркивать", "вычёркивать"],
    "хермон": ["ермон"],
    "херня": ["дрянь", "хрень", "фигня", "пустяк", "ерунда", "чушь", "бздёж", "хреновина", "фиговина"],
    "херов": ["хреновый"],
    "херовничав": ["херовничавши"],
    "херовничавши": ["херовничав"],
    "херово": ["хреново"],
    "херовый": ["хреновый"],
    "херонеи": ["херонея", "хероней"],
    "хероней": ["херонеи", "херонея"],
    "херонея": ["херонеи", "хероней", "арна"],
    "херота": ["херня", "вздор", "чушь"],
    "херсонская область": ["херсонщина"],
    "херувимский": ["ангельский"],
    "херувимчик": ["ангелочек"],
    "херь": ["хрень", "херня"],
    "хесус": ["сусо"],
    "хетогнат": ["щетинкочелюстные"],
    "хетт": ["хеттей", "хеттеянин"],
    "хеттский язык": ["хеттский"],
    "хех": ["хе", "ха"],
    "хеш-сумма": ["хеш", "хеш-код", "дайджест"],
    "хешировав": ["хешировавши"],
    "хешировавши": ["хешировав"],
    "хи": ["хи-хи", "хи-хи-хи"],
    "хи-хи": ["хихи"],
    "хиатус": ["гиатус", "зияние", "разрыв", "различие", "дистанция", "расстояние", "пропасть"],
    "хибара": ["лачуга", "хижина", "халупа", "халабуда", "развалюха", "дыра", "бомжатник", "клоповник"],
    "хибарка": ["лачужка"],
    "хибати": ["хибачи"],
    "хибувати": ["мати хиби", "бракувати"],
    "хиджаб": ["платок"],
    "хиджаз": ["геджас"],
    "хижина": ["лачуга", "конура", "избушка"],
    "хикикомори": ["хикки", "хикка", "хиккан", "домосед"],
    "хикка": ["хикки"],
    "хиккан": ["хикикомори", "хикка", "хикки"],
    "хикки": ["хикка", "хиккан"],
    "хилеав": ["килеаб"],
    "хилев": ["хилевши"],
    "хилевши": ["хилев"],
    "хилер": ["целитель", "врачеватель", "врач", "лекарь", "доктор"],
    "хилерство": ["целительство"],
    "хилиазм": ["милленаризм"],
    "хилив": ["хиливши"],
    "хиливши": ["хилив"],
    "хилить": ["раздуваться", "силиться", "усиливаться", "наполняться", "сильнеть", "здороветь"],
    "хилка": ["лечилка"],
    "хилурия": ["галактурия", "лактацидурия", "лимфурия"],
    "хилый": ["слабый", "слабосильный", "немощный", "тщедушный", "ветхий", "непрочный"],
    "хиль": ["хворь"],
    "хиляв": ["хилявши"],
    "хилявши": ["хиляв"],
    "хиляк": ["дрищ"],
    "хилять": ["идти", "двигаться", "выдвигаться", "уходить", "выдавать", "говорить", "походить", "подходить"],
    "химера": ["фантазия", "фантасмагория", "иллюзия", "мираж", "горгулья", "рекомбинант"],
    "химеризм": ["тетрагаметизм"],
    "химерический": ["химеричный"],
    "химеричный": ["химерический"],
    "химерный": ["химерический", "химеричный"],
    "химизировав": ["химизировавши"],
    "химизировавши": ["химизировав"],
    "химикалия": ["химикат"],
    "химикат": ["химикалии"],
    "химическая нить": ["химическое волокно"],
    "химическая чистка": ["химчистка"],
    "химический символ": ["химический знак"],
    "химическое волокно": ["химическая нить"],
    "химичив": ["химичивши"],
    "химичивши": ["химичив"],
    "химичка": ["химица"],
    "химия": ["химикат", "отрава", "химическая завивка", "перманент", "флюид", "уловка", "ухищрение", "хитрость", "трюк", "фокус", "жульничество", "обман", "плутовство", "исправительные работы", "допинг"],
    "химки": ["химари"],
    "химозин": ["реннин", "лабфермент"],
    "химчанин": ["химкинец"],
    "химчистка": ["химическая чистка"],
    "хина": ["хинное дерево", "цинхона"],
    "хинзир": ["хук"],
    "хинин": ["хина", "хинина"],
    "хиноксалин": ["бензопирарин"],
    "хинт": ["подсказка"],
    "хинтование": ["хинтовка"],
    "хинтовка": ["хинтование"],
    "хиония": ["хиона"],
    "хионофил": ["хионофит", "снеголюб"],
    "хип": ["хиппарь", "хиппи"],
    "хип-хопер": ["рэпер", "рэп-исполнитель", "эмси"],
    "хипопотам": ["речен кон"],
    "хиппарь": ["хипарь", "хиппан", "хиппи"],
    "хиппи": ["система", "хипарь", "хиппарь", "хиппан"],
    "хипповав": ["хипповавши"],
    "хипповавши": ["хипповав"],
    "хирадманд": ["доно", "донишманд"],
    "хиральность": ["киральность"],
    "хиральный": ["асимметричный"],
    "хирд": ["гирд"],
    "хирев": ["хиревши"],
    "хиревши": ["хирев"],
    "хиреть": ["чахнуть", "ослабевать", "загибаться", "угасать"],
    "хирний": ["хирявий"],
    "хиромант": ["хиромантик"],
    "хиромантик": ["хиромант"],
    "хирономида": ["комар-звонец"],
    "хиропрактик": ["мануальный терапевт"],
    "хиросима": ["ядерная война"],
    "хиротонисав": ["хиротонисавши"],
    "хиротонисавши": ["хиротонисав"],
    "хиротонисать": ["рукополагать"],
    "хиротония": ["голосование", "рукоположение", "ординация", "поставление"],
    "хирофесия": ["рукоположение", "хиротесия"],
    "хирург": ["оператор"],
    "хирург-ортопед": ["ортопед-хирург"],
    "хирургическая операция": ["хирургическое вмешательство", "оперативное вмешательство"],
    "хирявий": ["хиренний", "хирий"],
    "хит": ["шлягер", "бестселлер", "клик", "просмотр"],
    "хит-парад": ["чарт", "парад популярности"],
    "хитати": ["хитачи"],
    "хитачи": ["хитати"],
    "хитбокс": ["коллайдер"],
    "хитив": ["хитивши"],
    "хитивши": ["хитив"],
    "хитинный": ["хитиновый"],
    "хитиновый": ["хитинный"],
    "хитлер": ["гитлер"],
    "хитовав": ["хитовавши"],
    "хитовавши": ["хитовав"],
    "хитовость": ["популярность"],
    "хитон": ["хламида", "власяница"],
    "хитрев": ["хитревши"],
    "хитревши": ["хитрев"],
    "хитренький": ["хитрый"],
    "хитрец": ["ловчила", "плут", "пройдоха", "искусник", "ловкач"],
    "хитреца": ["хитринка"],
    "хитрив": ["хитривши"],
    "хитривши": ["хитрив"],
    "хитрий": ["лукавий"],
    "хитрик": ["хитрун"],
    "хитринка": ["хитреца"],
    "хитрить": ["лукавить", "темнить", "плутовать", "ловчить", "мудрить"],
    "хитровав": ["хитровавши"],
    "хитровавши": ["хитровав"],
    "хитрован": ["хитрец", "хитрюга", "ловкач", "проныра", "бестия", "мошенник", "обманщик", "плут", "пройдоха", "прощелыга", "хитрожопый"],
    "хитроватый": ["хитровастый", "хитроватенький", "хитровастенький"],
    "хитровыебанность": ["лживость", "эгоистичность", "наглость", "своекорыстие", "своекорыстность", "скользкость", "скрытность", "ушлость", "хитромудрость", "хитрозадость", "хитропопость", "хитромудость", "хитрожопость", "хитрожопистость"],
    "хитровыебанный": ["сложный", "непростой", "тяжёлый", "работа", "усложнённый", "заковыристый", "навороченный", "хитросделанный", "хитрый", "лживый", "эгоистичный", "наглый", "своекорыстный", "скользкий", "скрытный"],
    "хитрожопый": ["хитрый", "ушлый", "подлый", "хитрожопистый", "коварный", "дошлый", "себе на уме", "пронырливый", "оборотливый", "хитроватый", "с хитринкой", "с хитрецой", "пройдошливый", "продувной", "хваткий"],
    "хитросплетение": ["спутанность", "уловка", "интрига", "сеть лжи"],
    "хитросплетенье": ["хитросплетение"],
    "хитростный": ["замысловатый", "мудрёный", "хитроумный", "изобретательный", "выдумщицкий"],
    "хитрость": ["хитрушка"],
    "хитроумный": ["хитрый", "плутоватый", "лукавый"],
    "хитроумье": ["хитроумие"],
    "хитрый": ["лукавый", "хитроумный", "плутоватый", "ушлый", "изобретательный", "искусный", "ловкий", "замысловатый", "затейливый", "сложный"],
    "хитрюга": ["хитрец", "хитяра"],
    "хиус": ["северяк", "хыян"],
    "хиханьки": ["хаханьки"],
    "хихикав": ["хихикавши"],
    "хихикавши": ["хихикав"],
    "хихикнув": ["хихикнувши"],
    "хихикнувши": ["хихикнув"],
    "хихоньки": ["хаханьки"],
    "хичхайкер": ["стопер", "автостопер"],
    "хищение": ["хищенье"],
    "хищенье": ["хищение"],
    "хищничав": ["хищничавши"],
    "хищничавши": ["хищничав"],
    "хищнически": ["хищно", "безжалостно", "по-грабительски"],
    "хищнический": ["грабительский"],
    "хищный": ["плотоядный", "корыстный"],
    "хиёр": ["бодиринг"],
    "хлад": ["холод"],
    "хладев": ["хладевши"],
    "хладевши": ["хладев"],
    "хладив": ["хладивши"],
    "хладивши": ["хладив"],
    "хладнокровие": ["хладнокровность", "холодность", "спокойствие", "апатичность", "апатия", "безучастность", "бесстрастность", "бесчувственность", "бесчувствие", "незаинтересованность", "нейтральность", "нечувствительность", "равнодушие", "сдержанность", "сухость"],
    "хладнокровно": ["спокойно"],
    "хладнокровность": ["хладнокровие"],
    "хладнокровный": ["спокойный", "невозмутимый", "холоднокровный"],
    "хладнокровье": ["хладнокровие"],
    "хладный": ["холодный"],
    "хладостойкий": ["холодостойкий", "морозоустойчивый"],
    "хладостойкость": ["холодостойкость"],
    "хлам": ["барахло", "рухлядь", "старьё"],
    "хламив": ["хламивши"],
    "хламивши": ["хламив"],
    "хламить": ["захламлять", "засорять", "замусоривать"],
    "хламьё": ["хлам"],
    "хлапак": ["хлапе", "момче", "младеж"],
    "хлеб": ["выпечка", "мандро", "рубан", "шибан", "булка", "батон", "буханка", "чёрный хлеб", "зерно", "зерновые", "злак", "пропитание"],
    "хлебав": ["хлебавши"],
    "хлебавши": ["хлебав"],
    "хлебало": ["зев", "пасть", "хайло", "похлёбка", "рот", "варежка", "едало", "хавальник", "хлебалка", "хлебальник", "хлебобранка", "хлеборезка", "лицо", "морда", "рыло"],
    "хлебальник": ["пасть", "варежка", "хайло"],
    "хлебанув": ["хлебанувши"],
    "хлебанувши": ["хлебанув"],
    "хлебарница": ["фурна"],
    "хлебенная": ["хлебопекарня", "хлебная", "хлебня"],
    "хлебенное": ["десерт", "третье блюдо", "пирожное", "печенье"],
    "хлебенный": ["хлебный"],
    "хлебец": ["галета", "сайка", "мясной хлеб"],
    "хлебная": ["хлебопекарня", "хлебенная", "хлебня"],
    "хлебник": ["хлебопёк", "булочник", "хлеботорговец"],
    "хлебница": ["хлебня", "хлебёнка"],
    "хлебничав": ["хлебничавши"],
    "хлебничавши": ["хлебничав"],
    "хлебное вино": ["водка", "самогон"],
    "хлебнув": ["хлебнувши"],
    "хлебнувши": ["хлебнув"],
    "хлебный": ["хлебенный"],
    "хлебня": ["хлебопекарня", "хлебенная", "хлебная"],
    "хлебовоз": ["хлебовозка"],
    "хлебовозка": ["хлебовоз"],
    "хлебозавод": ["хлебзавод"],
    "хлебок": ["глоток"],
    "хлебопахотный": ["хлебопашенный", "хлебопашный", "хлеборобный", "земледельный", "земледельческий"],
    "хлебопашенный": ["хлебопахотный", "хлебопашественный", "хлебопашный"],
    "хлебопашеский": ["хлеборобский"],
    "хлебопашество": ["земледелие", "землепашество", "хлеборобство", "агрокультура", "агрикультура"],
    "хлебопашествовав": ["хлебопашествовавши"],
    "хлебопашествовавши": ["хлебопашествовав"],
    "хлебопашец": ["хлебороб", "землепашец", "землероб", "пахарь", "изорник", "ратай", "оратай", "плугарь"],
    "хлебопашный": ["хлебопахотный", "хлебопашенный", "хлебопашественный"],
    "хлебопекарня": ["хлебенная", "хлебная", "хлебня"],
    "хлебопечка": ["хлебопечь"],
    "хлебопечь": ["хлебопечка"],
    "хлебопёк": ["пекарь", "хлебопекарь", "хлебопечец", "хлебник"],
    "хлеборез": ["хлеборезчик"],
    "хлеборезчик": ["хлеборез"],
    "хлебороб": ["хлебопашец"],
    "хлеборобствовав": ["хлеборобствовавши"],
    "хлеборобствовавши": ["хлеборобствовав"],
    "хлебородный": ["урожайный", "плодородный"],
    "хлебосольничав": ["хлебосольничавши"],
    "хлебосольничавши": ["хлебосольничав"],
    "хлебосольно": ["от души", "радушно"],
    "хлебосольный": ["радушный", "гостеприимный"],
    "хлебосольство": ["гостеприимство"],
    "хлебостой": ["урожай", "зерна"],
    "хлебоуборочный комбайн": ["зерноуборочный комбайн"],
    "хлебушек": ["хлеб", "хлебушко"],
    "хлев": ["авгиевы конюшни"],
    "хлеснув": ["хлеснувши"],
    "хлеснувши": ["хлеснув"],
    "хлестав": ["хлеставши"],
    "хлеставши": ["хлестав"],
    "хлестаковствовав": ["хлестаковствовавши"],
    "хлестаковствовавши": ["хлестаковствовав"],
    "хлестаковщина": ["похвальба", "бахвальство", "хвастовство", "фанфаронство", "самохвальство", "хвастанье", "фанфаронада"],
    "хлестанув": ["хлестанувши"],
    "хлестанувши": ["хлестанув"],
    "хлестануть": ["хлестнуть", "хлобыстнуть"],
    "хлестанье": ["хлестание"],
    "хлестать": ["стегать", "шлёпать", "бичевать"],
    "хлестаться в десну": ["биться в дёсны", "долбиться в дёсны", "шарахаться в десну"],
    "хлестнув": ["хлестнувши"],
    "хлестнувши": ["хлестнув"],
    "хлестнуть": ["хлестануть"],
    "хлестнуться": ["хлеснуться"],
    "хлесть": ["хлысть", "хлясть"],
    "хлипав": ["хлипавши"],
    "хлипавка": ["клапан", "хлипак"],
    "хлипавши": ["хлипав"],
    "хлипкий": ["непрочный", "хлябистый"],
    "хлипко": ["слабо", "хило"],
    "хлобучив": ["хлобучивши"],
    "хлобучивши": ["хлобучив"],
    "хлобыснув": ["хлобыснувши"],
    "хлобыснувши": ["хлобыснув"],
    "хлобыстав": ["хлобыставши"],
    "хлобыставши": ["хлобыстав"],
    "хлобыстать": ["хлестать"],
    "хлобыстнув": ["хлобыстнувши"],
    "хлобыстнувши": ["хлобыстнув"],
    "хлобыстнуть": ["хлестнуть", "хлестануть", "ударить", "плеснуть", "хлопнуть", "дерябнуть"],
    "хлопав": ["хлопавши"],
    "хлопавши": ["хлопав"],
    "хлопанец": ["шлёпанец", "тапка"],
    "хлопание": ["хлопанье"],
    "хлопанье": ["хлопок"],
    "хлопать": ["шлёпать", "аплодировать", "хлопать в ладоши"],
    "хлопать ушами": ["хлопать глазами"],
    "хлопец": ["молодой человек", "юноша", "малый", "малой", "чувак", "кекс", "крендель", "паря", "парниша", "пацан"],
    "хлопкороб": ["хлопковод"],
    "хлопкоуборка": ["уборка", "хлопок"],
    "хлопнув": ["хлопнувши"],
    "хлопнувши": ["хлопнув"],
    "хлопнуть": ["убить", "прикончить"],
    "хлопнуть дверью": ["грохнуть дверью"],
    "хлопнуться": ["бухнуться", "упасть"],
    "хлопок": ["хлопчатник", "хлопья", "пыж"],
    "хлопотав": ["хлопотавши"],
    "хлопотавши": ["хлопотав"],
    "хлопотать": ["суетиться"],
    "хлопотливый": ["суетливый", "заботливый", "хлопотный", "затруднительный"],
    "хлопотно": ["проблемно", "проблематично"],
    "хлопотный": ["хлопотливый", "трудоёмкий", "беспокойный"],
    "хлопоты": ["хлопотня", "заботы", "суетня", "беспокойство"],
    "хлопушка": ["петарда", "шутиха", "хлопунец", "смолёвка", "выбивалка"],
    "хлопчатка": ["хэбэ", "хлопчатобумажная", "ткань", "хабешка"],
    "хлопчатник": ["хлопок"],
    "хлопчатобумажный": ["бумажный", "хлопковый"],
    "хлопчатый": ["хлопковый", "хлопчатобумажный", "бумажный"],
    "хлопчик": ["паренёк"],
    "хлопье": ["хлопья", "клочок", "охлопки", "охлопье", "очёсок"],
    "хлопья": ["клочья"],
    "хлораль": ["хлорал", "трихлорацетальдегид"],
    "хлоральгидрат": ["хлоралгидрат"],
    "хлорацетатний": ["хлороцтовий"],
    "хлорбензол": ["фенилхлорид"],
    "хлорвинил": ["винилхлорид", "хлористый винил", "хлорэтилен", "хлорэтен", "этиленхлорид", "полихлорвинил", "поливинилхлорид", "винил"],
    "хлордиазепоксид": ["либриум"],
    "хлорид": ["гидрохлорид"],
    "хлорид аммония": ["хлористый аммоний", "нашатырь"],
    "хлорид бария": ["хлористый барий"],
    "хлорид калия": ["хлористый калий", "хлоркалий"],
    "хлорид натрия": ["поваренная соль", "каменная соль", "хлористый натрий"],
    "хлорировав": ["хлорировавши"],
    "хлорировавши": ["хлорировав"],
    "хлористый аммоний": ["хлорид аммония", "нашатырь"],
    "хлористый водород": ["соляная кислота"],
    "хлороводород": ["соляная кислота"],
    "хлорокись": ["оксихлорид"],
    "хлороорганический": ["хлорорганический"],
    "хлорорганический": ["хлороорганический"],
    "хлорофан": ["пиросмарагд"],
    "хлороформ": ["трихлорметан", "метилтрихлорид"],
    "хлороформировав": ["хлороформировавши"],
    "хлороформировавши": ["хлороформировав"],
    "хлорохин": ["резохин", "делагил", "хингамин"],
    "хлороцтовий": ["хлорацетатний"],
    "хлортетрациклин": ["ауреомицин", "биомицин"],
    "хлортетрациклиновый": ["ауреомициновый", "биомициновый"],
    "хлорэтен": ["винилхлорид", "хлористый винил", "хлорвинил", "хлорэтилен", "этиленхлорид"],
    "хлорэтилен": ["винилхлорид", "хлористый винил", "хлорвинил", "хлорэтен", "этиленхлорид"],
    "хлоя": ["хлои"],
    "хлус": ["манюка"],
    "хлынув": ["хлынувши"],
    "хлынувши": ["хлынув"],
    "хлынуть": ["нахлынуть"],
    "хлыснув": ["хлыснувши"],
    "хлыснувши": ["хлыснув"],
    "хлыст": ["розга", "хлёст", "хлыщ"],
    "хлыстав": ["хлыставши"],
    "хлыставши": ["хлыстав"],
    "хлыстнув": ["хлыстнувши"],
    "хлыстнувши": ["хлыстнув"],
    "хлыстовство": ["хлыстовщина"],
    "хлыстовщина": ["хлыстовство"],
    "хлысть": ["хлесть", "хлясть"],
    "хлыщ": ["франт", "щёголь", "фат"],
    "хлюзда": ["нытик", "хлюздопёр"],
    "хлюздить": ["капризничать", "плутовать"],
    "хлюздопёр": ["нытик", "хлюзда"],
    "хлюпав": ["хлюпавши"],
    "хлюпавши": ["хлюпав"],
    "хлюпання": ["хлюпанина"],
    "хлюпать": ["плакать", "шмыгать", "чавкать", "сёрбать"],
    "хлюпик": ["слабак", "дохлик", "заморыш"],
    "хлюпнув": ["хлюпнувши"],
    "хлюпнувши": ["хлюпнув"],
    "хлюпнуться": ["плюхнуться", "шлёпнуться"],
    "хлюст": ["прощелыга"],
    "хлюстав": ["хлюставши"],
    "хлюставши": ["хлюстав"],
    "хлющ": ["злива"],
    "хляб": ["самун", "франзела", "пита", "погача"],
    "хлябав": ["хлябавши"],
    "хлябавши": ["хлябав"],
    "хлябать": ["болтаться", "шататься", "расшатываться", "хлопать", "хлебать"],
    "хлябающий": ["шатающийся", "качающийся"],
    "хлябив": ["хлябивши"],
    "хлябивши": ["хлябив"],
    "хляскав": ["хляскавши"],
    "хляскавши": ["хляскав"],
    "хляснув": ["хляснувши"],
    "хляснувши": ["хляснув"],
    "хлястав": ["хляставши"],
    "хляставши": ["хлястав"],
    "хлястнув": ["хлястнувши"],
    "хлястнувши": ["хлястнув"],
    "хлясть": ["хлесть", "хлысть"],
    "хлёбово": ["похлёбка"],
    "хлёбывав": ["хлёбывавши"],
    "хлёбывавши": ["хлёбывав"],
    "хлёстывав": ["хлёстывавши"],
    "хлёстывавши": ["хлёстывав"],
    "хм": ["гм"],
    "хмао": ["ханты-мансийский автономный округ", "югра"],
    "хмарочос": ["небосяг"],
    "хмелев": ["хмелевши"],
    "хмелевина": ["лупулин"],
    "хмелевши": ["хмелев"],
    "хмелеть": ["пьянеть", "охмелевать"],
    "хмелив": ["хмеливши"],
    "хмеливши": ["хмелив"],
    "хмелить": ["охмелять", "опьянять"],
    "хмельницкая область": ["хмельнитчина"],
    "хмурив": ["хмуривши"],
    "хмуривши": ["хмурив"],
    "хмуро": ["мрачно", "насупленно", "угрюмо"],
    "хмурый": ["угрюмый", "мрачный", "насупленный", "насупившийся", "смурной", "безрадостный", "пасмурный", "облачный", "героин"],
    "хмурь": ["хмурость", "угрюмость", "пасмурность"],
    "хмыкав": ["хмыкавши"],
    "хмыкавши": ["хмыкав"],
    "хмыкание": ["хмыканье"],
    "хмыкнув": ["хмыкнувши"],
    "хмыкнувши": ["хмыкнув"],
    "хна": ["лавсония неколючая"],
    "хникання": ["пхикання"],
    "хныкав": ["хныкавши"],
    "хныкавши": ["хныкав"],
    "хныкать": ["скулить", "жаловаться", "сетовать", "роптать", "плакаться", "ныть"],
    "хныкнув": ["хныкнувши"],
    "хныкнувши": ["хныкнув"],
    "хоановый": ["лопастепёрый"],
    "хоб": ["навм"],
    "хоббит": ["полурослик", "невысоклик", "периан"],
    "хоббихорсинг": ["хобби-хорсинг"],
    "хобидан": ["хоб рафтан", "хуфтан"],
    "хобот": ["хвост", "шланг", "хоботок"],
    "ховав": ["ховавши"],
    "ховавши": ["ховав"],
    "ховар": ["офтоббаро"],
    "ховать": ["прятать", "скрывать", "хоронить"],
    "ховаться": ["прятаться"],
    "ховерборд": ["гироборд", "гироскутер", "гироцикл"],
    "ховеркрафт": ["судно на воздушной подушке", "аэроход"],
    "ховрах": ["ховрашок"],
    "ховрашок": ["ховрах"],
    "ход": ["работа", "движение", "развитие", "курс", "право хода", "очередь"],
    "ходай": ["алла"],
    "ходатай": ["проситель"],
    "ходатайство": ["прошение", "челобитная"],
    "ходатайствовав": ["ходатайствовавши"],
    "ходатайствовавши": ["ходатайствовав"],
    "ходебщик": ["афеня"],
    "ходив": ["ходивши"],
    "ходивши": ["ходив"],
    "ходить": ["идти", "двигаться", "передвигаться", "ездить", "функционировать", "ухаживать", "заботиться"],
    "ходить вокруг да около": ["говорить обиняками"],
    "ходить за маленькой": ["мочиться", "писать"],
    "ходить на цыпочках": ["ходить на задних лапках"],
    "ходить по кругу": ["ходить кругами"],
    "ходить ходуном": ["ходить ходором"],
    "ходкий": ["быстрый", "стремительный", "быстроходный", "скоростной", "быстроногий", "резвый", "проворный"],
    "ходко": ["бойко", "быстро", "скоро"],
    "ходовой": ["подвижный", "беговой", "проезжий", "ходкий", "популярный", "обычный", "частый", "распространённый", "расхожий", "ловкий", "оборотистый", "расторопный", "скорый", "умелый"],
    "ходьба": ["хождение", "шагание", "спортивная ходьба"],
    "ходя": ["китаец"],
    "ходячая энциклопедия": ["эрудит", "всезнайка", "живая энциклопедия", "ходячая википедия"],
    "хождение": ["ходьба", "обращение", "странствие", "паломничество", "путешествие"],
    "хожденье": ["хождение"],
    "хозар": ["хазар"],
    "хозария": ["хазария"],
    "хоздоговор": ["хозяйственный договор"],
    "хозрасчёт": ["хозяйственный расчёт", "самофинансирование"],
    "хозяин": ["владелец", "обладатель", "собственник", "владетель", "производитель", "домохозяин", "домовладелец", "арендодатель", "начальник", "работодатель", "наниматель", "рабовладелец"],
    "хозяиновав": ["хозяиновавши"],
    "хозяиновавши": ["хозяиновав"],
    "хозяйка": ["владелица", "собственница", "начальница", "работодательница"],
    "хозяйничав": ["хозяйничавши"],
    "хозяйничавши": ["хозяйничав"],
    "хозяйничанье": ["хозяйничание"],
    "хозяйственность": ["расчетливость", "домовитость", "бережливость", "экономичность", "экономность", "безубыточность"],
    "хозяйство": ["экономика", "производство", "имущество"],
    "хозяйствовав": ["хозяйствовавши"],
    "хозяйствовавши": ["хозяйствовав"],
    "хозяйствующий субъект": ["экономический субъект"],
    "хоккаш": ["заминков"],
    "хоккей с шайбой": ["канадский хоккей", "хоккей"],
    "хокку": ["хайку"],
    "хокуспокус": ["абракадабра"],
    "холдинг": ["холдинг-компания"],
    "холдинг-компания": ["холдинг"],
    "холеный": ["холёный"],
    "холерный": ["холерический"],
    "холестаз": ["холестатический синдром"],
    "холестеатома": ["жемчужная опухоль"],
    "холестерин": ["холестерол"],
    "холестерол": ["холестерин"],
    "холецистохолангит": ["ангиохолецистит"],
    "холив": ["холивши"],
    "холивар": ["срач", "флейм", "склока"],
    "холивши": ["холив"],
    "холинолитический": ["антихолинергический"],
    "холистический": ["холический"],
    "холить": ["лелеять", "пестовать", "мирволить", "обихаживать", "нежить", "баловать", "голубить", "ласкать", "тешить", "беречь", "оберегать", "хранить", "сохранять"],
    "холка": ["загривок", "грива"],
    "холл": ["вестибюль", "передняя"],
    "холм": ["горка", "гора", "возвышение", "пригорок"],
    "холмив": ["холмивши"],
    "холмивши": ["холмив"],
    "холмистый": ["гористый"],
    "холмогорец": ["заугольник", "бык"],
    "холмогорка": ["корова"],
    "холмок": ["холмик"],
    "холмск": ["маука", "маока"],
    "холобазидия": ["голобазидия", "автобазидия"],
    "хологамия": ["гологамия"],
    "холодав": ["холодавши"],
    "холодавши": ["холодав"],
    "холодев": ["холодевши"],
    "холодевши": ["холодев"],
    "холодеть": ["хладеть", "стыть", "стынуть", "леденеть", "мерзнуть", "мертветь", "коченеть", "холоднеть", "выстывать", "охладевать"],
    "холодец": ["заливное"],
    "холодив": ["холодивши"],
    "холодивши": ["холодив"],
    "холодильник": ["рефрижератор", "холодос"],
    "холодильничек": ["холодосик"],
    "холодина": ["холод", "холодрыга"],
    "холодить": ["морозить", "охлаждать"],
    "холодище": ["холодрыга"],
    "холодная война": ["новая холодная война"],
    "холоднев": ["холодневши"],
    "холодневши": ["холоднев"],
    "холоднее": ["холодней"],
    "холодний": ["зимний"],
    "холодно": ["бесстрастно", "невозмутимо", "зябко"],
    "холодное оружие": ["холодняк"],
    "холоднокровие": ["холоднокровность", "хладнокровие"],
    "холоднокровный": ["пойкилотермный"],
    "холоднокровье": ["холоднокровие"],
    "холодность": ["безразличие", "сухость", "отстранённость", "фригидность", "суровость"],
    "холодняк": ["холодное оружие"],
    "холодок": ["прохлада"],
    "холодос": ["холодильник"],
    "холодосик": ["холодильничек"],
    "холодостойкий": ["холодоустойчивый"],
    "холодостойкость": ["хладостойкость", "холодоустойчивость", "криостойкость"],
    "холодоустойчивость": ["холодостойкость"],
    "холодрыга": ["холодюга", "холодюка", "холодина", "холодище", "холод", "мороз", "стужа", "стынь", "собачий холод"],
    "холодяка": ["холодина"],
    "холодянка": ["ледяная вода", "кипяток", "мороз"],
    "холокост": ["шоа", "катастрофа", "лохокост"],
    "холонув": ["холонувши"],
    "холонувши": ["холонув"],
    "холопротеин": ["протеид"],
    "холопски": ["по-холопски"],
    "холопский": ["рабский", "холуйский"],
    "холопствовав": ["холопствовавши"],
    "холопствовавши": ["холопствовав"],
    "холостив": ["холостивши"],
    "холостивши": ["холостив"],
    "холостой": ["бесполезный"],
    "холостяк": ["холостой", "бобыль", "старая дева", "холостячка"],
    "холостяковав": ["холостяковавши"],
    "холостяковавши": ["холостяковав"],
    "холостячка": ["незамужняя"],
    "холостёжь": ["холостяк"],
    "холотропное дыхание": ["ребёфинг"],
    "холотропный": ["голотропный"],
    "холофермент": ["голофермент", "голоэнзим"],
    "холофразис": ["голофразис"],
    "холоша": ["штанина"],
    "холощение": ["кастрирование"],
    "холощёный": ["кастрированный"],
    "холстинный": ["холстиновый", "холстяной", "холщовый"],
    "холуй": ["слуга", "лакей", "холоп", "челядин", "лизоблюд", "низкопоклонник", "подлиза", "подхалим", "прислужник", "приспешник", "прихлебала", "прихлебатель", "шестёрка", "прихвостень", "сервилист"],
    "холуйски": ["лакейски", "раболепно"],
    "холуйствовав": ["холуйствовавши"],
    "холуйствовавши": ["холуйствовав"],
    "холуяжничав": ["холуяжничавши"],
    "холуяжничавши": ["холуяжничав"],
    "холуяжничать": ["холуйствовать"],
    "холщовый": ["холщёвый", "полотняный"],
    "холщёвый": ["холщовый", "холстинный", "холстяной"],
    "холя": ["уход", "забота"],
    "холява": ["халява"],
    "холёный": ["изнеженный", "ухоженный"],
    "хомо советикус": ["гомо советикус", "совок"],
    "хомот": ["ярем"],
    "хомутав": ["хомутавши"],
    "хомутавши": ["хомутав"],
    "хомутив": ["хомутивши"],
    "хомутивши": ["хомутив"],
    "хомяк": ["лемминг", "хомячок"],
    "хомячив": ["хомячивши"],
    "хомячивши": ["хомячив"],
    "хомячить": ["жрать", "лопать", "трескать", "крысятничать"],
    "хона": ["манзил"],
    "хонавода": ["оила", "хонадон"],
    "хондриом": ["митохондрион"],
    "хондриосома": ["митохондрия"],
    "хондрома": ["хрящевик"],
    "хондэн": ["синдэн"],
    "хонинговав": ["хонинговавши"],
    "хонинговавши": ["хонинговав"],
    "хонинговать": ["шлифовать"],
    "хонсю": ["хондо", "ниппон"],
    "хоныхунэхумсос": ["хоны-хунэ-хум-сос"],
    "хоп-ап": ["хопап"],
    "хопкинс": ["гопкинс"],
    "хоплофобия": ["гоплофобия"],
    "хоппер": ["вагон-хоппер"],
    "хор": ["кор", "кавр"],
    "хорарный": ["интеррогативный"],
    "хорба": ["ворба"],
    "хорв": ["хорват"],
    "хорват": ["кроат"],
    "хорватия": ["республика хорватия", "социалистическая республика хорватия", "независимое государство хорватия"],
    "хорватка": ["кроатка"],
    "хорда": ["спинная струна"],
    "хординг": ["мшелоимство", "синдром плюшкина"],
    "хорезмийский": ["хорезмский"],
    "хорей": ["трохей"],
    "хореография": ["хоряга"],
    "хорея": ["пляска святого витта", "виттова пляска"],
    "хорз": ["нывыл"],
    "хориальный": ["хорионический", "плацентарный"],
    "хорив": ["хорев"],
    "хориоидеа": ["хориоидея"],
    "хориоидея": ["хориоидеа"],
    "хориоидит": ["задний увеит"],
    "хорион": ["сероза"],
    "хорионический": ["хориальный"],
    "хоркав": ["хоркавши"],
    "хоркавши": ["хоркав"],
    "хороба": ["хвороба"],
    "хороводив": ["хороводивши"],
    "хороводивши": ["хороводив"],
    "хороводить": ["хороводничать"],
    "хороводиться": ["возиться", "знаться", "водиться"],
    "хороводоводчик": ["хороводовод"],
    "хорология": ["ареалогия"],
    "хоронзон": ["коронзон"],
    "хоронив": ["хоронивши"],
    "хоронивши": ["хоронив"],
    "хоронимый": ["погребаемый"],
    "хоронить": ["погребать", "предавать земле", "списывать"],
    "хорониться": ["прятаться"],
    "хороняка": ["трус", "ссыкун", "ссыкло"],
    "хорохориться": ["геройствовать", "ершиться", "горячиться", "храбриться"],
    "хорош": ["будет", "довольно", "достаточно", "полно", "хватит", "стопэ", "харэ", "хорэ"],
    "хорошев": ["хорошевши"],
    "хорошевши": ["хорошев"],
    "хорошенький": ["симпатичный", "миловидный", "смазливый", "пригожий", "прелестный", "очаровательный", "миленький", "пьяненький"],
    "хорошист": ["четвёрочник"],
    "хорошка": ["красавчик"],
    "хоррор": ["фильм ужасов", "ужастик", "ужас"],
    "хорроркор": ["хоррор-кор"],
    "хортый": ["гладкошёрстный", "гладкошёрстый", "хорт", "хортица"],
    "хоругвь": ["знамя", "стяг"],
    "хорунжий": ["знаменосец"],
    "хорус": ["хор"],
    "хоры": ["антресоль"],
    "хорь": ["хорёк"],
    "хоряга": ["хореография"],
    "хорёк": ["хорь"],
    "хорёк душной": ["хорь", "хорёк", "вонючка", "вонялка", "воняйка", "воняюшка", "грязнуля", "грязнулькин", "грязнулькина", "грязнуличкин", "грязнуличкинский", "засеря", "серя-засеря", "засранец", "засранка"],
    "хост": ["узел сети"],
    "хост-компьютер": ["хост"],
    "хоста": ["функия"],
    "хостинг": ["колокация", "колокейшн"],
    "хостинг-провайдер": ["хостер"],
    "хот-дог": ["сосиска в тесте"],
    "хотев": ["хотевши"],
    "хотевши": ["хотев"],
    "хотелка": ["хотение", "желание"],
    "хотение": ["желание", "волеизъявление"],
    "хотеть": ["желать", "алкать"],
    "хотеться": ["тянуть", "не терпеться", "подмывать"],
    "хоттабыч": ["старик", "наркоман"],
    "хоть": ["хотя", "пусть", "что", "хотя бы", "к примеру", "например"],
    "хоть бы": ["хотя бы"],
    "хоть глаз выколи": ["темно", "темным-темно", "темным-темнёшенько", "не видать ни зги", "ни зги не видать", "ни зги не видно", "зги божьей не видать", "хоть глаз коли", "хоть глаза коли", "темно как у негра в жопе"],
    "хоть отбавляй": ["пруд пруди", "завались", "навалом", "выше крыши", "по горло", "хоть жопой ешь", "куры не клюют"],
    "хоть святых вон неси": ["ужас", "ужас что такое", "ужас что творится", "ужасно", "непристойно", "содом и гоморра", "святых вон выноси", "хоть святых выноси", "хоть святых уноси", "святых выноси и сам уходи", "хоть святых вон выноси", "хоть святых вон понеси", "хоть святых вон уноси"],
    "хоть святых выноси": ["ужас", "ужас что такое", "ужас что творится", "ужасно", "непристойно", "содом и гоморра", "святых вон выноси", "хоть святых неси", "хоть святых уноси", "святых выноси и сам уходи", "хоть святых вон выноси", "хоть святых вон неси", "хоть святых вон понеси", "хоть святых вон уноси"],
    "хоть трава не расти": ["всё равно", "фиолетово", "после нас хоть потоп"],
    "хоть тресни": ["что ни делай", "как ни старайся"],
    "хоть шаром покати": ["шаром покати", "шар шаром покати", "хоть шаром кати", "хоть шаром пусти", "хоть шаром покатись"],
    "хотя": ["хоть", "при том что", "невзирая на", "несмотря на", "хотя бы"],
    "хотя бы": ["хоть бы", "хотя б", "хоть", "даже", "пусть даже", "например", "к примеру", "вот", "хорошо бы", "пусть бы"],
    "хотя бы и": ["даже если"],
    "хоумлендер": ["зумер", "центениал"],
    "хоусит": ["хусит"],
    "хохлатев": ["хохлатевши"],
    "хохлатевши": ["хохлатев"],
    "хохлатив": ["хохлативши"],
    "хохлативши": ["хохлатив"],
    "хохлатка": ["курица"],
    "хохлив": ["хохливши"],
    "хохливши": ["хохлив"],
    "хохло-": ["укро-", "сало-", "свино-"],
    "хохлобакс": ["гривна", "карбованец"],
    "хохловермахт": ["саловермахт", "укровермахт"],
    "хохлолюфтваффе": ["укролюфтваффе", "салолюфтваффе", "свинолюфтваффе"],
    "хохломусор": ["укромусор"],
    "хохлопатриот": ["укропатриот", "салопатриот", "свинопатриот"],
    "хохлопропаганда": ["укропропаганда"],
    "хохлоукреп": ["укроукреп", "свиноукреп"],
    "хохлофюрер": ["укрофюрер", "салофюрер", "укропрезик", "хохлопрезик"],
    "хохлоюгенд": ["укроюгенд"],
    "хохлуша": ["хохлатка"],
    "хохлушечка": ["украиночка"],
    "хохлушка": ["украинка"],
    "хохляцкий": ["украинский"],
    "хохма": ["подковырка", "подначка", "шутка", "прикол", "острота", "розыгрыш", "бонмо", "насмешка", "красное словцо"],
    "хохмач": ["остряк", "циркач", "шутник", "насмешник", "штукарь", "острослов", "зубоскал", "юморист", "приколист", "остроумец", "прикольщик", "балагур"],
    "хохмачество": ["зубоскальство", "шутовство", "балагурство", "насмешничанье", "подшучивание", "насмехательство", "остроумничанье"],
    "хохмив": ["хохмивши"],
    "хохмивши": ["хохмив"],
    "хохмить": ["зубоскальничать", "балагурить", "остроумничать", "острить", "зубоскалить", "подшучивать", "острословить", "шутить", "насмехаться", "насмешничать"],
    "хохол": ["хохолок", "чуб", "чупрун", "вихор", "оселедец", "чуприна"],
    "хохолок": ["пучок"],
    "хохот": ["гогот", "смех"],
    "хохотав": ["хохотавши"],
    "хохотавши": ["хохотав"],
    "хохотанье": ["хохотание"],
    "хохотать": ["гоготать"],
    "хохотать как безумный": ["ржать как лошадь", "хохотать как сумасшедший"],
    "хохотать как сумасшедший": ["хохотать как безумный", "ржать как лошадь"],
    "хохотнув": ["хохотнувши"],
    "хохотнувши": ["хохотнув"],
    "хохотун": ["гоготун", "смешливец", "чайка-хохотун"],
    "хохотунья": ["хохотушка", "хохотун"],
    "хохотуша": ["хохотунья", "хохотушка"],
    "хочемка": ["хочёмка"],
    "хоша": ["хотя", "хоть", "хоча"],
    "хошен": ["наперсник"],
    "храбрев": ["храбревши"],
    "храбревши": ["храбрев"],
    "храбрец": ["смельчак", "герой"],
    "храбрив": ["храбривши"],
    "храбривши": ["храбрив"],
    "храбро": ["смело", "бесстрашно"],
    "храбрость": ["мужество", "смелость", "отвага", "доблесть", "бесстрашие"],
    "храбрый": ["бесстрашный", "отважный", "смелый", "решительный", "мужественный"],
    "храм": ["святилище"],
    "храмина": ["здание", "дом", "комната", "зала", "палата"],
    "храмовник": ["тамплиер"],
    "храмовый": ["храмный"],
    "храмостроитель": ["храмоздатель"],
    "храмывав": ["храмывавши"],
    "храмывавши": ["храмывав"],
    "хранение": ["сохранение", "оберегание", "укрытие"],
    "храненье": ["хранение"],
    "хранив": ["хранивши"],
    "хранивши": ["хранив"],
    "хранилище": ["репозитарий", "репозиторий", "склад"],
    "хранить": ["сохранять", "содержать", "заключать в себе"],
    "хранить в тайне": ["скрывать", "таить", "держать в секрете"],
    "храп": ["храпение"],
    "храпанув": ["храпанувши"],
    "храпанувши": ["храпанув"],
    "храпев": ["храпевши"],
    "храпевши": ["храпев"],
    "храпнув": ["храпнувши"],
    "храпнувши": ["храпнув"],
    "храповик": ["храповой механизм"],
    "храповой механизм": ["храповик"],
    "храпёж": ["храпение", "храп"],
    "хребет": ["позвоночник", "хребтина", "спина", "стержень", "основа", "гребень", "массив", "кряж", "цепь"],
    "хребтуг": ["мешок", "рептух", "рядно", "хребтюг"],
    "хрен": ["хрень", "хрён", "хренок", "хрыч", "хрычовка", "хреновка"],
    "хрен в стакан": ["ни в коем разе", "хер в стакан", "хуй в стакан"],
    "хрен моржовый": ["хуй моржовый"],
    "хрен с горы": ["хуй с горы"],
    "хрен с маслом": ["хрен с прованским маслом"],
    "хренов": ["пархатый"],
    "хреновенький": ["хуёвенький", "херовенький"],
    "хреновенько": ["хуёвенько", "херовенько"],
    "хреновина": ["хрен", "вещь", "штука", "штуковина", "фиговина", "фигня", "хрень", "хренотень", "херня", "дрянь", "лажа", "горлодёр"],
    "хреново": ["паршиво", "погано"],
    "хреновуха": ["хреновка", "хреновочка"],
    "хренотень": ["ерунда", "чушь", "дребедень", "дрянь", "хрень", "вещь", "штуковина", "штука", "фиговина", "фигня", "хреновина", "херня", "хуйня"],
    "хренушки": ["нетушки", "хуюшки"],
    "хрень": ["хренотень", "ерунда", "ерундень", "дребедень", "чушь", "дрянь", "фигня", "хреновина", "вещь", "штуковина", "фиговина"],
    "хризалида": ["куколка"],
    "хризантемный": ["хризантемовый"],
    "хризантемовый": ["хризантемный"],
    "хризолит": ["перидот"],
    "хризотил": ["белый асбест"],
    "хрип": ["хрипение"],
    "хрипев": ["хрипевши"],
    "хрипевши": ["хрипев"],
    "хрипенье": ["хрипение"],
    "хрипло": ["как", "немазаный", "колесо"],
    "хрипнув": ["хрипнувши"],
    "хрипнувши": ["хрипнув"],
    "хрипота": ["осиплость", "сиплость", "сипота", "хрип", "охриплость", "хрипение", "хрипенье", "хрипотца"],
    "хрисанф": ["кирсан", "хрисан", "хрисанфий"],
    "хрисма": ["хризма", "хрисмон", "христограмма"],
    "христарадничав": ["христарадничавши"],
    "христарадничавши": ["христарадничав"],
    "христианизировав": ["христианизировавши"],
    "христианизировавши": ["христианизировав"],
    "христианизовав": ["христианизовавши"],
    "христианизовавши": ["христианизовав"],
    "христианизовать": ["христианизировать"],
    "христианизоваться": ["христианизироваться"],
    "христианин": ["крестопоклонник"],
    "христианка": ["крестопоклонница"],
    "христианнейший": ["наихристианнейший", "архихристианский"],
    "христианствовав": ["христианствовавши"],
    "христианствовавши": ["христианствовав"],
    "христина": ["кристина"],
    "християнин": ["ирстенин"],
    "христопродавец": ["иуда", "иудушка"],
    "христорадница": ["христарадница"],
    "христос": ["спаситель", "господь", "машиах", "помазанник", "мессия", "назаретянин", "назарянин"],
    "христосик": ["смиренник", "скромник", "притворщик", "тихоня", "скромняга", "добрячок", "исусик", "непротивленец"],
    "христосование": ["христосованье"],
    "христосованье": ["христосование"],
    "христосъ": ["спаситель", "господь"],
    "хрихыц": ["хыц", "латыхга"],
    "хрия": ["речь"],
    "хробак": ["робак", "гробак"],
    "хрокало": ["хрокач"],
    "хромав": ["хромавши"],
    "хромавши": ["хромав"],
    "хромакей": ["телеинкрустация", "блюбокс"],
    "хроматизм": ["хроматика"],
    "хроматографировав": ["хроматографировавши"],
    "хроматографировавши": ["хроматографировав"],
    "хромать": ["чикилять"],
    "хромев": ["хромевши"],
    "хромевши": ["хромев"],
    "хромировав": ["хромировавши"],
    "хромировавши": ["хромировав"],
    "хромка": ["гармонь", "гармоника", "гармошка", "баян", "аккордеон"],
    "хромная кислота": ["хромовая кислота"],
    "хромоалитировав": ["хромоалитировавши"],
    "хромоалитировавши": ["хромоалитировав"],
    "хромоалитировать": ["алюмохромировать"],
    "хромобластомикоз": ["хромомикоз"],
    "хромозома": ["хромосома"],
    "хромой": ["хромоногий"],
    "хромомикоз": ["хромобластомикоз"],
    "хромоногий": ["хромой", "колченогий"],
    "хромосома": ["хромозома"],
    "хромотерапия": ["цветотерапия"],
    "хромофобный": ["хроматофобный"],
    "хрон": ["хроник"],
    "хроникёр": ["летописец", "редактор"],
    "хронировав": ["хронировавши"],
    "хронировавши": ["хронировав"],
    "хронист": ["летописец"],
    "хронически": ["постоянно"],
    "хронозона": ["стратиграфическая зона", "зона"],
    "хронологизировав": ["хронологизировавши"],
    "хронологизировавши": ["хронологизировав"],
    "хронологически": ["исторически", "последовательно"],
    "хронометрировав": ["хронометрировавши"],
    "хронометрировавши": ["хронометрировав"],
    "хронометрирование": ["хронометраж"],
    "хронометрировать": ["засекать", "засечь"],
    "хронометрист": ["хронометражист"],
    "хронотип": ["лимитотип"],
    "хронофотография": ["хронофотограмма"],
    "хрумкав": ["хрумкавши"],
    "хрумкавши": ["хрумкав"],
    "хрумкнув": ["хрумкнувши"],
    "хрумкнувши": ["хрумкнув"],
    "хруп": ["треск", "хрусть", "хряст", "хруст", "хряск", "хрустение", "хрупанье", "хрустнуть", "хрупнуть", "треснуть"],
    "хрупав": ["хрупавши"],
    "хрупавши": ["хрупав"],
    "хрупать": ["хрустеть", "трескать", "хрумкать", "хрустать", "грызть"],
    "хрупкий": ["ломкий", "субтильный"],
    "хрупкопластический": ["хрупко-пластический"],
    "хрупкость": ["ломкость"],
    "хрупнув": ["хрупнувши"],
    "хрупнувши": ["хрупнув"],
    "хруст": ["хрустение", "хрустенье", "рубль"],
    "хрустав": ["хруставши"],
    "хруставши": ["хрустав"],
    "хрусталик": ["хрусталь"],
    "хрустев": ["хрустевши"],
    "хрустевши": ["хрустев"],
    "хрустение": ["хруст"],
    "хрустенье": ["хрустение"],
    "хрустик": ["велосипедист", "мотоциклист", "мопедист", "велосипед", "мотоцикл", "мопед"],
    "хрустнув": ["хрустнувши"],
    "хрустнувши": ["хрустнув"],
    "хрущак": ["мучной хрущак"],
    "хрущёвка": ["хрущ", "хрущоба"],
    "хрущёвский холодильник": ["зимний холодильник", "хрущёвский шкаф"],
    "хрыч": ["хрен"],
    "хрю": ["хрюк", "хрюкание", "хрюканье"],
    "хрюкав": ["хрюкавши"],
    "хрюкавши": ["хрюкав"],
    "хрюкание": ["хрюканье"],
    "хрюканье": ["хрюк", "хрюкание"],
    "хрюкнув": ["хрюкнувши"],
    "хрюкнувши": ["хрюкнув"],
    "хрючево": ["жратва", "жрачка", "хрючило", "хавка", "хавчик", "хавло", "ирландское рагу"],
    "хрючило": ["жратва", "жрачка", "хрючево", "хавка", "хавчик", "хавло", "ирландское рагу"],
    "хрюшка": ["свинья", "хавронья", "неряха"],
    "хряк": ["кабан", "боров"],
    "хряпав": ["хряпавши"],
    "хряпавши": ["хряпав"],
    "хряпать": ["бить", "стучать", "хлопать", "есть", "жрать"],
    "хряпка": ["кочерыжка", "хряпок"],
    "хряпнув": ["хряпнувши"],
    "хряпнувши": ["хряпнув"],
    "хряпнуться": ["грохнуться", "хрястнуться", "шлёпнуться", "шмякнуться"],
    "хряскав": ["хряскавши"],
    "хряскавши": ["хряскав"],
    "хряснув": ["хряснувши"],
    "хряснувши": ["хряснув"],
    "хряст": ["хряп", "хрястанье", "хруст", "треск", "хрустение", "хряск", "хрупанье", "хруп"],
    "хрястав": ["хряставши"],
    "хряставши": ["хрястав"],
    "хряставший": ["бивший", "ударявший", "хлеставший", "дубасивший", "жравший", "уплетавший", "лопавший"],
    "хрястнув": ["хрястнувши"],
    "хрястнувши": ["хрястнув"],
    "хрясть": ["бах", "бац", "бздынь", "бряк", "бух", "бум", "бубух", "плюх", "хлобысь", "хлобысть", "хрясь", "чебурах", "шлёп", "шмяк"],
    "хрясь": ["бах", "бац", "бздынь", "бряк", "бух", "бум", "бубух", "плюх", "хлобысь", "хлобысть", "хрясть", "чебурах", "шлёп", "шмяк"],
    "хрящеватый": ["костистый"],
    "хтонический": ["подземный"],
    "хтонь": ["нечисть", "быдло"],
    "хуан": ["хуанито"],
    "хуанхэ": ["хуан-хе", "жёлтая река"],
    "хубавелка": ["красавица", "хубавица"],
    "хубавец": ["красавец", "хубавеляк"],
    "хубостник": ["непрокопсаник", "вагабонтин", "негодник", "проклетник"],
    "худав": ["худавши"],
    "худавши": ["худав"],
    "худев": ["худевши"],
    "худевши": ["худев"],
    "худеть": ["терять вес", "худать", "легчать", "сдуваться", "беднеть", "нищать"],
    "худжанд": ["ленинабад"],
    "худи": ["толстовка", "капюшон"],
    "худив": ["худивши"],
    "худивши": ["худив"],
    "худищий": ["худющий", "худущий"],
    "худлит": ["художественная литература"],
    "худо": ["плохо", "дурно"],
    "художественная галерея": ["картинная галерея"],
    "художественная литература": ["беллетристика", "изящная словесность", "худлит", "фикшн"],
    "художественный": ["артистический", "артистичный", "эстетический", "образный", "изобразительный"],
    "художество": ["искусство"],
    "художник": ["артист"],
    "художница": ["артистка", "скульпторша"],
    "худой": ["тощий", "костлявый", "исхудалый", "исхудавший", "отощалый", "худенький", "худющий", "худощавый", "поджарый", "сухой", "сухощавый", "сухопарый"],
    "худой мир лучше доброй ссоры": ["худой мир лучше доброй брани", "худой мир лучше доброй битвы", "худой мир лучше доброй драки", "соломенный мир лучше железной драки"],
    "худомания": ["анорексия"],
    "худорба": ["худина"],
    "худородный": ["незнатный", "неродовитый", "малоплодородный"],
    "худосочие": ["кахексия"],
    "худосочность": ["истощённость"],
    "худость": ["худоба"],
    "худотелый": ["тощий", "худой"],
    "худощавый": ["поджарый", "сухощавый", "сухопарый", "худой"],
    "худрук": ["арт-директор"],
    "худущий": ["худющий", "худищий"],
    "худший": ["наихудший"],
    "худъа": ["фиреб"],
    "худющий": ["худущий", "худищий"],
    "хуев": ["проклятый", "ненавистный", "чёртов", "осточертевший"],
    "хуева туча": ["с хуеву тучу", "туева хуча", "с туеву хучу", "фигова туча", "до фига", "до хрена", "до хренища", "до хера", "до херища", "хуева гора", "до хуя", "до хуя и больше", "до хуища", "до пиздищи"],
    "хуевато": ["плоховато", "дрянновато", "скверновато", "дерьмовато", "фиговато", "херовато"],
    "хуеватый": ["плоховатый", "дрянноватый", "скверноватый"],
    "хуевертив": ["хуевертивши"],
    "хуевертивши": ["хуевертив"],
    "хуевши": ["хуев"],
    "хуеглот": ["минетчик", "вафлёр", "защекан", "защеканец", "хуесос"],
    "хуежоп": ["мудло", "мудак", "мудачина"],
    "хуежопый": ["хитрый", "хитрожопый", "хитровыебанный", "неумелый", "неуклюжий", "кривожопый", "рукожопый", "плохой", "дрянной", "негодный", "неприятный", "чужой", "чуждый", "враждебный", "неестественный"],
    "хуемразь": ["хуеносец"],
    "хуеносец": ["хуемразь"],
    "хуеньки": ["нет", "хуюшки", "никак"],
    "хуеплёт": ["лгун", "лгунишка", "врун", "врунишка", "враль", "болтун", "болтунишка", "пустомеля", "пиздобол", "хуепутало"],
    "хуепутало": ["халтурщик", "мастер-ломастер", "небрежник", "кое-какер", "бракодел", "портач"],
    "хуерга": ["хуерговина"],
    "хуерговина": ["хуерга"],
    "хуерык": ["перелой", "триппер", "трипак", "гонорея"],
    "хуерылый": ["пиздорылый"],
    "хуесос": ["миньетчик", "минетчик", "тибетчик", "вафлёр", "вафлист", "вафел", "вафлеглот", "спермоглот", "членоглот", "сперможуй", "спермосос", "хреносос", "членосос", "чупа-чупсос", "видал сосун"],
    "хуесос ёбаный": ["ёбаный хуесос", "сраный хуесос", "хуесос сраный"],
    "хуесосив": ["хуесосивши"],
    "хуесосивши": ["хуесосив"],
    "хуесосить": ["давать в рот", "давать сосать хуй", "давать отсосать хуй", "давать отсасывать", "давать подсасывать", "давать высасывать", "давать за щёку", "кидать за щеку", "кидать на клык", "давать сосюру читать", "давать сосюру читать болту", "давать обгладывать косточку", "давать обглодать косточку", "давать глотать живчиков", "давать глотать молофью"],
    "хуесоска": ["вротобранка"],
    "хуесосничав": ["хуесосничавши"],
    "хуесосничавши": ["хуесосничав"],
    "хуета": ["поебень", "хуебень", "хуеберь", "хуетень", "хуебария", "хуёболда", "хуёвина", "хуёвина с морковиной", "хуита", "мандахуёвина", "хуер-буер", "суета"],
    "хуета на хуете": ["ебота на еботе"],
    "хуетень": ["ерундистика", "ерундень", "хренотень", "херотень", "херомантия", "поебень", "поебистика", "хуеберь"],
    "хуеть": ["наглеть", "охуевать", "фигеть", "офигевать"],
    "хужев": ["хужевши"],
    "хужевши": ["хужев"],
    "хужее": ["хуже"],
    "хуи гну": ["баранки гну", "хуй гну"],
    "хуило": ["хуина", "хуище", "хуилище", "хуильник", "шишак", "стояк"],
    "хуило моржовый": ["хуй моржовый"],
    "хуина": ["хуище", "хуильник", "хуилище"],
    "хуистый": ["хуястый", "хуистой"],
    "хуишко": ["хуец", "хуёк", "хуёчек", "хуишечко", "хуюсик", "хуюшечка", "хуюшечко"],
    "хуище": ["хуина", "хуинушка", "хуило"],
    "хуй в кожаном пальто": ["хуй в пальто", "никто", "никто и звать никак", "ноль", "ноль без палочки", "хрен в ступе"],
    "хуй в пальто": ["хуй в кожаном пальто", "никто", "никто и звать никак", "ноль", "ноль без палочки", "хрен в ступе"],
    "хуй важный": ["шеф", "начальник", "командир", "бугор"],
    "хуй гну": ["баранки гну", "хуи гну"],
    "хуй да ни хуя": ["хрен да маленько", "шиш да маленько", "хуй да маленько", "с гулькин хуй", "с хуеву душу", "с хуеву голову", "ничего", "ровно ничего", "ровным счётом ничего", "ничегошеньки", "дырка от бублика", "от жилетки рукава", "пшик", "шиш", "шиш с маслом"],
    "хуй забить": ["наплевать", "проигнорировать", "забить болт", "болт забить", "забить хуй", "положить хуй", "хуй положить"],
    "хуй колом": ["хуй горой", "хуй дыбом", "хуй торчком", "хуй штыком", "хуй стоит до потолка", "дыбом хуй"],
    "хуй ли": ["хули", "хуле", "хуля", "хуль"],
    "хуй моржовый": ["дурак", "придурок", "подонок", "хуй голландский", "хуй мамин", "хуй с горы", "хуй стоптанный", "хуило моржовый", "хуй трёхколёсный", "недотёпа", "бакулюм"],
    "хуй на блюде": ["хер на блюде"],
    "хуй на ны": ["хуй наны", "хуй на нэ", "хуй нанэ", "хуй в руль", "хуй на руль", "а хуй наны не видел у шпаны"],
    "хуй наны": ["хуй на ны"],
    "хуй ночевал": ["нет", "нету", "ничего", "пусто", "шаром покати", "рукава от жилетки", "дырка от бублика", "от жилетки рукава", "от бублика дырка", "от пизды дырка", "хуй там ночевал"],
    "хуй один": ["ничего", "ровно ничего", "ровным счётом ничего", "ничегошеньки", "дырка от бублика", "от жилетки рукава", "пшик", "шиш", "шиш с маслом", "шиш с прицепом", "ни шиша", "шиш да ни шиша", "ни черта", "фиг", "фиг один"],
    "хуй по всей морде": ["хуй по всей роже", "хуй по всей харе", "хуем по спине", "хуем по затылку"],
    "хуй показать": ["показать хуй", "наебать", "объебать"],
    "хуй с горы": ["хрен с горы"],
    "хуй с тобой": ["хуй с тобою", "хуй с ним", "хуй с ней", "хуй с ними", "хуй с вами", "хуй на тебя", "хуй на него", "хуй на неё", "хуй на них", "хуй на вас"],
    "хуй сосали комбайнёры": ["хуй", "хуй да ни хуя", "хуй да маленько", "хуй там", "хуй ночевал", "хуй там ночевал", "хуй в рот"],
    "хуй сосать": ["заработать хуем по спине"],
    "хуй там": ["нет", "ни за что", "ни в коем случае", "хуй в рот"],
    "хуй тебе на воротник": ["шиш", "хрена", "хера", "хуя", "хуй тебе", "хуй на рыло", "хуй на ны"],
    "хуй трёхколёсный": ["хуй моржовый", "хуило моржовый"],
    "хуй ушастый": ["хуй моржовый", "хуило моржовый", "хуй голландский", "хуй трёхколёсный", "хуй немытый", "хуй неумытый", "хуй вонючий", "хуй мамин", "хуй маринованный", "хуй с горы", "хуй стоптанный", "хуй ёбаный", "залупа коня будённого"],
    "хуйкнув": ["хуйкнувши"],
    "хуйкнувши": ["хуйкнув"],
    "хуйлан": ["колхозан"],
    "хуйло": ["мудила", "мудило", "мудло", "чмо", "пидр", "хуйлыга", "хуерлыга", "хуйман", "хуйманок", "хуеглот", "хуеглотина", "хуепутло", "хуепыжлово", "хуёпыч", "хуесос"],
    "хуйнув": ["хуйнувши"],
    "хуйнувши": ["хуйнув"],
    "хуйнуть": ["хуякнуть", "ёбнуть", "заебенить", "въебенить", "ебануть", "захуячить", "пиздануть", "похуячить"],
    "хуйню спороть": ["спороть хуйню"],
    "хуйня": ["шваль"],
    "хук-кипер": ["хуккипер"],
    "хуккипер": ["хук-кипер"],
    "хула": ["брань", "поношение", "порицание", "порочение", "поругание", "ругань", "срамословие", "срамнословие", "унижение", "осуждение", "обзывание", "хаянье"],
    "хулалынья": ["хулалынь-я"],
    "хулгайлах": ["хулгай хийх"],
    "хуле": ["чего", "что", "фиг ли", "фигли", "хули", "хуля", "хуль", "какого хуя", "хуй ли", "почему", "зачем", "с какой целью", "что толку", "нечего", "какого чёрта"],
    "хуление": ["осуждение", "охаивание", "порицание", "хаянье", "хуленье", "захаивание", "неодобрение", "брань", "поношение"],
    "хуленье": ["хуление"],
    "хули": ["чего", "что", "фиг ли", "фигли", "хуле", "хуля", "хуль", "какого хуя", "хуй ли", "почему", "зачем", "с какой целью", "что толку", "нечего", "какого чёрта"],
    "хулиард": ["дохулион"],
    "хулив": ["хуливши"],
    "хуливши": ["хулив"],
    "хулиган": ["хулюган", "озорник", "шалопай", "шалун", "проказник"],
    "хулиганив": ["хулиганивши"],
    "хулиганивши": ["хулиганив"],
    "хулиганство": ["бандитизм"],
    "хулиганствовав": ["хулиганствовавши"],
    "хулиганствовавши": ["хулиганствовав"],
    "хулитель": ["ругатель", "порицатель"],
    "хулить": ["бранить", "поносить", "порочить"],
    "хуль": ["чего", "что", "фиг ли", "фигли", "хуле", "хули", "хуля", "какого хуя", "хуй ли", "почему", "зачем", "с какой целью", "что толку", "нечего", "какого чёрта"],
    "хуля": ["хули", "хуле", "хуль"],
    "хуля-перехуля": ["что", "чего", "какого чёрта", "зачем", "почему", "хуля", "хули", "хуле", "хуль"],
    "хуманизация": ["антропоморфизм", "антропоморфизация"],
    "хунн": ["гунн"],
    "хунну": ["сюнну"],
    "хунта": ["жунта"],
    "хунхуз": ["краснобородый"],
    "хуншуй": ["ханьшуй"],
    "хупавый": ["тщеславный", "хвастливый", "гордый"],
    "хур": ["морин хуур", "моринхур"],
    "хурма": ["фигня", "мелочь"],
    "хурмо": ["рутаб"],
    "хуршед": ["офтоб", "шед"],
    "хуршедпараст": ["офтобпараст"],
    "хусейн": ["хуссейн", "хусайн", "гусейн"],
    "хусит": ["хоусит", "хусист"],
    "хуссейн": ["хусейн"],
    "хутор": ["мыза", "усадьба", "фольварк"],
    "хуторный": ["хуторской"],
    "хуторской": ["хуторный"],
    "хуту": ["бахуту"],
    "хуфу": ["хеопс"],
    "хуцпа": ["дерзость", "наглость", "кураж"],
    "хучь": ["хоть", "пусть и", "пусть даже"],
    "хушбахт": ["фархунда"],
    "хушмуомила": ["хушрафтор"],
    "хушмуошират": ["хушрафтор"],
    "хушрафтор": ["хушмуомила", "хушмуошират"],
    "хуэй": ["хуэйцзу", "хуэец"],
    "хуя с два": ["ничего подобного", "как бы не так", "вот ещё", "чёрта с два"],
    "хуякав": ["хуякавши"],
    "хуякавши": ["хуякав"],
    "хуякать": ["ебать", "хуячить", "хуярить", "хуюжить"],
    "хуякнув": ["хуякнувши"],
    "хуякнувши": ["хуякнув"],
    "хуякнуть": ["пиздануть", "ебануть", "сказануть", "ляпнуть", "квакнуть", "пёрнуть"],
    "хуякс": ["бац", "бах", "бабах", "шлёп", "блямс", "трах", "трах-тарарах", "бумс", "хрясь", "фигак", "херак", "херакс", "хренак", "хренакс", "членак"],
    "хуярив": ["хуяривши"],
    "хуяривши": ["хуярив"],
    "хуярить": ["ебошить", "хуячить"],
    "хуястый": ["хуистый"],
    "хуячив": ["хуячивши"],
    "хуячивши": ["хуячив"],
    "хуёвее": ["хуёвей"],
    "хуёвей": ["хуёвее"],
    "хуёвина": ["хуятина", "хуятинка", "дрянь", "ерунда", "ерундовина", "штуковина", "фиговина", "хреновина", "хуйня", "хуетень", "поебень", "поебистика", "хуйвала", "поеботина"],
    "хуёвить": ["трясти", "температурить", "колбасить"],
    "хуёвничав": ["хуёвничавши"],
    "хуёвничавши": ["хуёвничав"],
    "хуёвничать": ["уросить"],
    "хуёво": ["хреново", "херово"],
    "хуёк": ["хуёчек", "хуишко", "хуишечко", "хуюсик", "хуюшечка", "хуюшечко"],
    "хуёчек плачет жгучею слезой": ["капает с конца", "с хуёчка капает"],
    "хъвади": ["псхъа"],
    "хъо": ["къо"],
    "хъуг": ["гъог"],
    "хъыджэбз": ["пщащэ"],
    "хъэ": ["къэ"],
    "хьэжъ": ["хьэ"],
    "хьэрф": ["уьф"],
    "хью": ["хьюи", "хьюго"],
    "хэви": ["хеви-метал", "хэви-метал", "хеви"],
    "хэви-метал": ["хеви-метал", "хеви-метал-рок", "хеви", "хэви"],
    "хэдканон": ["хэд"],
    "хэдлайнер": ["гвоздь программы", "звезда"],
    "хэйтер": ["хейтер"],
    "хэллоуин": ["день всех святых", "самхейн"],
    "хэллоуинский": ["хеллоуинский"],
    "хэм": ["хемингуэй", "папа хэм"],
    "хэмилтон": ["гамильтон", "хамильтон", "хамилтон"],
    "хэсап": ["хисаб", "хъэсаб", "хъэсап"],
    "хэток": ["шляпа"],
    "хэш": ["хеш-таблица", "ассоциативный массив"],
    "хэшировав": ["хэшировавши"],
    "хэшировавши": ["хэшировав"],
    "хёвдинг": ["вождь"],
    "цавой": ["завой"],
    "цавокав": ["цавокавши"],
    "цавокавши": ["цавокав"],
    "цавокать": ["цекать"],
    "цагъыр": ["чагъыр"],
    "цагъырадогъан": ["цагырадогон"],
    "цагырадогон": ["цагъырадогъан"],
    "цак": ["чагъ"],
    "цаловав": ["цаловавши"],
    "цаловавши": ["цаловав"],
    "цап": ["хвать"],
    "цапав": ["цапавши"],
    "цапавши": ["цапав"],
    "цапаться": ["ссориться"],
    "цапка": ["тяпка"],
    "цапковав": ["цапковавши"],
    "цапковавши": ["цапковав"],
    "цапля": ["чапля", "чапура"],
    "цапнув": ["цапнувши"],
    "цапнувши": ["цапнув"],
    "цапнуть": ["сцапать", "укусить", "тяпнуть"],
    "цапонлак": ["цапоновый лак", "цапон-лак"],
    "цапфа": ["шип"],
    "цапфенный": ["цапфовый"],
    "цапфовый": ["цапфенный"],
    "цар": ["центрально-африканская республика"],
    "царапав": ["царапавши"],
    "царапавши": ["царапав"],
    "царапание": ["царапанье"],
    "царапанье": ["царапание"],
    "царапина": ["ссадина"],
    "царапка": ["царапинка", "рукавичка", "царапалка"],
    "царапнув": ["царапнувши"],
    "царапнувши": ["царапнув"],
    "царапнуть": ["оцарапать", "покарябать", "поранить"],
    "царапучий": ["царапистый", "царапающий", "царапающийся"],
    "царга": ["рама"],
    "царевав": ["царевавши"],
    "царевавши": ["царевав"],
    "царевбивець": ["цареубивець", "цареубивця"],
    "царевбивця": ["царевбивець", "цареубивець"],
    "царевица": ["кукуруз", "мамули"],
    "царевич": ["королевич", "принц"],
    "царевна": ["королевна", "принцесса"],
    "царедворец": ["вельможа", "придворный", "сановник"],
    "царедворець": ["придворний"],
    "царение": ["царствование"],
    "царенко": ["царевич"],
    "царенье": ["царение"],
    "царетворец": ["имиджмейкер"],
    "царив": ["царивши"],
    "царивши": ["царив"],
    "царизм": ["самодержавие", "абсолютизм"],
    "царить": ["царствовать", "распоряжаться", "властвовать", "господствовать"],
    "царица": ["государыня", "матка", "королева"],
    "царская россия": ["российское царство", "российская империя"],
    "царственно": ["по-царски"],
    "царственный": ["царский"],
    "царство": ["царствование", "область", "сфера", "мир"],
    "царство польское": ["привислинский край", "губернии царства польского", "губернии привислинского края", "королевство польское", "конгрессова польша", "конгресовка"],
    "царствовав": ["царствовавши"],
    "царствовавши": ["царствовав"],
    "царствование": ["царение"],
    "царствованье": ["царствование"],
    "царствовать": ["править", "властвовать", "лидировать", "царить", "господствовать", "установиться"],
    "царь": ["самодержец", "монарх", "властелин", "король"],
    "царь в голове": ["голова на плечах"],
    "царь зверей": ["лев"],
    "царь-батюшка": ["государь"],
    "царь-птица": ["орёл"],
    "царьгород": ["царьград"],
    "царьград": ["константинополь", "стамбул", "истанбул", "царьгород"],
    "царёв": ["царский"],
    "цатыр": ["чатыр", "чадыр"],
    "цахал": ["армия обороны израиля"],
    "цацка": ["безделушка", "побрякушка", "финтифлюшка"],
    "цацкаться": ["нянчиться", "носиться", "возиться", "сюсюкаться", "панькаться", "церемониться"],
    "цвель": ["плесень", "грибок", "гниль", "заплесневелость", "плесневелость", "ряска", "тина", "сырость", "гнильё", "болото"],
    "цвет": ["окраска", "краска", "оттенок", "тон", "цветовой заряд"],
    "цветастость": ["пестрота"],
    "цветастый": ["цветистый", "пёстрый", "разноцветный"],
    "цветение герани": ["геранизация", "цветёт герань"],
    "цветень": ["апрель", "пыльца", "перга"],
    "цветенье": ["цветение"],
    "цветив": ["цветивши"],
    "цветивши": ["цветив"],
    "цветик": ["цветок"],
    "цветковые": ["покрытосеменные"],
    "цветковый": ["покрытосеменной", "покрытосемянный"],
    "цветная революция": ["оранжевая революция"],
    "цветной": ["многоцветный"],
    "цветовая слепота": ["дальтонизм"],
    "цветовод": ["флорист"],
    "цветоводка": ["флористка"],
    "цветовое взаимодействие": ["сильное взаимодействие"],
    "цветовой": ["колористический"],
    "цветок": ["растение"],
    "цветокорректура": ["цветокоррекция"],
    "цветокоррекция": ["цветокорректура"],
    "цветометрия": ["колориметрия"],
    "цветомузыка": ["светомузыка"],
    "цветоножка": ["плодоножка"],
    "цветотерапия": ["хромотерапия"],
    "цветофильтр": ["светофильтр"],
    "цветочный": ["цветковый"],
    "цветь": ["цветение", "цветы", "цвет"],
    "цветёт герань": ["цветение герани", "геранизация"],
    "цвинга": ["струбцина"],
    "цвинтар": ["кладовище", "кладовисько", "гробки", "могилки", "погребище", "гробовище"],
    "цвинтарний": ["кладовищенський"],
    "цвинькав": ["цвинькавши"],
    "цвинькавши": ["цвинькав"],
    "цвинькнув": ["цвинькнувши"],
    "цвинькнувши": ["цвинькнув"],
    "цвирикав": ["цвирикавши"],
    "цвирикавши": ["цвирикав"],
    "цвирикнув": ["цвирикнувши"],
    "цвирикнувши": ["цвирикнув"],
    "цвиркав": ["цвиркавши"],
    "цвиркавши": ["цвиркав"],
    "цвиркнув": ["цвиркнувши"],
    "цвиркнувши": ["цвиркнув"],
    "це": ["цэ"],
    "цебарка": ["ведро"],
    "цеберка": ["цеберко"],
    "цеберко": ["цеберка"],
    "цебярь": ["пара", "эхярь", "паронь арьси", "лямбе вайме", "ляпе вайме", "лац тиф", "мазы", "танцти"],
    "цебярь вайме": ["ляпе седи", "пара вайме"],
    "цебярьста": ["лац", "парста"],
    "цевница": ["кувиклы", "кувички", "кугиклы", "свирель", "сопелка", "лира"],
    "цегельний": ["цегляний"],
    "цедив": ["цедивши"],
    "цедивши": ["цедив"],
    "цедировав": ["цедировавши"],
    "цедировавши": ["цедировав"],
    "цедить": ["процеживать", "фильтровать"],
    "цедрат": ["цитрон"],
    "цежение": ["процеживание"],
    "цеживав": ["цеживавши"],
    "цеживавши": ["цеживав"],
    "цезаристский": ["диктаторский"],
    "цезаропапизм": ["цезарепапизм", "царепапизм", "кесаропапизм"],
    "цезарь": ["чезаре", "сезар", "сесар", "кайзер", "царь", "кесарь"],
    "цейлон": ["шри-ланка"],
    "цейлонец": ["ланкиец", "шриланкиец"],
    "цейссовский": ["цейсовский"],
    "цейтрафер": ["таймлапс"],
    "цейхгауз": ["армерия", "арсенал"],
    "цек": ["кракле", "кракелюра"],
    "цекав": ["цекавши"],
    "цекавши": ["цекав"],
    "цековав": ["цековавши"],
    "цековавши": ["цековав"],
    "цековать": ["зенкеровать"],
    "цековка": ["зенковка", "цекование"],
    "цекотомия": ["тифлотомия"],
    "целакант": ["латимерия"],
    "целая вечность": ["уйма"],
    "целебес": ["сулавеси"],
    "целебный": ["целительный", "лечебный"],
    "целевая аудитория": ["ца", "целевая группа"],
    "целевая группа": ["целевая аудитория"],
    "целенаправленно": ["целеустремлённо"],
    "целенаправленность": ["целеустремлённость"],
    "целесообразно": ["разумно"],
    "целесообразность": ["оправданность"],
    "целеустремление": ["целеустремлённость"],
    "целеустремлённый": ["настойчивый", "упёртый"],
    "целиакия": ["глютеновая энтеропатия"],
    "целив": ["целивши"],
    "целивши": ["целив"],
    "целиковый": ["цельный"],
    "целиком и полностью": ["совершенно", "безоговорочно"],
    "целина": ["селина", "келина"],
    "целиноград": ["астана", "акмола", "акмолинск"],
    "целитель": ["врачеватель", "утешитель"],
    "целительно": ["целебно"],
    "целительный": ["целебный"],
    "целительство": ["врачевание", "нетрадиционная медицина"],
    "целить": ["метить"],
    "целиться": ["прицеливаться", "целить"],
    "целковый": ["рубль", "целковик"],
    "целла": ["наос"],
    "целлофанировав": ["целлофанировавши"],
    "целлофанировавши": ["целлофанировав"],
    "целлулоидный": ["целлулоидовый"],
    "целлюлит": ["гиноидный", "липодистрофия"],
    "целлюлоза": ["клетчатка"],
    "целлюлозник": ["целлюлозо-бумажник"],
    "целовав": ["целовавши"],
    "целовавши": ["целовав"],
    "целовальник": ["кабатчик"],
    "целовать": ["лобызать", "лобзать"],
    "целоваться": ["цаловаться"],
    "целое число": ["целое"],
    "целозначный": ["целочисленный"],
    "целокупный": ["целостный"],
    "целомудренник": ["авраамово дерево", "монашеский перец"],
    "целомудренно": ["непорочно"],
    "целомудренный": ["девственный", "непорочный", "стыдливый", "скромный"],
    "целомудрие": ["девственность", "невинность", "непорочность", "целомудренность"],
    "целостный": ["цельный"],
    "целость": ["неприкосновенность"],
    "целотонный": ["целотоновый"],
    "целый": ["весь", "полный", "единый", "цельный", "целостный", "неиспорченный", "неповреждённый", "неурезанный", "непочатый", "невредимый", "сохранный", "настоящий"],
    "цель": ["умысел", "намерение", "предел", "задача", "объект", "мишень", "жертва", "мушка"],
    "цельно": ["полностью", "целиком"],
    "цельнодеревянный": ["цельнодеревый"],
    "цельнокатанность": ["цельнотянутость"],
    "цельнокатаный": ["цельнотянутый"],
    "цельнокрайный": ["цельнокрайний"],
    "цельность": ["неделимость", "нераздельность", "целость"],
    "цельнотянутый": ["позаимствованный", "ворованный", "нелицензионный"],
    "цельный": ["целиковый"],
    "цементация": ["цементирование", "цементировка"],
    "цементировав": ["цементировавши"],
    "цементировавши": ["цементировав"],
    "цементирование": ["цементация", "цементировка"],
    "цементовав": ["цементовавши"],
    "цементовавши": ["цементовав"],
    "цена": ["стоимость", "плата", "значимость", "ценность"],
    "ценестезия": ["кинестезия"],
    "ценз": ["перепись", "чинш"],
    "цензировав": ["цензировавши"],
    "цензировавши": ["цензировав"],
    "цензор": ["ценсор"],
    "цензурировав": ["цензурировавши"],
    "цензурировавши": ["цензурировав"],
    "цензурировать": ["цензуровать"],
    "цензуровав": ["цензуровавши"],
    "цензуровавши": ["цензуровав"],
    "цензуровать": ["цензурировать"],
    "ценив": ["ценивши"],
    "ценивши": ["ценив"],
    "ценитель": ["любитель", "поклонник", "знаток"],
    "ценительница": ["любительница", "знаток"],
    "ценить": ["оценивать", "дорожить"],
    "цениться": ["стоить", "почитаться"],
    "ценник": ["прайс-лист", "прейскурант"],
    "ценно": ["полезно"],
    "ценностно-ориентационный": ["ценностно-ориентировочный"],
    "ценностный": ["ценовой"],
    "ценность": ["значимость", "полезность", "стоимость", "цена", "драгоценность", "сокровище", "норма"],
    "ценный": ["драгоценный", "дорогой", "важный", "бесценный", "полезный"],
    "ценный специалист": ["трудовой мигрант", "гастарбайтер", "ценный иностранный специалист"],
    "ценовый": ["ценовой", "стоимостный"],
    "ценология": ["биоценология"],
    "центаво": ["сентаво"],
    "центавр": ["кентавр"],
    "центениал": ["зумер", "хоумлендер"],
    "центиль": ["процентиль"],
    "центифолия": ["сентифолия", "прованская роза", "капустная роза", "майская роза"],
    "центнер": ["квинтал", "децитонна"],
    "центон": ["лоскутное стихотворение"],
    "центр масс": ["центр инерции", "барицентр"],
    "централизм": ["централизация"],
    "централизовав": ["централизовавши"],
    "централизовавши": ["централизовав"],
    "центральная нервная система": ["цнс"],
    "центрально-африканская республика": ["цар", "центральноафриканская республика"],
    "центральное разведывательное управление": ["цру"],
    "центральнокурдский язык": ["сорани"],
    "центральный административный округ": ["цао"],
    "центральный банк": ["центробанк", "национальный банк", "государственный банк", "народный банк", "резервный банк", "эмиссионный банк", "федеральный банк"],
    "центрее": ["центральнее"],
    "центрировав": ["центрировавши"],
    "центрировавши": ["центрировав"],
    "центрировка": ["центрирование"],
    "центрифуга": ["центробег", "центробежка"],
    "центрифугировав": ["центрифугировавши"],
    "центрифугировавши": ["центрифугировав"],
    "центрифужный": ["центробежный"],
    "центровав": ["центровавши"],
    "центровавши": ["центровав"],
    "центровальный": ["центровочный"],
    "центрование": ["центровка"],
    "центровочный": ["центровальный"],
    "центроид": ["барицентр"],
    "центроид треугольника": ["барицентр треугольника", "центр тяжести треугольника"],
    "центромера": ["кинетохор", "киномера"],
    "центросома": ["центросфера", "центроплазма"],
    "центросфера": ["центросома", "центроплазма"],
    "центрфорвард": ["центрофорвард", "центральный нападающий"],
    "центурион": ["кентурион", "сотник"],
    "центурия": ["кентурия"],
    "ценуроз": ["вертячка"],
    "цеп": ["боевой цеп", "молотило", "телепень"],
    "цепанув": ["цепанувши"],
    "цепанувши": ["цепанув"],
    "цепенев": ["цепеневши"],
    "цепеневши": ["цепенев"],
    "цепенеть": ["замирать", "застывать", "коченеть", "дубеть"],
    "цепенив": ["цепенивши"],
    "цепенивши": ["цепенив"],
    "цепив": ["цепивши"],
    "цепивши": ["цепив"],
    "цепкий": ["стеснять", "вязкий", "вяжущий", "упорный", "настойчивый", "упрямый"],
    "цепляв": ["цеплявши"],
    "цеплявши": ["цепляв"],
    "цеплянье": ["цепляние"],
    "цеплять": ["зацеплять", "подцеплять"],
    "цепочечка": ["цепочка"],
    "цеппелин": ["дирижабль", "диджкукулиай"],
    "цера": ["вощечка"],
    "цератония": ["кератония"],
    "цервикальный": ["шейный"],
    "цервикальный канал": ["эндоцервикс"],
    "церебрализация": ["кефализация", "энцефализация"],
    "церебральний": ["мозковий"],
    "церебральный": ["мозговой", "какуминальный"],
    "цереброзид": ["гликосфинголипид"],
    "цереброспинальная жидкость": ["спинномозговая жидкость", "ликвор"],
    "цереброспинальный": ["спинномозговой"],
    "церемониал": ["ритуал"],
    "церемониться": ["стесняться"],
    "церемония": ["церемониал", "обряд", "ритуал", "размеренность", "учтивость", "вежливость"],
    "церемонничав": ["церемонничавши"],
    "церемонничавши": ["церемонничав"],
    "церемонно": ["чопорно"],
    "церера": ["деметра"],
    "церкария": ["церкарий"],
    "церква": ["церковь", "храм"],
    "церковник": ["церковнослужитель", "священнослужитель", "священник", "святоша"],
    "церковничий": ["церковный", "церковников"],
    "церковно-богослужебный": ["богослужебный"],
    "церковно-приходский": ["церковноприходской"],
    "церковноприходский": ["церковноприходской"],
    "церковноприходской": ["церковноприходский"],
    "церковнославянский язык": ["славянский язык"],
    "церковнослужитель": ["причетник"],
    "церковушка": ["церковь", "церквушка"],
    "церковь": ["храм", "церква"],
    "цесаревич": ["кронпринц"],
    "цесаревна": ["кронпринцесса"],
    "цесариный": ["цесарковый"],
    "цесарковый": ["цесариный"],
    "цесарь": ["монарх", "самодержец", "кесарь"],
    "цессионар": ["цессионер", "цессионарий"],
    "цессионарий": ["цессионер", "цессионар", "перестраховщик"],
    "цессионер": ["цессионар", "цессионарий"],
    "цессия": ["уступка требования"],
    "цеста": ["пут"],
    "цестода": ["лентец"],
    "цетан": ["гексадекан"],
    "цетология": ["кетология"],
    "цефалгия": ["головная боль"],
    "цех": ["гильдия"],
    "цехин": ["дукат"],
    "цеховик": ["цеховщик"],
    "цеховщик": ["цеховик"],
    "цеховый": ["цеховой"],
    "цецек": ["чичэк"],
    "цецидия": ["галл"],
    "цецилия": ["сесилия"],
    "цзян": ["чан"],
    "ци": ["чи", "ки", "це"],
    "циан": ["дициан"],
    "цианизация": ["цианирование"],
    "цианировав": ["цианировавши"],
    "цианировавши": ["цианировав"],
    "цианистый водород": ["синильная кислота", "нитрил муравьиной кислоты"],
    "цианобактерия": ["сине-зелёный", "водоросль"],
    "цианоз": ["синюха"],
    "цибетон": ["циветон"],
    "цибик": ["цыбик"],
    "цивета": ["циветта", "виверра"],
    "циветта": ["цивета", "виверра"],
    "цивилизация": ["сивилизация", "цивилизованность"],
    "цивилизовав": ["цивилизовавши"],
    "цивилизовавши": ["цивилизовав"],
    "цивилизованность": ["культурность"],
    "цивилизовывав": ["цивилизовывавши"],
    "цивилизовывавши": ["цивилизовывав"],
    "цивилистика": ["гражданское право"],
    "цивилка": ["обывательница"],
    "цивильно": ["по-граждански", "штатски", "по-штатски"],
    "цивильное": ["штатское", "гражданское", "партикулярное"],
    "цивильный": ["гражданский", "штатский", "светский", "неофициальный", "партикулярный", "цивилизованный", "приличный", "культурный", "качественный", "достойный"],
    "циганеня": ["циганя", "циганча", "циганчук"],
    "циганча": ["циганя", "циганчук"],
    "циганя": ["циганча", "циганчук"],
    "цигарка": ["самокрутка", "цыгарка"],
    "цидула": ["цидуля"],
    "цидулка": ["цидула", "цидулька"],
    "цидуля": ["записка", "письмо", "цидула"],
    "цизальпийская галлия": ["предальпийская галлия"],
    "цик": ["центризбирком", "центральная избирательная комиссия"],
    "цикавый": ["интересный", "любопытный", "занимательный", "интересующийся", "пытливый", "сварливый"],
    "цикас": ["саговник"],
    "цикл": ["круг", "оборот", "сборник", "серия", "осадочный цикл", "седиментационный цикл"],
    "цикламен": ["дряква", "альпийская фиалка"],
    "циклевав": ["циклевавши"],
    "циклевавши": ["циклевав"],
    "циклевание": ["циклёвка"],
    "циклив": ["цикливши"],
    "цикливши": ["циклив"],
    "циклизовав": ["циклизовавши"],
    "циклизовавши": ["циклизовав"],
    "циклизовать": ["зацикливать", "зациклить"],
    "циклировав": ["циклировавши"],
    "циклировавши": ["циклировав"],
    "циклит": ["циклитол", "синтема"],
    "циклический": ["цикличный", "повторяющийся"],
    "цикличность": ["периодичность", "повторяемость"],
    "цикличный": ["циклический", "регулярный", "возвратный"],
    "циклоалкан": ["полиметиленовый углеводород", "нафтен", "циклан", "циклопарафин"],
    "циклобутан": ["тетраметилен"],
    "цикловав": ["цикловавши"],
    "цикловавши": ["цикловав"],
    "циклогексанол": ["гексалин"],
    "циклодекстринный": ["циклодекстриновый"],
    "циклодекстриновый": ["циклодекстринный"],
    "цикложир": ["циклоптер", "циклокоптер"],
    "циклоида": ["рулетта"],
    "циклоидальный": ["циклоидный"],
    "циклоидный": ["циклоидальный"],
    "циклон": ["буря", "ураган", "шторм", "тайфун", "центрифуга"],
    "циклонический": ["циклональный"],
    "циклооксигеназа": ["простагландинсинтаза", "простагландинсинтетаза"],
    "циклооктан": ["октаметилен"],
    "циклоп": ["великан", "киклоп", "полифем", "чудовище"],
    "циклопарафин": ["циклоалкан"],
    "циклопентан": ["пентаметилен"],
    "циклопентанпергидрофенантрен": ["стеран", "гонан"],
    "циклопический": ["колоссальный"],
    "циклотимный": ["циклоидный"],
    "цикля": ["скобель"],
    "цикута": ["вёх", "вех"],
    "цилиндрический": ["цилиндричный"],
    "цилиндричный": ["цилиндрический"],
    "цилиндроид": ["псевдоцилиндр"],
    "цимбопогон": ["лимонное сорго"],
    "цимес": ["прелесть", "изюминка"],
    "цимесность": ["смачность", "привлекательность"],
    "цимесный": ["смачный", "кошерный"],
    "цимлянское": ["цимлянское вино"],
    "цимозный": ["цимоидный", "симподиальный"],
    "цимол": ["метилпропилбензол"],
    "цимус": ["цимес"],
    "цина": ["оливо", "олово", "цинк"],
    "цинародий": ["цинарродий"],
    "цинарродий": ["цинародий"],
    "цинга": ["скорбут", "цынга"],
    "цинготный": ["скорбутный", "цинготник"],
    "цинерария": ["зольник", "пепельник"],
    "цинжать": ["цинготеть"],
    "цинизм": ["кинизм", "циничность"],
    "циник": ["киник"],
    "циничность": ["цинизм"],
    "циничный": ["цинический"],
    "цинк": ["цинка", "цинковый гроб"],
    "цинка": ["цинк"],
    "цинковав": ["цинковавши"],
    "цинковавши": ["цинковав"],
    "цинковать": ["оцинковывать"],
    "цинкографический": ["цинкографский"],
    "цинния": ["циния"],
    "циновка": ["цыновка", "рогожа"],
    "цинхона": ["хинное дерево"],
    "цинхоновый": ["хинный"],
    "цип": ["спецприёмник"],
    "циперус": ["сыть"],
    "ципрея": ["каури", "фарфорка"],
    "циприпедиум": ["башмачок"],
    "циранапох": ["дудук"],
    "цирей": ["гнойник", "абсцес", "фистула"],
    "цирк": ["клоунада", "дурдом", "потеха", "советский цирк", "цирк с огнями", "цирк с конями", "цирк на льду", "цирк да и только", "и в цирк ходить не надо", "к нам приехал цирк"],
    "циркадный": ["циркадианный"],
    "циркач": ["артист цирка", "фигляр"],
    "циркообразный": ["кратерный"],
    "циркорама": ["кругорама", "круговая кинопанорама"],
    "циркулировав": ["циркулировавши"],
    "циркулировавши": ["циркулировав"],
    "циркулирование": ["циркуляция"],
    "циркулирующий иммунный комплекс": ["цик"],
    "циркуль": ["козья ножка"],
    "циркулярный": ["циркульный", "круглый"],
    "циркуляция": ["циркулирование", "круговорот"],
    "циркумполярный": ["околополярный"],
    "циркумпонтида": ["причерноморье"],
    "циркумфикс": ["конфикс"],
    "циркумфлексный": ["циркумфлексовый"],
    "циркумфлексовый": ["циркумфлексный"],
    "циркумцизия": ["обрезание"],
    "цирульня": ["цилюрня", "перукарня"],
    "цирюльник": ["парикмахер", "брадобрей", "лекарь"],
    "цирюльня": ["парикмахерская", "барбершоп"],
    "цис-положение": ["цис-конфигурация"],
    "циссоида": ["циссоидаль"],
    "циссоидаль": ["циссоида"],
    "циссоидальный": ["циссоидный"],
    "цистерна": ["танк", "вагон-цистерна"],
    "цистицерк": ["финна", "пузырехвост"],
    "цистицеркоз": ["финноз"],
    "цистофиброскоп": ["фиброцистоскоп"],
    "цитадель": ["крепость", "донжон", "оплот", "твердыня", "опора", "средоточие", "прибежище"],
    "цитадельный": ["крепостной", "тюремный"],
    "цитата": ["выдержка"],
    "цитация": ["цитирование", "цитата"],
    "цитернадель": ["трясилка", "трясулька"],
    "цитировав": ["цитировавши"],
    "цитировавши": ["цитировав"],
    "цитирование": ["библиографическая ссылка"],
    "цитированье": ["цитирование"],
    "цитовав": ["цитовавши"],
    "цитовавши": ["цитовав"],
    "цитовать": ["цитировать"],
    "цитогамия": ["плазмогамия"],
    "цитоз": ["цитемия"],
    "цитозоль": ["гиалоплазма"],
    "цитокинез": ["цитотомия"],
    "цитокиновый шторм": ["гиперцитокинемия"],
    "цитолемма": ["плазмалемма"],
    "цитолимфа": ["гиалоплазма", "энхилема"],
    "цитология": ["клеточная биология"],
    "цитоплазматическая мужская стерильность": ["цмс"],
    "цитотомия": ["цитокинез"],
    "цитофотометрия": ["цитоспектрофотометрия"],
    "цитохром": ["гемопротеин"],
    "цитрат натрия": ["лимоннокислый натрий"],
    "цитрон": ["цедрат"],
    "цитрофортунелла": ["каламондин"],
    "циферка": ["цифрочка"],
    "цифра": ["показатель", "параметр", "число", "цифровой фотоаппарат"],
    "цифратор": ["дигитайзер"],
    "цифро-аналоговый": ["цифроаналоговый", "аналого-цифровой"],
    "цифроаналоговый": ["цифро-аналоговый", "аналого-цифровой"],
    "цифровав": ["цифровавши"],
    "цифровавши": ["цифровав"],
    "цифровая вычислительная машина": ["цвм", "эвм"],
    "цифровая фотокамера": ["цифровой фотоаппарат", "цифровик"],
    "цифровизация": ["дигитализация", "компьютеризация", "информатизация"],
    "цифровизировав": ["цифровизировавши"],
    "цифровизировавши": ["цифровизировав"],
    "цифровизовав": ["цифровизовавши"],
    "цифровизовавши": ["цифровизовав"],
    "цифровое золото": ["биткоин"],
    "цифровой": ["численный", "числовой"],
    "цифровой детокс": ["цифровая детоксикация"],
    "цифровой финансовый актив": ["цфа"],
    "цифровой фотоаппарат": ["цифровая фотокамера", "цифровая камера", "цифровик", "цифрофот"],
    "цицания": ["зизания", "канадский рис"],
    "цицес": ["цицит"],
    "циция": ["скъперник", "сребролюбец", "скръндза", "стипца"],
    "цк влксм": ["центральный комитет влксм"],
    "цнс": ["центральная нервная система"],
    "цоизит": ["зауальпит", "аниолит"],
    "цой": ["чхве"],
    "цокав": ["цокавши"],
    "цокавши": ["цокав"],
    "цокнув": ["цокнувши"],
    "цокнувши": ["цокнув"],
    "цоколь": ["постамент"],
    "цоколёвка": ["разводка", "распиновка"],
    "цокотав": ["цокотавши"],
    "цокотавши": ["цокотав"],
    "цокотуха": ["болтунья", "болтушка", "говорунья", "сорока", "стрекоза", "стрекотунья", "тараторка", "трещотка"],
    "цонг": ["къух", "арм"],
    "цопав": ["цопавши"],
    "цопавши": ["цопав"],
    "цопать": ["хватать", "цапать", "давать волю рукам", "лапать", "пьянствовать", "выпивать", "бухать", "кирять"],
    "цопнув": ["цопнувши"],
    "цопнувши": ["цопнув"],
    "цопнуть": ["схватить", "сцапать", "сцопать", "бухнуть", "врезать"],
    "цохилт": ["шаах"],
    "црен": ["чрен", "цырен"],
    "цру": ["центральное разведывательное управление", "ведомство плаща и кинжала", "ведомство рыцарей плаща и кинжала"],
    "цсу": ["центральное статистическое управление"],
    "цугундер": ["экзекуция"],
    "цугфлейта": ["цуг-флейта"],
    "цугцванг": ["тупик", "безвыходность", "безысходность"],
    "цук": ["дедовщина"],
    "цукав": ["цукавши"],
    "цукавши": ["цукав"],
    "цукать": ["погонять", "понукать", "одёргивать", "выговаривать", "делать выговор", "поучать", "придираться", "гонять", "донимать", "допекать", "досаждать", "изводить", "шугать", "дрючить"],
    "цукерка": ["цукерак"],
    "цукерок": ["цукерка"],
    "цуккини": ["цукини"],
    "цукорниця": ["цукерниця"],
    "цунами": ["калейдоскоп", "круговорот", "круговерть"],
    "цунар": ["чурка"],
    "цунареф": ["цунер", "чурка", "хач", "хурмоед", "грач", "клюв", "чёрный", "черножопый"],
    "цундере": ["цундэрэ"],
    "цундэрэ": ["цундере"],
    "цуценя": ["щеня", "щенятко", "цуценятко", "молокосос"],
    "цуцик": ["щенок", "щеночек", "кутёнок", "юнец", "молокосос", "мальчишка", "сопляк", "сопля", "сопливец", "сосунок", "салага", "птенец"],
    "цхинвал": ["цхинвали", "сталинир", "сталинири"],
    "цхинвали": ["цхинвал"],
    "цъфтеж": ["разцъфтяване", "цъфтене"],
    "цыбик": ["цибик"],
    "цыган": ["обманщик", "плут"],
    "цыганив": ["цыганивши"],
    "цыганивши": ["цыганив"],
    "цыганин": ["цыган"],
    "цыганка": ["помидор"],
    "цыганология": ["цыгановедение"],
    "цыганочка": ["цыганка"],
    "цыганская игла": ["цыганская иголка"],
    "цыганский пот": ["дрожь", "озноб"],
    "цыганский язык": ["романи"],
    "цыганствовав": ["цыганствовавши"],
    "цыганствовавши": ["цыганствовав"],
    "цыганщина": ["вульгарность", "страстность", "диковатость"],
    "цыганёночек": ["цыганёнок"],
    "цыганёночка": ["цыганочка"],
    "цыгъыс": ["чыгъыш"],
    "цыкав": ["цыкавши"],
    "цыкавши": ["цыкав"],
    "цыканье": ["цыкание"],
    "цыкать": ["цыцкать", "цокать"],
    "цыкнув": ["цыкнувши"],
    "цыкнувши": ["цыкнув"],
    "цынга": ["цинга", "скорбут"],
    "цынготев": ["цынготевши"],
    "цынготевши": ["цынготев"],
    "цыновка": ["циновка", "рогожа"],
    "цып-цып": ["цыпа-цыпа"],
    "цыпа": ["курица", "цыпочка"],
    "цыплятник": ["курятник"],
    "цыплёнок": ["цыплятина"],
    "цыпонька": ["цыпочка"],
    "цыпочка": ["цыпа", "цыпка"],
    "цыпочки": ["цыпки"],
    "цыркав": ["цыркавши"],
    "цыркавши": ["цыркав"],
    "цыркнув": ["цыркнувши"],
    "цыркнувши": ["цыркнув"],
    "цытвар": ["цытвора"],
    "цытвора": ["цытвар"],
    "цыц": ["ша", "тсс", "ш-ш-ш", "тихо", "молчать"],
    "цыцкав": ["цыцкавши"],
    "цыцкавши": ["цыцкав"],
    "цыцкнув": ["цыцкнувши"],
    "цыцкнувши": ["цыцкнув"],
    "цьомання": ["цьомкання"],
    "цьомати": ["цмокати"],
    "цэ": ["це"],
    "цю": ["аф эряви", "тят"],
    "цябол": ["илёв", "ёло"],
    "цямриння": ["цямрина"],
    "цянь": ["чох"],
    "цяпер": ["зараз"],
    "цяпцюх": ["тюрьма", "острог", "колония"],
    "ча": ["кьят", "джа"],
    "чабан": ["овчар"],
    "чабанив": ["чабанивши"],
    "чабанивши": ["чабанив"],
    "чабановав": ["чабановавши"],
    "чабановавши": ["чабановав"],
    "чабановать": ["чабанить"],
    "чабанствовав": ["чабанствовавши"],
    "чабанствовавши": ["чабанствовав"],
    "чабаня": ["чабаненко", "чабанчук"],
    "чабер": ["чабёр", "тимьян", "чабрец"],
    "чабрец": ["чебрец", "чабёр", "чабер", "чабор", "чебер", "чобр", "щебер", "щеберник", "москоский чабер", "москоский чабор", "душевик", "богородская трава", "богородская травка", "богородичная трава", "тимьян"],
    "чабрик": ["чабер"],
    "чабёр": ["чабер", "тимьян", "чабрец"],
    "чавахъ": ["балугъ"],
    "чавкав": ["чавкавши"],
    "чавкавши": ["чавкав"],
    "чавкание": ["чавканье"],
    "чавкать": ["хлюпать"],
    "чавкнув": ["чавкнувши"],
    "чавкнувши": ["чавкнув"],
    "чаво": ["чзв"],
    "чага": ["берёзовый гриб"],
    "чагар": ["чагарник"],
    "чагарник": ["чагар"],
    "чад": ["республика чад"],
    "чадив": ["чадивши"],
    "чадивши": ["чадив"],
    "чадить": ["дымить", "дымиться", "коптить"],
    "чадолюбний": ["чадолюбивий"],
    "чадородный": ["половой", "пубертатный", "репродуктивный"],
    "чадородье": ["чадородие"],
    "чадорождение": ["деторождение"],
    "чадоубийца": ["детоубийца"],
    "чадце": ["чадо"],
    "чадыр": ["цатыр", "чатыр"],
    "чаевав": ["чаевавши"],
    "чаевавши": ["чаевав"],
    "чаевание": ["чаеванье"],
    "чаеванье": ["чаевание"],
    "чаелюб": ["чаеман"],
    "чаеман": ["чаелюб"],
    "чаемый": ["будущий"],
    "чаепитие": ["чай"],
    "чаепитье": ["чаепитие"],
    "чаесборочный": ["чаеуборочный"],
    "чай": ["камелия китайская", "чайный куст", "чаеподобный напиток", "травяной чай", "чаепитие"],
    "чайка-хохотун": ["чайка-хохотунья"],
    "чайнафобия": ["китаефобия", "синофобия"],
    "чайник": ["электрочайник", "заварник", "запарник"],
    "чайничав": ["чайничавши"],
    "чайничавши": ["чайничав"],
    "чайничание": ["чайничанье", "чаёвничание"],
    "чайное дерево": ["мелалеука"],
    "чайный куст": ["камелия китайская"],
    "чайот": ["чайота", "мексиканский огурец"],
    "чайпа": ["чэйпа"],
    "чайхана": ["чайная"],
    "чайченя": ["пташечка"],
    "чакан": ["куга"],
    "чакра": ["падма", "марма", "шакрам"],
    "чакрыжив": ["чакрыживши"],
    "чакрыживши": ["чакрыжив"],
    "чакрыжить": ["чекрыжить"],
    "чакрыжник": ["чекрыжник"],
    "чалап": ["танъры", "алла", "ярадан", "рабби", "мевля", "илях", "худа"],
    "чалдон": ["челдон", "чолдон", "сибиряк"],
    "чалив": ["чаливши"],
    "чаливши": ["чалив"],
    "чалка": ["причаливание", "чал", "швартов"],
    "чалма": ["тюрбан"],
    "чалмоносец": ["мусульманин"],
    "чалый": ["чалко"],
    "чамасы": ["чамасында", "диярлек"],
    "чамрошный": ["невзрачный", "хилый"],
    "чан": ["чжан", "чжэнь", "цзян"],
    "чангкашак": ["гардкашак"],
    "чангча": ["чангол"],
    "чановой": ["чановщик", "чанщик"],
    "чао": ["чао какао", "ариведерчи", "аста маньяна", "чаушки"],
    "чапав": ["чапавши"],
    "чапавши": ["чапав"],
    "чапан": ["чепан"],
    "чапарраль": ["чапараль", "чапаррель"],
    "чапаруха": ["чепарка"],
    "чапать": ["трюхать", "хватать", "цепляться", "качать", "шатать"],
    "чапельник": ["сковородник", "чепела"],
    "чапкънин": ["чапкън", "развратник", "коцкар", "женкар"],
    "чапленя": ["чапленятко"],
    "чаплин": ["чаплиний"],
    "чаплиний": ["чаплин"],
    "чапля": ["цапля", "чапура"],
    "чаполоч": ["чаполоть"],
    "чапыга": ["чапига", "чепига", "чепыга", "чапыжник"],
    "чапыжник": ["чепыжник", "чапыга", "дробнолесок"],
    "чара": ["чарка"],
    "чарадзей": ["вядзьмак", "вядзьмар"],
    "чарас": ["чарыш"],
    "чарвака": ["локаята"],
    "чарджоу": ["туркменабад"],
    "чарка": ["чара", "стопка", "рюмка", "кубок"],
    "чаркъ": ["копчек"],
    "чарлз": ["чарльз"],
    "чарлстон": ["чарльстон"],
    "чарльз": ["чарлз"],
    "чарльстон": ["чарлстон"],
    "чарльстонив": ["чарльстонивши"],
    "чарльстонивши": ["чарльстонив"],
    "чаровав": ["чаровавши"],
    "чаровавши": ["чаровав"],
    "чарование": ["обаятельность", "очарование", "обольстительность", "чаровать", "сила", "пленительность", "прелесть", "неотразимость", "чары", "обаяние"],
    "чарованье": ["чарование"],
    "чаровать": ["пленять", "обвораживать", "завораживать", "сводить с ума", "околдовывать", "прельщать", "заколдовывать", "очаровывать", "зачаровывать", "покорять"],
    "чаровник": ["шармёр"],
    "чародей": ["маг", "волшебник", "колдун", "волхв", "тайновидец"],
    "чародейка": ["волшебница", "колдунья", "чаровница"],
    "чародействовав": ["чародействовавши"],
    "чародействовавши": ["чародействовав"],
    "чартер": ["договор фрахтования", "чартер-партия", "цертепартия", "чартерный рейс"],
    "чаруса": ["трясина", "топь"],
    "чарчаф": ["фередж", "фередже", "паранджа", "шаршаф", "чадра"],
    "чары": ["волшебство", "колдовство", "обаяние", "очарование"],
    "часик": ["часов яр"],
    "часов яр": ["часик"],
    "часовник": ["часослов"],
    "часовня": ["часовенка"],
    "часовой": ["одночасовой", "шестидесятиминутный", "почасовой", "охранник", "караульный"],
    "часок": ["часик"],
    "часослов": ["часовник"],
    "частив": ["частивши"],
    "частивши": ["частив"],
    "частик": ["частушка"],
    "частина": ["пайка", "шматок"],
    "частица": ["часть", "доля", "толика", "элемент", "компонент", "элементарная частица", "партикль", "постфикс"],
    "частично": ["неполностью", "отчасти"],
    "частичность": ["фрагментарность", "выборочность"],
    "частичный": ["неполный"],
    "частка": ["частина"],
    "частная военная компания": ["чвк"],
    "частный": ["частичный", "отдельный", "случайный", "нехарактерный", "личный", "приватный", "персональный", "индивидуальный"],
    "частный дом": ["тюрьма", "место", "заключения", "заключение", "темница", "застенок", "острог", "кутузка", "клетка", "решётка", "камера", "карцер", "яма"],
    "часто": ["то и дело", "частенько", "периодически", "нередко", "обычно", "регулярно", "постоянно", "повседневно", "густо", "плотно"],
    "частота": ["встречаемость", "частотность", "кратность"],
    "частота встречаемости": ["встречаемость", "процент встречаемости"],
    "частота сердечных сокращений": ["чсс"],
    "частотная модуляция": ["чм"],
    "частотник": ["преобразователь частоты"],
    "частотность": ["частота"],
    "частотомер": ["частотометр"],
    "частуха": ["алисма", "водяной подорожник"],
    "частушечка": ["говорушечка"],
    "частый": ["густой"],
    "часть": ["доля", "полк", "корабль", "войсковая часть"],
    "часть тела": ["член"],
    "часъ": ["година", "пора"],
    "часы": ["котлы"],
    "чат": ["болталка"],
    "чатан": ["аксак"],
    "чатик": ["чат"],
    "чатовий": ["дозорний"],
    "чатр": ["соябон", "шамсия"],
    "чатранг": ["хатуранга", "шатранг"],
    "чатыр": ["цатыр", "чадыр"],
    "чать": ["чай"],
    "чаубунагунгамауг": ["озеро вебстера", "вебстерское озеро"],
    "чауш": ["чаус"],
    "чафон": ["цафон"],
    "чахнув": ["чахнувши"],
    "чахнувши": ["чахнув"],
    "чахнуть": ["хилеть", "хиреть"],
    "чахотка": ["бугорчатка", "туберкулёз", "туберкулёз лёгких", "кровохарканье"],
    "чахоточный": ["чахотный", "туберкулёзный"],
    "чачван": ["чашман", "чиммет", "чашмбанд"],
    "чаша": ["кубок", "чарка", "чара", "пиала", "братина", "участь", "судьба"],
    "чашка": ["чашечка", "чаша"],
    "чашм": ["дида", "кобина"],
    "чашник": ["чашничий"],
    "чашничав": ["чашничавши"],
    "чашничавши": ["чашничав"],
    "чаща": ["заросль"],
    "чаще": ["почаще"],
    "чаще всего": ["преимущественно", "обычно"],
    "чащоба": ["чаща"],
    "чаяв": ["чаявши"],
    "чаявши": ["чаяв"],
    "чаяние": ["ожидание", "надежда", "мечта"],
    "чаятельно": ["вероятно", "наверно", "по-видимому", "может быть"],
    "чаять": ["думать", "надеяться", "уповать", "ожидать", "предполагать"],
    "чаёвничав": ["чаёвничавши"],
    "чаёвничавши": ["чаёвничав"],
    "чаёвничание": ["чаепитие"],
    "чаёвничанье": ["чаевничанье", "чаёвничание"],
    "чаёвничать": ["пить"],
    "чаёк": ["чаёчек", "чай"],
    "чвакав": ["чвакавши"],
    "чвакавши": ["чвакав"],
    "чвакнув": ["чвакнувши"],
    "чвакнувши": ["чвакнув"],
    "чвакнуть": ["чмокнуть"],
    "чвакнуться": ["чмокнуться"],
    "чваниться": ["зазнаваться", "задаваться", "кичиться", "спесивиться", "надмеваться", "тщеславиться"],
    "чванливий": ["чванькуватий"],
    "чванливо": ["кичливо"],
    "чванливость": ["гордыня", "кичливость", "спесь", "спесивость", "чванство"],
    "чванливый": ["чванный", "надменный", "надутый", "спесивый", "чванноватый"],
    "чванный": ["чванливый", "чванистый", "тщеславный", "кичливый", "спесивый", "высокомерный", "заносчивый", "надменный", "ломливый"],
    "чванство": ["чванливость", "чвань", "спесь", "высокомерие", "надменность", "гордыня", "тщеславие", "гонор", "заносчивость", "важничанье", "зазнайство", "гордость", "горделивость", "кичливость", "надутость"],
    "чви": ["тви"],
    "чвк": ["частная военная компания"],
    "чеби": ["чебеш"],
    "чеболь": ["дзайбацу"],
    "чеборец": ["темьян", "тимиан", "тимян", "чабрец", "чебрец", "чебарка", "чабёр", "чобор", "богородская трава", "боровой перец", "верест", "жадобник", "лебюшка", "лимонный душок", "мухопал"],
    "чеботарив": ["чеботаривши"],
    "чеботаривши": ["чеботарив"],
    "чеботарный": ["чеботарский"],
    "чеботарский": ["чеботарный"],
    "чеботарство": ["сапожничество"],
    "чеботарь": ["сапожник", "обувщик", "башмачник"],
    "чебурахав": ["чебурахавши"],
    "чебурахавши": ["чебурахав"],
    "чебурахнув": ["чебурахнувши"],
    "чебурахнувши": ["чебурахнув"],
    "чебурахнуться": ["упасть", "грохнуться", "шлёпнуться"],
    "чебурок": ["кляпыш"],
    "чебысга": ["курай", "сиповка"],
    "чевапчичи": ["чевапи", "чеваби"],
    "чеглик": ["чеглок"],
    "чего греха таить": ["что греха таить", "нечего греха таить"],
    "чеджу": ["чеджудо", "квельпарт", "тхамна"],
    "чеджудо": ["чеджу"],
    "чезнуть": ["исчезнуть"],
    "чеиз": ["дар", "зестра"],
    "чей": ["который", "чей-либо", "чей-нибудь"],
    "чей-либо": ["чей-то", "чей-нибудь"],
    "чей-нибудь": ["чей-то"],
    "чейнджевый": ["чейнджовый"],
    "чейнджовый": ["чейнджевый"],
    "чек-пойнт": ["контрольно-пропускной пункт", "кпп", "контрольная точка", "контрольный пункт"],
    "чека": ["чк"],
    "чекав": ["чекавши"],
    "чекавши": ["чекав"],
    "чекан": ["чеканка", "долото", "зубило", "резец", "клевец", "мухоловка"],
    "чеканив": ["чеканивши"],
    "чеканивав": ["чеканивавши"],
    "чеканивавши": ["чеканивав"],
    "чеканивши": ["чеканив"],
    "чеканить": ["ковать", "печатать", "набивать"],
    "чекануться": ["сбрендить", "чокнуться", "двинуться"],
    "чекап": ["обследование", "диспансеризация", "медосмотр", "профосмотр"],
    "чекать": ["проверять"],
    "чекбокс": ["флажок", "галочка"],
    "чекер": ["гриндер"],
    "чекист": ["гэбэшник"],
    "чекистня": ["гэбня"],
    "чекнув": ["чекнувши"],
    "чекнувши": ["чекнув"],
    "чекнуть": ["прочекать", "проверить"],
    "чекрыжив": ["чекрыживши"],
    "чекрыживши": ["чекрыжив"],
    "чекрыжить": ["чакрыжить"],
    "чекрыжник": ["чакрыжник"],
    "чексиз": ["чексизь", "кырыйсыз"],
    "чекуша": ["колотушка", "дубина", "долбня", "токмарь", "токмач", "чекмарь"],
    "чекушив": ["чекушивши"],
    "чекушивши": ["чекушив"],
    "чекушка": ["косушка", "четвертинка", "четвертушка", "шкалик", "чебурашка"],
    "чел": ["человек", "мужик"],
    "челдон": ["чалдон", "чолдон", "сибиряк", "гуран"],
    "челик": ["чел"],
    "челкартенгиз": ["шалкартениз", "челкар-тенгиз"],
    "челник": ["началник", "водач", "вожд", "водител", "предводител", "главатар"],
    "челнок": ["лодка", "лодочка", "чёлн", "шаттл"],
    "челночив": ["челночивши"],
    "челночивши": ["челночив"],
    "челночничав": ["челночничавши"],
    "челночничавши": ["челночничав"],
    "чело": ["лоб", "устье", "очелок", "очёлок", "челесник", "лаз", "голова", "очелье", "авангард"],
    "челобитие": ["челобитье", "челобитная"],
    "челобитная": ["ходатайство", "прошение"],
    "челобитчик": ["проситель", "ходатай", "истец"],
    "челобитье": ["челобитная"],
    "человейник": ["высотка", "многоквартирник"],
    "человек": ["землянин", "гомо сапиенс", "хомо сапиенс", "слуга", "половой", "официант", "лакей"],
    "человек с ограниченными возможностями": ["инвалид"],
    "человек человеку волк": ["человек человеку зверь", "закон джунглей"],
    "человеко-день": ["человекодень"],
    "человековед": ["человекознатец"],
    "человековедение": ["гуманология"],
    "человекодень": ["человеко-день"],
    "человекоединица": ["человеко-единица"],
    "человекознатец": ["человековед"],
    "человеколюб": ["человеколюбец", "филантроп"],
    "человеколюбец": ["филантроп", "человеколюб"],
    "человеколюбиво": ["гуманно"],
    "человеколюбивый": ["гуманный"],
    "человеколюбие": ["гуманность", "гуманизм", "филантропия", "человечность"],
    "человеколюбка": ["человеколюбица"],
    "человеколюбье": ["человеколюбие"],
    "человеконенавидение": ["человеконенавистничество"],
    "человеконенавистник": ["мизантроп"],
    "человеконенавистница": ["мизантропка"],
    "человеконенавистнический": ["мизантропический"],
    "человеконенавистничество": ["мизантропия"],
    "человекообразный": ["человекоподобный", "человековидный", "антропоморфный"],
    "человекоподобный": ["антропоморфный", "антропоморфический", "человекообразный", "гуманоидный"],
    "человекоубийца": ["душегуб", "душегубец", "убийца"],
    "человеческий": ["человечный", "гуманный", "приличный"],
    "человечество": ["люди", "человеколюбие", "гуманность"],
    "человечина": ["человечинка", "многолюдье"],
    "человечишка": ["человечишко"],
    "человечишко": ["человечишка"],
    "человечно": ["по-человечески", "гуманно"],
    "человечность": ["доброта", "гуманность", "гуманизм"],
    "человечный": ["человеческий", "гуманный", "сердечный"],
    "челонгар": ["чилингар"],
    "челюстегрудь": ["гнатоторакс"],
    "челюстноротый": ["гнатхостомата"],
    "челюсть": ["подбородок"],
    "челябинка": ["танкоградка"],
    "челябинск": ["челяба", "танкоград"],
    "челядин": ["челядинец", "холоп", "раб", "невольник"],
    "челядь": ["дворовый", "прислуга", "прихвостень", "угодник"],
    "чем": ["по сравнению с", "вместо того чтобы"],
    "чембало": ["клавичембало", "гравичембало", "клавесин"],
    "чембар": ["белинский", "большой чембар"],
    "чембия": ["листель"],
    "чемерица": ["кукольник", "чемерика"],
    "чемирь": ["чемер", "чемера"],
    "чемодан": ["сумка", "лимузин"],
    "чемоданний": ["чемодановий"],
    "чемпион": ["рекордсмен"],
    "чемпионат": ["первенство"],
    "чемпионесса": ["победительница"],
    "чемпионка": ["победительница", "топерша"],
    "чемпионствовав": ["чемпионствовавши"],
    "чемпионствовавши": ["чемпионствовав"],
    "чемчиковав": ["чемчиковавши"],
    "чемчиковавши": ["чемчиковав"],
    "чендж": ["чейндж"],
    "ченч": ["чейндж"],
    "чепан": ["чапан"],
    "чеплашка": ["чаплыжка", "контарка"],
    "чепурив": ["чепуривши"],
    "чепуривши": ["чепурив"],
    "чепурить": ["наряжать", "принаряжать"],
    "чепурний": ["охайний"],
    "чепуха": ["бессмыслица", "ерунда", "нонсенс", "пурга", "мура", "чушь", "бред", "вздор", "белиберда", "галиматья", "бред сивой кобылы", "ахинея", "глупость", "абсурд", "мелочь"],
    "чепуха на постном масле": ["ерунда на постном масле"],
    "черва": ["червь", "черви", "червы"],
    "червен": ["ален", "пурпурен", "румен", "зачервен", "аленочервен", "червендалест", "розов", "вишнев", "вишневочервен", "червеникав", "комунистически"],
    "червень": ["разноцвет", "июнь"],
    "черви": ["червы", "черва", "червь", "чирва", "черти", "сердце", "сердца", "жиры"],
    "червив": ["червивши"],
    "червивев": ["червивевши"],
    "червивевши": ["червивев"],
    "червивив": ["червививши"],
    "червививши": ["червивив"],
    "червивши": ["червив"],
    "червлень": ["шарлах", "багрец"],
    "червлёный": ["багряный", "тёмно-красный"],
    "червовый": ["червонный"],
    "червонев": ["червоневши"],
    "червоневши": ["червонев"],
    "червонец": ["десятка"],
    "червоний": ["кривавий", "калиновий", "бордовий", "бордо", "вишневий", "червлений", "черлений", "гранатовий", "малиновий", "маковий", "кумачевий", "кораловий", "коралевий", "шарлаховий", "червоногарячий"],
    "червонити": ["багрянити", "багрити", "обагряти"],
    "червонный": ["красный", "алый"],
    "червоновидий": ["червонолиций"],
    "червонозорий": ["червонозоряний"],
    "червонозоряний": ["червонозорий"],
    "червонолиций": ["червоновидий"],
    "червы": ["черви", "черва", "червь", "чирва", "черти", "сердце", "сердца", "жиры"],
    "червь": ["червяк", "ничтожество", "никчёмность", "пустое место", "пустышка", "червы", "черва"],
    "червяга": ["безногое земноводное"],
    "червяк": ["червь", "личинка", "ничтожество"],
    "чергар": ["номад"],
    "чердак": ["мансарда", "башка", "котелок"],
    "черевив": ["черевивши"],
    "черевивши": ["черевив"],
    "черевик": ["черевичек"],
    "череда": ["чреда", "последовательность", "цепь", "цепочка", "вереница", "ряд"],
    "чередив": ["чередивши"],
    "чередивши": ["чередив"],
    "чередить": ["чредить"],
    "чередиться": ["чредиться"],
    "чередовавши": ["чередовав"],
    "чередование": ["альтернация"],
    "чередованье": ["чередование"],
    "чередовать": ["перемежать"],
    "через": ["сквозь", "черезо", "чрез", "чрезо", "поперёк", "поверх", "над", "спустя", "с помощью", "посредством"],
    "через губу не переплюнет": ["через губу не плюнет", "не переломится"],
    "через жопу": ["плохо", "неумело", "некачественно", "кое-как", "из рук вон", "спустя рукава", "неправильно", "неверно", "грубо", "безвкусно", "неуклюже", "топорно", "чёрт-те как", "чёрт знает как", "через задницу"],
    "через жопу вывернуться": ["в лепёшку разбиться", "в лепёшку разойтись", "разбиться в лепёшку", "разойтись в лепёшку", "расшибиться в лепёшку", "вывернуться через жопу"],
    "через мой труп": ["ни за что", "и не подумаю", "хоть убейте", "нет", "хоть убей", "как же"],
    "через пень-колоду": ["через одно место"],
    "через хуй кинуть": ["наколоть", "кинуть через хер", "через хер кинуть", "кинуть через хуй", "наебать", "объебать"],
    "через час по чайной ложке": ["в час по чайной ложке", "черепашьим шагом"],
    "череззаборногузадерищенко": ["череззаборногузадерищенский"],
    "череззаборногузадерищенский": ["череззаборногузадерищенко"],
    "черезо": ["через", "чрез", "чрезо"],
    "черемис": ["мариец"],
    "черемисский": ["марийский"],
    "черемуховий": ["черемховий"],
    "черемха": ["черёмуха"],
    "черемховий": ["черемуховий"],
    "черемховый": ["черёмуховый", "черёмушный"],
    "черемша": ["дикий чеснок", "лук медвежий", "медвежий лук", "калба", "колба", "каменный лук", "каменный чеснок"],
    "черен": ["черенок", "рукоятка", "рукоять"],
    "черенковав": ["черенковавши"],
    "черенковавши": ["черенковав"],
    "черенковское излучение": ["черенок"],
    "черенковый": ["черешковый"],
    "черенок": ["рукоятка", "ручка", "рассада", "черешок", "черенковское излучение"],
    "череп": ["наст", "корка"],
    "черепашка": ["вредная черепашка"],
    "черепенник": ["черепеня", "черепеничник"],
    "черепковый": ["черепочный"],
    "черепная коробка": ["череп"],
    "черепно-мозговая": ["черепно-мозговая травма", "чмт"],
    "черепно-мозговая травма": ["черепно-мозговая", "чмт"],
    "черепно-мозговой": ["краниоцеребральный"],
    "черепокожное": ["моллюск"],
    "чересполосица": ["узкополосица", "многополосица", "длиннополосица", "чресполосица", "чересполосность"],
    "чересчур": ["чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "сверх меры", "избыточно", "чрезвычайно", "крайне", "изрядно", "в высшей степени", "необычайно"],
    "черешковый": ["черенковый"],
    "черешнянка": ["ягодянка"],
    "черешок": ["черенок"],
    "черкав": ["черкавши"],
    "черкавши": ["черкав"],
    "черканув": ["черканувши"],
    "черканувши": ["черканув"],
    "черканье": ["черкание"],
    "черкасская область": ["черкасщина"],
    "черква": ["църква"],
    "черкес": ["адыги", "адыгейцы", "кабардинец", "кавказец"],
    "черкеска": ["чоха", "чуха"],
    "черки": ["озынборын"],
    "черкизово": ["черкизово-подмосковное"],
    "черкнув": ["черкнувши"],
    "черкнувши": ["черкнув"],
    "черкнуть": ["нацарапать"],
    "чермное море": ["красное море"],
    "чермный": ["червлёный", "багровый"],
    "чернавка": ["смуглянка"],
    "чернев": ["черневши"],
    "черневши": ["чернев"],
    "чернеть": ["чернеться"],
    "чернеться": ["чернеть"],
    "чернец": ["монах", "черноризец"],
    "чернечество": ["черничество", "монашество"],
    "чернив": ["чернивши"],
    "чернивши": ["чернив"],
    "черниговская область": ["черниговщина"],
    "черника": ["черница"],
    "чернила": ["чернило", "бормотуха"],
    "чернило": ["чернила"],
    "чернильница": ["черниленка", "чернилка"],
    "чернильница-непроливайка": ["непроливайка", "непроливашка", "чернильница-невыливайка", "чернилка-непроливайка"],
    "чернильный мешок": ["чернильная железа"],
    "чернить": ["зачернять", "замарывать", "обвинять", "клеветать", "наговаривать", "оговаривать", "наводить навет"],
    "черница": ["монахиня"],
    "черничество": ["чернечество", "монашество"],
    "черничка": ["черника", "черница", "черничечка", "черничина"],
    "чернобыл": ["чернобыль", "чернобыльник"],
    "чернобыль": ["чернобыл", "чернобыльник"],
    "чернобыльник": ["чернобыл", "чернобыль", "полынь обыкновенная"],
    "черновик": ["набросок", "брульон"],
    "черновицкая область": ["черновичина"],
    "черновой": ["черновик"],
    "черноволосый": ["черноголовый", "темноволосый", "брюнет"],
    "черноглазка": ["капшак"],
    "черноглазый": ["черноокий"],
    "черноголовка": ["горлянка"],
    "черноголовый": ["брюнет", "темноволосый", "черноволосый", "чёрный"],
    "черногория": ["монтенегро"],
    "черногривый": ["черноволосый", "чернявый"],
    "черногуз": ["аист"],
    "черножопик": ["хач", "черножопый"],
    "чернокнижество": ["чернокнижие"],
    "чернокнижие": ["колдовство", "волхование", "чернокнижество", "оккультизм", "чернокнижье"],
    "чернокнижник": ["чёрный маг", "колдун"],
    "чернокнижница": ["волшебница", "колдунья", "кудесница", "чародейка"],
    "чернокнижничество": ["чернокнижие"],
    "чернокнижный": ["колдовской"],
    "чернокнижье": ["чернокнижие"],
    "чернокожий": ["темнокожий", "негр"],
    "черноколоска": ["черноуска"],
    "чернолесье": ["чёрный лес"],
    "черноликий": ["чернолицый"],
    "чернолицый": ["черноликий"],
    "чернолоз": ["чернолоза", "чернотал", "ива пятитычиночная"],
    "черномордый": ["темнолицый", "смуглый"],
    "черноморск": ["ильичёвск"],
    "черноокий": ["черноглазый"],
    "черноольшаник": ["черноольховник"],
    "черноплодка": ["черноплодная рябина"],
    "чернорабочий": ["разнорабочий"],
    "черноризец": ["монах", "чернец"],
    "черноризник": ["черноризец"],
    "черностоп": ["чернотроп"],
    "чернотал": ["ива пятитычинковая", "чернолоз"],
    "чернотроп": ["черностоп"],
    "черношёрстный": ["черношёрстый"],
    "чернуха": ["туфта", "трэш"],
    "чернушка": ["нигелла", "чёрный груздь", "оливково-чёрный груздь", "черныш", "чёрная дуплянка", "чёрные губы", "цыган", "чёрный еловый груздь", "оливково-коричневый груздь", "варен", "свинорыл", "подгруздок чёрный", "чёрная сыроежка", "чёрный хлеб", "чёрный"],
    "черныш": ["белохвостик"],
    "чернявый": ["брюнет"],
    "чернёный": ["аспидированный"],
    "черпав": ["черпавши"],
    "черпавши": ["черпав"],
    "черпак": ["половник", "поварёшка", "черпалка", "уполовник", "ополовник", "ковш"],
    "черпак говна": ["говноед"],
    "черпанув": ["черпанувши"],
    "черпанувши": ["черпанув"],
    "черпанье": ["черпание"],
    "черпачок": ["ковшик"],
    "черпнув": ["черпнувши"],
    "черпнувши": ["черпнув"],
    "черпнуть": ["достать", "почерпнуть", "приобрести", "позаимствовать", "набрать", "зачерпнуть", "черпануть", "выудить", "взять", "извлечь"],
    "черствев": ["черствевши"],
    "черствевши": ["черствев"],
    "черстветь": ["зачерствевать", "очерствевать", "сохнуть", "засыхать", "затвердевать"],
    "черствив": ["черствивши"],
    "черствивши": ["черствив"],
    "черт": ["шерт"],
    "черта": ["линия", "штрих", "полоса", "отрезок", "рубеж", "граница", "предел", "очертание", "форма", "признак", "особенность", "характеристика"],
    "чертив": ["чертивши"],
    "чертивши": ["чертив"],
    "чертить": ["линовать", "черкать"],
    "чертовка": ["бесовка", "плутовка"],
    "чертовня": ["чертовщина"],
    "чертовщина": ["дьявольщина", "бесовщина", "мана", "морока", "чертовня"],
    "чертог": ["палата", "палаты", "хоромы", "терем", "палаццо", "дворец", "замок"],
    "чертополох": ["бурьян", "волчец"],
    "черторой": ["промоина", "водомоина", "рытвина", "овраг"],
    "чертяга": ["чертяка"],
    "чертёж": ["эскиз", "карта", "план", "писание", "схема"],
    "чертёнок": ["бесёнок", "дьяволёнок"],
    "черчение": ["вычерчивание", "чертёж", "инженерная графика"],
    "черченье": ["черчение"],
    "черёд": ["очередь"],
    "черёмуха": ["черемха", "хлорацетофенон"],
    "черёмуховый": ["черёмушный", "черемховый"],
    "черёмушный": ["черёмуховый", "черемховый"],
    "чесав": ["чесавши"],
    "чесавши": ["чесав"],
    "чесалка": ["чесало"],
    "чесальщик": ["льночесальщик", "чесальник", "чесатель", "чомпи", "шерсточесальщик"],
    "чесанув": ["чесанувши"],
    "чесанувши": ["чесанув"],
    "чесать репу": ["чесать щи"],
    "чесать щи": ["чесать репу"],
    "чесать языком": ["болтать", "лясы точить"],
    "чесаться": ["зудеть", "свербеть"],
    "чеславич": ["чеславович"],
    "чеснок": ["чесночина", "чесночинка"],
    "чеснокодавилка": ["чесночница", "чеснокодавка", "пресс для чеснока"],
    "чесночив": ["чесночивши"],
    "чесночивши": ["чесночив"],
    "чесслово": ["честное слово", "воистину", "в самом деле", "действительно", "истинно", "поистине", "точно", "уверяю", "уверяю вас", "взаправду", "вправду", "ей богу", "ей ей", "заправду", "клянусь"],
    "чествовав": ["чествовавши"],
    "чествовавши": ["чествовав"],
    "чествованье": ["чествование"],
    "чествовать": ["воздавать почести", "величать", "именовать", "называть"],
    "честив": ["честивши"],
    "честивши": ["честив"],
    "честить": ["бранить", "ругать", "хулить", "поносить", "угощать", "величать", "принимать"],
    "честно": ["правдиво", "справедливо", "по-честному"],
    "честно говоря": ["по правде говоря", "по правде сказать", "честно сказать", "по чести говоря"],
    "честной": ["почтенный", "уважаемый", "благородный", "святой"],
    "честность": ["правдивость"],
    "честный": ["правдивый", "искренний", "бесхитростный", "безобманный", "добросовестный", "усердный", "безукоризненный", "безупречный", "порядочный", "целомудренный", "достоверный", "почтенный", "достойный", "уважаемый", "драгоценный"],
    "честолюб": ["честолюбец"],
    "честолюбиво": ["амбициозно"],
    "честолюбивость": ["честолюбие"],
    "честолюбивый": ["амбициозный", "тщеславный"],
    "честолюбие": ["амбиции"],
    "честолюбье": ["честолюбие"],
    "честь": ["благородство", "доблесть", "честность", "порядочность", "почёт", "почтение", "уважение", "знаки почёта", "доброе имя", "репутация", "милость"],
    "честься": ["полагаться", "считаться"],
    "чесунча": ["чесуча", "чечунча"],
    "чесунчовый": ["чесучовый", "чечунчовый"],
    "чесуча": ["чесунча", "чечунча"],
    "чесучовый": ["чесунчовый", "чечунчовый"],
    "чета": ["пара", "ровня"],
    "четвереньки": ["карачки"],
    "четверив": ["четверивши"],
    "четверивши": ["четверив"],
    "четверной": ["четырёхчастный", "учетверённый"],
    "четверо": ["четыре"],
    "четверовластие": ["тетрархия"],
    "четвероевангелие": ["евангелие-тетр", "тетроевангелие"],
    "четвероместный": ["четырёхместный"],
    "четвероногий": ["четырёхлапый"],
    "четвероногий друг солдата": ["лучший четвероногий друг солдата"],
    "четверопутие": ["квадривиум"],
    "четверостишие": ["четверостишье"],
    "четверостишье": ["четверостишие"],
    "четвертина": ["четверть", "четь"],
    "четвертинка": ["четвертина", "четверть", "четь", "четушка", "чекушка"],
    "четвертинный": ["четверичный", "четвертичный"],
    "четвертичный": ["антропогеновый"],
    "четвертичный период": ["антропоген", "антропогеновый период", "антропогеновая система"],
    "четвертной билет": ["четвертной", "беленькая", "лебедь"],
    "четвертовав": ["четвертовавши"],
    "четвертовавши": ["четвертовав"],
    "четвертованье": ["четвертование"],
    "четвертовать": ["четверить"],
    "четвертьвековой": ["двадцатипятилетний"],
    "четвёрочка": ["четвёрка"],
    "четвёрочник": ["хорошист", "ударник"],
    "четвёртая власть": ["сми"],
    "четвёртый": ["четыре"],
    "четиридесет": ["четирийсет"],
    "четыре": ["четвёрка", "хорошо"],
    "четыреста": ["четыре сотни"],
    "четырнадцатиугольный": ["тетрадекагональный"],
    "четырёхглавый": ["четырёхголовый", "четырёхкупольный"],
    "четырёхглазый": ["очкастый", "очкарик"],
    "четырёхголовый": ["четырёхглавый"],
    "четырёхголосие": ["четверогласие"],
    "четырёхгранник": ["тетраэдр"],
    "четырёхгранный": ["тетраэдральный"],
    "четырёхклассный": ["четвероклассный"],
    "четырёхместный": ["четвероместный"],
    "четырёхокись": ["тетраокись", "тетраоксид", "тетроксид"],
    "четырёхполосный": ["четырёхрядный"],
    "четырёхугольник": ["тетрагон"],
    "четырёхцветный": ["четырёхкрасочный"],
    "четырёхчастный": ["четверной"],
    "четырёхъязычный": ["тетралингвальный"],
    "четьи минеи": ["минея"],
    "чех": ["чеченец"],
    "чехвальство": ["хвастовство", "фанфаронство", "бахвальство"],
    "чехвостив": ["чехвостивши"],
    "чехвостивши": ["чехвостив"],
    "чехвостить": ["чихвостить"],
    "чехия": ["чешская республика", "богемия"],
    "чехлив": ["чехливши"],
    "чехливши": ["чехлив"],
    "чехлить": ["зачехлять"],
    "чечевицеобразный": ["линзообразный"],
    "чечен": ["чеченец"],
    "чеченец": ["чечен"],
    "чеченизация": ["кадыризация", "кадыровизация"],
    "чечено-ингушетия": ["чечено-ингушская автономная область", "чиасср"],
    "чеченская республика": ["чечня"],
    "чеченская республика ичкерия": ["чри", "ичкерия", "чечня"],
    "чеченский": ["чеченский язык"],
    "чеченский язык": ["чеченский"],
    "чечка": ["деталь", "аксессуар"],
    "чечня": ["ичкерия", "чеченская республика"],
    "чечёточник": ["степист"],
    "чечёточница": ["степистка"],
    "чешется пиздища": ["чешется манда", "чешется пиздище", "раззуделася пизда", "пизда чешется", "пизда горит"],
    "чешется пиздище": ["чешется манда", "раззуделася пизда", "чешется пиздища", "пизда чешется", "пизда горит"],
    "чешская республика": ["чехия", "чр"],
    "чешский": ["богемский", "чешский язык"],
    "чешский язык": ["чешский"],
    "чешуевидный": ["чешуеобразный"],
    "чешуекрылый": ["бабочка"],
    "чешуеобразный": ["чешуевидный"],
    "чешуйчатка": ["фолиота"],
    "чжурчжэнь": ["чжуличжэнь", "нюйчжэнь", "нюйчжи", "пиньинь"],
    "чи": ["ки", "ци"],
    "чиасср": ["чечено-ингушетия"],
    "чиби": ["тиби", "чибик"],
    "чибинь": ["чыбын"],
    "чибис": ["чибез", "пигалица", "пигалка", "пивик", "вьюха", "книгалка", "луговка"],
    "чибрик": ["пышка", "баурсак", "блинок", "пряженец", "мордовские оладьи"],
    "чивикав": ["чивикавши"],
    "чивикавши": ["чивикав"],
    "чивикнув": ["чивикнувши"],
    "чивикнувши": ["чивикнув"],
    "чивость": ["щедрость"],
    "чивый": ["щедрый"],
    "чигирь": ["персидское колесо", "нория"],
    "чигиря": ["задворки", "глушь", "захолустье", "глухомань", "медвежий угол", "периферия", "чёртовы кулички", "окраина", "ебеня", "пустошь"],
    "чие": ["алча"],
    "чиж": ["чижик", "чижичек"],
    "чижик": ["чиж"],
    "чижиный": ["чижовый"],
    "чижовый": ["чижиный"],
    "чиз": ["бор", "кола", "амвол"],
    "чизель": ["культиватор", "рыхлитель"],
    "чизурма": ["шаурма", "шаверма"],
    "чика": ["расшибай", "расшибалка", "расшибаловка", "расшибалочка", "расшибец", "расшиши", "замеряшки"],
    "чикав": ["чикавши"],
    "чикавши": ["чикав"],
    "чикаго": ["второй город", "город ветров", "чи"],
    "чикано": ["мексикано-американец"],
    "чики-пики": ["в ажуре", "в порядке", "зашибись", "ништяк", "пучком", "всё пучком и пизда торчком", "тип-топ", "чики-пуки"],
    "чики-пуки": ["в ажуре", "в порядке", "зашибись", "ништяк", "пучком", "тип-топ", "чики-пики"],
    "чикилять": ["хромать", "прихрамывать"],
    "чикнув": ["чикнувши"],
    "чикнувши": ["чикнув"],
    "чикнуть": ["отрезать", "резануть"],
    "чикса": ["бикса"],
    "чикуля": ["чика", "чикса", "цыпа", "цыпочка"],
    "чикчиры": ["рейтузы", "лосины"],
    "чили": ["чилийский перец", "острый перец", "острый перец чили", "чили кон карне"],
    "чилибуха": ["рвотный орех"],
    "чиликав": ["чиликавши"],
    "чиликавши": ["чиликав"],
    "чиликать": ["чирикать"],
    "чиликнув": ["чиликнувши"],
    "чиликнувши": ["чиликнув"],
    "чилим": ["кальян"],
    "чилингар": ["челонгар"],
    "чиллив": ["чилливши"],
    "чилливши": ["чиллив"],
    "чиллить": ["расслабляться"],
    "чилуба": ["луба", "луба-касаи"],
    "чимкент": ["шымкент"],
    "чимча": ["кимчхи", "кимчи", "чимчи"],
    "чимчи": ["кимчи", "чимча"],
    "чимчиковать": ["идти", "шуровать", "плестись"],
    "чин чинарём": ["как полагается", "как следует", "чин по чину", "чин чином"],
    "чин чином": ["чин чинарём", "честь честью"],
    "чинар": ["чинара", "платан"],
    "чинара": ["чинар", "платан"],
    "чингиз-хан": ["чингисхан"],
    "чингизид": ["чингизович", "чингисид"],
    "чингисид": ["чингизид", "чингисович"],
    "чингисхан": ["чингиз-хан", "тэмуджин", "темучин"],
    "чинив": ["чинивши"],
    "чинивши": ["чинив"],
    "чинила": ["ремонтник", "починщик"],
    "чинилка": ["точилка"],
    "чинить": ["исправлять", "восстанавливать", "ремонтировать", "починять", "очинять", "очинивать", "заострять", "точить", "затачивать", "отачивать"],
    "чиниться": ["ремонтироваться"],
    "чинно": ["степенно", "важно"],
    "чинность": ["степенность"],
    "чинный": ["степенный", "важный"],
    "чиновнический": ["чиновничий"],
    "чиновничий": ["чиновнический"],
    "чинодрал": ["бюрократ", "чиновник", "формалист"],
    "чинопочитанье": ["чинопочитание"],
    "чинящийся": ["ремонтирующийся"],
    "чип": ["микросхема"],
    "чипизация": ["чипирование"],
    "чипировав": ["чипировавши"],
    "чипировавши": ["чипировав"],
    "чипироваться": ["вакцинироваться", "привиться", "уколоться"],
    "чиповав": ["чиповавши"],
    "чиповавши": ["чиповав"],
    "чипок": ["булдырь", "чепок", "чапок", "бар", "пивная", "рюмочная", "пивбар", "пивнушка", "кабак", "питейный дом", "распивная", "распивочная"],
    "чипс": ["чипсина", "картофель фри"],
    "чипсина": ["чипс"],
    "чир": ["зимник"],
    "чирей": ["угорь"],
    "чирик": ["четверть", "четвертная", "четвертной", "червонец", "червончик", "червоный", "десятка", "десяточка"],
    "чирикав": ["чирикавши"],
    "чирикавши": ["чирикав"],
    "чирикать": ["щебетать", "пустословить", "болтать", "трепаться", "балаболить", "балабонить", "празднословить", "суесловить", "чиркать", "стрекотать", "трещать"],
    "чирикать на рыбьем языке": ["на рыбьем языке чирикать"],
    "чирикнув": ["чирикнувши"],
    "чирикнувши": ["чирикнув"],
    "чиркав": ["чиркавши"],
    "чиркавши": ["чиркав"],
    "чиркание": ["чирканье"],
    "чирканье": ["чиркание"],
    "чиркать": ["скрести", "карябать"],
    "чиркаш": ["черкаш"],
    "чиркнув": ["чиркнувши"],
    "чиркнувши": ["чиркнув"],
    "чирута": ["чирутка"],
    "чирутка": ["чирута"],
    "чиря": ["чирятко", "чирка", "чирок"],
    "чиряк": ["чирей", "фурункул"],
    "числанув": ["числанувши"],
    "числанувши": ["числанув"],
    "числануть": ["отчислить"],
    "численность": ["число", "количество"],
    "численный": ["числительный", "числовой", "количественный"],
    "числив": ["числивши"],
    "числивши": ["числив"],
    "числительное": ["имя числительное"],
    "числительный": ["численный"],
    "число маха": ["число маевского", "число берстоу"],
    "числовая ось": ["числовая прямая"],
    "числовая прямая": ["числовая ось"],
    "числовой": ["численный"],
    "чистейшей воды": ["чистейший", "чистой воды", "настоящий", "истинный", "типичный", "явный", "отъявленный", "отпетый", "самый что ни на есть", "в чистом виде"],
    "чистенько": ["чисто"],
    "чистив": ["чистивши"],
    "чистивши": ["чистив"],
    "чистилище": ["пургаторий"],
    "чистительный": ["чистильный", "очистительный", "очищающий"],
    "чистить": ["очищать", "опорожнять", "прочищать"],
    "чистить пылесосом": ["пылесосить"],
    "чистник": ["чистофайник"],
    "чисто": ["непорочно", "возвышенно", "целомудренно", "аккуратно", "безупречно", "искусно", "ловко", "умело", "совершенно", "полностью", "типично", "сугубо", "не более чем", "только", "просто"],
    "чисто-белый": ["белоснежный", "сахарный"],
    "чистовик": ["беловик"],
    "чистоган": ["наличные деньги", "наличность", "нал", "налик", "наличка", "живые деньги", "чистые деньги", "наличные", "чистые", "звонкая монета", "наличман", "прибыль", "доход", "барыш", "нажива"],
    "чистоганом": ["наличные деньги", "наличностью", "наличными", "налом", "наличкой", "живые деньги", "чистые деньги", "чистыми", "звонкая монета", "честно", "без обмана", "прямо", "открыто", "честь по чести", "по чесноку"],
    "чистодел": ["вор"],
    "чистой воды": ["чистейший", "чистейшей воды", "настоящий", "истинный", "типичный", "явный", "отъявленный", "отпетый", "самый что ни на есть", "в чистом виде"],
    "чистокровность": ["чистопородность", "чистоплемённость", "высокопородность", "высокопородистость", "знатность", "родовитость"],
    "чистокровный": ["чистопородный"],
    "чистописание": ["чистописанье", "чистопись", "каллиграфия"],
    "чистописатель": ["переписчик", "писарь"],
    "чистопись": ["чистописание"],
    "чистоплотность": ["опрятность", "порядочность"],
    "чистоплотный": ["опрятный", "аккуратный", "чистюля", "честный", "целомудренный", "чистый"],
    "чистоплюйка": ["белоручка"],
    "чистоплюйство": ["брезгливость"],
    "чистоплюйствовав": ["чистоплюйствовавши"],
    "чистоплюйствовавши": ["чистоплюйствовав"],
    "чистополье": ["поле"],
    "чистопородный": ["чистокровный"],
    "чистопробный": ["беспримесный", "высокопробный", "аутентический", "аутентичный", "подлинный", "настоящий", "натуральный", "действительный"],
    "чистосердечнейший": ["искреннейший"],
    "чистота": ["опрятность"],
    "чистотел": ["бородавник"],
    "чистотень": ["чистота"],
    "чистый": ["непорочный", "целомудренный", "невинный"],
    "чистюля": ["чистоплюй", "чистяк"],
    "чистяково": ["торез"],
    "чит": ["чит-код"],
    "чит-код": ["чит"],
    "чита": ["читинка"],
    "читабельность": ["читаемость", "удобочитаемость"],
    "читабельный": ["читаемый"],
    "читав": ["читавши"],
    "читавши": ["читав"],
    "читаго": ["чита"],
    "читаемый": ["читабельный", "лёгкий"],
    "читалка": ["читальня"],
    "читальщик": ["чтец"],
    "читатель": ["абонент"],
    "читать": ["прочитывать", "распознавать", "зачитывать", "декламировать", "проводить", "давать", "считывать"],
    "читать по диагонали": ["просматривать по диагонали", "просматривать"],
    "читающая": ["читательница", "лектриса", "чтица"],
    "читерив": ["читеривши"],
    "читеривши": ["читерив"],
    "читка": ["чтение", "прочтение"],
    "читывав": ["читывавши"],
    "читывавши": ["читывав"],
    "чиф": ["старпом"],
    "чифанька": ["забегаловка"],
    "чифир": ["чифирь", "чифер", "чернуха", "чехнарь", "черняга", "чай а ля рюс", "чифанка", "шанера", "чихирь", "чифирка", "шалфей", "сапог"],
    "чифирив": ["чифиривши"],
    "чифиривши": ["чифирив"],
    "чифирь": ["чифир", "чифер", "чернуха", "чехнарь", "черняга", "чай а ля рюс", "чифанка", "шанера", "чихирь", "чифирка", "шалфей", "сапог"],
    "чифут": ["евреин", "чифутин"],
    "чифутин": ["евреин", "чифут"],
    "чих": ["чихание", "чиханье", "чихота", "чох"],
    "чихав": ["чихавши"],
    "чихавши": ["чихав"],
    "чихание": ["чиханье", "чих"],
    "чиханье": ["чих", "чихание"],
    "чихать": ["пыхтеть", "плевать"],
    "чихвостив": ["чихвостивши"],
    "чихвостивши": ["чихвостив"],
    "чихвостить": ["костерить"],
    "чихнув": ["чихнувши"],
    "чихнувши": ["чихнув"],
    "чихуахуа": ["чихуа", "чиуауа", "чихуашка"],
    "чич": ["чичэк"],
    "чичвариться": ["чуфариться"],
    "чичер": ["хижа", "рянда", "слякоть"],
    "чичероне": ["гид", "проводник", "экскурсовод"],
    "чичисбей": ["кавалер", "компаньон"],
    "чичо": ["чичко"],
    "чк": ["чека"],
    "чкаться": ["слоняться", "шляться", "шататься", "шлёндать", "шлёндрать"],
    "чкнув": ["чкнувши"],
    "чкнувши": ["чкнув"],
    "член-корреспондент": ["членкор"],
    "членение": ["разбиение", "разделение", "дробление"],
    "членив": ["членивши"],
    "членивши": ["членив"],
    "членик": ["сегмент"],
    "членистоногое": ["артроподы", "артропод"],
    "членистохоботные": ["полужесткокрылые"],
    "членить": ["дробить", "делить", "расчленять", "разделять", "разбивать"],
    "членкор": ["член-корреспондент"],
    "членкоровский": ["членкорский"],
    "членкорский": ["членкоровский"],
    "членовоз": ["членовозка", "лимузин"],
    "членораздельно": ["разборчиво", "внятно", "вразумительно"],
    "членосос": ["сволочь", "подлец", "мудак", "мудило", "мудачина", "неумеха", "неумёха", "тряпка", "рохля", "мямля"],
    "членствовав": ["членствовавши"],
    "членствовавши": ["членствовав"],
    "членствовать": ["состоять"],
    "чмо": ["урод", "чмырь", "чмошник", "чмырдяй", "чушок", "чушкан"],
    "чмобик": ["мобик", "дух"],
    "чмок": ["поцелуй"],
    "чмокав": ["чмокавши"],
    "чмокавши": ["чмокав"],
    "чмоканье": ["чмокание"],
    "чмокать": ["чавкать", "хлюпать", "целовать"],
    "чмокнув": ["чмокнувши"],
    "чмокнувши": ["чмокнув"],
    "чморив": ["чморивши"],
    "чморивши": ["чморив"],
    "чмошник": ["чмо"],
    "чмошница": ["чмо"],
    "чмт": ["черепно-мозговая травма"],
    "чмырь": ["человек", "чел"],
    "чоботар": ["швець"],
    "човекомразец": ["саможив", "мизантроп"],
    "човка": ["клюн", "гага"],
    "чово": ["чо"],
    "чодирнишин": ["бодиягард", "бодиянишин"],
    "чой": ["ном"],
    "чойс": ["лапша быстрого приготовления", "доширак", "дошик"],
    "чокав": ["чокавши"],
    "чокавши": ["чокав"],
    "чокер": ["бархотка"],
    "чокеровав": ["чокеровавши"],
    "чокеровавши": ["чокеровав"],
    "чокнув": ["чокнувши"],
    "чокнувши": ["чокнув"],
    "чокнутый": ["сумасшедший", "тронутый", "с приветом"],
    "чомга": ["большая поганка"],
    "чон": ["джон"],
    "чоно": ["боохой"],
    "чоп": ["частное охранное предприятие", "частная охранная организация", "чоо"],
    "чопгар": ["чопкунанда"],
    "чопик": ["заглушка", "шкант"],
    "чопорно": ["церемонно", "надменно"],
    "чопорность": ["принуждённость", "церемонность"],
    "чора": ["тадбир", "гузир"],
    "чорба": ["супа"],
    "чорбаджия": ["богаташ", "думбаз"],
    "чорво": ["чорпо"],
    "чоризо": ["чорисо"],
    "чормех": ["салб"],
    "чорнильниця": ["каламар"],
    "чорногуз": ["лелека", "бусел", "бусол"],
    "чорногузеня": ["лелеча", "лелеченя", "бусленя"],
    "чорнозем": ["чорноземля"],
    "чорноризник": ["чернець"],
    "чорны": ["чарнавы"],
    "чорнявий": ["чорноволосий"],
    "чорняк": ["чернетка", "меланома", "чорноопух"],
    "чорох-су": ["чорох", "корух"],
    "чорпо": ["чорво"],
    "чорт": ["чёрт", "дьявол", "сатана"],
    "чортеня": ["дияволеня"],
    "чортиха": ["чортиця"],
    "чортиця": ["чортиха"],
    "чортъ": ["демонъ"],
    "чортя": ["чортеня", "дияволеня"],
    "чох": ["чих", "цянь"],
    "чоха": ["чуха", "черкеска"],
    "чохано": ["чёхано"],
    "чохом": ["скопом", "огулом", "сразу", "целиком"],
    "чпокав": ["чпокавши"],
    "чпокавши": ["чпокав"],
    "чпокать": ["трахать", "ебать"],
    "чпокаться": ["заниматься любовью", "совокупляться", "трахаться", "чокаться"],
    "чпокнув": ["чпокнувши"],
    "чпокнувши": ["чпокнув"],
    "чпу": ["числовое программное управление"],
    "чревастый": ["пузатый"],
    "чреватев": ["чреватевши"],
    "чреватевши": ["чреватев"],
    "чреватый": ["беременный", "грозящий"],
    "чрево": ["живот", "брюхо", "пузо", "утроба", "нутро", "внутренность"],
    "чревобесие": ["чревоугодие", "обжорство"],
    "чревовещав": ["чревовещавши"],
    "чревовещавши": ["чревовещав"],
    "чревовещание": ["чревовещанье", "вентрилоквия", "вентрология", "пророчество", "предчувствие", "предощущение"],
    "чревовещатель": ["вентролог"],
    "чревоугодие": ["обжорство", "чревоугодничество"],
    "чревоугодник": ["обжора", "гурман"],
    "чревоугодничав": ["чревоугодничавши"],
    "чревоугодничавши": ["чревоугодничав"],
    "чревоугоднический": ["гурманский"],
    "чревоугодничество": ["чревоугодие", "чревоугодье", "обжорство"],
    "чревоугодье": ["чревоугодие"],
    "чреда": ["череда", "очерёдность", "последовательность", "ряд"],
    "чредив": ["чредивши"],
    "чредивши": ["чредив"],
    "чредить": ["чередить"],
    "чредиться": ["чередиться"],
    "чрез": ["через"],
    "чрез-": ["гипер-", "сверх-", "супер-", "ультра-"],
    "чрезвычайная ситуация": ["чс"],
    "чрезвычайно": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "чрезвычайное положение": ["чп"],
    "чрезмерно": ["чрезвычайно", "слишком", "излишне", "сверх меры", "избыточно", "чересчур", "больно"],
    "чрезмерный": ["избыточный"],
    "чрезо": ["через", "чрез", "черезо"],
    "чрезъестественный": ["сверхъестественный", "чрезвычайный"],
    "чрен": ["церен", "црен", "цирен"],
    "чрескожно": ["трансдермально"],
    "чрескожный": ["трансдермальный"],
    "чресполосица": ["чересполосица"],
    "чсв": ["мания величия", "член семьи военнослужащего"],
    "чтение": ["чтенье", "чтиво", "слушания"],
    "чтенье": ["чтение"],
    "чтец": ["псаломщик"],
    "чтив": ["чтивши"],
    "чтивши": ["чтив"],
    "чтимый": ["почитаемый", "уважаемый", "глубокоуважаемый", "многоуважаемый", "достопочтенный"],
    "чтить": ["почитать"],
    "чтица": ["артистка", "читальщица"],
    "что греха таить": ["чего греха таить", "нечего греха таить"],
    "что два пальца обоссать": ["легко", "просто", "как нечего делать", "как два пальца обоссать", "как два пальца об асфальт"],
    "что есть духу": ["во весь дух", "во все лопатки", "изо всех сил", "на всех парусах", "очертя голову", "сломя голову", "со всех ног"],
    "что есть мочи": ["сильно", "мощно", "во всю мочь", "изо всей мочи"],
    "что есть силы": ["со всей силы", "изо всех сил"],
    "что за вопрос": ["не вопрос", "говно вопрос"],
    "что за счёты": ["какая мелочь", "какой пустяк"],
    "что и говорить": ["верно", "конечно"],
    "что ли": ["что ль", "может быть", "разве"],
    "что поделаешь": ["делать нечего", "никуда не денешься", "ничего не поделаешь", "ничего не попишешь"],
    "что попало": ["всякая всячина", "всё подряд", "ерунда"],
    "что такое": ["что"],
    "что ты говоришь": ["да ты что"],
    "что-либо": ["что-нибудь", "что-то", "нечто"],
    "что-нибудь": ["что-то", "что-либо"],
    "что-то с чем-то": ["с ума сойти", "обалдеть", "закачаешься"],
    "чтобы": ["чтоб", "дабы"],
    "чтокав": ["чтокавши"],
    "чтокавши": ["чтокав"],
    "чтомый": ["читаемый", "считаемый", "счётный", "исчисляемый", "подсчитываемый", "полагаемый"],
    "чу": ["тихо"],
    "чуана": ["тсвана", "бечуан", "сетсвана", "сечуана", "чвана"],
    "чуб": ["прядь", "чубчик", "чупрун", "хохол", "вихор", "оселедец", "косма"],
    "чубучок": ["курительная трубка"],
    "чубушник": ["филадельфус"],
    "чувак": ["парень", "мужик", "кент"],
    "чуваш": ["чувашин", "чувашанин"],
    "чувашия": ["чувашская республика", "чр"],
    "чувашский язык": ["чувашский"],
    "чувиха": ["чува"],
    "чувственник": ["беспутник", "беспутный", "бабник", "ходок", "потаскун", "гуляка", "женолюб", "женолюбец", "сластолюб", "сластолюбец", "блудник", "блудодей", "любодей", "прелюбодей", "любострастник"],
    "чувственность": ["сладострастие"],
    "чувственный": ["конкретный", "материальный", "телесный", "плотский", "сексуальный"],
    "чувствие": ["чувство"],
    "чувствительнейше": ["покорнейше"],
    "чувствительно": ["ощутимо"],
    "чувствительность": ["ощутимость", "восприимчивость"],
    "чувствительный": ["впечатлительный", "сентиментальный", "восприимчивый", "чуткий"],
    "чувство": ["сознание", "ощущение", "эмоция"],
    "чувство собственного достоинства": ["самоуважение", "чсв"],
    "чувствовав": ["чувствовавши"],
    "чувствовавши": ["чувствовав"],
    "чувствование": ["чувствованье"],
    "чувствованье": ["чувствование"],
    "чувствовать": ["ощущать", "чуять", "испытывать", "понимать", "догадываться", "улавливать"],
    "чувствоваться": ["ощущаться"],
    "чугун": ["чугуний"],
    "чугунев": ["чугуневши"],
    "чугуневши": ["чугунев"],
    "чугуний": ["чугун", "чугуняка", "железяка"],
    "чугунка": ["железная дорога", "железка"],
    "чугунок": ["чугун", "котелок"],
    "чудак": ["чудик", "чудило"],
    "чудачествовав": ["чудачествовавши"],
    "чудачествовавши": ["чудачествовав"],
    "чудачив": ["чудачивши"],
    "чудачивши": ["чудачив"],
    "чудачина": ["чудак", "чудик", "чудила", "чудило"],
    "чудачить": ["чудить"],
    "чудачка": ["причудница"],
    "чудашный": ["чудаковатый", "эксцентричный"],
    "чудесив": ["чудесивши"],
    "чудесивши": ["чудесив"],
    "чудесник": ["волшебник", "волхв", "колдун", "кудесник", "маг", "чародей"],
    "чудесница": ["волшебница", "колдунья", "кудесница", "чаровница"],
    "чудесный": ["сверхъестественный", "волшебный", "сказочный", "фантастический", "феерический", "прекрасный", "чудный", "превосходный", "отличный"],
    "чудив": ["чудивши"],
    "чудивши": ["чудив"],
    "чудик": ["чудак"],
    "чудила": ["чудак", "чудило"],
    "чудило": ["чудак", "чудила"],
    "чудинка": ["причуда", "причудливость", "чудаковатость"],
    "чудить": ["чудачествовать", "чудачить", "шутить", "дурачиться"],
    "чудиться": ["мерещиться", "казаться"],
    "чудище": ["чудовище", "монстр"],
    "чудний": ["дивний"],
    "чудно": ["чудесно"],
    "чудной": ["причудливый", "странный", "чудаковатый"],
    "чудный": ["удивительный", "чудесный", "волшебный", "прелестный", "прекрасный", "отличный"],
    "чудо": ["сверхъестественное", "диво", "волшебство"],
    "чудо в перьях": ["чудак"],
    "чудовище": ["чудище", "страшилище", "монстр", "урод"],
    "чудовищный": ["уродливый", "тератологический", "страшный", "гигантский", "огромный"],
    "чудодействовав": ["чудодействовавши"],
    "чудодействовавши": ["чудодействовав"],
    "чудодеяние": ["чудотворение", "чудодеянье"],
    "чудодеянье": ["чудотворение", "чудодеяние"],
    "чудом": ["чудесно", "невероятно", "необъяснимо"],
    "чудотворец": ["кудесник", "волшебник"],
    "чудотворив": ["чудотворивши"],
    "чудотворивши": ["чудотворив"],
    "чудотворить": ["чудодействовать", "чудотворствовать"],
    "чудотворица": ["прорицательница"],
    "чудотворно": ["чудодейственно", "чудодейно"],
    "чудотворный": ["чудодейственный", "чудодейный"],
    "чудотворство": ["чудотворение"],
    "чудское озеро": ["ледовое побоище"],
    "чужан": ["ас"],
    "чужбина": ["чужеземщина", "заграница"],
    "чуждаться": ["сторониться"],
    "чужденец": ["другоземец"],
    "чуждо": ["незнакомо", "отчуждённо"],
    "чуждость": ["отрешённость"],
    "чужев": ["чужевши"],
    "чужевши": ["чужев"],
    "чужедалье": ["чужбина", "чужеземщина"],
    "чужедальний": ["чужедальный"],
    "чужеземец": ["иностранец", "иноземец", "чужестранец"],
    "чужеземный": ["иноземный", "иностранный"],
    "чужеплеменный": ["иноплеменный"],
    "чужеродность": ["инородность", "разнородность"],
    "чужеродный": ["инородный"],
    "чужеспинник": ["захребетник"],
    "чужестранец": ["иностранец", "иноземец", "чужеземец"],
    "чужеяд": ["бездельник", "дармоед", "нахлебник", "паразит", "тунеядец", "трутень"],
    "чужеядный": ["паразитарный"],
    "чужое": ["чуждое", "неродное"],
    "чужоземний": ["закордонний"],
    "чужой": ["ксеноморф"],
    "чукар": ["чука", "скала", "височина"],
    "чукачан": ["чукучан"],
    "чукотский": ["луораветланский", "чукотский язык", "луораветланский язык"],
    "чукотский автономный округ": ["чукотка"],
    "чукотский язык": ["луораветланский язык"],
    "чукундур": ["панджар", "червено цвекло", "цвекло"],
    "чукучан": ["чукачан"],
    "чулан": ["кладовка"],
    "чули": ["тугу", "кукил", "куил", "кога", "кузиль"],
    "чулки в стакане": ["шнурки в стакане"],
    "чулман": ["кама"],
    "чулочник": ["кружевник", "мастер"],
    "чулочный": ["чюлошный"],
    "чулюкав": ["чулюкавши"],
    "чулюкавши": ["чулюкав"],
    "чумазенький": ["чумазый", "грязненький", "грязный"],
    "чумак": ["кабачник", "целовальник"],
    "чумаковав": ["чумаковавши"],
    "чумаковавши": ["чумаковав"],
    "чумачив": ["чумачивши"],
    "чумачивши": ["чумачив"],
    "чумбур": ["чембур"],
    "чумев": ["чумевши"],
    "чумевши": ["чумев"],
    "чумиза": ["буда", "головчатое просо"],
    "чумичка": ["ковш", "черпак"],
    "чумка": ["болезнь каре"],
    "чумной доктор": ["врачеватель чумы"],
    "чуперадло": ["опудало"],
    "чуприна": ["чупрына"],
    "чупрун": ["хохол", "чуб", "чуприна", "чупрына", "оселедец", "серяк"],
    "чур": ["чур меня", "нафиг-нафиг", "нахуй-нахуй"],
    "чурак": ["чурбан", "чурка"],
    "чураться": ["сторониться", "избегать"],
    "чурбак": ["чурбан"],
    "чурбан": ["чурбак", "чурка", "деревяшка", "дрова", "болван", "дурак", "тупица", "чучмек", "чурек", "урюк", "чурка неговорящая", "чурка с глазами", "чурка с ушами"],
    "чурбашка": ["чурбан"],
    "чурек": ["чурка"],
    "чуркобес": ["чурка", "ара", "зверёк"],
    "чурчхела": ["суджух", "шароц"],
    "чутка": ["чуток"],
    "чуткий": ["чувствительный", "тревожный", "отзывчивый", "участливый", "заботливый"],
    "чуток": ["чуть", "чуточку", "чуть-чуть", "чутка"],
    "чуточка": ["чуть-чуть", "капелька", "крошечка"],
    "чуточку": ["чуть-чуть", "чуток", "немножко", "чучуточку", "почучуточку"],
    "чуточный": ["чутошный"],
    "чуть": ["немного", "еле", "еле-еле", "едва", "едва-едва", "чуть-чуть", "чуток", "чуточку", "маленько", "с трудом", "насилу"],
    "чуть не": ["возможно", "едва не", "едва ли не", "чуть ли не", "почти что", "практически"],
    "чуть свет": ["ни свет ни заря"],
    "чуть-по-чуть": ["чуть-чуть", "едва-едва", "слегка", "немного"],
    "чуть-чутошний": ["чуть-чутошный"],
    "чуть-чутошный": ["чуть-чутошний"],
    "чутьё": ["нюх", "чуйка", "интуиция"],
    "чуфа": ["земляной миндаль"],
    "чуфыкав": ["чуфыкавши"],
    "чуфыкавши": ["чуфыкав"],
    "чуфыкать": ["чуфыркать", "чуфыскать"],
    "чуфыкнув": ["чуфыкнувши"],
    "чуфыкнувши": ["чуфыкнув"],
    "чуфыкнуть": ["чуфыркнуть"],
    "чуфыркав": ["чуфыркавши"],
    "чуфыркавши": ["чуфыркав"],
    "чуфыркать": ["чуфыкать", "чуфыскать"],
    "чуфыркнув": ["чуфыркнувши"],
    "чуфыркнувши": ["чуфыркнув"],
    "чуфыркнуть": ["чуфыкнуть"],
    "чуфыскав": ["чуфыскавши"],
    "чуфыскавши": ["чуфыскав"],
    "чуфыскать": ["чуфыркать", "чуфыкать"],
    "чуфыскнув": ["чуфыскнувши"],
    "чуфыскнувши": ["чуфыскнув"],
    "чуфыскнуть": ["чуфыкнуть", "чуфыркнуть"],
    "чуха": ["чоха", "черкеска"],
    "чухав": ["чухавши"],
    "чухавши": ["чухав"],
    "чухан": ["бомж", "замухрышка"],
    "чуханув": ["чуханувши"],
    "чуханувши": ["чуханув"],
    "чухаться": ["копаться"],
    "чухна": ["чухонец", "чухонка", "чухонцы"],
    "чухнув": ["чухнувши"],
    "чухнувши": ["чухнув"],
    "чухнуть": ["уйти", "уехать", "сбежать", "похитить", "украсть", "свистнуть", "слимонить", "стибрить", "спереть", "утянуть", "слямзить", "подтибрить", "стырить", "приделать ноги"],
    "чухня": ["чухна", "чушь", "фигня", "дурень"],
    "чухонец": ["талап", "чухна"],
    "чухонка": ["финка", "эстонка"],
    "чухонский": ["эстонский", "финский"],
    "чухралка": ["кардолентная машина"],
    "чучела": ["чучело"],
    "чучельник": ["таксидермист"],
    "чучмек": ["чукча", "хачик"],
    "чучуна": ["чучун", "мюлен"],
    "чучхе": ["кимирсенизм"],
    "чушка": ["поросёнок", "свинка", "рыло", "свинья", "чмо"],
    "чушок": ["чушка", "чухан"],
    "чушпан": ["ботаник", "лох", "фраер"],
    "чушь": ["ерунда", "чепуха", "нонсенс", "бессмыслица", "вздор", "ахинея", "околесица", "галиматья", "белиберда", "абсурд", "абракадабра", "чушня"],
    "чушь собачья": ["сорок бочек арестантов", "чёрт знает что", "бред собачий", "бред сумасшедшего"],
    "чуяв": ["чуявши"],
    "чуявши": ["чуяв"],
    "чуять": ["обонять", "унюхивать", "знать", "сознавать"],
    "чхав": ["чхавши"],
    "чхавши": ["чхав"],
    "чхве": ["цой"],
    "чхнув": ["чхнувши"],
    "чхнувши": ["чхнув"],
    "чхнуть": ["чихнуть"],
    "чъехынэм": ["генам"],
    "чъыг": ["чъыгы"],
    "чъыгы": ["чъыг"],
    "чыбын": ["чибинь"],
    "чыгъыш": ["цыгъыс"],
    "чымчык": ["канаттуу", "куш"],
    "чырванець": ["барвавець"],
    "чырвань": ["барва"],
    "чых": ["чыкъ"],
    "чья бы корова мычала": ["кто бы говорил"],
    "чэйпа": ["чайпа"],
    "чэщ": ["чещы"],
    "чюгны": ["чюпны"],
    "чяво": ["романо чяво", "ром"],
    "чяй": ["ромны"],
    "чё": ["что", "чего", "почему", "зачем"],
    "чёбот": ["башмак", "ботинок", "сапог"],
    "чёкав": ["чёкавши"],
    "чёкавши": ["чёкав"],
    "чёкать": ["чокать"],
    "чёлка": ["монобровь"],
    "чёлн": ["однодеревка", "челнок", "челночок", "ладья", "лодка", "лодочка", "лодчонка", "труба"],
    "чён": ["рувано кхам", "романо кхам", "чёрэнгиро кхам"],
    "чёпафнемс": ["юпиемс"],
    "чёпафтомс": ["юпадемс"],
    "чёр": ["кисыкари"],
    "чёрек": ["экмек"],
    "чёркав": ["чёркавши"],
    "чёркавши": ["чёркав"],
    "чёрная доска": ["доска позора"],
    "чёрная дыра": ["коллапсар", "бездонная бочка", "бездонный колодец", "прорва"],
    "чёрная магия": ["чернокнижие"],
    "чёрная немочь": ["эпилепсия", "мелена", "болезнь гончарного круга", "падучая болезнь", "падучая", "падучка", "проказа", "медведь", "суп"],
    "чёрная ольха": ["ольха чёрная", "ольха клейкая"],
    "чёрная работа": ["грязная работа"],
    "чёрная смерть": ["чума", "ротан"],
    "чёрненький": ["чёрный"],
    "чёрно-белый": ["бело-чёрный"],
    "чёрно-бурый": ["тёмно-бурый", "буро-чёрный"],
    "чёрное дерево": ["эбен"],
    "чёрное золото": ["нефть", "уголь"],
    "чёрное море": ["понт эвксинский", "русское море", "карадениз"],
    "чёрный континент": ["африка"],
    "чёрный копатель": ["чёрный археолог"],
    "чёрный корм": ["сено"],
    "чёрный лес": ["лиственный лес", "чернолесье"],
    "чёрный металл": ["чермет"],
    "чёрный список": ["чс", "стоп-лист", "блэклист", "блеклист"],
    "чёрный тмин": ["калинджи", "нигелла", "сейдана", "чернушка", "чернушка посевная", "чёрное семя", "римский кориандр"],
    "чёрный тюльпан": ["рябчик широколистный"],
    "чёрный феминизм": ["антирасистский феминизм", "вуманизм"],
    "чёрный хлеб": ["чернушка"],
    "чёрный чай": ["красный чай"],
    "чёрным по белому": ["русским по белому"],
    "чёрствость": ["зачерствелость", "заскорузлость", "сухость", "бездушность", "жестокость"],
    "чёрствый": ["зачерствелый", "засохший", "бездушный", "нечуткий"],
    "чёрт": ["анчутка", "бес", "дьявол", "демон", "нечистый", "окаянный", "шайтан", "лукавый", "сатана", "чёрт возьми", "чёрт побери", "чёрт подери", "ох", "вот же", "вот чёрт"],
    "чёрт возьми": ["чёрт побери"],
    "чёрт знает как": ["бог знает как"],
    "чёрт ногу сломит": ["ералаш", "без поллитры не разберёшься", "китайская грамота", "тёмный лес"],
    "чёрт побери": ["чёрт подери", "чёрт возьми", "чёрт побери на тёмный лес", "японский городовой"],
    "чёрт с виру": ["незнакомец"],
    "чёрт-те что": ["чёрт-те что и сбоку бантик"],
    "чёрт-те что и сбоку бантик": ["чёрт-те что"],
    "чёрта с два": ["нет-нет", "вовсе нет", "ничего подобного", "как бы не так", "вот ещё", "дудки", "дураков нет", "нашли дурака", "беса лысого", "чёрта лысого", "чёрта два", "хуя с два"],
    "чёртов": ["треклятый"],
    "чёртов куст": ["элеутерококк", "сибирский женьшень", "дикий перец"],
    "чёртова дюжина": ["тринадцать"],
    "чёртово колесо": ["колесо обозрения"],
    "чёртовый": ["скверный", "отвратительный", "проклятый", "ненавистный", "осточертевший"],
    "чёс": ["чесание", "зуд", "чесотка", "вычёсывание", "расчёсывание", "бегство", "драп", "драпак", "дёр", "стрекач", "побои", "избиение", "битьё", "расправа", "взбучка"],
    "чёсанок": ["валенок"],
    "чёсывав": ["чёсывавши"],
    "чёсывавши": ["чёсывав"],
    "чётки": ["вервица", "розарий"],
    "чёткий": ["отчётливый", "явственный", "различимый", "разборчивый", "резкий", "точный", "ясный", "недвусмысленный", "отточенный", "выверенный", "аккуратный", "рациональный"],
    "чётко": ["отчётливо", "ясно", "классно"],
    "ш-ш": ["тише", "тс", "тсс", "ссс", "тш", "тш-ш-ш-ш", "чш"],
    "ш-ш-ш": ["тише", "тс", "тсс", "ссс", "тш", "тш-ш-ш-ш", "чш", "ш-ш", "цыц"],
    "шаба": ["идь", "тётьмак"],
    "шабак": ["шин-бет"],
    "шабала": ["шумовка", "болванка", "чурка", "колода", "пустомеля", "болтун", "балаболка"],
    "шабаршив": ["шабаршивши"],
    "шабаршивши": ["шабаршив"],
    "шабашевав": ["шабашевавши"],
    "шабашевавши": ["шабашевав"],
    "шабашив": ["шабашивши"],
    "шабашивши": ["шабашив"],
    "шабашить": ["подшабашивать"],
    "шабашка": ["подработка", "халтура", "халтурка"],
    "шабашник": ["калымщик"],
    "шабашничав": ["шабашничавши"],
    "шабашничавши": ["шабашничав"],
    "шаббат": ["шабат"],
    "шаблонизация": ["шаблонизирование"],
    "шаблонизировав": ["шаблонизировавши"],
    "шаблонизировавши": ["шаблонизировав"],
    "шаблонний": ["шаблоновий"],
    "шаблонный": ["прямолинейный", "примитивный", "обыкновенный", "заурядный", "банальный", "трафаретный", "рефлекторный", "заезженный", "избитый", "тривиальный"],
    "шабнам": ["жола"],
    "шаболда": ["пустомеля", "болтун", "лгун", "шабалда", "шалава", "давалка"],
    "шабпарак": ["муши паррон", "хаффош"],
    "шабран": ["дивичи"],
    "шабрив": ["шабривши"],
    "шабривши": ["шабрив"],
    "шабрить": ["шабровать"],
    "шабровав": ["шабровавши"],
    "шабровавши": ["шабровав"],
    "шабровка": ["шабрение"],
    "шабёр": ["сябёр"],
    "шаварма": ["шаурма", "шаверма"],
    "шаверма": ["шаурма", "донер-кебаб", "шавуха"],
    "шавермейстер": ["шаурмен", "шаурмист", "шаурмье"],
    "шаверменная": ["шаурменная", "шаурмятня", "шаурмячная"],
    "шавийский": ["шауйский"],
    "шавка": ["шавочка", "шавчонка", "собачка", "собачонка", "сявка"],
    "шавкати": ["шамкати"],
    "шавла": ["шула"],
    "шавомс": ["пиксомс", "эрьхнемс", "аделамс", "кулофтомс", "стожамс", "вачкодемс", "тотнамс", "калгомс", "покодемс", "трудендамс", "валомс", "вишкста", "пиземс"],
    "шавуха": ["шаурма"],
    "шагав": ["шагавши"],
    "шагавши": ["шагав"],
    "шаганув": ["шаганувши"],
    "шаганувши": ["шаганув"],
    "шаганье": ["шагание"],
    "шагать": ["ступать", "идти", "ходить"],
    "шагать по трупам": ["идти по трупам"],
    "шагнув": ["шагнувши"],
    "шагнувши": ["шагнув"],
    "шагомер": ["педометр"],
    "шагренировав": ["шагренировавши"],
    "шагренировавши": ["шагренировав"],
    "шагъар": ["шэхъэр"],
    "шадраван": ["фонтан", "водоскок"],
    "шадрван": ["шедрван", "фонтана"],
    "шадровитый": ["шадроватый"],
    "шадуф": ["журавль"],
    "шажочек": ["шажок"],
    "шазамив": ["шазамивши"],
    "шазамивши": ["шазамив"],
    "шайвизм": ["шиваизм"],
    "шайка": ["шаечка", "шаюшечка", "бадья"],
    "шайка-лейка": ["шайка", "гопка", "гопкомпания"],
    "шайтан": ["иблис"],
    "шайтан-труба": ["гранатомёт", "базука"],
    "шайх": ["мулло"],
    "шакал": ["чакал", "чакалка"],
    "шакалив": ["шакаливши"],
    "шакаливши": ["шакалив"],
    "шакальё": ["сброд"],
    "шакалёнок": ["шакал"],
    "шакра": ["индра"],
    "шалава": ["девка", "проститутка", "шлюха", "стерва", "блудница"],
    "шалапендра": ["прошмандовка", "шаболда", "шлёнда", "шлёндра", "шлюндра", "шлюха"],
    "шалашка": ["шалаш"],
    "шалашовка": ["проститутка", "развратница", "распутница", "шаболда", "шалашовочка", "шлёнда", "шлёндра"],
    "шалберив": ["шалберивши"],
    "шалберивши": ["шалберив"],
    "шалберить": ["шалберничать"],
    "шалберничав": ["шалберничавши"],
    "шалберничавши": ["шалберничав"],
    "шалберничать": ["шалберить"],
    "шалев": ["шалевши"],
    "шалевав": ["шалевавши"],
    "шалевавши": ["шалевав"],
    "шалевать": ["шелевать", "шилевать"],
    "шалевши": ["шалев"],
    "шалив": ["шаливши"],
    "шаливши": ["шалив"],
    "шалман": ["пивная", "кабак", "шалманка", "ресторан", "ресторация", "рестик", "трактир", "заведение", "рыгаловка", "тошниловка", "кружало"],
    "шалманщик": ["трактирщик", "завсегдатай"],
    "шалобан": ["щелбан", "шелопет"],
    "шалобол": ["болтун", "трепло"],
    "шаловливо": ["озорно", "игриво"],
    "шаловливый": ["игривый", "проказливый", "непоседливый", "развязный", "фривольный"],
    "шалола": ["шаршара", "обшор"],
    "шалоник": ["шалонник", "шелоник", "шелонник"],
    "шалонник": ["шалоник", "шелоник", "шелонник"],
    "шалопай": ["бездельник", "повеса", "разгильдяй", "шаматон", "шалун", "проказник", "оболтус"],
    "шалопайка": ["бездельница"],
    "шалопайничав": ["шалопайничавши"],
    "шалопайничавши": ["шалопайничав"],
    "шалопайствовав": ["шалопайствовавши"],
    "шалопайствовавши": ["шалопайствовав"],
    "шалопут": ["бездельник", "повеса", "лоботряс", "шалопай", "лежебока", "лентяй", "байбак"],
    "шалопутствовав": ["шалопутствовавши"],
    "шалопутствовавши": ["шалопутствовав"],
    "шалость": ["баловство", "дурачество", "шутка"],
    "шалун": ["балбес", "озорник", "проказник", "сорванец", "сорвиголова", "шалопай"],
    "шалунья": ["проказница", "баловница"],
    "шалфей": ["сальвия"],
    "шалыга": ["шалыган"],
    "шалыганив": ["шалыганивши"],
    "шалыганивши": ["шалыганив"],
    "шалый": ["блажной"],
    "шальвары": ["шаровары"],
    "шальной": ["безумный", "одурелый", "очумелый", "сумасшедший", "помешанный", "одержимый", "полоумный", "безрассудный", "сумасбродный", "случайный"],
    "шальные деньги": ["бешеные деньги"],
    "шалюмо": ["свирель", "дудка", "дуда", "флейта"],
    "шаляй-валяй": ["шаля-валя", "кое-как", "небрежно", "спустя рукава"],
    "шама": ["шамма"],
    "шамав": ["шамавши"],
    "шамавши": ["шамав"],
    "шаман": ["заклинатель", "знахарь", "колдун", "спец", "хакер"],
    "шаманив": ["шаманивши"],
    "шаманивши": ["шаманив"],
    "шаманизм": ["шаманство"],
    "шаманий": ["шаманский"],
    "шаманить": ["шаманствовать", "колдовать", "ворожить", "волховать", "кудесничать", "химичить"],
    "шаманский": ["шаманий"],
    "шаманствовав": ["шаманствовавши"],
    "шаманствовавши": ["шаманствовав"],
    "шамануть": ["рубануть", "хавануть"],
    "шаматон": ["бездельник", "шалопай", "повеса"],
    "шаматонив": ["шаматонивши"],
    "шаматонивши": ["шаматонив"],
    "шамать": ["кушать", "закусывать", "заправляться", "подкрепляться", "жевать", "жрать", "лопать", "наворачивать", "рубать", "трескать", "хряпать", "трапезовать", "трапезничать", "хавать"],
    "шамбелян": ["камергер"],
    "шамир": ["адамас"],
    "шамкав": ["шамкавши"],
    "шамкавши": ["шамкав"],
    "шамкир": ["шамхор"],
    "шамкнув": ["шамкнувши"],
    "шамкнувши": ["шамкнув"],
    "шамма": ["шама"],
    "шамозит": ["брунсвигит"],
    "шамол": ["бод"],
    "шамотня": ["шамотнява", "метушня"],
    "шамотовый": ["шамотный"],
    "шампанизировав": ["шампанизировавши"],
    "шампанизировавши": ["шампанизировав"],
    "шампанское": ["шампунь", "шампусик"],
    "шампиньон": ["печерица"],
    "шампиньонник": ["шампиньонница"],
    "шампиньонница": ["шампиньонник"],
    "шампур": ["вертел"],
    "шамсия": ["мизалла"],
    "шамхальствовав": ["шамхальствовавши"],
    "шамхальствовавши": ["шамхальствовав"],
    "шамшер": ["сайф"],
    "шамшив": ["шамшивши"],
    "шамшивши": ["шамшив"],
    "шандал": ["подсвечник", "канделябр", "кандило"],
    "шандарахнув": ["шандарахнувши"],
    "шандарахнувши": ["шандарахнув"],
    "шандарахнуть": ["бабахнуть", "трахнуть", "треснуть", "звездануть"],
    "шандора": ["шандор"],
    "шанежка": ["шаньга"],
    "шанец": ["окоп", "шанц"],
    "шанжан": ["переливчатый"],
    "шановник": ["шанувальник"],
    "шанс": ["возможность"],
    "шанский": ["иньский"],
    "шансон": ["русский шансон", "блатнятина"],
    "шансонетный": ["шансонеточный"],
    "шансонеточный": ["шансонетный"],
    "шантажировав": ["шантажировавши"],
    "шантажировавши": ["шантажировав"],
    "шантажирование": ["шантаж"],
    "шантажировать": ["вымогать"],
    "шантажист": ["вымогатель"],
    "шантан": ["кафешантан"],
    "шантарские острова": ["шантары"],
    "шантары": ["шантарские острова"],
    "шантрапа": ["ничтожество", "ноль без палочки", "пройдоха", "проныра", "проходимец", "мошенник", "шелупонь", "шушера", "шпана"],
    "шантрет": ["шатен"],
    "шантропа": ["шантрапа", "шваль"],
    "шанування": ["поважання"],
    "шанхайская организация сотрудничества": ["шос"],
    "шаньга": ["шанежка"],
    "шанька": ["торбинка"],
    "шанёжник": ["архангелогородец", "помор", "трескоед"],
    "шапалак": ["шабпара", "парвона"],
    "шапама ланга": ["вайвелез"],
    "шапито": ["шатёр"],
    "шапка-ушанка": ["ушанка"],
    "шапочка": ["шапка", "шапчонка", "шапчоночка"],
    "шаптати": ["шапутати"],
    "шапутати": ["шаптати"],
    "шапчонка": ["шапочка", "шапчоночка"],
    "шар": ["шарик", "воздушный шар", "мяч", "пролив"],
    "шарага": ["шаражка", "шарашка", "кодла", "рога и копыта", "рогачка", "рогачёвка"],
    "шарада": ["шарада в лицах", "живые шарады", "загадка", "тайна"],
    "шаражка": ["шарашка"],
    "шарахав": ["шарахавши"],
    "шарахавши": ["шарахав"],
    "шарахаться": ["отбрасываться", "уклоняться", "отходить", "шандарахаться", "отскакивать", "стукаться", "шататься", "тусоваться", "носиться", "шлёндать"],
    "шарахаться в десну": ["биться в дёсны", "долбиться в дёсны", "хлестаться в десну"],
    "шарахнув": ["шарахнувши"],
    "шарахнувши": ["шарахнув"],
    "шарахнуться": ["шандарахнуться", "отскочить", "скакнуть"],
    "шарашив": ["шарашивши"],
    "шарашивши": ["шарашив"],
    "шарашиться": ["слоняться", "таскаться"],
    "шарашка": ["шарашкина контора"],
    "шарашкина контора": ["рога и копыта", "шарашка", "шарашкина компания", "шарашкин бизнес", "шарашкины навары", "шайка-лейка", "шатай-валяй"],
    "шардировав": ["шардировавши"],
    "шардировавши": ["шардировав"],
    "шардирование": ["шардинг", "сегментирование", "фрагментирование", "партицирование"],
    "шардировать": ["сегментировать", "фрагментировать"],
    "шаржевый": ["карикатурный", "гротескный", "пародийный", "издевательский", "юмористический", "иронический", "сатирический", "бурлескный", "фарсовый"],
    "шаржировав": ["шаржировавши"],
    "шаржировавши": ["шаржировав"],
    "шариаж": ["шарияж"],
    "шариажный": ["шарьяжный"],
    "шарив": ["шаривши"],
    "шаривав": ["шаривавши"],
    "шаривавши": ["шаривав"],
    "шаривари": ["какофония", "кошачий концерт", "бедлам", "шабаш"],
    "шаривши": ["шарив"],
    "шарик": ["тельце"],
    "шарикоподшипник": ["шариковый подшипник"],
    "шарить": ["нащупывать", "рыскать", "обыскивать"],
    "шариться": ["шарить"],
    "шарияж": ["шариаж", "шарьяж"],
    "шаркав": ["шаркавши"],
    "шаркавши": ["шаркав"],
    "шаркать": ["шоркать", "шлепать", "расшаркиваться", "шваркать"],
    "шаркивав": ["шаркивавши"],
    "шаркивавши": ["шаркивав"],
    "шаркнув": ["шаркнувши"],
    "шаркнувши": ["шаркнув"],
    "шаркёзи": ["саркози"],
    "шарлавык": ["шарлама"],
    "шарлатанив": ["шарлатанивши"],
    "шарлатанивши": ["шарлатанив"],
    "шарлатанствовав": ["шарлатанствовавши"],
    "шарлатанствовавши": ["шарлатанствовав"],
    "шарлатанствовать": ["шарлатанить"],
    "шарлот": ["шалот", "лук-шалот"],
    "шарм": ["обаяние", "обаятельность", "прелесть", "чары", "чарм", "пленительность", "обольстительность", "очарование", "чарующий", "сила", "неотразимость"],
    "шарногель": ["шрабкугель"],
    "шароб": ["май", "мусаллас", "бода"],
    "шаровав": ["шаровавши"],
    "шаровавши": ["шаровав"],
    "шаровары": ["шальвары", "шаравары"],
    "шаровидный": ["шарообразный"],
    "шаровик": ["дармовщик", "халявщик", "нахлебник"],
    "шаровой": ["сферический"],
    "шаровый": ["дикий", "серый"],
    "шаром покати": ["пусто"],
    "шаромс": ["шаракодомс", "шарозевомс"],
    "шаромыга": ["шаромыжник"],
    "шаромыжник": ["ловкач", "жулик", "пройдоха", "шаромыга"],
    "шаромыжница": ["шаромыга"],
    "шаромыжничав": ["шаромыжничавши"],
    "шаромыжничавши": ["шаромыжничав"],
    "шарообразный": ["шаровидный"],
    "шарохаться": ["шарошиться"],
    "шарошив": ["шарошивши"],
    "шарошивши": ["шарошив"],
    "шарошить": ["фрезеровать"],
    "шарошка": ["фреза", "борфреза", "бор"],
    "шароёбив": ["шароёбивши"],
    "шароёбивши": ["шароёбив"],
    "шароёбить": ["мотаться", "слоняться"],
    "шароёбиться": ["слоняться", "шляться", "шататься", "блуждать", "таскаться"],
    "шароёбство": ["шатание", "блуждание"],
    "шарпав": ["шарпавши"],
    "шарпавши": ["шарпав"],
    "шарпать": ["драть", "обдирать", "скрести", "царапать", "шаркать"],
    "шарукань": ["осенев"],
    "шарур": ["ильичёвск"],
    "шарушки": ["катышек"],
    "шаршара": ["шалола", "обшор"],
    "шаршаф": ["фередж", "фередже", "паранджа", "чарчаф", "чадра"],
    "шары по семь копеек": ["глаза по пять копеек", "глаза по пять рублей", "глаза по пять крон", "глаза по семь копеек", "шары по пять копеек", "шары по пять рублей", "шары по пять крон"],
    "шары подкатывать": ["подкатывать шары"],
    "шарьхкодемс": ["фатямс", "талакодомс", "сявомс мяльс", "содамс"],
    "шарьяж": ["шариаж"],
    "шарьяжный": ["шариажный"],
    "шастав": ["шаставши"],
    "шаставши": ["шастав"],
    "шасталка": ["остеломатель"],
    "шастаться": ["шляться"],
    "шат": ["шатание", "качание", "качка", "раскачивание", "шатка", "колебание", "разброд", "непоследовательность"],
    "шат-гора": ["эльбрус", "шат"],
    "шата": ["охабень", "оклад"],
    "шатав": ["шатавши"],
    "шатавши": ["шатав"],
    "шатавшийся": ["качавшийся"],
    "шатание": ["качание", "раскачивание", "качка", "шат", "шатка", "фланирование", "колебание", "разброд", "непоследовательность"],
    "шатанье": ["шатание"],
    "шатать": ["качать", "колебать", "покачивать"],
    "шататься": ["гулять", "шляться", "слоняться", "ошиваться", "околачиваться", "чкаться"],
    "шатаут": ["шутаут"],
    "шатдаун": ["выключение", "прекращение", "работа", "остановка", "закрытие", "перерыв"],
    "шатен": ["шантрет"],
    "шатировав": ["шатировавши"],
    "шатировавши": ["шатировав"],
    "шатирштихель": ["ребштихель"],
    "шатия": ["толпа"],
    "шатко": ["зыбко"],
    "шаткость": ["малоустойчивость", "зыбкость", "рискованность", "нетвердость", "спорность", "неправдоподобность"],
    "шатланырга": ["шатлану"],
    "шатлык": ["куаныч"],
    "шатляндыя": ["шкоцыя"],
    "шатнув": ["шатнувши"],
    "шатнувши": ["шатнув"],
    "шатранг": ["чатранг", "шатрандж"],
    "шатрандж": ["шатранг"],
    "шаттл": ["спейс шаттл", "челнок"],
    "шатунний": ["шатуновий"],
    "шатунок": ["крепёж"],
    "шатырлых": ["сатырлык"],
    "шатёр": ["палатка", "тент", "полог"],
    "шауйя": ["шавийя"],
    "шауни": ["шони"],
    "шаурма": ["кебаб", "донер-кебаб", "шаверма"],
    "шаурмен": ["шавермейстер", "шаурмист", "шаурмье"],
    "шаурменная": ["шаверменная", "шаурмятня", "шаурмячная"],
    "шаурмист": ["шавермейстер", "шаурмен", "шаурмье"],
    "шаурмье": ["шавермейстер", "шаурмен", "шаурмист"],
    "шаурмятня": ["шаурменная", "шаверменная", "шаурмячная"],
    "шаурмячная": ["шаурмятня", "шаурменная", "шаверменная"],
    "шаф": ["поставец"],
    "шафер": ["дружка"],
    "шаферствовав": ["шаферствовавши"],
    "шаферствовавши": ["шаферствовав"],
    "шафран": ["крокус"],
    "шафранный": ["шафрановый", "крокусовый"],
    "шахбану": ["шахиня"],
    "шахер-махер": ["афера", "махинаторство", "фигли-мигли"],
    "шахид": ["тегерань", "иранский экспресс", "цветёт герань", "цветение герани"],
    "шахид-такси": ["хачмобиль"],
    "шахин": ["рыжеголовый сапсан"],
    "шахиншах": ["шах", "шаханшах", "царь царей"],
    "шахиня": ["шахбану"],
    "шахист": ["шахиста"],
    "шахиста": ["шахист"],
    "шахматка": ["таблица"],
    "шаховав": ["шаховавши"],
    "шаховавши": ["шаховав"],
    "шахристан": ["хисар"],
    "шахс": ["шахсият", "одам", "кас"],
    "шахта": ["рудник", "колодец"],
    "шахта лифта": ["лифтовая шахта"],
    "шахтарча": ["шахтарчук"],
    "шахтний": ["копальневий"],
    "шахтёнка": ["шахта"],
    "шахтёр": ["горнорабочий", "горняк"],
    "шахтёрив": ["шахтёривши"],
    "шахтёривши": ["шахтёрив"],
    "шахтёрск": ["торо", "алексеево-орловка", "катык"],
    "шашель": ["домовый усач", "дровосек", "шашень"],
    "шашень": ["тередо", "древоточец", "шашель", "домовый усач", "дровосек"],
    "шашечный": ["шахматный"],
    "шашистка": ["шашечница"],
    "шашка": ["торец"],
    "шашлична": ["шашличня"],
    "шашличня": ["шашлична"],
    "шашни": ["происки", "козни", "интриги", "ковы", "каверза", "амуры", "любовная связь"],
    "шаштаразшы": ["шаштараз"],
    "шаърбоф": ["шоир"],
    "шаяв": ["шаявши"],
    "шаявши": ["шаяв"],
    "шаять": ["шаить", "тлеть", "тлеться"],
    "шваль": ["шантропа", "шелупонь", "шушера", "шушваль", "дрянь", "мерзость", "отбросы", "рвань", "рванина", "чернь", "быдло", "быдломасса", "гопота", "гопотень", "отребье"],
    "швальный": ["швейный", "пошивочный", "портняжный"],
    "швальня": ["швейная мастерская", "пошивочная", "портняжная мастерская", "портновская мастерская", "швальная", "ателье"],
    "швальщик": ["шваль"],
    "шваннома": ["нейрофиброма"],
    "швар": ["ашвар"],
    "шваркав": ["шваркавши"],
    "шваркавши": ["шваркав"],
    "шварканье": ["шваркание"],
    "шваркать": ["бросать", "кидать", "швырять"],
    "шваркнув": ["шваркнувши"],
    "шваркнувши": ["шваркнув"],
    "шваркнуться": ["бахнуться", "стукнуться"],
    "швартов": ["чалка", "чал", "пристань"],
    "швартовав": ["швартовавши"],
    "швартовавши": ["швартовав"],
    "швартовать": ["причаливать", "чалить", "ставить на причал"],
    "швартовив": ["швартовивши"],
    "швартовивши": ["швартовив"],
    "швартовить": ["швартовать"],
    "швартовка": ["причаливание", "пришвартовывание", "пришвартовка"],
    "швартовый": ["швартовный"],
    "швах": ["плохо", "скверно", "никчёмно"],
    "шведоязычный": ["шведскоязычный"],
    "шведский": ["свейский"],
    "шведский стол": ["конь"],
    "шведский язык": ["шведский"],
    "шведскоязычный": ["шведоязычный"],
    "швейник": ["портной", "суконщик", "швейница"],
    "швейный": ["портняжный"],
    "швейцар": ["привратник", "портье", "придверник"],
    "швейцарец": ["швейцар"],
    "швейцария": ["гельвеция", "швейцарская конфедерация"],
    "швермер": ["змейка", "шутиха"],
    "шветамбар": ["светамбар"],
    "швец": ["портной", "портняжка", "портнишка", "портняга", "лицовщик", "шваль", "шевец", "швейчик"],
    "швеция": ["королевство швеция"],
    "швець": ["чоботар"],
    "швея": ["портниха"],
    "шво": ["зшивка", "шов"],
    "шворень": ["шкворень", "стержень", "сердечник", "штырь"],
    "шворочка": ["мотузка"],
    "швыдкий": ["борзый", "быстроногий", "быстроходный", "быстрый", "проворный", "прыткий", "скоростной", "шустрый", "мгновенный", "скоротечный", "шибкий", "моментальный", "скорый", "спешный"],
    "швыривав": ["швыривавши"],
    "швыривавши": ["швыривав"],
    "швыркав": ["швыркавши"],
    "швыркавши": ["швыркав"],
    "швыркать": ["фыркать", "сёрбать"],
    "швыркнув": ["швыркнувши"],
    "швыркнувши": ["швыркнув"],
    "швыркнуть": ["фыркнуть"],
    "швырнув": ["швырнувши"],
    "швырнувши": ["швырнув"],
    "швырнуть": ["бросить", "запустить"],
    "швырок": ["бросок", "бита", "биток", "бабка", "швырковые дрова"],
    "швыряв": ["швырявши"],
    "швырявши": ["швыряв"],
    "швыряло": ["стакан"],
    "швырянье": ["швыряние"],
    "швырять": ["кидать", "бросать", "метать", "разбрасывать", "раскидывать", "трясти", "мотать"],
    "швыряться": ["бросаться", "кидаться"],
    "шеб": ["нишеб"],
    "шебаршив": ["шебаршивши"],
    "шебаршивши": ["шебаршив"],
    "шебаршить": ["шебуршить"],
    "шебаршиться": ["шебуршиться"],
    "шебби-шик": ["шэбби-шик"],
    "шебидан": ["омехтан"],
    "шебуршав": ["шебуршавши"],
    "шебуршавши": ["шебуршав"],
    "шебуршать": ["шебаршить", "шебуршить"],
    "шебуршаться": ["шебаршиться"],
    "шебуршенье": ["шебуршение"],
    "шебуршив": ["шебуршивши"],
    "шебуршивши": ["шебуршив"],
    "шебуршить": ["шебаршить", "шебуршать"],
    "шебуршиться": ["шебаршиться", "шуршать", "шелестеть", "ворошиться", "возиться", "копошиться"],
    "шебутив": ["шебутивши"],
    "шебутивши": ["шебутив"],
    "шевалье": ["кавалер"],
    "шевеленье": ["шевеление"],
    "шевелив": ["шевеливши"],
    "шевеливши": ["шевелив"],
    "шевелить булками": ["шевелиться", "шевелить чулками", "шевелить колготками", "шевелить помидорами", "дёргать булками", "трясти булками"],
    "шевелить колготками": ["шевелиться", "шевелить чулками", "шевелить помидорами", "дёргать булками", "трясти булками", "шевелить булками"],
    "шевелить помидорами": ["шевелиться", "шевелить чулками", "шевелить колготками", "дёргать булками", "трясти булками", "шевелить булками"],
    "шевелить рогом": ["думать", "соображать"],
    "шевелить чулками": ["шевелить колготками", "шевелить помидорами", "дёргать булками", "трясти булками", "шевелить булками"],
    "шевельнув": ["шевельнувши"],
    "шевельнувши": ["шевельнув"],
    "шевельнуть": ["пошевелить", "двинуть", "расшевелить"],
    "шевельнуть мозгами": ["раскинуть умом", "поварить котелком"],
    "шевельнуться": ["пошевельнуться", "пробудиться", "возникнуть", "появиться"],
    "шевелюра": ["волосы"],
    "шевелюристый": ["густоволосый", "пышноволосый"],
    "шевелёнка": ["стряхивание", "сдёргивание", "смаз"],
    "шевинговав": ["шевинговавши"],
    "шевинговавши": ["шевинговав"],
    "шевроле": ["шевик"],
    "шевыряв": ["шевырявши"],
    "шевырявши": ["шевыряв"],
    "шега": ["виц", "закачка", "глума", "майтап"],
    "шегаджия": ["шегобиец", "присмехулник", "присмехулко", "подигравач", "духовит", "зевзек"],
    "шедевральный": ["выдающийся", "гениальный"],
    "шедрван": ["шадрван", "фонтана"],
    "шедши": ["шед"],
    "шеечка": ["шейка"],
    "шезлонг": ["лонгшез"],
    "шейгец": ["плут", "ловкач"],
    "шейка": ["горлышко"],
    "шейкер": ["шекер"],
    "шеймив": ["шеймивши"],
    "шеймивши": ["шеймив"],
    "шейминг": ["осрамление", "опозорение", "стыжение", "пристыжение", "поругание", "травля"],
    "шеймить": ["стыдить", "позорить"],
    "шейный": ["цервикальный"],
    "шейный платок": ["галстук", "шарф"],
    "шейпинг": ["ритмическая гимнастика", "фитнес"],
    "шейретин": ["хитрец", "шмекер"],
    "шейтель": ["шейтль"],
    "шекерчи": ["ширинчи"],
    "шеки": ["нуха"],
    "шеко": ["щек"],
    "шекспиров": ["шекспировский"],
    "шекспировский": ["шекспиров"],
    "шелапут": ["шалопут"],
    "шелевав": ["шелевавши"],
    "шелевавши": ["шелевав"],
    "шелеп": ["плеть", "нагайка", "шелепень", "шелепуга", "шепалуга"],
    "шелепуга": ["шелопуга", "шелеп"],
    "шелест": ["шелестение"],
    "шелестев": ["шелестевши"],
    "шелестевши": ["шелестев"],
    "шелестенье": ["шелестение"],
    "шелестеть": ["шелестить"],
    "шелестив": ["шелестивши"],
    "шелестивши": ["шелестив"],
    "шелестить": ["шелестеть"],
    "шелестнув": ["шелестнувши"],
    "шелестнувши": ["шелестнув"],
    "шелковица": ["тут", "тутовник", "тютина", "тутовое дерево"],
    "шелкограмма": ["шелкография"],
    "шелкография": ["трафаретная печать", "шелкографский отпечаток", "сериграфия", "сериография", "шелкограмма"],
    "шелкопряд": ["тутовый шелкопряд", "шелковичный червь"],
    "шеллак": ["гуммилак"],
    "шеллингианец": ["шеллингист"],
    "шеломутник": ["жимолость", "кобылица", "волчья ягода"],
    "шелоник": ["шалоник", "шалонник", "шелонник"],
    "шелонник": ["шалоник", "шалонник", "шелоник"],
    "шелопай": ["шалопай"],
    "шелопуга": ["шелепуга", "хлыст", "кнут"],
    "шелопут": ["шалопут", "шелапут", "шелопай", "шалопай"],
    "шелохнув": ["шелохнувши"],
    "шелохнувши": ["шелохнув"],
    "шелохнуть": ["шевельнуть"],
    "шелтер": ["ночлежка", "прибежище", "пристанище", "убежище"],
    "шелудивев": ["шелудивевши"],
    "шелудивевши": ["шелудивев"],
    "шелудивость": ["паршивый"],
    "шелудивый": ["паршивый", "коростный", "коростовый", "чесоточный", "дрянной", "скверный", "грязный", "облезлый", "гадкий", "мерзкий"],
    "шелупонь": ["шантрапа", "шваль", "шушваль", "шушера", "сброд", "сявка", "шестёрка", "мелкая сошка"],
    "шелушенье": ["шелушение"],
    "шелушив": ["шелушивши"],
    "шелушивши": ["шелушив"],
    "шельда": ["эско"],
    "шельма": ["ловкач", "ловчила", "хитрец", "шельмец", "мошенник", "аферист", "плут"],
    "шельмец": ["шельма", "ловкач", "хитрец", "пройдоха", "мошенник"],
    "шельмовав": ["шельмовавши"],
    "шельмовавши": ["шельмовав"],
    "шельмовство": ["плутовство", "лукавство", "хитрость", "мошенничество"],
    "шельф": ["материковая отмель"],
    "шелюговав": ["шелюговавши"],
    "шелюговавши": ["шелюговав"],
    "шемая": ["шамая", "шамайка", "шаманка", "шемайка", "селява"],
    "шемизетка": ["кофта", "блузка", "шмизетка", "шемизетт", "рубашка", "манишка"],
    "шениль": ["синель"],
    "шеол": ["гадес", "хадес", "ад", "геенна"],
    "шепелеватый": ["шепелявый"],
    "шепеляв": ["шепелявши"],
    "шепелявев": ["шепелявевши"],
    "шепелявевши": ["шепелявев"],
    "шепелявение": ["шепелявость", "сигматизм"],
    "шепелявенье": ["шепелявение"],
    "шепелявив": ["шепелявивши"],
    "шепелявивши": ["шепелявив"],
    "шепелявить": ["пришепётывать"],
    "шепелявость": ["сигматизм", "парасигматизм"],
    "шепелявши": ["шепеляв"],
    "шепелявый": ["пришепётывающий"],
    "шепнув": ["шепнувши"],
    "шепнувши": ["шепнув"],
    "шепотня": ["шёпот", "шушукание", "перешёптывание"],
    "шепоток": ["шёпот"],
    "шептав": ["шептавши"],
    "шептавши": ["шептав"],
    "шептала": ["урюк"],
    "шептуха": ["шептунья"],
    "шерамыжничав": ["шерамыжничавши"],
    "шерамыжничавши": ["шерамыжничав"],
    "шербет": ["щербет", "сорбет"],
    "шеренга": ["ряд", "вереница"],
    "шереспёр": ["жерех"],
    "шерли": ["ширли"],
    "шероховатый": ["негладкий", "неровный", "шершавый"],
    "шерочка с машерочкой": ["сладкая парочка", "мы с тамарой ходим парой"],
    "шерп": ["шерпа"],
    "шерпа": ["шерп"],
    "шерри": ["херес"],
    "шерстив": ["шерстивши"],
    "шерстивши": ["шерстив"],
    "шерстистый": ["мохнатый"],
    "шерстобит": ["валяльщик"],
    "шерстобитничав": ["шерстобитничавши"],
    "шерстобитничавши": ["шерстобитничав"],
    "шерстобитный": ["шерстобойный"],
    "шерстобойный": ["шерстобитный"],
    "шерстомоечный": ["шерстемоечный", "шерстомойный"],
    "шерстомойка": ["шерстемойка", "шерстомойня"],
    "шерстомойня": ["шерстемойка", "шерстомойка"],
    "шерстопрядение": ["шерстопряденье"],
    "шерстопряденье": ["шерстопрядение"],
    "шерсточесалка": ["шерстечесалка", "чесалка", "карда"],
    "шерсточесальный": ["шерстечесальный", "чесальный"],
    "шерсть": ["шкура", "мех", "масть"],
    "шерстяной": ["шерстюган", "шерсть", "сука", "ссученный"],
    "шерть": ["шэрть"],
    "шерудив": ["шерудивши"],
    "шерудивши": ["шерудив"],
    "шершавев": ["шершавевши"],
    "шершавевши": ["шершавев"],
    "шершавив": ["шершавивши"],
    "шершавивши": ["шершавив"],
    "шершавость": ["шероховатость", "корявость"],
    "шершавый": ["шероховатый", "неуклюжий", "топорный"],
    "шершень": ["шершень обыкновенный", "шершень европейский"],
    "шеснарь": ["шеснарик"],
    "шессилит": ["азурит"],
    "шест": ["жердь"],
    "шественник": ["путник", "путешественник"],
    "шественный": ["поступательный", "проходимый"],
    "шествие": ["процессия", "следование", "поступь", "ходьба"],
    "шествовав": ["шествовавши"],
    "шествовавши": ["шествовав"],
    "шествовать": ["вышагивать"],
    "шестдесет": ["шейсет"],
    "шестерив": ["шестеривши"],
    "шестеривши": ["шестерив"],
    "шестерить": ["холуйствовать"],
    "шестерня": ["шестёрка"],
    "шестеро": ["шесть"],
    "шестерёнка": ["шестерня"],
    "шестерённый": ["шестерёночный"],
    "шестерёночный": ["шестерёнчатый"],
    "шестерёнчатый": ["шестерёночный", "шестерённый"],
    "шестигранник": ["гексаэдр"],
    "шестидесятиминутный": ["часовой", "одночасовой"],
    "шестидесятисекундный": ["одноминутный"],
    "шестиклинка": ["юбка-шестиклинка"],
    "шестипалость": ["многопалость", "полидактилия"],
    "шестипалый": ["шести", "пальцев"],
    "шестиразовый": ["шестикратный"],
    "шестиричный": ["шестеричный"],
    "шестисотячейник": ["гекзакосихор"],
    "шестистишье": ["шестистишие"],
    "шестиугольник": ["гексагон"],
    "шестнадесет": ["шестнайсет"],
    "шестнадесетоъгълник": ["хексадекагон"],
    "шестнадцатеричный": ["гексадецимальный"],
    "шестнадцатигранник": ["диоктаэдр"],
    "шестнадцатиячейник": ["гексадекахор"],
    "шестнарь": ["шестнарик"],
    "шестое чувство": ["интуиция", "ясновидение"],
    "шестой": ["шёстый", "полудюжинный", "шестая часть", "шестой час"],
    "шесток": ["припечник"],
    "шесть": ["шестёрка", "полдюжины"],
    "шестёрка": ["шоха", "шестерик", "официант"],
    "шеф": ["босс", "патрон", "глава", "руководитель", "шеф-повар", "опекун", "покровитель", "командир", "шофёр"],
    "шефство": ["патронаж", "покровительство", "наставничество"],
    "шефствовав": ["шефствовавши"],
    "шефствовавши": ["шефствовав"],
    "шея": ["шия", "выя"],
    "ши": ["карите"],
    "шиацу": ["акупрессура"],
    "шибав": ["шибавши"],
    "шибавши": ["шибав"],
    "шибанув": ["шибанувши"],
    "шибанувши": ["шибанув"],
    "шибануть": ["шибнуть"],
    "шибари": ["сибари", "кимбаку"],
    "шибать": ["ударять", "долбать", "бросать", "кидать"],
    "шибаться": ["кидаться", "шататься"],
    "шибеница": ["виселица", "висельница", "шибелица", "дыба"],
    "шибкий": ["скорый", "быстрый", "прыткий", "бойкий", "проворный", "торопливый", "спешный", "борзый", "живой", "беглый", "мгновенный", "молниеносный", "стремительный"],
    "шибко": ["живо", "бойко", "проворно", "стремительно", "борзо", "резво", "со всех ног", "во весь дух", "во весь опор", "во всю мочь", "во всю прыть", "спешно", "скоро", "бегло", "поспешно"],
    "шибнув": ["шибнувши"],
    "шибнувши": ["шибнув"],
    "шибонув": ["шибонувши"],
    "шибонувши": ["шибонув"],
    "шибър": ["клапа", "затвор"],
    "шива": ["махадев"],
    "шиваизм": ["шайвизм"],
    "шиваит": ["шиваист"],
    "шивера": ["перекат", "сарма"],
    "шиворот": ["шкварник"],
    "шиворот на выворот": ["наоборот", "с ног на голову"],
    "шиворот-навыворот": ["наизнанку", "наоборот", "навыворот"],
    "шивши": ["шив"],
    "шиес": ["шиэс", "сиесаёль"],
    "шиз": ["шизофреник"],
    "шиза": ["шизофрения", "шизик", "псих", "шизофреник", "шизофреничка", "заскок", "идея фикс"],
    "шизанутый": ["шизонутый", "чокнутый", "сумасшедший", "ненормальный"],
    "шизануться": ["шизонуться", "шизнуться"],
    "шизеть": ["шизовать", "офигевать"],
    "шизик": ["шизоид", "шиза"],
    "шизо": ["штрафной изолятор", "мурманка"],
    "шизобулия": ["амбивалентность"],
    "шизоид": ["шиза", "шизик", "шизофреник"],
    "шизоидия": ["шизоидность"],
    "шизоидность": ["шизоидия"],
    "шизонт": ["трофозоит"],
    "шизотипальный": ["шизотипический", "шизотипный"],
    "шизотипический": ["шизотипичный", "шизотипальный", "шизотипный"],
    "шизотипный": ["шизотипический", "шизотипальный"],
    "шизофреник": ["шиз", "шизик", "шизоид"],
    "шизофренировав": ["шизофренировавши"],
    "шизофренировавши": ["шизофренировав"],
    "шизофренировать": ["шизеть", "шизовать"],
    "шизофренический": ["шизофреничный"],
    "шизофренично": ["шизануто", "шизово", "шизоидно", "шизофренически"],
    "шизофреничный": ["шизофренический"],
    "шизофрения": ["деменция прекокс", "раннее слабоумие", "схизофрения"],
    "шизофренный": ["шизофренический"],
    "шик": ["блеск"],
    "шикав": ["шикавши"],
    "шикавши": ["шикав"],
    "шикам": ["батн"],
    "шиканировать": ["огорчать", "досаждать", "беспокоить"],
    "шиканув": ["шиканувши"],
    "шиканувши": ["шиканув"],
    "шикардос": ["шикос"],
    "шикарив": ["шикаривши"],
    "шикаривши": ["шикарив"],
    "шикарно": ["роскошно"],
    "шикарность": ["роскошность", "роскошь"],
    "шикарный": ["богатый", "роскошный", "пышный"],
    "шикнув": ["шикнувши"],
    "шикнувши": ["шикнув"],
    "шиковав": ["шиковавши"],
    "шиковавши": ["шиковав"],
    "шикор": ["сайд"],
    "шикос": ["шикардос"],
    "шила": ["шейла"],
    "шилишпёр": ["жерех", "шереспёр"],
    "шило на мыло менять": ["менять шило на мыло", "менять шило на свайку", "менять рыло на рыло"],
    "шиловидный": ["шилообразный"],
    "шилолистный": ["остролистный", "остролистый", "стрелолистый", "стрелолистный"],
    "шилообразный": ["шиловидный"],
    "шилохвостив": ["шилохвостивши"],
    "шилохвостивши": ["шилохвостив"],
    "шилохвостка": ["утка"],
    "шилье": ["шило", "игла", "жало"],
    "шильник": ["обманщик", "мошенник", "плут"],
    "шильничав": ["шильничавши"],
    "шильничавши": ["шильничав"],
    "шим": ["широтно-импульсная модуляция"],
    "шимоза": ["мелинит"],
    "шина": ["покрышка", "резина"],
    "шингард": ["шингарт"],
    "шингарт": ["шингард"],
    "шинде": ["сциндия", "скиндия", "синдия", "синдхия"],
    "шине": ["шинерояль", "креп"],
    "шинельная": ["гардеробная"],
    "шинельный": ["шинелевый"],
    "шинерояль": ["шине", "креп"],
    "шинировав": ["шинировавши"],
    "шинировавши": ["шинировав"],
    "шинкар": ["корчмар"],
    "шинкарив": ["шинкаривши"],
    "шинкаривши": ["шинкарив"],
    "шинкарить": ["шинкарствовать"],
    "шинкарствовав": ["шинкарствовавши"],
    "шинкарствовавши": ["шинкарствовав"],
    "шинкарствовать": ["шинкарить"],
    "шинкарь": ["корчмарь", "корчемник", "кабатчик", "трактирщик", "самогонщик"],
    "шинковав": ["шинковавши"],
    "шинковавши": ["шинковав"],
    "шинковка": ["шинкование", "овощерезка", "тёрка"],
    "шиновать": ["ошиновывать"],
    "шинок": ["кабак", "корчма", "бар"],
    "шиномонтаж": ["шиномонтажная мастерская", "шиномонтажка", "шинка"],
    "шинуазри": ["шинуазери", "китайщина"],
    "шип": ["остриё", "игла", "колючка"],
    "шипанг": ["айвонча"],
    "шипев": ["шипевши"],
    "шипевши": ["шипев"],
    "шипеть": ["сипеть", "шуршать", "злобствовать"],
    "шипибо": ["шипибо-конибо"],
    "шиповав": ["шиповавши"],
    "шиповавши": ["шиповав"],
    "шиповка": ["шипучка"],
    "шиповки": ["шиповка"],
    "шиповник": ["дикая роза", "роза собачья"],
    "шиповой": ["шиповый"],
    "шиповый": ["шиповой"],
    "шипперив": ["шипперивши"],
    "шипперивши": ["шипперив"],
    "шипперить": ["сводить", "сватать"],
    "шипперке": ["схипперке"],
    "шипящий согласный": ["сибилянт", "сибилянтный звук", "сибилянтный согласный"],
    "ширван": ["зубовка", "али-байрамлы"],
    "ширде": ["ваксста", "бокста"],
    "шире": ["ширше", "пошире"],
    "шири": ["пяли"],
    "ширив": ["ширивши"],
    "ширивши": ["ширив"],
    "ширик": ["широкоугольник", "широкоугольный объектив", "дёрн"],
    "ширина": ["широта", "размах"],
    "ширинка": ["гульфик", "серёдыш", "плат", "полотнище", "полотенце"],
    "ширинка дуется": ["дуется ширинка", "трещит ширинка"],
    "ширинлик": ["шириньлик"],
    "ширить": ["расширять"],
    "шириться": ["расширяться"],
    "ширка": ["ширяние"],
    "ширкав": ["ширкавши"],
    "ширкавши": ["ширкав"],
    "ширкнув": ["ширкнувши"],
    "ширкнувши": ["ширкнув"],
    "ширнак": ["шырнак"],
    "ширнармассы": ["широкие народные массы"],
    "ширнув": ["ширнувши"],
    "ширнувши": ["ширнув"],
    "ширнуться": ["уколоться"],
    "широкие взгляды": ["либерализм"],
    "широкий": ["толстый", "просторный", "большой"],
    "широко": ["обширно"],
    "широкобёдрый": ["пышнобёдрый"],
    "широковещательно": ["во всеуслышанье"],
    "широкозадый": ["толстозадый", "крутозадый", "задастый"],
    "ширококостный": ["ширококостый"],
    "ширококостый": ["ширококостный"],
    "широколиственный лес": ["лиственный лес"],
    "широкомасштабность": ["масштабность"],
    "широкомордый": ["широкорожий"],
    "широкоплечий": ["плечистый"],
    "широкопрофильный": ["разносторонний"],
    "широкоскулый": ["скуластый"],
    "широкосмуговий": ["широкосмужний"],
    "широкосмужний": ["широкосмуговий"],
    "широкость": ["широта", "размашистость"],
    "широкотекущий": ["широкий"],
    "широкотелый": ["эйрисомный"],
    "широкоугольник": ["широкоуголка", "ширик"],
    "широкоупотребимый": ["широкоупотребляемый"],
    "широта": ["обширность", "ширина", "простор", "неограниченность", "размах", "параллель"],
    "широта души": ["великодушие", "доброта", "щедрость"],
    "широчезний": ["широченний"],
    "широченний": ["широчезний"],
    "ширпотреб": ["дешёвка", "барахло", "дрянь", "хлам", "рухлядь", "поп-культура", "попса", "бульварщина", "пошлятина", "жвачка", "попкорн"],
    "ширпотребовский": ["ширпотребный"],
    "ширше": ["шире"],
    "ширь": ["простор", "даль", "приволье", "раздолье", "широта", "обширность", "неограниченность"],
    "ширяв": ["ширявши"],
    "ширявши": ["ширяв"],
    "ширять": ["парить"],
    "ширяться": ["ширять"],
    "шистозома": ["шистосома"],
    "шистозоматоз": ["шистосоматоз"],
    "шистосома": ["шистозома"],
    "шистосоматоз": ["шистосомоз", "бильгарциоз", "шистозоматоз"],
    "шистосомоз": ["бильгарциоз", "шистосоматоз"],
    "шит": ["чёрт", "блин", "фак"],
    "шитво": ["шитьё", "пошив"],
    "шито-крыто": ["концы в воду"],
    "шить": ["приписывать", "обвинять", "инкриминировать", "пробивать", "пробиваться", "прошивать"],
    "шитьё": ["шитво", "пошив"],
    "шифон": ["муслин"],
    "шифоньер": ["шифоньерка", "гардероб"],
    "шифоньерка": ["шифоньер"],
    "шифр": ["код", "тайнопись", "индекс"],
    "шифровав": ["шифровавши"],
    "шифровавши": ["шифровав"],
    "шифровальщик": ["шифровщик"],
    "шифрование": ["шифровка"],
    "шифровать": ["кодировать"],
    "шифроваться": ["кодироваться", "скрываться"],
    "шифровщик": ["шифровальщик"],
    "шифрограмма": ["криптограмма"],
    "шифртекст": ["криптотекст", "криптограмма"],
    "шифтинг": ["шифт", "осознанный сон"],
    "шихтовав": ["шихтовавши"],
    "шихтовавши": ["шихтовав"],
    "шихтование": ["шихтовка"],
    "шихтовой": ["шихтовый"],
    "шихтовый": ["шихтовой"],
    "шиш": ["дуля", "кукиш", "фига"],
    "шишига": ["шиш", "шишиган", "сатана", "бес", "чёрт", "кикимора", "домовой"],
    "шишкарь": ["шишка"],
    "шишковав": ["шишковавши"],
    "шишковавши": ["шишковав"],
    "шишмиш": ["нетопир"],
    "шкалик": ["мерзавчик", "косушка", "фуфырик", "получарка"],
    "шкалировав": ["шкалировавши"],
    "шкалировавши": ["шкалировав"],
    "шкандыба": ["колча", "колченогий", "хромой"],
    "шкандыбав": ["шкандыбавши"],
    "шкандыбавши": ["шкандыбав"],
    "шкандыбать": ["плестись", "ковылять"],
    "шкант": ["нагель", "чопик", "дюбель"],
    "шканцы": ["квартердек"],
    "шкап": ["шкаф"],
    "шкапа": ["шкапина"],
    "шкарбун": ["шкарбан"],
    "шкаре": ["ножице", "маказе"],
    "шкаторина": ["шкоторина"],
    "шкатулка": ["ларец"],
    "шкаф": ["шкап", "амбал", "бугай", "великан", "громила"],
    "шкафной": ["шкафный"],
    "шкафный": ["шкафной"],
    "шкафчик": ["шкафик", "шкапчик"],
    "шквал": ["порыв", "лавина"],
    "шквальный": ["ураганный", "проливной", "сильный", "массированный"],
    "шкварив": ["шкваривши"],
    "шкваривши": ["шкварив"],
    "шкварка": ["выжарка"],
    "шкварник": ["шиворот", "воротник"],
    "шкварчав": ["шкварчавши"],
    "шкварчавши": ["шкварчав"],
    "шкворень": ["шворень"],
    "шкворчав": ["шкворчавши"],
    "шкворчавши": ["шкворчав"],
    "шкентрос": ["шкень-трос"],
    "шкерив": ["шкеривши"],
    "шкеривши": ["шкерив"],
    "шкет": ["парнишка", "пацан", "пацанёнок", "шпингалет", "малец"],
    "шкирка": ["ворот", "воротник", "шиворот", "шкирняк", "шкирман", "шкирбон", "хибот", "холка", "загривок"],
    "шкодер": ["шкодра", "скадарское озеро"],
    "шкодив": ["шкодивши"],
    "шкодивши": ["шкодив"],
    "шкодить": ["шалить", "озорничать", "куролесить"],
    "шкодник": ["шкодливец", "шкода"],
    "шкодра": ["шкодер", "скутари"],
    "школа": ["шарага"],
    "школив": ["школивши"],
    "школивши": ["школив"],
    "школить": ["муштровать"],
    "школота": ["школьник", "школоло"],
    "школьничав": ["школьничавши"],
    "школьничавши": ["школьничав"],
    "школьный рюкзак": ["школьный ранец", "ранец"],
    "школяр": ["школьник", "студент"],
    "школярив": ["школяривши"],
    "школяривши": ["школярив"],
    "школярка": ["школьница"],
    "школярничав": ["школярничавши"],
    "школярничавши": ["школярничав"],
    "школярничать": ["школярить"],
    "школярство": ["школьничество", "педантизм", "схоластика", "схоластичность"],
    "школярствовав": ["школярствовавши"],
    "школярствовавши": ["школярствовав"],
    "шконарь": ["шконка", "шконочка"],
    "шконка": ["нары"],
    "шкот": ["шкут", "трос"],
    "шкоцыя": ["шатляндыя"],
    "шкраб": ["учитель", "педагог"],
    "шкрябав": ["шкрябавши"],
    "шкрябавши": ["шкрябав"],
    "шкрябать": ["шаркать"],
    "шкулять": ["вымогать", "обирать"],
    "шкуна": ["шхуна"],
    "шкурив": ["шкуривши"],
    "шкуривши": ["шкурив"],
    "шкурник": ["эгоист"],
    "шкурничав": ["шкурничавши"],
    "шкурничавши": ["шкурничав"],
    "шкурнический": ["эгоистический"],
    "шкурный": ["меховой", "шкурнический", "корыстный", "эгоистичный"],
    "шкурный интерес": ["интерес", "выгода", "корысть"],
    "шкуродёр": ["живодёр"],
    "шлаковав": ["шлаковавши"],
    "шлаковавши": ["шлаковав"],
    "шлакование": ["зашлаковка"],
    "шлаковидный": ["шлакообразный", "шлакоподобный"],
    "шлакообразный": ["шлаковидный", "шлакоподобный"],
    "шланги": ["кишки"],
    "шлангочка": ["шланг", "трубочка"],
    "шлафор": ["шлафрок"],
    "шлафрок": ["шлафор"],
    "шлейф": ["трен"],
    "шлейфовав": ["шлейфовавши"],
    "шлейфовавши": ["шлейфовав"],
    "шлем": ["каска", "шелом"],
    "шлеппер": ["маравихер"],
    "шлимазл": ["недотёпа"],
    "шлифовав": ["шлифовавши"],
    "шлифовавши": ["шлифовав"],
    "шлифовальщик": ["шлифовщик"],
    "шлифовальщица": ["шлифовщица"],
    "шлифовать": ["полировать"],
    "шлифовочный": ["шлифовальный"],
    "шлифовщик": ["шлифовальщик"],
    "шлифовщица": ["шлифовальщица"],
    "шлифовывав": ["шлифовывавши"],
    "шлифовывавши": ["шлифовывав"],
    "шлих": ["шлихт", "шлам", "порода", "руда"],
    "шлиховав": ["шлиховавши"],
    "шлиховавши": ["шлиховав"],
    "шлихт": ["шлихта", "шлих", "шлам"],
    "шлихта": ["шлихт"],
    "шлихтовав": ["шлихтовавши"],
    "шлихтовавши": ["шлихтовав"],
    "шлицевав": ["шлицевавши"],
    "шлицевавши": ["шлицевав"],
    "шлицевый": ["шлицевой"],
    "шлык": ["повойник", "шапка", "шлычок", "скуфья"],
    "шлындав": ["шлындавши"],
    "шлындавши": ["шлындав"],
    "шлюзовав": ["шлюзовавши"],
    "шлюзовавши": ["шлюзовав"],
    "шлюхан": ["потаскун", "альфонс", "жиголо", "проститут", "хастлер"],
    "шлюховав": ["шлюховавши"],
    "шлюховавши": ["шлюховав"],
    "шлюховатый": ["шлюший"],
    "шлюховать": ["проститутничать"],
    "шлюший": ["шлюховатый", "блядский"],
    "шлюшничав": ["шлюшничавши"],
    "шлюшничавши": ["шлюшничав"],
    "шлюшничество": ["проститутничество"],
    "шлягер": ["хит"],
    "шлямбур": ["пробойник", "шлямбурный скальный крюк"],
    "шлянье": ["шляние"],
    "шляпив": ["шляпивши"],
    "шляпивши": ["шляпив"],
    "шляпник": ["шляпочник"],
    "шляпница": ["модистка"],
    "шляться": ["слоняться", "шататься"],
    "шлёвка": ["хомут", "тренчик"],
    "шлёндав": ["шлёндавши"],
    "шлёндавши": ["шлёндав"],
    "шлёндать": ["слоняться", "шататься", "блондать", "шляться", "шлендаться", "шлёндрать"],
    "шлёндра": ["шаболда", "шлёнда", "шлюндра", "прошмандовка", "шалашовка", "шалапендра", "хлёндра"],
    "шлёндрав": ["шлёндравши"],
    "шлёндравши": ["шлёндрав"],
    "шлёндрать": ["слоняться", "шататься"],
    "шлёп": ["капель", "хлопок", "звук"],
    "шлёпав": ["шлёпавши"],
    "шлёпавши": ["шлёпав"],
    "шлёпанец": ["тапка", "хлопанец", "шлёпка"],
    "шлёпать": ["хлопать"],
    "шлёпка": ["шлёпанье", "шлёпанец", "тапка"],
    "шлёпнув": ["шлёпнувши"],
    "шлёпнувши": ["шлёпнув"],
    "шлёпнуться": ["плюхнуться", "ляпнуться", "шмякнуться"],
    "шмакав": ["шмакавши"],
    "шмакавши": ["шмакав"],
    "шмакодявка": ["малявка", "мелюзга", "мелкота", "мелочь", "малютка", "крошка", "крохотуля", "крохотулька"],
    "шмалив": ["шмаливши"],
    "шмаливши": ["шмалив"],
    "шмалить": ["курить", "дымить"],
    "шмаль": ["дурь"],
    "шмальба": ["стрельба"],
    "шмальнув": ["шмальнувши"],
    "шмальнувши": ["шмальнув"],
    "шмальнуть": ["пульнуть", "стрельнуть"],
    "шмальтин": ["смальтин"],
    "шмаляв": ["шмалявши"],
    "шмалявши": ["шмаляв"],
    "шмалять": ["палить", "пулять", "стрелять"],
    "шмара": ["проститутка", "шлюха", "шалава", "сожительница"],
    "шмат": ["кусок"],
    "шматка": ["шматина"],
    "шматок": ["кусок", "кусочек"],
    "шматьё": ["шмотьё", "шмотки", "тряпки"],
    "шмель-плотник": ["антофил", "полилект"],
    "шмеманит": ["обновленец", "модернист"],
    "шмольничав": ["шмольничавши"],
    "шмольничавши": ["шмольничав"],
    "шмон": ["обыск", "досмотр", "облава"],
    "шмонав": ["шмонавши"],
    "шмонавши": ["шмонав"],
    "шмонать": ["обыскивать"],
    "шмондя": ["пизда"],
    "шморгав": ["шморгавши"],
    "шморгавши": ["шморгав"],
    "шморгать": ["сморгать"],
    "шморгнув": ["шморгнувши"],
    "шморгнувши": ["шморгнув"],
    "шмот": ["одежда", "шмандёвок", "шпыря"],
    "шмотинка": ["шматинка"],
    "шмотки": ["тряпка", "шмутки", "барахло"],
    "шмотьё": ["шматьё", "шмотки", "тряпки"],
    "шмурыгав": ["шмурыгавши"],
    "шмурыгавши": ["шмурыгав"],
    "шмурыгнув": ["шмурыгнувши"],
    "шмурыгнувши": ["шмурыгнув"],
    "шмурыжив": ["шмурыживши"],
    "шмурыживши": ["шмурыжив"],
    "шмурыжить": ["шмыгать"],
    "шмыгав": ["шмыгавши"],
    "шмыгавши": ["шмыгав"],
    "шмыганье": ["шмыгание"],
    "шмыгнув": ["шмыгнувши"],
    "шмыгнувши": ["шмыгнув"],
    "шмяк": ["хрясь"],
    "шмяка": ["каша", "месиво", "жижа"],
    "шмякав": ["шмякавши"],
    "шмякавши": ["шмякав"],
    "шмякнув": ["шмякнувши"],
    "шмякнувши": ["шмякнув"],
    "шмякнуть": ["чебурахнуть", "брякнуть", "хлопнуть", "шлёпнуть"],
    "шмякнуться": ["шлёпнуться", "упасть", "свалиться"],
    "шнапс": ["водка"],
    "шнапс-идея": ["вздор"],
    "шнауцер": ["миттельшнауцер"],
    "шнека": ["шнек", "шняка"],
    "шнекоход": ["вездеход"],
    "шницелевый": ["шницельный"],
    "шницельный": ["шницелевый"],
    "шнобель": ["нос", "сопатка", "носопырка", "паяльник", "рубильник", "пятачок", "рыло", "морда", "волнорез"],
    "шноркель": ["шнорхель"],
    "шнорхель": ["шноркель", "удк"],
    "шнур": ["верёвка"],
    "шнурки в стакане": ["чулки в стакане"],
    "шнуровав": ["шнуровавши"],
    "шнуровавши": ["шнуровав"],
    "шнуровальный": ["шнуровочный"],
    "шнурованье": ["шнурование"],
    "шнуровать": ["зашнуровывать"],
    "шнурок": ["снурок"],
    "шнырив": ["шныривши"],
    "шныривши": ["шнырив"],
    "шнырнув": ["шнырнувши"],
    "шнырнувши": ["шнырнув"],
    "шнырь": ["пролаз", "пройдоха", "шустряк", "шестёрка", "козёл", "охранник", "сторож"],
    "шныряв": ["шнырявши"],
    "шнырявши": ["шныряв"],
    "шнырянье": ["шныряние"],
    "шнырять": ["рыскать"],
    "шнява": ["шнава"],
    "шняга": ["мелочёвка", "хрень", "дрянь", "гадость", "пакость", "ерунда", "фигня"],
    "шо": ["что", "чё"],
    "шоа": ["холокост"],
    "шобла": ["кодла"],
    "шовамс": ["тапамс", "тиемс", "почф", "шовафкст", "оржаптомс"],
    "шовинизм": ["ура-патриотизм"],
    "шовинист": ["ксенофоб"],
    "шовинистка": ["фашистка", "неофашистка"],
    "шоир": ["шоъир", "шаърбоф"],
    "шок": ["потрясение"],
    "шокер": ["электрошокер", "тазер"],
    "шокировав": ["шокировавши"],
    "шокировавши": ["шокировав"],
    "шокирование": ["эпатирование", "эпатаж"],
    "шоколад": ["шоколадка", "горячий шоколад"],
    "шоколадка": ["батончик", "негритяночка"],
    "шоколадная плитка": ["плитка шоколада"],
    "шоколадник": ["шоколатье", "растратчик", "расхититель", "взяточник"],
    "шоколадница": ["бабочка-шоколадница", "воровка"],
    "шоколадный": ["кофейный"],
    "шоколатье": ["шоколадник"],
    "шокшемс": ["потямс", "анамс", "симомс", "аделамс", "ётафтомс", "карьхцямс", "машфтомс"],
    "шони": ["шауни"],
    "шоопировав": ["шоопировавши"],
    "шоопировавши": ["шоопировав"],
    "шоплифтер": ["магазинный", "вор"],
    "шопоголизм": ["ониомания", "шопомания"],
    "шопот": ["шёпот", "молва", "кривотолки", "толки", "разговоры", "слух", "слухи", "сплетня", "сплетни"],
    "шоппинг": ["шопинг"],
    "шоркав": ["шоркавши"],
    "шоркавши": ["шоркав"],
    "шорканье": ["шоркание"],
    "шоркать": ["шаркать", "шуркать"],
    "шоркнув": ["шоркнувши"],
    "шоркнувши": ["шоркнув"],
    "шоркнуть": ["шаркнуть"],
    "шорная упряжь": ["шоры"],
    "шорничав": ["шорничавши"],
    "шорничавши": ["шорничав"],
    "шорня": ["шорная"],
    "шороо": ["газар"],
    "шорох": ["шуршание", "шелест"],
    "шорохаться": ["шевелиться"],
    "шорош": ["шерошь", "шарашь", "шарш", "шауш", "шорох", "шуга", "сало", "снежура", "шуршание", "шелест"],
    "шорпо": ["сорпо"],
    "шорт": ["короткая позиция", "продажа без покрытия"],
    "шорт-стек": ["короткий стек"],
    "шортист": ["медведь"],
    "шоссе": ["шоссейка", "шаша", "шоса", "саша", "соша", "саше", "шоссея", "шоссей", "шося", "шаха", "шафа", "автотрасса", "трасса", "автобан", "шоссейная дорога"],
    "шоссейник": ["шоссейный велосипед"],
    "шоссировав": ["шоссировавши"],
    "шоссировавши": ["шоссировав"],
    "шоу": ["представление"],
    "шоудаун": ["вскрытие"],
    "шоурил": ["видеовизитка"],
    "шоферив": ["шоферивши"],
    "шоферивши": ["шоферив"],
    "шоферить": ["шофёрить"],
    "шоферюга": ["шофёр"],
    "шофьор": ["водач", "машинист", "ватман"],
    "шофёрив": ["шофёривши"],
    "шофёривши": ["шофёрив"],
    "шофёрить": ["шоферить"],
    "шоша": ["пешоб", "бавл", "мезак"],
    "шошбин": ["шошпын"],
    "шошка": ["донъыз"],
    "шошпын": ["шошбин"],
    "шпагат": ["бечёвка"],
    "шпажник": ["гладиолус"],
    "шпак": ["стрюцкий", "штафирка", "рябчик"],
    "шпаклевав": ["шпаклевавши"],
    "шпаклевавши": ["шпаклевав"],
    "шпаклевание": ["шпаклёвка"],
    "шпаклевать": ["шпатлевать"],
    "шпаклёвка": ["шпатлёвка", "шпаклевание"],
    "шпаклёвщик": ["шпатлёвщик"],
    "шпала": ["фофан"],
    "шпалера": ["гобелен", "обои", "живая изгородь", "шпалер", "шеренга"],
    "шпалорезка": ["шпалорезный", "станок"],
    "шпана": ["урла", "босота"],
    "шпандырь": ["шпандер"],
    "шпанский": ["испанский"],
    "шпаргалив": ["шпаргаливши"],
    "шпаргаливши": ["шпаргалив"],
    "шпаргалить": ["скатывать", "сдувать", "сдирать"],
    "шпаргалка": ["шпора"],
    "шпарив": ["шпаривши"],
    "шпаривав": ["шпаривавши"],
    "шпаривавши": ["шпаривав"],
    "шпаривши": ["шпарив"],
    "шпаринка": ["шпарина", "шпарка"],
    "шпарить": ["ошпаривать", "обваривать", "жать", "жарить", "чесать"],
    "шпаровав": ["шпаровавши"],
    "шпаровавши": ["шпаровав"],
    "шпаровать": ["подштукатуривать"],
    "шпатель": ["мастихин"],
    "шпатлевав": ["шпатлевавши"],
    "шпатлевавши": ["шпатлевав"],
    "шпатлевать": ["шпаклевать"],
    "шпатлёвка": ["шпаклёвка", "шпадлевка"],
    "шпахтель": ["шпатель"],
    "шпача": ["шпаченя"],
    "шпаченя": ["шпача"],
    "шпекачка": ["шпикачка"],
    "шпенёк": ["стержень", "стерженёк"],
    "шпиг": ["шпик"],
    "шпиговав": ["шпиговавши"],
    "шпиговавши": ["шпиговав"],
    "шпик": ["сало", "шпиг"],
    "шпикачка": ["шпекачка"],
    "шпиковав": ["шпиковавши"],
    "шпиковавши": ["шпиковав"],
    "шпилив": ["шпиливши"],
    "шпиливши": ["шпилив"],
    "шпилить": ["пришпиливать", "буравить"],
    "шпиль": ["игла", "остриё", "шпиголь", "шпигорь", "гвоздь", "кабестан", "шпилька"],
    "шпилька": ["заколка", "булавка", "колкость", "насмешка"],
    "шпильки": ["туфля"],
    "шпильковав": ["шпильковавши"],
    "шпильковавши": ["шпильковав"],
    "шпингалет": ["задвижка", "шкет", "пацанёнок", "пацан"],
    "шпион": ["разведчик", "лазутчик", "шпик", "сыщик", "филер", "соглядатай", "доносчик", "обвиняемый", "обвинённый"],
    "шпионив": ["шпионивши"],
    "шпионивши": ["шпионив"],
    "шпионин": ["разузнавач", "разведчик", "агент"],
    "шпионка": ["разведчица", "лазутчица"],
    "шпионство": ["шпионаж"],
    "шпионствовав": ["шпионствовавши"],
    "шпионствовавши": ["шпионствовав"],
    "шпицберген": ["свальбард"],
    "шпицрутен": ["батог", "розга"],
    "шпиця": ["спиця"],
    "шплинтовав": ["шплинтовавши"],
    "шплинтовавши": ["шплинтовав"],
    "шпокать": ["чпокать"],
    "шпокнув": ["шпокнувши"],
    "шпокнувши": ["шпокнув"],
    "шпон": ["шпона"],
    "шпона": ["шпон"],
    "шпонировав": ["шпонировавши"],
    "шпонировавши": ["шпонировав"],
    "шпора": ["шпорца"],
    "шпорив": ["шпоривши"],
    "шпоривши": ["шпорив"],
    "шпрехав": ["шпрехавши"],
    "шпрехавши": ["шпрехав"],
    "шпрехать": ["говорить", "разбираться", "понимать", "шарить"],
    "шпрехшталмейстер": ["шталмейстер", "инспектор манежа"],
    "шпринт": ["шпринтов"],
    "шпринцевав": ["шпринцевавши"],
    "шпринцевавши": ["шпринцевав"],
    "шприцевав": ["шприцевавши"],
    "шприцевавши": ["шприцевав"],
    "шприцовав": ["шприцовавши"],
    "шприцовавши": ["шприцовав"],
    "шпрота": ["прибалт"],
    "шпротина": ["шпрота"],
    "шпрудельштейн": ["пизолит"],
    "шпулечный": ["шпульный"],
    "шпулька": ["шпуля"],
    "шпульный": ["шпулечный"],
    "шпунтина": ["шпунт"],
    "шпунтовав": ["шпунтовавши"],
    "шпунтовавши": ["шпунтовав"],
    "шпунтубель": ["пазник", "дорожник"],
    "шпыняв": ["шпынявши"],
    "шпынявши": ["шпыняв"],
    "шпынять": ["колоть", "тыкать", "укорять", "попрекать", "донимать", "подтрунивать", "издеваться"],
    "шпёхаться": ["трахаться"],
    "шрабкугель": ["шарногель"],
    "шрам": ["рубец", "рана"],
    "шрамировав": ["шрамировавши"],
    "шрамировавши": ["шрамировав"],
    "шрамирование": ["скарификация"],
    "шрамчик": ["шрамик"],
    "шрапнелевий": ["шрапнельний"],
    "шрапнель": ["перловка"],
    "шрапнельный": ["перловый"],
    "шредеровав": ["шредеровавши"],
    "шредеровавши": ["шредеровав"],
    "шри-ланка": ["цейлон"],
    "шримс": ["крангонид", "креветка", "чилим"],
    "шринкфляция": ["даунсайзинг"],
    "шрифт": ["письменность", "письмо", "алфавит", "азбука", "графика", "почерк", "пошиб", "гарнитура"],
    "шрифтовик": ["шрифтист"],
    "шрм": ["школа рабочей молодёжи"],
    "шрус": ["граната"],
    "шта": ["што"],
    "штаб-лекарь": ["военврач"],
    "штабелевав": ["штабелевавши"],
    "штабелевавши": ["штабелевав"],
    "штабелировав": ["штабелировавши"],
    "штабелировавши": ["штабелировав"],
    "штабист": ["штабник"],
    "шталмейстер": ["шпрехшталмейстер"],
    "штальхельм": ["стальной шлем"],
    "штамб": ["матерое дерево"],
    "штамп": ["печать", "штемпель", "стереотип", "клише", "шаблон"],
    "штамповав": ["штамповавши"],
    "штамповавши": ["штамповав"],
    "штампование": ["штамповка"],
    "штампованный": ["стандартный", "шаблонный", "трафаретный"],
    "штамповка": ["штампование"],
    "штамс": ["штамс шудиса", "саламс шудиса"],
    "штангенрейсмас": ["штангенрейсмус"],
    "штангенциркуль": ["штанген", "штанген-циркуль"],
    "штангет": ["штангенциркуль"],
    "штаненята": ["штанята", "штанчата"],
    "штанец": ["штанц", "штанцевый нож"],
    "штанина": ["брючина", "колоша", "порточина", "портошница", "паголенок"],
    "штанишки": ["брючки", "штаники", "штаны"],
    "штанкет": ["штанкета"],
    "штанкета": ["штанкет"],
    "штанц": ["штанец"],
    "штанцевав": ["штанцевавши"],
    "штанцевавши": ["штанцевав"],
    "штанцевание": ["высечка"],
    "штанчата": ["штаненята", "штанята"],
    "штаны": ["брюки", "порты", "портки", "штанцы", "штаники", "штанишки", "штанишечки", "штанчик", "штанчики", "штан", "штанища", "штанищи", "трусы", "панталоны"],
    "штанята": ["штаненята", "штанчата"],
    "штапелировав": ["штапелировавши"],
    "штапелировавши": ["штапелировав"],
    "штат": ["коллектив", "кадры", "штатное расписание", "регион"],
    "штатгальтер": ["штатгалтер", "статхаудер", "наместник", "дож"],
    "штатник": ["американец", "китовый", "стиляга"],
    "штатное расписание": ["штатка"],
    "штатный": ["нормальный", "допустимый", "плановый", "комплектный", "внутренний", "встроенный", "ординарный"],
    "штатовский": ["американский", "пиндосский"],
    "штатский": ["гражданский", "светский", "цивильный"],
    "штатское": ["цивильное", "гражданское", "партикулярное"],
    "штаты": ["соединённые штаты америки", "соединённые штаты", "сша"],
    "штевень": ["корч", "упряг"],
    "штегерь": ["штейгер"],
    "штейгер": ["щегерь"],
    "штемпелевав": ["штемпелевавши"],
    "штемпелевавши": ["штемпелевав"],
    "штемпель": ["штамп"],
    "штендер": ["стритлайн", "мимоход", "шалаш", "раскладушка", "спотыкач"],
    "штепсель": ["вилка"],
    "штепсельная розетка": ["электророзетка", "розетка"],
    "штепсельный соединитель": ["штепсельный разъём"],
    "штиблета": ["туфля", "гамаша"],
    "штивер": ["стивер"],
    "штилев": ["штилевши"],
    "штилевав": ["штилевавши"],
    "штилевавши": ["штилевав"],
    "штилевой": ["безветренный"],
    "штилевши": ["штилев"],
    "штилеть": ["утихать"],
    "штиль": ["безветрие", "спокойствие"],
    "штирборт": ["старборд"],
    "штифт": ["стержень"],
    "штоб": ["чтобы"],
    "штобы": ["штоб", "чтобы"],
    "штокавщина": ["сербский язык"],
    "штопав": ["штопавши"],
    "штопавши": ["штопав"],
    "штопаный гондон": ["вязаный гондон"],
    "штопать": ["заштопывать", "чинить", "латать", "лечить"],
    "штопка": ["штопанье"],
    "штопор": ["пробочник"],
    "штопорив": ["штопоривши"],
    "штопоривши": ["штопорив"],
    "штопорнув": ["штопорнувши"],
    "штопорнувши": ["штопорнув"],
    "штора": ["стора"],
    "шторм": ["буря", "ураган", "циклон"],
    "штормгласс": ["камфоргласс", "склянка фицроя", "штормовая склянка", "бароскоп"],
    "штормив": ["штормивши"],
    "штормивши": ["штормив"],
    "штормовав": ["штормовавши"],
    "штормовавши": ["штормовав"],
    "штормоваться": ["штормовать"],
    "штормовка": ["ветровка"],
    "штормтрап": ["штормовой трап", "шторм-трап"],
    "штос": ["штосс"],
    "штоф": ["бутылка"],
    "штраф": ["пеня"],
    "штрафанув": ["штрафанувши"],
    "штрафанувши": ["штрафанув"],
    "штрафануть": ["оштрафовать"],
    "штрафбат": ["штрафной батальон"],
    "штрафной батальон": ["штрафбат", "дисциплинарный батальон"],
    "штрафовав": ["штрафовавши"],
    "штрафовавши": ["штрафовав"],
    "штрафование": ["штрафованье"],
    "штрафованье": ["штрафование"],
    "штрафплощадка": ["штрафстоянка"],
    "штрафстоянка": ["штрафплощадка"],
    "штрейзель": ["посыпка", "штройзель"],
    "штрейкбрехер": ["стачколом", "предатель"],
    "штрек": ["продольная"],
    "штрипка": ["стремёшка", "тормоз"],
    "штрих": ["чёрточка", "деталь", "корректор", "штрих-корректор", "замазка"],
    "штрихкод": ["штриховой код", "штрих-код", "причёска"],
    "штриховав": ["штриховавши"],
    "штриховавши": ["штриховав"],
    "штрихование": ["штриховка"],
    "штриховой код": ["штрихкод", "штрих-код"],
    "штроба": ["паз", "штраба"],
    "штробас": ["фрай"],
    "штробив": ["штробивши"],
    "штробивши": ["штробив"],
    "штроборез": ["бороздодел"],
    "штройзель": ["штрейзель"],
    "штрудель": ["штруцель", "струдель"],
    "штруцель": ["штрудель", "струдель"],
    "штрёсснер": ["стресснер"],
    "штудировав": ["штудировавши"],
    "штудировавши": ["штудировав"],
    "штудия": ["этюд", "научное исследование", "научная работа"],
    "штука": ["кусок", "отрез", "экземпляр", "единица", "вещь", "объект", "предмет", "штуковина", "фиговина", "хреновина", "хрень", "фигатень", "штукенция", "трюк", "фишка"],
    "штукарив": ["штукаривши"],
    "штукаривши": ["штукарив"],
    "штукарка": ["ловкачка", "циркачка", "шутница", "мошенница"],
    "штукарь": ["ловкач", "трюкач", "штукмейстер"],
    "штукатур": ["штукатурщик"],
    "штукатурив": ["штукатуривши"],
    "штукатуривши": ["штукатурив"],
    "штукатурка": ["отделка"],
    "штукенция": ["штуковина", "хреновина", "штука", "свистулька", "фиговина", "дуделка", "фенька", "фенечка", "цацка", "фитюлька"],
    "штукмейстер": ["штукарь"],
    "штуковав": ["штуковавши"],
    "штуковавши": ["штуковав"],
    "штуковина": ["штука", "штукенция", "хреновина"],
    "штульваген": ["экипаж"],
    "штурм": ["приступ"],
    "штурман": ["навигатор"],
    "штурмовав": ["штурмовавши"],
    "штурмовавши": ["штурмовав"],
    "штурмовая винтовка": ["автомат"],
    "штурмовка": ["штурм", "штурмование"],
    "штурхан": ["штурханець", "штовхан"],
    "штык": ["багинет", "боец", "клинок", "чушка"],
    "штык в землю": ["братание"],
    "штык-нож": ["нож"],
    "штыковав": ["штыковавши"],
    "штыковавши": ["штыковав"],
    "штырив": ["штыривши"],
    "штыривши": ["штырив"],
    "штырь": ["заточка"],
    "шуб": ["болезнь блейлера", "блейлер", "процесс"],
    "шуба": ["жупан", "доха", "дублёнка", "кожа"],
    "шубрия": ["шуприя", "субарту", "субар"],
    "шувомс": ["карамс", "таргамс", "пялемс"],
    "шуга": ["снежура"],
    "шугав": ["шугавши"],
    "шугавши": ["шугав"],
    "шугай": ["кофта"],
    "шуганув": ["шуганувши"],
    "шуганувши": ["шуганув"],
    "шугануть": ["шугнуть"],
    "шугануться": ["шугнуться"],
    "шугейз": ["шугейзинг"],
    "шугнан": ["шигнан"],
    "шугнув": ["шугнувши"],
    "шугнувши": ["шугнув"],
    "шугнуться": ["шугануться"],
    "шудемс": ["кольгомс"],
    "шудра": ["единождырождённый"],
    "шузы": ["шуз", "шуза", "шузни", "шузняк", "шузняки"],
    "шукав": ["шукавши"],
    "шукавши": ["шукав"],
    "шукать": ["искать", "разыскивать"],
    "шукуфа": ["гул"],
    "шулерничав": ["шулерничавши"],
    "шулерничавши": ["шулерничав"],
    "шульга": ["шуйця"],
    "шум": ["гам", "гул", "гвалт", "грохот", "шумиха", "оживление", "суматоха", "ссора", "брань", "скандал"],
    "шумануть": ["нашуметь"],
    "шумахер": ["гонщик спиди"],
    "шумбагч завь": ["шумбагч онгоц"],
    "шумбаз": ["нумол"],
    "шумев": ["шумевши"],
    "шумевши": ["шумев"],
    "шумер": ["шумериец"],
    "шумиха": ["ажиотаж", "хайп"],
    "шумливый": ["громкий", "шумный"],
    "шумно": ["громко", "оживлённо", "звучно", "сенсационно"],
    "шумнув": ["шумнувши"],
    "шумнувши": ["шумнув"],
    "шумнуть": ["зашуметь", "призвать", "кликнуть", "покликать", "крикнуть", "позвать", "покричать"],
    "шумный": ["шумовой", "шумливый"],
    "шумовав": ["шумовавши"],
    "шумовавши": ["шумовав"],
    "шумозащитный": ["шумопоглощающий"],
    "шумоизоляционный": ["шумозащитный"],
    "шумора": ["адад"],
    "шумордан": ["шумурдан"],
    "шумурдан": ["шумордан"],
    "шунда": ["анда"],
    "шундый": ["андый", "мондый", "тегенди"],
    "шунтировав": ["шунтировавши"],
    "шунтировавши": ["шунтировав"],
    "шунтировать": ["зашунтировать"],
    "шунявка": ["мусор", "мент", "милиционер"],
    "шура": ["саня", "саша", "шурик"],
    "шурик": ["шура", "саша", "александр"],
    "шуркав": ["шуркавши"],
    "шуркавши": ["шуркав"],
    "шуркать": ["шаркать", "шоркать"],
    "шуркнув": ["шуркнувши"],
    "шуркнувши": ["шуркнув"],
    "шуровав": ["шуровавши"],
    "шуровавши": ["шуровав"],
    "шурпа": ["чорпа", "шорпо", "сорпа"],
    "шурстев": ["шурстевши"],
    "шурстевши": ["шурстев"],
    "шурум-бурум": ["суматоха"],
    "шурупив": ["шурупивши"],
    "шурупивши": ["шурупив"],
    "шуруповёрт": ["шурик"],
    "шурфовав": ["шурфовавши"],
    "шурфовавши": ["шурфовав"],
    "шурхав": ["шурхавши"],
    "шурхавши": ["шурхав"],
    "шурхання": ["шорхання"],
    "шурхнув": ["шурхнувши"],
    "шурхнувши": ["шурхнув"],
    "шуршав": ["шуршавши"],
    "шуршавши": ["шуршав"],
    "шуршанье": ["шуршание"],
    "шуршать": ["шелестеть"],
    "шуры-муры": ["амуры", "вась-вась", "шашни", "интриги", "происки", "козни", "всякая всячина", "ерунда", "мелочёвка", "тайник"],
    "шустовав": ["шустовавши"],
    "шустовавши": ["шустовав"],
    "шустрив": ["шустривши"],
    "шустривши": ["шустрив"],
    "шустрик": ["непоседа", "ловкач", "проныра"],
    "шустрить": ["суетиться", "хлопотать", "ловчить", "прислуживать"],
    "шустрость": ["бойкость", "ловкость", "проворность"],
    "шустрый": ["быстрый", "подвижный", "проворный", "ловкий"],
    "шустряк": ["живчик", "шустрик", "шустрила", "шустрило", "шушстрила", "карьерист", "подлиза", "подхалим", "пройдоха", "проныра", "шустрован"],
    "шут": ["дурак", "комик", "паяц", "клоун"],
    "шутан": ["шутер", "стрелялка"],
    "шутаут": ["шутаут-турнир"],
    "шутер": ["стрелялка"],
    "шутив": ["шутивши"],
    "шутивши": ["шутив"],
    "шутить": ["острить", "острословить", "балагурить", "шутковать", "вышучивать", "подшучивать", "подтрунивать", "дурачиться"],
    "шутиха": ["шутовка", "шутница", "забавница"],
    "шутка": ["острота", "скерцо", "пустяк", "безделица", "ерунда"],
    "шутка в деле": ["легко сказать", "шутка ли в деле"],
    "шутковав": ["шутковавши"],
    "шутковавши": ["шутковав"],
    "шутковать": ["шутить"],
    "шутливый": ["юморной", "шуточный"],
    "шутник": ["весельчак", "забавник", "остряк"],
    "шутовав": ["шутовавши"],
    "шутовавши": ["шутовав"],
    "шутовской колпак": ["дурацкий колпак"],
    "шутурпаланг": ["говпаланг"],
    "шуфутинов день": ["день прощания"],
    "шух": ["харсанг", "сахра"],
    "шухарив": ["шухаривши"],
    "шухаривши": ["шухарив"],
    "шухерив": ["шухеривши"],
    "шухеривши": ["шухерив"],
    "шухляда": ["скриня"],
    "шучивав": ["шучивавши"],
    "шучивавши": ["шучивав"],
    "шушваль": ["шелупонь", "шантрапа", "шушера", "сброд"],
    "шушера": ["сброд", "шваль", "шелупонь", "шушваль"],
    "шушлайка": ["шушлаечка", "ведёрко", "корыто", "ведро с гайками", "ведро с болтами"],
    "шушпан": ["сарафан", "рубашка", "балахон", "шушун", "красноголовый нырок"],
    "шушпанчик": ["сарафанчик", "рубашечка", "балахончик", "шушунчик", "красноголовый нырок"],
    "шушукав": ["шушукавши"],
    "шушукавши": ["шушукав"],
    "шушукание": ["шушуканье"],
    "шушуканье": ["шушукание"],
    "шушукаться": ["шептаться"],
    "шушы": ["бу"],
    "шхера": ["тайник", "схрон"],
    "шхериться": ["прятаться", "затаиваться", "скрываться", "залегать на дно", "шифроваться", "бояться", "озираться", "трусить", "дрейфить"],
    "шхуна": ["шкуна"],
    "шчыльна": ["шчытна", "ушчыльную", "усутыч"],
    "шчытна": ["шчыльна"],
    "шш": ["тише", "ш-ш", "тсс", "ссс", "тш", "тш-ш-ш-ш", "чш"],
    "шъофы": ["губгъо"],
    "шъхьагуащэ": ["шыхагуаще"],
    "шымкент": ["чимкент"],
    "шымкентец": ["чимкентец", "техасец"],
    "шымкентка": ["чимкентка"],
    "шынка": ["кумпяк"],
    "шырау": ["шырпы"],
    "шыртлака": ["ертыш"],
    "шэбби-шик": ["шебби-шик"],
    "шэло": ["шело"],
    "шэрандуны": ["шэран"],
    "шэрть": ["шерть"],
    "шёлк": ["шелковина", "шелковинка", "шёлк-сырец"],
    "шёлковый": ["мягкий", "нежный", "кроткий", "послушный", "тихий"],
    "шёпот": ["пошепт", "перешёптывание", "шелест", "шорох", "молва", "кривотолки", "толки", "разговоры", "слух", "слухи", "шопот", "сплетня", "сплетни"],
    "шёпотом": ["тихо"],
    "щабель": ["щаблина"],
    "щавелево-уксусная кислота": ["кетоянтарная кислота"],
    "щавелевый": ["щавельный"],
    "щавельний": ["щавлевий"],
    "щавельный": ["щавелевый"],
    "щавлевий": ["щавельний"],
    "щадив": ["щадивши"],
    "щадивши": ["щадив"],
    "щадить": ["миловать"],
    "щадниця": ["ощадна каса"],
    "щас": ["сейчас", "ща"],
    "щасливий": ["щасний"],
    "щат": ["кадри", "състав", "численост"],
    "щебенив": ["щебенивши"],
    "щебенивши": ["щебенив"],
    "щебенной": ["щебёночный", "щебённый", "щебневой", "щебневый"],
    "щебень": ["щебёнка", "битый камень", "щебель", "щебер", "щебло", "битыш", "щепа", "щебенник", "щебняк", "битняк", "укат", "утолока", "хрящёвка"],
    "щебет": ["щебетание"],
    "щебетав": ["щебетавши"],
    "щебетавши": ["щебетав"],
    "щебетание": ["щебет", "чириканье", "щебетанье"],
    "щебетанье": ["щебетание"],
    "щебетать": ["чирикать", "щёлкать", "лепетать"],
    "щебетнув": ["щебетнувши"],
    "щебетнувши": ["щебетнув"],
    "щебневой": ["щебневый"],
    "щебневый": ["щебневой"],
    "щебёнка": ["щебень", "битый камень", "битыш", "щепа", "щебёночная дорога", "щебенная дорога", "щебенник", "щебняк", "битняк", "укат", "утолока", "хрящёвка", "гнилушка", "грош", "копейки"],
    "щебённый": ["щебёночный", "щебенной", "щебневой", "щебневый"],
    "щеглячий": ["щеголий"],
    "щегол": ["молокосос", "салага", "первогодок", "слабак", "фат", "фанфарон"],
    "щеголиха": ["франтиха", "модница"],
    "щегольнув": ["щегольнувши"],
    "щегольнувши": ["щегольнув"],
    "щегольская болезнь": ["сифилис", "венерическая болезнь", "скверная болезнь", "стыдная болезнь", "французская болезнь"],
    "щегольски": ["франтовато", "молодцевато", "браво"],
    "щегольской": ["щеголеватый"],
    "щегольство": ["франтовство", "шик", "пижонство", "фатовство", "дендизм", "хвастовство", "бахвальство", "бравада", "удальство", "лихость", "лихачество", "молодечество", "ухарство", "бесшабашность", "кураж"],
    "щеголяв": ["щеголявши"],
    "щеголявши": ["щеголяв"],
    "щеголять": ["хвастать", "хвастаться", "хвалиться", "тщеславиться"],
    "щедривый": ["рябой"],
    "щедрина": ["оспина"],
    "щедровка": ["колядка"],
    "щедрой рукой": ["щедро", "богато", "изобильно"],
    "щедролюбие": ["щедрость"],
    "щедрый": ["великодушный", "тороватый", "богатый", "обильный", "изобильный"],
    "щек": ["шеко"],
    "щека": ["ланита", "губка"],
    "щеколда": ["задвижка", "защёлка", "шпингалет"],
    "щекотав": ["щекотавши"],
    "щекотавши": ["щекотав"],
    "щекотанье": ["щекотание"],
    "щекотать": ["тешить"],
    "щекотив": ["щекотивши"],
    "щекотивши": ["щекотив"],
    "щекотка": ["щекотание"],
    "щекотнув": ["щекотнувши"],
    "щекотнувши": ["щекотнув"],
    "щелбан": ["шалобан", "шелопет", "щулбан"],
    "щелевав": ["щелевавши"],
    "щелевавши": ["щелевав"],
    "щелеватый": ["щелистый"],
    "щелезуб": ["ядовитая слономышь"],
    "щелинность": ["спирантность", "фрикативность"],
    "щелканув": ["щелканувши"],
    "щелканувши": ["щелканув"],
    "щелкопёр": ["бумагомаратель", "писака", "бумагомарака", "графоман"],
    "щелкун": ["жук-щелкун"],
    "щелкушка": ["щелкун"],
    "щелоктав": ["щелоктавши"],
    "щелоктавши": ["щелоктав"],
    "щелокчив": ["щелокчивши"],
    "щелокчивши": ["щелокчив"],
    "щелочив": ["щелочивши"],
    "щелочивши": ["щелочив"],
    "щелп": ["сущность"],
    "щелпак": ["жук", "клещ"],
    "щелястость": ["щелистость"],
    "щелястый": ["щелистый"],
    "щемив": ["щемивши"],
    "щемивши": ["щемив"],
    "щемить": ["зажимать", "защемлять", "прищемлять", "сжимать", "стискивать", "ныть"],
    "щеневмерлик": ["понадусерик"],
    "щениться": ["ощеняться"],
    "щенок": ["мальчишка", "сопляк", "кутёнок", "молокосос"],
    "щеня": ["щенятко", "цуценя", "молокосос"],
    "щепав": ["щепавши"],
    "щепавши": ["щепав"],
    "щепет": ["нарядность", "щепеть"],
    "щепетильник": ["афеня"],
    "щепетильничав": ["щепетильничавши"],
    "щепетильничавши": ["щепетильничав"],
    "щепетильность": ["принципиальность"],
    "щепетильный": ["галантерейный", "парфюмерный", "изысканный", "модный", "чопорный", "церемонный", "мелочный", "меркантильный", "щекотливый", "деликатный", "вежливый"],
    "щепеткий": ["узкий"],
    "щепеть": ["нарядность", "щепет"],
    "щепив": ["щепивши"],
    "щепивши": ["щепив"],
    "щепляв": ["щеплявши"],
    "щеплявши": ["щепляв"],
    "щепотка": ["щепоть"],
    "щепотник": ["никонианец", "новообрядец", "никонианин", "троеперстник"],
    "щепоть": ["троеперстие", "щепотка"],
    "щербак": ["цикорий", "серпник", "петров кнут"],
    "щербатый": ["выщербленный", "рябой", "беззубый"],
    "щербет": ["шербет", "сорбет"],
    "щербив": ["щербивши"],
    "щербивши": ["щербив"],
    "щербина": ["зазубрина", "рябинка", "рябина"],
    "щербить": ["выщерблять"],
    "щерив": ["щеривши"],
    "щеривши": ["щерив"],
    "щериться": ["скалить зубы", "щерить зубы", "скалиться", "ощериваться", "ощеряться"],
    "щетина": ["небритость"],
    "щетинив": ["щетинивши"],
    "щетинивши": ["щетинив"],
    "щетинообразный": ["щетиноподобный"],
    "щетинохвостка": ["трехвостка"],
    "щеть": ["щетина"],
    "щец": ["щи"],
    "щецин": ["штеттин"],
    "щи": ["шти", "щаги", "капуста"],
    "щи лаптем хлебать": ["лаптем щи хлебать", "мух ноздрями ловить"],
    "щигля": ["щиглятко"],
    "щикать": ["сощикать"],
    "щиколка": ["лодыжка", "щиколотка"],
    "щиколотка": ["лодыжка", "щиколка"],
    "щип": ["щипок"],
    "щипа": ["щепа", "щепка"],
    "щипанув": ["щипанувши"],
    "щипанувши": ["щипанув"],
    "щипанье": ["щипание"],
    "щипать": ["теребить", "дёргать", "ощипывать", "пощипывать", "жечь", "чистить"],
    "щипач": ["карманный вор", "карманник", "мошенник"],
    "щипнув": ["щипнувши"],
    "щипнувши": ["щипнув"],
    "щирица": ["амарант"],
    "щирый": ["искренний", "откровенный", "честный", "истинный"],
    "щитовидная железа": ["щитовидка"],
    "щиток": ["приспособление"],
    "щитолистник": ["денежник"],
    "щитоносец": ["щитоноша", "аргентинский щитоносец", "плащеносный броненосец", "пичисиего"],
    "щитпост": ["говнопост"],
    "щифт": ["клечка", "клин", "колче"],
    "щука": ["щучка", "щучечка", "щучища", "щупак"],
    "щулбан": ["щелбан", "шалобан", "шелопет"],
    "щуняв": ["щунявши"],
    "щунявши": ["щуняв"],
    "щунять": ["журить"],
    "щупав": ["щупавши"],
    "щупавши": ["щупав"],
    "щупанье": ["ощупывание", "тисканье", "щуренье"],
    "щупать": ["ощупывать"],
    "щуплый": ["худой", "худенький", "субтильный", "невзрачный", "болезненный", "хилый", "чахлый"],
    "щуприна": ["чуб"],
    "щур": ["финский попугай"],
    "щурение": ["прищуривание"],
    "щуренье": ["щупанье"],
    "щуреня": ["щуря"],
    "щурив": ["щуривши"],
    "щуривши": ["щурив"],
    "щурик": ["щур"],
    "щурить": ["прищуривать"],
    "щуриться": ["жмуриться"],
    "щурм": ["пристъп", "атака"],
    "щурок": ["щурёнок"],
    "щуря": ["щуреня"],
    "щурёнок": ["щучка", "щурок"],
    "щусёнок": ["мальчишка", "молокосос", "пащенок", "птенец", "салага", "салажонок", "сморкач", "сопливец", "сопля", "сопляк", "сосунок", "щурёнок"],
    "щучив": ["щучивши"],
    "щучивши": ["щучив"],
    "щучий": ["щуковый", "щукин"],
    "щучина": ["щука"],
    "щучить": ["журить"],
    "щучка": ["щука"],
    "щялмахъ": ["щялушин"],
    "щялушин": ["щялмахъ"],
    "щёголь": ["фат", "франт", "хлыщ", "денди"],
    "щёгольский": ["щегольской", "франтоватый"],
    "щёкот": ["щекотка", "щекотание"],
    "щёлк": ["щелчок"],
    "щёлкав": ["щёлкавши"],
    "щёлкавши": ["щёлкав"],
    "щёлкать": ["хлопать", "свистеть"],
    "щёлкать клювом": ["считать ворон", "ротозействовать"],
    "щёлкающий": ["койсанский"],
    "щёлкнув": ["щёлкнувши"],
    "щёлкнувши": ["щёлкнув"],
    "щёлок": ["щёлочь"],
    "щёлочеупорный": ["щёлочестойкий"],
    "щёлочный": ["щелочной", "основный"],
    "щётки": ["ребровик"],
    "щётковидный": ["щёткообразный"],
    "щёткообразный": ["щётковидный"],
    "щёчный": ["ланитный"],
    "ърдазу": ["лебоню", "пяндра"],
    "ърьвя": ["ава"],
    "ыкав": ["ыкавши"],
    "ыкавши": ["ыкав"],
    "ыкнув": ["ыкнувши"],
    "ыкнувши": ["ыкнув"],
    "ынлу": ["нынлу"],
    "ынстэрит": ["авут", "богат"],
    "ыныкчан": ["ыныкчанский"],
    "ыныкчанский": ["ыныкчан"],
    "ыргытырга": ["ташларга"],
    "ых": ["эх", "ц-ц-ц"],
    "ыштан": ["салбар"],
    "ышыкъ": ["ярыкъ", "нур"],
    "э-ге-ге": ["эге", "вот оно что", "вот как"],
    "э-э": ["э-э-э"],
    "э-э-э": ["э-э"],
    "эа": ["хайя", "эйа", "энки"],
    "эбеновое дерево": ["чёрное дерево"],
    "эбионит": ["эвионит", "евионит"],
    "эблис": ["иблис"],
    "эбонитовый": ["чёрный"],
    "эбулиоскопический": ["эбуллиоскопический"],
    "эбулиоскопия": ["эбуллиоскопия"],
    "эбуллиометрия": ["эбуллиоскопия", "эбулиометрия"],
    "эбуллиоскопия": ["эбулиоскопия"],
    "эва": ["ева"],
    "эвакуатор": ["эвакуаторщик"],
    "эвакуировав": ["эвакуировавши"],
    "эвакуировавши": ["эвакуировав"],
    "эвапоратор": ["испаритель"],
    "эвапорограф": ["регистрирующий", "испаритель"],
    "эвбея": ["негропонт", "евбея"],
    "эвдемонический": ["эвдемонистический"],
    "эвен": ["ламут"],
    "эвенемент": ["сенсация", "случай", "событие"],
    "эвенк": ["тунгус"],
    "эвенка": ["эвенкийка", "тунгуска"],
    "эвенкийка": ["эвенка", "тунгуска"],
    "эвенкийский автономный округ": ["эвенкия"],
    "эвенкийский язык": ["эвенкский язык", "тунгусский язык"],
    "эвенкия": ["эвенкийский автономный округ"],
    "эвент": ["ивент"],
    "эвентуальность": ["возможность"],
    "эвентуальный": ["возможный", "вероятный", "потенциальный"],
    "эверест": ["джомолунгма"],
    "эвисцерация": ["экзентерация"],
    "эвкалипт": ["камедистое дерево", "дивное дерево"],
    "эвклаз": ["хрупик"],
    "эвклид": ["евклид"],
    "эвклидов": ["евклидов"],
    "эвксинский понт": ["чёрное море"],
    "эвм": ["электронно-вычислительная машина", "компьютер"],
    "эвольвента": ["инволюта"],
    "эволюционизм": ["эволюционная теория"],
    "эволюционировав": ["эволюционировавши"],
    "эволюционировавши": ["эволюционировав"],
    "эволюционировать": ["развиваться"],
    "эволюционистический": ["эволюционистский", "дарвинистический", "дарвинистский"],
    "эволюционистский": ["эволюционистический"],
    "эволюция": ["развитие", "изменение", "манёвр", "движение", "упражнение"],
    "эвора": ["эбора", "эбура"],
    "эвось": ["эвося"],
    "эвося": ["эвось"],
    "эвпатрид": ["евпатрид"],
    "эвристический": ["творческий"],
    "эвристичный": ["продуктивный", "креативный", "плодотворный"],
    "эвритроф": ["эврифаг"],
    "эврифаг": ["эвритроф"],
    "эврифагия": ["всеядность"],
    "эврот": ["эвротас"],
    "эвротас": ["эврот", "еврот"],
    "эвстазия": ["стабильность"],
    "эвтерпа": ["евтерпа"],
    "эвтрофикация": ["эвтрофирование"],
    "эвтрофирование": ["эвтрофикация"],
    "эвтюмия": ["атараксия"],
    "эвфемистично": ["эвфемистически"],
    "эвфемистичность": ["эвфемичность", "благозвучность"],
    "эвфемистичный": ["эвфемистический"],
    "эвфемичность": ["эвфемистичность"],
    "эвфемичный": ["эвфемистичный", "эвфемистический"],
    "эвфонический": ["благозвучный"],
    "эвфония": ["благозвучие", "эвфоничность", "фоника"],
    "эвфоссилия": ["эуфоссилия"],
    "эвфуистический": ["эвфуистичный"],
    "эгалитарность": ["равенство", "уравнительность"],
    "эгалитарный": ["уравнительный"],
    "эгей": ["эй", "гей"],
    "эгеста": ["сегеста", "акеста"],
    "эгестянин": ["сегестянин", "акестянин"],
    "эгида": ["эгид"],
    "эгирми": ["игирмэ", "йигирми"],
    "эглет": ["пистончик"],
    "эгоизм": ["себялюбие", "эгоистичность"],
    "эгоист": ["себялюбец", "себялюб", "самолюбец", "самолюб"],
    "эгоистично": ["эгоистически", "себятнически"],
    "эгоистичность": ["эгоизм"],
    "эгосинтонический": ["эгосинтонный"],
    "эгосинтонность": ["эгосинтония"],
    "эготизм": ["самовлюблённость", "нарциссизм"],
    "эгоцентризм": ["эгоизм", "эгоцентричность"],
    "эгоцентричность": ["эгоцентризм"],
    "эгрегор": ["ларв", "элементаль"],
    "эгрет": ["эгретка"],
    "эгретка": ["эгрет", "плюмаж"],
    "эдак": ["так", "этак", "эвдак"],
    "эдакий": ["этакий"],
    "эдам": ["эдамер"],
    "эдамер": ["эдам"],
    "эдельвейс": ["леонтоподиум"],
    "эдем": ["едем"],
    "эдесса": ["едесия", "едесса", "урха"],
    "эдеэ бариха": ["эдихэ"],
    "эдиакарий": ["венд"],
    "эдик": ["эдуард"],
    "эдирне": ["адрианополь"],
    "эдита": ["эдит", "идит", "эдда", "ди"],
    "эдихэ": ["эдеэ бариха"],
    "эдмунд": ["эдмон", "эдмонд"],
    "эдом": ["едом"],
    "эдфу": ["дебут", "атбо", "аполлинополь", "эджбо", "бехдет"],
    "эжектор": ["отражатель"],
    "эзга": ["ланга"],
    "эзда": ["ваксста", "видеста", "маласта", "кядьста", "ёткста"],
    "эзид": ["худо", "парвардигор", "яздон", "изад"],
    "эзк": ["тозк"],
    "эзопов": ["эзоповский"],
    "эзопов язык": ["эзоповский язык", "тайнопись"],
    "эзоповский": ["эзопов"],
    "эзотеризм": ["эзотерика"],
    "эзотерика": ["эзотеризм"],
    "эзотерический": ["тайный"],
    "эй": ["эгей"],
    "эйа": ["энки"],
    "эйбеншток": ["айбеншток"],
    "эйблефар": ["эублефар"],
    "эйджизм": ["эдалтизм"],
    "эйдология": ["эйдетика"],
    "эйкозапентаеновая кислота": ["эпк"],
    "эйлау": ["прейсиш-эйлау", "багратионовск"],
    "эйленшпигель": ["уленшпигель"],
    "эйлеров": ["эйлеровский"],
    "эйлеровский": ["эйлеров"],
    "эйндамс": ["арамс", "вельхтявомс", "кевонзамс", "кельмомс", "паломс", "тарькстамс", "шуфтомомс"],
    "эйнштейнианский": ["эйнштейновский"],
    "эйнштейновский": ["эйнштейнианский"],
    "эйрисомный": ["широкотелый"],
    "эйс": ["подача навылет"],
    "эйфорический": ["эйфоричный"],
    "эйфоричный": ["эйфорический"],
    "эйфория": ["эвфория"],
    "эйчар": ["кадровик"],
    "эйчариха": ["кадровичка"],
    "эйчтитипи": ["аштэтэпе"],
    "эйяфьядлайёкюдль": ["эйяфьядлайёкудль"],
    "эк": ["ишь"],
    "экабор": ["скандий"],
    "экав": ["экавши"],
    "экавши": ["экав"],
    "экасилиций": ["германий"],
    "эквадор": ["республика эквадор"],
    "экватор": ["полпути", "середина"],
    "экваториальная гвинея": ["республика экваториальная гвинея"],
    "эквивалентность": ["равноценность"],
    "эквивалентный": ["идентичный", "одинаковый", "равный", "такой же", "равновесный"],
    "эквиваленция": ["эквивалентность"],
    "эквидистантность": ["равноудаленность"],
    "эквидистантный": ["равноотстоящий", "равноудалённый"],
    "эквилибрировав": ["эквилибрировавши"],
    "эквилибрировавши": ["эквилибрировав"],
    "эквилибрист": ["ловкач", "искусник", "виртуоз", "умелец", "мастак", "дока", "циркач"],
    "эквилибристика": ["балансирование", "хождение", "по", "канат", "устойчивость", "несгибаемость"],
    "эквимолекулярный": ["стехиометрический"],
    "эквиритмический": ["эквиритмичный"],
    "эквиритмия": ["эквиритмичность"],
    "эквит": ["конник", "кавалерист", "всадник"],
    "эквоним": ["согипоним", "когипоним"],
    "экдистен": ["экдистерон"],
    "экдистероид": ["экдизон"],
    "экер": ["эккер"],
    "экзажерация": ["преувеличение"],
    "экзажерировать": ["преувеличивать"],
    "экзажеровать": ["преувеличивать"],
    "экзактный": ["точный"],
    "экзальтация": ["экстаз", "аффектация"],
    "экзальтировав": ["экзальтировавши"],
    "экзальтировавши": ["экзальтировав"],
    "экзальтированность": ["экзальтация", "возбуждённость"],
    "экзальтированный": ["восторженный", "возбужденный", "воодушевлённый"],
    "экзамен": ["экзаменация", "экзаменовка"],
    "экзаменовав": ["экзаменовавши"],
    "экзаменовавши": ["экзаменовав"],
    "экзарх": ["митрополит"],
    "экзархат": ["фема", "диоцез", "провинция", "эпархия"],
    "экзафлопс": ["эксафлопс"],
    "экзегеза": ["экзегетика"],
    "экзегетика": ["экзегеза"],
    "экземплификант": ["экземплификатив"],
    "экзентерация": ["эвисцерация"],
    "экзерсис": ["упражнение", "экзерцис"],
    "экзерциция": ["упражнение"],
    "экзиларх": ["эхмалотарх"],
    "экзина": ["экзоспорий"],
    "экзистенциальный": ["онтологический", "бытийный", "мировоззренческий", "фундаментальный", "экзистенциалистский"],
    "экзистенция": ["существование", "бытие"],
    "экзобиология": ["астробиология"],
    "экзокарпий": ["внеплодник"],
    "экзомис": ["экзомида"],
    "экзонартекс": ["экзонарфик"],
    "экзопептидаза": ["экзопротеиназа"],
    "экзоплазма": ["эктоплазма"],
    "экзопланета": ["внесолнечная планета", "экстрасолнечная планета", "экстрасолярная планета"],
    "экзопротез": ["эктопротез"],
    "экзопротеиназа": ["экзопептидаза"],
    "экзоспорий": ["экзина"],
    "экзотерический": ["общедоступный"],
    "экзотизм": ["заимствование"],
    "экзотика": ["экзотизм"],
    "экзотопоним": ["экзохороним"],
    "экзотрофный": ["эктотрофный"],
    "экзохорда": ["струноплодник"],
    "экзоэтноним": ["аллоэтноним"],
    "экивок": ["двусмысленность", "обиняк", "намёк", "увёртка"],
    "экий": ["экой", "какой", "ишь какой"],
    "экиньчи": ["экинджи", "экинчи"],
    "экип": ["экипирование", "екипировка"],
    "экипаж": ["команда"],
    "экипировав": ["экипировавши"],
    "экипировавши": ["экипировав"],
    "экипировать": ["снаряжать", "снарядить"],
    "экипироваться": ["снаряжаться"],
    "экипировка": ["амуниция", "обмундирование", "снаряжение"],
    "экипировщик": ["снабженец"],
    "эккер": ["экер"],
    "экклезиология": ["экклесиология"],
    "эккриновый": ["эккринный"],
    "эклектизм": ["эклектика"],
    "эклектик": ["эклектист"],
    "эклектика": ["эклектизм", "эклектичность"],
    "эклектист": ["эклектик"],
    "эклектицизм": ["эклектика", "эклектизм"],
    "эклектичность": ["эклектизм"],
    "эклектичный": ["эклектический", "разнородный"],
    "эклога": ["пастораль", "идиллия", "буколика"],
    "экмек": ["чёрек"],
    "эко": ["экстракорпоральное оплодотворение", "оплодотворение в пробирке", "оплодотворение", "искусственное оплодотворение"],
    "экобазар": ["экорынок"],
    "экобокс": ["экоурна"],
    "экодук": ["зверопроход", "скотопрогон", "биопереход"],
    "экозона": ["биогеографическая зона"],
    "экой": ["эко"],
    "эколог": ["зелёный"],
    "экологизировав": ["экологизировавши"],
    "экологизировавши": ["экологизировав"],
    "экологичный": ["зелёный"],
    "эконометрика": ["эконометрия"],
    "эконометрия": ["эконометрика"],
    "экономив": ["экономивши"],
    "экономивши": ["экономив"],
    "экономизировав": ["экономизировавши"],
    "экономизировавши": ["экономизировав"],
    "экономика": ["хозяйствование"],
    "экономить": ["беречь"],
    "экономический": ["хозяйственный", "экономный", "экономичный"],
    "экономичный": ["малозатратный", "экономный", "выгодный"],
    "экономия": ["бережливость", "экономность", "сбережение", "сохранение", "усадьба", "имение", "экономика"],
    "экономка": ["домработница", "домоправительница"],
    "экономничав": ["экономничавши"],
    "экономничавши": ["экономничав"],
    "экономно": ["бережливо", "рационально"],
    "экономность": ["хозяйственность", "бережливость", "бережность"],
    "экономный": ["бережливый", "экономичный", "эффективный"],
    "экопоселение": ["экологическое поселение"],
    "экосистема": ["биосистема", "бизнес-экосистема"],
    "экостратон": ["биогеостратон"],
    "экотип": ["климатип", "эдафотип"],
    "экотоп": ["биотоп"],
    "экоурна": ["экобокс"],
    "экран": ["дисплей", "телевизор"],
    "экранизировав": ["экранизировавши"],
    "экранизировавши": ["экранизировав"],
    "экранизовав": ["экранизовавши"],
    "экранизовавши": ["экранизовав"],
    "экранировав": ["экранировавши"],
    "экранировавши": ["экранировав"],
    "экранировать": ["предохранять", "предохранить"],
    "экранировка": ["экранирование"],
    "экранка": ["камрип"],
    "экс-депутат": ["экс-думец"],
    "экс-муж": ["экс-супруг"],
    "экс-премьер-министр": ["экс-премьер"],
    "экс-супруг": ["экс-муж"],
    "экс-супруга": ["экс-жена"],
    "эксабайт": ["экзабайт"],
    "эксафлопс": ["экзафлопс"],
    "эксгумировав": ["эксгумировавши"],
    "эксгумировавши": ["эксгумировав"],
    "эксиль": ["эксил"],
    "экскаватор": ["землечерпалка"],
    "экскаватор-погрузчик": ["погрузчик-экскаватор"],
    "эксклюзив": ["уникум"],
    "эксклюзивный": ["исключительный", "неповторимый", "уникальный", "элитарный", "авторский"],
    "экскремент": ["испражнение", "фекалия", "кал"],
    "экскрементофилия": ["пикацизм"],
    "экскременты": ["испражнения", "кал"],
    "экскретировав": ["экскретировавши"],
    "экскретировавши": ["экскретировав"],
    "экскреторный": ["выделительный"],
    "экскреция": ["выделение"],
    "экскурс": ["отступление"],
    "экскурсировав": ["экскурсировавши"],
    "экскурсировавши": ["экскурсировав"],
    "экскурсия": ["поход", "экспедиция", "приступ"],
    "экскурсовод": ["гид"],
    "экскурсоводка": ["экскурсоводша"],
    "экскурсоводша": ["экскурсоводка"],
    "экслибрис": ["книжный знак"],
    "экспа": ["опыт", "очки опыта"],
    "экспансивно": ["темпераментно"],
    "экспансивный": ["несдержанный", "порывистый", "горячий", "маниакальный"],
    "экспансия": ["распространение", "расширение"],
    "экспат": ["экспатриант"],
    "экспатриант": ["экспат"],
    "экспатриировав": ["экспатриировавши"],
    "экспатриировавши": ["экспатриировав"],
    "экспедировав": ["экспедировавши"],
    "экспедировавши": ["экспедировав"],
    "экспедиционно-вахтовый": ["вахтово-экспедиционный"],
    "экспедиционный корпус": ["экспедиционная армия", "экспедиционные силы"],
    "экспедиция": ["экспедирование", "поход", "путешествие", "поездка"],
    "экспекторация": ["откашливание", "отхаркивание"],
    "эксперимент": ["опыт", "попытка", "проба", "испытание"],
    "экспериментальный": ["эмпирический", "подопытный", "пробный", "опытный", "тестовый"],
    "экспериментатор": ["эмпирик"],
    "экспериментаторство": ["экспериментирование"],
    "экспериментировав": ["экспериментировавши"],
    "экспериментировавши": ["экспериментировав"],
    "экспериментировать": ["пробовать", "ставить опыт", "проводить опыт", "проводить эксперимент"],
    "эксперт": ["знаток", "мастер", "судмедэксперт"],
    "экспиация": ["искупление"],
    "экспирация": ["выдох", "выдыхание"],
    "эксплантировав": ["эксплантировавши"],
    "эксплантировавши": ["эксплантировав"],
    "экспликация": ["разъяснение", "объяснение", "пояснение", "легенда"],
    "эксплицировав": ["эксплицировавши"],
    "эксплицировавши": ["эксплицировав"],
    "эксплицитно": ["явно", "открыто", "развёрнуто"],
    "эксплицитность": ["выраженность", "открытость"],
    "эксплицитный": ["открытый", "неприкрытый"],
    "эксплоатационный": ["эксплуатационный", "эксплуататорский"],
    "эксплоатация": ["использование", "эксплуатация"],
    "эксплоатировав": ["эксплоатировавши"],
    "эксплоатировавши": ["эксплоатировав"],
    "эксплозивный": ["эпилептоидный", "возбудимый"],
    "эксплораторный": ["исследовательский", "поисковый"],
    "эксплорация": ["исследование", "изучение"],
    "эксплуататор": ["эксплуатирующий"],
    "эксплуатационник": ["коммунальщик"],
    "эксплуатация": ["эксплоатация"],
    "эксплуатировав": ["эксплуатировавши"],
    "эксплуатировавши": ["эксплуатировав"],
    "эксплуатирование": ["эксплуатация"],
    "эксплуатнув": ["эксплуатнувши"],
    "эксплуатнувши": ["эксплуатнув"],
    "экспозиметр": ["экспонометр"],
    "экспозиционный": ["вступительный", "выставочный"],
    "экспозиция": ["выдержка"],
    "экспонент": ["сигнификант"],
    "экспонента": ["экспоненциальная функция", "показательная функция"],
    "экспонентный": ["экспоненциальный"],
    "экспоненциальная функция": ["экспонента", "показательная функция"],
    "экспоненциальный": ["экспонентный", "показательный"],
    "экспоненциальный рост": ["степенной рост"],
    "экспонировав": ["экспонировавши"],
    "экспонировавши": ["экспонировав"],
    "экспорт": ["вывоз", "портирование", "перекодировка"],
    "экспортировав": ["экспортировавши"],
    "экспортировавши": ["экспортировав"],
    "экспортный": ["вывозной", "вывозимый"],
    "экспрессивно": ["выразительно"],
    "экспрессивность": ["выразительность", "экспрессия"],
    "экспрессивный": ["выразительный", "эмоциональный"],
    "экспрессионистический": ["экспрессионистский"],
    "экспрессионистский": ["экспрессионистический"],
    "экспрессировав": ["экспрессировавши"],
    "экспрессировавши": ["экспрессировав"],
    "экспрессия": ["выразительность"],
    "экспромт": ["импровизация"],
    "экспроприация": ["отчуждение", "национализация"],
    "экспроприировав": ["экспроприировавши"],
    "экспроприировавши": ["экспроприировав"],
    "экссудативный диатез": ["экзема"],
    "экссудация": ["просачивание", "выпотение"],
    "экстаз": ["эйфория"],
    "экстази": ["метилендиоксиметамфетамин"],
    "экстатический": ["экстатичный"],
    "экстемпорале": ["экстемпоралия"],
    "экстендер": ["расширитель"],
    "экстензия": ["разгибание"],
    "экстензо": ["абреже"],
    "экстенсивный": ["аддитивный"],
    "экстенсионал": ["денотат"],
    "экстенсиональный": ["объёмный"],
    "экстенсифицировав": ["экстенсифицировавши"],
    "экстенсифицировавши": ["экстенсифицировав"],
    "экстерналия": ["внешний эффект"],
    "экстернат": ["экстернатура"],
    "экстерорецептор": ["экстероцептор"],
    "экстероцептор": ["экстерорецептор"],
    "экстерьер": ["внешний вид"],
    "экстирпация": ["эктомия", "эксцизия"],
    "экстра": ["люкс"],
    "экстра-": ["сверх-"],
    "экстравагантно": ["причудливо", "странно", "необычно", "эксцентрично", "оригинально", "диковинно", "экзотически", "поразительно", "сногсшибательно", "шокирующе"],
    "экстравагантность": ["эксцентричность"],
    "экстравагантный": ["необычный", "необыкновенный", "причудливый", "эксцентричный", "оригинальный", "диковинный", "экзотический", "поразительный", "сногсшибательный", "шокирующий"],
    "экстраверсия": ["общительность", "открытость"],
    "экстравертивный": ["экстравертный"],
    "экстравертированность": ["экстраверсия"],
    "экстравертный": ["экстравертивный"],
    "экстрагировав": ["экстрагировавши"],
    "экстрагировавши": ["экстрагировав"],
    "экстрагирование": ["экстракция", "выщелачивание"],
    "экстрагонадный": ["внегонадный"],
    "экстрадировав": ["экстрадировавши"],
    "экстрадировавши": ["экстрадировав"],
    "экстрадиция": ["выдача"],
    "экстрадуральный": ["эпидуральный"],
    "экстракорпоральное оплодотворение": ["оплодотворение в пробирке", "искусственное оплодотворение", "эко"],
    "экстракт": ["вытяжка"],
    "экстрактный": ["экстрактовый"],
    "экстрактовый": ["экстрактный"],
    "экстрактор": ["выбрасыватель"],
    "экстракция": ["экстрагирование", "экстракшн"],
    "экстракшн": ["экстракция"],
    "экстралингвистический": ["внеязыковой", "внелингвистический"],
    "экстраординарность": ["исключительность", "необычайность", "необычность", "необыкновенность", "чрезвычайность"],
    "экстраординарный": ["чрезвычайный", "необычайный", "исключительный", "из ряда вон выходящий", "сверхштатный", "внештатный"],
    "экстрапирамидальный": ["экстрапирамидный"],
    "экстрапирамидный": ["экстрапирамидальный"],
    "экстраплацентарный": ["внеплацентарный"],
    "экстраполировав": ["экстраполировавши"],
    "экстраполировавши": ["экстраполировав"],
    "экстраполирование": ["экстраполяция"],
    "экстраполяция": ["экстраполирование", "обобщение", "распространение"],
    "экстрасенс": ["сенс", "сенсетив", "сенситив", "медиум", "ясновидец", "ясновидица", "ясновидящий", "ясновидящая", "яснослышащий", "яснослышащая", "телепат", "телепатка"],
    "экстрасенсорный": ["внечувственный"],
    "экстремалив": ["экстремаливши"],
    "экстремаливши": ["экстремалив"],
    "экстремально": ["чересчур", "чрезмерно", "излишне", "очень", "слишком", "сильно", "шибко", "весьма", "больно", "оченно", "зело", "дюже", "вельми", "сверх меры", "избыточно"],
    "экстремальный": ["предельный", "аномальный", "граничный", "пиковый", "чрезвычайный", "несусветный", "невообразимый", "необычайный"],
    "экстремальный метал": ["экстрим-метал"],
    "экстремист": ["радикал"],
    "экстренный": ["срочный", "неотложный", "не терпящий отлагательства", "внеочередной", "чрезвычайный"],
    "экструдировав": ["экструдировавши"],
    "экструдировавши": ["экструдировав"],
    "экструдировать": ["шприцевание", "выдавливание"],
    "экструзия": ["экструдинг"],
    "экстубировав": ["экстубировавши"],
    "экстубировавши": ["экстубировав"],
    "эксфолиация": ["расслаивание", "выветривание", "отшелушивание", "пилинг"],
    "эксцентризм": ["эксцентричность", "экстравагантность", "причудливость"],
    "эксцентрично": ["экстравагантно"],
    "эксцентричность": ["экстравагантность"],
    "эксцентричный": ["экстравагантный", "странный"],
    "эксцесс": ["происшествие", "инцидент"],
    "эксцизия": ["эктомия", "резекция", "экстирпация"],
    "эксцитатор": ["возбудитель"],
    "эксцитация": ["возбуждение", "вызывание", "возбуждённость"],
    "эксцитировать": ["возбуждать"],
    "эктаза": ["эктазис", "диастола"],
    "эктобласт": ["эктодерма"],
    "эктогенез": ["неоламаркизм"],
    "эктогенный": ["экзогенный"],
    "эктомезенхима": ["нейромезенхима"],
    "эктомия": ["резекция", "эксцизия"],
    "эктопическая беременность": ["внематочная беременность"],
    "эктопия": ["дистопия", "гетеротопия"],
    "эктоплазма": ["плазмагель", "экзоплазма"],
    "эктотека": ["экзотека"],
    "эктоэндомикориза": ["эктэндомикориза"],
    "эктэ пиктэ": ["асиа пиктэ"],
    "эктэндомикориза": ["эктоэндомикориза"],
    "экумена": ["ойкумена"],
    "экуменистский": ["экуменистический"],
    "экуменополис": ["сверхагломерация", "глобальный", "агломерация", "всемирный", "город"],
    "экшен": ["боевик", "экшн"],
    "эл-во": ["электричество"],
    "эласмосома": ["элайосома"],
    "эластичность": ["упругость"],
    "эластичный": ["гибкий"],
    "элатив": ["элятив", "аблатив", "исходный падеж", "отложительный падеж"],
    "элвис покинул здание": ["поздняк метаться"],
    "элвуд": ["вуди"],
    "элдэпээровец": ["жириновец"],
    "эле": ["гана", "только", "жана", "ещё", "же"],
    "элеат": ["элеец"],
    "элеватор": ["житница", "зернохранилище", "житохранилище", "самотаска"],
    "элевзинский": ["элевсинский"],
    "элевсинский": ["элевзинский"],
    "элегаз": ["шестифтористая сера"],
    "элегант": ["щёголь", "франт", "денди", "хлыщ", "фат", "модник", "пижон", "стиляга", "петиметр", "ферт"],
    "элегантно": ["изящно"],
    "элегантный": ["изящный"],
    "элегичный": ["элегический", "меланхолический"],
    "элеец": ["элеат"],
    "элейн": ["хелен", "элейна", "эллен"],
    "элекке": ["элеккеге", "иске"],
    "электоральный": ["избирательный", "избирательский"],
    "электорат": ["избиратели", "вторая нефть", "новая нефть"],
    "электр": ["электрум"],
    "электризовав": ["электризовавши"],
    "электризовавши": ["электризовав"],
    "электризовывав": ["электризовывавши"],
    "электризовывавши": ["электризовывав"],
    "электрика": ["электротехника", "электроприбор"],
    "электрифицировав": ["электрифицировавши"],
    "электрифицировавши": ["электрифицировав"],
    "электрическая лампочка": ["лампа накаливания"],
    "электрическая плита": ["электроплита"],
    "электрическая сеть": ["электросеть"],
    "электрическая цепь": ["электроцепь"],
    "электрический": ["электро-"],
    "электрический заряд": ["количество электричества"],
    "электричество": ["свет", "ток"],
    "электричка": ["электропоезд", "электрический поезд", "электромобиль"],
    "электро-индастриал": ["электро"],
    "электроавтомобиль": ["электромобиль"],
    "электробатарея": ["электрическая батарея"],
    "электробиограф": ["кинотеатр", "синематограф"],
    "электробритва": ["шейвер"],
    "электровелосипед": ["электрический велосипед", "велогибрид", "е-байк", "пауэрбайк", "педелек", "электровел", "электровелик"],
    "электрогазовый": ["газоэлектрический"],
    "электрогастрография": ["электрогастроэнтерография"],
    "электрогенерация": ["электропроизводство"],
    "электроглянцеватель": ["фотоглянцеватель", "электрофотоглянцеватель"],
    "электроград": ["энергоград"],
    "электрограф": ["электроискровой", "карандаш", "электроперо"],
    "электрогриль": ["гриль"],
    "электрод": ["контакт"],
    "электродвижок": ["электродвигатель"],
    "электрокар": ["электротележка", "электромобиль"],
    "электрокардиограмма": ["экг"],
    "электрокардиостимулятор": ["искусственный водитель ритма сердца"],
    "электрокаустика": ["гальванокаустика", "гальванотермия"],
    "электрокипятильник": ["кипятильник"],
    "электрокоагуляция": ["диатермокоагуляция"],
    "электроконвектор": ["конвекторный нагреватель"],
    "электрокортин": ["альдокортин", "альдостерон"],
    "электрокоса": ["электротриммер"],
    "электролампа": ["электрическая лампа"],
    "электролизный": ["электролитический"],
    "электролитический": ["электролизный"],
    "электромагнетический": ["электромагнитный"],
    "электромагнитная волна": ["электромагнитное излучение"],
    "электромагнитный": ["электромагнетический"],
    "электромашина": ["электрическая машина"],
    "электромиография": ["миография", "электронейромиография"],
    "электромобиль": ["электроавтомобиль"],
    "электромонтажник": ["электромонтёр", "монтёр"],
    "электромонтёр": ["электрик", "электромонтажник", "электротехник"],
    "электрон": ["негатрон"],
    "электрон-вольт": ["электронвольт", "эв", "электроновольт"],
    "электронвольт": ["электрон-вольт", "электроновольт"],
    "электронейромиография": ["энмг"],
    "электроник": ["электронщик"],
    "электроника": ["электротехника"],
    "электронная библиотека": ["электронная библиотечная система"],
    "электронная подпись": ["электронная цифровая подпись", "цифровая подпись"],
    "электронная почта": ["имейл", "мыло"],
    "электронная сигарета": ["вейп", "эсдн", "мод"],
    "электронно-ионный": ["элионный"],
    "электронное архивирование": ["архивация"],
    "электроннолучевой": ["электронно-лучевой"],
    "электронный компонент": ["радиодеталь"],
    "электронный листок нетрудоспособности": ["элн"],
    "электронный микроскоп": ["эм"],
    "электронщик": ["электроник"],
    "электрооптический": ["оптоэлектрический"],
    "электроотвёртка": ["электрическая отвёртка"],
    "электроотрицательность": ["эо"],
    "электропастух": ["электроизгородь"],
    "электропила": ["электропилка"],
    "электропитание": ["питание"],
    "электроплита": ["электрическая плита"],
    "электропоезд": ["электричка"],
    "электропроводка": ["проводка"],
    "электропроводность": ["электропроводимость", "проводимость"],
    "электропроводный": ["токопроводящий"],
    "электропроизводство": ["электрогенерация"],
    "электропылесос": ["электрический пылесос"],
    "электрореография": ["реография"],
    "электророзетка": ["электрическая розетка", "розетка"],
    "электросверло": ["электродрель"],
    "электросеть": ["электрическая сеть"],
    "электротрасса": ["энерготрасса"],
    "электротриммер": ["электрокоса"],
    "электроустройство": ["электрический прибор", "электроприбор", "электрооборудование"],
    "электрочайник": ["электрический чайник"],
    "электрочувствительность": ["электромагнитная сверхчувствительность"],
    "электрошокер": ["шокер", "тазер"],
    "электроэнцефалография": ["ээг"],
    "электрум": ["электр", "электрон"],
    "элемент": ["компонент", "составляющая"],
    "элемент множества": ["точка множества"],
    "элементарный": ["саморазумеющийся"],
    "элементарщина": ["азы"],
    "элен": ["анон"],
    "эленктический": ["сократический"],
    "элеонора": ["эля"],
    "элеутерококк": ["сибирский женьшень", "дикий перец", "чёртов куст", "экстракт космонавтов"],
    "элефантерия": ["слонница"],
    "элефантиаз": ["слоновость", "слоновая болезнь"],
    "эли": ["эла", "эля", "элла", "эллочка", "элочка", "элеонора"],
    "элизий": ["элисий", "элизиум"],
    "элизиум": ["элизий", "рай"],
    "элизия": ["стяжение"],
    "эликсир": ["лекарство", "настой", "бальзам"],
    "элиминация": ["элиминирование", "удаление", "исключение", "устранение"],
    "элиминировав": ["элиминировавши"],
    "элиминировавши": ["элиминировав"],
    "элиминирование": ["элиминация", "исключение", "удаление", "уничтожение"],
    "элиминировать": ["удалять", "исключать", "устранять", "уничтожать"],
    "элионный": ["электронно-ионный"],
    "элиста": ["степной"],
    "элита": ["верхушка", "верхи", "сливки"],
    "элитаризм": ["элитизм"],
    "элитизм": ["элитаризм"],
    "элитный": ["лучший", "отборный", "элитарный", "привилегированный", "первостатейный", "первоклассный", "престижный", "избранный"],
    "элиш": ["жумурият"],
    "элиэдулбэн": ["кукул", "йуойэ"],
    "эллада": ["греция"],
    "элли": ["энли"],
    "эллин": ["грек"],
    "эллинка": ["гречанка"],
    "эллипс": ["овал", "эллипсис", "опущение", "умолчание"],
    "эллипсический": ["эллиптический"],
    "эллипсоидальный": ["эллипсоидный"],
    "эллипсоидный": ["овальный", "эллипсоидальный"],
    "эллиптизировав": ["эллиптизировавши"],
    "эллиптизировавши": ["эллиптизировав"],
    "эллиптический тренажёр": ["эллипс", "орбитрек"],
    "эллиптичный": ["эллиптический"],
    "эллиптоцит": ["овалоцит"],
    "эллиптоцитоз": ["овалоцитоз"],
    "элмэ": ["алмэ"],
    "элодея": ["алодея", "водяная чума", "водяная зараза"],
    "элоквенция": ["красноречие", "витийство"],
    "элса": ["эльза"],
    "элсмир": ["земля элсмира"],
    "эль": ["элоах", "ил", "илу", "амуррум", "ишкур", "адад"],
    "эль-файюм": ["файюм"],
    "эльба": ["лаба"],
    "эльбор": ["боразон", "кубонит", "кингсонгит", "киборит"],
    "эльборус": ["эльбрус"],
    "эльбрус": ["шат", "шат-гора"],
    "эльвдальский": ["эльвдальский язык"],
    "эльвдальский язык": ["эльвдальский"],
    "эльвира": ["эля"],
    "эльмира": ["эля"],
    "эльнара": ["эля"],
    "эльчи": ["элци"],
    "элюировав": ["элюировавши"],
    "элюировавши": ["элюировав"],
    "элятив": ["элатив", "аблатив", "исходный падеж", "отложительный падеж"],
    "эмалировав": ["эмалировавши"],
    "эмалировавши": ["эмалировав"],
    "эмаль": ["зубная эмаль", "финифть"],
    "эманация": ["истечение", "излучение"],
    "эмансипировав": ["эмансипировавши"],
    "эмансипировавши": ["эмансипировав"],
    "эмансипированный": ["раскрепощённый", "освобождённый"],
    "эмбарго": ["блокада", "арест"],
    "эмбеддинг": ["вложение", "представление"],
    "эмблема": ["символ"],
    "эмблематичный": ["эмблематический"],
    "эмблика": ["амла", "амалаки", "эмблик"],
    "эмболизация": ["эмболотерапия"],
    "эмболомер": ["антракозавр"],
    "эмбоссирование": ["тиснение"],
    "эмбрион": ["зародыш", "зачаток"],
    "эмбриональный": ["зародышевый"],
    "эмбриопатия": ["фетопатия"],
    "эмбриотоксический": ["эмбриотоксичный"],
    "эмбэй": ["эмись"],
    "эмерджентность": ["системный эффект"],
    "эмеритальный": ["пенсионный"],
    "эмеритура": ["эмеритальная касса"],
    "эмигрировав": ["эмигрировавши"],
    "эмигрировавши": ["эмигрировав"],
    "эмилия": ["эмили", "мила", "эми"],
    "эмиль": ["эмилий"],
    "эминенция": ["преосвященство"],
    "эмираты": ["арабские эмираты", "оаэ"],
    "эмирячение": ["эмиряченье"],
    "эмись": ["эмбэй"],
    "эмитировав": ["эмитировавши"],
    "эмитировавши": ["эмитировав"],
    "эмитировать": ["выпускать", "выпустить", "напечатать", "отпечатать", "печатать", "выделять", "излучать", "излучить", "испускать", "испустить"],
    "эмиттер": ["излучатель"],
    "эмиттировав": ["эмиттировавши"],
    "эмиттировавши": ["эмиттировав"],
    "эммануэль": ["мэнни", "маню"],
    "эмманюэль": ["маню"],
    "эмменталер": ["эмменталь"],
    "эмменталь": ["эмменталер"],
    "эммер": ["полба"],
    "эмми": ["эм", "эмм"],
    "эмограмма": ["эмотикон", "смайлик"],
    "эмодзи": ["эмоджи"],
    "эмотивный": ["волнующий", "возбуждающий"],
    "эмотикон": ["эмотиконка", "эмоциконка"],
    "эмоция": ["переживание", "чувство"],
    "эмпат": ["сопереживатель"],
    "эмпатийный": ["сочувствующий", "сопереживающий"],
    "эмпатический": ["сопереживающий"],
    "эмпатия": ["сочувствие", "вчувствование", "сопереживание", "сострадание", "понимание", "отзывчивость", "чуткость"],
    "эмпиема плевры": ["гнойный плеврит", "пиоторакс"],
    "эмпирей": ["небо", "высь", "эфир", "рай", "елисейские поля", "кущи", "райские кущи", "парадиз", "эдем", "элизий", "элизиум"],
    "эмпирик": ["эмпирист", "практик", "прагматик"],
    "эмпирика": ["практика"],
    "эмпириокритицизм": ["махизм"],
    "эмпириомонистический": ["эмпириомонистский"],
    "эмпириомонистский": ["эмпириомонистический"],
    "эмпирически": ["практически", "экспериментально", "опытно", "опытным путем", "апостериори"],
    "эмпирический": ["апостериорный"],
    "эмпиричный": ["эмпирический", "реальный"],
    "эмулировав": ["эмулировавши"],
    "эмулировавши": ["эмулировав"],
    "эмулировать": ["имитировать", "воспроизводить", "симулировать"],
    "эмульгировав": ["эмульгировавши"],
    "эмульгировавши": ["эмульгировав"],
    "эмульсировав": ["эмульсировавши"],
    "эмульсировавши": ["эмульсировав"],
    "эмульсирование": ["эмульгирование", "эмульсификация"],
    "эмульсировать": ["эмульгировать"],
    "эмулятор": ["имитатор", "симулятор"],
    "эмуляция": ["соперничество", "конкуренция"],
    "эмустировать": ["веселить"],
    "эмфатический": ["эмоциональный", "выразительный"],
    "эн-меркар": ["энмеркар"],
    "энамелобласт": ["адамантобласт", "амелобласт"],
    "энантиоморфизм": ["хиральность"],
    "энантиосемия": ["внутрисловная антонимия"],
    "энантотоксин": ["энантин"],
    "энармон": ["энармоника"],
    "энармоника": ["энармон", "энгармоника", "энармония", "микрохроматика"],
    "энармония": ["энармоника"],
    "энбрикация": ["имбрикация"],
    "энвайронмент": ["инвайронмент"],
    "энвайронментализм": ["инвайронментализм"],
    "энгармонический": ["негармонический"],
    "энгельсина": ["геля"],
    "энгептин": ["азинитразол", "гистосепс", "гистомон", "дисамен", "меланокран", "нитрамин", "энтерамин"],
    "эндаумент": ["эндаумент-фонд"],
    "эндек": ["эпимелет", "номофилак"],
    "эндемик": ["эндем"],
    "эндемический": ["эндемичный"],
    "эндемичный": ["эндемический"],
    "эндимион": ["аполлон", "купидон", "адонис"],
    "эндо-": ["внутри-"],
    "эндоваскулярный": ["внутрисосудистый", "интраваскулярный"],
    "эндокард": ["эндокардий"],
    "эндокарпий": ["внутриплодник"],
    "эндокольпит": ["кольпит", "вагинит"],
    "эндокринная железа": ["железа внутренней секреции"],
    "эндоплазма": ["плазмазоль"],
    "эндоплазматический ретикулум": ["эпр"],
    "эндорфинный": ["эндорфиновый"],
    "эндоспорий": ["интина"],
    "эндотермность": ["теплокровность"],
    "эндотоксемия": ["эндогенная интоксикация"],
    "эндофауна": ["инфауна"],
    "эндоцервикс": ["цервикальный канал"],
    "эндоэтноним": ["самоназвание"],
    "эндшпиль": ["окончание"],
    "энебийлик": ["матриархат"],
    "эней": ["ойней", "иней"],
    "энеолит": ["халколит"],
    "энергетизировав": ["энергетизировавши"],
    "энергетизировавши": ["энергетизировав"],
    "энергетик": ["энергетический", "напиток"],
    "энергетическое перемирие": ["энергоперемирие"],
    "энергично": ["проворно", "расторопно", "деловито", "неутомимо", "живо", "резко", "решительно", "настойчиво"],
    "энергичный": ["деятельный", "активный", "напористый", "оживлённый"],
    "энергия": ["сила", "работоспособность", "энергичность", "быстрота"],
    "энергоград": ["электроград", "энергополис"],
    "энергоинформационный": ["биоэнергетический"],
    "энергокомплекс": ["энергоблок"],
    "энергомощность": ["электростанция"],
    "энергообследование": ["энергоаудит"],
    "энергооснащённость": ["энергообеспеченность"],
    "энергоотдача": ["энерговыделение", "энергопроизводительность", "энерговыработка", "энергопроизводство", "энергопоток", "энерговложение", "энергоэффективность"],
    "энергоперемирие": ["энергетическое перемирие"],
    "энергополис": ["энергоград", "электроград"],
    "энергопрограмма": ["энергетический", "программа"],
    "энергопроизводительность": ["энергоэффективность"],
    "энергосберегающий": ["энергоэффективный", "энергоэкономный"],
    "энергосбережение": ["энергоэффективность"],
    "энергосеть": ["энергетическая сеть", "силовая сеть", "энергетическая система"],
    "энергоснабжение": ["электроснабжение"],
    "энерготрасса": ["электротрасса"],
    "энергоуровень": ["достаточность", "количество", "объём", "оценка"],
    "энергоэффективный": ["энергосберегающий"],
    "энергоёмкость": ["энергозатратность"],
    "энзим": ["фермент"],
    "энзимология": ["ферментопатия"],
    "энзимопатия": ["ферментопатия"],
    "энигма": ["загадка", "тайна"],
    "энигматический": ["загадочный", "непонятный", "энигматичный"],
    "энигматичность": ["таинственность", "загадочность"],
    "энигматичный": ["загадочный", "таинственный", "энигматический"],
    "эниш": ["энис"],
    "энкаошка": ["нко"],
    "энки": ["эа", "хайя", "эйа"],
    "энли": ["элли"],
    "энмеркар": ["эн-меркар"],
    "эннеракт": ["октадекаиоттон"],
    "эноксидаза": ["фенолаза"],
    "энолог": ["винодел", "виноградарь", "дегустатор"],
    "энона": ["ойнона"],
    "энотека": ["коллекция вин", "винотека"],
    "энотера": ["ослинник"],
    "энотерапия": ["винолечение"],
    "энский": ["какой-то", "некий", "некоторый", "один"],
    "энсьерро": ["бег быков"],
    "энтальпийный": ["энтальпический"],
    "энтальпический": ["энтальпийный"],
    "энтальпия": ["теплосодержание", "тепловая функция"],
    "энтелехия": ["монада"],
    "энтерамин": ["серотонин"],
    "энтероадгезивный": ["энтероадгерентный"],
    "энтеробиоз": ["оксиуроз"],
    "энтерогепатит": ["гистомоноз"],
    "энтерокиназа": ["энтеропептидаза"],
    "энтеропатогенный": ["сальмонеллёзоподобный"],
    "энтероптоз": ["спланхноптоз", "висцероптоз"],
    "энтероскопия": ["интестиноскопия"],
    "энтеротриб": ["экразер"],
    "энтодерма": ["энтобласт"],
    "энтомолог": ["инсектолог"],
    "энтомология": ["инсектология"],
    "энтузиазм": ["воодушевление"],
    "энтузиаст": ["энтузазист", "фанат"],
    "энтузиастка": ["стахановка"],
    "энурез": ["энурезис"],
    "энхансер": ["максимайзер"],
    "энцефализация": ["церебрализация"],
    "энцефалограмма": ["электроэнцефалограмма"],
    "энциклопедист": ["полимат"],
    "энциклопедический": ["энциклопедичный"],
    "энциклоцитный": ["кольцоклетный"],
    "эо": ["электроотрицательность"],
    "эозинофил": ["ацидофильный гранулоцит"],
    "эокембрий": ["инфракембрий"],
    "эолийский": ["эолический"],
    "эолипил": ["машина", "шар"],
    "эон": ["этернитас", "зерван", "айон"],
    "эортология": ["праздниковедение"],
    "эосфор": ["фосфор", "венера", "люцифер"],
    "эпанафора": ["анаэпифора", "симплока"],
    "эпатаж": ["выходка"],
    "эпатировав": ["эпатировавши"],
    "эпатировавши": ["эпатировав"],
    "эпатировать": ["ошеломлять", "провоцировать", "шокировать"],
    "эпейрогенез": ["эпейрогенические движения"],
    "эпендима": ["эпендимный слой", "эпителий эпендимальный", "эпителий эпендимный"],
    "эпиблема": ["ризодерма"],
    "эпигейный": ["наземный", "напочвенный"],
    "эпигенема": ["биогеосфера", "фитогеосфера", "витасфера"],
    "эпигон": ["подражатель", "имитатор"],
    "эпигонский": ["несамостоятельный", "формальный", "школярский", "подражательный", "начётнический"],
    "эпигонство": ["подражательство", "приверженность"],
    "эпигонствовав": ["эпигонствовавши"],
    "эпигонствовавши": ["эпигонствовав"],
    "эпигонствовать": ["подражательствовать"],
    "эпиграмма": ["колкость", "острота", "язвительность", "насмешка"],
    "эпиграф": ["теглайн"],
    "эпидемический порог": ["эпидемпорог", "эпидпорог"],
    "эпидемичный": ["эпидемический"],
    "эпидемия": ["мор"],
    "эпидерма": ["эпидермис", "кожица"],
    "эпидермис": ["эпидерма", "кожица"],
    "эпидерсия": ["херня", "фигня", "абракадабра"],
    "эпидот": ["пистацит"],
    "эпидуральный": ["экстрадуральный"],
    "эпизод": ["происшествие", "событие", "случай"],
    "эпизодец": ["эпизодик"],
    "эпизодически": ["время от времени", "от случая к случаю", "нерегулярно"],
    "эпизоотология": ["ветеринарная эпидемиология", "эпизоотиология"],
    "эпикант": ["эпикантус"],
    "эпикантус": ["эпикант", "монгольская складка"],
    "эпикардий": ["эпикард"],
    "эпиклеза": ["эпиклесис", "эпиклеса"],
    "эпиклеса": ["эпиклеза"],
    "эпиконтинентальный": ["внутриплатформенный", "внутриматериковый", "прибрежный", "шельфовый"],
    "эпикуреец": ["сибарит", "гедонист"],
    "эпикуреизм": ["эпикурейство", "гедонизм"],
    "эпикурейство": ["эпикуреизм", "гедонизм"],
    "эпилепсия": ["падучая"],
    "эпилептический статус": ["эпистатус"],
    "эпилировав": ["эпилировавши"],
    "эпилировавши": ["эпилировав"],
    "эпилог": ["послесловие"],
    "эпиляция": ["депиляция"],
    "эпимастигота": ["эпимаст"],
    "эпимастиготный": ["критидиальный"],
    "эпимелет": ["эндек"],
    "эпимер": ["стереоизомер"],
    "эпинефрин": ["адреналин"],
    "эпиподий": ["зейгоподий"],
    "эпиприступ": ["эпилептический приступ", "эпилептический припадок"],
    "эпипроектор": ["эпископ"],
    "эпископ": ["эпипроектор"],
    "эпистиль": ["архитрав"],
    "эпистола": ["послание", "письмо", "записка"],
    "эпистолярный": ["письменный"],
    "эпистрофей": ["аксис"],
    "эпиталама": ["эпиталамий", "эпиталамион"],
    "эпиталамий": ["эпиталама"],
    "эпитеза": ["парагога"],
    "эпителиальная клетка": ["бокаловидная клетка"],
    "эпитимия": ["епитимья"],
    "эпитимпанум": ["аттик"],
    "эпитома": ["конспект"],
    "эпитр": ["послание", "письмо"],
    "эпифания": ["гамаф"],
    "эпифиз": ["шишковидная железа", "пинеальная железа"],
    "эпифитотия": ["эпифития"],
    "эпиценовый": ["общий"],
    "эпический": ["грандиозный"],
    "эпичный": ["эпический"],
    "эпоксидка": ["эпоксидная смола"],
    "эполет": ["эполета"],
    "эполета": ["эполет"],
    "эпос": ["эпика", "цикл"],
    "эпоха": ["эра", "период", "геологическая эпоха"],
    "эпохальность": ["значительность", "судьбоносность", "масштабность"],
    "эпохальный": ["великий", "поворотный"],
    "эпулид": ["наддесневик", "эпулис"],
    "эпулис": ["эпулид"],
    "эпы": ["миргын"],
    "эпюра": ["эпюр", "диаграмма"],
    "эра": ["система летосчисления", "летосчисление", "эпоха", "эон", "геологическая эра"],
    "эратема": ["геологическая группа", "фитема"],
    "эргативный падеж": ["эргатив"],
    "эргодический": ["эргодичный"],
    "эргодичный": ["эргодический"],
    "эргометрин": ["эргобазин", "эргоновин"],
    "эргономика": ["эргономия"],
    "эргостерол": ["эргостерин"],
    "эрготерапия": ["трудотерапия"],
    "эргофобия": ["эргазиофобия"],
    "эрджиес": ["эрджияс"],
    "эрджияс": ["эрджиес"],
    "эребуни": ["ереван", "эривань"],
    "эрегировав": ["эрегировавши"],
    "эрегировавши": ["эрегировав"],
    "эрегированный": ["возбуждённый"],
    "эрейтофобия": ["эритрофобия"],
    "эректор": ["выпрямитель"],
    "эрекция": ["стояк", "готовность"],
    "эресунн": ["зунд"],
    "эрехтей": ["эрехфей"],
    "эрехфей": ["эрехтей"],
    "эрец-исраэль": ["земля израильская", "земля обетованная", "святая земля"],
    "эрзац": ["заменитель", "суррогат", "субститут"],
    "эрзац-культура": ["псевдокультура"],
    "эрзурум": ["эрзерум", "арзерум"],
    "эрзя": ["эрзянин"],
    "эрзянин": ["эрзя"],
    "эрзянский": ["эрзянский язык"],
    "эрзянский язык": ["эрзянский"],
    "эривань": ["ереван"],
    "эриду": ["эреду", "эридуг", "урудуг"],
    "эриколин": ["арбутин"],
    "эринния": ["фурия", "эвменида", "мегера", "тизифона"],
    "эритрейское море": ["аравийское море"],
    "эритролейкоз": ["эритромиелоз", "эритролейкемия", "болезнь ди гульельмо"],
    "эритропоэтин": ["гемопоэтин"],
    "эритрофобия": ["эрейтофобия", "руброфобия", "симптом каспера"],
    "эритроцит": ["красное кровяное тельце"],
    "эритроцитолиз": ["гематолиз"],
    "эрих": ["эрх"],
    "эрка": ["нозпарвард"],
    "эркак": ["эркек"],
    "эрли": ["эрленьгянь"],
    "эрлифт": ["мамут-насос"],
    "эродировав": ["эродировавши"],
    "эродировавши": ["эродировав"],
    "эрозионный": ["эрозийный"],
    "эрос": ["эрот", "амур", "купидон"],
    "эрот": ["эрос", "амур", "купидон"],
    "эротизировав": ["эротизировавши"],
    "эротизировавши": ["эротизировав"],
    "эротизм": ["эротомания", "гамомания"],
    "эротика": ["чувственность", "сексуальность"],
    "эротичность": ["эротизм", "сексапильность", "сексуальность"],
    "эротомания": ["гиперсексуальность", "эротоманический бред", "эротоманный бред", "эротический бред"],
    "эрра": ["ирра"],
    "эрратив": ["какография"],
    "эрратические валуны": ["ледниковая эрратика"],
    "эрудированность": ["эрудиция", "начитанность"],
    "эрудит": ["всезнайка", "ходячая энциклопедия"],
    "эрудиция": ["учёность", "начитанность"],
    "эруптивный": ["эрупционный"],
    "эрупционный": ["эруптивный"],
    "эрь": ["эхярь"],
    "эрьгя": ["вий", "вииши"],
    "эрьхтемс": ["вачкодемс", "калтадемс", "чакодемс", "самс", "лисемс", "эвондамс", "появамс", "ляцемс", "пъргамс", "пъркштадемс"],
    "эрэс": ["реактивный снаряд"],
    "эрэфия": ["российская федерация"],
    "эряви": ["эрявикс"],
    "эрявкстомс": ["тумс", "ётамс"],
    "эряма": ["эряф"],
    "эрямс": ["эрямс эряфцень", "лисемс", "тиевомс", "улендемс", "эрсемс"],
    "эряф": ["эряма"],
    "эсав": ["ляхистан"],
    "эсватини": ["королевство эсватини", "свазиленд", "королевство свазиленд"],
    "эсватиниец": ["свазилендец"],
    "эсвэошник": ["свошник"],
    "эсдек": ["социал-демократ"],
    "эсер": ["социалист-революционер", "справоросс"],
    "эсерствовав": ["эсерствовавши"],
    "эсерствовавши": ["эсерствовав"],
    "эсик": ["эшик"],
    "эситив": ["эшитюв"],
    "эскадренный броненосец": ["додредноут"],
    "эскадренный миноносец": ["эсминец"],
    "эскадрон": ["шквадрон", "швадрон", "шкадрон"],
    "эскалативный": ["эскалационный"],
    "эскалация": ["увеличение", "рост", "расширение", "наращивание", "распространение", "обострение"],
    "эскалировав": ["эскалировавши"],
    "эскалировавши": ["эскалировав"],
    "эскалировать": ["увеличить", "усилить", "расширить", "усугубить"],
    "эскамотировав": ["эскамотировавши"],
    "эскамотировавши": ["эскамотировав"],
    "эскамотировать": ["присваивать", "присвоить", "скрывать", "скрыть"],
    "эскапада": ["эпатаж"],
    "эскапизм": ["эскепизм", "эскейпизм"],
    "эскарпировав": ["эскарпировавши"],
    "эскарпировавши": ["эскарпировав"],
    "эскейпизм": ["эскапизм", "эскепизм"],
    "эскепизм": ["эскапизм", "эскейпизм"],
    "эскер": ["оз"],
    "эскиз": ["набросок"],
    "эско": ["шельда"],
    "эскорт": ["конвой", "сопровождение"],
    "эскортировав": ["эскортировавши"],
    "эскортировавши": ["эскортировав"],
    "эскортница": ["эскорт-модель", "проститутка"],
    "эскроу": ["эскроу-счёт"],
    "эскроу-счёт": ["эскроу"],
    "эскулап": ["эскулапий", "асклепий"],
    "эскэр": ["аскэр"],
    "эслек": ["эсезонза", "эсьотям"],
    "эсминец": ["эскадренный миноносец"],
    "эспадрон": ["рапира"],
    "эспаньола": ["гаити"],
    "эспрессо": ["двойная половинка"],
    "эспри": ["перья"],
    "эссе": ["сочинение"],
    "эссенциализм": ["примордиализм", "субстанциализм"],
    "эссенция": ["квинтэссенция"],
    "эссив": ["изобразительный падеж"],
    "эста": ["снярда"],
    "эстакада": ["виадук", "путепровод"],
    "эстамп": ["гравюра", "оттиск"],
    "эстампи": ["эстампида"],
    "эстампида": ["эстампи"],
    "эстер": ["сложный эфир"],
    "эстерифицировав": ["эстерифицировавши"],
    "эстерифицировавши": ["эстерифицировав"],
    "эстет": ["гурман"],
    "эстетизировав": ["эстетизировавши"],
    "эстетизировавши": ["эстетизировав"],
    "эстетикотерапия": ["эстетотерапия"],
    "эстетический": ["художественный"],
    "эстетичный": ["изысканный", "живописный", "красивый", "прекрасный", "изящный"],
    "эстетный": ["красивый", "изящный", "эстетичный"],
    "эстетотерапия": ["эстетикотерапия"],
    "эстетствовав": ["эстетствовавши"],
    "эстетствовавши": ["эстетствовав"],
    "эстимация": ["оценка", "подсчёт"],
    "эстокиге": ["курок", "пяк курок"],
    "эстония": ["эстонская республика"],
    "эстонская республика": ["эстония"],
    "эстонская сср": ["эстония"],
    "эстрагон": ["тархун"],
    "эстрада": ["помост", "сцена", "варьете"],
    "эстрадиол": ["эстроген"],
    "эстремадурский": ["эстремадурский язык"],
    "эстрон": ["фолликулин"],
    "эструм": ["эструс", "течка"],
    "эструс": ["эструм", "течка"],
    "эсь мяльса": ["мяль вельде", "пара мяльса"],
    "эсэгэ": ["баабай"],
    "эсэмэсив": ["эсэмэсивши"],
    "эсэмэсивши": ["эсэмэсив"],
    "эсэмэска": ["смс"],
    "эсэнгешный": ["снговский", "эсэнговский", "эсэнгэвский"],
    "эта": ["ита"],
    "этаблировать": ["налаживать", "укреплять"],
    "этак": ["эдак", "так", "примерно", "приблизительно"],
    "этакий": ["такой", "эдакий"],
    "этакратия": ["этатократия"],
    "эталон": ["стандарт", "образец", "идеал"],
    "эталонировав": ["эталонировавши"],
    "эталонировавши": ["эталонировав"],
    "эталонирование": ["калибрование", "калибровка"],
    "этаналь": ["ацетальдегид"],
    "этановая кислота": ["уксусная кислота"],
    "этанол": ["этиловый спирт", "винный спирт", "метилкарбинол"],
    "этантиол": ["этилмеркаптан"],
    "этап": ["шаг", "стадия", "ступень"],
    "этапировав": ["этапировавши"],
    "этапировавши": ["этапировав"],
    "этапировать": ["отправлять по этапу"],
    "этатизировав": ["этатизировавши"],
    "этатизировавши": ["этатизировав"],
    "этен": ["этилен"],
    "этерист": ["гетерист"],
    "этерифицировав": ["этерифицировавши"],
    "этерифицировавши": ["этерифицировав"],
    "этернит": ["черепица"],
    "эти дни": ["критические дни"],
    "этизировав": ["этизировавши"],
    "этизировавши": ["этизировав"],
    "этика": ["ифика", "мораль", "нравственность"],
    "этикетировав": ["этикетировавши"],
    "этикетировавши": ["этикетировав"],
    "этикетирование": ["этикетировка"],
    "этикетировка": ["этикетирование"],
    "этикетка": ["ярлык", "бирка", "наклейка"],
    "этикетчица": ["этикетировщица"],
    "этиламин": ["аминоэтан"],
    "этилбромид": ["бромэтан"],
    "этилен": ["этен"],
    "этилендиаминтетрауксусная кислота": ["эдта"],
    "этиленимин": ["азиридин", "азациклопропан"],
    "этиленхлорид": ["винилхлорид", "хлористый винил", "хлорвинил", "хлорэтилен", "хлорэтен"],
    "этилия": ["волга"],
    "этилмеркаптан": ["этантиол"],
    "этилморфин": ["дионин"],
    "этиловый спирт": ["этанол"],
    "этимасия": ["престол уготованный", "етимасия"],
    "этимологизировав": ["этимологизировавши"],
    "этимологизировавши": ["этимологизировав"],
    "этимологичный": ["этимологический"],
    "этимология": ["правословие"],
    "этиолировав": ["этиолировавши"],
    "этиолировавши": ["этиолировав"],
    "этически": ["морально", "нравственно"],
    "этический": ["моральный", "нравственный"],
    "этичный": ["моральный"],
    "этничность": ["раса", "культура", "этническая идентичность"],
    "этнография": ["народоведение", "этнология"],
    "этнолингвистика": ["этносемантика"],
    "этнология": ["этнография", "народоведение"],
    "этнонимия": ["этнонимика"],
    "этнос": ["народ", "народность", "нация"],
    "этностереотип": ["национальный стереотип"],
    "этнохороним": ["этникон"],
    "это": ["именно", "же"],
    "это я понимаю": ["очень хорошо", "так и надо"],
    "этовав": ["этовавши"],
    "этовавши": ["этовав"],
    "этовать": ["этывать", "поэтовать"],
    "этот": ["сей", "данный", "энтот"],
    "этот свет": ["мир", "вселенная", "земля", "свет"],
    "этруск": ["тиррен", "туск"],
    "эублефар": ["эйблефар"],
    "эукариот": ["эвкариот"],
    "эукариоты": ["ядерные", "эвкариоты"],
    "эуриморфный": ["ширококостный", "эурисомный", "эврисомный", "брюшно-мускульный"],
    "эустресс": ["эвстресс"],
    "эуфиллин": ["аминофиллин"],
    "эуфониум": ["баритон"],
    "эуфоссилия": ["эвфоссилия"],
    "эухарис": ["амазонская лилия"],
    "эф": ["ферт"],
    "эфеб": ["отрок", "подросток", "юноша"],
    "эфебофилия": ["педофилия"],
    "эфебофобия": ["эфебифобия"],
    "эфедра": ["хвойник"],
    "эфедрон": ["меткатинон"],
    "эфемер": ["эфемерный организм"],
    "эфемерида": ["подёнка"],
    "эфемерность": ["мнимость", "нереальность", "призрачность"],
    "эфемерный": ["скоропреходящий", "непрочный", "мимолетный", "временный", "зыбкий", "мнимый", "воображаемый", "нереальный", "ирреальный", "иллюзорный", "кажущийся", "призрачный", "эфирный"],
    "эфенди": ["эффенди"],
    "эфес": ["ефес"],
    "эфиоп": ["абиссинец", "хабеша", "аксумит", "ефиоп", "ефиоплянин", "негр", "арап", "мурин", "арнаут", "басурман", "басурманин"],
    "эфиопия": ["абиссиния"],
    "эфиопка": ["абиссинка", "хабеша", "ефиоплянка", "негритянка", "арапка", "арнаутка", "басурманка"],
    "эфиопский": ["зулусский", "абиссинский"],
    "эфир": ["пятая стихия", "пятый элемент", "пятое тело", "диэтиловый эфир", "серный эфир"],
    "эфирномасличный": ["эфиромасличный"],
    "эфирномасляный": ["эфиромасличный"],
    "эфирный океан": ["воздушный океан"],
    "эфиромасличный": ["эфирномасличный"],
    "эфод": ["ефод"],
    "эффект вериго-бора": ["эффект вериго"],
    "эффективность": ["действенность", "результативность"],
    "эффективный": ["действенный", "результативный", "равноэффективный", "аналогичный"],
    "эффектировав": ["эффектировавши"],
    "эффектировавши": ["эффектировав"],
    "эффектничав": ["эффектничавши"],
    "эффектничавши": ["эффектничав"],
    "эффектно": ["великолепно", "впечатляюще"],
    "эффектор": ["эффекторный терминал", "эффекторный синапс"],
    "эффералган": ["парацетамол"],
    "эфферентный": ["относящий", "центробежный", "двигательный"],
    "эффузия": ["фильтрация"],
    "эфэсбэшный": ["фээсбэшный"],
    "эхав": ["эхавши"],
    "эхавши": ["эхав"],
    "эхинопс": ["мордовник"],
    "эхма": ["эх"],
    "эхнув": ["эхнувши"],
    "эхнувши": ["эхнув"],
    "эхо": ["отзвук", "отголосок", "отклик"],
    "эхо-кардиограф": ["эхокардиограф"],
    "эхограмма": ["батиграмма"],
    "эхограф": ["сонар"],
    "эхография": ["узи"],
    "эхокардиограмма": ["экг"],
    "эхокардиограф": ["эхо-кардиограф"],
    "эхокинезия": ["эхокинез", "эхопраксия"],
    "эхолалия": ["эхофразия"],
    "эхопраксия": ["эхокинез", "эхокинезия"],
    "эхосигнал": ["эхо-сигнал"],
    "эхофразия": ["эхолалия"],
    "эхярь": ["цебярь", "пара"],
    "эчке": ["куя", "покаряв"],
    "эчмиадзин": ["вагаршапат"],
    "эчпочмак": ["учпочмак"],
    "эшафот": ["плаха", "лобное место"],
    "эшек": ["неудача", "провал"],
    "эшелон": ["состав", "поезд", "уровень"],
    "эшелонировав": ["эшелонировавши"],
    "эшелонировавши": ["эшелонировав"],
    "эшик": ["эсик"],
    "эшитюв": ["эситив", "эшитив"],
    "эшлексез": ["ялкау"],
    "эшник": ["цэпээшник"],
    "эштафета": ["эстафета"],
    "эшяк": ["эсэк", "эшек", "эшэк"],
    "эътибор": ["нуфуз"],
    "эътиборнок": ["бонуфуз"],
    "эякулировав": ["эякулировавши"],
    "эякулировавши": ["эякулировав"],
    "эякулят": ["сперма", "семенная жидкость"],
    "эякуляция": ["семяизвержение", "семяизлияние"],
    "юао": ["южный административный округ"],
    "юар": ["южная африка", "южно-африканская республика"],
    "юас": ["южная африка", "южно-африканский союз"],
    "юбея": ["слоновая пальма"],
    "юбк": ["южный берег", "юбка"],
    "юбка": ["баба"],
    "юбочник": ["бабник", "волокита", "донжуан", "женолюб", "кобель", "ловелас", "любезник", "повеса", "селадон"],
    "юбчонка": ["юбочка"],
    "ювао": ["юго-восточный административный округ"],
    "ювелир": ["мастер", "искусник"],
    "ювенальный": ["ювенильный", "неполовозрелый", "юношеский", "подростковый"],
    "ювенальщик": ["ювенальник"],
    "ювенильный": ["ювенальный"],
    "ювукъ": ["дост", "ёлдаш", "къурдаш"],
    "юг": ["конфедеративные штаты америки", "конфедеративные штаты", "конфедерация", "кша"],
    "югендстиль": ["ар-нуво", "либерти", "модерн"],
    "юго-восток": ["зюйд-ост"],
    "юго-восточная азия": ["юва"],
    "юго-восточный": ["зюйд-остовый"],
    "юго-восточный административный округ": ["ювао"],
    "юго-запад": ["зюйд-вест"],
    "юго-западный административный округ": ["юзао"],
    "югославия": ["ксхс", "королевство схс", "королевство югославия", "демократическая федеративная югославия", "дфю", "фнрю", "сфрю", "союзная республика югославия", "срю"],
    "югъ": ["зюйдъ", "полдень"],
    "юдаизм": ["иудаизм", "гебраизм", "ивритизм", "идишизм"],
    "юденфрай": ["юденрейн"],
    "юдзу": ["юнос", "юзу"],
    "юдоль": ["лог", "разлог", "дол", "долина", "удол", "раздол", "раздолие", "юдолие"],
    "юдоль плача": ["юдоль плача и скорбей", "юдоль скорби", "юдоли скорби и печали", "юдоль печалей и скорбей", "юдоль слёз", "юдоль земная"],
    "юдофилия": ["юдофильство", "филосемитизм"],
    "юдофильство": ["юдофилия"],
    "юдофильствовав": ["юдофильствовавши"],
    "юдофильствовавши": ["юдофильствовав"],
    "юдофоб": ["антисемит"],
    "юдофобия": ["антисемитизм", "юдофобство"],
    "юдофобство": ["юдофобия", "антисемитизм"],
    "юдофобствовав": ["юдофобствовавши"],
    "юдофобствовавши": ["юдофобствовав"],
    "юдырык": ["юмырык"],
    "юеш": ["дымлы", "сулы"],
    "южав": ["южавши"],
    "южавши": ["южав"],
    "южанка": ["южаночка"],
    "южная корея": ["республика корея"],
    "южная осетия": ["республика южная осетия", "юо", "рюо"],
    "южно-африканская республика": ["юар", "южная африка", "азания"],
    "южно-африканский": ["южноафриканский"],
    "южно-африканский союз": ["юас", "южная африка"],
    "южно-сахалинск": ["южный"],
    "южно-сахалинский": ["карафутский", "южанский"],
    "южноафриканец": ["юаровец"],
    "южное": ["южный"],
    "южнокоммунаровск": ["бунге"],
    "южноминьский": ["минь-нань"],
    "южноминьский диалект": ["южноминьский язык", "миньнань", "хокло"],
    "южноминьский язык": ["южноминьский диалект", "миньнань", "хокло"],
    "южноосетинский": ["югоосетинский"],
    "южносахалинск": ["южно-сахалинск", "южный"],
    "южносахалинский": ["южно-сахалинский"],
    "южный": ["южное", "южно-сахалинск"],
    "южный административный округ": ["юао"],
    "южный буг": ["буг"],
    "южный вьетнам": ["государство вьетнам", "республика вьетнам", "республика южный вьетнам"],
    "южный камерун": ["западный камерун", "амбазония"],
    "южный ледовитый океан": ["южный океан"],
    "южный океан": ["антарктический океан", "южный ледовитый океан"],
    "юзабельность": ["практичность", "юзабилити"],
    "юзав": ["юзавши"],
    "юзавши": ["юзав"],
    "юзаный": ["использованный"],
    "юзанье": ["использование", "применение"],
    "юзао": ["юго-западный административный округ"],
    "юзать": ["использовать", "применять", "пользоваться"],
    "юзверь": ["юзверг", "ламер"],
    "юзер": ["пользователь"],
    "юзербокс": ["шаблон участника"],
    "юзерпик": ["ава", "аватар", "аватара", "аватарка", "авка"],
    "юзжав": ["юзжавши"],
    "юзжавши": ["юзжав"],
    "юзив": ["юзивши"],
    "юзивши": ["юзив"],
    "юзина": ["електроцентрала", "електрическа централа"],
    "юзкейс": ["сценарий использования", "вариант использования"],
    "юзо-лента": ["юзолента"],
    "юзовка": ["донецк", "сталино"],
    "юзу": ["юдзу"],
    "юй-мао-цю": ["бадминтон", "юй-мао-чю"],
    "юй-мао-чю": ["бадминтон", "юй-мао-цю"],
    "юк": ["южная корея", "республика корея", "рк", "юридическая компания", "юридическая фирма"],
    "юкагир": ["вадул"],
    "юкоз": ["укоз"],
    "юкозский": ["юкозовский"],
    "юла": ["волчок"],
    "юлд": ["илд"],
    "юлиан": ["ульян"],
    "юлианович": ["юлианыч"],
    "юлив": ["юливши"],
    "юливши": ["юлив"],
    "юлить": ["вертеться", "крутиться", "суетиться", "вертеть", "крутить", "лебезить", "заискивать", "угодничать", "пресмыкаться", "подлизываться", "подхалимничать", "изворачиваться", "увиливать", "ловчить", "хитрить"],
    "юлия": ["юля"],
    "юлозить": ["елозить", "ёрзать"],
    "юморив": ["юморивши"],
    "юморивши": ["юморив"],
    "юморина": ["квн", "юморины"],
    "юморист": ["комик", "сатирик", "весельчак", "приколист"],
    "юмористка": ["потешница", "шутница", "хохмачка", "острячка"],
    "юморной": ["юмористичный", "смешной", "забавный", "потешный", "прикольный"],
    "юморок": ["юмор"],
    "юмырык": ["юдырык"],
    "юнакиня": ["героиня"],
    "юнга": ["морячок"],
    "юнгштурм": ["юнгштурмовка"],
    "юнев": ["юневши"],
    "юневши": ["юнев"],
    "юнец": ["молокосос"],
    "юникод": ["уникод"],
    "юнионист": ["унионист"],
    "юнифа": ["униформа"],
    "юница": ["девица", "девушка", "молодка", "телица", "тёлка"],
    "юнкер": ["помещик", "землевладелец", "курсант", "кадет", "подпрапорщик", "вольноопределяющийся"],
    "юнкерствовав": ["юнкерствовавши"],
    "юнкерствовавши": ["юнкерствовав"],
    "юннатка": ["натуралистка", "естествоиспытательница"],
    "юннатовский": ["юннатский"],
    "юннатский": ["юннатовский"],
    "юнона": ["луцина", "соспита", "сиспита", "календария", "румина", "фульгура", "монета", "оссипага"],
    "юнос": ["юдзу"],
    "юноша": ["парень", "молодой человек", "пацан", "малый", "вьюнош", "вьюноша", "молчел", "молодой чемодан"],
    "юношествовав": ["юношествовавши"],
    "юношествовавши": ["юношествовав"],
    "юный": ["молодой", "незрелый", "юношеский", "ювенильный"],
    "юный натуралист": ["юннат", "юннатка"],
    "юпитер": ["софит"],
    "юпка": ["юбка"],
    "юра": ["юрский период"],
    "юрага": ["пахта", "пахтанье"],
    "юрген": ["георг"],
    "юрец": ["юрий", "юра", "юрик", "юрка", "юрчик"],
    "юри": ["сёдзё-ай"],
    "юридически": ["де-юре", "официально"],
    "юридический": ["правовой"],
    "юридический центр": ["правовой центр"],
    "юридическое лицо": ["юл", "юрлицо", "юрик"],
    "юриит": ["космохлор", "крейит"],
    "юрий": ["юра", "георгий", "егор"],
    "юрик": ["юридическое лицо", "юрлицо"],
    "юрисдикция": ["правомочие", "подсудность"],
    "юрисконсультствовав": ["юрисконсультствовавши"],
    "юрисконсультствовавши": ["юрисконсультствовав"],
    "юрислингвистика": ["лингвокриминалистика", "судебное речеведение"],
    "юрислингвистический": ["лингвокриминалистический", "судебно-речеведческий"],
    "юриспруденция": ["правоведение"],
    "юрист": ["правовед"],
    "юрка": ["юра", "юрий", "юрец", "юрик", "юрчик"],
    "юркав": ["юркавши"],
    "юркавши": ["юркав"],
    "юркий": ["увёртливый", "проворный", "быстрый", "подвижный", "живой", "ловкий", "пронырливый"],
    "юркнув": ["юркнувши"],
    "юркнувши": ["юркнув"],
    "юркнуть": ["прошмыгнуть", "шмыгнуть"],
    "юркость": ["прыткость"],
    "юрлицо": ["юридическое лицо", "юрик"],
    "юрод": ["юродивый"],
    "юродивый": ["безумный", "ненормальный", "сумасшедший", "чудаковатый", "чокнутый", "больной на голову", "не в себе", "с приветом", "с придурью", "безумец", "дурачок", "псих", "блаженный", "юрод", "изумок"],
    "юродливый": ["безумный"],
    "юродствовав": ["юродствовавши"],
    "юродствовавши": ["юродствовав"],
    "юрский период": ["юра"],
    "юрчик": ["юрий", "юра", "юрик", "юрец"],
    "юрьев-польский": ["юрьев-польской"],
    "юрьев-польской": ["юрьев-польский"],
    "юрьевич": ["юриевич"],
    "юсиа": ["информационное агентство сша"],
    "юстирный": ["юстировальный"],
    "юстировав": ["юстировавши"],
    "юстировавши": ["юстировав"],
    "юстировальный": ["юстирный"],
    "юстировщик": ["настройщик", "наладчик"],
    "юстиция": ["правосудие", "право"],
    "ют": ["корма"],
    "ютив": ["ютивши"],
    "ютивши": ["ютив"],
    "ютить": ["охранять", "защищать", "оберегать", "сберегать", "скрывать", "прятать", "давать кров", "давать пристанище", "давать приют", "приючать"],
    "ютиться": ["жаться", "тесниться"],
    "юфта": ["юфть", "юхта"],
    "юфтевый": ["юфтяной", "юхтовый"],
    "юфтовый": ["юфтевый", "юхтовый", "юфтяной"],
    "юфть": ["юфта", "юхта"],
    "юфтяной": ["юфтевый"],
    "юхта": ["юфть", "юхть"],
    "юхтовый": ["юфтевый"],
    "юшар": ["ящик"],
    "юшка": ["бульон", "навар", "отвар", "похлёбка", "баланда", "уха", "ушица", "юха", "кровь", "кровушка"],
    "юэ": ["гуандунский", "язык", "кантонский", "юэский"],
    "юэчжи": ["ятии", "яду"],
    "ююба": ["зизифус", "унаби", "китайский финик"],
    "я люблю тебя": ["я тебя люблю"],
    "я сказал": ["кому говорят", "кому сказал"],
    "я те дам": ["ай да ну"],
    "я упала с сеновала": ["взрыв на макаронной фабрике", "я у мамы дурочка", "не одна я поле кувыркалась", "кононенкино кубло"],
    "ябав": ["ябавши"],
    "ябавши": ["ябав"],
    "ябеда": ["донос", "извет", "клевета", "кляуза", "напраслина", "оговор", "поклёп", "доносительство", "ябедничество", "ябедничание", "ябедничанье", "наушничество", "наушничание", "наушничанье", "стукачество"],
    "ябедник": ["доносчик", "наушник", "жалобщик", "сутяга", "крючкотвор"],
    "ябедница": ["доносчица"],
    "ябедничав": ["ябедничавши"],
    "ябедничавши": ["ябедничав"],
    "ябедничание": ["ябедничанье"],
    "ябедничать": ["наушничать", "фискалить", "капать", "кляузничать", "доносить", "стучать", "заявлять", "сигнализировать"],
    "ябиру": ["бразильский ябиру", "седлоклювый ябиру"],
    "ябко": ["яблуко"],
    "яблоневый": ["яблочный"],
    "яблонь": ["яблоня"],
    "яблоня": ["яблонь"],
    "яблочко": ["яблоко", "цель"],
    "яблочная кислота": ["оксиянтарная кислота", "гидроксибутандиовая кислота", "малат", "малоновая кислота"],
    "яблочный спас": ["спас", "второй спас", "великий спас", "средний спас", "спас на горе", "преображение господне", "преображение"],
    "яблуко": ["ябко"],
    "яблунина": ["яблуня"],
    "яблуня": ["яблунина"],
    "яблучко": ["яблуко", "гал"],
    "яв": ["ява"],
    "яванский": ["явский", "яванский язык"],
    "яведрик": ["явида", "чорт"],
    "явив": ["явивши"],
    "явивши": ["явив"],
    "явида": ["яведрик", "чорт"],
    "явить": ["обнаружить", "показать", "проявить"],
    "явиться": ["появиться", "показаться", "возникнуть", "прийти", "прибыть", "предстать", "стать", "оказаться", "явить собой"],
    "явка": ["явление", "появление"],
    "явкання": ["нявкання"],
    "явкати": ["нявкати"],
    "явление": ["явленье"],
    "явленний": ["явлений"],
    "явленность": ["эйдос", "сущность"],
    "явлення": ["поява"],
    "явленье": ["явление"],
    "явлинец": ["яблочник"],
    "являв": ["являвши"],
    "являвши": ["являв"],
    "являть": ["показывать", "обнаруживать", "представлять", "являться"],
    "являться": ["возникать", "представать", "приходить", "прибывать", "быть", "оказываться"],
    "являясь": ["будучи", "возникая", "показываясь", "появляясь", "обнаруживаясь", "приходя", "заявляясь", "прибывая"],
    "явность": ["очевидность", "открытость", "эксплицитность"],
    "явный": ["очевидный", "открытый", "неприкрытый", "несомненный", "ясный", "откровенный", "нескрываемый", "эксплицитный"],
    "яволь": ["да", "конечно", "разумеется", "слушаться", "так точно", "хорошо", "непременно", "безусловно"],
    "явор": ["ложноплатановый клён", "псевдоплатановый клён"],
    "явственно": ["отчётливо", "внятно", "определённо"],
    "явственный": ["заметный", "явный", "ощутимый"],
    "явствовав": ["явствовавши"],
    "явствовавши": ["явствовав"],
    "явствовать": ["следовать", "вытекать"],
    "явши": ["яв"],
    "явь": ["настоящее", "сущее", "идущее", "свершающееся"],
    "яга": ["баба-яга"],
    "ягав": ["ягавши"],
    "ягавши": ["ягав"],
    "ягайло": ["ягелло"],
    "ягдташный узел": ["квадратный узел", "охотничий узел", "соломонов узел", "соломонова петля", "оттянутая петля"],
    "ягелло": ["ягайло"],
    "ягель": ["олений мох"],
    "ягниться": ["объягняться", "котиться"],
    "ягня": ["ягнёнок", "барашек", "овечка", "агнец", "агница"],
    "ягнятник": ["бородач"],
    "ягнёнок": ["агнец", "барашек"],
    "ягодица": ["афедрон", "зад", "седалище", "сидальница", "попа", "жопа", "жопка", "жопочка", "попка", "попец", "попочка", "попца", "попунчик", "бздея", "гузло"],
    "ягодник": ["вакциниум"],
    "ягодничав": ["ягодничавши"],
    "ягодничавши": ["ягодничав"],
    "ягодовидный": ["ягодообразный"],
    "ягодообразный": ["ягодовидный"],
    "ягодянка": ["черешнянка"],
    "ягуарёнок": ["детёныш", "ягуар"],
    "ягулев": ["яглон", "яглион"],
    "ягур": ["лепеха", "лепеха звичайна", "шувар", "шавар"],
    "ягурт": ["йогурт", "югурт"],
    "яд": ["отрава", "токсин", "зло", "вред", "злобность", "насмешка", "глумление"],
    "ядай": ["адай", "дай"],
    "ядвига": ["гедвига", "хедвига", "хедвиг"],
    "ядеречко": ["ядерце"],
    "ядерка": ["ядерное оружие"],
    "ядерная война иксов": ["война иксов"],
    "ядерная дубина": ["атомное оружие", "ядерное оружие"],
    "ядерник": ["ядерщик"],
    "ядерное оружие": ["атомное оружие"],
    "ядерное разоружение": ["денуклеаризация"],
    "ядерное эффективное сечение": ["эффективное сечение ядра", "ядерное сечение реакции", "микроскопическое сечение реакции"],
    "ядерный синтез": ["термоядерный синтез"],
    "ядерный электорат": ["базовый электорат"],
    "ядерце": ["ядеречко"],
    "ядерщик": ["атомщик", "физик-ядерщик"],
    "ядовитый": ["токсичный", "отравляющий", "вредный", "опасный"],
    "ядовитый гриб": ["несъедобный гриб"],
    "ядренев": ["ядреневши"],
    "ядреневши": ["ядренев"],
    "ядрище": ["нуклеус"],
    "ядро": ["сердцевина", "основа", "движок", "нуль-пространство", "яйца", "ятра", "мудо", "муде", "мудя"],
    "ядрышко": ["ядро", "шарик"],
    "ядрён батон": ["япона вошь", "ядрёна мать", "японский городовой", "ядрёна бомба"],
    "ядрёна вошь": ["ядрёна мать", "ядрёна матрена", "так твою мать"],
    "ядрёна репа": ["едрёна репа"],
    "яечня": ["яешня"],
    "яешня": ["яечня"],
    "яжемать": ["яжмать", "мамашка", "овуляшка"],
    "яжмать": ["яжемать", "яжбатя"],
    "язва": ["рана", "болезнь", "мор", "зло", "вред", "порок"],
    "язвив": ["язвивши"],
    "язвивши": ["язвив"],
    "язвина": ["язва", "выбоина", "щербина", "нора"],
    "язвинка": ["выбоинка", "щербинка", "язвочка"],
    "язвительно": ["колко", "насмешливо", "саркастически", "ядовито"],
    "язвительность": ["сарказм", "насмешливость", "желчность", "ехидность"],
    "язвительный": ["колкий", "саркастический", "ядовитый", "насмешливый", "ехидный", "едкий", "злоехидный", "злоречивый", "остроязыкий", "сардонический", "злоязычный", "остроязычный", "желчный", "сатиричный"],
    "язвить": ["насмехаться", "укалывать", "подкалывать", "иронизировать", "ранить", "уязвлять", "причинять боль", "мучить"],
    "язвление": ["насмехание", "насмешка", "подкалывание", "поражение", "ранение", "уязвление", "мучительство"],
    "язвочка": ["язвица"],
    "яздон": ["худо", "парвардигор", "изад", "эзид"],
    "язевина": ["язевое мясо", "язина"],
    "язид": ["йезид", "езид"],
    "язидит": ["йазидит"],
    "язина": ["язевина", "язевое мясо"],
    "язицтво": ["язичество"],
    "язичество": ["язичництво"],
    "язичництво": ["язичество"],
    "язна": ["домод", "амак"],
    "язон": ["ясон"],
    "языг": ["ясыг", "яс", "язамат"],
    "язык": ["переводчик", "проводник", "толмач"],
    "язык вражды": ["хейтспич"],
    "язык проглотить": ["прикусить язык", "закусить язык", "набрать воды в рот", "пальчики оближешь"],
    "языкоблудствовав": ["языкоблудствовавши"],
    "языкоблудствовавши": ["языкоблудствовав"],
    "языковая группа": ["речевая группа", "языковой коллектив"],
    "языковая единица": ["единица языка"],
    "языковед": ["лингвист"],
    "языковедение": ["лингвистика", "языкознание"],
    "языковедный": ["языковедческий"],
    "языковедческий": ["языковедный"],
    "языковидный": ["языкообразный"],
    "языковой": ["лингвистический", "вербальный", "словесный"],
    "языковый": ["язычный"],
    "языкознание": ["лингвистика", "языковедение", "языкознанье"],
    "языкознанье": ["языкознание", "лингвистика", "языковедение", "языковеденье"],
    "языкотворческий": ["лингвокреативный"],
    "язычество": ["идолопоклонство", "этническая религия"],
    "язычковый": ["увулярный"],
    "язычник": ["политеист", "многобожец"],
    "язычница": ["политеистка", "идолопоклонница"],
    "язычничав": ["язычничавши"],
    "язычничавши": ["язычничав"],
    "яик": ["урал"],
    "яиц нет": ["яиц нету", "без яиц"],
    "яичко": ["тестикула", "семенник", "ятро", "тестис", "яйцо"],
    "яичница": ["яишница", "яичня", "яишня", "яишенка", "неразбериха"],
    "яичница по-морскому": ["яичница по-флотски"],
    "яичница по-флотски": ["яичница по-морскому"],
    "яичница-глазунья": ["глазунья", "яичница", "яишница", "глазуха", "глазастая яичница", "яичня", "яишня", "яишенка"],
    "яишенка": ["яичница", "яишница", "яичня", "яишня"],
    "яишница": ["яичница", "яичня", "яишня", "яишенка"],
    "яишня": ["яичница"],
    "яйки": ["мошонка", "яйца", "яйцы", "яицы", "муди", "муды", "мудя", "шары", "яичница"],
    "яйко": ["яйцо"],
    "яйца задницу не учат": ["яйца курицу не учат", "хвост голове не указка", "голова у ног ума не просит", "не учи учёного", "не учи отца ебаться"],
    "яйца курицу не учат": ["хвост голове не указка", "голова у ног ума не просит", "не учи учёного", "яйца задницу не учат", "не учи отца ебаться"],
    "яйцастый": ["мудастый", "мудястый"],
    "яйце-": ["оо-", "ово-"],
    "яйце-мясной": ["яично-мясной"],
    "яйцевидно": ["яйцеобразно"],
    "яйцевидный": ["овальный", "эллипсообразный"],
    "яйцевод": ["маточная труба"],
    "яйцеголовый": ["заумный", "мудрёный", "башковитый", "головастый", "ботаник", "интеллектуал"],
    "яйцеклетка": ["ооцит", "овоцит"],
    "яйценосный холмик": ["яйценосный бугорок"],
    "яйцеобразно": ["яйцевидно"],
    "яйцеобразный": ["яйцевидный", "яйцеподобный"],
    "яйцеродный": ["яйцекладущий"],
    "яйцесортировальный": ["яйцесортировочный"],
    "яйцо": ["ооцит", "эллипсоид", "овоид"],
    "яйцовый": ["яйцевой"],
    "яйчоночки": ["яйчонки", "тестикула", "половой член"],
    "як": ["тибетский бык", "хрюкающий бык"],
    "якав": ["якавши"],
    "якавши": ["якав"],
    "якамара": ["блестянка", "жакамар"],
    "якамс": ["люкамс", "шерьхкомс", "молемс"],
    "якание": ["яканье"],
    "який": ["котрий"],
    "яким": ["иаким", "еким", "аким", "иоаким"],
    "якнув": ["якнувши"],
    "якнувши": ["якнув"],
    "яко": ["как", "подобно", "словно", "точно", "точь-в-точь", "на подобие", "вроде", "будучи", "в качестве", "оттого что", "поскольку", "потому что", "так как", "ако", "ибо"],
    "яко тать в нощи": ["украдкой", "незаметно", "исподтишка"],
    "якобинец": ["бунтарь", "революционер", "вольнодумец"],
    "якобинизм": ["якобинство"],
    "якобит": ["тори"],
    "якобы": ["будто", "как будто"],
    "яков": ["иаков"],
    "якорив": ["якоривши"],
    "якоривши": ["якорив"],
    "якорь": ["ротор"],
    "яксарт": ["силис", "сырдарья"],
    "якум": ["аввал"],
    "якуп": ["якуб"],
    "якутия": ["республика саха"],
    "якутка": ["якутянка"],
    "якутский": ["якутский язык"],
    "якутянка": ["якутка"],
    "якшаться": ["знаться", "водить знакомство", "водить компанию"],
    "ял": ["ялик"],
    "ялан": ["дала"],
    "ялбуз": ["эльбрус"],
    "ялганларга": ["алдашырга"],
    "ялик": ["ял"],
    "ялинка": ["ялиночка"],
    "ялиновий": ["смерековий"],
    "ялиночка": ["ялинка"],
    "яловев": ["яловевши"],
    "яловевши": ["яловев"],
    "яловица": ["яловка"],
    "яловичный": ["яловочный"],
    "яловка": ["нетель", "яловица"],
    "яловочный": ["яловичный"],
    "ялхийтта": ["ялхитта"],
    "ялхитта": ["ялхийтта"],
    "ям": ["ямская слобода", "почта", "почтовая станция", "почтовый стан", "гон", "перемена", "станок"],
    "яма": ["углубление", "впадина", "низина", "провал", "выемка"],
    "ямайский креольский язык": ["патуа"],
    "ямало-ненецкий автономный округ": ["янао"],
    "ямалский": ["ямальский"],
    "ямальский": ["ямалский"],
    "яман": ["насар"],
    "ямник": ["погреб", "подвал"],
    "ямпец": ["стиляга"],
    "ямчатость": ["выщербленность"],
    "ямчатый": ["выщербленный"],
    "ямчуг": ["селитра", "ямчуга", "емчуг", "емчук"],
    "ямщик": ["извозчик", "кучер", "возница", "почтарь"],
    "ямщиковав": ["ямщиковавши"],
    "ямщиковавши": ["ямщиковав"],
    "ямщичив": ["ямщичивши"],
    "ямщичивши": ["ямщичив"],
    "ямщичничав": ["ямщичничавши"],
    "ямщичничавши": ["ямщичничав"],
    "ямьле": ["матур"],
    "ямьсез": ["шыксыз"],
    "яна": ["яночка", "яся", "янка", "яська", "янина"],
    "янао": ["ямало-ненецкий автономный округ"],
    "январь": ["генварь"],
    "янгол": ["ангел"],
    "яндексовав": ["яндексовавши"],
    "яндексовавши": ["яндексовав"],
    "яндере": ["яндэрэ"],
    "яндова": ["ендова"],
    "яндэрэ": ["яндере"],
    "янина": ["яна"],
    "янки": ["американец", "америкос", "пиндос", "гринго"],
    "янтарны": ["бурштынавы"],
    "янтарный": ["золотисто-жёлтый"],
    "янтарь": ["алатырь", "илектр", "сукцинит"],
    "януарий": ["ианнуарий"],
    "яо": ["минь", "мань"],
    "яой": ["сёнэн-ай", "яойчик"],
    "япанча": ["епанча"],
    "япон": ["японец"],
    "япона мать": ["ёшкин кот"],
    "японист": ["японовед"],
    "японистика": ["японоведение"],
    "япония": ["страна восходящего солнца", "японская империя", "ниппон"],
    "японо-российский": ["российско-японский", "японско-российский"],
    "японовед": ["японист"],
    "японоведение": ["японистика"],
    "японский городовой": ["бляха-муха", "ёпрст", "ёксель-моксель", "ёшкин кот", "японский магнитофон", "япона мать"],
    "японский разведчик": ["китайский разведчик", "японский шпион", "китайский шпион"],
    "японский шпион": ["китайский шпион", "китайский разведчик", "японский разведчик"],
    "японское море": ["корейское море", "восточное море", "восточно-корейское море"],
    "яппи": ["метросексуал", "мажор", "денди", "карьерист"],
    "яр": ["овраг", "лощина", "балка"],
    "ярадан": ["танъры", "алла", "худа", "рабби", "мевля", "илях", "чалап"],
    "яралырга": ["туарга"],
    "яранга": ["вигвам", "чум"],
    "ярга": ["свастика"],
    "ярем": ["ярмо", "хомут", "бремя", "тяжесть", "иго", "рабство", "неволя"],
    "яремный": ["подъяремный", "яремоносный", "впрягальный", "упряжной", "упряжный", "рабочий", "подневольный", "рабский", "угнетённый", "порабощённый", "мучительный", "тягостный", "тяжкий"],
    "ярив": ["яривши"],
    "яривши": ["ярив"],
    "ярило": ["ярила"],
    "яриться": ["сердиться", "серчать", "дуться", "злиться", "гневаться", "выходить из себя", "беситься", "разъяряться", "доводить до белого каления", "рвать и метать", "бушевать", "неистовствовать", "свирепствовать", "безумствовать", "бесноваться"],
    "яркий": ["сияющий", "сверкающий", "светлый", "резкий", "кричащий", "выделяющийся", "ясный", "заметный", "неординарный", "выдающийся", "блестящий"],
    "ярко": ["светло"],
    "ярко выраженный": ["типичный"],
    "ярко-жёлтый": ["канареечный", "канареечно-жёлтый"],
    "ярко-красный": ["алый", "яркокрасный"],
    "ярко-пурпуровый": ["ярко-пурпурный", "фиолетово-ярко-красный"],
    "ярко-синий": ["васильковый"],
    "ярковато": ["пестровато"],
    "ярковатый": ["пестроватый"],
    "ярлык": ["бирка", "этикетка", "грамота", "стереотип"],
    "ярмо": ["хомут", "ярем", "бремя", "тяжесть", "иго", "рабство", "якорь"],
    "яро": ["неистово", "рьяно", "страстно", "яростно"],
    "яровизировав": ["яровизировавши"],
    "яровизировавши": ["яровизировав"],
    "ярозит": ["ютаит"],
    "ярослав": ["иарослав"],
    "ярослава": ["яся", "ярославна", "ярославка", "слава", "славка", "рося"],
    "ярославка": ["ярославна"],
    "ярославль": ["ярик"],
    "ярославна": ["ярославовна"],
    "ярославович": ["ярославич"],
    "ярославская область": ["ярославия", "ярославщина"],
    "яростно": ["ожесточённо", "злобно", "озлобленно", "энергично", "возбуждённо"],
    "яростный": ["бешеный", "неистовый", "неукротимый"],
    "ярты": ["ярым"],
    "яруга": ["лог", "яр"],
    "ярус": ["ряд", "слой", "уровень", "геологический ярус", "пласт", "страта"],
    "ярусолов": ["ярусник"],
    "ярхцамс": ["поремс", "сускомс"],
    "ярхцамс-симомс": ["симомс-ярхцамс"],
    "ярыга": ["ерыга", "ярыжка", "ярыжный человек", "ярыжник", "пьяница", "пропойца", "бражник", "винопийца", "пьянь", "пьянь беспробудная", "пьянь беспросветная", "голь кабацкая", "беспутник", "развратник"],
    "ярыжник": ["ярыга"],
    "ярыкъ": ["ышыкъ", "нур"],
    "ярым": ["ярты"],
    "яс": ["ясин"],
    "ясамакъ": ["япмакъ", "этмек"],
    "ясачный": ["ясашный"],
    "ясашный": ["ясачный"],
    "ясен пень": ["разумеется", "а как же", "а то", "без базара", "кто бы сомневался", "понятненько", "понятное дело", "само собой", "так точно", "точнее некуда", "ясен перец", "ясен хрен", "ясен красен", "ясно как днем", "ясное дело"],
    "яска": ["ласка"],
    "яскравий": ["блискучий", "барвистий"],
    "яснев": ["ясневши"],
    "ясневши": ["яснев"],
    "ясненько": ["понятненько", "ясен пень"],
    "ясниться": ["яснеть"],
    "ясно": ["безоблачно", "солнечно", "отчётливо", "понятно"],
    "ясно даже и ежу": ["ежу понятно", "ясен пень"],
    "ясновельможный": ["сиятельный"],
    "ясновиденье": ["ясновидение"],
    "ясновидец": ["провидец", "прозорливец", "экстрасенс", "ясновидящий"],
    "ясновидица": ["ясновидящая"],
    "ясновидящий": ["менталист", "ясновидец", "ясновидица"],
    "ясноглазый": ["ясноокий"],
    "ясноокий": ["ясноглазый"],
    "яснослышанье": ["яснослышание"],
    "яснотковые": ["губоцветные"],
    "ясный": ["светлый", "чёткий", "отчётливый", "внятный", "понятный", "очевидный", "доступный", "постижимый"],
    "ясон": ["язон"],
    "ясонька": ["голубушка", "душенька", "милая"],
    "ясочка": ["голубушка", "душенька", "милая"],
    "яспис": ["яшма"],
    "ясриб": ["ятриб"],
    "яссы": ["ясы", "туркестан"],
    "ястреб": ["ястржембский"],
    "ястреб-перепелятник": ["малый ястреб", "перепелятник"],
    "ястыкъ": ["бойлукъ"],
    "ясы": ["яссы", "туркестан"],
    "ятваг": ["ятвяг", "судин"],
    "ятвеж": ["язиг"],
    "ятвяг": ["ятваг", "судав", "судин", "дайнав", "язиг"],
    "ятленя": ["дятленя"],
    "ятовь": ["ятовье"],
    "ятовье": ["ятовь"],
    "ятреба": ["утроба"],
    "ятриб": ["ясриб"],
    "ятровь": ["свояченица", "ятровья", "ятровка", "ятровица"],
    "ятрогения": ["иатрогения", "врачебная ошибка"],
    "ятромеханика": ["иатромеханика", "ятрофизика", "биомеханика"],
    "ятрофизика": ["иатрофизика", "ятромеханика"],
    "ятрофобия": ["иатрофобия"],
    "ятрохимия": ["иатрохимия"],
    "яуап": ["сиселеш"],
    "яфет": ["иафет"],
    "яфетидология": ["яфетическая теория", "теории стадиальности", "марризм"],
    "яфо": ["яффа"],
    "яффа": ["яффо", "яфо", "яфа", "иоппия", "иоппа"],
    "яффо": ["яффа"],
    "яхве": ["иегова", "саваоф", "господь"],
    "яхвист": ["иеговист"],
    "яхимов": ["йоахимсталь"],
    "яхонт": ["корунд"],
    "яхонтовый": ["дражайший", "любезный"],
    "яхромец": ["яхромчанин"],
    "яхромчанин": ["яхромец"],
    "яхт-клубский": ["яхт-клубовский"],
    "яхтенный": ["яхтный", "яхтовый"],
    "яхтовладелец": ["яхтсмен"],
    "яхър": ["обор", "кошара", "конюшня"],
    "ячав": ["ячавши"],
    "ячавши": ["ячав"],
    "ячеив": ["ячеивши"],
    "ячеивши": ["ячеив"],
    "ячеистость": ["губчатость", "ноздреватость", "пористость"],
    "ячеистый": ["ноздреватый", "пористый"],
    "ячейка": ["ячея", "первичка"],
    "ячество": ["индивидуализм", "самовлюблённость", "себялюбие", "ячность", "эгоизм"],
    "ячея": ["ячейка"],
    "ячменный": ["яшный"],
    "ячмень": ["жито", "житарь", "житмень"],
    "яшкаться": ["якшаться"],
    "яшма": ["яспис"],
    "яшмовый": ["ясписовый"],
    "яшный": ["ячменный"],
    "яшчарка": ["яшчарыца"],
    "яшчарыца": ["яшчарка"],
    "ящар": ["ящерица", "ящерка", "рептилия", "земноводное", "пресмыкающееся", "гад", "червоземное"],
    "ящер": ["панголин", "динозавр"],
    "ящерица-бегун": ["хлыстохвостая ящерица"],
    "ящеричка": ["ящерка"],
    "ящерка": ["ящеричка"],
    "ящик пандоры": ["рог изобилия"],
    "яядями": ["сэвэнчэдеми"],
    "яяори": ["самандаори"],
    "яёи": ["яёй"],
    "яёй": ["яёи"],
    "ёб": ["дрожь", "ток"],
    "ёб твоя мать": ["ёб твою мать"],
    "ёба": ["ёбаный в рот", "бля", "блядь", "нахуй"],
    "ёбалды": ["мошонка"],
    "ёбанный": ["ёбанный-переёбанный"],
    "ёбаногандонный хуепедераст": ["хуепуполо залупоглазое", "хуепуполо промандоблядское"],
    "ёбаный": ["отъёбанный", "поёбанный", "выебанный", "наёбанный", "скверный", "плохой", "паршивый", "дрянной", "презренный", "отвратительный", "проклятый", "чёртов", "второсортный", "третьесортный", "дерьмовый"],
    "ёбаный насос": ["ёб твою ёб", "ёб твою мать", "ёбаный покос", "ёбаный по черепу", "ёбаное вымя", "ёбаный ананас", "ёбаный карась", "ёбаный компот", "ёбаный налево", "ёбаный насрать", "ёбаный носорог", "ёбаный пиздец", "ёбаный по голове", "ёбаный понеси", "ёбаный стос"],
    "ёбаный стыд": ["ёбаный по черепу", "ёбаное вымя", "ёбаный ананас", "ёбаный карась", "ёбаный компот", "ёбаный налево", "ёбаный насос", "ёбаный насрать", "ёбаный носорог", "ёбаный пиздец", "ёбаный по голове", "ёбаный покос", "ёбаный понеси", "ёбаный стос", "ёбаный сыр"],
    "ёбаный шашлык": ["ёб твою ёб", "ёб твою мать", "ёбанный в рот", "ёбаный по черепу", "ёбаное вымя", "ёбаный ананас", "ёбаный карась", "ёбаный компот", "ёбаный налево", "ёбаный насос", "ёбаный насрать", "ёбаный носорог", "ёбаный пиздец", "ёбаный по голове", "ёбаный покос"],
    "ёбарь": ["ебака", "ебец", "ебун", "ёбщик", "ебач", "ёбырь", "ёбрь", "хахаль", "хахарь"],
    "ёбкий": ["ебучий"],
    "ёбко": ["заёбисто", "ебуче"],
    "ёбкость": ["ебливость", "ебучесть"],
    "ёбля": ["совокупление", "половой акт", "секс", "трах", "перепихон", "ебля", "канитель"],
    "ёбнув": ["ёбнувши"],
    "ёбнувши": ["ёбнув"],
    "ёбнутый": ["ебанутый", "чокнутый", "спятивший", "сумасшедший", "безрассудный", "придурковатый"],
    "ёбнуть": ["стукнуть", "ударить", "вдарить", "ебануть", "ударить электрическим током", "выпить", "намахнуть", "замахнуть", "дёрнуть", "дерябнуть", "бахнуть", "бабахнуть", "шлёпнуть", "наебнуть", "украсть"],
    "ёбнуть по фазе": ["ёбнуть фазу"],
    "ёбнуть фазу": ["ёбнуть по фазе"],
    "ёбс": ["бац", "бах", "блямс", "блямсь", "шлёп", "трах", "еблысь", "еблысть", "хуяк", "хуякс"],
    "ёбс-переёбс": ["так-перетак", "так-растак", "тудыт-растудыт", "тудыть-растудыть", "ядрёна корень", "ядрёна кочерга", "ядрёна матрёна", "ядрёна мать", "ядрёна-кучерёна", "ядрёный корень", "япона мама", "япона мать", "японский городовой", "ёб твою ёб", "ёб вашу ёб"],
    "ёбург": ["ебург", "екат", "екатеринбург", "свердловск"],
    "ёбывав": ["ёбывавши"],
    "ёбывавши": ["ёбывав"],
    "ёбывать": ["поёбывать", "потрахивать"],
    "ёбырь": ["ебака", "ебец", "ебун", "ёбщик", "ебач", "ёбарь", "ёбрь", "хахаль", "хахарь", "пихарь"],
    "ёва": ["сафсата", "музахраф"],
    "ёвар": ["мададгор"],
    "ёгра": ["отмель"],
    "ёдово": ["ежа", "ежево", "едиво"],
    "ёж": ["ёж обыкновенный", "противотанковый ёж", "ёжик", "бобрик"],
    "ёж-рыба": ["рыба-ёж"],
    "ёжив": ["ёживши"],
    "ёживши": ["ёжив"],
    "ёжистый": ["колючий", "жёсткий"],
    "ёжиться": ["кукожиться", "жаться", "мяться", "стесняться", "смущаться", "робеть", "заниматься", "тренироваться"],
    "ёкав": ["ёкавши"],
    "ёкавши": ["ёкав"],
    "ёканье": ["ёкание"],
    "ёкарный бабай": ["ёлы-палы", "блин", "чёрт"],
    "ёкать": ["икать", "замирать", "хлопнуть", "стукнуть", "ударить", "отнекиваться"],
    "ёкнув": ["ёкнувши"],
    "ёкнувши": ["ёкнув"],
    "ёкнуть": ["икнуть", "крякнуть", "ойкнуть", "дрогнуть", "ухнуть", "защемить", "замереть"],
    "ёкодзуна": ["йокодзуна"],
    "ёксель-моксель": ["ёк-макарёк", "ёлки-палки", "ух ты"],
    "ёла": ["елла", "иола"],
    "ёлка": ["ель"],
    "ёлламакъ": ["йибермек"],
    "ёло": ["илёв", "цябол"],
    "ёмкий": ["вместительный", "просторный", "обширный", "многозначный", "богатый", "объёмный"],
    "ёмкость": ["вместимость", "объём", "сосуд", "электрическая ёмкость", "электроёмкость", "конденсатор", "заряд", "количество информации", "размер"],
    "ёмлакспинге": ["идькспинге", "шабакспинге"],
    "ёпрст": ["ё-моё", "ё-моё-коробка-спичек", "о-ё", "ой-ё", "ой-йо", "ёбстудэй", "ёкарный бабай", "ёханый бабай", "ёханный бабай", "жёванный бабай", "ёклмн", "ё-ка-лэ-мэ-нэ", "ёкала-манокала", "ё-кэ-лэ-мэ-нэ", "ё-пэ-рэ-сэ-тэ"],
    "ёпт": ["йопт", "ёпта", "ёптыть", "ёб твою мать"],
    "ёпта": ["йопт", "ёпт", "ёптыть", "ёб твою мать"],
    "ёра": ["ёрник", "забияка"],
    "ёрамс": ["таколдомс", "улемс мяль", "калямс мяльти", "арьсемс", "тяряфтомс", "сърхкамс"],
    "ёрдамс": ["кадомс", "лоткамс", "яфодемс", "ёрдамс вельф", "ёрдамс туркс", "ёрдамс алу", "валхтомс", "каямс", "араламс пря", "панемс", "потафтомс", "сявомс"],
    "ёрдамс алу": ["ёрдамс"],
    "ёрдамс вал": ["азомс вал", "пъшкядемс вал"],
    "ёрдамс вельф": ["ёрдамс", "ёрдамс туркс"],
    "ёрдамс идь": ["каямс идь"],
    "ёрдамс пряста": ["нардамс", "юкстамс"],
    "ёрдамс туркс": ["ёрдамс", "ёрдамс вельф"],
    "ёрзав": ["ёрзавши"],
    "ёрзавши": ["ёрзав"],
    "ёрзанье": ["ёрзание"],
    "ёрзать": ["вертеться", "елозить", "егозить", "метаться", "дёргаться", "суетиться", "юлить"],
    "ёрзнув": ["ёрзнувши"],
    "ёрзнувши": ["ёрзнув"],
    "ёрмунганд": ["йормунганд", "мидгардсорм"],
    "ёрник": ["насмешник"],
    "ёрничав": ["ёрничавши"],
    "ёрничавши": ["ёрничав"],
    "ёрничать": ["глумиться", "издеваться"],
    "ёрнический": ["насмешливый", "глумливый", "шутовской"],
    "ёршик": ["обыкновенный ёрш"],
    "ёсуман": ["ёсамин", "ёсмин", "суман"],
    "ётазь": ["меле"],
    "ётамс": ["шаштомс", "аськолдамс", "аськолямс", "ётамс вакска", "таргавомс", "тяльгомс", "инголдамс", "тумс", "эряфкстомс", "прядовомс"],
    "ётафтомс эряфс": ["тиемс арьсефть"],
    "ёткста": ["эзда"],
    "ётмек": ["гыржын"],
    "ётунхейм": ["йотунхейм"],
    "ёфицировав": ["ёфицировавши"],
    "ёфицировавши": ["ёфицировав"],
    "ёфтан": ["ёфт кардан"],
    "ёш": ["йош"],
    "ёшкин кот": ["безобразие", "гадство", "свинство"],
}

# UK: 1,466 words, 4,022 synonyms
UK_WIKT_SYNONYMS: dict[str, list[str]] = {
    "а-": ["проти-"],
    "абажурчик": ["абажур"],
    "абат": ["настоятель", "ігумен", "пріор"],
    "аберація оптичних систем": ["похибка зображення"],
    "абетка": ["алфавіт", "азбука", "альфабет"],
    "абиде": ["аби де", "будь-де", "де-небудь", "десь", "де хочеш", "де попало"],
    "абиколи": ["будь-коли", "коли-небудь", "коли-будь", "коли-не-коли", "коли хочеш", "коли прийдеться"],
    "абихто": ["будь-хто", "хто-будь", "всякий", "кожний", "кожен"],
    "абищо": ["що-небудь", "будь-що", "що-будь", "що", "попало", "хочеш"],
    "абориген": ["тубілець", "автохтон"],
    "абощо": ["тощо"],
    "абрикос": ["мореля", "боросква"],
    "абрубтивні приголосні": ["глоталізовані приголосні", "зімкнено-гортанні приголосні"],
    "абстрактний": ["загальний", "умоглядний"],
    "абстракція": ["абстрагування"],
    "абсурд": ["безглуздя", "нісенітниця", "нонсенс", "несусвітенність", "безглуздість", "нісенітність", "неподобність", "недоладність", "на вербі груші", "сон рябої кобили", "купи не держиться", "бридня", "абракадабра", "глупство", "дурниця"],
    "абшит": ["відставка", "звільнення"],
    "абіогенний": ["небіологічний"],
    "абісаль": ["абісальна зона"],
    "абітурієнт": ["вступник", "вступниця", "випускник", "випускниця"],
    "абітурієнтка": ["вступник", "випускниця"],
    "авангард": ["передній відділ"],
    "аванс": ["завдаток", "передплата"],
    "авантюра": ["пригода", "приключка"],
    "аварійний": ["запасний"],
    "аватарка": ["юзерпік"],
    "август": ["серпень", "огастес"],
    "автомагістраль": ["автострада"],
    "автомат": ["машина", "механизъм", "шмайзер"],
    "автономний": ["самостійний", "некерований"],
    "автопробіг": ["автозмагання", "авторалі", "автопарад", "пробіг", "кілометраж", "автоквест"],
    "авторитет": ["вага", "перевага", "авторитетність", "вплив"],
    "авторитетний": ["впливовий", "поважний", "владний", "менторський"],
    "автострада": ["автомагістраль"],
    "ага": ["аґа"],
    "агарянец": ["агарянин", "мохамеданин", "мюсюльманин", "турчин"],
    "агарянин": ["магометанин", "мусульманин", "ізмаїльтянин", "араб", "турок"],
    "агент": ["уповноважений", "шпигун", "розвідник", "резидент"],
    "агентство": ["представителство", "агенция", "бюро"],
    "агонія": ["агонізування"],
    "агресивний": ["нападницький", "загарбницький", "заборчий", "наступальний", "ворожий"],
    "агропромисловість": ["аграрна сфера", "аграрна галузь", "сільське господарство"],
    "агіологія": ["агіографія"],
    "адвокат": ["аблакат"],
    "адвокатство": ["заступничество", "защита"],
    "адвокатський екзамен": ["адвокатський іспит"],
    "адвокатський іспит": ["адвокатський екзамен"],
    "адекватність": ["правильність", "відповідність"],
    "адиге": ["адиґе"],
    "админкодекс": ["коап"],
    "адоптація": ["усиновлення", "повсиновлення", "удочеріння"],
    "аеродром": ["летовище"],
    "аеропорт": ["летовище"],
    "аж гульк": ["аж глядь"],
    "ажурний": ["прозорий", "ажуровий", "мистецький", "викінчений", "довершений", "філігранний", "тонкий"],
    "ажіотаж": ["бум", "гарячка", "лихоманка"],
    "азбука": ["алфавіт", "абетка", "альфабет"],
    "азбучний": ["абетковий", "алфавітний"],
    "азербайджанська мова": ["азери"],
    "азиль": ["притулок"],
    "азіатський": ["азійський"],
    "аквамариновий": ["аквамаринний"],
    "акомпанемент": ["супровід"],
    "акомпанувати": ["супроводжувати", "пригравати"],
    "акробатичний": ["спритний"],
    "активітив": ["діяльник"],
    "актор": ["удавач"],
    "актуальний": ["назрілий", "злободенний", "наболілий", "пекучий"],
    "акурат": ["точно", "саме", "якраз"],
    "акуратист": ["чепура"],
    "акцентувати": ["наголошувати"],
    "акцептувати": ["затверджувати", "ухвалювати"],
    "але": ["та", "однак", "проте", "втім"],
    "алкотестер": ["спиртомір", "драгер"],
    "алтимат": ["алтимат фризбі"],
    "алфавіт": ["абетка", "азбука", "альфабет"],
    "алькир": ["алкер", "алькер", "алкир", "алькеж", "анкер", "анкир", "антір", "валькир", "ванкир", "ванькир", "вантір", "ванькір", "янір", "альков"],
    "альманашний": ["альманаховий"],
    "альтиметр": ["висотомір"],
    "альтруїзм": ["безкорисність", "самовідданість"],
    "алюміній": ["люміній"],
    "алярм": ["тривога"],
    "алярмовий": ["тривожний"],
    "аматор": ["любитель", "дилетант"],
    "амбар": ["комора", "стодола"],
    "амбасада": ["посольство"],
    "амбразура": ["бійниця", "стрільниця"],
    "амвон": ["проповідниця", "казальниця"],
    "амністія": ["помилування", "прощення"],
    "ампутація": ["утин"],
    "аміант": ["азбест"],
    "аналогічний": ["подібний", "схожий"],
    "анахорет": ["пустинник"],
    "англієць": ["ягляни", "джон буль"],
    "анексіоніст": ["загарбник", "гарбач"],
    "анемограф": ["вітрозаписка"],
    "анонімний": ["безіменний"],
    "ансамбль": ["гурт", "група"],
    "антефікс": ["лобова черепиця"],
    "антиклерикальний": ["антицерковий"],
    "античний": ["класичний", "древній"],
    "антропометрические данные": ["физикальные данные", "комплекция"],
    "аніж": ["ніж"],
    "анітрохи": ["нітрохи", "ніскільки"],
    "апо-": ["з-", "від-", "без-"],
    "апогей": ["апоцентр", "зеніт"],
    "апокаліпсис": ["одкровення", "об'явлення"],
    "апрель": ["март", "май"],
    "аранжування": ["обробка"],
    "арахіс": ["земляний горіх", "китайський горіх"],
    "арбітр": ["посередник", "суддя", "рефері", "третейський суддя"],
    "аритмічний": ["неритмічний"],
    "аромат": ["пахощі"],
    "ароматний": ["запашний"],
    "арт-директор": ["художній директор"],
    "арфа": ["гарфа", "гарпа"],
    "архітект": ["архітектор", "будівничий"],
    "архітектор": ["будівничий", "зодчий"],
    "астронавт": ["космонавт"],
    "аська": ["месенджер"],
    "атовець": ["учасник ато"],
    "аудиторія": ["слухацтво"],
    "афера": ["шахрайство", "гешефт", "ґешефт", "шахер-махер", "махінація"],
    "афіни": ["атени"],
    "аґа": ["ага"],
    "баба": ["стара", "бабка", "бабуня", "бабуся", "бабусечка", "бабусенька"],
    "бабак": ["дурны", "лянівы", "абібок"],
    "бабування": ["бабництво"],
    "бабця": ["бабуня"],
    "бавити": ["забавляти", "няньчити", "доглядати"],
    "багатогранник": ["многогранник"],
    "багатократний": ["частий", "багаторазовий"],
    "багаторазово": ["не раз", "часто", "багато разів"],
    "багатоступінний": ["багатоступеневий"],
    "багатоярусний": ["багатоповерховий"],
    "багатство": ["розкіш"],
    "багаття": ["вогнище"],
    "баглаї бити": ["ледарювати", "байдики бити", "бити баглаї"],
    "багнистий": ["болотистий", "грузький", "грязький"],
    "бажати": ["хотіти", "прагнути", "жадати", "зичити"],
    "бажаючий": ["хотіти", "охочий"],
    "базально-клітинний рак шкіри": ["базаліома", "базально-клітинна карцинома", "бкрш"],
    "базарянин": ["базарник", "крамар", "торговець", "крамарчук"],
    "байдики бити": ["посиденьки справляти", "байдикувати", "лежати на печі"],
    "баклажанний": ["баклажановий"],
    "баланс": ["паритет"],
    "банально": ["примітивно"],
    "бандит": ["опришок", "хуліган"],
    "банк": ["лихварня"],
    "банка": ["банька", "слоїк", "бляшанка"],
    "банкрутство": ["банкротство"],
    "банкрутський": ["банкротський"],
    "баночка": ["банечка"],
    "бануш": ["токан"],
    "бар'єр": ["огорожа", "ворота", "ґрати", "перешкода"],
    "бартер": ["взаємозалік"],
    "бархатка": ["оксамитка"],
    "басиста": ["басистий", "контрабасист"],
    "батрак": ["наймит"],
    "батракування": ["наймитування"],
    "батракувати": ["наймитувати"],
    "батрацтво": ["наймитування", "наймитство"],
    "батрацький": ["наймитський", "наймитів"],
    "батрачити": ["наймитувати"],
    "батрачка": ["наймичка"],
    "батько": ["тато", "основоположник"],
    "батьківщина": ["спадщина", "спадок", "нащадок", "материзна", "дідівщина", "дідизна", "бабизна", "прадідизна", "прадідівщина", "отчина", "вітцівщина", "предківщина", "патримоній", "патримоніум"],
    "батяр": ["вар'ятунцьо", "макабунда", "андрус", "бахур", "буґера", "волоцюга", "пройдисвіт", "розбійник", "фраєр", "гопник", "забіяка", "хуліган"],
    "бачення": ["візія", "погляд", "сприйняття", "уявлення"],
    "башня": ["вышка", "каланча", "точечный дом"],
    "бджола": ["двокрилка", "крилата трудівниця", "божа комаха"],
    "безбарвність": ["безколірність"],
    "безборонний": ["безперешкодний", "беззаборонний", "вільний", "беззахисний"],
    "безвиглядний": ["безнадійний", "безвихідний", "безпорадний", "безпросвітний", "невилазний", "безперспективний"],
    "безвіз": ["режим візової лібералізації"],
    "бездощовий": ["бездощевий"],
    "беззаконний": ["незаконний", "протизаконний", "протиправний", "самовільний", "свавільний"],
    "безколірність": ["безбарвність"],
    "безлактозний": ["безмолочний"],
    "безпроволочно": ["не зволікаючи", "без затримки"],
    "безробіття": ["безділля"],
    "безсторонній": ["неупереджений", "справедливий"],
    "безстрашний": ["хоробрий", "відважний", "сміливий", "мужній"],
    "безтактність": ["нетактовність"],
    "безустанний": ["безперервний", "постійний"],
    "безчесний": ["підлий"],
    "безшлюб'я": ["целібат", "нешлюбність"],
    "березень": ["березіль", "березоль", "капельник", "протальник", "запалі сніги", "з гір потоки", "соковик", "полютий", "красовик"],
    "березка": ["повійка", "кручений панич"],
    "берестин": ["костянтиноград", "красноград"],
    "бескет": ["бескид"],
    "бескид": ["бескет"],
    "бесстрашный": ["храбрый", "отважный", "смелый", "мужественный", "неустрашимый"],
    "бешкетник": ["скандаліст", "розбишака", "буян", "шибеник", "дебошир", "хуліган", "пустун", "шалапут", "озорник", "бузотер", "грубіян"],
    "бешкетувати": ["пустувати"],
    "бинда": ["конвеєр"],
    "биря": ["бирька"],
    "бита голова": ["обметаний", "бувалий", "бувалець", "битий жак"],
    "бити в очі": ["засліплювати", "впадати в око"],
    "бити лихом об землю": ["піднестися духом"],
    "битий жак": ["бувала голова", "стріляний горобець"],
    "битком набитий": ["яблуку ніде впасти"],
    "битмейкер": ["компонувальник", "укомпоновувач"],
    "благати": ["заклинати", "молити", "волати", "упрошувати"],
    "благаючий": ["який благає", "котрий благає", "благаючи", "благальний"],
    "благая рыса": ["благая характарыстыка", "благая чарта"],
    "благая чарта": ["благая характарыстыка", "благая рыса"],
    "благоденство": ["благоденствування", "благодать", "блаженство"],
    "благодійність": ["доброчинність"],
    "благодіяння": ["нарука"],
    "благополуччя": ["добробут", "щастя", "гаразд"],
    "близько": ["біля", "поряд", "зблизька", "недалеко", "неподалік"],
    "блюдо": ["таріль"],
    "бо": ["адже", "позаяк", "тому що", "через те що", "оскільки", "затим що"],
    "богослов'я": ["теологія"],
    "божба": ["присяга", "обіт", "клятва", "обітниця", "присягання", "клятьба", "закляття"],
    "боковий": ["бічний"],
    "болезнь": ["недуг", "заболевание", "хворость"],
    "болото": ["багно", "трясовина", "мочарі", "твань", "грязюка", "безініціативність"],
    "болт": ["прогонич"],
    "борба": ["боротьба", "бійка", "сутичка"],
    "боросква": ["абрикос", "абрикоса", "персик"],
    "боротьба": ["борба", "бійка", "сутичка"],
    "бос": ["хазяїн", "володар", "начальник", "керівник", "шеф"],
    "босий": ["босісінький", "босоногий", "голоногий", "роззутий", "невзутий"],
    "боївка": ["бойова група"],
    "бразолійний": ["синій"],
    "бранець": ["рекрут", "новобранець", "салага", "москаль"],
    "брат": ["однодумець", "друг", "земляк", "свояк", "одноплемінець", "чернець", "ближній"],
    "брати на кпини": ["глумитися", "кпити", "покпити"],
    "брати ноги на плечі": ["давати драла"],
    "бретер": ["дуеліст", "дуелянт"],
    "брехати": ["обманювати", "заливати", "гавкати", "гавкотіти", "дзявкати", "дзявкотіти", "рявкати", "гвалтувати", "валувати", "заливатися", "в'їдати"],
    "бригада": ["ланка"],
    "броварство": ["пивоваріння"],
    "бродяга": ["блудяга", "безхатченко", "бідага", "бідолага", "бідняга", "сердяга", "чолов'яга"],
    "бруд": ["болото", "грязюка", "грязиво", "грязота", "кал", "калило", "каля", "калюка", "твань", "тванюка", "багно", "багнюка", "бруднота", "брудота"],
    "будка": ["вартівня", "сторожка", "конура"],
    "будування": ["будівля", "споруда", "архітектура"],
    "будучність": ["майбутнє"],
    "будущий": ["майбутній", "прийдешній"],
    "будівний": ["креативний", "творчий"],
    "буква": ["літера"],
    "буквально": ["дослівно", "слово в слово", "майже", "ніби", "достеменно"],
    "букодірка": ["зяблик", "букивчак", "зябок", "снігарик", "берестянка", "шпінька", "шпінькало", "потринькач", "пінькус", "пінкус", "армілка", "дзюбок", "березівка", "буківник", "букодірчак"],
    "бульба": ["пухир", "бульбашка"],
    "бундючитися": ["зарозуміватися", "загордіти", "підіймати носа", "високо нестися"],
    "бундючний": ["гордовитий", "чванливий", "пихатий", "пишний", "розкішний"],
    "бункер": ["схрон"],
    "бунтівник": ["бунтар"],
    "бур": ["лопатень", "свердел", "свердло"],
    "бур'ян": ["хопта"],
    "бургаське озеро": ["вая", "озеро бургас"],
    "буркун-зілля": ["бурковина"],
    "буртіль": ["згорток", "пакунок"],
    "бусурман": ["бусурмен"],
    "бусурмен": ["бусурман", "іновірець", "гяур", "нехристиянин", "невіра", "нехрист"],
    "бутерброд": ["канапка", "сендвіч"],
    "бути": ["існувати"],
    "буття": ["матерія", "природа"],
    "бухоблік": ["бухгалтерський облік", "бухгалтерія"],
    "буцегарня": ["тюрма", "фурдиґарня"],
    "буцімто": ["буцім", "неначе", "начебто"],
    "бюлетень": ["агітка", "твіт", "бланк"],
    "бюро": ["представителство", "агенция", "агентство", "служба", "работа", "служено", "учреждение"],
    "біги": ["переховування", "втеча", "перегони"],
    "бідний": ["убогий", "вбогий"],
    "бізнес-леді": ["бізнесменка", "бізнес-вумен"],
    "бій": ["бійка"],
    "біла акація": ["робінія звичайна"],
    "білет": ["квиток"],
    "білка": ["вивірка", "білиця", "вевірка", "веврик", "пухівка"],
    "біля": ["близько", "коло", "недалеко"],
    "білість": ["білизна", "білина"],
    "біографія": ["життєпис"],
    "біомедична геронтологія": ["експериментальна геронтологія", "антивікова медицина", "продовження життя", "збільшення тривалості життя"],
    "біржа": ["ярмарок"],
    "бісики в очах грають": ["бісики випускати"],
    "в основном": ["в общих чертах", "в главном", "как правило"],
    "в основному": ["переважно", "головним чином", "здебільшого"],
    "в'язниця": ["іванова хата", "цюпа"],
    "ваба": ["принада", "надило"],
    "вабець": ["принадник"],
    "вабик": ["принада"],
    "вабило": ["надило", "принада"],
    "вабильщик": ["принадник"],
    "ваблений": ["наджений"],
    "ваблячи": ["надячи"],
    "ваганти": ["голіадри"],
    "вагіна": ["безодня", "біда", "бідка", "бородата борода", "вульгарна пройда", "галка", "гандила", "горбик", "грішне місце", "гава", "гига", "давалка", "дамська", "штука", "дасиця"],
    "вагітний": ["концептуальний", "зародковий"],
    "вагітність": ["тяж", "вагота"],
    "вада": ["недолік"],
    "важкодум": ["тугодум", "доходяй", "доходяга"],
    "вазодилататорний": ["судинорозширювальний"],
    "вакація": ["канікули"],
    "валенродизм": ["інкорпорація", "розвідувально-підривна діяльність"],
    "валуй": ["сироїжка смердюча"],
    "валькир": ["валькір", "ванькир", "ванкир", "алькир", "алкир", "альков"],
    "вантаж": ["тягар"],
    "вантажник": ["навантажувач"],
    "вантуз": ["плунжер"],
    "вараш": ["кузнецовськ"],
    "вареник": ["пиріг"],
    "варта": ["належаць", "трэба"],
    "ввідтоновий": ["увіднотоновий"],
    "вглиблюватися": ["заглиблюватися", "вникати"],
    "вголос": ["голосно"],
    "вгору": ["угору", "догори"],
    "вдвоє": ["удвоє", "вдвічі", "наполовину"],
    "вдосталь": ["удосталь", "вдостачу"],
    "вдруге": ["знову"],
    "веб-камера": ["вебка"],
    "вебтун": ["вебкомікс", "вебманхва", "манхва", "комікс"],
    "ведмідь на вухо наступив": ["немузикальний"],
    "вежа": ["башта", "вишка", "в'язниця"],
    "велетенський": ["велетневий"],
    "вересень": ["сівень", "маїк", "покрійний", "бабине літо"],
    "верстат": ["ткацький верстат", "верстак"],
    "верховенство права": ["зверхність права"],
    "вибитися з грошей": ["витратитися", "потратитися", "розтратитися", "втратитися", "отратитися", "стратитися", "розтринькатися"],
    "виведення коштів": ["виведення активів", "фінустанова", "банкопад", "обкатувати схеми"],
    "вивірка": ["білка"],
    "вигадун": ["вигадько"],
    "вигук": ["крик"],
    "винительный": ["аккузативный", "аккузатив"],
    "вино": ["піка"],
    "випадковий": ["несподіваний", "нежданий", "негаданий", "непередбачений", "ненавмисний", "невмисний", "неумисний", "перший-ліпший", "припадковий", "незакономірний", "казуальний", "принагідний", "непостійний", "оказіональний", "шалений"],
    "виповісти": ["виказати", "висловити", "вилити", "вимовити", "відмовити"],
    "вислів": ["фраза"],
    "високий": ["височезний", "височенний", "превисокий", "превисоченний", "підхмарний", "висотний", "гінкий", "прогонистий", "крутий", "панівний", "рослий", "рославий", "рослявий", "довгий", "довжезний"],
    "високість": ["висота"],
    "висходження": ["марення", "несамовитість", "самозабуття", "забуття", "пал", "запал", "душевне піднесення", "імпульсивність", "шаленство", "піднесення", "захоплення", "безтямний", "безтямкий", "безтямно", "нестяма"],
    "виїздити": ["об'їздити", "об'їхати", "обколесити", "обколесувати", "облітати", "обкрутити", "обміряти", "обмрірити", "об'їжджати"],
    "владоможець": ["начальник", "владці", "влада"],
    "власник": ["володілець", "владар", "володар"],
    "властивий": ["притаманний"],
    "вмить": ["умить", "миттю", "намліока", "навмліока", "навмлівіч", "млавіч", "на мліг ока"],
    "внескодавець": ["вкладник", "жертводавець"],
    "внесок": ["даток"],
    "внутрішньо переміщена особа": ["впо"],
    "вогнівка": ["огнівка"],
    "военнослужащий": ["солдат", "военный"],
    "волинянин": ["волинець"],
    "володимир": ["володимир-волинський"],
    "воркоголік": ["працелюб", "працеман", "роботоголік"],
    "ворог": ["недруг", "неприятель", "противник", "супротивник"],
    "восьмигранник": ["октаэдр"],
    "вповісти": ["повісти", "сказати", "розказати", "розповісти"],
    "вправний": ["спритний"],
    "вроде": ["навроде", "подобно", "наподобие", "чему-то", "кажется", "как будто", "будто бы"],
    "вставляти палиці в колеса": ["совати дрючки в колеса"],
    "всіма способами": ["всяко"],
    "втілення": ["велика панагія"],
    "вуйко": ["вуй"],
    "вщент": ["навпроч", "цілком", "внівець", "дотла", "впень", "геть"],
    "выход": ["выезд", "возможность"],
    "вівця": ["овечка", "биря", "бирька", "стрижка"],
    "вівчар": ["чабан"],
    "віголос": ["експерт", "знавець"],
    "віголоска": ["експертка", "знавчиня"],
    "відеоблог": ["влог"],
    "відеотрансляція": ["стрим"],
    "відкат": ["хабар"],
    "відміна": ["різновидність", "варіант"],
    "відповідь": ["відвіт"],
    "відпуст": ["розгрішення"],
    "відстань": ["дистанція"],
    "відчуженість": ["занедбаність", "запущеність"],
    "віжн-студія": ["студія живого ефіру"],
    "військовослужбовець": ["військовий", "солдат"],
    "вік": ["сторіччя", "століття", "епоха", "ера"],
    "вільнюс": ["вільно", "вільна"],
    "вімана": ["іншопланетна техніка"],
    "віп-зона": ["ві-ай-пі-зона"],
    "вірник": ["вірянин", "віруючий", "адепт"],
    "вірогідний": ["певний", "більш-менш", "імовірний"],
    "вість": ["віда", "відвість", "відповість", "вістка", "вістонька", "вісточка", "звідомлення", "звістка", "звістонька", "звісточка", "звість", "звісь", "новина", "оголоска", "оповістка"],
    "вітаю": ["добридень", "привіт"],
    "віцилопочтлі": ["уїцилопочтлі"],
    "гай": ["дубняк", "вільшняк", "куча"],
    "галка": ["галиця", "галочка", "галонька"],
    "ганьба": ["приниження", "сором", "стид", "гудьба", "безчестя"],
    "гардероб": ["роздягальня"],
    "гармоніювати": ["гармонувати", "гармонізувати"],
    "гармонія": ["злагода", "погодженість", "милозвучність", "благозвучність", "евфонія", "співзвуччя", "консонанс"],
    "гарнітур": ["набір", "комплект", "прибор", "куверт"],
    "гачі": ["ґачі", "ґаці", "штани", "брюки", "сподні", "шаровари", "ногавиці", "порти", "портки", "портяниці"],
    "гданськ": ["ґданськ"],
    "гексагон": ["шестиугольник"],
    "гексаоктаэдр": ["сорокавосьмигранник"],
    "гексаэдр": ["шестигранник"],
    "гексоктаэдр": ["сорокавосьмигранник"],
    "гель": ["желе"],
    "ген-збудник": ["домінантна ознака"],
    "генічеськ": ["генічі", "єнічі", "усть-азовськ"],
    "гептагон": ["семиугольник"],
    "герць": ["поєдинок", "герець"],
    "глава": ["баня", "верх", "купол", "голова", "розділ"],
    "глубоководный": ["эпроновский"],
    "глупость": ["дурость", "тупость"],
    "гобец": ["голбец", "говбец"],
    "говбец": ["голбец", "гобец"],
    "говбур": ["вир", "коловорот", "нурт", "чорторий", "крутіж", "круговерть", "коловерть", "водоверть", "крутоверть", "нурта", "нуртина", "нуртовище", "круговорот", "крутовир'я", "шум"],
    "говорити": ["агакати", "агакнути", "акати", "акнути", "ахати", "ахкати", "ахнути", "бевкати", "бевкнути", "бекати", "бекнути", "бекотати", "бекотіти", "бечати", "віднікуватися"],
    "голая панночка": ["калачики лісові", "мальва лісова", "мальва звичайна", "зензівер"],
    "голбец": ["говбец", "гобец", "голобец"],
    "голобец": ["голбец"],
    "головним чином": ["головне", "в першу чергу"],
    "гончарство": ["гончарне виробництво", "керамічний", "виробництво", "кераміка"],
    "гореть": ["пылать", "светить"],
    "горно": ["горнило", "гартовня", "гартувальня", "кузня"],
    "горнє місце": ["високе місце", "вишнє місце"],
    "город-порт": ["місто"],
    "городський": ["міський"],
    "горячий": ["жаркий", "пылкий", "вспыльчивый"],
    "господар": ["собственик", "стопанин", "сайбия", "домовладика", "работодател", "владетел", "разпоредник", "разпоредител", "управител", "началник", "шеф", "големец", "властелин", "притежател", "съдържател"],
    "гострий момент": ["небезпечний поворот"],
    "гражданський друк": ["гражданка"],
    "граничний": ["маржинальний", "додатковий"],
    "грати на нервах": ["морочити голову", "сидіти в печінках"],
    "грецька республіка": ["греція"],
    "гробовище": ["гробниця", "кладовище"],
    "грозьба": ["погроза", "грізьба"],
    "громкое преступление": ["нашумевшее преступление"],
    "грудомаха": ["брила"],
    "грізьба": ["погроза", "грозьба"],
    "гудьба": ["музика", "гудіння"],
    "гузаха": ["комашка", "кузька", "жучок"],
    "гук": ["какофонія"],
    "гумінові кислоти": ["гуміни"],
    "гумінові препарати": ["гумати"],
    "густина": ["гущина", "густота", "густість"],
    "гусятниця": ["гусятник", "чавун", "чавунець"],
    "гърне": ["делва"],
    "гіперпуризм": ["пуризм"],
    "гістьба": ["гостина", "подорож"],
    "дабрачыннасць": ["дабрадзейнасць"],
    "давньоруська мова": ["староруська мова", "давньоукраїнська мова"],
    "далебі": ["далебіг", "їй бо", "їй богу", "їй-право", "справді", "справді-бо", "бігме", "бігме-так", "бігме-таки", "істо", "таки так", "присяй-бо", "присяй-богу", "справді ж", "справді ж бо"],
    "далеко": ["неблизько", "вдалині", "вдалечині", "ген", "ген-ген", "геть", "геть-геть"],
    "дальше": ["далі", "дальш"],
    "дама сердца": ["возлюбленная"],
    "даровщина": ["дармовщина", "даровщинка", "халява"],
    "дарій": ["дарко", "дарчик", "дарусик"],
    "дательный": ["дативный", "датив", "дательный падеж"],
    "дати тягу": ["дати драла", "взяти ноги на плечі", "дати ногам знати"],
    "дати шитиків": ["дати хлости", "лупцювати"],
    "дах": ["стріха", "стеля", "покрівля"],
    "даішник": ["даїшник", "гаішник", "гаїшник", "регулювальник", "міліціонер"],
    "два": ["двійка"],
    "двенадцатигранник": ["додекаэдр"],
    "двійнята": ["близнята"],
    "двійнятко": ["близнятка"],
    "де макар телят не пас": ["далеко", "на краю світу", "куди ворон і кісток не заносить", "де козам роги правлять", "за горами й долами"],
    "дев'яностий": ["дев'ятдесятий"],
    "дев'яносто": ["дев'ятдесят"],
    "дев'ятдесят": ["дев'яносто"],
    "декорум": ["благопристойність"],
    "день": ["доба", "дата", "життя"],
    "державна мова": ["офіційна мова"],
    "державна районна електростанція": ["конденсаційна електростанція"],
    "держпрограма": ["державний", "ініціатива"],
    "десять": ["червонець", "десятка", "десяток"],
    "дещиця": ["трохи", "дрібниця", "абищиця"],
    "деятельность": ["занятие", "дело", "активность"],
    "джинса": ["матеріал з ознаками замовності", "статейка"],
    "диво": ["дивина", "чудо", "рідкість", "курйоз", "диковина", "чудасія"],
    "динамічне гальмування": ["електричне гальмування"],
    "диск": ["кружало", "платівка"],
    "дитячий будинок": ["дитбудинок"],
    "дияконник": ["захристія", "паламарня", "мала ризниця", "ризниця"],
    "для": ["ґля", "ради", "заради"],
    "дніпро": ["даніпер", "гунівар", "данпар", "донар", "днабр", "узу", "озу", "узи", "атель", "барух", "варух", "катеринослав", "січеслав", "дніпропетровськ", "дніпропетрівське"],
    "доба": ["день", "днина"],
    "додекаэдр": ["двенадцатигранник"],
    "докризовий": ["передкризовий"],
    "домувати": ["мешкати", "проживати", "жити"],
    "домівка": ["оселя", "житло", "місце проживання"],
    "донощик": ["інформатор", "кляузник", "шістка", "сексот"],
    "дорога": ["шлях", "путь", "путівець"],
    "досвід": ["навичка", "навики", "практика", "школа", "мудрість"],
    "досить": ["достатньо", "багато", "доста"],
    "дочка": ["доч", "донька", "дівка", "дівчина", "дочір", "дочер", "дочухна", "доня", "доця"],
    "дощ": ["хлющ", "злива", "мжичка", "дощовиця"],
    "драглий": ["желеподібний"],
    "дрес": ["кес"],
    "дривітня": ["древитня", "дривитня", "дривитинь"],
    "друг": ["товариш", "приятель", "побратим", "добрий знайомий", "любко", "коханий", "любимий", "посестра"],
    "дружба": ["побратимство", "стосунки", "довір'я", "товариськість"],
    "дружина": ["жінка", "супруга"],
    "думка": ["дума", "мисль", "гадка", "міркування", "ідея", "помисел", "помисл", "думонька", "оцінка", "судження", "враження", "погляд", "розуміння", "поняття", "переконання"],
    "дурень": ["дурний", "тупко", "тупак", "глупак", "бельбас", "недотепа", "нетяма", "недоумок", "дурепа", "дурило", "дурко", "дурник", "дурнило", "товкач", "просторіка"],
    "дурило": ["дурень"],
    "душа": ["дух", "психіка", "настрій", "особа", "людина", "серце"],
    "душа не лежить": ["з душі верне"],
    "душпастир": ["ієрей", "священнослужитель", "піп", "парох", "пастор", "ксьондз", "канонік", "духовний наставник", "пастир-консультант", "катехит", "капелан", "священик"],
    "дціб": ["державний центр інформаційної безпеки"],
    "діалект": ["наріччя", "говірка", "говір", "балачка", "діялект"],
    "дівочість": ["жіночість", "дівоцтво", "незайманість", "цнотливість", "цнота", "панянство", "неблазність", "невинність", "непорочність"],
    "дільба": ["поділ", "діленина", "ділення"],
    "діяльник": ["активітив"],
    "діяння": ["вчинки", "дія", "поведінка", "дії", "поводження", "позиція", "речі", "манери", "обходження", "обходини", "політика", "поступування", "поведення"],
    "евентив": ["подійник"],
    "ейчар": ["кадровик"],
    "екзил": ["вигнання"],
    "екзорцизм": ["вправність", "чаклунство"],
    "економний": ["ощадливий"],
    "економічний": ["народногосподарський"],
    "екс-голова": ["екс-керівник", "екс-глава"],
    "екслібрисист": ["графік"],
    "експериментальна геронтологія": ["біомедична геронтологія", "антивікова медицина", "продовження життя", "збільшення тривалості життя"],
    "експонент": ["експонента"],
    "екстремальне значення величини": ["екстремум"],
    "електронна лексична картотека": ["лексична картотека"],
    "електронний маркетинг": ["е-маркетинг"],
    "електронно-обчислювальний центр": ["дата-центр", "ферма"],
    "енергетична цінність": ["поживна цінність", "харчова цінність"],
    "ера": ["епоха", "столетие", "век", "период", "цикъл"],
    "ерзац": ["підмінка", "підмішка", "цикорій", "солодова кава"],
    "етнопедагогіка": ["народна педагогіка"],
    "етнофестиваль": ["гуляння", "гульня", "фестини", "фест"],
    "ефір": ["живий ефір", "наживо"],
    "жабський": ["псилоцибе"],
    "живець": ["щіпка", "щепка", "прищепа"],
    "жид": ["єврей", "гебрей", "юдей", "іудей", "ізраїльтянин"],
    "жировий пагін": ["вовчок", "жировик"],
    "жироустійник": ["декантатор"],
    "житомирська область": ["житомирщина"],
    "жовнір": ["вояк", "солдат"],
    "жовта акація": ["карагана дерев'яниста"],
    "жовтень": ["листопад", "вересень"],
    "жовтобрюх": ["полоз жовточеревий"],
    "жовтогарячий": ["оранжевий", "помаранчевий"],
    "жопа": ["дупа", "гузно", "срака", "зад", "сідниця"],
    "жохлі": ["одноразово"],
    "жінка": ["фразеологічне зрощення", "євин накоренок", "пані", "міледі", "шанована", "жіночка", "сіньйора", "дама", "господиня", "мем", "місс", "молодиця"],
    "забаганка": ["каприз"],
    "завдаток": ["аванс"],
    "завжди": ["завсіди", "повсякчас", "постійно", "навіки", "споконвіку"],
    "загальнопедагогічний": ["загальноосвітній", "педагогічний", "всепедагогічний"],
    "задати перцю з маком": ["карати", "лаяти", "висміювати"],
    "зажужвеляний": ["затужавілий", "зашкарублий", "зсохлий", "пожухлий"],
    "заклад фахової передвищої освіти": ["зфпо"],
    "залицятися": ["доходжати"],
    "залояний": ["засмальцьований", "замащений", "замазаний", "зашмарований"],
    "заможність": ["достаток", "багатство"],
    "запозичення": ["запозичене слово", "калька"],
    "запущений": ["занедбаний"],
    "зараз": ["відразу", "негайно", "тепер", "нині", "щас", "цю мить", "акурат"],
    "заробітчанство": ["остарбайтер", "ґастарбайтер", "джоббер", "дорібок"],
    "зарплата у конверті": ["сіра зарплата", "ліва зарплата", "лівак"],
    "заселений": ["залюднений", "населений", "оселений", "обселений", "замешканий"],
    "засіб": ["спосіб"],
    "заткни-жопу": ["льонок звичайний"],
    "затор": ["бар'ер", "перашкода", "замінка", "завада", "загародка", "кардон", "шлагбаум", "рагаткі", "гара", "тормаз", "скула пад бокам"],
    "захист": ["оборона", "заступництво", "опіка", "притулок", "укриття", "захисток", "протекція", "охорона", "заслона"],
    "збіднілість": ["зубожіння"],
    "збільшення тривалості життя": ["продовження життя", "антивікова медицина", "експериментальна геронтологія", "біомедична геронтологія"],
    "зворотний": ["назадній", "поворотний"],
    "звір": ["ссавець"],
    "згнітитися": ["гинути", "пропадати", "сконфузитися", "затушуватися", "засоромитися", "змішатися"],
    "здоровенькі були": ["добридень"],
    "здійснювати": ["вчиняти", "реалізувати", "виконувати", "втілювати"],
    "землеустрій": ["землевпорядження"],
    "земля": ["ґрунт", "суша", "материк", "край", "країна", "держава"],
    "зернотрейдер": ["зерноброкер", "біржовик", "зернопостачальник", "зернооператор"],
    "злива": ["дощ", "ряснота", "рясність", "ряснощі"],
    "злорадство": ["зложелателство", "завист", "злоба", "жлъч", "ненавист", "омраза", "неприязън", "неприязненост", "вражда", "недоброжелателство", "ехидност"],
    "змі": ["засоби масової інформації"],
    "зневажання": ["пошановування", "поціновування", "цінування"],
    "знедійснювати": ["касувати", "анулювати"],
    "знеліснення": ["збезлісення", "обезліснення"],
    "знову ж таки": ["знов-таки"],
    "зовнішньоекономічний": ["народногосподарський", "імпортно-експортний"],
    "зокрема": ["окремо", "скажімо"],
    "зона ато": ["ато", "зона оос"],
    "зооантропонозний": ["антропозоонозний"],
    "зрошувані землі": ["поливні землі"],
    "зуб": ["зубець", "зуб'я"],
    "зубець": ["зуб"],
    "инуда": ["деінде", "деинде"],
    "каблограма": ["депеша"],
    "кава": ["кавове зерно", "кофе"],
    "кадик": ["борлак"],
    "кадило": ["кадило звичайне"],
    "кадровик": ["ейчар"],
    "казан": ["медник", "бакър", "бойлер", "кош", "съдържател", "контейнер"],
    "казання": ["проповідь"],
    "казенщина": ["формалізм"],
    "какао": ["какао-порошок"],
    "калабаня": ["калюжа", "барліг", "баюра", "ковбаня", "калабатина", "бакай", "ковтьоба"],
    "калабатина": ["ковбаня", "калабаня"],
    "каламуть": ["каламуття"],
    "камбана": ["клепало"],
    "кампанія": ["інфо-кампанія", "промо-кампанія", "таймінг"],
    "камрат": ["дружбан", "старина", "дружище"],
    "канавка": ["рівчак"],
    "канарейка": ["канарка"],
    "канарка": ["канарейка"],
    "капелан": ["душпастир", "священик", "поле", "духівник", "сповідник", "пастир", "проповідник", "законовчитель"],
    "каптур": ["відлога", "капюшон", "затула", "коба", "кобка"],
    "кар": ["цирк"],
    "карданний вал": ["кардан"],
    "картопля": ["бульбу", "мандабурка", "буля", "бульба", "бульмани"],
    "каса": ["скарбниця", "віконце"],
    "кат": ["мучитель", "недолюдок"],
    "катакомба": ["підземелля"],
    "категорія": ["клас"],
    "кацап": ["батус", "бацай"],
    "квартоблік": ["квартирна черга", "стати на чергу", "стати на квартиру"],
    "кедрівка": ["горіхівка"],
    "кейф": ["кайф"],
    "кераміст": ["керамік"],
    "керманич": ["кермовий", "стерновий"],
    "кермовий": ["керманич", "стерновий"],
    "керч": ["корчів"],
    "кислиця": ["барбарис звичайний"],
    "китайська мова": ["китайський"],
    "кицька": ["кішка", "киця", "кітка"],
    "киця": ["кицька", "кітка", "кішка"],
    "кичиться": ["гордиться", "хвалиться", "бахвалиться", "похваляться", "заноситься", "чваниться"],
    "киях": ["качан"],
    "київська область": ["київщина"],
    "київська русь": ["давня русь", "русь"],
    "кладовище": ["цвинтар", "гробовище", "могилки"],
    "клявза": ["загата", "гать"],
    "кляп": ["затичка"],
    "кляштар": ["манастыр"],
    "клімат": ["осоння"],
    "клінічний стан хворого": ["загальний стан хворого"],
    "книга": ["книжка", "фоліянт", "друк", "том"],
    "кнопкодав": ["депутат", "маріонетка", "тушка"],
    "княжа україна": ["україна-русь"],
    "кобила": ["лошиця"],
    "кобилиця": ["свинуха тонка"],
    "ковбаня": ["калабаня", "чорторий", "вирва", "вир", "бакай", "нурт"],
    "когут": ["тетерук"],
    "код": ["шифр", "пароль"],
    "коефіцієнт": ["сучинник"],
    "козак": ["запорожець", "низовик", "компанієць", "юнак", "парубок", "молодець", "легінь", "орел", "зух"],
    "козуб": ["козубень", "козубенька"],
    "колесо щастя": ["колесо фортуни"],
    "коловий": ["круговий"],
    "компот": ["узвар", "юшка", "кулага"],
    "комуналка": ["комірне"],
    "комунікатор": ["телефон", "смартфон", "навігатор", "мобільний телефон", "мобільник", "мобільний", "комірка"],
    "комфорт": ["вигода", "догода", "утул", "добробут", "затишок", "зручність"],
    "кондомініум": ["осбб", "об'єднання", "співвласник", "багатоквартирний", "будинок"],
    "контактная сварочная машина": ["контактная машина"],
    "континент": ["материк"],
    "контроля народин": ["контроль над народжуваністю"],
    "кооперація": ["взаємовиручка", "співробітництво"],
    "копченя": ["копченина"],
    "кордон": ["межа", "рубіж"],
    "кореляція": ["взаємозалежність", "взаємовідношення"],
    "корепетитор": ["концертмейстер"],
    "корж": ["опріснок"],
    "користувач": ["абонент"],
    "користь": ["хісно", "хосен", "прибуток"],
    "кориця": ["цинамон"],
    "кормовые деньги": ["командировочные"],
    "коров'як": ["дивина ведмеже вухо"],
    "корсар": ["пірат"],
    "корсет": ["шнурівка", "шнуровиці"],
    "кохання": ["любов"],
    "коштовний": ["дорогий"],
    "край": ["кінець", "пруг", "пружок", "околиця", "окрайок", "окраєць", "шматок", "смерть", "держава", "країна", "сторона", "кордон"],
    "крапельний": ["краплинний"],
    "красноголовець": ["підосиковик"],
    "красота": ["краса", "врода"],
    "країна": ["держава"],
    "крем-фарба": ["крем-блиск"],
    "кривда": ["несправедливість", "образа", "ураза", "шкода", "неправда"],
    "крига": ["лід"],
    "кригохід": ["кригоплав"],
    "кримінологія комунікативна": ["кримінологія масових комунікацій"],
    "кримінологія миротворча": ["кримінологія сутнісна"],
    "кримінологія радикальна": ["кримінологія критична"],
    "кримінологія інтегративна": ["кримінологія конститутивна"],
    "криниця": ["колодязь", "криничка", "криничовина", "чур", "чуркало", "нора", "живець"],
    "криси": ["поля", "вінця", "пруг"],
    "криця": ["булат", "сталь", "кресало"],
    "криївка": ["схованка", "потайник", "сховок"],
    "кругозір": ["кругогляд", "обрій", "круговид", "світогляд", "видноколо", "крайнебо", "небокрай", "горизонт", "овид"],
    "кріпкий": ["міцний"],
    "кузня": ["ковальня", "горнило", "горно"],
    "кука": ["коржик"],
    "кукурудза": ["качаниста", "пшінка", "пшеничка", "кияхи", "чи таки"],
    "культспадщина": ["забуток"],
    "купно": ["сукупно", "укупі", "вкупі"],
    "купол": ["морські котики"],
    "курва": ["хвойда", "шльондра", "шерепа", "любка"],
    "куричка": ["мряка", "мжичка", "мигичка"],
    "кухар": ["повар", "кок"],
    "куче": ["пес", "псе"],
    "кучки": ["сльота"],
    "кшталт": ["гештальт"],
    "кімната": ["світлиця", "цімря"],
    "кін": ["сцена"],
    "кіно": ["кінематографія", "кінофільм", "кінотеатр"],
    "кіоск": ["будка", "рундук"],
    "кіпер": ["голкіпер"],
    "кішка": ["кицька", "кітка", "киця", "котиця", "якір", "кітва", "кітвиця", "кігті"],
    "лад": ["упорядкованість", "організованість", "устрій", "система", "режим"],
    "лазарет": ["лікарня", "лічниця", "госпіталь", "шпиталь", "клініка", "медсанбат"],
    "лазерний диск": ["сідюк"],
    "лайно": ["адзежына"],
    "лайнсмен": ["лінійний суддя", "арбітр"],
    "ламати голову": ["думати"],
    "ласиці": ["лисиця"],
    "ласолюбний": ["хтивий", "похітливий", "плотолюбний"],
    "лата": ["латка"],
    "латинська мова": ["латина", "латинь", "латинська"],
    "лацінка": ["лаціна"],
    "лацінскае пісьмо": ["лацініца"],
    "лев'ячий": ["левиний"],
    "легінь": ["юнак", "парубок"],
    "легітимація": ["узаконення", "адпоція", "легітимізування", "посвідка"],
    "лежати крижем": ["лежати долілиць"],
    "лем": ["всього", "всього-на-всього", "доперва", "лиш", "лише", "лишень", "просто", "тільки", "тільки-тільки", "тільки-но", "усього", "усього-на-всього"],
    "ленник": ["голдівник"],
    "леґалізація": ["узаконення"],
    "либонь": ["ніби", "нібито", "начебто", "мабуть", "здається", "певно", "напевно"],
    "лимпач": ["цегла невипалена"],
    "листопад": ["грудень", "жовтень"],
    "литва": ["лєтува", "летува"],
    "лиходумно": ["зловільно"],
    "лицезрение": ["созерцание"],
    "лицезреть": ["видеть", "зреть", "наблюдать"],
    "лопати": ["лопатися", "тріскати"],
    "лущити": ["злущувати", "облущувати", "вилущувати", "лузати", "теребити", "вилузувати", "розлузувати", "розлущувати", "розлускувати", "вилуплювати", "облуплювати", "обдирати"],
    "льон": ["льон-довгунець", "льон-кучерявець"],
    "любов": ["інтерес", "пристрасть", "схильність"],
    "люди": ["сторонні", "працівники", "кріпаки"],
    "людям на сміх": ["погано", "недобре"],
    "лібрето": ["абреже", "синопсис"],
    "лінк": ["посилання", "гіперпосилання"],
    "лінтер": ["лінт"],
    "лінія": ["лінійка", "ідейність", "ідеологія"],
    "літера": ["буква"],
    "літературно-оповідний": ["наративний"],
    "літній": ["немолодий"],
    "м'яз": ["мускул"],
    "м'який": ["твердий", "цупкий", "ніжний", "пухкий", "крихкотілий", "еластичний", "пругкий", "тонкий", "шовковий", "шовковистий", "пружинний", "пружиновий", "приємний", "дратівливий", "тихий"],
    "м'якун": ["молюски"],
    "м'яч": ["круглий", "гострий момент", "друга половина матчу"],
    "магазин": ["крамниця", "крам", "склеп", "кооператив", "кооперація", "універмаг", "універсам", "супермаркет", "гіпермаркет", "комора", "хижа", "сипанець", "шпихлір", "спіжарня", "шафарня"],
    "магістерська робота": ["магістерка"],
    "мазанка": ["ляпянка", "тынкаванка", "неахайны", "лапцюх", "пуцкала", "аблэхач", "мазэпа"],
    "майстер": ["фахівець", "спеціаліст", "спец", "професіонал", "професіоналіст", "віртуоз", "митець", "мастак", "артист", "штукар", "майстерник", "мистець", "тімаха", "умілець", "вмілець"],
    "майти": ["мабуть"],
    "макабричний": ["страшний", "жахливий", "моторошний"],
    "маковина": ["мачок", "маковинець"],
    "макорженик": ["маківник", "опріснок", "опрісник", "маковик", "маторженик", "медяник", "медівник"],
    "маківник": ["корж", "опріснок", "опрісник", "макорженик", "маковик", "маторженик", "медяник", "медівник", "мачник"],
    "мала батьківщина": ["мала земля"],
    "малобюджетний": ["бюджетний"],
    "малозабезпечений": ["незаможний", "незаможник"],
    "мара": ["привид", "примара", "фантом", "сновидіння", "нечисть"],
    "маршрутизатор": ["роутер"],
    "мастити": ["змащувати", "вимащувати", "змазувати", "шмарувати", "намазувати", "підплачувати", "улещувати"],
    "мати": ["матір", "неня", "ненька", "мама", "паніматка", "породілля", "роділля", "поліжниця", "мачуха", "матінка", "матуся", "мамуся", "мамуня", "мамочка", "мамця"],
    "мачок": ["маковина", "маковинець"],
    "машинозчитуваний": ["машиночитний"],
    "маячня": ["дурня", "абсурд", "нісенітниця"],
    "медицинский работник": ["медработник"],
    "медицинский факультет": ["медфакультет"],
    "медична сестра": ["медсестра"],
    "медична школа": ["медичний факультет"],
    "медичний персонал": ["медпрацівники", "медичні працівники", "медичні робітники", "медичні співробітники"],
    "медичний працівник": ["медпрацівник", "медичний робітник", "медичний співробітник", "медичний персонал"],
    "медичні працівники": ["медпрацівники", "медичні робітники", "медичний персонал", "медичні співробітники"],
    "медичні робітники": ["медпрацівники", "медичні працівники", "медичний персонал", "медичні співробітники"],
    "медичні співробітники": ["медпрацівники", "медичні працівники", "медичні робітники", "медичний персонал"],
    "медпрацівники": ["медичні працівники", "медичні робітники", "медичний персонал", "медичні співробітники"],
    "медіа-персона": ["медійна персона"],
    "менеджмент": ["управління", "адміністрування", "керування", "керівництво", "адміністрація", "управа"],
    "менська мова": ["гаельська", "гаельська мова", "менська гаельська мова"],
    "ментовка": ["ментура", "мусорка", "мусорня"],
    "мета": ["ціль", "мішень", "задум", "намір", "план", "зміст"],
    "металевий": ["металічний"],
    "метушня": ["шамотня"],
    "милування": ["богородиця елеуса", "богоматір милування"],
    "минулий": ["колишній"],
    "мистецтво": ["творчість", "артизм"],
    "митусь": ["врізнобіч"],
    "млавіч": ["умить", "вмить", "миттю", "намліока", "навмлівіч", "навмліока"],
    "мліг": ["мить", "миг", "момент", "мент"],
    "мобільний": ["сотовий"],
    "мов оселедців в бочці": ["як оселедців у бочці"],
    "мова": ["язик"],
    "мовник": ["мовознавець"],
    "могила": ["яма", "домовина", "гробівець", "гробки", "кенотаф", "курган", "льох", "смерть", "загибель"],
    "монокоаліція": ["монобільшість"],
    "москаль": ["вояк", "солдат", "солдатчина", "москвин", "росіянин", "руський", "кацап", "лаптьошник"],
    "москвожер": ["москвоненависник", "москвофоб", "русоненависник", "русофоб"],
    "москвожерство": ["москвоненависництво", "москвофобство", "русоненависництво", "русофобія"],
    "моторошно": ["боязко", "боязливо", "боязно", "жаско", "жахно", "запко", "лячно", "страшно", "торопко"],
    "мужественный": ["храбрый", "стойкий", "энергичный", "смелый"],
    "музичний": ["музикальний"],
    "мукачеве": ["мукачево", "мукачів"],
    "мукачево": ["мукачеве", "мукачів"],
    "мусорка": ["ментура", "ментовка", "мусорня"],
    "мусорня": ["ментура", "мусорка", "ментовка"],
    "міньба": ["міна", "обмін", "вимін", "розміна", "заміна", "міняння", "мінянка"],
    "мір": ["зараза", "епідемія", "мор", "моровиця", "пандемія", "панзоотія", "помір", "помірок", "помірщина", "помір'я", "пошесть", "промір", "промірок", "умирачка", "мертвячка"],
    "містич": ["міщанин", "міщани"],
    "місто": ["город", "базар", "місце", "місцевість", "посада"],
    "місто-побратим": ["споріднені міста"],
    "місце": ["місцина", "локаль", "фрагмент", "позиція", "вакансія", "вакантне місце"],
    "місія": ["завдання", "роль", "дипломатичне представництво"],
    "міць": ["могутність", "могуття", "спромога"],
    "на мліг ока": ["вмить", "умить", "миттю", "намліока", "навмліока", "навмлівіч", "млавіч"],
    "на один зразок": ["на один кшталт", "на один манір", "на один лад"],
    "на один кшталт": ["на один манір", "на один зразок", "на один лад"],
    "на один лад": ["на один кшталт", "на один манір", "на один зразок"],
    "на один манір": ["на один кшталт", "на один зразок", "на один лад"],
    "навдивовижу": ["надзвичайно", "напрочуд"],
    "навмисно": ["демонстративно"],
    "навмлівіч": ["умить", "вмить", "миттю", "млавіч", "навмліока", "намліока"],
    "навмліока": ["умить", "вмить", "миттю", "млавіч", "навмлівіч", "намліока"],
    "навпаки": ["інакше", "протилежно", "наперекір", "всупереч", "назад", "навіґлі"],
    "навчальний": ["учбовий"],
    "навчання": ["наука", "освіта", "напучення", "настанова", "вказівка"],
    "навідлі": ["навідліг", "навіґлі"],
    "навідліг": ["навідлі", "навіґлі"],
    "навіки": ["навік", "надзвичайно", "дуже"],
    "навіґлі": ["навідлік", "навпаки", "навідлі", "навідліг"],
    "надаремний": ["даремний", "марний", "непотрібний"],
    "надарен": ["дарен", "възнаграден", "награден", "удовлетворен", "премиран", "възмезден", "способен", "опитен", "сръчен", "кадърен", "талантлив", "даровит", "умен", "щастлив", "ощастливен"],
    "надити": ["вабити", "рибалити"],
    "надконституційний": ["понадконституційний"],
    "найвищий ступінь": ["апогей", "вершина", "вища точка", "кульмінаційний пункт", "гіпербола", "перебільшення"],
    "накивати п'ятами": ["дати драла", "дати драпака", "дати дьору", "дати дьорки", "драпонути навтікача", "дременути навтікача", "дременути навтьоки", "дати ногам волю", "дати ногам знати", "дати тягу", "дати чосу", "намазати п'яти салом"],
    "намліока": ["умить", "вмить", "миттю", "млавіч", "навмлівіч", "навмліока"],
    "наперсткар": ["наперсточник"],
    "наповнення": ["виповнення"],
    "наподобие": ["вроде", "в виде"],
    "населений": ["залюднений", "заселений", "оселений", "обселений", "замешканий"],
    "населений пункт": ["місто", "село", "селище"],
    "наснага": ["сила", "запал", "піднесення"],
    "науковий ступінь": ["вчений ступінь", "учений ступінь", "наукове звання", "академічний ступінь"],
    "нацвідбір": ["кастинг", "проби"],
    "наявність": ["присутність", "факт"],
    "неблазність": ["цнота", "дівоцтво", "дівочість", "панянство", "незайманість", "невинність", "непорочність", "чистість"],
    "небо": ["блакить"],
    "невинність": ["невинуватість", "неповинність", "безвинність", "безневинність", "непривинність", "непричинність", "невиннощі", "цнота", "дівоцтво", "дівочість", "панянство", "неблазність", "незайманість", "непорочність", "чистість"],
    "невіголос": ["невіглас", "неук"],
    "негативна риса": ["погана риса"],
    "негативний": ["поганий", "несприятливий"],
    "негативний образ": ["негативний персонаж"],
    "негативный": ["отрицательный"],
    "незайманість": ["неторканість", "незачепленість", "нерушеність", "непорушеність", "незрушеність", "непорушність", "непочатість", "цілинність", "цілісність", "цнота", "дівоцтво", "дівочість", "панянство", "неблазність", "невинність"],
    "незалежність": ["автономія"],
    "незворотність": ["невідворотність", "неворіття", "невороття"],
    "неокортекс": ["ізокортекс", "нова кора"],
    "неосяжний": ["неозорий", "безкраїй", "безмежний"],
    "непорочність": ["невинність", "невинуватість", "неповинність", "безвинність", "безневинність", "непривинність", "непричинність", "невиннощі", "цнота", "дівоцтво", "дівочість", "панянство", "неблазність", "незайманість", "чистість"],
    "нетерпляче": ["нетерпеливий", "нетерпливий"],
    "нечто": ["что-то", "кое-что"],
    "новація": ["нововведення", "новина", "новинка", "інновація"],
    "новомова": ["мова пропаганди", "мова революції", "радянська мова"],
    "нога": ["крак"],
    "номінатив": ["називний відмінок"],
    "ночлежный дом": ["ночлежка"],
    "нощ": ["вечер", "среднощ", "тъмнина", "тъма", "мрак"],
    "нульовий": ["початковий", "вихідний", "відправний", "первинний", "перший", "первородний", "первозданний", "первісний", "первобутній", "твірний"],
    "ні разу не": ["зроду", "аж ніяк", "ніяк"],
    "оаза": ["оазис"],
    "оазис": ["оаза"],
    "обалдуй": ["олух", "придурок"],
    "обезліснення": ["знеліснення", "збезлісення"],
    "оберіг": ["захист", "охорона", "заступництво", "прикриття", "забезпека", "заслона", "заступа"],
    "область": ["ареал"],
    "обостриться": ["заостриться"],
    "образ": ["подоба", "подобизна", "абрис", "мара", "мана", "постать", "сильвета", "сильветка", "лик", "копія", "зліпок", "зняття", "символізація", "символьний світ свідомості", "характер"],
    "образец": ["экземпляр", "эталон", "идеал", "шаблон"],
    "обсяг": ["об'єм"],
    "обчищений": ["чищений", "очищений", "дармойований", "обкорований", "точений", "обчухраний", "вичищений", "шеретований"],
    "общественный": ["социальный", "коллективный", "общий", "общительный"],
    "обява": ["обявление", "разгласа", "публикация", "известие", "съобщение", "обнародване", "оповестяване", "афиш", "реклама", "плакат", "антрефиле", "бележка"],
    "обізнаний": ["компетентний"],
    "овва": ["бач", "як", "який", "скільки", "ба", "ач", "ич"],
    "овечий хутір": ["донецьк"],
    "огир": ["жеребець"],
    "огниво": ["криця", "кресиво"],
    "оголошення": ["зголошення"],
    "огудиння": ["огудина"],
    "одарка": ["одарина", "дарина", "дарія", "дар'я", "дарійка", "дара", "даронька", "дарочка", "дарка", "дарця", "даруся", "дарусенька", "дарусечка", "даруня", "даруненька"],
    "одеська область": ["одещина"],
    "один": ["одиниця"],
    "одинокий": ["самотній", "самітний", "поодинчий", "самий", "самісінький"],
    "озерознавство": ["лімнологія"],
    "окам'янілість": ["окаменілість"],
    "окаменілість": ["окам'янілість"],
    "окап": ["черепиця"],
    "океанарій": ["океанаріум"],
    "окличник": ["оповісник"],
    "оклюзія": ["захаращка"],
    "околот": ["фашина"],
    "окоп": ["окіп"],
    "окопчик": ["окіпчик"],
    "окремий": ["окремішній", "окремний"],
    "октаэдр": ["восьмигранник"],
    "олива": ["маслина"],
    "онлайн-платформа": ["майданчик", "онлайн-майданчик", "онлайн-система"],
    "онлайн-трансляція": ["стрим", "стрім"],
    "опінія": ["судження", "враження", "погляд", "розуміння", "уявлення", "поняття", "переконання", "внутрішній голос", "здання", "репутація", "оцінка", "твердження"],
    "орава": ["юрба"],
    "оранжевий": ["жовтогарячий", "помаранчевий", "апельсиновий", "померанцевий"],
    "орація": ["рація"],
    "орач": ["хлібороб"],
    "орган": ["знаряддя", "засіб", "періодичне видання", "деталь", "вузол"],
    "оришина": ["конюшина повзуча", "лишки"],
    "остарбайтер": ["ґастарбайтер", "запрошенець"],
    "отчуждение": ["экспроприация"],
    "оун-р": ["оун-революційна"],
    "офіс-менеджер": ["секретарка"],
    "охайливість": ["охайність", "чепурність", "хупавість", "чупарність", "чепурість", "харність", "акуратність", "ретельність"],
    "охота": ["ловля", "желание", "хочется"],
    "оцелот": ["леопард оцелот"],
    "очищений": ["чищений", "обчищений", "дармойований", "обкорований", "точений", "обчухраний", "вичищений", "шеретований"],
    "п'яніти": ["кучерявиться"],
    "п'яте колесо до воза": ["приший кобилі хвіст"],
    "паливний етанол": ["біоетанол"],
    "пальпаторно": ["дотиково"],
    "памперс": ["підгузник"],
    "панянство": ["дівоцтво", "дівочість", "незайманість", "цнота", "неблазність", "невинність", "непорочність"],
    "паніка": ["переполох", "сполох", "переляк"],
    "папір": ["документ"],
    "парамілітарний": ["напівмілітарний"],
    "парафіянин": ["прихожанин"],
    "пардус": ["пард", "пантера плямиста"],
    "паркан": ["баркан", "палісада", "живопліт"],
    "паркувальний автомат": ["паркомат"],
    "партбос": ["голова партії", "ватажок"],
    "партнерська програма": ["партнерка"],
    "парі": ["заклад"],
    "пасажирський автомобіль": ["машина", "авто"],
    "пасивний": ["неактивний", "інертний", "недіяльний"],
    "патрон": ["набій", "ладунок"],
    "паупер": ["бідняк", "бідак", "незаможник"],
    "пауперизація": ["зубожіння"],
    "певний": ["правильний", "точний", "вірогідний", "спокійний", "твердий", "упевнений", "владний", "вірний", "незмінний", "постійний", "неминучий", "якийсь", "деякий", "незначний"],
    "педколектив": ["педагогічний колектив"],
    "пенис": ["член"],
    "пентаэдр": ["пятигранник"],
    "пеніс": ["агрегат", "антена", "апарат", "аргумент", "багатство", "балда", "банан", "бандура", "бен", "бидло", "біда", "бобик", "болванка", "болт", "бомко"],
    "первинна медико-санітарна допомога": ["первинна ланка", "первинка"],
    "передбачення": ["прогноз"],
    "перелоги": ["судома"],
    "перестраханий": ["перестрашений"],
    "переступень": ["бріонія", "вовчі ягоди", "перелитень", "переступ"],
    "переходный": ["промежуточный"],
    "перигей": ["перицентр"],
    "перигейна відстань": ["перигейна висота"],
    "перформансист": ["постановник"],
    "пзу": ["постоянное запоминающее устройство"],
    "пивовар": ["бровар", "пивоварець"],
    "пилосмок": ["пилосос", "порохотяг", "тягнибруд"],
    "писарь": ["переписчик бумаг"],
    "писатель": ["литератор"],
    "писати": ["заносити", "журналіст", "преса", "бути", "письменник"],
    "письменність": ["грамотність", "писемність"],
    "питання": ["запитання"],
    "плавець": ["плавник", "перо", "крило"],
    "платіжка": ["квитанція"],
    "платіжний термінал": ["електронний термінал", "банкомат"],
    "плахта": ["пакрывала", "шерстухъ", "палатна"],
    "пломба-наклейка": ["пломба-самоклейка"],
    "плотный": ["густой", "крепкий", "сытный"],
    "по": ["программное обеспечение"],
    "побратим": ["товариш", "приятель", "названий брат", "споборник", "соратник", "сподвижник"],
    "побут": ["устрій"],
    "поверхня": ["рельєф"],
    "повсякчас": ["постійно"],
    "повінь": ["повідь"],
    "повісти": ["повідати", "розказати", "розповісти"],
    "погана риса": ["негативна риса"],
    "погляд": ["очі", "зір", "міркування", "помисел", "судження", "думка", "гадка"],
    "подстрекатель": ["подзуживатель", "провокатор"],
    "поділля": ["збруч", "зазбручанське поділля"],
    "пожарное депо": ["пождепо"],
    "пожертва": ["внесок", "даток"],
    "позиціонування": ["налаштування", "аранжування", "калібрування", "впорядкування", "вирівнювання"],
    "позірний": ["уявний", "уявлюваний", "гаданий", "примарний", "мислений", "несправжній"],
    "поисковик": ["поисковая система"],
    "показувати": ["демонструвати", "являти", "появляти", "знайомити", "позначати", "позначувати", "виставляти", "афішувати", "пред'являти"],
    "покрив": ["покривало", "вкриття", "покриття", "конфайнмент"],
    "полива": ["глазур", "поливо", "шкливо"],
    "полосуватий": ["смуговий"],
    "полтавська область": ["полтавщина"],
    "польодовиковий": ["післяльодовиковий"],
    "польща": ["польша"],
    "політичний блок": ["спілка", "союз", "альянс"],
    "поліфонізм": ["поліфонічність"],
    "поліфонічний": ["багатозвучний", "багатоголосий"],
    "помаранчевий": ["оранжево-червоний"],
    "поренче": ["спинка", "бильце"],
    "порнократія": ["темні віки"],
    "поросква": ["бросква", "боросква", "брослина"],
    "порочний": ["розпусний"],
    "португальська мова": ["португальська"],
    "посетитель": ["гость"],
    "послідовність": ["черговість", "систематичність", "лад"],
    "посткризовий": ["покризовий"],
    "постулат": ["аксіома"],
    "потомствений": ["з роду", "з прадіда", "з роду в рід", "родовий", "порідний", "майновий", "удідичений", "дідичний"],
    "похідний": ["вивідний"],
    "похідня": ["факел", "світоч", "світич", "смоляник", "факля"],
    "пошукова оптимізація": ["сео-оптимізація"],
    "правдолюбець": ["правдолюб"],
    "правдолюбство": ["правдолюбність"],
    "правдонька": ["правдочка"],
    "правдочка": ["правдонька"],
    "праведність": ["благочестя"],
    "правник": ["правист", "юрист", "адвокат", "законоведец"],
    "право": ["законодавство"],
    "право вибору": ["право обрання", "виборче право"],
    "правове становище": ["правове положення", "правовий статус", "юридичний статус"],
    "правосуддя": ["юстиція", "судочинство"],
    "правота": ["правилност", "справедливост", "правда", "истина", "правдивост"],
    "прадідівщина": ["прадідизна"],
    "пражець": ["пражанин"],
    "практика": ["діяльність", "досвід", "реальність"],
    "прапор": ["знамено", "стяг", "корогва", "хорогва", "коругов", "хоругов", "коругва", "хоругва", "штандарт", "прапорець", "папороть"],
    "прапороносець": ["хорунжий", "прапорщик"],
    "праття": ["прання"],
    "працелюбство": ["працелюбність"],
    "працетерапія": ["ерготерапія"],
    "прач": ["праник"],
    "преклонный возраст": ["поважний вік"],
    "преторіанин": ["преторіанець"],
    "при": ["біля", "поруч"],
    "приветливый": ["радушный"],
    "призвідник": ["призвідець"],
    "призвідниця": ["зачинщиця"],
    "приймаченько": ["приймак"],
    "прикметниковий": ["ад'єктивний"],
    "приміщення": ["приміщання"],
    "припев": ["рефрен"],
    "приповісти": ["примовити", "приказати", "приговорити", "розказати", "розповісти"],
    "природа": ["натура", "світ", "навколишнє середовище", "навколишній світ", "довкілля", "навколишнє географічне середовище", "суть", "сутність"],
    "прискіпання": ["прискіпування"],
    "приспособление": ["приспосабливание", "устройство"],
    "притулок": ["притул", "пристановище", "азиль"],
    "приход": ["парафія"],
    "приходько": ["прихідець", "прихідько"],
    "прихідько": ["прихідець"],
    "проводар": ["проводир", "провідник", "ватажок", "отаман", "ватаг", "керівник"],
    "проводир": ["проводар"],
    "проворність": ["спритність"],
    "программный токораспределитель": ["птр"],
    "продавчиня": ["продавщиця", "торговка", "крамарка", "торгаш", "спекулянтка"],
    "продажник": ["подкупник", "наемник", "безчестник", "подлец", "вероломник"],
    "произнести": ["вымолвить", "проговорить", "сказать"],
    "проксимальний": ["ближній", "центральний"],
    "промо-акція": ["промоція", "акція", "стимулювання збуту"],
    "промоутер": ["плекач"],
    "проникливість": ["передбачливість", "вдумливість"],
    "проповісти": ["провіщати", "пророкувати", "пророчити", "навіщувати", "провістити"],
    "прополений": ["висапаний"],
    "прорейтингувати": ["означити", "рейтинг"],
    "простат-специфічний антиген": ["пса"],
    "проститутка": ["повія"],
    "проукраїнський": ["український"],
    "професійно": ["фахово"],
    "прясть ушами": ["упрямиться"],
    "пускати бісики": ["грати очима", "смалити халявки", "підбивати клинці", "стріляти очима"],
    "пустеля": ["пустиня", "тундра", "безлюддя", "порожнеча"],
    "путинленд": ["путинстан", "диснейленд", "мордор-путинленд"],
    "пятигранник": ["пентаэдр"],
    "південна корея": ["республіка корея"],
    "півень": ["когут"],
    "півкопок": ["півкопи", "полукіпок", "тридцяток", "четвертак"],
    "підлий": ["підступний", "безчесний", "підлотний", "облудний", "непевний", "лукавий", "облудливий", "каверзний", "пекельний", "диявольский", "гадючий", "зміїний", "намір", "риса", "недобрий"],
    "підповісти": ["підказати"],
    "пізній іван": ["прокрастинатор"],
    "пісуар": ["дзюрник", "сцяльник"],
    "пісюн": ["агрегат", "антена", "апарат", "аргумент", "багатство", "балда", "банан", "бандура", "бен", "бидло", "біда", "бобик", "болванка", "болт", "бомко"],
    "раб": ["невільник", "кріпак", "кріпосний"],
    "рада": ["порада", "нарада", "засідання"],
    "раз по раз": ["раз у раз"],
    "райвідділ": ["райвідділок", "райвідділення"],
    "рак товстої кишки": ["колоректальний рак"],
    "ранок": ["порання", "поранок", "рання", "світанок", "світання", "світ"],
    "рація": ["підстава", "сенс", "глузд", "резон", "промова", "виступ", "мова", "слово", "річ", "орація"],
    "реанімація": ["реанімаційна", "реанімаційна палата", "реанімаційне відділення"],
    "результат": ["виник", "виникнення"],
    "рейдер": ["захопник"],
    "рейкобус": ["рейковий автобус"],
    "репост": ["розшарення"],
    "репрографія": ["репродукування"],
    "рерайт": ["перепис", "переписування"],
    "респектабельний": ["поважний", "гідний", "солідний"],
    "ретинобластома": ["рак сітківки ока"],
    "ретро-автомобіль": ["ретро-авто", "ретро-автівка"],
    "рисунок": ["малюнок"],
    "робити з мухи слона": ["згущувати фарбу"],
    "робот": ["автомат", "маніпулятор"],
    "родительный": ["генитив"],
    "рожба": ["дете", "чедо", "син", "наследник", "потомък", "творба", "произведение", "творение", "дело", "създание", "бебе", "детенце", "кърмаче", "пеленаче", "сукалче"],
    "роза": ["троянда"],
    "розвальцем": ["розвалькувато", "в розвалочку", "врозвалочку", "урозвалочку", "перевальцем"],
    "розтягай": ["пиріжок"],
    "рок-музикант": ["рок-музика"],
    "роковини": ["річниця", "ювілей"],
    "ропетовщина": ["неоросійська стилістика"],
    "російська мова": ["московська мова"],
    "рукопокладення": ["хіротонія"],
    "румунська мова": ["румунська"],
    "русифікація": ["русифікування", "зросійщення"],
    "русь": ["київська русь", "давня русь", "україна"],
    "руський": ["давньоруський", "український", "російський", "росіянин", "москаль", "радянський"],
    "рухоме майно": ["рухомість", "особиста власність"],
    "рушник": ["втиральник", "втиральничок", "набожник", "полотенечко", "полотенце", "рушничок", "утиральник", "утиральничок", "весільний рушник", "вишиваний рушник", "вінчальний рушник", "рушник на покуті", "образ", "брати рушники", "сватати"],
    "різноаспектний": ["багатоаспектний"],
    "різномастий": ["одномасний", "одномастий"],
    "різнопозиційний": ["різноракурсний"],
    "рік": ["вік", "літо"],
    "річниця": ["роковини", "ювілей"],
    "саветник": ["саветодавац", "консултант", "инструктор", "суфлер", "алдерман", "конзулент"],
    "саж": ["хлів", "свинарник"],
    "сайт": ["вебсторінка", "сторінка", "лендинг"],
    "сало": ["здір", "смалець", "лій", "солонина"],
    "самар": ["новомосковськ"],
    "санскрит": ["санскритська мова"],
    "свабода": ["воля"],
    "сватбен": ["брачен", "женитбен", "съпружески"],
    "свобода": ["свободи", "воля"],
    "сволота": ["мерзота"],
    "святогір'я": ["святогірська обитель"],
    "свідомість": ["притомність", "тяма", "розум", "усвідомлення", "світогляд", "світобачення"],
    "свійський": ["домашній", "хатній", "доморослий", "звиклий", "навиклий", "звісний", "звичний", "звичайний"],
    "світанок": ["ранок", "поранок", "рання", "порання", "світання", "світ", "світань", "розсвіт", "розсвітання", "розсвітанок", "переддень", "переддення", "досвіт", "досвіток"],
    "свічадо": ["дзеркало", "панікадило"],
    "свічка": ["свічка згоряння", "супозиторій", "свічка медична", "кандела"],
    "секс": ["статевий акт", "коїтус", "дзюбавка"],
    "село": ["селище", "слобода", "присілок", "оселок"],
    "середина": ["центр"],
    "середній медичний колектив": ["середній медичний персонал"],
    "середній медичний персонал": ["середній медичний колектив"],
    "серце": ["душа", "настрій", "переживання", "чуйність", "чуттєвість", "сердешність", "любов", "кохання", "почуття", "особа", "людина", "вдача", "характер", "норів", "друже"],
    "сестринський персонал": ["середній медичний персонал"],
    "силует": ["тінь"],
    "система воєнно-наукової інформації": ["система вні"],
    "скан-копія": ["відбиток"],
    "скань": ["філігрань"],
    "склонение": ["сгибание", "наклон"],
    "скорочення": ["купюра"],
    "скрапувати": ["стікати", "сочитися"],
    "скрупульозний": ["точний", "пунктуальний", "дріб'язковий"],
    "скръб": ["печал", "тъга", "мъка", "меланхолия", "прискърбие", "отчаяние", "огорчение", "безутешност", "страдание", "горест", "жал", "болка", "траур", "загриженост", "песимизъм"],
    "скіфолог": ["скіфознавець"],
    "слава": ["послава", "поголос", "репутація"],
    "слайдер": ["зринальні вікна"],
    "слов'яни": ["слов'янці", "мала україна", "мала земля"],
    "словаччина": ["республіка словаччина"],
    "словниковий запас": ["лексика"],
    "службовець": ["держслужбовець", "найманець"],
    "смартфон": ["комунікатор", "камерафон"],
    "смелый": ["храбрый", "мужественный", "бесстрашный", "отважный", "неустрашимый"],
    "смерековий": ["ялиновий", "смеречаний"],
    "сміливість": ["смілість", "хоробрість", "відвага"],
    "сміятися на кутні": ["реготатися на кутні"],
    "сновида": ["сомнамбула", "снохода", "лунатик"],
    "соб": ["цоб"],
    "собака": ["дока"],
    "совість": ["сумління"],
    "сон": ["сон-трава", "сон розкритий", "сон широколистий", "анемона", "сон-зілля", "сонник"],
    "сонце": ["небесне світило", "світило", "небесний диск", "геліос"],
    "сооружение": ["возведение", "постройка"],
    "сорокавосьмигранник": ["гексаоктаэдр", "гексоктаэдр"],
    "сорокине": ["краснодон"],
    "сотовий": ["стільниковий"],
    "соціальний": ["суспільний", "громадський", "стратовий"],
    "соціальні відносини": ["суспільні відносини"],
    "соціологія": ["суспільствознавство"],
    "спадчына": ["спадчыннасць"],
    "спеціальна школа": ["спецшкола"],
    "спеціально": ["навмисно", "виключно", "нароком"],
    "спеціальність": ["професія", "фах"],
    "спеціаліст": ["фахівець"],
    "споконвіку": ["споконвіків", "споконвічно"],
    "сполучені штати америки": ["сша", "злучені штати америки", "зша", "з'єднані штати америки"],
    "споруда": ["будова", "спорудження", "будування", "забудування"],
    "споріднені слова": ["спільнокореневі слова"],
    "спосіб": ["засіб", "прийом"],
    "справочинство": ["діловодство"],
    "спрецизовання": ["дефініція", "точність"],
    "сракопад": ["ожеледь", "ожеледиця"],
    "ставити крапку у матчі": ["зафіксувати результат"],
    "ставка": ["штаб", "куш", "внесок", "платня", "орієнтація"],
    "сталь": ["криця"],
    "стан": ["торс", "талія"],
    "старостинський замок": ["галицький замок"],
    "статизм": ["астатизм"],
    "стереотипізовувати": ["стереотип", "стереотипно"],
    "стерх": ["лелека чорний"],
    "стодола": ["клуня", "осить"],
    "стожари": ["плеяди"],
    "стойкий": ["прочный", "крепкий", "железный", "упорный", "упрямый", "несгибаемый", "химстойкий"],
    "столиця": ["стольний град", "центр"],
    "сторона": ["аспект"],
    "стремінце": ["стремено"],
    "стрижень": ["шпень", "шпеник", "шпеньок", "стержень", "шток", "штир", "штифт", "осердя", "кістяк", "осередок", "основа", "серцевина", "бистрина", "бистрінь", "бистря"],
    "строительный надзор": ["стройнадзор"],
    "стрівба": ["пищаль", "стрільба", "рушниця", "стріляха"],
    "стріляти поглядом": ["бісики впускати"],
    "студень": ["грудень"],
    "стьоб": ["глуз", "глум", "насміх", "книпа", "глузування"],
    "суахілі": ["кісуахілі"],
    "субстрат": ["нижній", "шар", "основа", "поживний", "середовище", "підґрунтя"],
    "сульфат кальцію": ["кальцій сульфат"],
    "суперсучасний": ["інноваційний", "інновативний"],
    "суспільні відносини": ["соціальні відносини"],
    "сушарка": ["сушило"],
    "существо": ["создание"],
    "схимник": ["чернець", "монах"],
    "сюрреалізм": ["надреалізм"],
    "сільськогосподарська артіль": ["колгосп"],
    "сільськогосподарське машинобудування": ["сільгоспмашинобудування", "сільське машинобудування", "трактор", "причеп", "напівпричеп"],
    "сім п'ятниць на тиждень": ["флешка"],
    "сірома": ["бідняк", "бідолаха", "біднота"],
    "січ": ["січа"],
    "так само": ["теж", "ще", "подібно", "схоже", "аналогічно"],
    "таксофон": ["телефон-автомат"],
    "тать": ["злодей", "вор", "грабитель", "разбойник"],
    "твердь": ["небозвід", "небо"],
    "творительный": ["творческий", "креативный", "созидательный", "инструментальный"],
    "тека": ["папка", "портфель", "директорія", "каталог"],
    "телик": ["зомбоящик", "блакитний", "екран"],
    "телугу": ["телуґу", "телунгу"],
    "тема": ["тематика"],
    "темплан": ["рознарядка"],
    "тенета": ["кім", "завій", "узвій", "пута"],
    "теологія": ["богослов'я"],
    "тепер": ["зараз", "наразі"],
    "теперішній": ["сучасний", "нинішній", "сьогочасний", "сьогоднішній", "новий", "новітній", "сьогоденний", "сьогорічний", "новочасний", "поточний", "модерний"],
    "термосумка": ["сумка-термос"],
    "термінатив": ["здійсненник"],
    "тернопільська область": ["тернопільщина", "тернопілля"],
    "тимчасово окуповані території": ["ордло", "ордо", "орло", "окупований крим"],
    "ткацький верстат": ["верстат"],
    "тло": ["фон", "полотно", "узир"],
    "тлумач": ["товмач"],
    "тобто": ["цебто", "себто", "сиріч"],
    "топ-менеджер": ["топ", "управитель", "найманець"],
    "торік": ["минулого року"],
    "тощо": ["і таке інше"],
    "трайбалізм": ["трибалізм"],
    "трансгени": ["генетично", "модифікований"],
    "трансивер": ["приймодавач"],
    "тремпель": ["вішалка", "вішак"],
    "триаконтаэдр": ["тридцатигранник"],
    "триб життя": ["уклад життя"],
    "тридцатигранник": ["триаконтаэдр"],
    "тубілець": ["абориген", "автохтон", "туземець"],
    "туріндустрія": ["індустрія туризму"],
    "тут": ["отут"],
    "тюрма": ["в'язниця", "темниця", "острог"],
    "тяжба": ["бечування", "позов"],
    "тяжкий": ["важкий", "нелегкий", "важкуватий", "заважкий", "непосильний", "надсильний"],
    "тяхліти": ["хекати", "дзявкати", "дзяволіти", "лящати"],
    "тітка": ["тета"],
    "убавляти": ["розважати"],
    "убожество": ["убіжжя"],
    "уборна": ["убиральня", "вбиральня", "туалет", "уборна кімната", "клозет", "кльозет", "виходок", "сральник", "гримувальня"],
    "убілюватися": ["полотніти"],
    "увічливий": ["чемний"],
    "угорець": ["мадяр"],
    "угорська мова": ["угорська", "мадярська мова"],
    "угорщина": ["мадярщина"],
    "удобный": ["сподручный", "комфортный"],
    "узвар": ["увар", "адвар"],
    "узел линча": ["висельный узел"],
    "узир": ["тло"],
    "україна": ["русь", "україна-русь", "русь-україна", "київська русь", "давня русь", "мала русь", "гетьманщина", "рутенія"],
    "україножер": ["україноненависник", "українофоб"],
    "укулеля": ["укулеле"],
    "упосля": ["потім", "пізніше", "згодом"],
    "уряд": ["вряд", "поряд", "підряд"],
    "устройство": ["обустройство", "налаживание", "приспособление"],
    "утеміч": ["вночі", "уночі"],
    "утильвиробня": ["утилькомбінат"],
    "учитель": ["вчитель"],
    "учтивость": ["вежливость"],
    "фабіанство": ["фабіанізм"],
    "фаготовий": ["фаготний"],
    "фальсифікаторський": ["фальсифікаційний", "фальшувальний"],
    "фан-камп": ["фан-містечко"],
    "фастів": ["хвастів"],
    "фах": ["професія", "кваліфікація", "спеціальність"],
    "фаховий": ["професійний"],
    "фахово": ["професійно"],
    "фахівець": ["спеціаліст"],
    "федеративна республіка німеччина": ["німеччина"],
    "фермент": ["ензим"],
    "фешн-індустрія": ["мода", "індустрія моди"],
    "флажолет": ["гармоніка"],
    "фонетичний": ["звуковий"],
    "форум": ["веб-форум"],
    "фоса": ["канава", "рів", "рівчак"],
    "фосфат кальцію": ["ортофосфат кальцію"],
    "франківщина": ["івано-франківщина"],
    "фундальний": ["донний"],
    "фізичний недолік": ["інвалідність"],
    "філософський": ["філософічний"],
    "філософія": ["світогляд", "світорозуміння", "світосприймання", "світосприйняття"],
    "фільонка": ["тахля"],
    "філігрань": ["скань"],
    "філіжанка": ["кубак", "кварта"],
    "філістерство": ["міщанство"],
    "фінал": ["завершення", "довершення"],
    "фінуправління": ["відомство", "фінустанова"],
    "фірма-одноденка": ["фірма-метелик"],
    "фірмовий поїзд": ["експрес"],
    "фірмовий стиль": ["айдентика"],
    "хазяйство": ["господарство", "дім", "садиба", "господарська діяльність", "господарювання"],
    "халабуда": ["буда", "курінь", "віз", "ридван", "конура", "будка"],
    "ханбок": ["чосонот"],
    "характер": ["вдача", "тип"],
    "харалужний": ["сталевий", "стальний", "крицевий", "булатний"],
    "харківська область": ["харківщина"],
    "хвальба": ["вихваляння", "похвала", "схвалення", "похвальба", "комплімент", "дифірамби", "панегірик", "мадригал", "хвастощі", "похваляння", "хвастовство", "вихвалка", "самохвальба", "фанфаронство", "фанфаронада"],
    "хвастів": ["фастів"],
    "хвіст": ["потік", "валка"],
    "хмарний сервіс": ["веб-сервіс"],
    "ходьба": ["ходіння", "прогулянка"],
    "хоч мак сій": ["хоч маком сій"],
    "хоч там що": ["хоч там як", "хай там що", "хай там як"],
    "хоч у вухо бгай": ["хоч до рани клади", "і води не замутить"],
    "храбрый": ["смелый", "мужественный", "отважный", "неустрашимый", "бесстрашный"],
    "храм": ["святиня"],
    "хрускіт": ["тріск", "луск"],
    "хтивий": ["похітливий", "плотолюбний", "ласолюбний"],
    "хто-небудь": ["хтось", "будь-хто", "абихто"],
    "хула": ["осуд", "ганьба"],
    "хусейн": ["хуссейн"],
    "хіротонія": ["рукоположення", "рукопокладення", "поставлення", "ординація"],
    "цар": ["володар", "монарх", "король", "бог"],
    "царська горілка": ["царська вода"],
    "цебто": ["тобто", "себто", "сиріч"],
    "цегелля": ["цегла бита", "крихта"],
    "цементація": ["торкретування", "хіміко-термічна обробка металів"],
    "централізація": ["децентралізація"],
    "цесія": ["уступка"],
    "цивілізація": ["прогрес"],
    "цикорій": ["цикорій салатний"],
    "цинамон": ["коричне дерево", "кориця"],
    "цитринова кислота": ["лимонна кислота"],
    "цифрова валюта": ["криптовалюта"],
    "цукрувати": ["цукрити"],
    "цуценя": ["молокосос", "шмаркач", "сопляк"],
    "цюрувати": ["тягти", "рвати"],
    "цягнік": ["поїзд"],
    "цяперашні": ["сучасны"],
    "цілинність": ["цілісність"],
    "ціль": ["мета"],
    "цільба": ["зцілення", "вилікування"],
    "цісаризм": ["цісарський режим"],
    "ціцібенька": ["посмітюха"],
    "чай": ["гербата"],
    "частка": ["частина", "частинка"],
    "чвертка": ["чверть"],
    "чверть": ["чвертка", "навчальна чверть"],
    "червень": ["кресень", "ґедзень", "червивий місяць", "гнилець", "ізок", "коник"],
    "черга": ["колєйка"],
    "чернігівська область": ["чернігівщина"],
    "чистість": ["охайність", "незаплямованість", "харність", "цнота", "дівоцтво", "дівочість", "панянство", "неблазність", "незайманість", "невинність", "непорочність"],
    "чищений": ["очищений", "обчищений", "дармойований", "обкорований", "точений", "обчухраний", "вичищений", "шеретований"],
    "чомусь": ["чому-то", "з якоїсь причини"],
    "чорт є возьме": ["а я відаю", "дідько знає"],
    "чорт є не возьме": ["грець з ним", "пропади воно пропадок"],
    "чос": ["шосе"],
    "чосонот": ["ханбок"],
    "что-нибудь": ["что", "что-то", "что-либо"],
    "что-то": ["нечто", "что", "что-либо", "что-нибудь", "слегка", "отчасти", "как-то", "около", "приблизительно", "порядка", "примерно"],
    "чур": ["криничка", "криничовина", "чуркало", "нора", "живець"],
    "шабасівка": ["шабашка", "суботник"],
    "шаблон": ["зразок", "штамп"],
    "шелепітка": ["мантачка", "хвітька"],
    "шелест": ["шелестіння", "шарудіння", "шурхіт", "шурхання", "шерхіт", "шерех", "шемрання", "шемріт", "шемріння", "шерх", "шерхання", "шерехтіння", "шерхотіння", "шелех", "шамотіння"],
    "шестигранник": ["гексаэдр"],
    "шийба": ["шитво"],
    "широко поширений": ["широко розповсюджений"],
    "широко розповсюджений": ["широко поширений"],
    "шитик": ["пояс", "пасок", "швора", "нашийник"],
    "шконка": ["нары"],
    "шкумиль": ["капость", "пустощі", "шкода", "прикрість"],
    "шкумильник": ["капосник", "каверзник", "неслух", "збиточник", "шкодливець", "пустун"],
    "шкідливий вплив": ["негативний вплив", "шкідлива дія", "побічні ефекти", "небажані ефекти", "негативні наслідки", "згубні наслідки", "пагубні наслідки"],
    "шляйфа": ["шлейф", "хвіст", "трен"],
    "шпирати": ["нишпорити"],
    "штатівський": ["американський"],
    "шум": ["гомін", "шелест", "рокотання", "гуркіт"],
    "шчасце": ["поспех", "удача", "радасць", "задаваленне"],
    "щасливий": ["радісний", "прекрасний", "солодкий", "безхмарний", "незатьмарений", "сонячний", "золотий", "красний", "красен", "променистий", "благословенний", "благословен", "щасний", "погожий", "гарний"],
    "щастя": ["доля", "талан", "жереб", "судьба", "фортуна", "планета", "планида", "уділ", "пай", "задоволення", "утіха", "втіха", "кайф", "кейф", "насолода"],
    "щоб": ["аби", "най"],
    "щось": ["дещо", "приблизно", "близько"],
    "щурик": ["серпокрилець", "стриж", "щур", "ластівка берегова"],
    "электрический стул": ["эдиссонка", "эдиссонинка", "формально говоря", "зубной врач", "на самом деле", "огромная роль", "орудие убийства"],
    "юзерпік": ["аватарка"],
    "юннат": ["юннатівець"],
    "юрська система": ["юр"],
    "яблуко": ["ябко"],
    "ядуха": ["задишка", "астма"],
    "языкознание": ["лингвистика", "языковедение"],
    "яйце": ["яйцеклітина", "яєчко"],
    "яйцеподібний": ["яйцюватий"],
    "яйцеподібність": ["яйцюватість"],
    "як у бога за пазухою": ["як у христа за пазухою"],
    "як-не-як": ["хоч там що", "хоч там як", "хай там що", "хай там як"],
    "який завгодно": ["будь-який"],
    "якстій": ["одразу", "відразу", "негайно"],
    "якщо": ["коли"],
    "ялина": ["смерека"],
    "ялмужник": ["благодійник"],
    "яремче": ["яремча"],
    "яти": ["грати", "їбати", "трахкати"],
    "ячати": ["ячіти", "квилити", "скиглити", "проячати", "проквилятн", "проквилити", "проскиглити", "мекати", "лементувати", "галасувати", "галасати", "кричати", "волати", "ґвалтувати", "горлати"],
    "європейський союз": ["єс", "європейська унія", "європейська співдружність", "євросоюз"],
    "євросоюз": ["євроунія", "євроспілка"],
    "євростадіон": ["євроарена"],
    "єврочемпіонат": ["футбольний чемпіонат", "європа"],
    "євхаристія": ["причащання"],
    "єдність": ["згуртованість", "цілісність", "неподільність", "нерозривність", "схожість", "подібність", "спільність"],
    "єлей": ["олива", "бальзам на душу"],
    "і таке інше": ["і тому подібне", "і так далі"],
    "івано-франківська область": ["івано-франківщина"],
    "іврит": ["гебрейська мова"],
    "іграшка": ["цяцька"],
    "ікона": ["образ"],
    "ім'я": ["імення", "ймення", "наймення", "найменування", "назвисько", "кличка", "ідентифікатор", "мітка", "слава", "репутація"],
    "імплантологічний": ["вживлювальний"],
    "імунітет": ["несприйнятливість", "резистентність", "недоторканність"],
    "іміджмейкер": ["маніпулятор", "політтехнолог", "піарник"],
    "інвазія": ["зараження"],
    "інстаблогерка": ["інстаграмер"],
    "інтернатівець": ["інтернатник"],
    "інтернет-версія": ["хмарний", "он-лайновий"],
    "інтернет-пірат": ["кіберпірат"],
    "інформагентство": ["інформаційне агентство", "інформаційна агенція", "агенція інформації"],
    "інформаційне наповнення": ["вміст", "уміст", "контент"],
    "інформцентр": ["довідкове бюро", "інформбюро"],
    "іт-послуга": ["іт-сервіс"],
    "їда": ["їжа", "страва", "пожива", "пожитки"],
    "їдальня": ["локаль"],
    "їдець": ["їдок"],
    "їдло": ["їжа"],
    "їхати": ["мчати", "рухатися", "пересуватися", "переміщатися"],
    "ґаджет": ["дрібничка", "дурниця"],
    "ґалаха": ["ворона", "ґаврона"],
    "ґатунок": ["сорт", "якість", "різновид"],
    "ґвалт": ["галас", "шум", "пробі"],
    "ґвинт": ["гвинт"],
    "ґданськ": ["гданськ"],
    "ґданський": ["гданський"],
    "ґедзь": ["ґедз", "овід", "сліпень", "дзиз", "дрік"],
    "ґей": ["гомосексуал", "гомосексуаліст", "мужоложець", "педераст", "підор"],
    "ґелда": ["роззява"],
    "ґилбани": ["око", "ґилбаки"],
    "ґля": ["для"],
    "ґречний": ["галантний", "ввічливий", "чемний"],
}


WIKT_SYNONYMS: dict[str, dict[str, list[str]]] = {
    "ru": RU_WIKT_SYNONYMS,
    "uk": UK_WIKT_SYNONYMS,
}


def get_wikt_synonyms(word: str, lang: str = "ru") -> list[str]:
    """Get synonyms for a word from Wiktionary offline data."""
    db = WIKT_SYNONYMS.get(lang, {})
    return list(db.get(word.lower(), []))
